(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   5353797,      90200]*)
(*NotebookOutlinePosition[   5399951,      91733]*)
(*  CellTagsIndexPosition[   5396561,      91619]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["excerpt from",
    FontSlant->"Italic"],
  " Numerical and Analytical Methods for Scientists and Engineers"
}], "Subtitle"],

Cell["\<\
The material in this notebook is copyright John Wiley and Sons, \
2003. Bullk reproduction or resale is prohibited.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["7.3 The Particle-in-Cell Method", "Subtitle",
  FontColor->RGBColor[1, 0, 0],
  CellTags->{"i:55", "c:27"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["7.3.1 Galactic Dynamics", "Subsubtitle",
  CellTags->"c:28"],

Cell[TextData[{
  "\tOur galaxy is a good example of a nearly collisionless (ideal) gas. The \
\"particles\" in this gas are individual stars (see Fig. ",
  ButtonBox["7.9",
    ButtonData:>"Fig. 7.9",
    ButtonStyle->"Hyperlink"],
  "). Although these stars interact via the gravitational force,  for \
individual pairs of stars the interaction potential energy is, on average,  \
very weak compared to the  kinetic energy of typical stars, and so these \
binary interactions can be neglected to  lowest approximation. This can be \
seen using a simple order of magnitude estimate. The average speed of a star \
in the galaxy is roughly ",
  Cell[BoxData[
      \(TraditionalForm\`v \[TildeTilde] 100\)]],
  " km/s. This gives a kinetic energy for a solar mass star of  ",
  Cell[BoxData[
      \(TraditionalForm\`K = \(m\ v\^2/2\  = \ 10\^40\)\)]],
  " joules.  However, the average distance between stars is roughly ",
  Cell[BoxData[
      \(TraditionalForm\`d\  = 1\)]],
  " light year (somewhat more near the edge of the galaxy, less near the \
center).  This gives an interaction potential of ",
  Cell[BoxData[
      \(TraditionalForm\`U = \(\(G\ m\^2/
              d\)\(\ \)\(=\)\(10\^34\)\(\ \)\)\)]],
  "joules, so ",
  Cell[BoxData[
      \(TraditionalForm\`U/K\ << 1\)]],
  " . The typical gravitational interaction between stellar pairs is \
negligible compared to the stars' kinetic energy. "
}], "Text",
  CellTags->"i:76"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000<Z0003:R000`400?l00000o`00003ooooooooo
oooooooooooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`00
oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]
ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003ooooooooooooo
ooooool]ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003ooooo
ooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo
003oooooooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?oooooooooooooooooo
obgooooo003oooooooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?oooooooooo
ooooooooobgooooo003oooooooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?oo
ooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`006oooool04P0;2@X03@/<00`:
2`0B41405aDF00/92P0=2``03`d>00h<3@0=2``03P`=014?40081P/03@/@010>4`0B41D03`dB00L5
2P802`T>00`02PP=00h<4@0?3A8030X=00l:3@0=2@X030P900d92P0@30d04@d>010<3@0B3Pl200X6
1`0300T51P0@30d05A4@00805A4@00D02`L601hJ6@0:1PD030P700X61@0200`81`0;00l;2P0D40l0
3`/:00h:2@0<20L03@T8018>3@0E4A004@d<00d9200<20L00P0>2PT06@0>2PX05A4B014=3P0?30`0
4Ph?00d92P0;20P02@D600/7200A3@h040`=014=3P0D3a005Q0B018>3`0?2``03PX;00/92P0:20T0
3P`=020P800b<S804A4A00D51@0=30d00`0;2@X00`0<2P/03P`=00`:2`0200/92P0900`:2`0;2@X0
2`T:00`:2`0>30d040h?014?400@3Pl02`T:00803@/<018030X;00X82@0:20T02@L800T72P0J61/0
2@L:01PF6@0100803@/>01LE601>C4l07Q`O018@4`0G5AP01`D800X82@0;2@X200h<3@0;00d;300;
2@X00`42018@4@081PL04@l@00/92P091`P01`D600T7200>30d00P0@3Pl0100>30d03@/<014?4007
1@H200l=3P0?00h<3@0>31404A0D0040100E4aP02PP=01<A5P0<2Pl03`dB00X83@071@X02@L<00`:
3`060`X03@XA008030T@00@08AhU00D22@0;20l02`P?0P0<2A0200d:4@0>00`:3`0;2@h03@/@00h<
4@0=2a002@L<00/93P0:20d020H;00L52P0:20d03@/>00h<3P0?3@h2014?400>00`:2`091`P030X;
00X82@071@H03P`=0040000P7Ql030/=01@B5@0=2`h030X=01dK7P01008600`:3@0400X83@0:1`h0
2PL>00X74P802PHD00/02`LE00T64@0:1a002`P?00d;400?3A0020H700`:2`0M6ad05A<F00`:3`02
00d;400<00/83`091Pd02PL>00X73P0<2A8030TD00P5400710h02@H?00d:4`0>2a<030T@100<2Pl0
2P0<2A00514J03Tf?`0]:S802`P?01@A600:20h030X?00`:3@0;2@`200X82`0=00401@0F4aX02@H=
01dJ8@0T8BP02PP>01DB6@050PT02PL>00H32P091Pd030X@00`73@0200d8300B00/62P0<1`/04`hB
05IAE@0P6al03@P<00h93@0<1`/03`X>00`:3@0:20/020H901LE600B41<01`D800`:3@0=2`h03`d@
0P0<2Pd03`0>30l040dD00D32@0B3aH02PL>00T63@0C41L01P<:02PU;00B3aH00P0600`9400=2a00
2@L:00T7200200X82@0:00/92P0<2P/01P@500L51P0=2``02`T:00L51P0?3@h030P900X61`8020@5
00T02PH700`82@0K5aP02@D600D10P0B3Pl020@5010<3@091@H00P0>2P/0100<20T03PX;014=3P0?
2``200d92P0800/720070`@0100100`82@091@H020@500X61`0=2@X200h:2`0300`82@0;1`P02PH7
00802PH700P020@500/720050@803@T:00l;30050@803@T:00`82@802@D600<04@d>01LC500<20T0
100<20T02P0=2@X03PX;01<?400F4Q<03PX;00d92P0>2P/02PH700/7200>2P/200`82@0300l;300>
2P/02`L800802PH70P091@H0300;1`P03@T:00h:2`0=2@X02`L800`82@0H51D07QXK010<3@070`@0
2`L800d82`D02PD900@02`H:00`72`0<1`/02`H:0P0:1@T01P0?2Q403PT@00/63@0910/02PD<00`7
3P803PT@00@02PD<00`73P0?2Q402@@;1P0<1Q001P0?2A<03@LA00/53`0@2Q@01P0:00d74@H030L>
01X03PT@00T42`0<1`h04@`C00/63@0<1`h03@/@00X93P0920h02PPC00T84`0411001`LC00h?6P0L
7bH0=3Ln00/=4@020`L02PP=00h93`0910X03PT?00T52P0A31802PD;00/6308030L=00P02`H<00X5
2`0:20/01`D801<A500<2Pd01P@700@21@8020H900d01P@700d;3P040`D04@lB00l:3P0=20`030L;
00/62P0:1@T02@@800d8300;1PX030L;00803`X>00H03@P<00d;3P030@@02PP;01@B5@071@P300`:
3@802`T<0P0:20/08`0?2Q0030L=00`73@0?2Q403PPB00d74@0;1@l02`H=00`73P0>2@l03`X@010;
4P0?31H03P/D00d:4`0;21402PL>00P52`0>31404Q0C00d;3@0>30d04Q0A00h<3`040PL02PP=00d;
40071@X09R@Y07ajO`0M6b000`4600P62`0C4AH020H;00802PP=01002@L<00`:3`0?3A803`dB00d;
400@3Q<04a4F014?500E4aP040hC00`:3`040PL03`dB00h<4@0H5Q/04PlF0`0:1a0200X74P0300X7
4@0:1a002`P?008030T@0P0;20l00`0?31<03P/B00d:4@0200`9400@00d:4@0:1a002`PA00d:4`0<
2A002`P?00X73P0>31401P@900`:3@0>30l05Q@G00L6200<1`d03@P>00l:4@803`TC00P03@LC00<0
1`0E3aP040/A00/6300A3@l03PX;00/62P804@`@00D050lC00/62P0C3Q8040/?00l:3P0200h93@0E
00l:3P0@2`l040/?00l:3P0=20`03PT=010;3`0A31003@P<010;3`0;1PX03@P<01<>4P0>2@d04@`@
010;3`0=20`02`H:00h93@0C3Q803@P<00<03`X>00H040/?014<400A31003PT=00`72`0;1PX200`7
2`803`X>0P0@2`l0400?2Ph03PX;00`8200@2`l02PD900`83P0K5Al01`4;014;500A31<03@P<010<
2`0C3``040`901<=3P0G4A<200l92`0V01<=4@0<1PX03PP<00d63@0>1`h03`P?00T22P0F41D030H8
00X41P0=1`T050h@01LA4`0>20X01@0101hH6P0=1`T08A/M00@0000=20T030H800d72@0C3@l02P@6
01hH700Y8bL02@<700D01@0H4AP01`0701D>5P0=1`d05Q0D00d72`0=20/03`T=01D?4`090`L200`6
2P0400d72`0<1PX02`D900h52PP040D;00/03`@:00h32@0>0`T0304701873@0>10T02`0601<83P0<
0`L03P<900l42P0201052`803`@:00T03P<;00d22P0=0PX03@8:00h32`0@1@d03`@<00h32`0?10`0
0P0A1Ph01`0>0`/03`<=00h2300>0P`03@4;00h2300?0`d00P0=0@/200h230803`<=00`01`040187
3`0<0@T0304901D:4P0=0PX04@H>00/1200>0`/040D=00`12@0;00PDooooo`006oooool03P0<2P/0
3`d>00d;300>30d03`d>00P61`0@3Pl030X;00/92P0=2``03P`=00`:2`0?3A0030X>0P0:20`0200=
2`l03`dA00`:3P0:20`02@L;00d;3`0<2Ph02`T<0`0>2P/200l;300=010<3@0?2``020@501<?400P
71d03@T:00`82@0>2PT03@T801<?3P0<20L040`;018>3@0200d9200<014=300?2`X03@T800l;2P0;
1`H03PX900l;2P0>2PT03`/:010<2`0>2PT03@T80P0?2`X0700;1`H02`L700/7200@30d0510A00D1
0P070`@0510A01LC500@30d03@T:00l;300;1`P03@P900`6200;1`P03@T:00l;300?3@h04@l@00H4
1@0<30`0410@00H61P0:2PX02`X;00/92P0<2P/300d;300300`:2`0;2@X030X;008030X;00L02`T:
00d;300=2``03P`=010>3`0?3@h02`T:00803@/<018030X;00/92P0:20T02PP900/930061@L0G5YM
020N8@0<2Pd03`d@00@21@0G5AP02@L:00d;3P0;2@`030X=00`:2`0=2``200l=3P0700h<3@0=2``0
928S02XX:@0>30d02`T:00H41@0200`:2`0400d;300?3@h03`d>00`:2`802PP901L03P`=00`:2`0@
3Pl01`D600l=3P0:20/03@/?00`:3P0?3A403P`@00H4200:20`03@/?00h<400=2`l03`dA01<A5@0?
3A<02`P>010=4`081@/08QlU01PF700200/93`8030X@00P03@/A00d;400<2Pl02`T=00d;3`0>3100
3@/?00X830@02`T=00<03`dA01<A500>30d00P0:20T03`0;2@X02PP900T7200>30d03`d>00L51P0:
20T05A<D0490@@0Y9bX01@<600T72P0?3A003@/>00l=400600/9300400X8300:20h02PL>00X74@80
2PLC01T03P/F00`9500<2A4030X?00d;400?3A001`D700H41P0A3a803@/>00X83@0?3A801@<800T6
3@0P7B@05Q<J00/8400A3QP04a0K010=600>2aD03@XC00h;500>2a<03@XA00@03@/@00T03P`C00L4
3@0E4Q/03``D00L42`0A3QD02@L=00`:3`0<2Pd00P0;2@`0400:20/040hC00L52P0:1`d030/@00h<
4P0<2@l01P@9010>500=2Q00=c@j01LD6P0:20d030L;00d8300>2@d200`72`0400l:3P0@30l030L;
00`72`804@`@01X03PT=00P72@0920X03`d@00/9300920X040hA00T72P0;2@`030X=00X82`091`X0
2`T<00/93P0>2a407A/Q06]XKP0;20h0;b`b05=@EP0B3aD04a4F00l<4P0;2@l020H;00P62@802@L8
00T02PP900/92P0;2@X02@L800X82@0?3@h03@/<00P61`0;2@X01P0<20T00`0=2@X03`/<00/72002
00d92P802@D601402`L800`82@0<20T02PH700T51P0;1`P02PH700`82@0>2P/030P900X61`0>2P/0
30P900/7200<20T03`/<010<3@0200/7200:00X61`0<20T03@T:00d92P0E4A8071PI014=3P0:1PL0
3PX;00d92P8030P900@02`L800d92P0C3a005a<D0P0=2@X400`82@802PH700d03@T:00X61`0:1PL0
2`L800T51P0:1PL030P900d92P0>2P/03@T:00/720091@H030P900803`/<00<030P900/7200<20T0
0P0<20T0200;1`P030P900h:2`0=2@X02@D600`82@0;1`P02@D71@0:1@T00`0;1PX030L;00`72`02
00/62P0800X52@0<1`d03`XA018=4`0=20h02`H<00`73P080`T200/6300300X5300>2@l03PT?00H0
30H@00L0208<00X43P0C3AL08adW01H@6P070P/030L>00D030L=00@030L>00P32P0:1@`03PT?0P0:
1@/04`0810X02`L=00P6300610d03P/G01PG8`1EE60061PS09RJX@33aLX06A/P00H72`081P/030L=
00D01P0<1`d02PH;00h93`0;1P`0100<1`d0100;1P`0108500X82`061@L200X82`0900h<3`0?3A00
2`T<018@4`061@L030X=00L5200>2@d03@P<00<030L;00@02`H:00h93@0;1PX030L;0`0?2Ph02P0;
2@`01P@700d;3P0B41<01`D800X82`0<2Pd02`T<00X82`091`X200P62@05010<4P0>2Q003PXA010<
4`0@2aD00P0?2Q@01P0=2A0030P?00`83P0<20h030P?00/84P<02`PA00P02`P?00/83P0;2@h02`T<
00d;3@0D4Q<04a4B00l=40802@L<00`02PP=00D4200:20d06aTN00<21P0B41D01`D:00l=4P061@T0
3@/@010>4`0=2a0200/93P802@L<00/02`T>00h<4@0=2a002@L<00P62`0;2@h071XO03Pf>`0R82D0
30X?01DB6@0300d:4`803@XE00<03@XD00/84@0;20l00`0<2A0200/83`0D00X73P0;20l030T@00h;
4P0@3A@030TB00d:4`0?31D03``C00h;4P0=2Q403`dB00X83@0?3A0020H900T72P0=2`h03PT>00l:
3`0@2a82010:500?00l95@0<2100;BL`03Lb>00E41H03PX<01DA4P0<1`/04PdA01PC5`0P6al04PdA
00h93@0=20`03`X>00804@`@00<03`X>00d8300@2`l00P0@2`l0300B3A405A0D01LB5P0=20`04`hB
00l:3P0=20`04@`@010;3`0;1PX03`X>010;3`<03`X>00<03@P<00l:3P0?2Ph00P0?2Ph00`0@2`l0
4PdA010;3`0400h93@803`X>0P0@2`l0400?2Ph03PX;014=3@0A31003`X>00h9400<1Q003@PA00d8
400<1`d040/?00h:2P0;1`@03PX701@>3`0H4Q@200l92`0D014;3`0<1PX04P`@01<<4`0<1@`050dD
00X32`0>20d04@/=01PB500A2`d03`T;014;3@0;1PL0618D03H`<P0D3Q004@/=00H10P0D3Q0200/5
1`0@014;3@0:1@H02`D901@>4P070PD050dD00`6300=1Pd06A8J00h83P0=1`/01`45014<3`070PD0
5@lC00`62P803PP<00@03@L;00`62P0<1PX03PD:200@1@/200l42P0900h32@0B1`d03`@:00`11`0=
0PP03`@:01052`0>0`T03`@:008040D;0P0?10X03@0>0`/03@8:00d22P0=0PX03P<;01053@0;0@P0
3@8:00h32`0=0PX03P<;01463P0?0`d00P0>0P`0100=0@/03P8<00l33@0=0@/300h230803`<=00`0
3@8:00h32`0?10`03`@<00d32P0900H02P0700d22P0A1Ph03`@<00X01`0?10`Dooooo`006oooool0
4`071@H02`T:00X82@0:20T030X;00h<3@0M6a`05A<D014?400C4A804@l@00X82@0>30l03`d@018@
4`0@3Q402PP;00/9300B41<00P0=2`h0700?3A003P`?00l=400=2@X03`/<010<3@0A3@h03`/<00h:
2`0B3Pl04@d>010<3@0D41403@T:01<?400:1PD030P700/71P091@@01P8101<?3P0<20L02@D400d9
200>2PT03@T800l;2P0;1`H200l;2P0300h:2@0?2`X04@d<008030P701P03PX9014=300?2`X03@T9
018>3`0A3@h03`/<01`H6@0J5QL03`/<01dI6P0>2P/09R8S04A0@@0T82404Pd?018<3P0A3@h03`/<
00d92P0<2P/03P`=00D3100@410200/;2`0601PH600920T02`T:00d;300?3@h03@/<0`0;2@X01`0<
2P/03@/<00`:2`0;2@X030X;00/92P0<2P/00P0>30d01@0:20T03@/<00d;300=2``030X;00802`T:
00d040hA00/9300?3Q0040hA00X82`0>30l04a4D00P62@0=2`h03P`?00X82`0>30l02@L800D02PP9
00H04@l@01`J6`0;2@X040h?00d;300@3Pl300h<3@0A00d;300:20T020H700T7200:20T04@l@01DC
500<2P/08R0Q01TG6P071@P02`T<00`:3@030P@04@lB00/9300:20/00P0<2Pd020091`X030X=00/9
3P0=2a009R@Y018@5@0@3Q<00@040P0;2@h200`:3`803@/@00<03@/>00`:3@0<2Pd00P0=2`h02P0:
20/030X=00`:3@0:20/020H900T72P0;2@`040h?00/92P0:20T300/92P0:00P61`0=2``040h?014?
400100002@L800d;3P0A3a800P0300P62@P02PP;0P0;2@`06@0;2@h02`P@00/84@0;21403``F00d:
4`0=2Q0030X=00/9300>30l02`T<00P62@0=2`h030X=00`:3`0A3a@01`D:00H32P0E4QT04@hE00h;
500>2aD02@HA00X74P0;21800P0;21400`0;21002`P?00/93P0300/93P0800d;4P050P/02PL@00h;
4`0@3A@04PlF00P6300;2@h400/9300@00l=4P0G5AX00@0400d;400100@02@L<01PF6`0100@040hC
07EcN00G5AX01`D:00/62P0<1`/03@P<00`72`802`H:00l01`8601LB5P0?2Ph040/?00/62P0@2`l0
H5iQ04E3AP0Y9bX00@0200T72P0@3Q4020H900T72P0;2@`00P081PT02P0:20/04@lD02h/<@0D4QL0
1P@901DC600A3a@03`dB010>4`091``200/93P0300<110081PT020H700@02@L800P02PP900`:2`0>
30d03@/<00P61`0610D02`L800d92P803PX;01X03@T:00/720091@H030P900h:2`0;1`P03`/<00X6
1`0>2P/030P900d92P0?2``02PH700H20`0>2P/02`L800`82@0=2@X02`L800T51P0=2@X030P900/7
200=2@X03PX;00l;30<02`L800P030P900d92P0>2P/0510A01XF5`0?2``01@4200/720803PX;00<0
3@T:00/720091@H00P0810D0200?2``03@T:00d92P0;1`P02PH700d92P0:1PL020@50P0>2P/01@0;
1`P030P900h:2`0>2P/02`L800803@T:00<03`/<010<3@0=2@X00P0<20T00`0;1`P02PH700X61`04
00X61`0700`82@0;1`P01P8300P41@0B3Pl04@d>00/72@0;00/62P0900T42P0>2@l04@`B00P32@04
00D02`H<00h93`0C3Q@04@`B00<02@@:00<030L>00`6400<1Q000`0<1Q0200X43P0400T33@0G4A/0
4P`F00`63`H02`H<01X03`X@00d83P0=20h03PT?00d83P0;1P`030L=00d83P0910/01`4;00/84P0F
4R00:bLe00D43@0;2a<0:2L]00h?4`0A41D02@L<01@?5@0;1P`03@P>00/6300A31802`H<00`73@80
3@P>00h030L=00/6300C4A@02PP;00/9300>30l04Q0C07ilO`0G5AP01`D800@21@0O7B002@L:00X8
2`8030L;100=20`0100>2@d02PD900X52@0<1`/200h93@0300X82`0610L01085008020H900<01085
00X82`0:20/00`0:20/02P0:20d03P/B00d:4@0>2a8040dD00l<5@0>2a@03``E00d:4@0<2A0200/8
3`0300/84@0:1a402PL@00802PL@00P02PL>00X83P0;2@h02@L:00X82P0A3a003`d>00P62P801P@9
01003@/@01LE6P0C4AH03@/@01DC600K6Ah0108701/I7P0?3A803P`A00`:3`0:20d02`T>00d;400<
2Pl03P`A0P0;2@h0100?3A802`T>00`:3`0C4AH200X83@0300T7300?3A802@L=00<02`PA0P0;21<0
0`0;21802`PA00/83`0200d:4@0600`9400;20l040dD00l<4`0=2Q402PL>0P091Pd00`0;214030TB
00l<5@0200l<4`0700d:4@071@X02@L<01HD5`0:20/01@<601/I7002010;3`0B010;4@0@2a8040XD
010:5P0S7BL030P?01@?5@0>2@l050lB00<0000B3A403@T<00L21P0>2@d020<700h93@0=20`03`X>
0P0A31001P0?2Ph03@P<00`72`0=20`03PT=00l:3P804@`@00<03@P<01@?4`0B3A400P0=20`02P0A
31002@@800h93@0@2`l03`X>00h93@0?2Ph03PT=00d8300>2@d2010;3`0300l:3P0A310040/?0080
3`X>0P0>2@d200l:3P8040/?01003`X>00h:2`0<20P020@501<>4P0j=C/09R0Z01D?6@0>2A002`H<
01HA5@0A30l020@3010<2`0A2`d050h@0P0?2@/04P0A2`l03`T=010:3P0;10/03PL>01@=500700P0
40X?00@0000500402`D700`6200@2P`03PP:00D00@0=1`T02`D701hH6P803`T;01@040X<00`62009
0`D03@L900`62P0=1`/08Q`P00T22@0D3a@0100400P12@0<1@`04`dA010:3P0D3Q803PP<01PB5P0<
1PX03`T=00h830<03@L;00<03`H;01052`0@1@/00`0@1@/600l42P0801<83P0:00D04@H<01P=4`0@
1@/04@H<00h32@0?10X201052`803`@:00d03P<;00d22P0=0PX03@8:00h32`0@1@d0200500`12@0?
10`03P<;01463P0M4QX03`<=00803P8<00<03@4;00h2300?0`d01P0>0P`0300A1Ph0304901<8400@
1@d02@0601P=5@0B1`l03`@<01053@0>0`/02`0800l431Cooooo000Kooooo`<02PP901402@L800/9
2P0?3@h05A<D00h<3@0;2@X03`d>00h<3@081PL02PP;00/9300@3Q403P`?00/9300A3a804Q0C00X8
2`0200/9300400T72P0=2`h03@T:00l;30804@d>0P0?2``0100<20T040`=00L3100A3@h2018>3`09
01DA400400000`00014=300?2`X02PH501<?3P0;1`H030P700803PX900<04@d<00l;2P0?2`X00P0>
2PT05@0B3Pd05A4@00h:2@0;1`H030P7014=300E4A004Ph>00T51P0>2P/04Ph?00<000050@8040`=
01XF5`0<20T09R8S04I2@`0W8b@03`X<00/51`0200d92P0@00`82@0<2P/03P`=00H41@0>3Ph01PH6
00d=3@0W9bL05aHF00/92P0=2``03`d>00d;300;2@X02PP900`:2`<03@/<0P0<2P/200/92P0300d;
300>30d02`T:00<03@/<0`0<2P/0300100805Q@G00T72P0D4QD01@<601<A500<2Pd0108500`:3@0:
20/040hA018@4`<02PP900T02@L800X82@0:20T00@0000h<3@050`@04@l@00l=3P0A3a001@0<2P/0
3`0;2@X03@/<00/92P0@3Pl0518C00h<3@0W9BH0=38e01DC5P0100807Q`O01DC5P0200<040hA00`:
3@0200l=400600/9300>30l0:RP]01/I7P0Q7b@03P`A0P0A3a@200/93P8030X?0P0=2a001P0>30l0
2`T<00/9300<2Pd03@/>00/9308040hA01H03`d@00`:3@0<2Pd03@/>00d;300;2@X030X;00d;300;
2@X02PP900T820091`P02`T:010>3`0:20T040h?01@B5@0A3a80518E00X82`030@@0518E1P0<2Pd0
100;2@X02`T<00/93P0;2@l200/83`0I00d:4P0<2A0030X?00/9300:20T03@/=00d;3P0<2Pd03`dA
00d;400<2Pl03@/A00l<4`0>2a802@H>00`94P0?31D03@XD00`9500>2aH03``F00l<5@0>2a@03@XB
00d:4@0400d;400400`:4@081@h02`PA00h;4`803@XA00<02@L=00/93P0;2@`00`0;2@`00`071@X0
1@<8014?500200d;400301DC600:20d05A<H00803`dB00@05Q@I010>4`0<1`/030L;0P0=20`08@0<
1`/02`H:00/62P0?2Ph01P45010;3`080`L050lC0:VWZP0Q7b806ALJ034_<P01008030X=00T72P0;
2@`030X=00X82`091`X02`T<00`:3`1UHfP00`46010>4`040PL07A/P01<A5P020@D0GE]P08n=TP0:
20d04Q0C00T72P0600T7200700`:2`0;2@X02`T:00T720050`@02PH700`82@0200d92P0900`82@0:
1PL03`/<00X61`0<20T03`/<00h:2`0@30d03`/<008030P900@03`/<00/720070`@03PX;0P0;1`P0
0`0=2@X02`L800X61`0300/7208030P900D03@T:00h:2`0=2@X030P900/7200200`82@803PX;00L0
2@D600P41@0<20T03@T:00P41@091@H02PH700803@T:01L030P900l;300=2@X03@T:00/7200:1PL0
30P900X61`0;1`P04`l@010<3@0;1`P02@D600`82@0;1`P02@D600h:2`0@30d04@d>018>3`0?2``0
3@T:00/7200200T51PD02PH700L02`L800`82@0:1PL02@D6010<3@0B3Pl03PT<00/02`H:00T01P47
00/6300=20h01P4700L2200C3Q@05A0F01XE6`0G4QP00P0=20h00`0<1`d030L>00`73P0400`73P06
00/63@0=20l01P4800/63@0:1@`040/B1P0;1P`06@0@2a403`X@00d83P0=20h03PT?00/6300>20`0
30D;00X32`0;0`h030HA00`64P0300T02`PB00`;4`0@3A@00P4600000P081P/06A@J00l:400>2@l0
30L=014<4P0;1P`0100=20h03@0;1P`02`T<00D31P0;2@`04Q0C01LE6029QhX04a4D014?4P0E4aH0
HEmR010>4@0=2`h00`0=20`300h93@0I00d8300910P02@@800/62P0<1`/02`H:010>4@030@@05aDH
014?4P081PT04Q0C00T72P0:20/02`T<00h<3`0?3A003`dB00`94@0<2A803P/D010=500>2a803@XA
00h;4P0200d:4@0<00d:4`0>2a@03P/D00`94P0;21402PL?00T63@081@`02@H<00`:3`0<2Pd02@L:
0P0;2@`0400=2`l04Q0E00d;400:20d04@lD010>4`081P/04@lD01@B5`0E4aP08b4V00l=4P0<2Pl0
2PP=00T7300;2@h200h<4@0500l=4P0:20d01`D:00d;400?3A800P0>31401@0<2Pl03@/@00P62`0<
2Pl0514H00<02`PA0P0;21<00`0;21802`PA00`9400300d:4@0:00`940091Pd02PL>00/83`0<2A00
3P/B010=500:1a002`PA00d:4`803P/B00L03@XA00/93P0?3A8081hQ01<A500=2`h08AlR008040`=
018040/@010;4P0@2a8040XD00l94`0=2A003`X@00<0100A3@l06aLH00`72`0D3a<05a8F01`G6`0@
2`l04`hB010;3`0?2Ph200h93@0300l:3P0@2`l03@P<00@03@P<00P030L;00h93@0C3Q8050lC00l:
3P0<1`/04@`@00`72`803PT=00@03@P<00h93@0A310040/?0P0>2@d00`0B3A404@`@00l:3P0400l:
3P0400h93@0=20`03`X>00l:3P8040/?01803`X>00h:2`0A3@d081`M00h93@0H51T03PT@00@01P0?
2Q4030L=01LB5P0A30l020@3010<2`0>20X04@/=00l92`0@2P`2018<400Z00d72`0400@05@hE01H?
5P0@2A40;2H[01@>4004000040X<00`6200=1`T03`T;010:300H4Q@030H800d72@0;1@L03`T;018<
3P0C3@l030H800h82P0@2Ph030H:00@00P0I4QT04P`B02lX;`2RVj<06A8I010:3P0400805a8E00@0
0P0:10P04P`@00l93@0>20`03@L;00h8300?2@d040P=1@0@1@/600l42P0801<83P0<0@L06PlE02DJ
800G31804PL=00h32@0?10X201052`803`@:00d03P<;00d22P0=0PX03@8:00h32`0@1@d02`0800h3
2`0A1Ph03P<;00l4300J3aL03`<=00803P8<00<03@4;00h2300?0`d01P0>0P`02@0?10`03@8:01D:
4P0>0`/03@@:02XO9`0N4a/040D=00`12@0200h32`0300d22_oooooooooo01;ooooo000Kooooo`0H
01HD5@0=2``030X;00`:2`0;2@X03P`=00d;300<2P/02`T:00h<3@0@3Pl03`d>010>400;2@/03P`>
00l=3`0E4aD0:BLY01XH6P0>30h040h@00h<3P0;2@/04@lA0P0?2``2010<3@804@d>01804`l@00/7
200;1`P05Q8C00h:2`0?2``03P/:00h:2@0J5QD0510?014=300>2PT06aLF00h:2@0?2`X04@d<010<
2`0A3@`2010<2`803`/:01P04`l>01HB4@0D40l03PX900d9200A3@`0510?014=3@0C3a003@T:00l;
300k=cP0<bl`00d92P0C3a003PX;00d92P0B3Pl03PX;018=3`0F41805a<D018>3`0;1`P200X82@06
00/92P0C4a<03`l?00T92@0=3@d030/<0`0=2``00`0<2P/02`T:00`:2`0200d;300400h<3@0=2``0
3@/<00d;308030X;00<03P`=00l=3P0>30d01P0=2``0100@3Q401`D8014?4P081PT200h<3`803@/>
01@03P`?00/9300>30l03@/>00l=3P0>30d03@/<00`:2`0=2``03`d>00`:2`0G5AH01`H600h<3@0;
2@X03`d>00/92P0:20T02`T:00`:2`803@/<01P03P`=00l=3P0;2@X040h?00`:2`0G5AH02`T;034_
<@0>3@h030X<00d;3@0?3Pl04a4C00P6200<2P`03P`>00/92`0B41806QPL01@B5P0;2@d03@/?00/9
3@0<2Ph200/93@8030X>00T03@/?00d;3P0?3A002`T;00X82P0<2P`03@/=00`:300;2@/00P0=2`d0
1P0<2P`03@/=00h<3P0:20T020H700T720803@/<00d030X;00X82@0F51D0518C00T8200<2P/04@l@
010>4@0;2@`04@lB00h<3`0B41<02`T<00D030X=00D030X;00`;2@0<2`X030X<00`:3P0200`:4006
00/93P0<2Pl03@/>00`;2P0;2PP030X;0P0=2`l200`:3`0400/93`091`d04@hE01DB6P803@XC0P0<
2A<2010=600500h;5@0<2A802`PA00d:4P0@3A@0100@3Q<0200?3A@040dF00`94P0:1`l02`P?00h;
4P0?3A<02PP=0P0;2@`200`:3@0@02TW:`1JF5`040hB00/93@0@3Q802`T=01HD60050`L030X>014?
4`0610P02`X=00h93@0<1`/02`H:00d830803`X>01D04`hB00d8300>2@d040/?00/62P0>2@d0928U
01<A500<2Pd01`D800d;3P0>30l02`T<00`:3@0=2`h02`T<00X82`0<2Pd03P`@00d;3`0<2Ph00P0?
3A401`081PX01@<7014@4`0A3a<0<c4e00X8300920X00P0<2P/300/92P802PP900D02`T:00T7200<
2P/040h?00/92P0600`82@09010<3@0S7b0020@5014=3P0?2``04Ph?00d92P0<20T02`L8008030P9
0P0=2@X200/7200300h:2`0?2``03PX;00802`L8100<20T00`0?2``03@T:00`82@0300`82@0300d9
2P0810D02PH700803PX;00L030P9018>3`0>2P/03@T:00h:2`0=2@X02`L800803@T:0`0<20T02P0;
1`P02PH700d92P0B3Pl03@T:00X61`0B3Pl07ATJ01TE5P0<20T200h:2`0500/7200=2@X02`L800`8
2@0=2@X00`0<20T01@0;1`P02PH700/7200<20T02PH700802`L800@02@D600d92P0>2P/03@P;1@0<
1`/0100;1PX02PD900/62P0;1PX200`72`0<00T42@0;1P/030L<00/62`0?2Pl06QDJ00`7300>2@h0
3@P=00/62`0>2@h03@P=1P0<1`h01`0910/040/B00`73P0@2a803PT@00d83`0=20h01@0=20d200l:
3`0E00/62`0:1@X03@P=00T3200;0`P02`<900d5300?1Pl03PHB00/44@0=1Q803@LB00P42`0810X0
2PL;00h:3P080`T050lE00l:400H4aT05Q4G008030L=01403@P>00h93`0>2@l03@P>00`73@081`T0
3P`?00T72P0=2`h02@L:010>4@0C4A@02PP;00/93013@D@02`T<00l=400200l:3P803PT=0P0=20`0
3@0>2@d030L;00d8300>2@d030L;00T4200=30h00`4400X82`0@3Q40518E00P72@0;2@`00P0<2Pd0
3@0>30l03`d@00l=4P0;2A4030XB00l=4`0A3aD03`dC00d;4@0@3Q@03P`B00d;4@0=2a<00P0>31D0
2P0>2a<030TA00`9400:1`h02@L=00/83P0>31403@/?00/93@0?3A4200h<400=00l=4P0<2Pl02@L<
00P62`0:20d02`T>00l=4P0@3Q<0518G00h<4@0<2Pl040hC00h<4@0200`:3`0>00d;400;2@h02PP=
014?500@3Q<020H;00/93P0<2Pl020H;00/93P0:20d03P`A00l=4P0<2A0300h;50803P/F00<03P/E
00`94P0=2Q400P0>2a8200d:4@03018?5P0@3A@03``C00<030T@00<02PL@00/84@0>2a@00P0?31<0
1`0>2a803@/@00d;400H5QT03@/>00`:3@0@3Q400P0@30`0400?2Pd03PT?00l:400@2a<0618L02XT
;@0D3aH04`hD010;3`0>2P`0=C0d024L800>2@d04PdA00`72`0?2Ph2010;3`803PT=0P0@2`l06@0A
31004PdA018=4@0B3A4040/?00h93@0@2`l04@`@01D@500D3a<03`X>018=4@0?2Ph04PdA014<400@
2`l03`X>010;3`0C3Q803`X>010;3`0D3a<04`hB010;3`0?2Ph00`0@2`l0100?2Ph03PT=00l:3P0?
2Ph2010;3`0?00l:3P0>2@d04Ph>00d92P040@40:B@Y03Xe>P0S7R@04@`B00l:400B3A<03`X>00/7
2@0=2@/03PP:008040X<00h03`T;010:3P0B31005Q0D00L21`0F3aH02@@901dF7P0R72405Q0B00T4
1@0A2`d040X<018<3P8040X<0P0?2@/06`0=1`T03`T;00d72@0B30h0618D01@>400<1PP03@L;010:
3P0C3A402P<:00`6300:0`X0<BXb00h83P0=1`/06Q@H04Q2AP0F4A@01P4400l93@0>20`03@L;00h8
300A2`l04`dA01<:3`0501052`803P<90P0?10X201052`0800h32@0:00D04`P>01T>500@1@/03047
00h32@0?10X201052`803`@:00D03P<;00d22P0=0PX03@8:00h32`0201053@0601463P0@1@d03049
00/1200=0PX03`<=0P0>0P`00`0=0@/03P8<00l33@0200l33@<03P8<00d03@4;00l4300?10`04PL?
00d22P0?1@`09AXR01hC6`0>10/02`4801053@0?10`0304901Cooooo000Kooooo`0301TG600:20T0
2`T:008040h?02804a4B014?400A3a003P`=00`:2`0;2@X03@/<00X82@081PL040h?00h<3@0;2@X0
6aTJ01XH6@0=2``03P`=00/92P081PL040h?014=3P0?2``03PX;010<3@0B3Pl04`l@00d92P050@80
5A4B018>3`0L61T0BDE6075]K00300003`/:0P0E4A001@0<20L03PX900L30P0<20L04`l>00804Ph=
00<030P7010<2`0A3@`00P0@30/00`0A3@`05Q8A014=3002010<2`0F00`81`0<20P03`/<00T51P0?
2``0>CDf034];P0A3@h02@D600`82@0A3@h03`/<014=3P0=20T04@/=01@@4@0B3Pl03@T:00d;300A
3a003P`=00H61P803Ph>00@02PX:014@400>30d030X;0`0;2@X0100<2P/03@/<00d;300>30d200d;
300400h<3@0=2``030X;00h<3@8040h?1P0=2``01P0;2@`03@/>00d;3P0:20/03`d@00h<3`802PP;
010030X=01<A50091`X03@/>00h<3@0=2``02`T:00X82@0;2@X03P`=00X82@0H5QL030X;01@B4`0=
2``02`T:0P0<2P/04@0;2@X02PP900/92P0;2@X01P@500l=3P0;2@X04a4B014?400<2P/040h?00H5
1@0@3Pl03`d>00X82@0C4A808AlP008040h?00T04@l@00`:2`0C4A803P`?018@4`0100804Q0C00`:
3@091`X00P0;2@`200`:3@803@/>00X03`d>00/92P0:20T02`T:00d;300<2P/04@l@018@4@0@3Pl0
3@/<0P0;2@X01@0>30d020H700P61`0>30d0518C00805Q@E00/030X;00T720091`P030X;00@20`06
1@L071XM05ABE@0K6A`0108501<A500500X82`0500X82@0<2`P030/900`;2@0<2Pd00P0<2Pl04@0;
2@h03@/>00l=3P0?3P`03Pd900l=3P0@3Q<03`dB00X83@0;2@h03P/B014>5@0:1`h020D>010=5P0;
21402@HA00803@XE00H030TD00`94`0=2Q<03P/D00h;4`0<2A0400`:3`0:00P63@0:1a0020D>00/8
400=2Q402@H=00d:400:20d02PP;00/9308030X=0240108504Y8B`0<2Pd00@0201`J7@081PT01@<6
00l=400B41<01P@700/9300>30l040/?00`72`0:1@T03PT=014<400B3A403@P<00/62P0?2Ph00`02
00d8300@2`l05Q@G014?4P0<2Pd05Q@G00h<3`071@P02PP;00/9300=2`h00P0:20/03`0<2Pd00P03
00h<3`0<2Pd00`4401HD5`081PT04a4D00`:3@0=2`h01`D800/9300<2Pd03P`=00d;300200`:2`80
2`T:0P0<2P/01P081PL03@/<01LE5P0C4A8040`=00h:2`8030P901H03PX;010<3@091@H0AT9300L3
100=2@X04Ph?00/7200?2``040`=00d92P0<20T04@d>01LC500C3a003PX;00`82@0;1`P02PH700T5
1P0<20T03@T:0`0>2P/02`0=2@X030P900`82@0<20T03PX;00l;300@30d03PX;00`82@0>2P/030P9
008020@500H03@T:00T51P091@H03`/<010<3@0?2``500`82@0@00h:2`0=2@X03`/<010<3@0:1PL0
30P900l;300@30d03PX;00H20`0?2``04@d>00`82@0;1`P02@D600X61`8030P90P0=2@X300/720<0
3@T:0P0<20T00`0A3@h03PX;00X5200500`72`0400/62P0:1@T02`H:00/62P8030L;00@04PdA014<
400>2@d030L;0P0;1PX200d8300500`72`0?2Ph050lC00l:3P0<1`d01@0<1`h01P0=20l040/B00L2
2@0A31<04PdD00T42PH03PT=01D04@`@01<>4P0=20`02`H:010;3`0;1@T03@@901<9400A1`l0308;
00/2300@21D03@DB00L22@0C3QD040/A00T4200D3a<030L=00d83P0>2@l00P0X8bT00`0910X030L=
00d83P0200h93`0F00d83P0<1`d020H900H41`0C4A@030X=00L520050`H03`d@00X82`0K6A`00`44
014?4P040PD04@`@010;3`0?2Ph03PT=00`72`0;1PX03`X>010;3`804PdA00X03@P<00T4200;2@`0
6aTL085oPP1NG5l01`D8014?4P0=2`h030X=0P0;2@`030091`X02@L<00`;4P0=318040lD01<C5P0@
41803Ph@01<C5@0@41803PdB00`;40802`XB01`02`P?00`9400<2A003@XA00d;400?3A803@/@00T7
300?3A806aTN01LE6P0>31402PP=00/93P0C4AH03@/@00X83@0<2Pl02PP=00/93P0C4AH03P`A00l=
4P081`/03@/@00/93P0<2Pl03@/@0P0<2Pl0200U8bP0:RP]00h<4@0<2Pl040hC00T7300=2a002PP=
0P0<2Pl0100<2A0030TB00`94P0<2A8200`9500300`94`0<2A803@XA00803P/B0P0=2Q4200l<4`07
00h;4P0?31<03``C014>5@0;214030TB00l<5@02014>5@0K010=500@3Q<02`T>00l=40091`X04Q0C
00h<3P0?2`X03`/800d92@0<1`/03@P>00l:4@0300L0;RPa00X5300E41H030P<00`72`0n>Cd081/O
014<400O6Qh061<G00d8300<1`/03`X>00804PdA00D03`X>00`72`0>2@d040/?018=4@0201<>4P05
014<400@2`l03@P<01D@500G4QH00P0A31001`0?2Ph050lC01LB5P0D3a<03PT=00/62P0E41@00P0A
31001@0G4QH05A0D014<400@2`l04PdA00804`hB00@04@`@010;3`0?2Ph03`X>0P0@2`l03`0?2Ph0
3PT=00l;300<20T03`/<018=4@0K5QX02@@801HA5`0E41H040/A014<4P0B3A<03`X@018<3`02014;
3@0;00d72@0;1@T03PP<010:3P0?20l05a0G018;4P1?B5005@lD014;3@0I4aD00P0A2`d01P0D3Q00
3@L900h82P0600803PP:00`620803PP:01804@/=00l92`0A2`d03PP:01D?4`0H4QH01@0301H?5P0<
1@`071DL00@01@0C31<05a4E018<400=20/02`D901PB5P0:10P200`62P0400h8300B31005Q0D01@<
4@D040D;0P0>0`T200l42P8040D;00P060dC01873@0=0PP03@8800h32@0A1P`03P<900l42P8040D;
0P0?10X02@0>0`/03@8:00d22P0=0PX03P<;01053@0>0`/03@8:00h32`0201463P0600l4300?0`d0
3P8<00h2300=0@/03P8<0`0?0`d200h230803@4;00<04@H>00d22P0<0@T00`0<0@T0100>0`/02`08
00l4300@1@d200`12ACooooo000Kooooo`0800l=3P0=2``03`d>00X82@0B41402PP900h<3@0<2P/2
00X82@0500`:2`0>30d03P`=00d;300<2P/00P0>30d02`0<2P/03@/<00X82@0=2``030X;00X82@0=
2``03@T:00h:2`0?2``040`=00804@d>00`04`l@00d92P0?2``03@T:01lK700f<S<0FEED00d9200?
2`X04@d<010<2`0B3Pd600l;2P08014=300:1PD04@d<010<2`0H51<01@4000h:2@0@30/2014=300]
00h:2@0>2PX03PX;00d92P0?2``04@d>01@@4@0@30d01@42010<3@0F4Q<01P8301DA4P0;1PL03PP:
010<3@0A3@h02@D600L51P0;2@X0Cde>01/K6`0A4A40N7Qh03lo?`071PL04@l@00d;300;2@X03`d>
00T7200B41401@<400H41@0A3a002`T:00`:2`0;2@X030X;018@4@0A3a002PP900P61`0<2P/03@/<
00803`d>00<03@/<00`:2`0<2Pd01@0<2Pd0100?3A003P`?00h<3`0=2`h200`:3@0300h<3@0=2``0
3@/<00804@l@00T030X;00h<3@0=2``03@/<00P61`050`@03P`=00`:2`0=2``00P0>30d3010>3`06
00h<3@0C4A804Q0A00`:2`0A3a0030X;100;2@X02@0:20T0518C00h<3@091`P02PP900h<3@0@3Pl0
2`T<00d;3P0200l=400500d;3P0;2@`01`D800X82`0>30l00P0?3A000`0=2`h03`d>00h<3@0200`:
2`0400h<3@0?3@h030X;00`:2`803@/<00H030X;00/92P071@H020H700T7200<2P/200d;300;00/9
2P0@3Pl02@L800h<3@0;2@X03P`=00P72@0Q7b809R@W05YHF`0=2`h00P0;2@`04@0>30l030X=018@
4`0:20/030X;00d<2@0F5A<02PT700`:3@030@H020H;00l=4P0=2`h030X;00`;2@0<2`L030/;0080
30X?00D030X@00`9400<2A0030TA00`94P0400`9500:00/84`0A3QT01`@?010=5`0100L05a@M00d:
4P0;20l030X?00d;40801P@900`030XA00<02@0a;SL02`P@01@A600100D03@X@00H42@0;2@`03@/>
010>4@0<2Pd300d;3P801P@700h06ALJ01hL7`0F51L02`T<00X82`0;2@`020H900d8300;1PX040/?
018=4@0=20`030L;01@?4`8040/?01403`X>00`72`0>2@d03P`?00/9300>30l020H900800`0I5aX0
DU1C01LE600=2`h020H900@21@0?3A002PP;00/9300200`:3@0J00/9300:20/040hA00/9300E4aH0
3@/>00@21@0A3a8030X;00l=3P0;2@X01`D600`:2`0C4A803`d>00X82@081PL02`T:014?400C4A80
2`L800h:2`0;1`P04@d>00/7200<20T200h:2`803@T:0P0<20T0300=2@X03`/<00/7200;1`P05a<D
020L7@0N6Q/02PH700l;300B3Pl02PH700T51P802PH700D0?SXk00h:2`091@H02@D600d92P0200X6
1`0500d92P0<20T030P900d92P0E4A800P0<20T03@0>2P/01`<400H20`091@H02PH700/7200=2@X0
3`/<018>3`0810D02@D600X61`0;1`P00P0>2P/02@0=2@X030P900X61`0:1PL02@D600`82@0B3Pl0
4`l@00T51P0200P41@0=00`82@0@30d02`L800X61`0<20T03`/<00<000070`@04Ph?00H20`0<20T0
3`/<00`82@0200d92P0800/7200<20T04@d?01`G6`0M61`04@`@00/62P0=20`200`72`803@P<0P0<
1`/08@0910P061<G01dH700=20`02@@800`72`0=20`081/O00T5200F4AD071LK00h93@0=20h02PD;
00/7300B3A<03@P>010;4@0;1P`00`0401/F700300@050lE00H21`0=20`020<700l:3P0<1`/03`X>
00T5200C3Q804@`@00d8300200T4200=00/52@0700403@<700P01P0G3AH040PA01H>6@0500P040TB
00l:4@0<1`d02PD900h93@0200d83P803PT?0P0?2Q00100910X02PD;01@?5@0D3aD200/6300=00@2
1@0@3Q400@0201@B5@0;2@`03P`?014?4P0;2@`020H900/9300<2Pd02@L:00d8300200`72`0k00d8
300>2@d03`X>014=400;1PX00`02018=4@0400<05A0D00P72@0:20/0DU1C03Xh>`0:20/040hA00h<
3`091`X04@lB00l=40091`X03@/@00h=50081`d010<801PH6@0M7A/03`l=01HF500A4A403Ph@00L6
300;2Q804A0H010>500;2@h02PP=00h<4@0=2a0030X?00H42@0F4aX01`@;00l<4`0O72<01@8800X8
3@0=2a002PP=00P62`0=2a004Q0E00d;400;2@h040hC018@5@0=2a002PP=010>4`0B41D00P0?3A80
200=2a002PP=00`:3`0>314040hC00h<4@0<2Pl02`T>0P0<2Pl02`0;2@h02PP=00T63@0100L04a0I
00H3300?31L01`@?00/84P0=2Q<03@XA00803P/B0P0?31<0100A3QD01@89014>5@0?31<200T63@0Q
01HC700710d0>3Dn018?5P0>2a8030T@00d;400610T0518E00400P0<2Pd03`d?00/7100C3``04Ph<
01HB4`0B3A402`H<01@?5P0A31<03PT@00h93`0A314050lC00l:3P0A3A007aXN01HA5@0;1PX050lC
01<>4P0@2`l03`X>008040/?00<03`X>010;3`0@2`l00P0A3100100B3A404`hB018=4@0A3102010;
3`0M014<400B3A404@`@01`G6`0R7B407QTM01<>4P0<1`/04PdA00`72`0=20`05Q4E01TD600C3Q80
4@`@010;3`0A310050lC01LB5P0I51P03`X>00`72`0B3A405A0D00h93@0;1PX0510A00h:2`0=2@X0
0P0@30d05P0>2P/04PdA01<>500C3Q@04`hE014<4`0@2a804@/>00/51`0<1PP040X<010:3P0>20`0
3PT<01/D6`0>1`h05PlF02DN9P0H4AL040X<00h82P0?2@/2014;3@0S00`6200G4A<02084028L7P08
0P@05a4C00d72@0;1@L02P@600h82P0J51H0208600/52@0A2`l050dD00l83`0A2Q4040TA00`5300=
1`/030H:00/52@0=1`/03PP<00/52@0W8BD08adQ00/52@0_:Bd0;2HZ01893P0?10X04@H<01<83P0B
1`d00P0>0`T00`0?10X04@H<014630020146300401P=4`0D2@l03@8800h32@803`@:00P02`0601D:
400C20h02P0501T>500A1P`0304901053@804PL?00@0200500l4300C210040D=0P0=0PX00`0>0`/0
304900l33@0500l33@0B01H:500?1Pd02`0901D94`0<0@X03`<=01873`0<0PT03`@<00L0100A1Ph0
200500L0100D2A403`@<00/0200B1`l040D=5?ooool001_ooooo00H040h?00l=3P0?3@h02@L800l=
3P081PL600`:2`0300h=300=30/030/:00803Pd<00/030/:00h=300;2PT03Pd<00d<2`0;2PT03Pd<
00d92P0>2P/03`/<010<3@02014=3P0<00l;300E4A807ATJ01DA4P0?2``05Q8C010=300E4A005Q8A
00/81`0S7ah03@T81P0?2`X01`0B3Pd030P700h:2@0:1PD06ADD00`9200?2`X00`0@30/0100?2`X0
40`<014=3P0@30d200l;308040`=00X03`/<018>3`0<20T061@E00/7200?2P/040X<01LC500N6Q/0
510A0P0<2P/05`0a;c004Q8B00l?3`0k>c/06ATI00d<30040`<03P`=010>3`0;2@X0518C00/92P0B
41403P`=00X82@0>30d03`d>01@B4`091`P02PP900d;300<2P/03@/<00802PP900@02`T:00`:2`0<
2P/03@/<1P0<2Pd200h<3`0700d;3P0<2Pd030X=00`:3@0>30d03@/<00h<3@02010>3`0700d;3009
1`P02@L8014?400D4Q<03`d>00h<3@0300d;308030X;00<02`T:00l=3P0=2``00P0A3a001P0=2``0
3`d>00`;2P0<2`X03@/;00d<2`803Pd<00H02@L700d<2`0?3@d03@`;00`:2P0;2PT700d;3@0700`:
300:20X02PP:00`:300=2``02@L800d;2`0200l>3@0400d;2`0920L030/:00`;2P803@`;00<030/:
00/:2@0;2@X00P0<2P/300d;300F010>3`081PL061HG00d;300;2@X02@L800l=40091`X0108501<A
50050`H0518E00l=400<2Pd02@L:00l=40081PT030X;014@3P0510<061HH00l=40803`dC00H03`dB
00d;400<2Pd030/:00d<2P0=30d300d;4@0500d:4@0=2Q803@XC00`94`0<2A@00`0<2AD0400<2A@0
4PlJ00`9500<2A<03``E00l=5@0<2A402PL>00X83@0?3A803P`A00d;400>2a8030TB01lL9@0<2A42
014>5@06014>50091``02`T<00`:3@0>30l03`d@0P0;2@/02`0?3@l03@/=00X82P0A3a40518D00l=
3`0:20X030X<00d;3@0;2@/04PdA00803PT=00@03`X>00h93@0C3Q804PdA0`0>2@d03`0;1PX03@P<
00`:3@091`X02PP;00T72P0:20/09B<V00l=400C4A@081hQ00d;3P0l>Sd0518E00/92`0400`:300>
00/92`040P@03`d?00T72@0:20X04@lA00H41P0:20T02`T:018@4@0F51D04Q0A00P61`0;2@X200d;
30<030X;00H02PH7010<3@091@H030P900/7200F4Q<200h:2`<03@T:00h030P900/7200?2``03PX;
00X61`0<20T040`=018>3`0D414040`=00P41@0<20T04@d>00l;30803PX;00D04`l@00h;2`0<20T0
6ADF010<3@0200`82@803@T:00P061@E028N7`0G4a@030P900d92P0<20T02PH700`82@803@T:00@0
3`/<014=3P0@30d02PH70P0;1`P00`0:1PL03PX;010<3@0200l;30<03@T:00l03PX;018>3`0C3a00
2`L800`82@0B3Pl02PH700D20P0=2@X04@d>00h:2`0:1PL05Q8C018>3`060P<00P0@30d02P0>2`/0
2@D600X61`0=2@X03PX;00`82@0:1@P030L;00/62P0:1@T200h93@0h00`72`0=20`030L;00/62P0<
1`/03@P<00X5200C3Q405A0C00/62@0:1@P030L:01LC5@0l>3X07a/M00P31P0=2@/04Ph@010;400;
1P/030P<00d83@0:1@X02`L;00X52P0A3140IV5V00h93P070`L03`X?00l:3P091@L03@T;00H2100D
41803`X=00l;3@0>2@`02`L900X5200<20X03PT:00l82P0D3A003@L:00`52`0=1Ph040XC00l84@0:
1@`02`P=00T62@081@L03``=00d8300=20h200h93`803`X@00`061<I00/6300?2Q003`X@00P32@0C
3Q@030X=020N8@040PD01`H800T72P0>30l200`:3@802PP;00D030X=00d;3P0>2@d03@P<00`72`02
00/62P0=00`72`0@2`l03`X>01HA5@0=20`04`lB00X62@0<2Pd02PP;00/930091`X03`d@00<11002
00/9300L00d;3P0A3a804Q0C014?4`0;2Pl0410C01DF5`0N81`09bTR02X/900S9Ad04Q@?01PI5`0A
4A<03`lD00P73@0@3Q<02`T=018@50030@D0;B/`06ARI`0I5Q`00`4700d:4P0:20l02`P@00l<4P80
30X?00L02`T>00X83@0=2a003P`A00/93P0:20d03P`A008040hC00P03P`A00d;400>31402`T>00L5
2P0@3Q<0518G00d;40<03P`A00<03@/@00`:3`0<2Pl00`0<2Pl02@0<2A003``E00P63P0A3QL02PLB
00X84P0B41T03@XC00d:4@0200h;4P803``C00X01@89014?5@0:1`h04@hE00L42`0B3aH04a0I00P5
3P0F4a`01P<:0P0@3A@0300C4AH040hC01DC5P0E51H05Q@G02LU9`0n>SH07a`F01HC3`0C3`h03@T:
01D@5@804PdD01<040/B010;4@0B3A804PdA01<>4P0@2`l03PT=014<400C3Q802PD901<>4P0@2`l0
3`X>010;3`0A31003`X>010;3`0B3A404`hB00804PdA00<040/?018=4@0A31000P0@2`l01P0A3100
4PdA00h93@0C3Q805A0D01<>4P804@`@00L03@P<014<400B3A404@`@00l:3P0@2`l03`X>00803PT=
00X04@`@018=4@0D3a<04PdA00l:3P0E41@05a8F010;3`0?2Ph04@d>0P0?2`/0100B3Ph04@d=00l;
2`0B3A02010;4@0401<=5P0G4A`06A<L010:3@<040X<0P0@2Ph07P0M5a/08AXQ01D>5@0>1`h03PL?
00l83P0B30h040X<014;3@0C3@l04P`>01@>400?2P/07aTK071ZK00O6A/03`X;01D@4@070P<06aDG
00l:2`0D3Q0020<601@>4P0A2`l04@XA00`5300>1`h03`P@00h73P<03`T=00H040X>014;3`0F41@0
9AlS01lI7@0?2@d2018<400801L?500D2@l03`@:00l42P0@1@/04@H<00h32@0?10X40146300300l4
2P0>0`T03`@:00804PL=01<03`@:01873@0D2@l04@H<00`11`0D2@l03`@:00l4300@1@d04PP?020E
7@0:0@L050TA00/2200B1`l05``D00l4300:00L03P<;00H03`<=00T03@8;01<74@0<0@X0304:0104
3P0<00X0200500l4300900H00P0@1@d0100>0`/05@XB01053@0>0`/201873`0300`22Ooooooooooo
01;ooooo000Kooooo`08014?400D4Q<05aDF014?400J61T05Q@E00X82@0<2P/200h<3@0500`:2`0:
20T03Pd;00d<2P0<2`T00P0>3@/01`0<2`T03Pd;00/:200>3@/03@`:00/:200>3@/00P0>2P/0400?
2``040`=010<3@0@30d04Ph?010<3@0F4Q<05A4B018>3`0D41403PX900l;2P1;AdH08AdL01LC4P0@
30/700l;2P05014=300E4A003@T801lK6P0F4Q401@0?2`X0100A3@d04Ph?014=3P0?2``200d92P0U
01PD5@0@30d00`0002/W:01dL7407ATJ00`72@0>20X030P900h:2`0<20T03@/<00`:2`0?3@h02@T9
00h>3P0C4a<02`/;01@C500C4A804@l@00`:2`0E4a@04Q0A0040000:20T02`T:024O800;2@X030X;
030^;`0F51D03@/<00l=3P0>30d030X;00d;300200`:2`0300d;300?3@h04Q0A00X030X=0P0;2@`3
00d;30803P`=00L03@/<00`:2`0@3Pl05aDF010>3`050`@0108300<03`d>00d03P`=00d;300=2``0
3@/<00`:2`0>30d03`d>00d;300<2P/02PT700/:200<2`T03@`:00803`h<00P03Pd;00l>300<2`T0
2PT701HE4`0V9B<03`d>00d;30802`T:00@03@/<00l=3P0@3Pl03P`=0P0<2P/0100=2``03P`=00L6
100;2PP200l>300400/:20071P@030/900`;2@803@`:00<030/900/:200>30d00P0=2``08@0<2P/0
2`T:00/92P0B41408b4R04U7B00B414030X;01@B4`071PP0518E01LE60081PT03@/>010>4@0=2`h0
1`D800T72P0B41<030X=018@4`0@3Pl0928U01@B5`1:Add0?3U003Xg?P0>2a<03@XA00`:3`0<2Pd0
3@/<00h<3`0200d:4@8030T@00D030TB00d:500=2QD03@XE00d:5P0200d95`0900d95P0300/03P/F
01<@6P081@h04@hG04=0B00C41L030X?00803P`A01@02`T>00h;4P0K62403@XC00h;4`0>2a807a`S
00l<4P040PL01`D800X82`071@P02PP;00`:2`091`P03@/<010>3`0<2P/02PP900d;308030X;00X0
3P`=00l=3P0<2P/04@`@00`72`0;1PX030L;00d8300D3a<04@`@0P0=20`00`0>2@d02`H:00d83002
00T72P0<00d;3P091`X00`4400T72P0D4QD020H900/930071@P0108500h<3`0;2@X030X;0P0=2``0
4@0<2P/02`T:01@B4`0:20T01P@500d;300610D04@l@00/92P0?3@h030X;00<10P0510@05A<D00h<
3@0?3@h03@/<00802PP900L03@/<00h:2`0810D02`L801lK700G4a@0100100H03@T:01H020@500d9
2P0@30d03PX;00d92P0>2P/0510A018>3`0:1PL040`=018>3`091@H040`=00d92P0300002`L800l;
300D41404@d>00/720091@H02`L80P0>2P/01`0=2@X05A4B00h:2`070`@02PH700/720091@H00P0;
1`P02@0:1PL030P900d92P0=2@X02`L800h:2`0<20T02@D600`82@0200d92P0O00`82@0;1`P02`L8
00`82@0;1`P030P900d92P0810D02PH700/720050@803PX;01LC500;1`P040`=01HB4`0<20T00`00
01@@4@091@H00`0001@@4@0=2@X02@D600`82@0@30d03@T:00`72P0@2`l03`X>00d83002010;3`06
00h93@0=20`02PD900T4200;1PX03PT=0P0<20T200/7208030P900T03@T:00/7200810D04@d>00T5
1P0J5QL05A0D018=4@0A31000P0<1`/03@0@2`l03`X>00D0100810L030L;01LB5P0=20`05a<D00/7
200=2@X0100100X61`0810D00`0:1PL0400;1`P03PX;010<3@1TGUh03`T:01D?4`0E3QD02@@:010;
4P0300D06QLM01@C600C4A@02`/:00@4100:20/300d83P803PT?00d03`X@01XE6`0m>3h0?3Lm01HA
5`0;1P`020H900@21@091`X03P`?014?4P1:B4/01`D8008030X=00@02@L:00/9300?3A003`X>100=
20`03@0>2@d040/?00T4201`Jfl0BTE901LB5P0C3Q802@L:00l=400@3Q403@/>00/9300610L00P0>
30l07P091`X03`d@018@4`092@/04a@F01@F5@0<3PT09BPO051CB01LH580DUI802<V7@0Q91d05QPE
01dN800C51H04Q0C01TG6P0H5QT03P`?00h<4@0J5ad02PL>00D22@0B3aL04a0I00L43@0<2A403@/@
00/93P8030X?0P0;2@h200d;400>00`:3`0=2a0040hC01`J7`0J61d05Q@I01DC600;2@h0518G01XH
7@0=2a0030X?00/93P0<2Pl200d;408030X?00X03@/@00h<4@0?31<08AhW00`94P0=2Q<05A8M00H3
3P0:1a403P/D1@0>2a809`0I5Qd0FUMN020M900<2A004a0G00`:400?31D05Q<L00l<5@0?31<05Q<J
00X73P0B41D05A<H06YXJ`0R82<0928U09JDU@3`kNH0MgA[01hK5@0?2`P03`/:018=4P0@2a804@`C
018=500B3A<04@`A010;3`0300802`H:00<00P0E41@030L;01dH700D3a<04@`@00l:3P02014<4003
00l:3P0A31004`hB00804`hB00@040/?00d8300B3A404@`@0P0@2`l00`0A31004PdA010;3`03014<
400901<>4P0E41@05A0D01lJ7P0400<04PdA01/F6P0@2`l04PdA00D04@`@00@03`X>00d8300B3A40
4`hB0P0>2@d06`0>2P/03`/:014=300B3Pd04@d<00l;2P0A3@h03`X>00l:4@0C3AP05a4O01TC7`0?
2@d05@lA01@>400@2P`040X>018<400<1PX03`P?01<<4`0@2A003PL?014;400>20X030H800d72@03
00h82P0B01D?4@070@<03`T;00L10`0E3a402`D702PR90080P@040X<00`6200H4QH02`H9010:3P0?
20l040T@018;4P0B2a<03`P?0P0=1`/200h8300?00l93@0>20`040X>00d72`0@2Ph03PP<014;3`0O
5Q/05``B00l42P0=0PP03`@:01873@0>0`T03`@:00D04@H<0P0@1@/01`0?10X03P<900`11`0C20h0
40D;00h32@0=0PP00P0>0`T0300900H03`@<01D:4P0700@06a0H00L0100900H04@H>01L<500>0`/0
2@0600l430H03P8<0180300:00l53@0@10h03@4;01<74@0>0P`03`@<01873`0;00P05@XB02lT;007
00@03@8:01053@0700@02`0801X?5`0700@Dooooo`006oooool0200=2``04@l@01@B4`0=2``05Q@E
01<A4P0:20T030X;0P0>30d01@0<2P/02PP900h=2`0=30X030/900803Pd;00P030/900l>300<2`T0
3`h<00h=2`0<2`T03`h<00h:2`<03`/<0P0@30d0300?2``020@500T51P0=2@X040`=01<?400?2`X0
2PH502@P7`0H51<0:2@S018>3@L03`/:00D02@D400h:2@0J5QD0CDU805=?CP0500l;2P0300l;2`0?
2``03`/<00803`/<02D03PX;00T51P0@30d061@E00@00@0R7Ql00`0001<>3`0=1`T03`/<01HB4`0B
3Pl03@/<00l=3P0B41404A4A00l?3`0A4A403Ph>00P7200E4a@03@/<018@4@071@H00@0001PF5`0G
5AH020H700800@0100009R@U05IDE@0O7Ah020H700D310091`P04a4B00803@/<00@030X;00d;300?
3@h04Q0A300<2Pd300d;308030X;00@03P`=00d;30050`@01P@50P0A3a000`0<2P/03@/<00d;3002
00h<3@803`d>0P0=2``0200<2P/03P`=00h<3@0:20T02@P600X91`0;2PP030/90P0>3@/0200A40h0
3`h<00T81P081`D05QDC02TX9P0?3@h03@/<0P0;2@X0100=2``03`d>00X82@0<2P/300h<3@0300`:
2`0:2@L02`X8008030/900@02`X800X91`0<2`T030/90P0=30X01P0<2`T02`X800d;300=2``030X;
00/92P802PP900l040h?028P8@17ADH040h?00/92P0C4A8020H900l=400>30l020H901dK7P0S8B@0
71XM00D31P0100800P071@P01@0B41<01`D801/I70050`P0;b`d00807Q/T00d03P/E00`94P0<2Q00
3@/>00h<3`0>31003@XA00`9400<2A402`PA00X7400<2A<03@XE00@03@TG00P04@dJ00P5400;21<0
20D?00X7400X9Bh0FeQP01XG7P8040hC01@03`dB00h<4@0B3aH08b0Y00X7400@3AD03@XA01lL8`0?
3A<02@L<010>4@0E4aH03@/>00h<3`0?3@h02PP900/92P0?3@h030X;00X82@803P`=0P0?3@h02P0>
30d030X;010;3`0<1`/03PT=014<400?2Ph04`hB018=4@0>2@d200l:3P0400`72`0?2Ph020H900X8
2`803`d@00<02`T<00`:3@0@3Q400P0@3Q40100610L04Q0C00d;3P0;2@X400d;300?00/92P0@3Pl0
1PD50040000B41402PP900T7200<2P/01@<400`:2`0B41403@/<00P61`0100002@L800803P`=00P0
20H700@20`0B3Pl03@T:014=3P0U8B8071PI00P41@H03@T:00/02`L800d92P0=2@X030P900h:2`0?
2``03@T:00`82@060P<03@T:014=3P0200X61`0800/7200U8B80104100L3100;1`P02@D600P41@0:
1PL200d92P0800`82@0;1`P03@T:00X61`0<20T03@T:00`82@0:1PL200`82@0300X61`0;1`P03@T:
008030P900@03`/<00`82@091@H03@T:0`0<20T200/7200:00`82@0;1`P02PH700`82@091@H02`L8
00`82@0:1PL05Q8C01hJ6`802`L800P03PX;014=3P0A3@h02`L800<0000j=SL0HemP018>3`802PH7
00P03PX;00d92P0:1PP040/?018=4@0;1PX020<700/62P803@P<00P02PD900T4200;1PX03PT=00l;
300;1`P02@D600d92P803PX;01P04Ph?00D10P091@H05A4B00X61`0B3Pl00`0200`72`0>2@d04@`@
00d8300:1PT03PT=00/62P080`L050lC01LB5P0>2@d04`l@00X61`0>2P/040`=00L3100;1`P200T5
1P0B00/7200<20T03`/<010<3@24P7l06ADE00`72`0=20h020H<01@A600T8BP0@d9700L830061PP0
2`d;018B4P0:20/030L=0P0=20h200h93`0C00H11`060PL06aHL01/F70070`P01`8801HD5`0:20/0
5A<F018@4`0:20/0>3Hi00L5200<2Pd03@/>00X82`0;2@`03`d@00`72`0200/62P0_00d8300>2@d0
3`X>00d9300D3a<030L;010<3`0?2Ph01`8600d;3P071@P02PP;00/930081PT03`d@00d;3P0>30l0
1`D800d;3P0A3a8020P:00d>3`0C5A009BPQ02<V6@1_Lf@0b/jm0:JZV@1DF4X0?3ld02d`:P0S9B@0
3a4@01/I6P091`P00P4200h<3`0;2@h02`T?01HC6P050P/01@<;01TF7`0B3aX04PlG00d;400<2Pl0
0P0=2a004P0;2@h030X?010>4`0?3A803@/@00`:3`0?3A806aTN01DC600>31404a4F00X83@0<2Pl0
4Q0E00d;400;2@h02PP=00/93P803@/@0P0<2Pl01P0=2a003P`A00l<4`0100L0924Z00T73`803P/F
00<040dG00h;500>2a80100>2a80<P0=2Q40CdaC01PE70081@`04PlF00h;4P0?31D07AXS01@A6P0F
4aX0514H00`9400I5a`02`T>01DC5P0F51L01P@70::QX@3oo_L0Ogac01XG4@0>2PL04@d<014<4@0@
2a804@`C018=500B3A<04@`B010;4@0A3100=S4e00d8300J5AT02@@801/F6P0D3a<04@`@010;3`0A
31004PdA010;3`0A31004PdA01<>4P0B3A4040/?00h93@0B3A404@`@0P0@2`l0100A31004PdA01<>
4P0B3A4201<>4P08018=4@0@2`l06QDI00D1100B3A404`hB00<00P0A3102018=4@804@`@0`0@2`l0
7P0>2@d04PdA018=4@0>2@d03`X>00d92P0@30/04Ph=018>2`0A3@X040`9014=3@0A31004PdD01<=
600B31X04P`H00l93@0E3a4050h@010:300@2Ph04P`@014;3`0B2a805a0G01<<4`0@2A404``B00l9
2`803@L900<03PP:00d72@0=1`T00P0=1`T04P0M5aT03@L900d72@0910D0618D0;J`/P0K5AL0AT12
01H@500P6Qh03@L;00d63@0A2Q404P/B014:4P0>1`h03@L;00h830<03`T=00h03PP<01@>4P0?2@d0
3@L;014;3`0<1PX04`/@01H;4@0A1P`040D;0146300@1@/03P<900l42P@04@H<00L04`P>0146300?
10X0304700d2200@1@/03`@:008040D;00X03P<900`11`0?10X05@XB00T01P0=0PX02`0806AIH@0C
21003P<;0P0@1@d00`0=0PX0304900l4300600h2300B01043P0:00P03P8<0186400?0`d040@>0146
3P0=10X04PL?01X?5`1ICUH04@H>00L0100=0`X06@hF01`A6@0B1`l01`045?ooool001_ooooo00D0
3`d>01<A4P0B41402@L800l=3P0700`:2`0300h=2`0=30T030/800803Pd:00L030/800l>2`0<2`P0
3`h;00h=2P0<2`P03`h<00H03`/<00`05A4B014=3P0@30d03`/<010<3@0?2``040`;00l;2P0A3@`0
4Ph=014=300<20L600l;2P0>010<2`0=2@P04Ph=010<2`0Z9RD09B4P010<2`0?2`X03PX900l;2P0@
30/03PX:00d92P0>2P/2010<3@803`/<02<040`=01@@4@0;1`P0510A00P41@0E414040X<00X61`0=
2@X03PX;00d;300?3@h030X;00/;2`0>3Ph06ATI01PH600?3Ph0G5YK05ABD`0A3a004a4B00T8200=
2``03`d>00P61`0<2P/05A<D010>3`0C4A803P`=018@4@0D4Q<03P`=00P61`0300`:2`803@/<00<0
3P`=00`:3@0<2Pd0100<2Pd200d;3P803P`?0P0?3A000`0<2P/03@/<00d;300200/92P0700h<3@1^
K6d0AdE6014?400:20T040h?00h<3@0200/92P8030X;0P0=2``01`0?3@h03P`=00`:2`0?3@h04Q0A
00T7200:2@L00P0;2PL400`;200500d<2@0<2`P02PT600/:1`0>3@/01P0=2``0200;2@X03@/<00l=
3P0>30d03@/<00`:2`0>3@/03@`90P0;2PL0100=30T03Pd:00`;200<2`P200d<2@0300`;200;2PP0
3@/<00803@/<00L030X;00/92P0;2@X040h?00H41@0D4Q<02`T:00802PP901T03@/>00`:3@081PT0
40hA01dK7P0P7R403P`?00`:3@0G5AP07Q`O00/9300=2`h040hB00X83@0J5ah02@L@00`85@0@31T0
3@XF00`9500<2A403@/@00h<4@0?3A<03``C00803P/C00@030TB00/84P0=2Q@03P/F100>2QP0100=
2QH05A8M014>6@0<2A<200h;500H01HC6`0>2a802PP=00d;400;2@h030X?010=500O72D030TB00h;
4`0@3A@04a0G00d;4@091``04@lB01LE600;2@`03@/>00h<3@0;2@X03P`=010>3`0<2P/03@/<0`0?
3@h07@0>30d03@/<00d;300A31003PT=014<400D3a<04@`@018=4@0A31003PT=00l:3P0@2`l03@P<
010;3`0A3a803`d@00/930091`X02PP;00`:3@0>30l02PP;00`:3@0>30l02PP;00X92`0<2P/03@/<
00803P`=01/03@/<00`:2`081PL0=C<d01PF5`0@3Pl02PP9014?400=2``02`T:00d;30081PL03@/<
02@R8`0b<3407A/L00X82@081PL03@/<010>3`0810D040`=00`82@0>2P/02`L801<?400<20T00`0=
2@X200h:2`0K00l;300=2@X02`L800X61`0;1`P02PH700l;300A3@h03PX;00/7200D414071PI00l;
300H51D0@cm001LC500:1PL03PX;00d92P0<20T03@T:00l;300=2@X02`L800h:2`0;1`P02PH70080
2`L800@02PH700l;300@30d03`/<0P0=2@X01`0>2P/030P900`82@0?2``02`L800X61`0?2``01@0>
2P/0100?2``030P900/7200?2``200d92P0E014=3P0<20T02PH700l;300=2@X02`L8010<3@0?2``0
1`@400`82@0:1PL02@D601HB4`0A3@h030P900X61`0;1`P030P900X6200?2Ph04PdA00802`H:0P0>
2@d01P0=20`030L;00/62P0<1`/03@P<00l;30802PH701/03`/<00d92P0=2@X02@D6010<3@0A3@h0
1`<400T51P0:1PL0:RDY03lj?P0<20/02PD900D1100=20`04PdA00<00P0D3a<01P8500T4200?2Ph0
0`0001TE5P091@H04`l@00H20`0<20T00P0;1`P400d92P803P/;00/02@P800X9300=2a001`L<040o
A@1BDeP03Q0B00d@3`082`P02@X900T72P0200`73@<03@P>00P03`X@00/6300=20h03@P>00`73@0?
2Q0040hA00X82`802`T<00<03@/>00X82`0:20/0100<2Pd01@0:20/03PT=00`72`0<1`/02`H:0080
30L;00d040/?00X52@0?2`h04@`@08=nPP1@Bdl02`T<010>4@091`X03@/>00L5200>30l03`d@0080
2`T<02T03`d@014?4P0@41404aHC01dQ6@0[<2<0GF=B0<G;]@3mond0m_[V0:neXP1TJET0:RhU018F
4@0J71X040l?01@B4`0C4A<02`X<014?500>31802`P?00d:4`0a;SL0;2Tb010>600:1`l03P`A00l=
4P0>314030X?00/93P0>31403@/@00`:3`0=2a003P`A00d;400@3Q<030X?00T7300200`:3`0800/9
3P0=2a0030X?00/93P0:20d02`T>00`:3`0=2a0400`:3`0800`9400A3aL0I65Z03<`>@0=2QD04a0K
01<@6P0?31D200l<4`803P/B01T03@XA00/93`0E4QT02PL>00l<4`040PP040dD014>5`0C41T040dF
018?5P0<2A00514H010>4`081P/05Q@G00/:300K6A`0<S0a05YGC`0/:Qh03``500l<1`0?2`X04`lA
00804PdC00L040/B010;4@0B3A<04PdC018>4@12?D4030P;00804`hB00@03`X>01D@500B3A4040/?
0P0B3A400`0@2`l04PdA018=4@02010;3`04018=4@0C3Q804PdA014<408040/?00<04@`@018=4@0D
3a<00P0A31002P0B3A4040/?00`72`0B3A40AD14010;3`0>2@d05Q4E00h93@0?2Ph3014<400E010;
3`0?2Ph04PdA014<400D3a<04`hB010;3`0D3a<040`=018>3@0A3@`03`/8010<200B3P/04@d=014<
400A31<040XF00h75`0>21D040X>00<040X<0`0@2Ph01P0?20l040T@014:4@0@2A404`dB01<=3`<0
4@/=010040X<00h82P0@2P`04@/=00d82@0A2`d040X<018<3P0<1`P05Q0B00l92`0X8b@04@/?01PB
5P0A2`l030D<0P0?20l05@0>1`l03`P?010:3P0A2`l04`dA018<400A2`l03PP<01@>4P0@2Ph03@L;
018<400<1PX040L<01<83P0A1P`04PL=0146300?10X03P<900l42P040146300700l42P0@1@/040D;
00l42P0@1@/05P/A00`11`0201`A5`0?01052`0>0`T04@L<00h52`0=0PX04`P@00T01P1<@DT050XA
01463P0>0`/03@8:00l4300@1@d03P<;00H03@4;00L04@D?01hD700800H04PH@00d12`0?0`d04PL?
0080308900T04`P@03`a>@0900H05P/C01473P0i;SH0>2de00l5300D2A405?ooool001_ooooo00P0
20H700h<3@0?3@h01@<400d;300<2P/03P`=00`:2`802PP900h030X;00h<3@0>3@/03@`900`;1`0>
3@/03Pd:00`;1`0@3`d03@`9010?2`0?3P/03@`:010?3@H03`/<00d05Q8C01<?400>2P/03@T:018>
3`0D4140>cXh018A3`0300004Ph=00d9200E4A0040/:00803`/:02X03P`:00d<2P0=30X03`/:00d9
200A3@`02PH501LC4P0:1PD04@d<00h:2@0=2@P03PX9010<2`0?2`/03PX;00l;300@30d03PX;00d9
2P0C3a0030P900h:2`0B3Pl01`<401LC500<1`T03@L;00l:3P0H51D04Ph?00X61`0<2@X02@L800D3
100<2P/03`h<00X91`0:2@P04@l@018@4@0@3Pl200X82@0;00h<3@040P<030X;010>3`040P<03P`=
01DC500>30d030X;00X82@081PL00P0>30d01@0?3@h04@l@014?400@3Pl03P`=00H030X=0P0>30l2
00l=4003010>4@0A3a802`/=008030`>0P0820X01`0=3@h02@T900l=3P0F51D03P`=00H41@0=2``0
0P0@3Pl0100?3@h03P`=00d;300<2P/200l=3P0B00`:2`0@3Pl0518C00T7200>3@/03Pd:00d<200=
30X03@`900`;1`0@3`d03Pd:00d<200?3P`03`h;00`;2@0;2@X03@/<0P0?3@h01@0=2``02`T:01PF
5`0E4a@04@l@008040hA00<04@l@00h=2`0=30X00`0=30X00`0>3@/030/900`;2@0200d<2P0300`;
2@0;2PP03P`=00D03P`=01h03`d>014?40081PL03@/<00l=3P0C4A804@lB00d;3P091`X03`d@00T7
2P081PT03P`?00400P091`X04a4D00T72P0A3a803`dB014>5@081@`04a0I00T64@081A0030TD00`9
4P0<2A403@XA00l=4P0A3aD2018?6003014>5`0?31D03P/F00803P/F100>2QP07`0A3A`04`lN0080
3@0>2QP01P<>01LD7`091Q402`PA010=5P0F4aX03``C00`9400;20l0514H00d:4`091`d04@hE00H3
2P0<2A001P<:00d;400A3a@01@<800`93`091``02`T<018@4`0C4A@03@/>00h<3`0;2@`00P0<2P/2
00/92P0K00h<3@0=2`h02@L:00X72P0<1`/02@@800`72`0?2Ph02`H:00`83@0<2Pl02@L<00/:3`09
1`X02PP;00`:3@0@3Q404@lB00/9300:20/02@L:00@21@0?3A002`T<00d;3P0>2P/03`/<008040`=
00L03P/<00`:2`0E4a@04a4B0040000?3@h01P@5008040h?01402PP9018@4@0C4A802@L800h<3@0@
3Pl020H700X82@0B41404@l@00H41@0810D03`/<00h:2`0E4A8030P900T51P0200`82@803@T:0P0>
2P/00`0;1`P030P900h:2`02014=3P0>00l;300L61T01@4200T51P0>2P/02`L800`82@0?2``02`L8
014=3P0@30d00`0001<?400<20T200T51P0900`82@0?2``03`/<010<3@0A3@h040`=00/7200>2P/0
510A00803PX;00@03@T:00X61`0:1PL02`L80P0<20T0100>2P/02PH700/7200>2P/600`82@0=00P4
1@080`L03@T;00`82@0:1@T02PD800l;300A31002@@701LC500_:Rh09b<T00L3100200`82@0600<0
000;1`P02`L800T4200;1PX030L;0P0:1@T0200<1`/03PT=00d8300;1PX03`X>00d8300:1@T030L;
0P0=20`200`72`0:00d92P0810D02`L800l;300:1PL02`L801@@4@0300002PH700h:2`802PH70180
40/?03`g>`060PD05A0D00T420091@P030L;01LB5P060@D061<G00T420070`H03PX;04Y6A`0E4A80
4Ph?00/7200810D300d92P0A00`82@0;1`P02@D600800@0<2``00@4300P82P040`P04a@I00X;400>
3a@0004200/<3P041PH00`D400T72P0;1PX00P0<1`/200d8300=00d83P0D3aD03`X@00h93`0@2a40
20<9044o@P0@3Q403`d@010>4@0:20/02`T<00d;3P0200/9300?00h<3`0<2Pd01@<601PC5`0D3a<0
4PdA00l:3P0=20`030L;00T4200I51P01P45010<3`0E41@02PD900<03@/>02d02PP;00/9300a;c80
5aDH00h<3`0B41<03`d@00`:3@0A4A403Q8=01lU6`0e>bd0LGQT0<C<]03^mm`0m?[S08ZBO@0a>2H0
92XN00`A2`0@4Pl02@P802DS9P0O7B004Q0C01dK800710X03@XA014>5@0G51`03P/D00P53P0;2100
3@/@018?5P0?31802PP=00`9400<2Q001P@900D22@0<2@l040hC00`940091``00P0?3A8010081P/0
2PP=00d;400<2Pl500/93P<030X?00T02`T>00X83@091Pd03@XA01HC6P0?31D040dF00P53P0E4Q/0
0`0?31<01@0>2a803@XA00d:4@0?31<00@05008030T@01H02PL>010=500B3aH01P<:010=5@0F4aX0
2@H=00h;4P091``02`T>018@4`0N71l04a4D00d<3@0>2`H0514800h;1@0@30T03`/:010<3P0D3aD0
4@`B0P0>2@l02`0A318050lE01D@500;1`X03@P<01PC5`0=20`04PdA01D@500B3A404@`@00804PdA
00T04@`@01<>4P0@2`l03@P<00h93@0C3Q805Q4E018=4@0A31000P0@2`l02P0A31004PdA01HA5@0@
2`l03PT=010;3`0B3A4040/?00l:3P0I51P201D@500400D0100E41@04PdA01<>4P805A0D024050lC
01<>4P0@2`l03`X>018=4@0?2Ph03PT=018=4@0B3Pl04`l>010<2`0=2@L03`/8018>2`0@30`03@P<
00/6300<1Q403`TG014;5@0A2`l02`D700`6200@2P`040X>00h8300B31004@/?00/52@0@2A004``C
014;400B30h00P0@2P`08P0?2``03PX;010<3@0=2@X03`/<00/51`0@2P`03PP:01072P0O5QL04`X;
01092`0K5AL05Q0B020K7`0M61`040/A00l83`0>1`h03`P@0109400=1`/04@P=018:3`0@2Ph04@P=
00`52@0>20`03PD:00l8300:10P03PD:01T?5@0A1P`200h32@0401052`0A1P`03P<900l42P@04@H<
01003`@:01<83P0E2Q004PL=01052`0B1`d03P<902XO9@0X7B<04PL=01052`0A20`04PL?01D:4P0?
10`05P/C0P0@1@d01P0=0PX03P<;01873`0C21004PL?00h32`803@8:01H03@8;00d12`0=0P/03@8:
01864013>4401`0400h2300B1a0040D=00X01`0B1`l01`0401P=5@0900H05P/C00T01P0=0PX02P07
00d22P0B1`l02P075?ooool001_ooooo00P01`D600`:2`0B41403`d>00L51P081PL061HG00l=3P80
3@/<00d03P`=01@B4`0>2P/040`<014=300A3@h03`/;00`81`0B3Pl04@d=00l;2P0?2`/03`/<0080
40`=01P03`/<00h:2`0?2``03`/<010<3@0B3Pl03`/<00h:2`0B3Pl00`0001XH6@0H6AH01PL200d<
200C3``03PT6014<2@0B2`T03@T6014=2P0B4Ph03a4<00d=2`0@3Pd201DA4P0?014=3P0>2P/03PX;
00h:2`0C3a00Cd]<01lK70030000510A00H20`0C3a004@d>00l;300>2P/04@d>00D03`/<00X04P`A
00h73P0B2a806A<G00l93@0I4aL030L900h:2@0=2@P03`/:0P0=2@H0500A3P`03P`=00X82@0B4140
2`T:00T7200B41402`T:00l=3P0;2@X03@/<010>3`0<2P/040h?00/92P0B41402`T:010>3`0A3a00
3P`=0P0;2@X07`0=2``03`d>00`:2`0;2@X030X;00d;300@3Pl04a4B00P61`0?3@h040h?00`:2`0>
30d02PT;00hB5@0?51P01@T<01@H6`0:3Q4010D800X;3@0;2`d03@d=00d<2P0;2PP03Pd;00X82@07
1@H02`T:00l=3P0=2``00`0>30d0400K6AX0518C00h<3@0610D03@/<00X9200=30X040h?00h=300=
30X03@/<00/:2@0=30X03`d>00d<2`0610D400`:2`0J00`:300<2Pd01P@703hl?`1]Jfh07A/P00l=
4P091``02`T<00d;300;2@X03P`=018@4@0>30d03`d>00X82@0>30d04@l@00/92P081PL030X;00d;
300<2P/02@L801@B4`0Q7b0200`:2`0<00d;300>30d02`T:00P61`0D3a<04@`@010;3`0A310040/?
00l:3P0A31003`X>0P0<1`/09`0@2`l050lC00l=4P0<2Pl02`T>00X73P0?31<03@XA018?5P0;20l0
2`T?00d;400<2Pl040dE00h;5P0J5b805a@O00l<5`0E4Qd030TD00/84`0D4A`02PLB014>6@0;21<0
4PlO0080500E4RL02`PK01HC900f<d@0518P00h<6@0G5B805aDQ00d;5P091a802`T@00d;400300d:
4@<03@XC0P0=2QD01`0>2aH040dI01DB6`050P/03@XA00`9400?31<00P0=2a0200d;3P0C00d;300<
2P/02PT900/;3@0D5AL020L901/G600?2``03PP:01D@500I51P00P4601@D700;3QL03a<K01DD6@05
0`H030X=00d;3P0200P62@08014?4P0?3A003@/>00l=400>30l02`L;00l93@0<1PX200h8300:00P3
1P0:1@T030L;010<400100803@/>00h<3`0C4A@02`H:00`72`803@P<00H03PT=00l:3P080`L040/?
00h93@0400<300d8300G00`72`0;1PX030L;00h93@0@2`l03`X>00T4200B3A4050lC00`72`0D3a<0
3PT=014<400>2@d02`H:00d8300A3100DTeA00H11@0@2`l03@P<01<>4P070PH00P0>2@d200l:3P0b
00h93@0=20`01`<6014<400D3a<01P8501PC5`0;1PX03`/<08j:R`0O6a`02`L801<?400>2P/02@D6
00<0000W8b@01P8301DA4P0@30d03PX;00d92P0@30d0510A014=3P0?2``04@d>00l;300<20T02@D6
00/7200>2P`01`8601`G7@091@T05Q4E00h93`0;1P/030L;01@?5@0@31002`H:059=D`12?Sl030P7
00/71P0=2@T03PX;00/62P0:1@T400/6300500/63@0;1P`02PD900X52@0;1PX00P0<1`/01`0=20`0
30L;00`72`0;1PX030L;00d8300910P00P0B3A40400:1@T030L;00h93@0:1@T02@@800X52@0;1PX0
3PT=014<400>2P/00`0000h:2`0;1`P02@D600`82@0@30d200X61`0301DA4P0D414020@500<030P9
00<02`L800X61`0:1PL00P091@H02@0;1`P030P900l;300@30d03`dB020O900000@05QDJ018A5`02
00L6300C01HE6`0h>Cd0000400l?50061PP030X;00l;2`0A3@h020@500d92P0;1`P02`H:00d8300B
3A403`X>00L21`0<1`d03PT=00/7200200h:2`0400X61`0<20T030P900`82@803@T:00`03PX;00h9
3@0=20h03PT?00H11`0=20h04PdA014<400?2Ph030P900<0000A3@h200P41@0I00X82@0<2P/030X;
00`:2`0:20T020H7028P8@0:20T01`D6018@4@081PL06a/K018F4@0K81T0>d4e03Dl:P1[Le`0XJVA
0;W1Z@1DG4L09RdM01@J3`0?50h03a4>00`;3P0201<A5P803@/@01l05aDJ06YXK@1=Be003P`B00`9
40060`X02PH=00d83`0=1a403@P@00d83`0;21402`P@00d:4@0:2A402`XA00`;4@0>3AD02`X?00D3
200<2Pl03@/@0040100c<CH0AD=800/93P091``03`dB00P62`091``040hC00803@/@00L030X?00d;
400>31407Q`Q01HD6@0;20l030T@00803``C00L030T@00d:4@0@3A@040dD00l<4`0=2Q4040dD00<0
3``C00D040dD018?5P0A3QD04@lD014>5002010>4`0D00l=4P081P/03@/@01<A5P0A3a@03`dB010>
4P0B41405QDC01@C4P0>30d040h?018@4`0>30l02`T<00l=40091`X03@/>00T72P0?3A02014?4P0Y
00l=400<2Pd020H900`:3@081PT04@lB00H41`0n?3l04a4D01<A5P0A3a@030X?01<A5P1HEU/0BDM<
014?500@3Q<04@lD01<A5P0E4aP04a4F01D@5P0>2@l02`H<00h93`0B3A<04@`B010;4@0B3A<040/A
00h93`0B3A<05Q4G010;3`0I51P030L;014<400P6al03@P<01D@50070PH00P0?2Ph0;00=20`030L;
014=3P0A3@h04`l@010<300?2`X0510?01@@4@0G4a@04`hB00d83@0H4aT04`hB014;3P0>20X030H8
00d72@0@2P`04@/=00h92P0@2P`06A<E00P31P0K5AT0204501483@0>20`040X>00X82`081PT03P`?
00X82`0100803@P<00T31`0C2Pl07a8F01L92@0?0`<04PP9014;2`0@30/030X<0P0@3Q40900;1P/0
3PL>014:4P0B210040L<01052`0B20d04PT>0146300A1``05PdB01T>500@1P`03@@901L<4P0H3A<0
3`@:01873@0C20h04@H<00l42P0>0`T04PL=01@93`0=0PP02`0601052`0900<03@0701@73P0E20l0
4@@;00X0100B1@`04@@;0185308050L>00L04@@;01D83`0>0@P03@0701/>5@2hZk8091LN00<040<:
00<03`8900h1200>0@P00P0>0@P02P0?0PX03`8;01032`0@0`X0200401853@0A10/03`8;00h12@09
00<800l22@8040<:00<04@@;01853?ooool04oooool001_ooooo00<04Q0A00/92P0<2P/00P0@3Pl0
0`0A3a0030X;00X82@0300d;300301<A4P0@30d03`/<00@03PX;00@04`l@018>3`0@30d040`=0P0A
3@h0100?2``03PX;00h:2`0?2``2014=3P0T00d92P0F4Q<030P901<?400k=cP020H700h@30041@80
2PX7010<2P0@20L05@d<01H?3P0<1`D03@`900h>2`0B51007QlM01DB4`0D41404@d>00h:2`0A3@h0
510A014=3P0>2P/06aLH00`82@0=2@X03``<01XF5`091@H040`=01hJ6`0j=SL0510A1@0?2``0400C
3A<020@901H@5`0B3A803`X>00/6200>2@/03@P800h92@0D3`d040`900l:1`0>2`T04Q0A00d;300:
20T200h<3@0:01DC50091`P030X;00l=3P0<2P/040h?00d;300T8R<07Q`M014?40802`T:00@03P`=
00`:2`0;2@X030X;0P0=2``300`:2`0Y00d;300>30d040h?010>3`0:20T01`D601LE5P0Q7b0051<E
00P<3`0?5Q/092T/00/@50062`h02`lB00T:300`<C<09bLW0040000?3P`04A0=010>3`0<2P/03@/<
00h<3@0<2P/03`d>014?400<2P/02PT900L51P0A3a0030X;00T7200>30d040h?00d;30091`P02PP9
00h<3@0=2``00P0:20T600`:2`0D00`:300<2Pd0518E014?4`0R82D02`T>01LE6`0=2a002`T>00d;
3P0;2@`03P`?018@4`0=2`h03`d@00h<3`091`X02PP;00/930081PT200`:2`0400l=3P0>30d03`d>
01@B4`802`T:00P03@/<010>3`0?3@h03@/<00d8300<1`/03PT=018=4@8050lC0P0@2`l04`0>2@d0
3@P<010;3`0B3A403@/@00l=4P0<2Pl04a4F00d;400D4QL02`T>00`:3`0?3A8040hC00d;400;2100
3``G010=600?31L00`0;21<04`0K62<0;BXe018?6P0D4A`03@XE00l<7@040QL03`/Q00l<800>2al0
6QLZ00h;7@0D4B806QPW01TG9@0A3a`03P`J00h;5@0=2a000P0=2a409@0=2Q403@XC00`94`0<2A@0
3@TG00h:6@0>2QP03@TH00d95`0@3AP02`PA00L43@0?31D02`P?00`:3`0=2a003@/>00d;300<2P/0
2PT:00T;3P0520X01`T;01<A500<2@/03`X<010;3`0?2Ph030/@00T;4`000@/0LGIn02XY;P0A3a80
2@L:00X82`0;2@`00P0>30l200`:3@803P`?00d02`P;00T41`0A20d04PT>00P31P0T7R803PP<01TD
60081@P03`d@024O8P0d<SD02@L:00H03@P<00H02`H:014<400<1`/020<700d8300?2Ph600d83008
020K7`0G4QH061<G00L31P0T7b<02`H:00h93@0=20`200/62P8030L;00D03PX=00`82`0K5QX030L;
01@?4`0200l:3P0300d8300<1`/02`H:00802`H:00/03@P<00/62P0>2@d03`X>00H21@0@2`l030P9
024M7P081@D03PX;00l;300200X61`0J01DA4P0Z9RL05Q8C00T51P0:1PL06ADF00L4100<20T08AdN
01PD5@0=2@X03`/<00h:2`0?2``040`=00h:2`0:1PP05A0E03D`=@0B3A80100400L21`0>2Ph04`hC
00<00`0=2@d201@?500800h:2`0<20H02`L600`8200=2@X02`H:00X52P0<1`d300`73P0400`73`0<
1`d02`H:00/62P<030L;00/03@P<00`72`0<1`/02`H:00`72`0=20`020<700h93@0?2Ph02@@800X5
2@0500/62P0>00d8300?2Ph04@d>00D10P0<20T02`L800h:2`0E4A80JfMX01XG5`0?2``0104100X6
1`0B3Pl300`82@802`L802002PH700`82@0=2@X03PX;00d92P0<20T01`D800L52P0Q82D030/@00T8
3P0410T03`hC00`<4@0i>3h0UIBI01<C60081`d030`?014=300=2@L03`/:00h:2@0A3@d03PX;00d9
2P0>2P`04PdA010;3`0<1``040/?018=4@8030P900@02`L800X61`0?2``030P90`0=2@X0<`0>2P/0
3PT=014<4`0810T03PT?00d93P0C3Q80<B``00l;3P0C3a004Ph?00h:2`0:1PL03@T:00/92P0?3@h0
2PP900l=3P0C4A803P`=02@R8`0H5QL030X;00l=3P0C4A803Ph>00lA3P0F6A<06alE02H[700U;1H0
>D0Y04Y@>`0[<B007b@E01@H3`0>4@h03a4@00`;3`0<2Pl03@/@00l=4P0A3a@030X?02DS:00C4AH0
2PP=00`:3`0>31403`XB00h64@0300d74@0D00/84@0A3QL00`4900l>5P0E51`0Ti:J01`K8`0=2a80
2@L<00`:3`0A3a@02PP=020N8`0X9R/03@/@01<A5P0M6b004Q0E00/93P0>314200d;400900`:3`0=
2a003P`A01@B5`0?3A802PP=00d;400A3a@040hC00<030T@0P0=2Q40100>2a803``C00l<4`0?31<2
010=5003014>5@0?3A803`dB00803P`A0P0=2a001`0O7B804@lD010>4`0B41D03P`A02HT:@0A3a80
0P0F51L01@0A3a804Q0C018@4`0B41<02`T<00804@lB00P06ALJ01<A500@3Q403`d@010>4@0C4A@0
6QPK01lM80804@lB0100518E00l=400Z:2/04@lB00X83@0I5a`040hC00d;400Q7b@071XO014?500D
4QL05A<H018@5@0@3Q<03`dB0P0B3A<01P0D3aD05A0F018=4`0;1P`04@`B018=4`8040/A00D04`hD
01HA5`0@2`l05a8F018=4@02014<400401@?4`0>2@d04PdA01D@50804PdA03<061<G00l;300@30d0
4`l@010<3@0?2``0510A01<?400?2``020@502@P8@0c;c004Ph?018<3P0@2P`03PP:00l92`0A2`d0
4P`>01@>400;1@L02`H701LA4`0910D050`@01@;400=1`/04PdA014?4P0>3Q004a<E00/;3@0H5QT0
2`L:01LA5@0D2a006`lA020@4@0H2PX05P/<010:2P0<20P03Pd=01@D5@0D4QD030T=00`73@0?1@d0
3P@;01052`0B1`d00P0C20h201873@0701<83P0F2a404`P>00h32@0@1@/04@H<00l42P0301052`04
00l42P0=0PP03`@:01052`803`@:00<040D;0185300D1`h00P0H2a800`0F2A004@@;018530020144
2`804PD<00L03P8800d01`0A10/05`XA00h3200S6Ad03P8800<040<:0P0?0PT300h120803`890P0@
0`X01P0E20l0304601462`0E2`l04`H=00h220H03`8900<03P4800l22@0?0PT00`0@0`XDooooo`00
6oooool03P0>30d030X;018@4@0B41402`T:00T7200B41402PP900`:2`0?3@h03@/<00`:2`0@30d0
3`/<0P0<20T01P0=2@X03PX;01<?400C3a004@d>010<3@804@d>0`0>2P/09`0@30d04@d>018>3`0E
4A8061@E01@@4@0B3Pl0R8B502h/;@0<3@/02`/900l?3@0A3@`04`d=01/B4`0T7Ad03PX900l>3009
2@L020X701LG5@0A3Pl03`/<00`82@0:1PL03@T:010<3@0<20T0510A00H20`0=2@X06ADF01@@4@0a
;Bh05a<D00X61`0<20T081`M00T61P0500l;300Q00`72`0S7R@0E4mE01XE6P0?2Ph00`0001PD5@0?
2``03@T800h:200<20D03`/8014>3@0:20T030X;01DC50030@807Q`M04]9BP0H5QL00P0100l=3P0D
4Q<04@l@00/92P1eLg@0FeUJ00<10P0C4A806QPI00/92P0:20T02`T:00803@/<00D02PP900`:2`0<
2P/030X;00/92P0200`:2`0C00/92P0>30d03@/<00H41@071@H03@`>00lC5P1bMg/0]kc001`Q900>
4aH03a<F00D6200=3Q003Ph>00/:200?3P`04A0>010>3`0200`:2`802`T:01<04@l@01lM7P0<2P/0
4@l@00d;300>30d040h?00/92P0C4A80518C01<A4P0A3a0030X;00d;300@3Pl03P`=00X82@0;2@X0
40h?00@030X;01D030X<00`:3@0200<02@L;01<A5P0B41D03``B00L52P0<2Pl03@/>00/9300=2`h0
4@lB00`:3@0;2@`03`d@00P62@0=2`h04Q0C00X82`0>30d00P0;2@X02P0:20T03P`=01DC500=2``0
30X;00d;300A3a0040h?00l=3P0?2Ph200d8300400l:3P0>2@d03@P<00l:3P8040/?01003PT=00l:
3P0@2`l030X?00P62`040PL040hC00l=4P081P/03`dB018@5@0D4QL04a4F00l=4P0=2Q805a@O0P0>
2aH01@0?31L020D@01HC7P0100T00P0:00803@XE00L02PLB01TF900:1aP02`PI01TF9`0E4R<040dP
00803``M00H040dN00d;6P091aD02@LE00`9500=2a0300d:4@0R00d:4`0=2Q@03``G014=6`0C3ad0
4PhL00l;6@0A3QT0:BHa01@A6P091Pl0514J00l<4`0;2@h030X?00d;3P0=2``030X;00/:2`072Pl0
8bP/01TL800B4AH01@<600T6200@2`l030L;00D31`0B4AL02PXB00l?5`0E51T020H900`:3@803`d@
00@03@/>00X82`0:20/02`T<0P0<2Pd03`0<20`050hB00l62`0=10T04`dA03D_<`0600@00`0204=0
@`0a;c804@lB00@21@0D4QD03`X>00h93@0200d8300500`72`0;1PX03PT=010;3`0:1@T00P0>2@d0
4P0@2`l03@P<00l:3P0?2Ph03PT=00`72`0:1@T07APL00d8300>2@d01`8603<^<P080`L04PdA00h9
3@0<1`/040/?00h93@802`H:00H040/?01@?4`0?2Ph040/?00<00P0;1PX200T4200H00d8300A3100
4`hB00`72`0D3a<040/?00h93@0:1@T04`hB00`82@0>2P/06ADF00@10@060P<03`/<00h:2`0;1`P0
0`0000X61`0810D07ATJ010<3@0G4a@03`/<0P0300004`0>2P/02`L800X61`0@30d04`l@00l;300=
2@/00`0200D010091@P04PdA01@?4`070PH00`0200h93@0_:Rh00`0200@00`0:1PP00P0;1`H0100<
20P02`L800X52@0;1P/200d83P<03@P?00<030L=00`72`0<1`/00`0<1`/02@0=20`030L;00`72`0;
1PX030L;00d830080`L02`H:00d8300200T4200300X52@0=20`030L;00@030L;00`00`0000D10P0C
3a001@4200P41@0N6Q/0R8B5020L7@0=2@X0100100h:2`0<20T600/720803`/<01803@T:00/7200:
1PL01`D601DC60040`P00P4600H52P0;2Pl030/@01DD6@0A41D0000401PG700920d0000200<0000<
20H2010<2`0400D20@060P<03@T:00h930803`X>00P03`X?014<400A310030P900d92P0<20T02`L8
00l;30D03@T:01803@P<00`83P0Q72806QDK00/6300>2@d0:B@X08F0Q00?2``04@d>010<3@0A3@h0
6QHG014?400C4A801`D600d;300C4A8200T7200B02HT9@0K6AX03@/<00D3100>3Ph0414@0001000<
3`P0Gf9F038f9@0S9aH0>3`[02P/7P0K7Q<02P`600/=300D5AL04@lD0P0:20d02P0>31403@/@014?
500A3a@020H;018@5@0;2@h04@lD00/63@0>1Q4300d74@0>00/84@0610`01`@=01HE7@0<2a<071/S
00L63P0?3Q<03`dB00`:3`0;2@h02@L<00X83@0?3A8200d;4004014?500=2a0030X?00l=4P803@/@
00@030X?00d;400>31403@/@0P0<2Pl02@0@3Q<04Q0E010>4`0=2Q4030T@00/83`0<2A003@XA010=
500200h;4P@040dD0`0A3a@2010>4`0900l=4P0I5a`04@lD018@5@0@3Q<02@L<01HD6@091`X03P`?
00803`d@01/04Q0C014?4P0@3Q403@/>01<A500@3Q40518E00h<3`0C4A@040hA00d;3P0?3A005Q@G
01`J7@0;2@`040hA00h<3`0@3Q403@/>00`:3@0>31405Q@I010>4`081P/03@/@01TG700A3a@00P0J
61d02@0D4QL03`dB010>4`0C3Q@040/A00l:400A31805Q4G01TD6P04014<4P0C01<>500D3aD050lC
00L21P080`L04PdA07ehO01ED5@061<G00X52@0?2Ph08ahR018=4@0400<03@T:00l;300C3a0040`=
00l;300201<?400900l;300C3a002`L800d92P0;1`P04P`>014;3@0@2P`04@/=00804P`>02<05@lA
01hH6P0G4A<030H801/E5`0?1`/05@`A014;3`0>2@d05A<F05]IG02IVI/06ATK00`:3@0=1`/06Q@H
00X11P0F2@`03`4100/0000?1@D03PP800h:2`0>30d03@d=00h<3`0>2Pl03`P?0188400@1Pd04@H<
01<83P0B1`d03`@:01052`0201873@0401<83P0E2Q004`P>01052`803`@:0`0>0`T0200@1@/03P<9
0146300D2@l03`@:00d2200?10X03`890P0@0`X200l22@0=00h1200C1Pd04@@;01442`0B1@`04@@;
00h1200?0PT04PD<00/11@0I31<02P0401L:4@0600l22@803P480P0?0PT201032P0600h1200?10T0
;1lV03DX;`0J3A@020021P0?0PT600h121Cooooo000Kooooo`0D00@20`0<2P/05Q@E01DC500D4Q<0
71XK028P8@0>30d02PP9010>3`0>30d01`D6014=3P0?2``03@T:00`82@0>2P/03`/<01<?400B3Pl3
010<3@0Z014=3P0?2``03PX;00h:2`0?2``040`=014=3P0>2P/02@D600<0000;1`P06aLH00X82@0;
30T030`:00h>300>2PT03`T901<=3@0E3`l01@4000/:200>3P`02`d:01<C4@0>2``040`=00l;300<
20T02`L800d92P0;1`P05A4B00`82@0B3Pl06ADF00`82@0>2P/04`l@00X61`0B3Pl05a<D1P0?2``0
3@0E4A@01`88028M8@0;1PX03PT=03<_<01HE5D0510A01<?3P0E4A0040`;00l;200@3@`00P071@H0
4P0B41400@0001@B4`0n?3d0518C00@20`0?3@h040h?00h<3@0:20T040h?01LE5P0H5QL00@0000h<
3@0;2@X02PP900/92P803@/<00<02PP900`:2`0<2P/00`0<2P/0100;2@X0108300`:2`0A3a0200P6
1`0G01TH6@052@`0@DA906eaM0000@@02`lB00H6200B4aD01@H800P8200A4A402@T900X82@0B4140
40h?014?400@3Pl04@l@01XH6@2WYJH0;B//0040000:20T00P0?3@h01`0=2``04@l@018@4@0G5AH0
61HG00/92P0<2P/00P0B41400`0?3@h03@/<00l=3P0400`:2`0A00`:300<2Pd01@<600/93@071@X0
108700P6300>314030X?00d;3P0:20/030X=010>4@0;2@`03P`?010>4@0=2`h00P0C4A@0200:20/0
40h?018@4@0B41403P`=014?400I5aP03`d>0P0=2``01@0?3@h03P`=00d;300B3A403PT=00803@P<
00<02`H:00X52@0?2Ph00P0@2`l05P0>2@d03`X>010;3`071@X02@L<01DC600:20d071XO00L52P0;
2@h030X?00h<4@0?3A804@lD01HC6`0Q7RL0514J00l<5@0<2A800`09010=5P040@X2010=5P0?00L4
3@0A3QL08b4]00X85P061180518P018@7P0;21T04@hO010=7P0?31d030TJ00/86@0<2AX03@/F0080
3@XA00l03@XB00d:4`0=2Q<03P/E00l<5`0B3aX04a0L014=6`0>2QP03P/F02PU;P0@3AH00@0500T6
3@071@/00P0;2@h300d;3P0E00/:3P0G7280X:N]06U]L`092Ph03`lA018@4`091@H0510A014<4@0@
2a404@hE00H42`071@X01085014?4P0=2`h030X=00h<3`091`X02PP;008030X=01002`T<00`93005
00<04`X?01483@0=1`/05@lC00l93@0910P0BTI:0490@`0V92L02`T<00T72P0?2Ph03PT=0P0=20`0
1`0<1`/02`H:00`72`0;1PX01P45014<400;1PX00P0=20`200l:3P0:00h93@0<1`/02PD900<00P0?
2`h040/?00<00P0A3A004`hB014<40803@P<00X040/?00h93@0:1@T02`H:00X52@060@D030L;018=
4@080`L02`H:0P0:1@T02P0>2@d04`hB01D@500;1PX02PD901@?4`0>2@d03@P<00h93@0>2P/200`8
2@0:00d92P0@30d01P8301<?400F4Q<02`L8010<3@0:1PL040`=00d92P802@D600T03PX;010<3@0>
2P/02@D600P41@0>2P/04Ph?00h:2`0=2@/00P0=20`0100810L01P4501<>4P0:1@T2020K7`0404e8
C00Q72000`02014<3`<030P900@02PH700X52@0<1`/03@P<0`0=20h00`0=20l03@P>00`72`0400`7
2`0;00d8300<1`/030L;00/62P0<1`/03@P<00X52@0;1PX03@P<00`72`0;1PX00P0<1`/200d83080
30L;00d02`H:00l;3003000020@500`82@0C3a0030P900d92P03000040`=00d92P0:1PL02@D600H0
2`L802@03`/<00h:2`0:1PL02@D600`82@0=2``03@/@00/:3`0?3Q<0000400d<4@0e=3T00@0500d<
4@0510T02@P=00/:3`0=3@l06ADD00X71@0300004Ph=018>3P0I5AH03@T:00d82`0;1PX030L;010;
400@2`l03PT=00d92P0A3@h040`=00/7200<20T500d92P0b00d8300>2A000`04018=4`0C3Q@00`02
02TT:01LEe/03`/<00h:2`060P<02PH700h:2`0@3Pl04@l@00L51P0;2@X03`d>00L51P0G5AH03@/<
00P61`0B41400P0100h>3P0<30h04A<@014C3P0]<2H02@d0024U5P0H70d061/@01TL4`0B51003@h@
010A5@0@3Q<030X?00h<4@0?3A802`T>00X83@0<2Pl02@L<00l=4P0;2@h05aDJ00X6300>1`l300d8
3`0800/83`0B3aH0514H00`;4@0A41H0000500d<4P081P`200d;400500`:3`0C4AH05aDJ01@B5`0;
2@h00`091``01P0<2Pl03`dB00d;400=2a0030X?00d;40<03P`A00@040hC018@5@0B41D03`dB0P0?
31<200d:4@0400l<4`0B3aH03@XA00d:4@<040dD00@03``C014?500A3a@04@lD0P0@3Q<0<P0?3A80
3@/@01<A5P0D4QL03@/@00`:3`0:20d03@/>010>4@0?3A003P`?014?4P0>30l03@/>00l=400F51L0
3P`?014?4P0=2`h04Q0C010>4@0>30l03@/>00l=400@3Q403@/>01DC5P0B41<05aDH00`:3@0D4QD0
4@lD00/93P0?3A801P@900l=4P0G5AX03@/@01HD6@0H5Q/04a4F00l=4P0A3a@04`hD018=4`0@2a40
4@`B01HA5`0J5A/04PdC0P0A318301<>500I014<400O6Qh05Q4E02HQ9@11?400:B@X02lZ;P0I51P0
81/O03Lb=P0R7B4040/?00d92P0@30d0510A014=3P0?2``04Ph?00d92P0@30d061@E00T51P0>2P/0
5A4B018<3P04014;3@0[018<3P0:10H03PP:00l92`0>20X06A<E01PA500G3Q<03PP<00d72`0J61/0
Q8:50=;Ad`0X9RT03`X>01<>4P0E3a<01P0201T>4@0G2@T04PH801882@0<1PH02`L800X82@081PL0
2`H:00l93@0@2Ph04PP@01@9400E2Q005P/A01@93`0A1P`040D;01873@0A1P`03`@:01873@0D2@l0
4`P>0146300200l42P0900h32@0?10X040D;00l42P0F2a406PlE01052`0;00H03`@:00804PD<00D0
4@@;01032P0@0`X040<:01<63@02018530804`H=00L040<:00/01@0C1Pd050L>00/01@0A10/040<:
00H03`890P0>0@P200l22@8040<:00H04`H=00d11`0L3aH07a8I0185300F2A0600l22@H03P485?oo
ool001_ooooo00`03@/<00h<3@0>30d02@L800`:2`0K6AX08AlP00l=3P0;2@X040h?00d;30091`P2
014=3P8040`=0P0?2``00`0B3Pl04@d>00l;300300l;3003014=3P0@30d03`/<00<03`/<01<04@d>
010<3@0C3a003`/<01@@4@0=2P/03`h=010?3`0A40l04@l?014<3@0A30`03PT:010<300@3Ph03`h>
00/:2P081`L040d>0080510A00l04@d>00h:2`0=2@X03PX;01<?400>2P/03`/<01HB4`0@30d020@5
010<3@0B3Pl03`/<014=3P0@30d01@0?2``03P0@30h02PL:010=400C4180510C00h;300M6Q/04@h?
01LD500M6QX05A8A00l<2`0?3@d05A<D0P0=2``04P0A3a002PP900`:2`081PL03P`=00l=3P071@H0
3P`=00/92P0I5aP04@l@01<A4P0L6Q/05aDF00h<3@0<2P/02`T:00`:2`803@/<00<030X;00d;300?
3@h00P0>30d0100=2``04@l@00/92P0:20T200l=3P0G010?4@0A4QH01PL<010C5P041PP03@lB018B
50061`T03@d?00h>3`071`P020P900`;300<2P/03@/<010>3`0>30d03@/<01HD5@1FE5D061LG00l=
3P0A3a000P0=2``02`0:20T03@/<00/92P0A3a0061HG00P61`0>30d040h?014?400@3Pl03P`=00D0
30X;014030X<00`:3@0=2`h02`T=00h<4@0=2a0040dC00/93P0<2Pl03@/>00X82`0<2Pd03`d@00X8
2`0<2Pd03@/>00l=400200/93008018@4`0A3a403@/=010>400>30h02PP:00/92`0?3@l200/92`80
3P`>00@03@/=010;3`0=20`03@P<0P0?2Ph05P0=20`040/?010;3`0>2@d03@P<010;3`0B3A404a4F
00<21P0D4QL04a4F018@5@091``02`T>00`:3`0>31404@lD01LE6P0F4aX03P/D00`94P0>2a@2014>
5`0:00l<5@0<2A80514J00X7400F4a`03@XC00l<5@0@3QP03@/E00d:5P803@XH00L040`K00d:6P0<
2AX03@TJ00h:7@0?2al03``J00803@XB0`0=2Q<03P0=2Q@03@XE00h;5P0>2aL03@XF00`8500610`0
5A8J014>5P0>2a805a@K02XX;P0:20d02`T>0`0=2`l0700<2a004AHM061WL00m@TX02@`A00T:3P0=
30h03@T:00`82@0C31003PH<00/42@0B2a003P/>00/9300B41<01P@700L5200@3Q402`T<00d;3P0?
3A0030X=00X82`0=2@d04@/?00l62`0A20d200l93@0700h8300:1PT03PX>010>4@030P@040hA00l=
400600d83006014<400@2`l03@P<020K7`0A310040/?1P0=20`01`0E41@07QTM01LB5P0F4AD03PT=
018=4@0<1`/00`0=20`02@0;1PX02PD900h93@0E41@03`X>00/62P0=20`040/?00l:3P0200d83080
3PT=00<03`X>02@O8`0b;C400P0?2Ph01@0:1@T04`hB01`H6@0O6a`020@500803@T:00`040`=00h:
2`0810D02PH7018>3`0f<S<07a/L018>3`0=2@X03PX;010<3@0=2@X200/7200E00X61`0<20T03PX;
00d92P0<20X03`X=00h:300B3Q001@43018>40091@L04`lA010;3P0A3@l020@601@?4P0<20X03PT<
00l;3@0>2P`02`L900<030L;00D030L<00`73@0<1`d030L>00d83@0200h93@0400d8300<1`/030L;
00d8308030L;00/02`H:00`72`0=20`03@P<00X52@0=20`040/?00`72`0=20`02`H:00`72`0300d8
300=00`72`0A3@h04`l@01`H6@0=2@X030P900X61`0<20T040`=00X61`0@30d0510A00T51P0200X6
1`802`L80P0<20T07@0=2@X030P900/7200;1`P03PX;00l;300920X02`T=00h=4@0610P03PdA02l]
<@0B4A@081hR01DC5`1mNgl06APL00P6200?2`X030P601XF5@0o>cX09B4Q014>3P0A3@h03`/=00T4
200:1@T04@`A00803PT=00<03@T:018>3`0B3Pl00P0<20T200h:2`<03@T:00d030L;00l:40091@X0
3PT?02hY;`0E4A@04@`@01@?4`0A3@h03@T:01XF5`0K5aP02PH700802PP90`0;2@X0800<2P/03@/<
00`:2`0H5QL03P`=02HT9@081PT030`A00/<300>3`h03Pl:00D70`0D5Pd05AL>010B2`0C51004Q<B
00d=4@0>3A<02`T>00l=4P0B41D040hC00d;400;2@h040hC00/93P0>314020H;01<A5P0<20h03PL?
0`0=20l04`0;20l030T@00X73P0A41H020L=01`K8@081`d02`X?00d;400>31403@/@00`:3`0=2a00
30X?00/93P0=2a003`dB00h<4@0<2Pl00`0=2a002P0<2Pl03@/@00h<4@0>314040hC018@5@0A3a@0
40hC00l=4P0A3QD2010=50<03``C00<030T@00d:4@0@3A@00P0@3A@00`0?31<03`dB00l=4P0200h<
4@<03@/@01405Q@I01@B5`0=2a004@lD01<A5P0J61/06ALJ014?4P0>30l04@lB00d;3P0F51L03@/>
00h<3`0;2@`04@lB00`:3@04010>4@804@lB01003@/>018@4`0B41<04Q0C010>4@0E4aH04a4F010>
4`0H5Q/03`dB01<A5P0<2Pl03@/@014?500C4AH04@lD0P0@3Q<0500@2a405Q4G01LB600E41H04@`B
00l:400C3Q@04@`B018=4`0F4AL050lE018=4`0E41@02`H:014<401aK70030L;01LB5P0C3Q8040/?
0P0C3Q80200?2Ph040/?014=3P0D41405a<D01<?400>2P/04@d>0P0?2``01@0>2P/04Ph?01PD5@0:
1PL040X<00<04@/=0P0@2P`09@1@BT`0NG=e01lI6`0C3@l03PP:014:3@0=10T03PH:01LB5P0<1`/0
:2HY04Q6B@0<2Pd03@P<00h93@0C2a003`D:01D:3@0A1PL040L901892`0=1`P03PP:010;300;1PL0
2PD8010:3@0?2@`03PH<01883P0@1@/03`@:0146300C20h040D;00l42P0@1@/00P0>0`T0100@1@/0
4`P>01873@0A1P`201873@804@H<00T04PL=01D:400H3A<050T?01873@0@1@/04PD<01442`0@0`X0
0P0?0PT0100@0`X04@@;01032P0A10/201@73P070185300C1Pd02@030186300?10T060/B00d31`02
00h120803`890P0@0`X200h120803`890P0@0`X01P0?0`T040<:01<63@0A10/03P8801D83`H03`89
0`0@0`X200l22@0300h12?oooooooooo01;ooooo000Kooooo`8030X;0P0B4140100?3@h04Q0A00d;
300;2@X200d;300400/92P0?3@h04@d>018>3`804`l@00@04@d>00h:2`0@30d03`/<0`0=2@X01@0>
2P/04`l@010<3@0?2``03PX;00803@T:02@03`/<014=3P0>2P/040`=01XF5`070`@02@L800/92P0<
2P/040h?00l;300;1`P04`l@02HT9@0M6a`04Q0A01<A4P0@3Pl040`=018>3`0A3@h03PX;00`82@0=
2@X03`/<01PD5@0C3a0040`=01PD5@0?2``071PI00@00@0E4A802@D6024M7P0:1PL500l;300P010=
3P0B41403`d>03Hd=@0X9RL04a4B00d;30091`P020H700d;300<2P/03`d>00h<3@0;2@X02PP900h<
3@071@H03`d>02LU9P0I5aP040h?00X82@0B41405A<D00X82@0G5AH0518C010>3`0;2@X03@/<014?
400>30d200/92P0P00d;300?3@h02`T:00d;300?3@h040h?00l=3P0>30d03`d>00/92P0<2P/03`d>
00/92P0?3@h01PH800/<40071``07alQ00l?4@0b<S@03`lA00T92`0:2P`03`lA00d=3`0<30h030X;
00h<3@0B41403P`=00X82@0A3a02018@4@0@014?400:20T03P`=00D310081PL040h?00T7200:20T0
4Q0A00P61`0A3a002`T:00P61`0;2@X03@/<00/92P@030X;01h030X<00`:3@0D4QD03P`@018@5@04
0PL040hD018@5@0<2Pl03@/>00X82`0;2@`03P`?00T72P0?3A005Q@G01`J7@0?3A0071XM03Pf>@0Y
9bX01`D800<1100?3A004Q0C010>4@0;2@`020H900T72P0=2`h200l=4008018=4@0>2@d03PT=00l:
3P0>2@d03@P<014<400?2Ph200`72`0V010;3`0D3a<02`X>00d;400j>3d0QhF:01XH7@0>31403@/@
00l=4P0<2Pl02PP=00`:3`0B41H01`@=00d:4`0>2a@03@XC01<@6@091Pl01@8;01@A6P0@3AH02PL@
00P53P0A3QD03@XA018?600:21002`PC014>6@0>2QP03PXI00d96P0?2a`04`hR01@?8`0A3A/500d:
4`0300l<5P0@3AP03P/F00803@XE00L03@XD010=500>2a804a0G00h;4P0?31<0:bT^00802PP=0`0=
2a001`0=2a405ALS00013@0;3aT03Q4H00l@500E51P00P0?2``07P0E30l03PD:01H;4@0D2Pl030L;
00P62@0?3A002@L:00/930091`X03@/>010>4@0A3a8030X=00X82`0<2@`02`D900l62`0F3A801002
01@?4P0G4AD030L;01<?4`0>30l05A<F00@31@0A3a802`H:00`72`803@P<01803PT=00l:3P0;1PX0
2`H:00X52@0R7B4030L;00T4200=20`030L;00/62P0<1`/03PT=010;3`060@D05A0D00/62P080`L2
00h93@0?00/62P0A31004@`@00d8300<1`/03PT=014<400<1`/02`H:01<>4P0;1PX03PT=00T4200;
1PX030L;00<03PT=01P0QX650=7<d00S7R803PX=00L21P0@2`l03PX;01<?400?2``05Q8C00<0000L
61T03`/<00<0000@30d04`l@05IBD`0V8R<030P900/7200=2@X03PX;00/7200<20T200h:2`802`L8
01403@T:01@@4@0L61T05A4B018>3`0300004Ph?00/7200>2P/00`00018>3`050@802`L800h:300?
2Ph04@`@00l:3P0200`72`0400d8300;1PX02`H:00/62`802`H<00@03@P=00h93@0>2@d03@P<0P0<
1`/01@0=20`030L;00`72`0;1PX030L;00803@P<01L020<700/62P0@2`l030L;00d8300910P02PD9
00d8300>2@d03@P<00`72`0:1PL030P901HB4`0;1`P03`/<00d92P0A3@h01`<400T51P0=2@X0510A
00T51P0200X61`802`L80P0<20T0800810D02`L800l;300@30d030P900P41@050`H020H900X82`0?
3A001@<600L5200>30l03`d@00400P0D4QD02`T<00/92P0300004Ph<01@@3`0R7Qd02@H501dI6P0E
4A804Ph@00T4200;1PX04`hC00h93@0A31003PX;0P0?2``0100<20T03`/<00h:2`0>2P/200d92P0T
00`82@0<1`/02`H=014<4P0=20h05Q8G00<00P0O6Qh03PT=00`82@0>2P/04`l@00<0000B3Pl03@/<
00T7200A3a002`T:00<10P0:20T02`T:0040000Q7b007Q`M08N5QP0H5QT03`hD00<21`0<30h04Q8A
01LG5@0720<02@T700h>300E5AD04a<F0P0;2Q000`0@3Q<05A<H014?500200/93P0800d;400?3A80
0P05018@5@040PL02PP=014<4`0>1`l300d83`0D00/83`0=2Q4020D<00X93`0920h02`X@00`;4@0;
2Pl02@L<00d;400F51T03@/@00D320071@X03@/@00`:3`0;2@h03P`A00l=4P0>314200d;400600`:
3`0=2a003P`A00/93P0<2Pl03`dB0P0>31403@0@3Q<03``C010=500@3A@03``C00d:4@0:1`h02`P?
00`9400?31<04@hE010=500>2a800`0A3a@2010>4`803`dB00T030X?01<A5P0B41D02PP=00l=4P0F
51L0518E00`:3@0;2@`00P0A3a80200l>Sd071XM014?4P0D4QD07Q`O018@4`0A3a803`d@0P0>30l0
500@3Q404a4D00h<3`0?3A0040hA00/9300E4aH04@lB00X83@0B41D03P`A00d;400C4AH05A<H01LE
6P0E4aP0518G01DC600D4QL04Q0E0P0C3Q@08P0@2a403PT?014<4P0G4QP04`hD014<4P0B3A<05Q4G
01@?5@0A31804@d@01TD600H4aL03@P<01hI7@0;1PX04PdA00d8300B3A402`L:00d8300B3A404`l@
01HB4`0I5AH0510A00h:2`0@30d030P900T51P0J5QL03PX;00`82@0G4a@200l92`8040X<01@03`T;
00h82P0L5QP0<B/]01/E5`0=1`T05a4C01D;400H3A<04@P=00`42@0@2`l03@P<00T72P0>30l020<7
014:3P0=10T04PL=01@:3P8040L:00@04PX=00d72@0>20X04@/=0P0:10H02@0C3@l04@/=00h82P0E
31404`P>00l42P0I3Q@081DK01/@5P0201D:400301H;4@0C20h040D;00804PL=00/04@H<01@93`0E
2Q004`P>0146300B1`d03@8800h32@0J3aD0714G01052`03018530804@@;00d040<:00d01`0=00L0
3P480185300C1Pd04PD<00/01@0I31<05PT@00l22@0<00H04@@;00803P480P0?0PT201032P803P48
0P0?0PT201032P0600d01`0@0`X02P0400T00`0>0@P03@071P0?0PT0100B1@`04@@;01032P0@0`X2
00l22ACooooo000Kooooo`0I00h<3@0?3@h03`d>00l=3P0>30d030X;018@4@0:20T02@L800P61`07
1@H03P`=014=3P0@30d03PX;00l;300I5AH08alP00/7200>2P/040`=014=3P0@30d03`/<01<?4002
00X61`0601@@4@0810D0510A00`82@0:1PL030P90P0>2P/200l;300300X82@0C4A803@/<008030X;
00H0518C038`<@0]:b`0518C00/7200@30d200d92P0401`H6@0;20P040`=01HB4`804Ph?00H07QXK
00X61`0B3Pl03`/<00h:2`0@30d3014=3P04010<3@0<20T02PH700d92P804@d>01T03``=010>3`0@
3Pl040h?00l=3P0>30d030X;014?400=2``08R0Q00`:2`0;2@X03P`=00/92P0@3Pl03`d>00@20`0T
8R<0EeEF01LE5P0200403`d>0040000?3@h04Q0A00D03P`=00D020H701@B4`0D4Q<02PP900l=3P03
00h<3@0>00l=3P0A3a0040h?00`:2`081PL03`d>00h<3@0:20T03P`=00H41@0?3A003Ph@00l>400?
3A0300h>400600000P0Q8B<061LL00H52P0?3a802`T:0P0:20T00`0;2@X03P`=010>3`0200h<3@0:
00l=3P0A3a004a4B01<A4P0B414030X;00L51P081PL040h?01HD5@803@/<00@030X;00l=3P071@H0
4Q0A100>30d0800>30h03P`?00`:3@0@3Q80518G00/93P0A3Q@04@lD01@B5`091`X04a4D03hl?`0C
4A@02@L:00X92`0?3A00?S`o038`<`040PD04@lB00l=400>30l03`d@00h<3`0:20/020H900d;3P07
1@P071XM00d;3P091`X05aDH0P0@2`l200l:3P803PT=0P0A3102010;3`803`X>01D04Q0E00P62`0M
6b00;2X_00L52P0E4aP03`dB014?500<2Pl04@lD018@5@0=2Q002`P?00`9400=2Q403P/B00l<4`0:
1`h02@H=00d:4@0?31<00P0=2Q40100>2a8030X?00/83`0<2A0200h;500400d95P0<21H030PG00d9
60803PXK00d040`J010=600=2QD030TD01<@6`0B3aX040dG018?600A3QL040dF00d:4`0<2A803@XA
00D03@/@01@02PP=00`:3`0>2a8030T@00/83`0<2Q802`dI00/=6P092aH020P@00X;3`0<2`l03@T:
00H20`0E30l040D;00/01P0F2Q003PT=00`:3@803@/>0P0>30l02P0C4A@0EE=F018@4`0;2@`00@02
00l;3`0>20`040L<01483@0?2@d2010:3P08014<400;20/03P`?010>4@0;2@`02@L:00`72`0>2@d2
010;3`0400h93@0=20`03@P<00h93@803`X>00<03PT=00d8300;1PX00P0A31001`0;1PX06aHJ01/F
6P0A31003`X>00d8300<1`/00P0;1PX02P0=20`03`X>014<400A31003PT=00d8300:1@T02`H:00`7
2`0=20`200h93@0W00d8300<1`/030L;00d8300>2@d03`X>03dh?01NFEd08ahR00T4200E41@0;2L[
02DQ8P0?2``00`00014=3P0300008alP010<3@0<20T02`L800h:2`0B3Pl05A4B00d92P0300005a<D
00L3100F4Q<03@T:00`82@0@30d03PX;00T51P0:1PL030P900d92P0?2``03PX;008030P900<03@T:
00`82@0;1`P00`0:1PL01P0=2@/030L=018=4`0@2a003@P<05MBEP803`X>00D040/?00`72`0=20`0
3PT=00`72`0200/62P0I00`72`0=20`03@P<00l:3P0500@03@T<01@?4`030080;BP/00H11@0910P0
3@P<00/62P080`L030L;018=4@070PH04PdA055<D0080`L03@P<00h:2`091@H02`L800P41@02010<
3@<03@T:00P030P900/7200;1`P03@T:010<3@0A3@h0100101DA4P803@T:0P0>2P/01@0<20T02PH7
00T51P091`X02`T<00803@/>01H02`T<00T72P0>30l030X=00X82`091`X02`T<00`:2`0=2@P02PH4
01HB4@091@@04Ph>04M3A00E4A803`X=00H11@03008040/@00X52@0>2@d03@T:0P0<20T0500=2@X0
3PX;00/7200<20T03@T:00l;300>2P/02`H:00d83`0A31801@0600/6300@2`l01P4500h93@0;1`P0
30P9014=3P0@30d03@T:1P0=2``0400A3a0040h?00`:2`0=2``04a4B00h<3`1CDUL02`X?00L72@0>
3Pl030`<014A3`0@41004Q8B00l?4@0<2`l200`;4@03014?500?3A803P`A00<030X?00X05Q@I0040
100C4AH00@0401PF6`0G4aT050dD018=4`0@2a403PT?0P0<2Pl00`0;2@h030/@00l>4`0200X93P0;
00h<4@0?3A803@/@00`:3`0B41D04@lD00h<4@081P/01`D:01LE6P0?3A800P081P/0200K6Ah00@04
01DC600>31403@/@01<A5P050`P040hC0P081P/00`091``030T@00d:4@02010=500300l<4`0=2Q40
40dD00803``C01d03P/B00l<4`0@3A@01`D:010>4`0>31404@lD010>4`0?3A800P05018@5@0A3a@0
2PP=01<A5P0B41D04@lB01@B5@0F51L040hA00`:3@0?3A00>3Hi00`:3@091`X07adP092>T@0Q7b80
40hA014?4P0201<A500@014?4P0@3Q405A<F03@b=@0<2Pd05A<F00D41P0S8B@04Q0E014?500=2a00
30X?00l=4P0C4AH04Q0E014?508040hC00l04@lD018@5@0>2@l05a8H00L220080`T06A@J00l:400D
3aD040/A02PS:@1/Ifd071LM010;4@0B3A400P0A31001@0B3A404`hB01<>4P0E41@04`hB00<04PdA
00P04`hB03<_<012?Sl040`=014=3P0C3a00510A010<3@803`/<01803@T:01HB4`0@30d04@/=00h8
2P0<1PP03`T;010:300>20X04@/=018<3P0H4Q@04P`>01PB500C2@d04`P>01893P0A2Ph200l:3P0Z
01<>4P0910P030H:01D=4P0A20d05@X@01L>4`0H4Q@01`4300h92P0E3a403PD801D<3`0800801P00
01L>4@0H3a8040X<0148300B1`d0304701<83P0J3aD01`0201<83P0:00D06@hD00l52P0?10X03@88
01052`0A1P`04`P>01873@0700804@H<00h32@0?10X04PL=01D:400D2@l03`@:1P0A10/?01032P03
00l22@0>0@P03P4800H03`891P0@0`X01@0?0PT03P4800h1200>0@P040<:00804@@;00D03`890185
300F2A005@P?00h1200Dooooo`006oooool00`0=2``03P`=00h<3@0200d;30<02`T:0P0B414200`:
2`0600l;300@30d040`=010<3@0F4Q<071PI0P0A3@h0100@30d03`/<00h:2`0=2@X202l[;00Q00X6
1`0@30d05a<D00X61`0C3a003`/<00h:2`0?2``040`=014=3P0?2Pd03@P;00`:300<2``02`X<014B
4`0=30d05A@E00d;3@0:1`T03`X=00/62@0B3Pl030P900l;300C3a0061@E00P41@0E4A80920Q02hZ
:`0?2``03PX;00803`/<00P040`=014=3P0A3@h04@d>01XF5`0M6AX05Q8C010<3@803`/<01T03P`;
00h>2P0>3@`03@`<00`;2`0<2``02PT901PG600510D040l@00h=3`0;2Ph04a8D00/92P081PL03`d>
00/92P0:20T040h?00H41@0E4a@0<Bl`01/I6P0?3@h03P`=00D03@/<018020H7014?400A3a002PP9
010>3`0B414030X;00/92P0:20T030X;00d;300;2@X03@/<00T7200<2P/03P`=00T7200?3@h400l<
3P0?00h<3P0>30l03`h@00L6200];C00:2L/00X93P1BDEH0518E01@B4`0B41403`d>00h<3@0<2P/0
2`T:00803P`=0P0;2@X09`0>30d0518C014?400<2P/02`T:00`:2`0=2``02`T:00X82@0=2``040h?
00/92P0>30d030X;00d;300>30d03`d>010>400A3a8030X=00/93@091``0518G01LD6P0R82D040hC
00/9300B41<0;R`_01HD5`091`X03`d@00d;3P091`X05Q@G01@B5@091`X03P`@00`:3P0200d;3`80
30X>00H03`dA00X9300<2Ph030X>01HD60081PX2010;3`803`X>0P0>2@d2014<408040/?0P0?2Ph0
30091``04@lD00D4200A3a@02@L<00X83@0>314040hC00h<4@0C4AH05A<H014>50803P/B100=2Q40
1@0>2a803``C00h;4P0;20l030T@008040dC0`0>2Q401@0=2A803@PB00d85@0=21D03PTG00803`XI
00L03PXH010<6@0>2aL02`LC00h;5P0?31L03@XD00803@XC00@03P/D00l<500?31@030X?100<2Ph0
100<2Pl02PP>00`93`0=2Q4200X73`0M00`94P0;2QD02PTE00/:500;2a002PX?00X:300A3a0040`=
01@<400?10/060dD01@8400A31003`d@00h<3`0<2Pd02`T<00X82`081PT04a4D018@4`0200<04a4D
00h:3P0>20`040L<01483@0?2@d00P0@2Ph01`050@@040d@00X82`0:20/04Q0C00X82`0=20`01@0>
2@d01@0=20`03PT=00l:3P0?2Ph03PT=00803@P<00T04PdA00`82`0=20`0C4M;018=4@0?2Ph03PT=
00d8300<1`/00P0=20`2010;3`0500d8300>2@d040/?010;3`0>2@d00P0=20`200`72`0M00/62P0=
20`030L;00`72`0=20`03PT=00l:3P0B3A402@@800D1100E41@020<700h93@0@30d00`00014=3P0<
20T03`/<00`82@0=2@X03`/<010<3@0?2``030P900X61`0?2``01`<400/7200?2``00P0@30d00`0?
2``02`L800`82@0200d92P0400/7200=2@T03`/;00h:2P8030P80`0>2PX04@0=2@T030P800d92@0>
2@d04`hE014=4P0E41D05a8G02TT:00@2`l03@P<00`72P091@L030P:00/72@0:1@P03@P<00803PT=
0P0?2Ph01P0@2`l01`<601`G6`030080>cHj06iYK@<03PT=00l02`H:00X52@0;1PX02@@801LB5P08
0`L03`/>00P31`0>2@d02@D601DA4P0R7Ql02`L800P51@0C3a000`0=2@X200`82@0=00/7200810D0
3PX;00h:2`0D414030T900`82@091@H03PX;018>3`0;1`P03PX;01HB4`0200d:30802`P:0P0=2P`0
500>2`d03@X<00/82P0;20X030T;00`92P0<20L04@d;00T5100:1PD02`L701/G600>2P/03@T;00`7
2`0@2`l03@T=00d8300>2@d03@T:0P0<20T01@0=2@X03PX;00d92P0=2@X03PX;008040`=00P03@P<
00`83P0K5Q`0JVE[01PC6@060PD04@`@00d830803@T:00<03PX;00l;300?2``00`0:20T200/92P80
30X;01h0518C00d;300>30d02@L800h<3`0N72402`T>00h<4@0@3a402`X;00`;3@0@3a003Pd?00l>
4@0B41D03`dC00/93`0@3Q<03`dB00h<4@0=2a003P`A00l=4P071@X07A/P00d;400O7B803`dB00`9
3@0@2@l200l:3`0G010;400>31003P`@00/93@0;2`h0410C00d<400<2`l03@/@00`:3`0@3Q<03`dB
00T7300?3A8061HK00/93P0B41D03`dB014?500I5a`03@/@00P72`0B41D00P0A3a@01`0B41D01@<8
01DC600<2Pl04@lD00X83@0?3A801P0>2a80400@3A@03``C00l<4`0>2a803``C010=500=2a00518G
018@5@0G5AX04a4F00h<4@0@3Q<07Q`Q01`J7`0=2a02010>4`0>014?4P0>30l030X=014?4P0B41<0
3`d@00h<3`0A3a804a4D010>4@1lNWd03`d@00h<3`0?3A02010>4@0=00l=400>30l07Q`O04]9C00@
3Q402`T<01TG6P091`X040hC01<A5P0G5AX061HK01DC6007010>4`0=01HA5`0?2Q007APN01dH7P0@
2a406A@J014<4P0F4AL04PdC04e8CP0J5A/06aHL01@?4`03018=4@0301<>4P0D3a<04`hB00804PdA
0`0A31001P0E4A8020@500/7200F4Q<03`/<01LC50804Ph?02d04@d>00h:2`0B3Pl04@d>01@>400C
3@l04@/=00l92`0B30h05@lA01H@4P0I4aD0=S0b03`f>01/IVP06A0D01@73P0C20h04@X>010:3P0?
2Ph03`/>018=4@0D3Q806aDH01P=4`0D1`h0610E014>4@0;20/04Pd?00h82`0<10H04@L;01882`0H
3Q004@P:01092@0W8B40;2@V01D:400@1@/04@H<00h52@0M4QP00P0B1`d03@0E2Q0040D;01X?5@0;
0PH06@lD01052`0<0PL040D;01/@5P0B1`d04`P>0146300B1`d00P0C20h00`0?10X04@@;01442`04
01442``040<:0`0B1@`201442`0301032P0?0PT03`8900@03`891P0@0`X0300?0PT03P4800h1200>
0@P040<:01442`0D1`h060/B01L:4@0B1@`03P8800d11aCooooo000Kooooo`0J00d;300>30d03P`=
00h<3@0=2``02`T:010>3`0<2P/02`T:00d;300D4Q<06QPI00d92P0@30d04@d>010<3@0A3@h04`l@
00l;300>2P/03@T:00l;300A3@h04`l@00l<300A3@h400l;30803@T:01D02PH700h:2`0D41405A4B
00l93@0@2`l02@L:018A4`092P`07AhP02l`<P0S8bD03`lA00h93@0F41@040X>00l;300A3@h03@T:
00h:2`0B3Pl00P0;1`P01`0810D04@d>018>3`0=2@X030P900l;300@30d00P0A3@h02P0@30d05A4B
01LC500C3a003`/<00h:2`0?2``03`h<00d>2@0=3@/200`<2P0=00`<300@41002@T900`<3P0^;S00
2PX<00X93P0=30l03`d>014?400<2P/03P`=018@4@0201<A4P0501@B4`0D4a<02`T:00/92P0=2``0
0`0<2P/200d;300:00/92P0@3Pl03P`=00X82@0>30d04Q0A00l=3P0=2``02PP900`:2`803P`=00H0
4@l@00/92P0:20T03`d>00h<3@0<2P/500h:2`0900d:3@091`X08AlR01TH7@0F5AX01`H;01XK800<
2Pd03@/<00803`d>00<03P`=00`:2`0?3@h00P0>30d200l=3P0?00h<3@0100003@/<018@4@0?3@h0
5Q@E02DS900B41402PP900/92P091`P03P`=00d;300<2P/03@/<00803P`=01T03`d?010>4@081PT0
>CLk00D3200100@03@/A014?500<2Pl040hA014?4P0M6ah061HI00X82`0<2Pd01P@702@R9@0L6Qd0
1085010>4@0@3Q<03P`A00`:3`0:20d02`T>008030X?00D05Q@I010>4`081P/03`dB00<11P02010;
3`803`X>0P0>2@d00`0@2`l03`X>00l:3P0300l:3P0600d;400>31402`T>00`:3`0=2a004Q0E0`0;
2@h02@0=2a003`dB00`:400:1`h02`P?00d:4@0?31<040dD00l<4`0200d:4@0800`9400>2a804@hE
01DA600C3QD040/B00h9400=20l200`640803PPB00@03`TC010:500@2Q@04@`I0P0F4R00100>2QL0
2PLB00/84`0:1a4200X7400300d:4P0>2a803``B00D03`d@00@03`dB00h;4P0?31<03P/B0P0;2140
1@0>2a@050hH018<5P0@3AD03PdB00802PX<00X0108300T7200H4QP040H>01@84P0H31H040/A00h<
3`0=2`h02`T<0P0:20/02P0;2@`00@0201DC5P0=2`h06QPK00h:3P0>20`040L<01483@0?2@d2010:
3P0800d8300;1`/00P0300P62@0F51L04@lB014<400?2Ph200d8300300h93@0?2Ph030L;00@03PT=
00P030L;00X52@0>2@d030L;00d83003008050lC00d830<030L;00T03PT=00l:3P0@2`l03`X>00d8
300>2@d03`X>010;3`0>2@d00`0=20`200`72`0>00d8300<1`/030L;00d8300>2@d03`X>010;3`0B
3A404`hB00/72P03008050lC00d92P0K5aP200d92P0700T51P0?2``0510A00h:2`0:1PL02@D600/7
200200d92P0400<0000N6Q/01@4200X61`804@d>00P03PX;00d92P0>2P/030P900/71`0=2@P03`/:
00h:2@8030P700@03@T800h:2@0>2PT03PX90P0=2@P01P0=20`00`0500h93`0@31404`hD00<00P80
2`H:00D02@D600d92P0F4Q<0510A00h9300200d830803PT=00T03`X>00/62P0P6al02PD902DP900=
20`02`H:00d8300>2@d00P0=20`2014<400600l:3P0>2@d04PdA00d8300>2@d02PD90P0:1PL0100D
414040`=01@@4@0@30d600`82@0>010<3@0<20T03`/<044m?P0U8B803PX;00/7200>2P/040`=00`8
2@0@30d06QHG00h:2`0=2@X200`82@0500d92P0>2P/03PX;00h:2`0=2@X00P0<20T03`0<20L02`L6
00l;2@070`807ATH00l;2`0810D04Ph?00d92`0910P04PdA00/62`0D3a<03PT=00d92P0200`82@03
00d92P0>2P/03`/<00803PX;010040`=014=3P0?2Ph040/B00X52`0U82H04@`B01XE6@0=20`02`H:
00l;300>2P/02`L800d92P0@30d030X;0P0=2``300l=3P0A010>3`1=Bd`020H700l=3P0A3a006ALH
00`:3@0@3Q<030X=00T72P0>30l040hA014?4P0;2@`030X=00d;3P0<2Pl00P0>314200d;400>00h<
4@0?3A803@/@00P62`1]Jg00A49705eKH00>31404PhB014;3`0?2Ph03@P<00`72`0:20/200l=4007
00/;3@0=3@l030`>00`<3P0?3Q8020H;00L52P0200`:3`0H024O900Z:2d02PP=00d;40081P/02@L<
01HD6@0A3a@03`dB01dK80040`L04@lD018@5@0<2Pl09R@Y00T7300M6b000@04010>4`0@3A@03``C
00d:4@0<2A003@XA0P0@3A@200l<4`0400h;4P0?31<040dD00d;40804Q0E00L07A/P01PF6`0A3a@0
20H;014?500B41D040hC00806ALL00`02`T<010>4@0D4QD03@/>00/9300B41<0518E014?4P081PT0
7Q`O00/9300L6Qd6014?4P0;00l=400=2`h06QPK01@B5@0@3Q407Q`O01<A5P0D4QL071XO024O900M
6b000P0B41D401<A5P0>018@5@0A318071LM00h93`0@2a409B0V01hI7`0H4aT04@dB00X52`0U82H0
3@P>01<>500B3A42010;3`0300l:3P0@2`l040/?00<04`hB01404PdA014<400A310040`=01DA4P0@
30d03`/<01TE5P0?2``04Ph?01<?400G4a@06ADF00`82@0=2@X030H800d72@02010:300;00l92`0B
30h050h@010:30070@<0EU1B0=7;c@0^92P050L>01<83P0C2@h00P0@2Ph09P0@2`l04PdA01H@501f
K740@CHl00P00P0?2@h05aHK01`J7@0B3Q804P`@00h31`0F2`l060dA01T?400@1PL01P0000H1000@
20X04`P>01052`0E2Q00714G069GG@0]8RP0304700d2200E2Q001`0200`11`14>Cl01`0201D:400C
20h03P<902TO900F2a4050T?100@1@/<01442`H040<:1@0A10/00`0@0`X03`8900l22@0400l22@H0
40<:00`03`8900h1200>0@P03P4801032P0A10/02`0500l22@0@0`X03@0700`01P0=00LDooooo`00
6oooool00`0@3Pl04@l@014?4002010>3`0300h<3@0;2@X03`d>00<03P`=01002PP900`82@0@30d0
4Ph?010<3@0?2``040`=014=3P0@30d03PX;00l;300@30d04@d>01<?40070`@04Ph?0P0A3@h00`0>
2P/04@d>01DA4P0200l;300901@@4@0B3Pl040X>01<=4@0610L040lB018C5@1?D5806AXL008030`>
00/040/?01@=4@0D3Q804`l@00d92P0A3@h04`l@00X61`0A3@h03PX;014=3P0200h:2`0300X61`0B
3Pl040`=00804@d>00@040`=00l;300=2@X03@T:0P0?2``03`0>2P/03`/<010?3@0@4@`03Pl:00d=
2P0=3@/03Ph>00l?3`0A4A40LW9d0:VX[00I61d03PdB00h=4002010>3`0<00`:2`0?3@h03`d>00/9
2P071@H02PP900/92P0A3a004Q0A00X82@0=2``03P`=0P0?3@h2010>3`03014?400?3@h02`T:0080
3@/<00@03P`=00/92P0:20T03@/<0P0?3@h050091`P03`d>00`:2`0G5AH0:2HW01TF5`0?2@T040T9
00l92@0?2@/03`X;00h93@0<2Pl08R0U00P7300>3a@03@hC00l@500;2@`030X;0`0>30d0:00=2``0
4@l@00/92P0<2P/04Q0A01DC500>30d03@/<01@B4`0>3@d020H7024P8016A4D030X;00d;300H5QL0
3@/<014?40071@H04@l@010>3`0?3@h03P`=00d;3@0<2Pd0518E038`=00@3Q<03P`A00`:400<2Pl0
2`T>014?4P0<2Pd061HI01@B5@0;2@`03`d@00/9300<2Pd2010>4@0=00H41`0=2a003`dB00h<4@0=
2a0040hC01<A5P13@DH0KVaa00l=4P0D4QL01`H:018@5@02010;3`803`X>0P0>2@d600l:3P0700h<
4@0?3A803P`A01PF6`0Q7b@03P`A00l=4P0200d;40802`T>0`0=2a0300h<4@0300l=4P0>31403P`A
008030X?00<040hC01@@5`0A2aD00`0?2A<200d83`803PT@00/03`XA010;4@0@2a803PTD010<6`0B
3Q`03@TG00h:600?31L03@XD00`94P0300`9400400`:3P0>30l03P`=00h<3@803P`?01D03P`A00`9
400>2a803``E00/84@0:1a003@PC01894`0B21006Q<J01dI7P0D4QD04A4A030`<P0A41<030L>0148
4P0=0`l04PLC00h93`0<2Pd0100=2`h00`0B41<030/=00l=400200h<3`0504I2AP0>20`040L<0148
3@0?2@d00P0@2Ph0200F4AD040`@00h<3`0<2Pd0;R`_06e[KP0C3Q804@`@0`0?2Ph00`0@2`l030L;
00d8300200h93@0800d8300<1`/04PdA00`82`0C3Q801`<601<>4P0910P300`72`0800d8300?2Ph0
40/?00`72`0>2@d040/?00l:3P0=20`200`72`803@P<0`0?2Ph01`0=20`030L;00`72`0=20`03PT=
00l:3P0;1PX00P080`L03@0@2`l04PdA010;3`0I5QH04@d>00L3100:1`L0;BTZ01PD5@0C3a0040`=
00l;300>2P/00P0=2@X02@0<20T04`l@05]GF00F4Q<04@d>00h:2`0@30d0510A010<3@0200X61`04
00/71`0=2@P03`/:00h:2@@030P701<03@T800h:2@0>2PT030P700h93@0D41H0HeiU04E0A`0=2@h0
20@900l:3`0>2@d030P900h:2P0F4Q40510?00d92P0;1PX030L;00<03@P<01P03PX=00T5200>2@d0
1P45010;3`0B3A402`H:014<400?2Ph02@@800`72`0;1PX04@`@00P31`0:1PT030L;010;3`0=20`0
3`/<00T51P0<20T02`L801<?400A3@h500`82@0?00d92P0<20T03`/<00d92P0T82403@T:00`82@0B
3Pl03PX;00/7200>2P/040`=00h:2`0<20T03@T:00803`/<00<03@T:00`82@0>2P/00`0>2P/0400=
2@X030P700h:2@091@@03PX902<O7P0>2PX03`/<00d92P0=20/04@`@010;3`0@2a0030P;00h93@0=
2@X200`82@0300d92P0>2P/040`=00803PX;00X040`=014=3P0?2Ph09b8X00h:3`0H4aT04@dB00H1
1@0=20`030L;0P0?2``00`0=2@X03PX;010<3@0600h<3@0<00X82@0]:b`00`8200l=3P0;2@X03@/<
014?400B41803@/=00d;3P0@3Q403@/>0P0<2Pd0200?3A003`d>01`J700[:B/03`dB00h<4@0=2a00
3P`A0P0?3A801`0<2`l0518G014?500>314040hC00l;3`0@2Ph00P0>2@d0100?2Ph03@/>01DC5P0D
4QD200`<3P0300/;3@0<30h03`hB00801`D:01X040hC00T730081P/03P`A00X83@0E4aP0;R`a01HD
6@081P/04@lD01DC60081P/03@`@01<A5P1=Be005aDJ04Q6B`0E4aP03@/@018@5@0A3a@040dD00l<
4`0>2a803@XA00h;4P8040dD0P0?31<03`0>2a803``C010=500>314040hC00l=4P0F51T03P`A010>
4`0B41D04@lD00h<4@0B41D06QPM01@B5`0200`:3@0;00l=400E4aH05Q@G018@4`0A3a8040hA018@
4`0A3a805aDH00T72P0A3a80100@3Q402P0A3a805aDH00h<3`0C4A@04Q0C01LE60081`T05A<H014?
500C4AH201PF6`0301<A5P0A3a@04a4F00805A<H00@04a4F014?500G4QP09B0V0P0E41H02`0U82H0
5a8H01D@5P0E4AH06QDK010;4@0H4aT040/A01HA5@0D3a<04`hB00<04PdA00d05A0D01HA5@0F4AD0
5Q4E01<>4P0B3A403`/<018>3`0C3a004Ph?01<?400?2``0510A008030P900D061@E00`82@0H51D0
4P`>00h82P0201@>40803@L903404`d?00X51P0F4180618D02XT9P0E2Pl05@L>01@83P0C2@h04@X>
010:3P0?2Pd04@`?01<;3`0F31805`/A01P:4@0?20h05AHJ04M6B`1>BTl050`A01<8300E2Ph04`L;
01<72@0E30`050`:014<2@0B2@/05P/A01873@0@1@/03@@803L/<P0G3A8040D;01<83P0B20d03`D:
01L<4P11=c`04@P<01<83P0=10P05P/A03X`=@0F2a4050T?008040D;0P0A1P`601442`H04PD<1P0@
0`X500l22@0301032P0?0PT03`8900@03`891P0@0`X01@0?0PT03P4800h1200>0@P040<:00804@@;
00D03@4700h1200B1@`04PD<00h2200Dooooo`006oooool03`0?3@h040h?010>3`0@3Pl03`d>00d;
300<2P/02PP900H41@0>30d0:2HW03Dc=00<20T040`=014=3P02010<3@09014=3P0@30d040`=010<
3@0?2``03@T:00`82@0A3@h02PH700803@T:020071PI00d92P0E4A8071PI01<?400@30d04Ph?00d9
2P0E3A<03PL>00L52P0F51T01`P<05QLG`1ZK70051<H00h=4P0G4QP03`D=018<400D3a007ATJ01<?
400@30d02PH701XF5`0<20T03`/<01PD5@0a;Bh040`=00/720<04@d>01D040`=00l;300>2P/03`/<
014=3P0?2``030P900h:2`0@3``03a0:00d>2@0;30P030`:00d=2`0E5AD02`/=028R9019BD`02@P=
00P73@0<2Ph00P071@H05@0D4Q<06ALH01@B4`0?3@h04a4B00/92P091`P03P`=00/92P0<2P/02`T:
00d;300>30d03`d>010>3`0>30d03@/<00h<3@0?3@h03@/<00`:2`0200/92P0600`:2`0?3@h040h?
00l=3P0=2``04Q0A0P0<2P/01@0E4a@02PL8010:2P0B2PP04PT:008040X<00/03`X>00L52P0>3140
2PT?01<D6@010PL01PH=018@4`0A3a0040h?00h<3@0200d;300A00/92P0=2``03@/<00d;300>30d0
3`d>00`:2`0H5QL07A/L01PF5`0C4A805A<D00`:2`0?3@h061HG00D3100F51D00P0@3Pl03`0?3@h0
3P`=00h<3@0=2`d030X=01DC5P0:20`04Q0E01LE6P0=2a4040hC01<A5P0F51L03@/>02DS9P0201<A
500B00l=40030@@06QPK010>4@050`H03P`?00h<4P0D4AP04a0G00h;4P0@3A@04a0G01`I800V8bX0
0P0600/93`0P7B@02`T>0P0@2`l200l:3P803PT=0P0=20`05P0>2@d03`X>00l:3P0?2Ph040hC00<1
1P0=2a00;bdb03Tg?00;2@h040hC00d;400@3Q<030X?00d;400A3a@040hC00l=4P0=2a002`T>00X8
3@0<2Pl200h<4@0:00/93P0:20d030X?00l:4`0?1a@03@DB00l74`0B2QD04P/C01094@803`P?00D0
40X>014;3@0A2`l03@TA00`85`0200d96009014=6`0@3AP03@XD00h;500=2Q403@X@00`:3`0<2Ph0
2`T<00802`T:0P0;2@`0500;2@h030T@00l<4`0B3aP03``E00`94P0<1a806PlG01032P090@D020<7
00H41@0E5AD0?Ci001XJ700;20h04PXG01<;6P0A21H04@`B0P0?3A0300h<3`0:01@B5@0100805aDH
00800`0F51L05A8E00h8300@1``04@P=00l93@8040X>00H01@0400l<3`0D4QD030X=01HD5`0j>3/3
00l:3P0500h93@0=20`02`H:00/62P0<1`/00P0=20`0200<1`/02`H:00@00`0E41@00`0201XE6@0D
3a<030L;0P0=20`200`72`803PT=0P0=20`200h93@803@P<1P0>2@d02P0=20`030L;00`72`0=20`0
3PT=00l:3P0>2@d040/?00l:3P070PH200d8300800L4100300001`<402HR8`2IUIH0PGen00d92P0?
2``2010<3@0800h:2`0<20T03PX;00H20`0L61T01P<300`82@0@30d200h:2`0700d92P0;1`P02`L8
00/71`0=2@H03`/800h:1`0400`81@0A00h:1`0@30T03`/800h:1`0H4aL030H@02hY<00Q72<02PD<
01HA5`0;1P/03PT=00h:2`0;1`L03PX900h:1`0<20P00P0<1`/200d8300800h93@091@P03@P<00d8
300@2`l05Q4E00/62P0D3a<2028M8@804`hB00`04PdA00@00`0A31005A0D00P31`0?2Ph05a<F00d9
2P0;1`P03@T:00<000070`@300/7208030P90P0=2@X0300H51D04@d>00H20`0;1`P0510A00/7200?
2``03@T:00`82@0>2P/03`/<00`82@L03PP:01<03`T;010:300?2@/03PP:00`61P0<20L03PX800d9
200>2PT030P8010<3@0?2``03@P;01D@500400<07aXO00P31`0>2@d03@T:008030P900l03@T:00h:
2`0?2``030P900/7200=2@X03`/<00l:3P0I51/050lE00<0100E41H020<702LR9P0?2Ph00P0>2P/0
1`0A3@h040`=00l;300=2``030X;00/92P0:20T00P091`P02P0;2@X01@<400d;300A3a003@/<00h<
3@0;1`H040`=01DA4P0D4142010;3`0901@?4`0@30d04Ph?00X61`0?2`X07ATJ014?4`0?3A803P`A
00803@/@01@04@lD01@B5`040PL03P`A00H42@0K6Ah03`/?00h8300=20`03`X>014<400@3Q40518E
010>4@0<30h04a<E014A4`0=3@l040lC00h<4@801`D:01H03@/@018@5@0C4AH01`D:00h<4@0J61d0
2PP=00/93P0B41D0>SPm01<A5P0I5a`040hC00X83@0=2a002`T>00X83@0<2Pl01P@900l=4P0=2Q40
3P/B0P0?31<200h;4P0=010=500?31<03``C00h;4P0?31<040dD014?500B41D03`dB01<A5P0=2a00
7Q`Q00d;400200l=4P0A014?500F51T06ALL010>4@0B41<06ALJ01`J7@0J61/04Q0C01PF6@0?3Q00
1`D801hL7`0B41<09R@W010>4@0?3A000P0>30l02P0?3A0040hA00400P0L6Qd040hA00@21@0<2Pd0
3P`?01DC600B41D2010>4`0401<A5P0E4aP040hC01<A5P805A<H00P04a4F010>4`0H4aT04`hD01XE
6`0I51X03`X@014<4P805A0F00L07QTO00l;400J5A/050lE01HA5@0D3a<04`hB00<04PdA02<050lC
01HA5@0F4AD05A0D018=4@0A31005A4B01hJ6`070`@09B4R02<O800=2@X04`l@00d92P0V8R<0B4A5
01DA4P091@H03PP:00`6200A2`d030H8014;3@0O6A/02PD600d72@0A2`d050h@00P2100F2a005PL>
01@73P0C2@h04PT>010:3P0201<=4@0Q01D<4@0A20`0200201832P0G4AL04Q<H04i=DP1PG6406Q4F
0146300900004`@701X>400I3`l040P600`70`0<10@040D;00l42P0G31806@hD01P=4`0G31805@X@
01P=4`0900@05``B00T0100A20`06@hD00l52P0;00H050T?00804`P>00D04@H<01052`0A1P`04PL=
0146300601442`H04PD<1P0@0`X200l22@<040<:00<04@@;00l22@0?0PT0100?0PT601032P0800l2
2@0>0@P03P4800h1200@0`X04@@;00l22@0=0@L300`01P0300/01Ooooooooooo01;ooooo000Koooo
o`0800h<3@0>3Ph03Ph>00h>3P0=3@d02`/;00X:300<30h200H6200>00l?4@0=3@l02PP9010<3@0A
3@h040`=014=3P0B3Pl02`L800h:2`0@30d04@d>010<3@0?2``200`82@0R01XF5`0<20T04@d>00T5
1P0?2``06QHG010>3`0>2``04Ph?00d92P0>20`07aXN00l=400@3Q80>CXn0<K:c@2g^K/08B0U00T9
2`0D3a<02P@8018<3P0H51D0@Cdn02@P8@0<20T05A4B030/;@0I5AH0510A00T51P0F4Q<020@5018>
3`<04@d>00<040`=00h:2`0>2P/00P0?2``01P0<20T02`L800l;300A3`h03Pl:00d<20802PX800`0
3@`:00X92@0?3a400@02018A4`0:2@h03@/@01@B5P0;2@X02PP900h<3@091`P200`:2`0@01HD5@0?
3@h040l?00d;30030@8030X;00X82@0;2@X030X;00d;300>30d02`T:00X82@0=2``040h?00l=3P<0
3@/<00@040h?01<A4P0D4Q<04@l@0P0=2``300`:2`0D010=3@0@2PX040/8010:2P0@2P`03`/<00l;
3@0>30l03`d@00L62`0@3a@02P/?00`;400A3a803`d>00d;300<2P/03P`=00l=3P0:20T2018@4@05
00/92P0:20T04Q0A01@B4`0>30d00`0:20T01`081PL02`T:00/92P0D4Q<01`D603Dc=015@d@0100>
30d0800>30h03P`?00/9300>31003`dB00D3200:20d02`T>00h<3`0>30d01@<402@R8`0:20T03@/<
01HD5@0100004@l@00T7200:20/05ADG01@D600G61d05A@I00d<4@0920h02`X?00T73@0:1`h06aTN
014>500<2A0030L=0P0@2`l200l:3P803PT=0P0=20`0;P0>2@d03`X>00l:3P0?2Ph030X?010>4`0M
6b001PD900h<4@0<2Pl03@/@00X83@0?3A802`T>00`:3`0@3Q<03P`A00h;4P0=2a4030X?00`9400:
20h02PP=00/83`0;2@l030X?00h;4P0?2a<030H@00`43`0?21<04PdD01@=5@0A2a803PT?00l93@0@
2Ph040`=014;3`0A3AD04PhL010<6P0?31P04PlJ00h;500:1a0200d:4@0500d;4@0=2a003@/@00d;
3P0=2``00`0=2`h0700=2a0040dD01<@5`0H5A`05A8K014>5`0?2a<04PP@00l42P0F3a<061<G00X8
2@071PP03`lA00T83@0>31802@<=00`44@0>1Q@050lE018@4`0A3a803`d@00h<3`0=2`h00@0201`J
7@081PT201<A500300`9300>1`h03PL>00803`P?00T040X?00l:3P0F4AD040`@00X82`0?3A004Q0C
00P62@0=20`00P0>2@d01@0=20`02PD900P31`0;1PX030L;00803@P<00X030L;00/62P0>2@d02`H:
01HA5@0<1`/02`H:018=4@0>2@d03@P<0P0<1`/02P0=20`03PT=00l:3P0=20`02`H:00`72`0>2@d0
3`X>010;3`0?2Ph200h93@8030L;00h03@P<00`72`0<1`/03@P<00h93@0?2Ph050lC00/62P0E41@0
4@`@00h93@0:1@T03PT<024M7P800`0001L0<Bd^01`H6@0>2P/02PH700T51P0;1`P040`=01<?400B
3A403@P<00<0000B3Q003@T:014=3P0=2@X020@500X61`0>2P/03@T:00/71`0=2@P03`/:00h:2@03
00`81`0B00d9200?2`X04Ph=014=300?2`X0920S01`G7P0C3Q@02`H<00T42P0G4QP02@@900`72`0>
2@d030P900l;300A3@`03PX<0P0=20`0300>2@d03`X>00l:3P0C3Q801@0400/62P0B3A4020<700l:
3P0400<05Q4E01TD60802@@80P0:1@T06P0>2@d04PdA00D00`0B3100BTA801LB5P0?2``03`X=00h9
3@0E4A803PX<00/62P0;1`P030L:00`72`0=2@X03@T;00<0000>2P/05a<D00<0000>2P/04Ph?00X6
1`0=2@X040`=0P0>2P/00`0@30d040X<00h82P0200`6200F00h82P0@2P`03@L900l92`0@2P`03`T;
00d72@0;1@L0208201@?3P091@@00`00010<3@0A3@h03`/<00T51P0E4A801P4504@o@`0g<SH03PT=
00d92P8030P901P03@T:00h:2`0?2``02`L800X61`0<20T03`/<00h93@0;1``040/A01D@500=20d0
6A@H01dH700@2`l03@T:00h:2`0C3a004Ph?00l;300>30d03@/<00`:2`0:20T200P61`0E00X82@0B
414030X;00T8200B4140518C00`82@0?2``05A4B014=3P0@2`l05a8F01@?4`0?2``05A4B018>3`0A
3@h06QHG014?4`0?3A803P`A008030X?02`02PP=00T7300Q7b@02`T>00l=4P0:20d0510C018<3P0@
2`l03`X>010;3`0>30l03`d@00`:3@0=3@l05aLI01DE5`0>3Q002PT=00h<4@0@3Q<03`dB014?500?
3A803P`A00D3200C4AH04@lD00P62`0C4AH040hC0040100D4QL01@@8020N8`0?3A803@/@00X83@0B
41D020H;018@5@0>314030T@00d:4@8040dD00<03``C00d:4@0@3A@00P0?31<0100>2a803``C010=
500A3a@201<A5P0601PF6`0F51T0;bdb00h<4@0C4AH0518G0P0<2Pl03`0D4QL03`d@024O8P0_;C00
6QPK00`:3@0E4aH03`d@01XH6`0C4A@09R@W00h<3`0:20/04a4D014?4P02010>4@0@014?4P0C4A@0
518E010>4@0B41<06ALJ00l=400D4QD05aDJ01PF6`0E4aP04a4F01DC600I5a`04a4F01DC608061HK
01805A<H01<A5P0G5AX04`lE014?500D3aD05Q4G01`G7@0P6b4030L=01TD600F4AH030L=014<400C
3Q804@`@010;3`0?2Ph200h93@0;01<>4P0E41@05Q4E01@?4`0A310040/?010<3@0A3@h040`=01PD
5@0300000P0E4A804@0>2P/030P901PD5@0D4140=S8c00/51`0?2@/04`d?00h82P0P6Q`0>C<e048l
?P0@2P`0208401TC5@0=1`T04PL<008050L>01d04`P>01893P0B2@h03@D:01L>4`0C2Pl05@X@01X=
500A10/03@H<00T83@0@3a@03PX>01/B5`0W72@07Q4H01T=4@0D20`03`D601491`0E3@/05`h?01@;
400900D030<801<:3`0700804`P>00L00P0201<83P0901X?5@0D2@l03PD900d2200C20h060dC00l4
2P0H3A<04@H<008040D;00<04PL=01<83P0A1P`01P0A10/6018530P040<:0P0A10/2018530H03`89
0P0@0`X01P0@10P040<:01442@0@0`X03P<900d220803P4800P04@<:01<42@0@0@P050D:01452@0>
0PH03`<701@831Cooooo000Kooooo`0400h>3`0930d04aDG00D82P806ahP00P041@G01PL7`0Q9BT0
2PlC00L=400@51L030`>00l=3P8030X;02H040h?00h<3@0=2``03@/<00`:2`0=2``03P`=00l<3@0D
3a006ADF01LC500?2``03@/<00l=3P0A3a002`X:00l?3`0a<C4030/;00l=3@0>2@L040`:01<B400;
2P/08R<U04E6B01BDeD04Q8D00d=3@0>2PT071LD00X60P0C40d06APF014@3P0;2PP03@`:020O7@80
40h?03003`d>00h<3@0<2Pd02@L:018@4`0:20/03P`?01HD5`0:20/02`T<00l=400F51L03`h@00T7
2P0?3A003@/<010=3@0B3Ph040d>018?400A3@h03PX;00l<3@0@30d03PX;00/82P0>2P`03P`=01PH
600:2PX030`<00L71`0C4A8030X;01@B4`0G4a@03@T:010<3@0B3@h040d=014@3P0<2`T02`X8014@
3P0;2PP03@`:00`;2@0=30X200l>300300`;2@0?3P`03`h<00803`h<00<03Pd;00d<2P0>3@/01@0>
3@/0300<2PP040d<018@3`0710@0;Rd[03Dd<P0A40l03P`<00/92@0<2PX02`/:00h=30803@/<100<
2P/200h<3@0500X82@0<2P/040h?00/92P0>30d00P0@3Pl03@0>30d03@/<00h<3@0;2@X040h?00l=
3P0=2``0;B//02h/;@0U8bH0<Blb01PF6@0C4A@00P0<2Pd08@0;2@`03@/>00h<3`0>30l03@/>00/9
2`0?2P/04@`<018>300<20D04a0=00d<200G5Q802PX800l?3@0?3`h02`/;00h@3`0M9bD0WjRY0;W1
`@0k@D803Q8D00`>400?3a802PP<00h<3`0?2Pl04P`A00h93@0;20/030X=00d;3P0200h<3`0@00d;
3P0G5AP04@lB00h<3`0?3A0030X=00X82`0<2@l040dD00L42`0C41L020H<01PE700F4aX0:2D/014>
5@803P/B02403@XA00/8400=2Q<040dE00P53@0?31D040dE01@A6@060``030TA01<@60050P/03@XA
00H42P0<20h05a@J01DC600D41H03@X?00P62`0E4AL03P/@00/:3@0E4QL03@X@00h;4@0<2Q002`T?
010>500@3A<030X@00d;400?3A800P0@3Q<01@0>314030X?00h<400A3a@03`dB00803@/@00`04@lD
00T7300P7R<03@/A00`93`0;2@h03@T?00d:3`0@31803`dB00h<400<2Pl200d;400900l=4P0@3A<0
3`/A00h:400=2a00:BL/01DC600=2a003`dB00803@/@01T03P`A00l=4P0<2Pl02`T>00d;400B3QH0
3PXB00X63P0A3A@02`P>00d;4@0?3A803@/?00X82`091`X02`T<00h<3`0B41<05aDH00@31@0>30l0
2`T<00h<3`0=2`h030X=00802@L:00@030X=00d;3P0<1`/03PT=1@0?2Ph01@0B3A4020@7010<3`0<
20/02`H:00803@P<0P0<1`/00`0=20`03PT=00`72`0300h93@03010;3`0B3A402PP=008020H;00D0
2`T>00l=4P0A3a@02@L<00P62`0200l=4P0300/93P0=2`l03PT=00802PD90P0=20`0100<1`/03PT=
00d8300<1`/200d8300X00h93@0<1`h03@P>00h93P0>2@l03@P<00`72`0@2`l040`=01HB4`0@30d0
20@500l;3@050P<05Q4D00h:300A30l020D606IRI00g<SD03`X=01D@4`0;1`T04@`?010<3P0=2@/0
2`L900X6200;1`T03@P<01D@500G4QH04@`A010;400I51T05A0G018=500@2a402`H<00`73@802@@:
02@03PT?00/6300<20d040/A00l:400>2@l03`X>00`72`0>2@d03`X>00`72`0B31003`T=00h8300?
1``04@P=01893P0C2Pl03`X>010;400910X03@P>00X52P0D41D02`H<01LB5`0F4AL02PD;00h93P0A
31803`X>01@@4`1[IVX061@G00P31`0@2`l300d8300800`72`0;1PX02`H:010<3@0<20T0<Rh_00/7
200@30d300`82@803@T:01<03PX;00h92`0?1`/040L;00l72`0>20`03PP;00h82P0;1`P03@X:00P7
1@0;2@T02PP8020N7P0@3Q403@/>00/9300:20/030X=00L03@/>00X02`T;01<A4`0D4Q<030X;00l=
3P0J61T02PP900`:2`0;2@X030X;0P0>30d0100?3@h03P`=00d;300=2``200`:2`802`T:00X02@L8
00d;300>30d030X;00d;3P0@3Q404a4D05YHF`091`X04@lB1P0>30l01@0=2`h030X=00`:3@0<2Pd0
3@/>00802`T<01403@/>00h<3`0>30l03`d@014=3`0@2PX03`/;00h:2`0?2``03@/<00l=3`0?3A00
3`hC01<B5`0B4AH030/@00/93P0200h<4@0300d;400<2Pl030X?00<03@/@0`0>31401`0;2@l04@hE
010=500>2a802`P?00h;4P0:1`h00P0=2Q402`0;20l03P/B00h;4P0?3Q@03PdC01<B600E51X040lE
00h=4`0@3aD04A0F00803@`B00T04Q4G010?5@0=31403`hC00d<4@0F5AX03@`A00l>4`0@3a@00P0>
3A802@0A41D04Q4F010?500C4A@061<G01XE6@0C3Q8040/?01<>4P06018=4@0<014<4P0B3A<071LM
010;4@0E41H06aHL01HA5`0O6R004`hD00h93`0E41H050lE0P0B41D201<A5P0=01@B5`0E4aP05A<H
014?500H5Q/05A<H01PF6`0=2a004Q0F014@5@0E51T040lD01@C5`02018@4`0801<@4`0E4A805Q8C
01LA500G4A<05Q8C00l;300@30d201<?400:01@@4@0C3a004Ph?010<3@0B3Pl04@d>01<?400D4140
5a<D01<?40804Ph?00D040`=014=3P0A3@h04@d>010<3@02014=3P804@/?01`0618F00h8300C3A40
4`dA01D?4`0A2`l05Q0D010:3P0?2@d06A0E01@93`0B1`d04@H<01873@0E2Q005@/@01D:400F2a40
50T?01873@0C20h03`L:01@?400=20T04``@01H<500P5R0050TD0P0@1@h06P0A1@/04@H901871`0@
20T03`X>010:3P0>20`030H:00h62`0@20d040L<01483@0?1P/0?C<i03DZ<00>1@T06@hD00h42@0K
41H030<704]0AP0F2a404`P>0146300?10X03P<90`0@1@/2014630@040D;00L03@8801P=4`0C20h0
4@H<01032P0E20l03P4800804`H=00<04@D;01032P0@0`X00P0A10/201032P803P<;01H03P<900l2
2@0?0PT03`8901842P0A10L04P<701011P0C10P03P<600T21P0=1`/040H900l4200B0`L04`450180
1@0B0PD04@<40103100?10@03P@45?ooool001_ooooo01803A4D010E600A5QT01``@00/@50001@T0
000506U/L@2/[k@0:Rha00D9300L82<03Ph@014?400<2P/02`T:00h<3@0;2@X600d;300N00T41@0D
4140510A01DA4P0T8R<0<Bl`00d;300?3`l0410@03Ti>@0<30`04A0>018=2P091@@030X;014@4@08
2@d01@H:00`=400H61X0410@01@@400400005Q8?014>3@0@3`d03@`:014@3P0:20T04@l@0`0>30d0
2`0=2``02`T<00`:3@0:20/02`T<00`:3@081PT02@L:00X82`091`X01085008061HI00<020H900X7
2@0=2@X00P0@30d00`0B3Pl040`=00d92P0200l;300H00h:2`0=2@X03`/<018@4@0000001`L700d=
3@0D51@040h?00T7200A3a00510A00d92P0A3@h04`d?00`8200100002`X800L6100E51803`h<00d<
2P0<2`T03@`:0P0?3P`00`0<2`T02`X800`;2@0400d<2PH03Pd;00X051<A014@3P0:2@P040l=00l>
300O7Q`02PT700`;2@0>3@/030/90P0:2@L07P0>30d03@/<00`:2`0;2@X03@/<00h<3@0<2P/03@/<
00X82@0;2@X03`d>00T7200<2P/04@l@01<A4P0A3a003P`=00`:2`0C4A805A<D01LE5P0<2P/02`T:
00P61`091`X061HI00d;3P0?3A003@/>010>4@803@/>0P0<2Pd200d;3P0P01<=4@0A30l04@d>00`8
2@0D4Q003Pd;00`;2@0;2`/02`/=00T83@0920h02P/?03Dn?@3QjnX0logl04]BDP0830d03A4B010A
4`0<2Pd04a4D00`72`0E3a<02@@8010<400=2`h030X=00h<3`0?3A0040hA01PF6@0?3A0200`:3@0L
00d;3P0>30l061HK01/I7P0:20d01P@9018@5@0X9R/0518G00/93P081P/03P`A00P62`0>2a<06QLP
014>5`0710d05A8K00d:4`050`/04PlH00`94P0A3QL04PlH00P53P15@TT0>SPm00d;40801P@900P0
3@/@00l=4P0610T02`T>00L52P0B41D05Q@I00H52@803@/@00@030X?00l=4P0=2a002`T>0`0=2a02
00`:3`0300T7300<2Pl03`dB00803P`A00T040hC00h<4@0<2Pl05A<H010>4`0200D03@/@00`:3`0=
2a000P0>314200d;400@014?500?3A8030X?00X83@0;2@h03@/@014?50081P/03@/@01@B5`0:20d0
3@/@00/93P0>314040hC00h<4@8030X?00`03@XC00d;4`040@X06aPO00X73P091Pd09bDZ01XH700<
2Pd02@L:00H41`030@@201XH6`0600P62@0<2Pd02PP;00d;3P0@3Q403@/>0P091`X03`0=2`h040hA
010;3`0?2Ph03@P<00`72`0>2@d03`X>00/62P0:1@T01@0401HA5@080`L06aHJ00h93@0200`72`06
00l:3P0=20`02PD900T4200=20`03PT=0P0=20`03@0>2@d030X?00X83@091``02`T>00d;400>3140
1`D:01LE6P0o?D80;bdb00H42@0<2Pl00P0=20`00`0<1`/02`H:00d8300200h93@0900d8300<1`/0
3@P<00d8300>2@d02PD<00`73@0=20h03`X@00803`X>01H02@@800`82@0O6a`02`L8018>3`0M6A/0
5A0D00<00P0;1PX00`0201TD601BCE40:RDY00<00P0D3a<02`H:00`72`0>2P`03PX;00`82@0;1`P0
2PH70`0;1PX01`0<1`d03@P>014<4P0?2Q403`X@00d83P0:1@/00P0<1`d01@0=20h03PT?01LB600F
4AL02PD;00802`H<00P02PP;00T72P081PT03@/>018@4`0>2@d03@P<00`72`803@L;01@03PP<00l9
3@080`T04PdC00d83P0?2Q0030L=010;4@0<1`d04`hD014<4P0;1P`03`X@00h93`0[9RX020<701XE
6@0300802@@801XE6@<03@P<0`0<1`/01P0<20T04Ph?03<_<00<20T040`=00d92P@040`=0P0?2``3
00l62`<03@L900H03PX;01HC50091`P020L500@30@0:2@L200d;3P8030X=0P0;2@`600d;3P08010>
3`0;2@X03@/<00`:2`071@H020H700`:2`0=2``200h<3@8030X;01003@/<00X82@0:20T02`T:00h<
3@0@3Pl03@/<00D3100=2``03`d>00T7200:20T02@L:00`:3@0>30l02@L:2@0>30l300d;3P0=00h<
3`0D4QD03`d@00P62@0A3a806QPK01<A500>2P/040X:00l;300>2P/03`/<00d;3P0200l=400500`;
400>3A803PdB00d<4@0=2a000P0>31400`0=2a0030X?00`:3`0300`:3`0800d;400>31403P`A00T7
3@0A3QD03``C00/83`0B3aH200`9400?00l<4`0=2Q402`P?00h;4P0=2Q403@`B00`;4@0@3aD04a8H
00h=4`0=318040lE01<B600A41H030/A00803`hD01<03@`A01LF6`0=31402PT>00d<4@0H5a`03`hC
010?500A41D03`hC00h=4P0@3a@02`T<00l=400B41<040hA00l=400C4A@03P`?00803`d@00l040hA
014?4P0A3a807adR01HD6@0=2a0040hC01hL8@091``04Q0E01HD6@0>31403@/@01@B5`0@3Q<00`0A
3a@3018@5@0801<A5P0G5AX05aDJ01<A5P0L6Ql03`dB00`;4@0J6Al201@C600600l=4@0Y9bX04Q0C
01<@4P0D41404`l@0P0D3Q001@0K5aP0:2@U01`H6@0>2P/040`=00804Ph?00/04`l@01PD5@0;1`P0
4@d>00/7200M6AX071PI01@@4@0?2``03PX;00`82@0600l;300301D?4`0A2`l08adQ008030H:00L0
4P`@014;3`0@2Ph03PP<00l93@0D3Q805@dB00L04`P>00/050T?01873@0@1@/04@H<01072@0F4100
3`T;01@<4@0?1@d05@/F00l43`0201<74@0601@83P0D20`050P:01892`0>20`03PD:0P0?1P/03@0<
1PX040X>00`62P0400804P`@00l93@0:0@H04@L<01D:400;0@H050T?0146300700800P0B1`d01P0A
1P`03`@:00l42P0?10X03P<900l42P804PL=00<04@H<00l42P0;00H00P0?10X03`0I3Q@050T?00l4
2P0>0@P05`XA00d21`0;00D0300600P00P0B1@`04@@;01032P0?0PT040<:0185300400l22@0D00l3
2@0>0`T04`P>01042`0E20l03@0701@73P0E2Q004@XA00h83`0A20d04PL=01<32P0A00H04@0400h0
000@0@@05PL:01<82@0;0@8Dooooo`006oooool04`0:3aD041DK01<H7P0=4QP041DJ00T>4P0c=S/0
7B0U030c>00310P04A8F0042100>3Ph04@l@00`:2`0;2@X03`d>00`:2`0=2``00P0>30d04`0=2``0
30X;00`:2`0B30h05A4B018>3`0?2``05Q@E01hL7@0?3@h020P801@D500>3Ph030`<00/92P0>2@P0
40`=00/9300>31000P0B4aL0300>3a<02`X?00/;3@0D41809AlO014=300<2PP02PT700P71@0?3P`0
20H700l=3P<03@/<00l030X;00X82`0>30l01P@701<A500D4aD01P@7014?4P0C4A@00`4401DC5P11
?d80>SPk028P8`091PP00P0A3@h00`0>2P/04@d>018>3`0200l;30<04@d>0140510A04e;C00P8200
20P800/;2`0>3Ph02PP9010>3`0?3@h04@d>00d92P0A3@h04`d?00`8200920H04Q4?00l>300200T8
1P0300d<2P0<2`T03@`:00803`h<0P0<2`T01@0=30X03`h<00l>300@3`d03`h<00H03Pd;00T010<1
01DD4P0920H06APF004000081`H02PT700l>300@3`d00`0<2`T200`:2`@03@/<01H02`T:00d;300:
20T02`T:00h<3@081PL03@/<014?400C4A804@l@00h<3@0=2``01`D600P61`091`P05aDF00T7200B
41400`44010>4@081PT030X=0P0:20/0800A3a8040hA00h<3`0>30l040hA014?4P0B2a804`dC01LB
5P0B3A405A8C00P61`0@3Q003Ph@00`;400A41L061HQ01TI8@0G8240GFMV06YcLP0O9BD02`l@00`@
4@0=3Q002PP;01<A500:1@T05a4E00P31`0D4QD03`d@0P0<2Pd02@0>30l03`d@00/930081PT01`D8
00T72P0<2Pd03@/>00H52@0200H42@0A014?500610T00`4600X83@0=2a005A<H01<A5P0=2a003`dC
03llA@2`[KH07Q/T00401`0<2A806QLP018?600;21400`0<2A803@1;B4h0?C]000l=4P0?3A8061HK
01LE6P0D4QL05aDJ0040100K6Ah0BDM<02LU:P091``00P0=2a00100<2Pl03`dB00`:3`091``200X8
3@0600/93P0=2a0040hC00/93P0<2Pl03P`A0P0=2a001P0?3A8040hC00d;400<2Pl05A<H00801@T0
3@/@01h02PP=00L52P0:20d02PP=01LE6P0610T03`dB010>4`071@X030X?00X83@0<2Pl040hC00h<
4@0;2@h02PP=01HC700;21403@XC01@A60050PT06AHM01DC600<2Ph020H900d;3P0@3Q403@/>00`:
3@0@3Q4200d;3P0400X82`091`X04@lB00h<3`802@L:01`03P`?014?4P0B3A403`X>00`72`0;1PX0
3@P<00l:3P080`L071LK00<00P0Q720040/?00H11@0=20`02`H:00l:3P0F4AD050lC00l:3P0=20`0
4@`@01<>4P0A31003`X>010;3`0<2Pl02`T>0P0:20d04@0;2@h030X?00d;400@3Q<0518G01DC600@
3Q<03@/@00`72`0?2Ph03PT=00/62P0<1`/03`X>00h93@0=20`030L;00803@P<00<03PT=00/63@0<
1`d00P0>2@l0600>2@d04@`@00P31`0300003`/<00D10P0F4Q<09b<U00d8300S7R802`H:00X52@0=
20`03PT=00d8300C3Q8020@7018=4@0G4QH02PH800l;300=2@X02`L800X61`802PD900T030L;00d8
3P0<1`d02PD;00X5300>2@l03@P>00/6300<1`d00P0=20h0300:1@/08ahT02PS:@060@L01@0601HB
600820X02`/=00P82P0:20/03`d@00`8308030L;0P0<1PX0500=1`/03PP<00l:400>2@l02`H<014<
4P0500H03`X@00d83P0@2a403@P>00`73@0?2Q0030L=01hI7@060@D05Q4E01lJ7P0G4QH03PT=1@0=
20`01`0<1`/040`=00T51P0G4a@00`0000`82@0B3Pl00P0A3@h2010<3@0300l;300>2P/040L<0080
40L<0`0>20X01`0H51D07Q/L00L51P061@<02`X8010>3`0;2@`00`0=2`h00`0<2Pd02`T<00`:3@05
00`:3@0400d;30071@H02`T:00d;30802PP900@04Q0A00l=3P0@3Pl03`d>0P0;2@X04P0D4Q<03`d>
00`:2`0<2P/03P`=010>3`0R82402`T:00l=3P0>30d01`D600d;300;2@`030X=014?4P0920X05A<F
00X82`H03@/>00<03`d@00h<3`0=2`h00P0>30l03P0:20/03@/>018@4`071@P00@0200L5200B3Q40
40X:00l;300>2P/03`/<00d;3P0>30l03@/>100<2a00100=2a003P`A00h<4@0=2a0200`:3`<03@/@
00D03`dB010>4`0@3Q<040dC01<@5`0200/83`0<00h;4P0=2Q4040dD01<@5`0A3QD03P/B014>5@0?
31<03`hD00d<4P0B4AL051<I0P0@3aD0600>3A<051<I018A5`0;2Q0030/A00h=4`0=31404A0E01HE
6P0D4aP03PdB01TH7@0?3Q<04Q4F01<B5`0>3A8030/@00l>4`0B41<0518E01DC5P0A3a803`d@014?
4P803P`?01003`d@010>4@0A3a804@lB014?500H5Q/081hS014?500<2Pl061HK010>4`0B41D03@/@
00l=4P0E4aP040hC1P0A3a@03P0B41D05A<H01@B5`0=2a00518G00P62`0G5Q`04a8G00X93P0?3Q<0
6APL00d;3P0B41<04a0B0P0C3a02018<3P0502TU9P0g<c@08alP014=3P0C3a000P0A3@h02@0E4A80
5Q8C010<3@0P71d01P8301PD5@0G4a@04@d>010<3@0201<?4004010<3@0>2P/03`/<010<3@803`/<
010040X>01@>4P0a:bl05Q0D00`62P0B31002`D9010:3P0>20`040X>00l93@0>1`/04`P>01@93`0E
2Q004`P>0P0B1`d0900C20h050T?01873@0@1@/04@H<00l72P0D3Ph03@L901@<4@0@1Ph05`dF0105
400A1@l04@H>01<73@0D20`050P:01@8300?1P/03P<900l62`0A20d03PD:00T31`0O6Ad04`dA00/5
2@0?2Ph04@/?00`42@0C20h050T?00T0100>0`T060dC014630804`P>00D04@H<01873@0@1@/03P<9
00l42P0201873@0<0146300?10X03`@:01@93`0A1P`05``B01873@0?10X0200201<63@0>0PP04@@;
0P0F2A001P0A10/040<:01032P0B1@`05@P?01T<4`@03`8900@03P<900h32`0:00L030<;0P0800L0
3P0A1a00100500@0100=1`h02@0700L0100B10/04P4900l01P0B0@L05@H901D93@0B1`P030835?oo
ool001_ooooo01<01@/G05QOJP2HWjP0GFA]01lU;@0A5A/030dD00`<4@0A4AD04Q4F00h=400=30l0
30X;00l=3P0;2@X030X;014?400?3@h03@/<00803`d>00@03P`=00/92P0:20T050h@0`0@30d0100=
2``030X;00l=3P092@T2014A4@0A00h>3P0;2@X04@`>014=3`0<2Ph03P`B00h?5@0;2a807QhU051?
EP0d<cP02PH901<>400?2``040d>018@4P0=2``00P0A3a000`0N71d030X;00d;300200d;300K00`:
2`0:20X0518E00/9300]:bh0<S0c00d;3P0B41<040hA01DC5P0K6A`030X=00T72P0@3@l04Ph?010<
3@0>2P/05Q8C01/G600C3a0030P900h:2`0@30d04@d>01@@4@0f=3D061PH00803Ph>00@03`l?00T7
200;2@X03@/<0P0?2``02`0A3@h04@/=00d92@0E51802PT700/:20081`H040l=00d<2P0<2`T03@`:
00803`h<00@030/900/:200;2PP03@`:0P0>3@/00`0=30X03Pd;00h=2`0400h=2`0Z018A3`0:2@L0
3@`:00/:200C4Q0040l>00l>300B4@l03`h<00d<2P0C4Q004Q4?00T7200;2@X03`d>014?400?3@h0
30X;00/92P0>30d030X;00d;300?3@h02@L800l=3P0@3Pl03P`=00`:2`0=2``040h?00X82@0A3a00
2PP902l];P0<2`/03@/<00X82`0@3Q4030X=014?4P0>30l03@/>0P0?3A0200d;3P0T00l=400?3A80
50dE010:4@0B3A<04@`A01`I6`0E4aD03@/>00X93P0<2a402PPD00`:5`0?3aT0318D00H=3@0B61P0
41HF00lB4`061`T03Ph@00T72P0>30l040/?01<>4P0@2`l061HI014?4P0=2`h02`T<00`:3@0=2`h0
2PP;00d;3P0>30l030X=0P0;2@`200l=4P0F00h<4@0Q7b@020H;00X83@0=2a002PT=02DS:00[:Bh0
5A<H00d;4@0>2a80>3Dl010=500B3aH02@H=00P6300;20l03P/B018?5P0:1`h02`P?01@B60802`T>
00l030X?00d;400?3A801`D:018@5@0A3a@03@/@020N8`0T8RL0518G00h<4@0=2a002`T>010>4`0?
3A80100<2Pl01`0=2a003P`A00h<4@0?3A803P`A00/93P0:20d00P0=2a001P0>31405Q@I01HD6@09
1``03`dB00h<4@@03@/@02L03P`A00T7300>31403P`A00`:3`0A3a@03`dB00h<4@0=2a003P`A00T7
300:20d03P`A00d;400?3A804Q0E010>4`0>31403@/@010=5P0>2a@03@XC00h;4P0X9B`020D<018@
5@0=2`l030X=00l=400=2`h01`D800h<3`0<2Pd040hA00T72P0;2@`03P`?00l=400=2`h00P0;2@`0
4`0=2`h03`d@014<400?2Ph03@P<00`72`0>2@d03`X>010;3`0J5QT06A@H00h93@0910P05A0D00l:
3P0<1`/03PT=01@?4`0A31000P0>2@d00`0B3A404`hB014<400200l:3P0300`:3`0;2@h02`T>00<0
2`T>00T030X?00h<4@0;2Ph03`dB010>4`091``03@P<010;3`0?2Ph00P0=20`0100?2Ph03PT=00d8
300<1`/200d8300C00h93@0?2Q403`X@00h93`0=20h02`H:00T4200?2Ph03PX;00l;300<20T020@5
010;3P0=2@`0510C00l:3P0?2`h02@D800h:3@0200d8300900`72`0=20`03`X>00l:3@0>2P/03@T:
00`82@0;1`P02`H:008030L;0P0<1`d01P0;1P`03`XA018=500@2a403@P>00`73@803PT?01P030L=
01<>500?2Q003@P>01D@5P0<20h02PX<00`=3`0?41802`/=00P82P0;2P`02`X=00/9300;20`02`L;
00`72`0=20`03PT?00`73@0V8BL0=c8h018=4`0<1`d200h93`0:00`73@0=20h03`X@00`73@0A3100
2`H:00h93@0A310040`?018=4@<03@P<0`0>2@d01P0<20T02@D601<?400B3Pl0510A00/720803`/<
0`0>2P/0100=2@X04PT<0189300B2@`3010:300800X61`0B3a001P@500T7200:20T030X;00/9300<
2Pd300d;3PL030X=0P0=2``03P0?3@h030X;00/92P0@3Pl03`d>00L51P0<2P/03@/<00/92P0>30d0
71XK01DC500A3a003@/<0P0<2P/0300H5QL020H700h<3@0?3@h020H700`:2`0<2Pd0518E00/9300=
2`h030X=00l=40H03@/>00<03`d@00h<3`0=2`h00P0>30l0400C4A@030X=00T72P0O7B00;B/^01dK
7P0>2P`040X<00l;300>2P/03`/<00d;3P0<2Ph030X?00d<4@0>3A8200`;4@0400d<4@0>31403P`A
00d;40@030X?0`0=2a005`0>31403P/A00h;4P0<2A0061DL00l<4`0=2Q403``C018?5P0@3A@03P/B
010=500?31<03PdC00`;4@0?3Q@04Q4G00l>500@3aD04A0F01HE6`0E51X040lE00804A0F00d05QDJ
010?500S8RL040lD06UXK@0K6Ql040lD018A5P0C4QL03`hC00h=4P0@3a@04Q0C00804a4D00<04@lB
010>4@0?3A000`0A3a83018@4`0;01XH7@0D4QL04Q0E018@5@1VI6T040hC00l=4P0@3Q<03`dB014?
500D4QL0100B41D3014?500@01@B5`0E4aP04a4F01dK800b<3D05aDJ018A5`1FEE/0D4mD00h=4P0D
4aL05aDH018@4`0C4180510A01<?40804`d?01006ADF01lK700D41404Ph?01LC500D414040`=01TE
5P0E4A809b<T03di>P0F4Q<04Ph?01<?400?2``04@d>0P0F4Q<04`0B3Pl03`/<010<3@0D41404Ph?
00l;300C3A4040X>02TS9`0B31002`D9010:3P0C3A4040X>00d72`0?2@d040X>01493P0C2Pl00P0D
2a00;00B2@h040L<01483@0D2a005@`A01<:3`0A20d04PT>014:3@0B30d0208401493P0;0@T05@/D
01463`0@1@h04@H>01@83P0F2Ph05`/>01H:3`0B1P`04@@;0186300B20d03`H;00l7300H4aL030L;
010<40040PD0514D01D>4P0900@04`P>01@93`0A1P`03@<800d2200C20h04@H<00h32@0B1`d03`@:
0P0@1@/30146300501052`0G31807A8H01873@0A1P`00P0@1@/0300>0PP04`H=01032P0B1@`03@47
01042P0B1@`04@@;01032P0A10/04`H=01H940803`<701H03`8900h32@0>0`/030@<01D<5P0:10l0
2P@A00h95@081A00BDA@09J@V@0a:c803@@=01D;4`0>0PX060PB01002P0I2Q806``B0185300>0`L0
40D95?ooool001_ooooo00h07RLf09NP[@3hool0WjFa02L]=P062A005aLO01DE6P0A3a@05Q@G00d8
300A3@h03@/<00l=3P8030X;02L040h?00h<3@0=2``03`d>010>3`0>30d02PP900T7200D3Q004Ph?
014=3P0@30d030X;00/92P0920P05QHF014A4@051@D01PH6014?400A2`l030L=00l=4P0C4AP03`lI
00h>600_;cP0Xj:Z03@c>@0C3Q<05Q0D00X52@091PT030X?00P62@091`X01@<6010>4@0=2`h00`0>
30d03P0=2``03`d?01DC5P01008040hA02TW:P0C4A@03`d@00/930030@@02`T<014?4P071@P02PL9
0P0>2P/0100=2@X0510A01HB4`0A3@h200h:2`0<00d92P0<20T03PX;00`:2`0C4a<030`<00<30`08
20P05aDF010>3`0=2``03@T:0P0?2``02P0>20X0510@00h=2`0C4Q002`X803Xi=`0920H03@`:00`;
2@0=30X200l>300300`;2@0;2PP02`X8008030/900<02`X800X91`0>3@/01@0>3@/0300100007QdK
00h=30040`403`h<01<B40081`D02`X800P71@0=30X05aHD00l>308030X;01d03@/<00h<3@0@3Pl0
40h?00`:2`0?3@h03P`=010>3`0A3a002PP900`:2`0?3@h03P`=00`:2`0;2@X030X;00800@0>30d0
30X;01lM7P0;2@X01`D601PF6@0E4aH03`d@018@4`0;2@`02PP;00/9300400`:3@0A00/9300C31<0
3`X=01<?400D40l07adI01HE400?3P/01PH600h>400E51/0?C]806ATKP0>4Q@01`/<00T=3P0;3Pl0
0P0?4180?@0R8R@05A<F00l=400G5AP01`8601<>4P0B41<03P`?00`:3@0=2`h03P`?00l=400;2@`0
3P`?00d;3P091`X020H900T72P0;2@`00P0302DS9P20OX40;B/^00/9300B41<01P@700L5200@3Q40
3@/>00d;4@0C41L00@05018?5P050PT04@hE010=500;20l05A8I01lL8`0A3QD03P/B01<@5P0:20d0
3@/@018@5@0>31404Q0E00h<4@0100@03P`A00P62`0;2@h09R@Y01DC600>314030X?00X83@0B41D0
518G00l=4P0>31400P0?3A800`0>314030X?00d;400200d;40802PP=00L03@/@0040100J61d0?ce2
01DC600610T02PP=00803P`A0`0<2Pl03P0>31403`dB01DC600?3A802@L<010>4`0=2a001`D:014?
500:20d06ALL01HD6@0<2Pl02PP=0P0<2Pl05P0:20d02@L<00X83@0100L02@H?00@12P0710/0924X
00401@071@X02@L;00`:3@0?3A004a4D01@B5@081PT03`d@02@R9@0E4aH030X=00<1100;2@`400`:
3@0300/9300=20`03PT=00803PT=0P0?2Ph02@0I51P0MW5e00@00`0300806A@H00<00P0@2`l03`X>
00d8300300`72`0300d8300>2@d03PT=008030L;00D03PT=00X83@0;2@h02`T>00`:3`0200/93P06
014?50040PL01P@900L52P0;2@h0518G0P0=20`01`0?2Ph040/?00h93@0<1`/03PT=00d8300<1`/0
0P0=20`0400>2@d03PT@00h93`0>2@l03@P>00/62P0:1@T03`X>00X61`070`@03@T:00h:2`0@2`h0
8ahR0;Ze^@0P6al200/62P07018=4@0F4AD05Q4E00X52@0>2@d040/?010;3P0200`82@0Q00d92P0<
20T02`H:00d8300910P020<900h93`0<1`d03PT@00l:4@0>2@l03@P>00/6300A318040/A00X52`0=
20h04@`B00d83P0;1P`03``A00L82P021PL04QHG01TM7P0:3Pl020T;00/<3P0<30h02`/=00T92`0:
20/02`T<00802`H<00H040/A01TD6P080`T030L=00d83P0<1`d200d83P0300`73@0=20h02PD90080
40/?00<00`0200H11@0:1PT00P0=20`200h93@803`X>00H04Ph?00/7200400403`/<010<3@0>2P/4
00d92P803PX;0`0@1`P0200>20P03PP900h82P0810D030T;00d;3P0B41<020H90`0<2Pd0100:20/0
2`T<00d;3P0?3A0600/930803P`=01P03`d>00/92P091`P03@/<01lM7P0=2``03`d>00/92P0610D0
2`T:00H41@071@H020H700`:2`0?3@h040h?00H41@071@H02PP900h<3@0<2P/02PP900T72P0C4A@2
00T72P0301DC5P0<2Pd030X=00D030X=01003@/>00`:3@0<2Pd030X=00d;3P0;2@`020H900/9300F
51L06ALJ014?4P0=2@`040X<00l:3P0>2@d03`X>0P0=2a001P0>31403@`B00/:400;2Q003PdC010>
50803P`A00X03@/@00`:3`0<2Pl03P`A010>4`0?3A803P`A00d;400<2Pl02PP>0P0I5Qd0400?31<0
40dD00P5300;20l03P/B00d:4@0<2A003``C00h;4P0<2a402@P>00`;4@0?3Q@03@`B00l>500=3183
00l>5009014@5P0=31803PdB01HE6P0K6al07QdR02XY;P0G5Q/04A0E008040lD0`0B4AH200h>4004
010@4P0B4Q@04Q8D018B508051@F00d04a<E018B500A4A<0410B00H52P0J6Ah010<802LV:`0F5AX0
71/P00d<4@0A41D04a8G008040lD00@051<H01@B5`0C4AH04a4F0P0B41D04@0A3a@05Q@I01/I7P04
0PL0:BL/06ARI`0E4aP071/Q02DT:P0A41D071/P01PF6P0<2Pd04Q0C01<@4P0D41405A4B00805Q0B
0P0F4Q<01`0E4A80510A014=3P0@30d04Ph?01@@4@0>2P/00P0H51D05@091@H0510A01LC500B3Pl0
4@d>018>3`0A3@h04Ph?00d92P0>2P/04`l@014=3P0=2@X04`dA00/52@0D3Q8030H:00l93@0=1`/0
4@/?00/52@02014;3`0D00d72`0C2a0050/@01@;400C2Pl04@P=0107300A20d04`X?01@;400B2@h0
40L<01483@0C31005@lC00`62P0F3Q<02`8701@:4P0B210201<8400@01@83`0E20l05@P?01D73P0F
1`h05`P?01<63@0A1P`040L<00/4200E41@04PdA00/9300N7R00BTY<01H@50804@H<00P03@8800/0
1P0F2a403`@:01D:400@1@/0304701@93`804PL=00T04@H<00l42P0>0`T03`@:01873@0@1@/06PlE
0146300>0`T00P0?10X01P0:00@02@0301H9400Y72<08A@K03<V;@804@@;00@040<:00l22@0>0@P0
3P480P0A0PL03`0?0`P03P<900h3300;10`0100700D13@071A<0:BLe01<B8@1iMhD0oo[o04]3CP0:
0Pd08aTT01H:500200h12`8050L@00<03`8;00d12@0B1@`05?ooool001_ooooo01d07BHe05YSL@2k
`m00EeeY01<F800?4Q/03`lG00T83@0?3A003`X>01<>3`0D3Q004@d>014?400<2P/02`T:00h<3@0;
2@X03@/<00l=3P0@3Pl03P`=00X82@081PL04@/=018>3`0@30d03@T:00h<3@02018@4@0I0000000B
4Q801PH602TY:@0K6AX04PdA00l:400<2Pl00`8:00P84P0E5Al06QXT07elQ00J6Al03`X@014;3`0D
3a<03``A014?500?3A8040hB00H41`0<2Pd03@/>00h<3@0200l=3P0@00h<3@0@3Q00108501<A500<
2Pd04Q0C01lM80091`X02PP;01PF6@0>30l02@L:01<A50081@L03`/<010<3@803PX;01@030P900d9
2P0C3a004Ph?00l;300;1`P030P900X82@0E5AD00`<3018B4P071`L04Q0A00l=3P0=2``030P900l;
300>2P/030H800T51@8030/900H0:BPV0=_Jf00d<c403@`:00`;2@0=30X200l>300300`;2@0>3@/0
3Pd;00803Pd;00<03@`:00/:200>3@/01@0>3@/03P0F5A<00@0001<B40030P003`h<00h=2`0;2PP0
3`h<00h=2`0G5Q@08B0N01<B400?3@h03P`=0P0;2@X0700@3Pl0518C00`:2`0@3Pl03`d>014?400B
41402PP900T7200>30d040h?00h<3@0:20T02@L800/92P0?3@h030X;00T7200=2``03`d>018@4`0=
2`h02PP;010>4@0=2`h03P`?00/9300=2`h200l=400K00d;3P0;2@`03`T;01<>3@0N6aH07Q/D01`K
40061P004A4800h?2P0D51801PD9028Q:@1@CeL05aXL00D92P062P/04A8D00l@4P0:2`d05aLI00/9
300610L06QPK00L21P0K5QX03@/>008030X=01h03P`?014?4P0B41<030X=00h<3`0=2`h02`T<00h<
3`0B41<03P`?00P62@010080:BLZ00400P0A3a8020L901<A500@3Q403`d@00L520081PX02@H=01`I
800610X04a0G00l<4`0:1`h01`@;00d:4@0E4QT200X73P0;03Le>`0X9R/00P0500X83@0>314030X?
00X83@081P/03@/@00/93P071@X00P0<2Pl0200?3A802`T>00X83@0C4AH05Q@I00l=4P0;2@h03P`A
0P0A3a@08P0@3Q<02`T>00/93P0<2Pl02PP=00/93P0@3Q<03`dB00@21`0@3Q<00@04018@5@0=2a00
3`dB00h<4@0<2Pl02`T>00`:3`0?3A802PP=010>4`0=2a003`dB01dK800S8BH03P`A01@B5`0=2a00
:RP]01dK80091``03P`A00l=4P0>314200/93P0E00d;400;21403@XC00l<5@091Pd01`@;01<@5`0=
2a003@/?00X82`091`X02`T<00l=400A3a8030X=01XH6`0:20/03P`?010>4@091`X02`T<00803@/>
00@02`T<00T72P0;1PX03@P<100?2Ph020060@D061@G010;3`0910P02`H:014<400>2@d03`X>0P0>
2@d02P0A31004`hB00h93@0>2@d03@P<00/62P0=20`03`X>00X83@0;2@h300`:3`0@00/93P091``0
3@/@00d;400?3A802PP=00@21`0>2@d030L;00h93@0A31003PT=00X52@0>2@d03@P<00`72`803@P<
00<03PT=00`73P0=20h00P0>2@l05P0=20`030L;010;3`0=2@X030P900L310050@804@d?00`72`1H
DeL03PT=018=4@0910P02@D800L21P0300804`hB00h93@0400<030L:00/7200<20T200d92P0800`7
2`0>2@d02PD900T42P0?2Q002PD;00L22@0910X200`73@0300/6300C3Q@04`hD008030L=00X04PdC
010;4@0;1P`040dB00h?4@0420T07B4R02lc=00K7b004A8D0P0<3@l02P0<30h02PX<00X:300<2Pd0
1`88014<4P0<1`d03@P>00/6300>2@l200`73@0:00l:400=20h02`H<00h93`0C3Q803@P<00T42006
0@D071LK00T420803@P<0P0>2@d200l:3P0800/7200@30d02PH701@@4@0<20T020@500`82@0=2@X2
00h:2`803`/<0`0>1@H03`0<1PH030H700`6200C3a0030T;00/9300?3A001P@701<A500=2`h02`T<
00T72P0:20/03@/>010>4@0600/9300800`:2`091`P03@/<00d;300;2@X03@/<01PF5`0610D200T7
200400P61`0>30d03P`=00h<3@803@/<00h030X;00/92P0@3Pl03P`=00P61`0;2@X03`d>00d;3009
1`X030X=01<A500E4aH0:bT/00<110H030X=00<03@/>00`:3@0;2@`00P0<2Pd0300E4aH05Q@G00h<
3`0:20/030X=00h<3`0@30h040X<00l:3P0>2@d03`X>00d;40803`dB00D03@`B00T83P0:2@l040lE
018@5P0200h<4@0@00d;400<2Pl030X?014?500E4aP0518G01<A5P0A3a@040hC01DB600d<CP0:RL^
00H32P0D4AP03``C00`940803``C01h03P/B014>5@0A3QD03PdC00/:400>3A<04A0F00l>500B4AL0
40lE014@5P0@3aD04a8H01HE6`0@3aD03@`A010?501fMGX0T8nD00d<4@0?3Q<04Q4F00l>4`0>3A80
4a8G01DD6@0B4AH04a<E018B500C4aD201DE5`0E01<C5@0F5QP05QHH01@D5P0C4aD04A4C010@4P0D
4aP0?Se202HU:P0^;C805A@I00T83@0<2a004Q4F01DD6@0A41D03`hC01HE6P0E4aP0518G00804a4F
0P0B41D00`0H5Q/03P`A01XH7@0201LE6P0;01PF6`0;2Q006APM00P7300g=S/04@lC01LE600B41<0
4a0B01DA4P0F4Q<00P0H4Q@0200B3Pl0510A01XF5`0G4a@04Ph?01@@4@0E4A80510A0P0F4Q<01@0<
20T0510A01DA4P0I5AH05A4B00804`l@0P0@30d0200;1`P03@T:018>3`0@30d030P900d72`0<1PX0
4`dA0P0D3Q805`0<1PX03PP<014;3`0S7B407aTM00l93@0C2a0050/@01<:3`0B2@h04@P=0107300A
20d04PT>01<:3`0A20d03`H;0107300>1`/03PP<00L11@0D3A402@05008040H>00<04`P@01873@0A
1@`00P0@0`X05P0C10/06@P@01X;4P0E1`h040D;01873@0B31002`H:00@21@0=30h010@603<d=P0;
1PX04`P>01052`0I3Q@06PlE00l42P0D2@l06PlE01@93`0?10X201P=4`0901<83P0A1P`03P<900d2
200?10X04PL=00T0100E2Q0040D;00803`@:00L03P<901H9400=00L050L>01hA600:00@06@dC0080
3`89100B1@`201421`0F00l31`0>0`/03@<<00/4300<1Q804@dJ028P;P24Pi<0BTYK01hM;@19@e40
7ADQ00T1300?1A003@<=00`02P0=0@/03`8<00l22`0>0@X03`8;010331Cooooo000Kooooo`0=00T@
7@0>5R806R4]01TN:P0>4Q/03Q0H00l?5P0?3Q804`hB01H@4`0F3Q0040X:018>3`0200l=3P803P`=
1`0=2``0900?2@/03PX;00l;300?2``030X;00/92P0@3Pl02PX:00h>3P0?3`l0ADE505ECE00A3100
30L=00d;400F51`0L71j07=cO@0@41X04Q4I010?5@0@2a404@/?014<4P0B3QD03P`C018?5P0:1`d0
40dC00`:3`0<2Pd03@/<00h<3@0A3a004Q4?00l=3P804Q0C00H02@P:00d;3P0=2`h02@L:00/9300=
2`h200h<3`0500`:3@0=2P`03PX;00h:2`0?2``00P0>2P/0100?2``04@d>014=3P0B3Pl2014=3P0B
03hl?@0Z:RX02`/;00`<300@41005aDF00/92P0>30d03@T:018>3`0@30d030H8018>3P0>3@/02PT7
01HE4`13@T0061LE1P0<2`T00`0>3@/03@`:00d<2P0200h=2`0700d<2P0?3P`03`h<00d<2P0<2`T0
3@`:00X91`0700d<2P0700L6100=30X030/901dL6P0;2PP02PP900`:2`0200l=3P0401<A4P0I5aP0
2PP900d;30803P`=00@03@/<00`:2`0;2@X03@/<0`0>30d0200=2``03P`=00h<3@0B414040h?00h<
3@0;2@X04@lB0P0@3Q4200`:3@0301LE600C4A@04@lB00803P`?01@03`d@00l>3@0F4@/05a@801PF
1P0`;Q`0J6YC038d700H6PP04aD702X[8@0I6QD020P:00`;3`0<30h02PX<00/<3P0?3a4030`>00T9
2`803@/>0P0<2Pd300/9300<02DS9P0920X030X=00H41`0B41<03P`?00l=400B41<02`T<01PF6@0/
:Rd04@lB0P0=2`h05`0?3A003@/>00X82`0;2@`0518E00`:3@0>30l04Q0C00d;3`0<2Pl03@/@00`:
3`0@3Q<03`dB00/93P0=2a003P`A00l=4P0A3a@040hC00d;400<2Pl03@/@00803P`A0P0<2Pl500/9
3P0600d;400<2Pl02`T>00h<4@0;2@h030X?0P0=2a001P0?3A803P`A00/93P0=2a0030X?00/93P80
2PP=00H030X?010>4`0=2a003@/@00`:3`0;2@h200`:3`0B00h<4@0E4aP04Q0E00l=4P0F51T03@/@
010>4`091``030X?00l=4P0<2Pl061HK06ARI`0V92T03@/@00T7300G5AX0<c4f100>31403`0=2a00
30X?00/94@0;21404PlH00l<4`0;20l05A8I00h<4@0=2`l030X=00T72P0H5QT05Q@G00X82`0200`:
3@0?00d;3P0?3A003P`?00P62@0?3A002`T<00T72P0=2`h02`T<00l:3P0@2`l030L;018=4@0@2`l0
2PD9008040/?00<07APL01`G6`0?2Ph00P0B3A404P0:1PT04@`@00h:3@0;1PX03@P<014<400=20`0
3`X>01@?4`0<1`/04PdA00T7300<2Pl02`T>00d;400;2@h030X?00h<4@<030X?00`02`T>00T7300=
20`03PT=018=4@0?2Ph03PT=01<>4P0<1`/040/?00/62P0?2Ph200h93@0P00h9400=20h03@P>00h9
3`0@2`l050lC010;3`0g<c@05A4B00@00@0C3a002@D701dH70060@D03@P<01<>4P0]:2`04PdA00D1
100C3Q806aHJ00h:3@0@2`l030P:00l;300F4Q<030P9010<3@0F4AD02`H:00`72`0;1P`200h93`0W
00`73P0>2A003PT?014<4P0>2@l03@P>014<4P0;1P`04`hD00T42P0C3Q@04@`B00`93P0?41805QXK
05eQHP3Ri^H0^ko003/l?P0B4aD0414C00d=3`0:2P`02`X<00d;3P0>2@l040/A024L8P0910X05Q4G
00T52P0;1P`03@P>00h93`0<1`d02`H<00d83P0=20`02`H:00803@P<00P02PD900h93@0;1PX030L;
00d8300?2Ph02`H:00h93@H03PX;00L03`/<00h:2`0?2``030P901<?400X92@03`L6008040P60100
3PP800l92P0?2@/02PL700l<3P0;2P`04Q0E00h<4@0920`03`d@00h<3`0<2Pd03@/>00l=400@3Q40
4@lB0P0;2@`01@081PT03P`?00P62@0=2``03`d>00803P`=00T030X;01XH6@0X9RL02PT900P61`0<
2P/02PP9010>3`0?3@h00P0<2P/0100=2``030X;00X82@0<2P/200d;30803P`=01<03`d>018@4`09
1`X040hA00T72P0G5AP02@L:00d;3P0E4aH07Q`O00l=400C4A@02`T<00l=40081PT04Q0C02`Z;@1:
B4/03`d@008040hA01@03@/>00X82`0;2@`040`?01@>4P0A31003@P=018=4`0A3a@03`dC00D32@0<
2a409bH]01PG7`0=31@03`hD00h<4@0<2Pl03P`A00l=4P803@/@0P0;2@h02@0C4AH03@/@00/93P0C
4AL0AT=:03@a>00<2Q005A8I00d:4@0200l<4`0700h;4P0?31<03``C014>5@0Z:Bl0AdI<01<B6002
00d<4P0=010?5@0A41H03@`B00h=4`0?3Q@02`X@00h=4`0E51T02`X?01/J7`0T8bP04A0E00h=4P04
018A5P07014@5@0@3a@04A4C01@D5P0?3a405aLI01@D5P0200l?4@0>014A4`0;2`d05QHH014A4`0@
41805A@I02<R9`0D4aP04A0E01lN8`0F5AX04A0E01DD6@0G5Q/201<B5`0800h=4P0E4aP061HK00P6
2`0D4QL040hC01LE6P0d<SL201DC600301LE6P0@3Q<06ALL00804a8H00/061LL01dL8@0J61`04@lB
01HD5`0C41805a<D01@@4@0I4aD04Pd>01@@4@0301DA4P0601@@4@0C3a005A4B01LC500B3Pl040`=
0P0C3a001P0B3Pl05a<D00X61`0B3Pl05Q8C00l;30804`l@0P0B3Pl2014=3P0600l93@0@2Ph04@/?
014;3`0?2@d03PP<0P0A2`l02P0C3A405@lC00l93@0B31003`T=01@>4P0?2@d03PP<01D?4`0@2Ph2
00l93@0:010:3P0K5AT040X>01<<4P0>1`h02`@:01<;400I41D050/@014730804`P>01@050P>01@7
3P0D1a0050D=01X:4@0P4AP06PdD0146300B20d050dA00H11@0C3a<0?3/n0:f][`1VIfT05A0D01D:
400@1P/0714G00/21PL04PL=1P0A1P`201873@040146300?10X03`@:00l42P804PD<00@03`8900h1
200>0@P030460P0?0PT20185300J01442`0?0PT04@8701421`0?0`P03P<:00h3300;10`02@<=00T5
4P1>C5X0a<;>06=SL`020@l03`TF00d54@0E3aP06A4L00/4300=1Pd050/D00d42`0>0`/03@8901<6
3`0B1@dDooooo`006oooool03P031a802Q0J00`@6@0<41T03a4H00h?500?3Q@03`hB00d;3P0=2@X0
3PT9014;2`0B3Pl040h?0`0?3@h00`0>30d030X;00`:2`0400`:2`0400l92`0?2``03`/<00l;3080
30X;00<02PP901<C4`0C4a<00P0@41005P0?3@h03@P901LB5P091``01`H<030`>00N7RH03PhF010?
5`0>3A<03`X?00l93@0?2Ph020@>00402@091Pl02PL?00h;4P0=2a003`d@00l=3P0@3Pl2014@3P07
01@B4`0h=ST0@T1301TG6P0B41<07A/N01@B5@0300`:3@0:00d;3P0>30l040d?010<3@0?2``03PX;
00l;300@30d04@d>010<3@<04@d>018040`=02DS900J6QX04A4A00P8200000004a4B01LE5P0E4a@0
3`/<018>3`091@H0100000`8200?3P`06QTG01LF50071P@=00d<2P06018A3`0<2`T030/900`;2@0;
2PP06QTG0`0A40h200l>300D00h=2`0@3`d01@@200h=2`0?3P`03Pd;00/:20081PL03@/<01DC500D
4Q<030X;00H41@091`P020H700X82@0>30d03`d>00/92P0>30d300l=3P0@00h<3@0=2``00@0000l=
3P091`P05A<D00h<3@0:20T03P`?00l=400A3a803`d@00h<3`0F51L04a4D014?4P803P`?01P03`d@
00l>30050@005aD2038b6P2MWH<0mOOI0<O:Z`1:CC4051L201<F1@0<3PD0410>01HF5P0<30h030X=
00d;3P0?3A003@/>00/9300:20/02`T<00`:3@0=2`h200h<3`0L010>4@050`H04Q0C018@4`0C4A@0
1085018@4`0@3Q404@lB00/9300F51L09R@W00h<3@0<2P/03@/<00l=3P0>30d030X;00/92P0C4A80
2PP900h<3@0100001P@6010>4@0F51L03@/>00T72P803@/>00H02@L:00d;3P0B41<01`D800D31P0=
2`l200X83@0401<A5P0F51T03`dB00X83@8030X?0`0;2@h0:P0<2Pl02`T>00`:3`0@3Q<030X?00/9
3P0<2Pl02`T>00X83@0<2Pl03@/@00X83@0<2Pl02`T>00X83@0;2@h030X?00l=4P2ASi@0CD]@00/9
3P081P/01@<800`:3`0;2@h04@lD018@5@0D4QL06QPM01<A5P0U8bP04a4F00P62`0>31403`dB018@
5@0I5a`00`4601@B5`0=2a001P@900l=4P8030X?0P0=2a00300<2Pl02`T>00/84@0A3QL00P080040
1@050`T030T@00h<4@0<2Ph03@/>00X82`806QPK0P0@3Q405`0=2`h02PP;00/9300A3a802`T<00X8
2`071@P02@L:00l=400<2Pd05a8F00l:3P0300803@P<01HA5@0E41@02PD900`72`0G4QH05A0D00X5
2@0;1PX04PdA008030L;01003PT=059=D@070PH03@P<00/62P0D3a<07aXN00h93@0<1`/02@L<00h<
4@0@3Q<01@<8010>4`091``030X?0`0=2a001`0<2Pl02`T>00/62P0>2@d04PdA00l:3P0;1PX00P0>
2@d01`0E41@01P4500`72`0B3A402PD900d83`0>2@l00P0?2Q003P0>2@d05a8F00X52@0?2``00`00
00`82@0@30d06A@G02TT:00=20`030L;00H11@0J5AT03`X>0P0@2`l02@0C3Q802PD900/62P0D3a80
2PH700l;300<20T02@D600h93@0200`72`0S00/6300<1`d03PT?00d83`0910/0100500L2200<1`d0
3@P>00`73@0:1@/04PdC00X52`0?2Q003PT?00h;400<30h04a@F09fNX03`lO<0hnCV02`/;P0@4180
3`d@00`:3@0:20/030L;00d8300=20h020<9014<4P0910X06A@J00P32@0<1`d00P0=20h03`0:1@/0
2@@:00/6300D3a<03@P<00`72`0A31003`X>00/62P060@D020<702HQ9@0C3Q802`H:00`72`0600h:
2`0I00l;300=2@X03@T:00d92P0B3Pl071PG018:200B2PL040P500h91P0=1`H030H801hJ6`060`L0
0@0401DB6@081P`06QPM00T72P0;2@`03@/>00l=400D4QD05Q@G00@21@0200L5200400H41`0:20/0
3@/>00d;30801`D60P0?3@h0200J61T0<c4b00D310091`P03`d>00L51P0@3Pl030X;0P0:20T0100<
2P/02PP900T7200>30d300d;308030X;01801@<600`:3@030@@05A<F00800`0;2@`030X=01DC5P0M
6ah04Q0C00l=40091`X020H9018@4`0G5AP0SH^>0<K4a`0U8bH200h<3`0@00`:3@0;2@`03@/>00l;
400A2Q4040/A00d83P0@2a403``C00/83`0M6R406QTQ0860R01OGVH0000900X83`803`dB00l03P`A
00`:3`0<2Pl03`dB00/93P0?3A801P@901XH7@0g=CX0:2D[010=50050PT0514H00h;4P071@/00P0@
3A@05P0?31<040dD010=500B3aH0=SDk06UXKP0=31802`X@00H52`0?3Q@03@`B00/:400>3A<04A0F
00l>500A41H04a8G00P7300F5AX09B@Y01LF6`0<2a02010?50<04Q4F02d04A0E00h?4@0A4Q@03a0B
02//;P0a<S@051DG00d>400D5AL05AHH01@E5`0?41803PlA00L830061`/07AhR01XK7`14ADT06AXN
00@52@0C51P02P/?014B5P0?41@06QTN00d;400;2@h0928W01TG700H5Q/04Q0E01HD6@0?3A804Q0E
01@B5`0E4aP061HK018A5`0E51T051<H014@5@0C4QH06ALJ01<A500F4aD00P0@30d00`0H4Q@01P02
014=3P03018>3`04014=3P0@30d04Ph?01HB4`804Ph?00L04`l@014=3P0?2``04`l@00h:2`0C3a00
5A4B00804Ph?0P0A3@h2010<3@0300l;300?2@d040X>008040X>0P0?2@d0600A2`l03`T=01D?4`0A
2`l03@L;00/52@0L5QX0100201<=4@0O6Ad01002018<400:10P05a4E00L21@0500<01P0401/D6P0F
3aH04@XA00l7300?1PT03PD8010620804PL;01L04`L=01<63`0C1Q004PD=01<63@0D1`h04PD<00l4
2P0>1@X04PX?00H11@080`L0C4Y=0>7OhP29QhX02@@700h32@0?1@X04@H<00L00P0B1`d040D;0146
300201873@0301052`0>0`T040D;00L040D;0P0?10X200h32@0800l22@0>0@P03P4800h1200?0PT0
40<:00l22@0@0`X201442`8040<:0P0?0`L05P0?0PT03P<900h3300;10`01P0900d74`0>2QP0:RHd
00d<60081180100700l73`0=1Ph00`05010;4P0;1P`0<2/a00d4300<0@L0200200`01@0H2@hDoooo
o`006oooool0300:3A@051LN00hA600<3a@04A8F00X;3`0@3a@04a8E014?4P0=2``03PX:018>3@80
40h?100?3@h600`:2`0400l92`0?2``040`=010<3@8030X;01T03`d>01@D500:2PX03@d=00X:2P0A
3a0050lA00h:2`0>30l020L<01/L8@051P/030`C00h=4`0=31403PT<00l92`0?2Ph08A`W014>6@0<
2A@02`PB01DB6@081@`03`dA00803`d>0P0?3P`01@0;2@X05aDH01TG6P0510H020H900802`T<00X0
4Q0C010>4@0?3A003`d@010>4@0B3a404@d>00l;300>2P/03`/<0P0A3@h05`0@30d04@d>014=3P0A
3@h040`=00X82@010@403`l?010@400410@03P`=00`:2`0C4A804`l@00d92P0@30d04@/=014=3@0>
3@/07ahL03<b<00B4@l040l=00H02`X800<030/900d<2P0>3@/00P0<2`T01`0>3@/03`h<00P71@0>
3@/04Q4?010?3@0V9B<00P0B4@l0300A40h03`h<00h=2`0>3@/02`X800X91`0?3P`03@`:00`;2@0>
3@/02`T:00`:2`803P`=0P0=2``01P0@3Pl02`T:00`:2`0B41404a4B00`:2`803P`=00X03`d>00h<
3@0>30d030X;01<A4P0Q7b000`42014?400>30d03`d>0P0<2Pd05P0@3Q403`d@00`:3@0C4A@03@/>
00`:3@0:20/02`T<00d;3P0?3P`061@9030^6`1IFD40aLFY0?cnh03>d[40?d8U018F000A50<03@h6
00h>3P0?3a4200d;3P803P`?00D03@/>00`:3@0;2@`02`T<00`:3@0300d;3P0<00T72P040PD0518E
00X82`0=2`h02PP;01<A500A3a8040hA00P62@091`X04Q0C0P0<2P/05P0=2``03P`=00h<3@0>30d0
6QPI0040000>30d04a4B01DC500B41804Q0C01HD5`0>30l02PP;00d;3P0@3Q4020H900L5200<2Pd0
108500h<3`0G5AT200`:3`04010>4`0B41D03@/@00/93P<030X?0`0;2@h01@0:20d030X?010>4`0<
2Pl02PP=00803P`A00D030X?010>4`0B41D03@/@00`:3`0300/93P0M00`:3`0>3140O7Yo03dk@007
1@X05A<H018@5@0:20d040hC018@5@0?3A803@/@014?500=2a00;bdb01hL8@0?3A8040hC00h<4@0<
2Pl02@L<00P62`0Y9b`09bDZ01HD6@0=2a002`T>00`:3`0=2a000P0<2Pl0800;2@h01`@=028O:00_
;3D09B8Y014>5@0200H05A<H00l=4@0>30l01P@700X82`0610L040hA00`:3@0;2@`02PP;00T72P0<
2Pd03P`?00/9300:20/03@/>00l=400:20/02PD9018=4@0<1`/050lC018=4@0910P04PdA0P0>2@d0
:@0<1`/02`H:01<>4P0A31003`/>01@?4`0M6A`0]K2d02hY;@0=20`02PD9014<400K5QX030L;00d8
300=2a004@lD00T7300G5AX0<S0e00L52P0=2a003`dB00h<4@0=2a002`T>00`:3`0<1`/03@P<010;
3`0=20`02`H:00l:3P0D3a<00`0201LB5P0R7B404`hB00<00P0=20l03`X@008040/A01/03PT=00/6
2P03008040`=01@@4@0L61T02`L801PD5P0U82@03PT=00d8300300803`X>01@?4`0E41@00`0200T4
200?2Ph00`0200T61`060P<02PH700d92P091@H03PT=00l:3P0=20`00P0;1P`02P0=20h03PT@00h9
3`0>2@l04@`B00l:400<1`d03`X@010;4@0?2Q0200/6300;00T42P0>2Q0061PJ02<T9P2JVid0V9RJ
07AdMP0L6ah03`d@00h<3`0<2@`00P0;1PX03`0<1`/03@P>00L2200<1`d020<901D@5P0910X02`H<
00`73@0>2@l03@P>00h93`0A31806QDI018=4@0200h93@8030L;00H02`H:00P31`0]:2`05Q4E00l:
3P0;1PX600h:2`0C00L3100=2@X04`l@01<?400810D00`0001491`0A2@H040P500h91P0=20H03@L7
00/62P0B3a<04Q0E00401@0D4AP01@8900`:3`0200d;3P0300h<3`0@3Q4040hA008040hA01P03@/>
00l=40091`X03@/>018@4@081PL01`D600`:2`050`@030X;00@20`0E4a@04Q0A00`:2`091`P020H7
00`:2`0:20T02`T:00d;300;2@X02PP900l=3P0>30d200d;300800`:2`0;2@X04@lB00/9300200<0
5aDH00<1100<2Pd200X82`0:00d;3P091`X030X=00l=400H5QT02@L:00X82`0Q7b80:BLZ00H51`<0
3@/>00D030X=00h<3`0?2a0040T@00l:400200h93`803P/B01P01@8900`;4`0Z:C408b8Z018@6`0<
2Q403`dB014?500>31402PP=00`:3`0?3A801`D:01PF6`0?3A8020H;01HD6@0;20h04PlF01LD6`0A
3QD04a0G01DB6@0>2a8300d:4@0D00h;4P0@3A@06aXP00P73@0A41H04a8H00l>500E51X03`hD00d<
4P0@3aD04A0F00d<4P0<2a4040lD00/:3`0J6Ah09RDZ01XI7P0>3A8200l>4`09014@5@0B4AH04Q4F
018A5P0=3Q0051DG00l@4P0V9bT0;Rla008051DG00X030d?01`M7`0>3a40414C01@E5`0C51P05QLK
04]<D00S92P0QXN;0P0E5QX07@0?41@04Q<G02@U:@0H6Ad0Bda@02PV:`0>31405A<H01LE6P0A3a@0
3`dB018@5@0F51T04a4F018@5@0G5AX05Q@I00d<4P0C4QP05QDJ01DD6@0B4AD04Q0C01/I700?30h0
5a<D01`H6@0N61X050h@00804@d>0P0B3Pl0100A3@h040`=018>3`0F4Q<201@@4@0401DA4P0A3@h0
4Ph?00l;30803@T:00<04@d>01HB4`0A3@h00`0@30d200l;30D040X>02803`T=01D?4`0>20`05Q0D
01LA5@0C3A403PP<01<=4@0G4AD04@/?00l93@0C3A404@/?01<=4@0400805@lC020J7P0A2`l03@H>
018;4`0A2Q4040P=00l62@0A20T04PP90147200A1PX04PH<01853P0B1@l05@PA01@93`0C1Pd04@H<
0P0A20d02`0D31404P`@01D@500J5AT0BdU<02lZ;P0>1``04@H<01873@0L4AL07A8H008040D;00D0
4@H<01873@0B1`d040D;00d2200600l42P0300h32@0?10X03`@:00803`@:00L03P<900d01`0;00D0
3@4700h1200=00L04PD<00H040<:0P0?0`L00`0?0PT03P<900h32P0200d3300A00d5400400L0208<
00L130090`d08QPQ00H01P0=1Ph05a8I00/7300910X02PD;01D@500D2`h05P/A00/00P0:00005?oo
ool001_ooooo00`02`/;01@D500@41003@h?00l?3`092@X03@d>018B4P0C4a<0410@00d<300<2P/2
00h<3@@03`d>1P0=2``0100@2P`040`=010<3@0@30d200d;300:00P61`0E5AD0410@00h>3P0<30`0
40h>014<2`0I5QD0=C<e010>4@<02``@01X03@d@00d=3P0>2P/03`X8010<3@1IE600E51N00H33`0A
3QT03P/C00d:4@0>31003@/=00d;300=30X030/900h<300:20/020H900h<3`0=2`h02`T<014?4P0D
4QD04@lB00h<3`8030X=00D03``>014=3P0?2``03PX;00l;3002014=3P0700l;300@30d04@d>010<
3@0?2``03@/<00/;2`0300d=3@0=00h<3@0@3Pl0;bd^02l[;00@30d04`l@01@>400C3`l040l=00T8
1P0D4a401@@300h=2`0600`;2@0;00/:200>3@/040l=00`;2@0;2PP03Pd;010?3@0;2PP03`h<00h=
2`061@<00`0@3`d00`0?3P`03Pd;00d<2P0200`;2@0501`K6@0B4@l02@P600`;2@0=30X00P0=2``0
1`0<2P/03P`=00h<3@0=2``05A<D00l=3P0=2``00P0@3Pl00`0:20T02`T:00`:2`0300d;300900`:
2`0P7Ql0:2HW00X82@0B41403@/<00`:2`0=2`h02`T<00803@/>01D02`T<00l=400=2`h03@/>00h<
3`0@3Q40518E01LF500R7AH081d?03Lf8@1BDST0YZR905eQ@@0Q90X041<001<E2@0>3``03PdD00/9
400>2Pl00P0A31001@0@2`l03@/>00d;3P0>30l03@/>008030X=0P0;2@`03@0@3Q403P`?00`:3@0=
30h01`D800d;3P091`X03@/>010>4@0>30l030X=00d;3P0;2@X00`0=2``03P0>30d03`d>05]IFP0?
3@h06QPI00D4100L6Q/04@lA010>4@0?3A003P`?014?4P0?3A003@/>0P0:20/02P0?3A002@L:014?
4P0H5QX040hC00l=4P0;2@h02@L<00X83@0=2a0200h<4@0300d;400<2Pl02`T>00803@/@00D03P`A
01<A5P0>31403@/@010>4`0200h<4@03010>4`0A3a@03P`A00D030X?01/03@/@00h<4@0@3Q<03P`A
00`:3`0=2a0030X?01@B5`0B41D02`T>00T7300<2Pl03P`A010>4`0>314030X?00d;400<2Pl03@/@
014?500<2Pl02`T>00X83@091``03@/@00/93P0<2Pl00`0>31407`0=2a003@XC018?600S82T07Q/R
00`9400C41L03P`A00/93@0C4A@03P`?00l=400;2@`03`d@00L5200<2Pd040hA00`:3@0>30l03@/>
00X82`0=2`h03P`?00/930071@P03@P<010;3`0400<04`lB01`H6`0B3A400P0>2@d02`0=20`02`H:
00X52@0>2@d02PD9018>4@0;1`X04PhA018=4@0D3a<040/?00802`H:00@03PT=00T4200B3A402@L<
0P0@3Q<05`0F51T0;B/`01DC600;2@h030X?00X83@081P/02`T>00l=4P0>2@d03@P<00l:3P0<1`/0
2`H:010;3`0>2@d02@D800d9300W8RH0:2<W01@?4`0>2A003`X@008040/A01D03@P<010;3`0<1`/0
40`=00l;300F4Q<02PH7014<3`0<1`/01P4500h93@0<1`/040/?024L800[9RX02PD900/72P0F4AD0
20@701<?4@0;1`P00P0=2@X0200;1`P03`X>00h93@0>2@d030L=00d83P0?2Q003PT@0P0>2@l04@0A
318040`A00d93P0@2a404`hD00/6300B3A<030L=00L2200=2@l03`hA00P72P0N7Al040hA01HD5`0C
3a<03`X>00803PT=00L03PP<00d72`0=1`/030L=00h93`0@2a402@@:00<030L=0P0=20h200`73@04
014<4P0D3a<040/?00d830802@@800L05Q4E01TD60080`L04`hB00@00`0<1`/03`X>00H03PX;01D0
3@T:00/7200810D02`L8014=3P0A3@`03`L400l80`0@20D03PT6010:2@0@2PX040/?014=4P29Qh`0
<2hd010>5@0:1`h030X?00`:3@0=2`h00P0<2Pd0100;2@`01@@601`K7@091`X200`:3@0E010>4@0=
2``02@L800`:2`0D4Q<02PP900h<3@0E4a@03@/<00`:2`0=2``02PP900/92P0=2``02`T:00`:2`0?
3@h03P`=00d;300?3@h03P`=00803@/<0P0<2P/02`15@dH04a4D00P62@0920X04a4D010>4@0?3A00
3@/>00h<3`0=2`h01P@700<03P`?00D040hA00X82`0<2Pd040hA00`:3@0200d;3P0P00`:3@0?3A00
3`/@00l83`0A31804@`C00h9400>2a804a0H01XG800=31@03`hG014?6P0>3AL05aDM010>4`0A3a@0
3`dB00`:3`0=2a00928W01<A5P081`/04@lD010>4`0E4aP03@X@00d:4@0A3QD02PL>00h;4P0A3QD2
00l<4`0<00h;4P0?31<03``C014>5@0:2@l04Q4G00X93`0L6b403PdC00l>500@3aD03@`B0P0?3Q@0
200<2a403PdC010?500>3A8040lD00l>4`0=31404a8G0P0@3a@4018A5P03010A4`0H6A/0414C00<0
4Q<E02/03a0B03/l?P0S92H06Q/M01DF600?41804A8F01@E6@0@4AD03a0D01PI7@0?41@03@hB014B
5P0=3Q806Q/O01DF6P0e=SX05aDJ01DC600U8bP0DDmD02h/<@0G5AX0518G01LE6P0A3a@040hC01HD
6@0H5Q/051<I014@5P0@3a@04Q4F01<A5@0A3a806ALJ018?4@0N6Q/04`l@01D?4@0I4aD04`l@00<0
510A0P0C3a003@0@30d04Ph?014=3P0D41405A4B010<3@0C3a005A4B01lK700D41402PH7010<3@0B
3Pl00P0A3@h2010<3@0300l;300A2`l040X>008040X>0P0A2`l05`0E3a<02P@8014;3`0K5AT06A<G
00h830060@D05Q4E01HB5@0:1@T05A0D00h:3@1=B4`040/?01LB5P0B3A402PD900l9400@2A404``C
01@<4@0A20/04@P900804PP901P04PL;01<73@0C1Pl04`DA01D94P0B2`l04@L<01483@0B2@h04@X>
010:3P0>20`03`T=00d72`0C3A4040P=00h52P0A1P`04@L<00/21P0J3aD040H;0146300@1@/30146
30L040D;00<03P<900l42P0A1P`00P0A1P`00`0@1@/04PD<00l22@020185300300h2200G2Q404@@;
00@040<:00<04@@;00l22@0?0PT00P0?0PT00`0?0`T03P<:00`2200200l4300?00`12@0G2a<03`@<
00d52`0?20h04@/@028M8P1SHF@020L907UgN@2KV9P04@P900d41P0A10H04@8501Cooooo000Koooo
o`0=00l;200>2`P040l;00l>300@3``05QDC00`<2P0<30/03@d=00d?3P0<3Pd02PX:00/92P0200`:
2`0300d;300>30d03P`=00H03P`=00L04@/=010<3@0A3@h04@d>00h<3@0=2``05Q@E00802`/;0240
0@4100d=3@071P@02@D201TE4P0a<2h02`X;00T:300H6A/02``>00h>400=3@d03`/9010;200A3@h0
4PdJ00d95`0?2aT01P<>00l<5@060`X030X>00d;3P0=2``03@`:00d<200>30`04@lB01<A500?3A00
30X=00h<3`0@3Q400P0?3A001@0>30l030X=00/9300=2P`03`/<00<03PX;100?2``05@0@30d03`/<
00l;300>30d04Q8B00`<300C4a<071`L00h<3@030P805Q@E01PD5@0@30d04Ph?01<=3`0>2PX01@@2
014@3P0B4@l03@`:00l>300600d<2P0<00X91`0>3@/040l=00/:200:2@L03Pd;00/:200<2`T03`h<
00h=2`0=30X030/90`0>3@/300d<2P0>01@C4@0P7ad04a8@010?3@0;2PP04A0>00l=3P0>30d03`d>
014?400>30d01`D600l=3P0=2``200X82@802`T:00@02@L800/92P0=2``03P`=0P0?3@h00`040P<0
2@L800`:2`0200l=3P0300h<3@0D4QD03@/>00803@/>00<02`T<00l=400<2Pd00P0<2Pd0400=2`h0
40hA01<A4P0C3PX05Q<9030_7@1jNF@0DU@j03`o900D5@804A<601PI4`0E5AP04a4N00X74P0>2@h2
014<40803PT=00<040/?00`:3@0<2Pd00P0<2Pd200/;3@0700X82`091`X020H900d;3P0J61/04@lB
010>4@0300l=400C00/930071@P02`T:00h<3@0=2``02`T:00`:2`0>30d05aDF00<10P0B41401P@5
00X82@081PP030X=00X82`0<2Pd04a4D00l=400200L5200600X82`0<2Pd02PP;00L5200:20`03@/@
0P0<2Pl200d;400700h<4@0?3A803P`A00d;400<2Pl02`T>00`:3`0200T7300500`:3`091``02@L<
00/93P0<2Pl00P0=2a001@0;2@h030X?00`:3`0<2Pl03@/@00<030X?00X01@<800/93P0?3A805A<H
01TG70091``040hC00h<4@0=2a003P`A0P0?3A80100>314040hC00l=4P0=2a0200`:3`04010>4`0B
41D02@L<00h<4@8040hC00<030X?00d;400?3A800`0?3A805@0T8BX05Q<L00l<5@0;20l01`@;00h;
4P0@3Q<020H:010>4@091`X02PP;00/9300B41<02`T<00`:3@081PT01P@701LE600=2`h02@L:00`:
3@0200/9300801@B5@0500@02`H:01dH701;ATX0@Se100D0100?2Ph201@?4`03018=4@0?2Ph030L;
00804@`@02<02`H:00T4200@2`l03`X>010;3`0<1`/03`X>01D@500;1PX04@`@00/93P0>314040hC
00@31`0100@01`D:00d;400>31403@/@00l=4P0J61d08AlT00d8300@2`l050lC00l:3P0:1@T03@P<
00`72`0I51P00`0200P41`0G4QH03`X>010;4P0200h93`0?00d83P0=20`03PT=00<00P0E4A80=S8c
03hj>`0G4a@020@600`72`0@2`l03PT=014<400:1@T01@4400803PT=01804PdA01<>4P0=20`04`hA
00X61`0<20T020@5014=3P0F4AD030L;00d8300=20h03`X@010;4@0>2A003`XA018=4`0H4aT202hY
;`0701PC6@0>2Pl03PT?024L8P0F4AL03PT?018=4`02014<400401LB5P0>2@d05a8F00X420803`T=
0P0A20d20107300=00`5300?2Q0040/A00h93`0910X03PT?00d83P0>2@l030L=00X52`0;1P`03`X@
00l:3P0200/62P803@P<00L05A0D00/62P0:1@T04PdA01LB5P0?2Ph01`8600H03PX;00<01P8300h:
2`0=2@X00P0<20T03`050@0040P501090`0@20D03PT600h91`0>20P02`H:00X72`0d<SL00@0500`:
4P091Pd02PP=00`:3@0300d;3P0800/9300G5AP0Kfe`020N8@0100803`d@00@21@0A3a0200d;300<
010>3`0610D030X;00d;300@3Pl05A<D00X82@050`@04Q0A00`:2`0:20T02`T:0P0>30d200`:2`<0
3@/<0P0>30d01`0?3A0020H900d;3P0<2Pd0518E00T72P0<2Pd00P0;2@`07@0?3A000`4400l=400=
2`h05A<F00L6200D4QD07A/N00/9300=2`h03P`?00d;3P0<2Pd03P`?00l;400?20l04PdC01D@5P0>
2A003P/D00l<5@0P7BH05Q@O00H53`0200/0?Sa705]IH00@3Q<03P`A00803`dB00d03P`A01<A5P0B
41D03`dB00T730030@H03@/@01LE6`0:1`h01`@;01DB6@0H5A`05Q<J008040dD01H03``C010=500@
3A@04PlF00X93`0>3A<040lE05ACF@040`T06aXP01HE6`0B4AL040lE00l>500>3A<04Q4G00`;400?
3Q<051<H01DD6@0D4aP030/@0P0A41D2018A5P0Q014@5@0@3a@03a0B00dA4P0>4Q<06QhO01@H6@0I
7Ah0310A05aPH@0h?3d05a/L00`@4@0C5aP041@G00hB5@062Pd05ATL01TM800420/02`lB01PL7`0@
51L03a<F01DI700@4AD06QTN01<A5P0=2a008AlT01LE6P0:20d05Q@I00<04Q0E01004a4F01DC600D
4aT051<H014@5@0?3Q<04@lC01DC5P0:20/06aPJ00`82@0h=3D0DD]=020J700C3a00510A0P0E4A82
01<?400=01DA4P0D41404Ph?01TE5P0L61T05a<D014=3P0D4140:2@U01HB4`070`@04@d>01<?4002
018>3`804@d>00<040`=018<400@2Ph00P0@2Ph01@0A2`l04P`@018<400A2`l030H:00804`dA00d0
5A0D00<00P19A4P0GUUM014<400Z9BT030L;01XE6@0400<0K6M[09:=T@0U82@040XA00804@XB01d0
4PX?0189300@1`P04@P601882@0B1`/04`L=01<63`0C1A804@P@00l:3P0@2Ph03`T=00d72`0>20`0
4PX?01XA5P0C2Pl030<80107300F2a40714G00/01P0>1@T0?c@j06YOI@0E31004PL=014630020105
2`0301873@0E2Q0040D;00D040D;00`03P<900l42P0C20h050T?01<83P0A1P`03@0700X0100A10/0
4`H=01032P0O4QT201442`<03`8900@04@@;00h32`0>0`/03P<90`0?0PT04P0<00H0408701<42@0>
00@050D:01862P07008030D9020L7@0?2``0;2/[00d=2`13@d40KV]Z01/C4@09000040D501<51ACo
oooo000Kooooo`0>014=2P081P<02`X800/:200:2@L061LE010@3P0;2`/02PX:00`>3@0?4A003@d=
00X82@0;2@X200`:2`803@/<1P0?3@h2010<3@0O00l=3P0@3@h03P`=00d;300>30d01P@501@D500?
3@h06ALH00D3100>2PT03PX701`K6@0=30d02PX<00/<3P0=3@l03Ph>00l=3P0>30T040`9018>3`09
1`l06aPS01<@6@0A3QL00@0501DB6@0=2`l03@/<00h<3@0200l>300C00d;2`0B41<04@lB00T72P0B
41<04@lB00X82`0>30l03`d@014?4P0@3Q403`d@00h;3@0=2@X03PX;00l;300>2P/03@T:00h:2`02
00l;300E010<3@0?2``03`/<00X7200@410030`<00L71`0@41003`d>00h<3@0:20T02@D601<?400=
2@X01`<4018@3`020@003Pd<010?3@0>3@/020L500H02`X800D02PT700h=2`0@3`d02`X800T81P02
00h=2`05010?3@0=30X02`X800d<2P071P@00P0=30X400h=2`0F00/:200?3P`020L600l>30020@00
3`h<018@4@0?3@h02`T:00h<3@0@3Pl03P`=00`:2`0=2``02`T:00X82@0<2P/03`d>00T7200;2@X0
3P`=010>3`804@l@00<05A<D00d;300C4A800P0=2``00`0>30l061HI00l=4P0200d;3P0N00d;3@0@
3Pl040h?00l=3P0?2``040`=018>3`0C3a004Ph;01DB301PH5@0h^3C0;>dXP0a<R0051@600h?1`0D
518061LL01TG900=2aH030T>010>4@0?3A003@X<00h:2`0@30d030P900d92P0<2Pd03PX>0P0>30l0
3`0A3a8020H;00L5200E4aL0IF=X06e[KP0?3A402`T>00X82`0>31003`dB00`:3@0<2P`03P`=00d;
300200/92P0700h<3@0:20T04@l@00X82@0>30d01@<4010>400200/9300A00`:3@0A3a803`d@00T7
2P0<2Pd03@/>00`:3@0@3Q403P`?00`83@0<1`d02PD;018=4`0G4QP04`hD010;4@0A31800P0@2a40
1`0>2@l03@P>00h;400<2Pl02`T>00h<4@0;2@h00`0<2Pl00`0?3A803@/@00X83@0300`:3`803@/@
00D030X?00/93P081P/03P`A014?500200T73007018@5@0>314030X?00h<4@0@3Q<03P`A00X83@02
00d;400700/93P0=2a0040hC00h<4@030@H03@/@00X83@02010>4`0300/93P0=2a003P`A00@040hC
01h06QLN01DB6P081@`020D<00h;4P081@`0518G00T72`0>30l02@L:00d;3P0B41<02@L:00X82`0?
3A002PP;01<A500f=3L04@lB00`:3@0=2`h030X=014?4P0S7R8030L;01<>4P0300803@P<01XF6@0F
4AD2014<400@00/62P0910P030L;00h93@080`L03@P<01<>4P0A310040/?018=4@0?2Ph030L;01D@
500P6al03`X>00h93@803@/@00<01`D:01DC600A3a@00P091``02@0;2@h02PP=00l=4P0N7240:2H[
00/62P0C3Q806A@H01<>4P0200T4200:00/62P0@2`l03@P<00`72`0?2Ph03@P<014<4P0>2@l03@P>
00`73@803@P<01X01P4501/F6P0D41802PH700T4200@2`l030L;01<>4P0>2@d061<G010;3`0=20`0
50lC00d8300910P030L;00X52@0>2@d03@T:014<400>2@`081/O02PS9`0C3Q803@P<00d83P8040/A
01<03PT@00P32P0F4AL091lV01D@5P0300@02PD;01D@5P080`T081/Q01@?5@0:1@/030L<01TD6006
0@D03PT=01D@500>2@d04@/?00803`T=00/040X>01893P0A20d040L<00/42`0=20h03PT?014<4P0;
1P`03PT?00`73@0300d83P0300l:400F4AH04`hB008030L;01L04@`@00l:3P0=20`030L;010;3`0<
20/05A0D00l:3P0@30d03PX;00h:2P0>2PT03PX;00h:2P0>2PT01`<400h:2P0:1PD02@D600l;2`0>
2PT040/7014;1@0200h91@0900d81@0<1PH01`<401<@4P0@3Q40518G018@5@081P/03@/>00803`d@
01/03P`?00`:3@091`P020H901lM7P0<2P/05A<D00P61`0B41402PT700H50`071P@02`X800L6100A
3a002@L800l=3P0610D03@/<00l=3P0610D02PP900T7200:20T03@/<00`:2`0;2@X00P0<2P/05P0=
2``03P`=00h<3@0?3@h02@L:018@4`0<2Pd02PP;00/930091`X030X=00L520050`H040hA00d;3P0P
7R402@L:00/9300C4A@02PP;00<1100@3Q4200h<3`0<00`:3@0;2@`03@/>00h;3`0>2@l04`hD01HA
5`0>2A003``C01LD6`040@P01@@<0P0?3QH0500E51`04a4G00l=4P0=2a003`dB014?500?3A802PP=
014?500?3A8040hC01HD6@0>2a802PL>01@A600C41L03``C010=500:1`h03P/B0`0=2Q40500>2a80
40dD00h=4`0510X051<I00<2200V9b`03@hC01hN9P0H6Ah04Q8H00l>500=31804A0E01TH7@0C4QL0
20L<00X93P0A41D040lD0P0B4AH07@0B4QD04A0E010@4P0?3a805aPJ00`@4@0=41407b0R00lC5009
2`d03a0B00/=3`0P92D03PlA01DG6@062P/04A8F018E600<41<04Q<G00/>4@0G6ah051DI00X<400A
5AP03PlC010B5P0E5QX06APM00805A<H00D02`T>01LE6P0@3Q<071XO01@B5`0201LE6P0>010>4`0A
3a@02PT>01HE6P0J6Ah051<H00l=4@0A3a806ALJ00l<3P0G4a@05Q8C01TC5@0B30h201<?4080510A
00h04`l@018>3`0B3Pl040`=00l;300F4Q<06QHG01HB4`0B3Pl02`L801dI6P0=2@X020@501TE5P80
4`l@0P0B3Pl01`0A3@h04@`@01<=4@0@2Ph03`T=010:3P0B31000P0C3A40:P0J51P03@L;00d82`0@
2Ph03@P<00T4200/9b/0Pgj203Lb=P0300805a8F00h93@0O6Qh0J6=W07agN`0300804P`C01094@0=
1Pd03`L=01<:3@0D2``04`X;01892P0C20`04`P?01<8400C1a404@TA010;3`0B3A4040X>00h8300?
2@d03@D:00d42@0>1@X05`dB00T0100?10X04PL=01052`805``B00@0>Bhd00l42P0B1`d04@H<0P0?
10X00`0C20h05``B014630050146300700h32@0@1@/04`P>01D:400D2@l04PL=01P;4P0201853009
00h12008008040D:0185300A10/03`8900h1200?0PT04PD<00803P<;01H03P<900l22@0?0PT03`89
01<42@0?00D04P<601H7300G1`/0404601H;4@0?1PX0100000l;30091`L01@@201@B4`0=2@P05`h?
00T0000?1PH0BSi05?ooool001_ooooo00<030/=00h>3`0?3a000P0=3@h01@0>3Pl030`=00h>4007
1`T0410B00802PX<00<030X;00h<3@0?3@h00`0A3a00600D4Q<03@/<01DC500>30d02@L801<A4P0A
41<04Q4C00d=3`0;2Pd04@lB00`:3@0B41<03``?00l;3`0B3A404`hB018>400I5QH03Pd<00h<3@0@
3Pl03@/<00X92P@03`d>00X03`d=00l=3P0>30l03P`?02@R900B41800`43018@4P0:20T04a4B0P0=
2``020091`P04a4B00P61`0<2P/06ALH014?400>30d03@/<0P0A3a004`0:20T03P`=00l=3P0?30d0
4@d>010<3@0>2P/040`=014=3P0B3Pl0510A01LC500C3a003PX;014=3P0@3Pd03@`:00l>300>3@/0
0P0<2`T0100=30X03Pd;00h=2`0=30X200`;2@0600l>30061@@05aHD02DT8P0B4@l03Pd;0P0;2PP2
00`;2@803@`:00P04Ph;00h:1`0;20D03@T700h:1`0C3``03PX7018>2`803`/800l05Q8?01LE4@0=
30X05ADC00X:200C4a402PX8014@3P0920H04A0>00h:2@0:1PD071PG00l;2P0?30/00`0>3@/200d<
2PH030/904T03@`900d<2P0>3@/03Pd;00l>3@0?3@h03P`=00d;3@0<2Pd03P`?00h<400<2Pl02`X@
01DE6P0=3A402@T;00l?3@0:2@H04@h:010<2@0D3``030H501@<300D3Pl05Q<C01HF5@15AD<0XJ6O
07UiM`0B4a405QHF00/:3@0E51P061LL01DD6`061@`0>C/o00lA4`0:2``03`h=018>300<1`L04P/:
014;2`0A30`040/?00h93`0<2@h04Q0F00l<4`0I5Q`04PlF05QEG01NFf404PlE010=50091``03P/B
00d:4@0?3A803@/>00`:3@0@3Q402PP;010>4@0?3A002`T<00`:3@0?3A002`T<00l=400=2`l04@lD
00803P`A00<03@/@00X83@0@3Q<00P0C4AH300d;400500d73P0A2A0050/C01<:4P0A2A000P0C2a80
3P0B2A404PXA00l73P0>1Pd03`L>01<<4`0?2Q004@`B00d83P0;1P`040/A00h93`0?2Q003PT?0P0=
20h03@0?2Q0040hC00h<4@0C4AH02`T>018@5@0=2a003`dB014?500C4AH03`dB00d;400?3A800`0;
2@`03@0J61/05A<F00h<3`0:20/03P`?014?4P0>30l02`T<00`:3@0=2`h030X=00/9300=2`h00P0>
30l200/9308030X=00D03@/>00h<3`0>314040dC00l=4P0200d;400?00h<4@0:20d030X?00h<4@0=
2a002`T>00T7300@3a@02PT>01@C600:2@h03P`A010>4`0=2a003P/@008030L=00H040/A014<4P0@
2a403P`A00`:3`0;2@h200`:3`0B00X83@0<2Pl03@/@00d;400<2Pl02`T>00h<3`0;2@`03`d@00d;
3P0;2@`03P`?02@R9@0:20/030X=00l=40091`X02PP;0P0<1`/400d830803PT=00L03`X>00h93@0;
1PX02PD900l:3P0=20`03PT=00804@`@01803`X>00d8300;1PX030L;010;3`0>2@d02`H:01@?5@0@
31403@P>014<4P0<1`d05a8H00h:3`0810T03`X@00H11P0G4QP600`72`0H00d8300<1`/030L;00h9
3@0?2Ph03@P<00`7300;1P/03@P>014<4P0=20h030L=00d83P0E41H06QDK014<4P0<1`d03PT?00d8
3`0E41P0?SQ201<>5@0:1@`04@`C0P0=20h200h93@803`X>00<03`X=00h:2`0>2P/00P0>2P/03P0?
2``04@d>00l;300=2@X02`H800`72@0>2@/03PT=00H21@0L5a/02`H:01<>4P0<1`/03@P<0P0<1`/2
00d83007010;3`0>2P`040`=010<3@0=2@X030P900d92P0400`82@0@00h:2`0?2``040l=00T8100:
2@H081lL00d<200@3`/020L400d<2@0:2@D05aHC01<B400@3@X03P/700l;1P803@X500<030T400`8
100>2PH00P0>2`L05P0>2`P03@X700/81P0>30d030`=00/;2`0:2PX02`X:00`;2@0=30/030X900h:
2P0E4A004@d<00h:200;2PD03@`600/:100A40/04a8>00l>2`0;2PP200/92P<02`T<00P02`T:00l=
3P0>30d03@/<00T7200:20T04@l@00h<3@803@/<00/03P`=00d;300=2`h03P`?00X82`0=2`h040hA
00d;3P0?3A003P`?00d;3P0200h<3`0400l=400>30l03P`?00h<3`803@/>00d02PP;00L5200A3a80
3@/>010>4@0C4A@030X=00d;3P0A3a803P`?00X8300<2Ph03`dA00H03P`@01003@/>00l=400B41<0
3@/>00h<4@0A3Q@03``C00h;4P0=2Q803P/C00l<5@0=2a803@`B010?5@0B4AL040lE0P0<2a405P0A
41H030/A014@5P0?3Q@03PdC01DD6@040`L03a0E01<D700?4QT0DUQO0=SMh`1PIF`05QPO010A5P0;
31004A0E010?5@0B4AL051<H018A5P0A41D2018B500:01<C5@0C4a<04A4B014A4@0C4a@071`N01LH
6P0C51H05aLI014B50804Q8D02/04A4C018C5@0@41804Q<E01@D5P0B4AH04a<G01LG6`0K6Ql071/P
01PH7@0C4QL05ADJ01TI7@0F5AX03`lD01<B5`0E4aH04a4D00h<3`0N71l0518E03`j?@0W9BP04a4D
01@B5@0I5aX05A<F01<A500=3@l051@F01HF600G5aT03Pd@014?4P0C4A@04@dA014<400F4AD06Q@H
01<=4@0F4Q<0510A00<04Ph?00T04`l@01DA4P0A3@h04`l@018>3`0A3@h06aLG01@@3`0C3`h00P0A
3@`0800@30d03`/<018>3`0?2Ph040/?01lJ7P0I51T02PD901DA4`0A3@h02`L8014=3P0F4Q<0510A
00d92P0?2``04@d>018>3`0?2``03`X>00P42@0D3aD0?3Lm028M8`0<1`d04PdC00d83P0<1`d050lE
01XE6`0E41H03`T?0P0?20l01P0@2A003`T>00l93P0>20d05@lD01D=4`8040P?00@02`@:04@nA@0P
6b403@P>0P0>2@l01@0E3QD03@D<00l53@0?1@d04@H>00804PL?01804PL>0146300A1P`040D;0146
300B1`d03@8801P=4`0B1`d01`0201@;3`0k<3H03P<90146300B1`d04@H<01052`0B1`d200l42P80
4@H<00/02P450146300H3AD05P/C01463P0=0PX03P<;01463P0?10`040D=01873`0200l430030146
3P0?0PT03`8900H03`89010040<900l22@0>0@L03@0700l42P0>10T03@<800l72`0>1@X0308600/3
1`0C2@d040D:00l42@0=0`L08AHK5?ooool001_ooooo00d03@d?00h>400<30h02`/=00`<3P0@4180
20P:00X:300@41802`/=00d=3`092@/03@/<00@03P`=01T03@/<00`:2`0>30d02@L800X82@0>30d0
30X;018B500C4aD02PX<00d=3`081PT040hA014?4P0@2`l03`X>014<400A2`l03`X>05eJF`0H5QL0
4a4B00/92P091`P07A/L00H03P`=00<02PP900`:2`0;2@X00P0=2``01@0>30d0518C00l=3P071@H0
3`d>008040h?00L020H702DS900m>c`04a4B00@20`081PL03`d>008040h?00l04a4B018@4@0?30d0
3`/<00h:2`0B3Pl061@E01dI6P0G4a@04@d>01<?400@30d030P900h:2`0>30/00P0;2PP00`0>3@/0
40l=00l>300300h=2`0800d<2P0<2`T030/900d<2P0B4@l030/900D40P0<2`T400h=2`<03@`:00L0
2@P601DD4P0E51803Pd;010?3@040`8020L500802`X800/02PT700d<2P0;2PP010@201<C4@0<30X0
410>00H6100<2`T05A@B00d<2P02014=3003010<2`0E41003`/:00803@`:0P0;2PP00`0:2@L030/9
00`;2@0400`;2@0C00d<200>3@X03Pd;00h=2`0?3@d03`d>00d;300;2@/02`T<00d;3P0=2`l02`T>
014@5P0N7B<051<H00/9300=30X03Pd9014=2P0200l;200F00H20@0@2P`05@lA00l=3P0=3@d00@41
00h>3P0A4A805ADG02DU9`0Z:Bh0?ci307IeNP0@3aD03PlD034f>@093@h05ALF02LW9P0]:BH07APE
01491`8040X:01L03PT=00d83P0:20d01`D:00T7300G5AX02`T>01<A5P0100@02`T>00@21`071@X0
<S0e01PF6`0@3Q<08b4T00X82`0200<01`D800d;3P040PD030X=00h<3`0200/9300>00d;3P081PX0
108700T7300A3a@02PP=00L52P0>31403@/@00T7300?3A806QPM01HD6@0A2a420188400<01@:4P0E
2a<050XB0188400A1`l04PP@00l53@0>10`03`D=00l83`070PP02PD;0P0;1P`06@0?2Q002PD;00/6
300<1`d03@P>010;4@0B3A<02@L<00X83@0B41D02@L<00l=4P071@X03P`A010>4`0B41D03`dB00h<
4@0?3A801`D801DC5P0>30l02@L:00P62@071@P00P0A3a801`0@3Q4030X=00/9300=2`h02`T<00X8
2`0<2Pd00P0?3A000`0<2Pd03@/>00d;3P0300`:3@0700/9300<2Pl03`dB00h<4@0<2Pl02`T>00d;
400300/93P<030X?00D04a8G00T83@0<2a000P4600H52P0200X83@0700/83@0=20h03PT?00l93`0?
2Q0030L=00`:3`0200l=4P0400d;400:20d01`D:00T730<030X?00L02PP=00`:3@0=2`h04a4D014?
4P0;2@`030X=00802PP;00H04@lB00`:3@0610L02PP;014<400>2@d200d8300300h93@0?2Ph03@P<
00<03PT=00D030L;00/62P0>2@d030L;00d8300200l:3P0800d8300>2@d030L;00d8300?2Ph03PT=
00`72`0D3aD200d83P09014<4P0300@02PD;00d83P0H4aT02@D:00T42P060@L02PD:00D030L;0P0>
2@d01@0=20`03`X>010;3`0>2@d03PT>00803@P>014040/A00d83P0<1`d03PT?00l:400>2@l030L=
00h93`0=20h030L?00P2300Q6bD040/C00d83`0A31<03PT?00d83P0200h93@803`X>00H030P900d9
2P0@30d040`=00l;300=2@X300h:2`0;00d92P0<20T030P901<>4P0F4AD00`02010;3`0?2Ph020@7
00/62P0<1`/00`0>2@d02@0=20`040`=01@@4@0G4a@04`l@00h:2`0810D02@D600X61`0300d92P0E
00/7200B4@l06aXH01XI5`0[:RP051<A00`;2@0:2@L03`h<00X91`0D4a40:BPV00T8100;1`@03@T6
00h:1`0=2@H030P500X60`0B3P/03`/8008030P500@03PX7010<2@0?3@h03P`=0P0<2P/200d;3007
0040000E4a@00@00018@4@0610D07A`J00X:0`0200/:1@04014@2`0C4Ph040l;00X91`802PP90`0:
20/03`0:20T01`D602PV9`0Q7b006ALH018@4@030P8071XK0040000E4a@04Q0A00l=3P0<2Pd03`d@
00h<3`0200l=400300`:3@0>30l03@/>00803@/>0P0>30l0100:20/02`T<00`:3@0=2`h200h<3`03
02HT9`0100804@lB00800@0200D03`d@010>4@0C4A@04@lB00d;3P0200l=40D03@/>02X040hA014?
4P0A3a804Q0C00`:3@0<2Pl03P`B00d:4@0?31<04@hF00l<5@0=2Q<03P`C00h=4`0<2a402`X@00`;
4@0?3Q@02`X@00`;4@081`d04A0F00h=4`0@3aD04Q0E00X:300B4aP03a8I00hA600a=Ch0P8B=038f
?`0520l02``A014B5P0E4aL040lE018A5`0D4aP04Q4F014@5@0B4Q@201<C5@0501<C4`0D51@051@D
01@D500Z:R`00P0D51H0700I6A/07QhP01dM7`0:2P`061PJ00L72@0>3Q006QXL01<C5@0B4AH03`hC
00h=4P0A41D05QDJ01PG700A41D05A@I01`K800J6Ah04a8G018A5P0A3a803`d@01dK7P0L6Qd04@lB
06UWJP0a;c8200l=400@01TG6P0C4A@03`d@018B500P82803`lA014A4`0K6Q`05Q@G00l=400C41<0
61<G01`G6`0C3A406A<G01<?40804Ph?00/0510A01DA4P0F4Q<05Q8C01<?40091@H0;BTZ048n?`0A
3@`05a<A01@@3`02018>3@804`l@00h0510A01LB5P0G4QH05a8F01@?5@0?2Ph02`L9010<3@0F4Q<0
4@d>00h:2`0C3a003PX;010<3@804@d>00P040`=00l:3P0B3A<05A0F00H21`0;1P`061<I00`73@@0
3PT?00<03`X@010:4@0?20l00`0@2A003P0?20l030D<00@0100:0`X05PlF00X32P0X8BP0`[c207Ia
M`0K5Q`050lE00X52`0A2Q404PTA0P0?1@d0100A1Ph04PL?01873`0B1`h20146300G01052`0A1P`0
4PL=00/01P0<0@L050X?00l42P0700803PD901hC6@0F2a403`@:01@93`0G31803`@:01052`0A1P`0
3@8801873@0:00D03PD900l4300>0`/00P0=0PX02P0>0`/040D=00d22P0?10`040D=00h32`0=0PX0
3`@<00`01P0=00L200h120803`89100@0`X02@0?0PT03P4800`11`0C2@h02P0500/01P0B1`d040D;
00/01P0201052`0301<83P0900@03P<901Cooooo000Kooooo`803Ph@00P02`/=00X:300=3@l04A4C
010@4P0<30h04Q8D00@41P80410B01<03@/<00h<3@0>30d03@/<00`:2`0;2@X030X;010>3`0?3@h0
2@L800`:2`0C4A80>SXl01dM7`092@/05aLI00X82`0A3a8040hA00803`X>00H040/?010:3P0=20`0
7Q/L00P61`030@82010>3`0300L51P0=2``03@/<00D03@/<01P04a4B00D3100@3Pl0518C00`:2`0V
92D05A<D00T7200@3Pl03P`=00d;30050`@03`d>018@4@0?3@h06QPI010>3`0;2@X03`d>01LE5P0E
4a@03`d>00l<3@0@30d200h:2`0?014=3P0E4A804Ph?00h:2`0?2``03@T:00/7200=2@X03``<00d<
2P0;2PP03@`:00h=2`0;2PP030/900803Pd;00T03@`:00`;2@0<2`T020L5014@3P0F5A<03`h<018A
3`0;2PP00P0?3P`0300>3@/03@`:00d<2P0<2`T02@P600`;2@0:2@L020L500d<2P0@3`d02`X800d<
2P803Pd;00@03@`:00X91`030`405ADC0P0;2`T03P030`4030/901<B400920H04@d<01@@3`060P40
4Pd=010<2`0>3@/03@`:00`;2@0;2PP02PT71P0<2`T0:`0>3@T03Pd:00h=2`0>3@/03Pd<00h<3@0?
3@h03P`>00d;3P0?3A003`dA00d;400<2Pl0518G00l=400:20T03@`900l>2P0A3@X03PX7010?3@0;
1`P03PT=00T420091`P03Ph>014A4@0D51@051@E01<C5@0B4Q@040lD01dL8@0k>Sl03`hD00H73004
1PT07B4R01<E5029RHP0XIbI020K600D30X00P0B30`05@0A31003@/@00`:3`0D4QL02@L<00d;400>
31406ALL00d;40091``05A<H018@5@0?3A80518G05]IGP1>C4l02@L:00h<3`0H5QT04Q0C010>4@02
00l=400F00h<3`0?3A002`T<014?4`0=2a003`dB00h<4@0200D01`D:00l=4P0=2a002@L<00d;400F
51T04a4F00l93`0@1Ph03P@<0188400D2Q804PP@01473`8050XB00X04@L?01063P0A1`l03PP?00X5
2`0B3A<04@`B00`73@0@2a402`H<0P0<1`d02`0>2@l040/A014<4P0@3Q<01P@900D420071@X0518G
00/93P0>31403`dB008040hC0P0?3A80300H5QT04@lB00D31P0F51L061HI01<A500=2`h030X=00/9
300:20/02`T<00h<3`802`T<00D03P`?014?4P0@3Q403@/>00h<3`0200d;3P0600`:3@0;2@`02`T<
00`:3`0>31403@/@0P0;2@h300`:3`802`T>0P0=2a00200>3A802PX>010?500@3a@08R0U00d;400@
3Q<03@X?0P0>2@l0300=1`h03`X@00l:400;2@h02PP=00d;400D4QL06ALL01<A5P0A3a@03P`A00`:
3`802PP=00T03@/>00`:3@0@3Q403P`?00/9300=2`h03`d@00`:3@0=2`h00P091`X01`0@3Q403PT=
010;3`0A31003`X>00/62P0910P01@0=20`02@0<1`/03@P<00/62P0<1`/03PT=00d8300<1`/04@`@
00h93@0200d8300>00`72`0;1PX02PH;018=4`0:1@/03PT?00l:400;1P`03`X@00T42P0I5AX0C4M=
01hI7`0>2@h500`72`803PT=00h03@P<00l:3P0?2Ph03@P<00h93P0=20h030L=00h93`0;1P`030L=
00h93`0=20h030L=00/630803@P>00P03PP@00D02@0C3AL03`TB00P32P0?2Q403PT@00d83P803PT=
0P0?2Ph01`0;1`P03@T:010<3@0A3@h03`/<00`82@0=2@X00`0>2P/01@0=2@X030P900<00P0@2`l0
5a8F00800`0200<05a8F00/62P0<1`/00P0?2Ph0700>2@d03@P<00/7200?2``05A4B01<?400@30d0
3@T:00`82@0>2P/04@d>018>3`0@30d03@T:00/92P0_;Rd05QDC01LE5P0=2`/010<100/92P0=2`/0
1@@200/92P0N7A`01`H400X60`0<20D200h:1`0400`81@091@804Ph;010<2@803PX700H03`/8010<
2@0>2PT03@T:00X82@0<20T200/92P0700d;300;2@`06ALL01/I7P0@3a@0000200`;1P0200X91004
00`;1P0;2PH02@P400d<2P803@/<0`0=2`h03@0;2@X00`4202TW:00Y9bP0;2X[01`J6`0G5AH0DU1A
00@20`091`P020H70040000<2Pd00P0=2`h200h<3`0500d;3P0>30l03@/>00`:3@0=2`h00P0>30l0
0`0;2@`030X=00d;3P0200d;3P0;00/9300Q7b802`T<00X82`0200<08R0S00`:3@0@3Q404Q0C014?
4P0>30l00P0?3A0500d;3P0Z00h<3`0<2Pd03@/>00l=400;2@`03@/@01<@5P0@3A@03@XA00/8400=
2Q<040dF01<A600@3aD03PdC00`;4@0>3A<04A0F00l>500L6b404Q4G00d<4P0@3aD04A0E01LE6P0C
4A@0410F00T<4`0>4AP082@]01DI8P072a@05APO01LH7@0D4aP0518F010?5@0B4AL051<H018A5P0A
41D04Q8D0P0A4A<0200A4A404a<C01<C4`0B4Q804Q8D00@41P0K6ad02`/=0P0<30h03P0:2P`05QHH
00H6200A4A<06QXL01LG6@0=31403PdB014@5@0D4aP04a8G010?500A41D04a8G0P0I61d201<B5`0I
018@4`0I5aX04Q0C01<A500?3A00:2HY01TG6P0J61/0518E010>4@0D4QD071XM03hn@01ADE<02PX<
01@D5P0B4A<04a4D00h<3`0F4aH04`hB02PS9`0O6Ad05@lC01DA4P0201@@4@<04`l@00P05Q8C01LC
500810D0=S8c05IBD`0?2`X05A4?018>3@8040`;01004Ph?01<?40091@H04@`@01<>4P0=20`030L=
00l:3P0B3A0040`=018>3`0D414040`=00/7200>2P/040`=0P0A3@h0800@30d04PhA00X52`0A3180
6QDK01LB600E41H03PT?018=4`0A31803`X@010;4@0B3A<04@/B00l83`0@2A004@XA0109400?20l0
4``C0109400B2a803PL>00l83`0F3aH0HE]Q03<^=00=20h040/A00D01P0;10/030<;0P0?1@d0100A
1Ph04PL?01873`0B1`h20146300301052`0A1P`04PL=00803`@:00L04`P>01@93`0?10X060dC02DJ
800L4AL04@H<00804PL=00<02P4500l42P0900@00P0A1P`00`0D2@l02`8600l4300200l4300900h3
2`0=0PX03@8:00d22P0>0`/03`@<00d22P0<0@T03`@<0080300600<03@0700h1200?0PT00P0@0`X3
01442`0>01032P0>0@P01`02034V;00D2@l07a@J00P00`0<0@L04`P>01052`0<0@L04`P>00d2200A
1P`Dooooo`006oooool200h>400;00`<3P0;2`d03@d?014A4`0;2`d02PX<014A4`071`T03@d?00`<
3P0>30d00P0?3@h06`0>30d03@/<00/92P0C4A8030X;01<A4P0<2P/08AlP0490@@3=cLl0De=E01DE
5`0H61X04@lB01<A500@3Q403`X>014<400B3A404@/?00h93@0A3Pl040h?00T7200E4a@07A/L01@B
4`0600h<3@0N00`:2`0B41401`D600h<3@0?3@h01`D601lM7P0B414020H7018@4@0?3@h09bDV04E3
A00E4a@05Q@E01LE5P0>3@d0<c4b01<A4P0=2``03P`=00P61`0<2P/05A8C01<?400@30d03PX;00`8
2@0=2@X03`/<1@0@30d01`0>30/030/900d<2P0=30X030/900/:200=30X00P0>3@/01@0=30X030/9
00`;2@0<2`T02`X800803`h<00D02PT700l>300>3@/03Pd;00d<2P0300`;2@08010?3@0:2@L05QDC
01TH5P0920H030/900l>300=30X200h=2`0@00d<2P0>3@/06ATG02PX9P0D51803Ph<00P81P0@3`d0
1PD301@C4@0@30/06aLF00/71P0G4Q404@d<00l>30<03Pd;00<03@`:00`;2@0<2`T0100<2`T01@0?
3PX03`h;00h=2`0>3@/03Pd<00803P`=02X03@/=00`:3@0>30l03P`@00`:3`0?310030T;00X61P0=
2@T03``:00/:1P0A40h02PX900d=3P091`/03`hC00`<4@0=3@l030`<018B4P0K6a/04Q8C00T92`0<
30h051<H00X93P0?3Q<020P=01PH7@0<41<030d?00@51@19AdL0EU5>01`G500A30T04@/;014<2`0?
2`l030X?00/93P071@X200d;400W014?500<2Pl030X?00d<400A3a@02PP=00h<4@030@H08b4V01LE
600?3A005A<F00`:3@0:2@/02`T<00l=40091`X03`d@00d;3P081PT0BDM;03Xh?@0A3a@030X?00d;
400C4AH02`T>00`:3`0>31402PP=00`:3`0>314040/A0109400>1`h040T@014:4@0@2A003`P?0080
4@XA00T03PL>00d63@0>1`h03PP?010;4@0N6Al06QDK00h93`0A3180100?2Q00200>2@l03@P>01HD
6@0H5Q/07A/P00/93P0=2a0030X?0P0>3140400?3A8040hC014?500?3A80@Cm202DS9P0?3A0040hA
00@21@0U92H04Q0C00l=400<2Pd02`T<00d;3P0>30l200d;3P0300l=400B41<04Q0C00803P`?0P0=
2`h200`:3@0700/9300<2Pl03`dB00h<4@0<2Pl02`T>00d;400300`:3`0Y00d;400>31403P`A00/:
3`0I6Ad0>CPm0:RW[012@DH05Q@I01TG700@3A8040/A00l:400<1P`04PdC00h93`0<2Pl03@/@00h<
4@0A3a@04Q0E01PF6`0B41D02PP=00P62`0;2@h03P`A00l=40091`X02PP;00T72P0:20/03`d@010>
4@0:20/02`T<00l=400=2`h030X=01<>4P0?2Ph00P0<1`/00`0>2@d03`X>00d8300300d8300300h9
3@0?2Ph03`X>00803@P<00<03PT=00d8300<1`/00`0=20`03`0>2@d04PdA01@?4`0`:c401@4600d8
3P0<1`d02PH;00l:400810T06QDK00`73@1ED5H0FUEK010;400500`72`803@P<00P030L;00h93@0=
20`02`H:00d83@0=20h030L=00h93`802PD;0P0=20h0300@2a403`X@00X52`0=20h040/C00d74@0>
21803`XB00<01@0?2Q403`X@00d83P803PT=0P0?2Ph01P0<20T03@T:010<3@0A3@h03`/<00d92P@0
3PX;00P03@T:00`82@0?2Ph01P4500d9300G4aH0EU5E02PT9`803@P<0P0?2Ph01@0>2@d030L;00`8
2@0=2@X03PX;00803@T:01@040`=00h:2`0@30d04`l@01@@4@0@30d030P900/92`0B41<01`D701@B
5@0;2@`05Q@F00D31P0=2`d030X<00X82`0@3Q003P`=00`81`803@T60P0>2PL00`0=2@H03PX7010<
2@02014=2P0B00l;200=20D040T901092P0>2@X03PP:00l:3@0@2a0040hB00d<4P0:2A40410H00d?
5`0>3aD03@`:00X91@0=30P03Pd90`0<2`T300`:2`8030X=00h040h?00<10P0>30d03`d>01`J6`07
1@H06QPI05ECE00F51D02@L800`:2`0B41403@/>00`:3@803P`?00<03@/>010>4@0>30l00`0<2Pd0
0`0=2`h03P`?010>4@0200l=40803@/>00P03`d@04i<C`0^;2l030X=00d;3P0G5AP020H900h<3`80
3`d@200>30l01`0@3Q403P`?00l=400@3Q4030X=00l=4P0B41H00P0@3A@0100?31@040dF010=5P0?
3AD200h=4`0J00l>500>3A<03PdC01LF700f=C/09B@Z00d<4P0F5A/04Q4F00T7300>30l04Q4G00h?
5`0?4QT030lH018F7`0>4Q/03Q4H01TI7`0O7R<04a4E010?5@0B4AL051<H018A5P0A41D2018B500<
014A4`0C4a<05aLG01LG5`0D51@03`lA01HF6010@4807AdO01<C5@0@41805aLI0`0B4Q@04@0G5aT0
4Q8D018A5P0A41D040lD018A5P0C4QL04Q4F01DD6@0@3a@04Q4F01<B5`0A41D051<H018@4`0H5QT0
518E00805Q@G01@030X=01<A500V92L05A<F00d;3P0G5AP03`d@01<C5@0I6A/0820R01@D5P0C4QD0
5Q@G01<A500B3Q8071LK018=4@0?2@d04@/?01@@4@@05A4B00P0510A018>3`0G4a@07ATJ00d92P0K
5aP04Ph=01@@3P<04`l>0P0C3a00300i=CH03`X>00h93@0H4aL050lE018=4@0@30h05A4B00l;300@
30d05A4B018>3`8040`=0P0A3@h03`0B3Pl04@d@018=4`0A31803`X@00P42@0;1P`050lE010;4@0;
1P`030L=014<4P0@2a403`T@01094003014:4@0>0109400A2Q402`H;014:4@0<1@`050dD00/42`0A
2a403@P>01TD6P0>2@l02@D:01<<4`0<0`/200l53@0401463P0B1`l04PL?01873P804@H<00/040D;
0146300B1`d03`@:01H;4@0@1@/03P<901H;4@0D2@l04PL=0146300200l42P080146300C20h04`P>
00/11P0C20h03PD900/11P0C20h200l4300:01463P0B1`l04@H>01053@0=0PX03`@<01053@0>0`/0
3@8:00l430803P48100?0PT04P0@0`X04@@;01442`0A10/040<:00h1200>1@T0;R@Y01dB600L4aL0
3P@901893@0>0`T03@<801052`0J3aD04@H<00l42QCooooo000Kooooo`0=00`<3P0>3Q003Ph@00`<
3P0=3@l03Ph@01/K7@0G5aT03@d?014A4`0@418051@F00h<3@0300l=3P0400h<3@0=2``04@l@00X8
2@803P`=01@08R0Q03Tg>02VYZP0?cm100l?4@0<30h04@lB00L5200=2`h040/?018=4@0D3a<050hB
014<400;20T03`d>01HD5@0B41401`D600D310H03P`=00H03`d>00h<3@0D4Q<03P`=00d;300C4A82
00h<3@0@00X82@0A3a003@/<01/I6P0/:R/00@0000T7200;2@X02@L8040n?`0@3Pl02PP900h<3@0;
2@X07A/L02@Q8P804`l@00@04Ph?014=3P0@30d03PX;0P0<20T02P0>2P/03`/<00l;300<2PT040l=
01@C4@0?3P`02@P600`;2@0?3P`200h=2`0900d<2P0<2`T030/900d<2P0<2`T051<A01PG5@0A40h0
2`X800803@`:100>3@/02@0;2`/00P8200@4100;2`/03Ph>02XZ:P0@41002PX:00T92@0200/;2`0A
01@D500A4@l08B4O00`<2P0:2PP020P600`;2@0@3`d0?Sdk018>3@0E4A003@T800d81`0=2@P030/9
00d<2P0>3@/00P0?3P`600`;2@0500l>2P0?3P/03Pd;00h=2`0=30/00P0=2``0900;2@/02`T<00d;
3P0=2`l02`T>01D@500@2P`03PP800d9200=2`L030/700L71@0D51D06AXN00L83@062A403A0G00T:
30092@T01PH601hN7P0?3a00410B00/;3@0L6b00:RT^00P8300K6R003@`B00X;3`0Q8B<020P801DB
4P0K5Q<01`8000l:1`803`/:00<03@X=00/93P0920d00P0H5QT0;`091`X03@/>00800`0?3A004a4D
00P62@010080518E010>4@071@P03@/>00800`0100801`D8010>4@030@@030X=00H41`0>30l00`44
010>4@1GEET081hS0040100=2a0040hC00l=4P071@X04Q0E01DC600=2a002PP=00d;400=2@l03PL>
00l83`0=1Pd02`@;00`5300>1`h03`P?0109400=1Pd030D<00d63@0>20h02@@:00803`X@00@030L=
00l:400<1`d03`X@0P0@2a401`0=20h02`H<0040100:20d06ALL00L52P0;2@h00P0>31403@0<2Pl0
3@/@010>4`0A3a@03P`A00400P081PT04a4D00H41`010080AdE801@B5@0A3a800P0=2`h00`0>30l0
30X=00d;3P0200`:3@0300h<3`0?3A003P`?00802`T<0`0<2Pd0100=2`h03@/@00l=4P0>314200`:
3`0400h<4@091``02`T>00h<4@803`dB01`03P`A01<B5`0C4QL092<X08b;T00U8bP06ALL01<A5P0=
2Pl05A0F01@?5@0<1Pd04@`B00d83P0=2a003P`A00d;400:20d01`D:00/93P0:20d020H;00T7300<
2Pl03P`A00h<3`0:20/02`T<0P0:20/02`0>30l01`D800P62@0;2@`03`d@00`:3@071@P08QdQ01XE
6@0E41@03`X>00<03@P<00@030L;00/62P0=20`03`X>0P0@2`l200h93@0400l:3P0>2@d030L;00`7
2`803@P<00l03PT=01<>4P0G4QH0<bhd00<0100C3Q@04@`B010;4@0>2@l030L=01LB600910X0JFAZ
08Z5R`0B3A801@0<1`/200h93@0F00d8300>2@d03@P<00/62P0=20d03`X@010;4@0C3Q@03@P>00/6
300>2@l030L=00d83P0A318030L=00/6300=21005a4K00`6400@2a<01`8901@?5P803@P>0P0>2@d2
00l:3PH03PT=00l040/?00l:3P0=20`02`H:00`72`0=20`03PT=03dh?00=20`03PT=04I1A@0I51P0
3`X>00h93@0=20`00`0<1`/200h:2`0600d92P0:1PL02PH700d92P0<20T03PX;0P0@30d0500=2@X0
2PH700X82`0D4QL02@L<01HD6@0@3Q<071XO00d;400?3A803@/@00L52P0k>Ch0AdE800l;300>2PT0
30P700d9200?2`X04Ph=100>2PT0400=2@P03@L701<92P0B20T04@P;0189300@2a004@`B00h;4P0:
21807AdY06EWL`20Q9005QTR00h>3P0;2PP2010?3@0300d;300@3Pl030X;00D030X;00@040h?00`:
2`0>30d03`d>0P0C4A803`0@3Pl020H700T7200D4Q<030X;00P61`0<2Pd03`d@01HD5`0D4QD03@/>
00h<3`0=2`h030X=00/9300200`:3@0300d;3P0>30l03@/>00<03@/>00L04@lB010>4@071@P06aTL
00800`0100805A<F00803@/>0P0>30l00`0=2`h03P`?00l=400500l=400<00`:3@0;2@`030X=00T7
2P0=2a004@hD00l<4`0A3QD04PlG014>5`0?31D03P`C1@0=3180;P0000D05A@J014@5P0=31804A0F
00l>500C4AH040hA00L630061Ph041<J01lR:`0:3AH05aXS01LG7`0?3Q@03@`A010>4P0@3aD04Q4G
01@C600B4AH04A0E018B500C4aD04Q8D01<C4`0J6QX06a/K01DE5@0J6Q`04Q8D014A4`0F5QP05ADG
01LG6@0B4Q@030`>01LG6@092@/08b<U00/;3@0F5AX04Q4F010?500B4AH201<B5`0401LF6`0@3a@0
4Q4F01@C608040lD01X05aDH01<A500J61/04a4D010>4@0F51L040hA00l=400=2`h04@lB01LE600A
3a803@d?01`L7P061PP020P:01HE600A3a805Q@G01HB5P0M61`04PdA02lY;@0H4QH0510A01DA4P80
5Q8C00X05A4B01@@4@0H51D05A4B00l;300J5QL06aLH00X61@0A3@/04`l>0P0E4A002@0B3Pl04@d>
03`h>@0A31003@P<00h93@0@2a406QDI04E0@`02010<3@0301@@4@0:1PL02PH700<040`=00l04@d>
018>3`0=2@`05a8H01lJ800>2@l030L=010;4@0?2Q004@`B010;4@0?2Q004@`B018=4`0B31800P0A
2Q40400B2a804@XA014:4@0E3QD03PL>01L@5`0=1Pd030D<00P1200@2Q000`0402LR:01@Be406QDK
00l83`0C2Q8200l53@0401463P0B1`l04PL?01873P804@H<00d040D;0146300B1`d02P0500h32@0@
1@/050T?01D:400B1`d04`P>01873@0A1P`03P<900803@8800L03P<90146300E2Q00NVme044f?00@
1@/03`@<008040D=0P0A1Ph01`0B1`l03P<;01053@0A1Ph03`@<00h32`0@1@d00P0B1@`0100A10/0
40<:00l22@0>0@P200l22@0@01032P0?0PT03P4800d01`0C20h03P<90146300=0PP05P/A01<83P0=
0PP040D;01D:400O51X050T?01052aCooooo000Kooooo`0>00/;3@0>3Q003`lA00d=3`0<30h03@d?
04e=C`0f=SP03Ph@010@4P0820X04A4C00h<3@0?3@h3010>3`0300h<3@0;2@X03`d>00<03P`=01<0
30X;02PX:P0=3@l02PX<01<C5@0I5aX01@<600d;3P0@2`l04PdA01HA5@0E3a<04PdA014>3`0<2P/0
1P@500`:2`0A3a0030X;00H03`d>00<03@/<00P61`0G5AH00P0;2@X00`0K6AX040h?01DC5002010>
3`0800H41@091`P040h?00h<3@0E4a@020H700800@0G5AH200X82@0400l=3P050`@04Q0A01lL7@<0
510A00H04@d>00l;300@30d040`=00l;300A3@h201<?4007014?3P0F5A<06QTG014@3P071P@02PT7
00l>300200h=2`0;00d<2P0<2`T030/9010?3@0A40h030/900/:200?3P`02PT700d<2P0>3@/00P0?
3P`07P0@3`d04A0>018B4P0C4a<03Ph>00H61P051@D03Ph>01<C4`0;2`/02@T900`<300=3@d06ATI
00<30@0D51801@D300`<2P0>3P`03`h<00`;2@1:BDL03@T8010<2`0A3@`03`X:00/71P0920H02`X8
00d<2P803`h<1P0<2`T0:@0?3PX03`h;00h=2`0>3@/03@`;00d;300?3@h03P`>00d;3P0?3A003`dA
00d;3P0B31004@/<00h:2@0<20L02`X6010A30071`D0:2TZ03<f>`0E61l01PTC00/>5@092Ph03`l?
01DE5@0i>CT05ADF00410`0?3a4010<800h=4P0?3Q<00`8800l>500:2`l03`lA018@4@0;1`L03PT6
00804Pd:0P0A3@`0900>3A0030/@00/:3`0=2`h040hA00@21@0A3a801`D801LE600=2`h0518E01DC
5P0=2`h01P@700/9300A3a800@02010>4@0<2Pd03@/>00l=400=2`h02PP;00l=400100806ALJ05QF
FP0F51T020H;00h<4@0200D03`dB01<A5P0K6Ah06QPM010>4`802`T>00H030P>01<<4`0E3QD04@XA
00h73P0?20l3018;4P0900l83`0>1`h03`P?01<=500:1@/02@@:00d83P0C3Q@05Q4G00803PT?00D0
3`X@010;4@0>2@l030L=00d;400200H42@0400D3200B41D030X?00h<4@8030X?00h040hC018@5@0>
31407A/N00l=40071@P061HI014?4P0C4A@03P`?00/9300:20/03@/>00h<3`8030X=00<02PP;00T7
2P0;2@`00P0<2Pd02@0:20/02`T<00`:3@0<2Pd03@/>00h<3`0>314040hC00l=4P0200d;400700h<
4@081P/030X?00l=4P0@3Q<03`dB00d;400200X93P0<00l>4`0F5AX03`hC00X83@0;2@h02PL<01LB
600H4aT03@L=00l:400C3Q@03@/@0P091``01@0=2a004@lD00L52P0:20d030X?00803@/@01X030X?
00d;3P0;2@`03P`?00d;3P0:20/03@/>00`:3@0;2@`020H900T72P0;2@`02PP;00/62P0C3Q8061<G
01LB5P0?2Ph02`H:00d8300<1`/02`H:00d8300?2Ph040/?014<40803`X>01D040/?00h93@0=20`0
4PdA014<400>2@d02`H:00h93@0B3A403@P>00l:400>2@l020@901D@5P060@L05a8H00D01P0F4AL0
30L=01@?5@0?2Pl01@0<1`/06P0?2Ph040/?00h93@0?2Ph03PT=00`72`0?2Pl04@`B018=4`0F4AL0
3`X@00d83P0@2a402PD;00P32@0B3A<03`X@00X52`0:1@d06aDO00X43P0A31@03PT@01TD6`0<1`d0
3@P>0P0>2@d300l:3P803PT=01803@P<00h93@0?2Ph04@`@00l:3P0<1`/02PD900/62P0>2@d02`H:
05IAE@0910P04`hB018=4@0?2Ph040/?00l:3P0=20`200/62P0400d8300<20T03@T:00h:2`8030P9
0P0>2P/04`0?2``040`=00l;300=2@X02`L800<11P0l>Sl040hC00H42@0>31402`T>00h<4@0:20d0
20H;00`:3`1mNh00UI>F014=3P0>2PT00P0<20L0100A3@`0510?010<2`0>2PT200/71P0D00`81`0?
2@T040H701461`0@1PL03`H;00l83P0=2a003``E00/;5@0=3a/09BLd0<O:f02UYk<04A0A00`:2`0?
3P`03@/<00P61`0:20T600h<3@0600`:2`0=2``04Q0A00`:2`0200404@l@0P0?3@h0200=2``01P@5
00l=3P0=2``030X=01<A500M6ah06ALJ0`0=2`h02@0<2Pd02`T<00`:3@0<2Pd03@/>00X82`0;2@`0
30X=00d;3P0200h<3`0600400P0>30l030X=01<A500?3A002@L:0P0=2`h200l=40803P`?1@0@3Q40
0`0?3A0030X=00d;3P02014?4P1K01HD6@0H5Q`04PlF00h;4P0<2A403P/D018?600C4AP040lE00h=
4`0=31803PdC014@5P0@3aD04a8H018A5`0I61h04A0F00`;4@0<1`d03`X>01@B600C4QX0410H00/>
5`082a@051LP010@600?3Q@04Q0E01/H700A3QD04Q4G01@C600B4AH04A0E018B500A4A<03`lA014A
4@0H61P06ATI01<C4`0>3Q009RHX02`/;P0P828010@601DE5`0=3@l04A4C01hN800=3@l0>c/m01HF
600?3Q<04Q4F01LF6`0H5a`04Q4F00/:3`0G5Q/04Q4F01HE6P0G5Q/04A0E00h=4P0C4A@0518E01PF
6@0E4aH071XM010>4@0I5aX04@lB01TG6P0G5AP04Q0C028P8`0?3a40ShnA018B500H61X03Pd@028P
8`0D4QD07a/O014<400`:bl0J69V01`F6P0301PD5@0L01DA4P0A3@h03`/<01DA4P0@30d06ADF01<?
400810D06QHE00d91`0A3@`04`l>018>3@0?2``03@T:00/7200E41@071LK00l:3P0T7bD0Ad960;fi
^`0K5aP01`<401DA4P0=2@X0510A014=3P8040`=00l04@d>018>3`0C3a801`8800X52`0>2@l03`X@
018=4`0:1@/03`X@018=4`0>2@l02`H<010;4@0B31<00P0A2Q40400B2a804@XA014:4@0A2Q4030D<
01H?5P080@P06a@K01D>5@0<1P`03PT?01dH7P0D3aD01P4700h73P0:0`T200l53@0401463P0B1`l0
4PL?01873P804@H<00`040D;0146300B1`d050T?00h32@0@1@/050T?00d2200A20`04PL=0146300@
1@/20146300;00d2200>0`T05P/A02@I7`3`iN/0SX>901062`0D2A404`P@01463P0?10`00P0>0`/0
0`0?10`040D=01873`0200l4300601463P0D1`h050L>01<63@0A10/03`890P0>0@P200l22@803P48
00d0300601D:400;0@H0200301L<4P0>1@T0304700l42P0<0PL02P0501<83P0=0PP04@H<01Cooooo
000Kooooo`0301<C5@0=3@l04Q8D0080410B00h06a/M096AT`1iNG/03@d?00h>400<30h0410B00d;
300?3@h040h?014?400@3Pl03P`=010>3`@03`d>00P040h?010@4P0A4A<0410B00h>400>30l040hA
00l=40804@`@00T04PdA01@>4P0C3Q804a0A00T720081PL03@/<00l=3P091`P01P0?3@h03@0>30d0
40h?00h<3@0=2``040h?01<A4P0B4140518C01<A4P0?3@h040h?00l=3P0=2``00P0?3@h02`0>30d0
3`d>010>3`0;2@X08b4R00l=3P0=2``02@L8010=3P0B3Pl03@T:00803`/<00D02`L801<?400?2``0
3PX;018>3`0200h:2`0K010>3@0J6AL0I6=Q00l>300:2@P061LE00X91`0@3`d05QDC00/:2@0?3Pd0
;Rd[018A3`0<2`T03Pd;00l>300@3`d05A@B01HE4`0I61H04Q4?00T81P0<2`T03`h<00P8200C4a<0
2`/;00803@d=00`0:BTY014A4@0;2`/03@d=00l?3`092@T030`<014A3`0;2`T01`L500d=2`0<30X2
00h=2`0:00l>300?2`X0510?01`H5`0G4Q8040`;00h=2`0?3P`03Pd;00d<2P802`X803`051<A00`;
2P0>3@/03`h<00d<2P0@3`/03@`900X91`0920H02`X900d;300>30d030X<00d;3P0?3A003P`@00T7
2`0D3a<03PP;00`92@0E4Q802@T701DE4`0?41002@/<00/>4`072a803Q8L00/>5@0:2`h02`/;00T9
2@0>3Ph0410A00`<3P0=3@l03@`A00`;400:2Ph020L=00l>500<31002PP;010>3`0=2@T040/800d8
1@0?2PL03@T800/91`0?3a403@dA00P8300<2Pd02PP;00/9300>30l03@/>00`:3@0=2`h200/93004
014?4P0:20/03@/>00d;3P8030X=00D04Q0C00h<3`0;2@`02`T<00`:3@0200h<3`0C00`:3@0<2Ph0
2PP=00X83@0?3A802`T>01lM8P0@3Q<02@L<010>4`0T8RL0BTQ=010>4`0?31403`X@01`G7@0B3Q<0
4PdC00h93`0200d83P0:00h93`0@2a403PT?00h93`0?2Q003PT?014<4P0=20h03@T>014<4P803PT?
02D03@P>00/6300A318040/A00T7300G5AX061HK00/93P0=2a003P`A010>4`0920`020H;018@5@0<
2Pl04Q0E00L5200A3a801P@7010>4@0=2`h03Pd?014?4P0;2@`02PP;00h<3`0=2`h02`T<00d;3P09
1`X02PP;00h<3`0;2@`030X=00T72P0C4A@0:BLZ008030X=00<03P`?00l=4P0=2a000P0<2Pl01P0=
2a003`dB010>4`091``03`dB00/93P8030X?01@030/@00T83@0?3Q<01PD:00l=4P0:20d03P`A00`9
3P0@2a403`X@00d73@0?2Q003PT?00`:3`0=2a0030X?00/93P0:20d030X?00d;40803P`A0P0?3A80
3P0=2`h02PP;00l=400>30l02`T<00h<3`0<2Pd02@L:00h<3`0C4A@01P@700/9300>2@d040/?0P0A
310200h93@0400l:3P0>2@d03@P<00d830<030L;00P02@@800h93@0<1`/04@`@00X62@0<1`/03@P<
00`72`803@P<00h02`H:010;4@0<1`d04PdC00/6300F4AL02`L<00d83P0?2Q0040/A00l:400=20h0
3PT>00h93@<030L;1@0>2@d01P0=20`030L;00`7300;1P`03PT?018=4`802`H<014040/A024L8P0A
318030L=00d83P0B3A<03@L?010:500B31H04@/D00h9400?2Q404@`C01@?5@0L5a/040/?01@?4`02
00h93@0400l:3P0A31002@D800P31`803@T<00D050lC00d8300J5AT01@4400h93@0600l:3P8030L;
0P0=20`0300>2@d03`X>00/7200@30d02@D6014=3P0B3Pl03@T:00/7200<20T03PX;00l;308040`=
00h03P`@01PF6`0F51T030X?00P62`0>314020H;00`:3`0E4aP0108703/j?P0a;c8040`=010<2`80
3PX900D06QHE014=300=2@P040`;00l;2P0200h:2@0G010:2P0G3@h04@L801<92`0B2@d091hT00`9
3P0?31@030/E00l@70082QL0G5m/0453C`0?3A403@`>00/92`0:20X05Q@F00l=3P0>30d03@/<00`:
2`0=2``00P0>30d0100=2``030X;00/92P0<2P/200d;3004018@4@0?3@h03@/<00h<3@803`d>00<0
3P`?00d;3P0<2Pd00P0=2`h01`0>30l03@/>014?4P0<2Pd04Q0C00h<3`0@3Q400P0?3A00400H5QT0
3`d@00/9300?3A004@lB01<A500>30l02`T<00h<3`0B41<02`T<010>4@0N71l03`d@00T72P0?3A04
00h<3`0a00l=400>30l03`d@014?4P0?3A003P`?014?500H5A/05Q<J00/83`0@3AD0514J00d:4`0>
31<04a8H00/:400Q82H07ahT014@5P0B4AL04A0F00l>500@3aD03`hD00d;4@0C3Q@04`hB014>5@0@
3aL03`lG00h@6@0=41T03Q0I014@600B3aH04a4F01DA5@0A3QD040lE01<B5`0E51T05QDJ01DE5`0G
5aT0410B01@D500E5AD03`l?01TI6@0201@D5P805QHH00X05ADG01@D5P0M7Al05aLI018B500C4aD0
51@F018B500H5a`05A@I0P0D4aP03@0C4QL040lD01@C600G5Q/05QDJ018A5P0A41D04a8G01HD5`0E
4aH061HI01/I700I5aX00P0C4A@04@0B41<04a4D01DC5P0E4aH04a4D014A4`0T92H05QHH00h>400H
5aT04Q0C01`J7@0E4QD05A0D01hI7@0P6Qh07QPL008061@E00D05A4B01@@4@0J5QL07a/L01@@4@02
01<?4004018>3`0@30d040`;01@@3P805A4@00l0510?014=3P0@30d0EE5B01LB5P0D3a<03`X>01PC
6@0I51P0>cLi01TE5P0D41406ADF010<3@0E4A800`0B3Pl0100A3@h03`/<010;3`0A318301<>5080
4@`B00l06aHL010;4@0@2a403`X@01PC6@0=20h06a@K02<L8`0B2a803@H=018;4P0D3A@04``C018;
4P0@2A000P0>1`h00`0>20h03PT?00h93`02010;4@0400h73P0?1Ph04@L?01473`<04PL?00P050T@
06=HGP0H3A<04`P>00`11`0B1`d050T?00d420805@X@0P0@1@/70146300S00/01P0D2@l091TO01lD
6P0B1`d04PL?01463P0@1@d04@H>01053@0>0`/050TA00X01`0O51`05P`C00h32`0?1@`03`D901@9
3P0>0`P04PD<00d31`0E2`l03`8901442`0@0`X03`8901032P0A10/03`H:0146300<0PL03`@:0146
300>1@T00P0>0`T200l42P0301052`0A1Pcooooo01?ooooo000Kooooo`0500T92`0E5AL00002014A
4`0;2`d00P0A4A<02@0P82800`<501<C5@0@418061PJ00`:2`0>30d040h?014?4002018@4@H040h?
00L03@d?00h>400=3@l02`/=00`:3@0>30l030X=00803`X>00T040/?014;3`0@2`l09B8S01<A4P0?
3@h04Q0A01DC500B4140200=2``200`:2`0500h<3@0@3Pl040h?014?400@3Pl00`0>30d200`:2`80
3P`=00@02`T:00d;30071@H061HG0P0?3@h02`0>30d03P/<01XF5`0G4a@03`/<018>3`0@30d04@d>
00d92P0>2P/04`l@008040`=00d040h=00X91`01000030/900L6100H5aD04a8@00@30@0510804A0>
00l>300g=S@07QdK00802`X801X03@`:00l>300A40h02PT700d<2P0<2`T02@P600/:200=30X020P8
014B500<3@l03PlA01PI6`16AdT03@h@00l@4P0>3a4030d?00d>400@4A8030`:010@3P0M7A/02PX8
00d=2`802`X800H030/900d9200A3@`05a<B01@?3P0A3@`200h=2`<03@`:00P00@00034`;P1AD4h0
0@0000l>300P7ad04A0<00l>2`803@`:02d03`d=010>3`0?3@h03@/=00d;3P0>30l03`dA00`:3`05
0`P03P`A00X:30030`D06a/K00840`0?4A001PT:00`?500>4AP05APP00/>5@0:2`d04Q8B02@T900>
3Ph020P900d=3`0>3Q001`H;00D42@0@3a@00P4701XI7`19Ad`061<G01LC500?2@X04`h;01`G500G
4Pl0510?00h=2`0;2`d05aPL00@52@0>3@l00P0=2``01@0?3@h03@/<00`:2`0=2``03P`=00802`T:
02T01P@500d;300>30l040hA01<A500:20/040hA00D31P071@P030X=014?4P0?3A003@/>00d;3`0;
2@h04Q0E00`;3`0B41D0<S0e00h<4@081P/03`dB01<A5P0_;C803`dB01DC600100@0JVQ]02XX;@0F
51T00`4600d;400?3A804@lD00T7300;2@h02PP=00T52`0=20h050lE01PC6@0200/6300400l:400>
2@l03PT?00/630803`X@00@02@L<01<A5P0D4QL02PP=0P0;2@h0300:20d03@/@01DC60030@H03`dB
00D3200F51L02`T<01<A500:20/04@lB00l=40802PP;01003P`?00d;3P091`X03@/>010>4@0>30l0
4Q0C014?4P0=2`h03`d@01PF6@0;2@`04a4D00l=400J61/03P`?0P0<2Pl200/93P8030X?01<04a4F
00T7300?3A803@/@00X83@0M6b005QDJ00l>4`071P/02@P=0040100N72403@/@00/83@0?2Q0040/A
00h83P0@2a403`X@00<03@/@00<030X?00/93P0?3A800`0?3A8200h<4@0=00T72P0;2@`03@/>00T7
2P0>30l05A<F00d;3P0>30l05aDH020N8@0:20/01@<600d8300300h93@803@P<00@030L;00d8300=
20`03@P<0P0>2@d01P0F4AD061<G00<00P0;1PX03PT=028M8@804@`@0P0B3A40200A310040/?00l:
40060@L05a8H00`73@0C3Q@03`X@0P0>2@l0100?2Q003PT?00h93`0>2@h200d8300300`72`0=20`0
3@P<00@03PT=02H03@P<00`72`0=20d03@P>00l:400A31803@P>00l:400;1``05A0F00`73@0@2a40
3`X@014<4P0;1@d03@LA00l94`0>2A4030L>00d83`0?2Q003@P>014<40080`L040/?00`72`0;1P`0
4PdC01<>500N6Al03@P>00X62`0C3Q@02@@:00d93P0E41H06QDK010;4@H03`X>0P0>2@d300d8300:
00`72`0>2P/030P9010<3@0S7b006ADF00X61`0;1`P030P900h:2`<03`/<00@030X=00P62@0610L0
2PP;0`0=2`h08@0:20/06QPK014?4P0<2Pd02`T<010<3@0;1`P02PH701TE5P0K5aP030P900X61`0?
2``04Ph?014=3P0=2@X03@L901P?400C2P`0618D01@>400=2@/03`X@004010071Pd02PXD01@D7P04
1a4051@N00X83P040PL07Q`Q018@500200800`0400/9300:20T02@L800X82@802`X80`0<2P/0100>
30d03`d>010>3`0?3@h200h<3@803@/<00@030X;00h<3`0=2`h030X=0P0=2`h200h<3`0>01<A5001
008020H901DC5P0?3A0040hA00l=400F51L03P`?00/9300A3a804Q0C010>4@0>30l200`:3@0700/9
300=2`h07A/N02TW:P0B41<02@L:00d;3P0200`:3@0H00l=400B41<0518E018@4`0=2`h02`T<00X8
2`091`X02`T>018?5@0D4AP04@hE00X73`0A3QL0514J00`:4P0D4aT030/A01LF700D4aT040lE018A
5`0A41H03`hD0P0@3aD0100>318050lE01@?4`0C3aH2014@600C010@6P0?3aT0410J014@600C41L0
5A0F01H@5@0=2Q405A@J01LF6`0@3a@04Q4F00l?4@0B4Q@03Ph@018B4P0E5AD04Q8B01/K6`0201@D
5P805QHH00X05ADG01@D5P0D51H04a<E018B500D51H05ADG01<C5@0H5a`05A@I0P0B4AH04@0@3a@0
30/@01@C600E51T051<H018A5P0A41D04Q4F01HD5`0C4A@06QPK028P8`0O7B004Q0C01@B5@0C4A@0
518E00805Q@G00/04a4D018B500A4A<0410B01@D5P0G5QT03`d@01TG6P0G51L050lC01<>4P0201@>
4P0701LC500F4Q<0510A01@@4@0L61T08QhO01@@4@0201<?4005018>3`0A3@h04@d<01<?3@0B3Pd0
0P0A3@`2018>3`0>01hJ6`0:1@T05a8F018=4@0A31804`hB00h9300>2P/061@E00/7200=2@X00`00
00h:2`0?2``3010<3@04010<3`0@2a4040/A00l:408040/A00L050lE00P32@0A3180:RD[00P32@0@
2a403`T@00806Q<J00@04@XA018;4P0A2Q403`P?0P0A2Q405P0@2A003`P?00l83`0?2@l03@P>00`7
3@0>2@l04@`B018;4P0@1`l03P@<00l53@0B1`l050TA01D:4P0C20l040D;0148300;00H03P<900l6
2P0F2a4200T0100301P=4`0I3Q@03PD900H04@H<00P04PL=01052`0>0`T02P0500T0100A1P`04`P@
01053@803@8:01X03P<;00l4300<0@T01`0401`A6@0G31@01`0401<8400I31<040<:01L:4@0J3A@0
50L>00`01P0>0@P040<:01442`0@0`X04`H=01H9400<0@L09a`R03H[<@0B1`d02P45014630<03@88
0`0>0`TDooooo`006oooool02@0>3Q0030`>00410`0=3@l04A4C00P82P0:2P`04A4C00L72@0201LG
6@04024Q8`0=2``03P`=00l=3P<040h?00<03@/<00h<3@0>30d00P0>30d0200=2``03@d?00h>400=
3@l030`>00d;3P0>30l02`T<0`0=20`0200>20`03@P<014>3`071@H02PP900h<3@0=2``02PP92P0=
2``300h<3@0300l=3P0>30d03P`=00803P`=02@030X;00d;300@3Pl04Q0A010>3`0A3a0020H700l=
3P0=2``030X;00l=3P0@3@h09B4R024M7P0@30d04Ph?010<3@0=2@X030P900l;300C3a004Ph?014=
3P0B40l051<A00<2000G5Q@00@0000h=2`0920H01@@200/:200@3`d02@P601HE4`061@@300`;2@03
010?3@0?3P`03@`:00803`h<0P0=30X09`0<30X02@T;00h?4@0<3@l01@H800H72@0J6ad01PL901<D
5P0720X010D700P92`072@T06QXJ00@40P0820H00P8001DE4`0A40h040l=00h=2`0>2PT03@T800h:
2@0;1PD04Ph=00l>300=30X030/900h=2`0?3P`06aXH00/:2@0T8b400@0000h=2`0K6QP040l;010?
300200h=2`0400l=3@0@3Pl03`d>00d;3@8030X=01l03P`@00h<4@0A41H01`P=00h?4`0[:Rl0GUmQ
00P:2@0?4A001`X:00`@4`0;3Q<05QPO01@E6P0>3Q006ATI03dm?@0N7Qh03Ph?00T92`0V9RP09bH[
0000100D4aP02PT?00T83P0F51T01`8601<?400C3@h03@P5008020<000H020@3014A3`082``02@d@
01DF600?3Q0200d;300W00h<3@0<2P/02`T:00l=3P0:20T01P@500/92P081PL03P`=00D31P0B41<0
20H9010>4@0Y9bX00P0300/9300>30l03`d@00d;3P0:20/03@/?00l=4P0>31402@L<00P62`0M6b00
2PP=00d;400A3a@020H;014?500100@030X?014?500100@06ALL00d;400B41D01P@900803P`A01<0
2@L<01DC600A3a@02PL<00X52`0A3180:bH/028M8`0B3A<02`H<00d83P0?2Q003@P>00l:400=20h0
108700/93P0=2a002PP=00803@/@00/05Q@I0040100D4QL06QPM01@B5`081`/02@L:00L5200E4aH0
3@/>00@21@0200h<3`0500d;3P0@3Q403`d@00/9300<2Pd00P0;2@`02P0@3Q404@lB00h<3`0B41<0
5aDH00H41`0=2`h030X=01PF6@0;2@`600/93P0C00X83@0A3a@03@/@00X83@0?3A80;B/`010?5001
00D02`X?01LF6`0C4QL03`dB00d;400;20d03`X@010;4@0>20h040/A00l:400300h<4@0400d;400;
2@h040hC00l=4P803P`A00<03@/@00`:3`0;2@`00P0<2Pd200X82`0700`:3@0?3A002`T<00d;3P0F
51L02PP;00/9300600d8308030L;01H03@P<00h93@0>2@d03`X>00D1100;1PX01@04014<400?2Ph0
0`0200`72`070PH04PdA00`72`0500@040/?00h93`070PP04@`B00P32@0C3Q@03@P>1@0>2@l00`0>
2@h03@P<00d8300400d830<03PT=01803@P<00`72`0<1``03@P>00h93`0?2Q003PT?010;4@0G4QP0
9R4W01<>500?2Q002PD;010;4@0<1`l03@LA00h84P0?2A8200d83`0B00d83P0@2a406A@H00h93@0@
2`l01`8601@?5@0910X050lE059=D`0M61h03`X@014<4P0300@03PT?00<0100?2Q0030L=1P0>2@d0
100?2Ph03PT=00h93@0=20`200`72`08014=3P0<20T04Ph?02<O800E4A803@T:00`82@0=2@X400l;
300c014?400;2@/020H700/9300=2`d02PP901HD5`0=2`d03@/<00h<3`081PP05A<D00T51P0?2``0
30P9010<3@0=2@X03PX;00/7200?2``04@d>00l;300>2P/03@T:00`61P0@2P/00`0000`6200E4A<0
0`0200<1100D4QP01@@:014@5P0?3aH05aLO00d;4@0C4AH00@0401HD6@0100@081hQ00/9300:20T0
2@L800X82@0:2@L02`X8014?400?3@h03P`=00D03@/<0P0>30d200`:2`0300h<3`0=2`h030X=0080
3@/>00L03P`?00`:3@0>30l05Q@G00l=4029QhX0;bd`00802`T<00D040hA00/9300:20/03P`?00d;
3P0200/9300S00`:3@0;2@`02`T<00X82`0@3Q405Q@G00P62@071@P03@/>00`:3@0=2`h03`d@01<A
500E4aH0518E014?4P0@3Q404@lB018@4`0D4QL030T?01<@5`0W92/04PlG00/84@0G51d03`dE014@
5P0920h02`X@00T83P0?3Q@04a8H014@5P0?3Q@00P0@3aD01P0?3Q<050lE01D?4`0D3aH04PlH014@
60<0410J01004Q0I01D@5`0E41H05a4F01DB6@0J6Al04a8G00`;400C4QL04A4C018B500?3a404Q8B
01DE5@0D51@06ATI0P0C4aD301@D5P0901<C5@0?3a404A4C01<C5@0E5AL05QHH01@D5P0J6Ah05aHK
00805QDJ00<051<H014@5@0C4QL00P0C4QL3014@5@0M01HD5`0D4QD05aDH01/I700H5QT03`d@01DC
5P0D4QD05A<F01LE600F51L04a4D01`L7P0C4aD051@F01LG6@0C4Q@03@/>01DC5P0H5AP061<G01D@
500H4QH06aDI01PD5@0I5AH05A4B00l;300A3@h00`0D414201<?400C018>3`0A3@`03`/9010<2`0A
3@`05Q8A01XF5`0L61T03@T:00d8300L5a/050lC00l:400E41@05Q8D01DA4P0X92D03`/<01PD5@03
010<3@804@d>01@040`=010<3`0@2a403PT?00d83P0>2@l040/A01<>500300@08A`R06]VK00L5ad0
1`8801<=500?20l02P<:00d63@0G41L04@XA00/52`D040T@00L04@/B00l:400<1`d03@P>010;4@0A
2Q404@T@00804@L?0`0B1`l0300D2A001`0201D:400?10X05@X@01052`0B1`d06a0F01L<4P0?10X0
1`02014630L040D;00P04PL=01@93`0@1@/03@8801052`0<0@T03P<;01@94@806@hF00<050TA0146
3P0?10`00P0>0`/201D:4P0702`O9P0800802`0500P00P0C20d0200200l22@0201032P0900l22@0B
1@`05@P?00L00P0e:S00CD9801dB600?10X0200300H03@885?ooool001_ooooo01004a<E00/;3@0I
6A/01`L900/;3@0A4A<05QHH00d=3`0820X04Q8D00l?4@0@418040h?00l=3P0=2``030X;0P0;2@X0
100>30d03`d>014?400A3a0200h<3@0700d=3`0?3a403Ph@00d=3`0?3A004@lB00l=4003014<4006
014;3`0@2`l06QLH00`:2`0?3@h040h?0P0>30d600l=3P07010>3`0?3@h040h?010>3`0>30d03@/<
00h<3@0200d;30803`d>0`0@3Pl0@P0?3@h03P`=00l=3P0@3Pl02PP900h<3@0M6a`04Q0A01HD5@0<
2@X07QXK01/G600=2@X040`=00h:2`0=2@X03PX;014=3P0B3Pl04`l@018>3`0D4A4010<201TH5P0<
2`T04A0>00l>300A40h03Pd;01<B400m?3X051<A00X9200>3@/040l=00h=2`0?3P`05A@B010?3@0>
3@/030/900h=2`0@3`d03`h<00d=2`0=3@l02@X<00`=3`082@/02P/=00L82P0=3Q00<S<e01DF600F
5aT01PL901PJ6`2<S8`0<c<a00/;2P0<30X010@300d<2P0;2PP02PT700h:2@804Ph=00<050l>014=
300?3P`00P0>3@/2010?3@0800/:2@0?3P`02PT700d<2P0<2`T04A0>00d<200=30T200d<2P0]00h<
300>30d03`d>00h<3P0;2@`02PP;00d;3`0@3aD03a4I014D7@0<3aD020T>01<F600<41403@l>00`>
3P0>3a801PH:018A5`0J6Al03`lA00L71`0J6QX02@T900h>3`0D51H0<C4c04E4B@0A41D02`X?00T8
3P0A41H030X?018=4@0@30d05A0@024I5`0G3`d03PX700X81P0@40h0=cXk02LZ;@0U:BX03Pd?0080
30X;01003@/<00`:2`0;2@X03@/<00`:2`0B41407Q`M00d;30071@H030/=00l>400A3a807adP03<a
=00F51L03@/>0P0;2@`02P0<2Pd03P`?00d;3`0?3A801@<801PF6`091``02PP=00l=4P0<2Pl200h<
4@0C00h=4@0:20d06QPM07ilP@14@TL0<2hc010>4`091``030X?00l=4P0:20d040hC02<Q9P0N7240
3``A00/6300B3A<07aXP01<>500200/63006018=4`0E41H040/A00d83P0:1@/03@/@0`0>31408@0@
3Q<03`dB00X83@0`;S<0?3Xo00d<40091``040hC00h<3`0F51L02`T<01DC5P0610L0@Cm201TG6P0@
3Q403P`?018@4`0@3Q402`T<014?4P0=2`h030X=00d;3P0:20/03@/>01@B5@0;2@`06QPK00l=400C
4A@04@lB00/93P0400`:3`0D00/93P071@X04@lD00H42@0B41D03@`@00`:3`071P/06QXN018A5P0;
2Pl0<Bld010>4`0<2Pl02`L=00l:400@2a403`T?014<4P0?2Q0300h<4@0400d;400;2@h03@/@00d;
408030X?0P0;2@h03@0=2`h030X=00l=400F51L040hA00H41`0;2@`03`d@00X82`0<2Pd02@L:00h<
3`0>2@d00`0=20`200h93@0300`72`0=20`03@P<00803PT=01<03`X>00h:3@0C3Q803PT=028N8@0J
5AT03@P<01D@500K5QX03`X>01@?4`0H4aL030L;00l:400A31803PT?010;4@0V8BL040/A00D03PT?
00@03PT>00d8300=20`03PT=0`0=20`300h93@0?00d8300<1`/02`H;00h93`0?2Q0030L=00d83P0?
2Q005A0F02@O9@0A31803PT?00P32@0=20h03PTA00803PPB014040XC010;4P0?2Q403PT?018=4`0K
5QX03PT=01<>4P0D3a<040/A00`73@0B3A<0>C@j01PC6@0=20h050lE03@_=@02010;4@0300P42@0@
2a403PT=00D03PT=00<03`X>00h93@0>2@d00P0=20`01`0<1`/040`=010<3@0?2``0510A00X61`0B
3Pl00P0=2@X300l;300F00h:2`0;2@T03@`;00d<2P0;2PT02PT800`;2@061@@03`h<00T81P0A40l0
40l=00`;2P0>2P/02`L8018>3`0=2@X040`=00d92P0>2P/03`/<00h:2`803@T:01@04@d>00h;300@
3@h040h?00X7200G5AH04Q0A014?400=2`d030X=00H41`0@3a8020L;00/8400E4QT02@H=01@B6024
PXL0EUAI00d;3P8030X;00H030/900d<2P0=30X03`d>00h<3@0=2``200h<3@0500l=3P0;2@X030X;
00h<3@0?3@h00P0@3Pl00`0>30l03@/>00`:3@0200d;3P0300h<3`0=2`h04@lB008030X=00@0Cde@
01lM800>30l03P`?0P0A3a802`0B41<040hA00`:3@0;2@`03@/>00l=400@3Q404a4D00h<3`0;2@`0
3`d@00803@/>00<040hA00l=400?3A000P0@3Q40;`0B41<040hA010>4@0A3a803`d@00/9300;2@h0
3``B01XG7P0T8BP04a0H00h;500E4Q/03@/B010?5@0C4QP051<I00l>500=318051<I014@5P0?3Q@0
40lE014@5P0A41D04PdC01<=4@0B3A@040dF010>5P0?3QP04A4K014@6`0C4AT05Q4H01HA5`0G4AL0
4PlF014@5P0@3a@04Q4F01HE6P0@41805QHH01@D5P0D51@05ADE008051@D00<04A4C018B500C4aD0
0P0C4aD00`0B4Q@03Ph@018B500401DE5`0301LF6`0F5AX05A@I00805aHK00@05A@I01LF6`0F5AX0
5A@I0P0F5AX0200E51T04@lB01DC5P0E4aH04a4D01HD5`0J61/05Q@G0P0E4aH01@0G5AP05Q@G01<A
500C4aD04A4C00805QHH00T051<E01LE600A3a805Q8F01HA5@0C3Q805@lC01PB5P0F4Q<00P0L61T0
0`0H51D05a<D01PD5@0401@@4@0601<?400C3`h05a<A01@@3`0C3`h04@d<0P0B3Pl04P0D41404`hB
01PC5`0@2`l03`X@01HA5@0C3a40:bLX048n?`0A3@h02PL7014=3P0D41405A4B01@@4@0B3Pl040`=
010;3`803`X@00X03PT?00l:400?2Q0040/A01lJ800@2a404`lD00d93P0>2@l04@/A0P0D3A@0100@
2A003`P?014:4@0A2Q4401094008014:4@0D3QD04`hD00l:400=20h03PT?00l83`0@20l201473`08
01873`0C21004PL?0106300D2@l04`T>01D:400F2a4301052`040147300D2@l05``B014630H040D;
0`0?10X00`0@1@/04`P>0146300201463P0@01D:4P0H3AD06@hF01H;4`0=0PX03`@<00l5300C2100
3@@:01483P0D1`h03`D90185300M41L04@D;01D83`804@@;00X03P4800`01P0?0PT04PD<01<83P0:
0PD0=BX`02/R9P0F31403@@80`0>0`T300d221Cooooo000Kooooo`0500@41P0D51H02`/=03`l?P0F
5QP00P0<30h200h>400;00l?4@0=3@l02@T;010>3`0>30d030X;00/92P0<2P/03@/<00h<3@0@3Pl0
0P0B41400`0?3@h03P`=00/;3@0200d=3`0400`<3P0>30l040hA00h<3`803`X>00T03PT=00h8300=
20`06QLH00X82@0?3@h03P`=00X82@0<2P/01P0>30d03P0?3@h03@/<00l=3P0A3a003@/<00X82@0>
30d030X;00d;300A3a0040h?00h<3@0@3Pl04@l@0P0<2P/03P0D4Q<06QPI014?400;2@X06ALH00L5
1P0D4Q<02PL8018>3`0=2@X03PX;010<3@0=2@X04@d>0P0B3Pl05P0>2P/04Ph?018>3`0?3@`04A0>
03Th=P0@3`d02PT700/:200E51807QdK00l>300<2`X02PT701@C4@0;2PP03@`:00l>300F5A<08B0N
01`K6@0A40h200/:200G010?3@0=30X030/:018C5@072`h02`lB00<72P0<41<02`lB05=GFP3MhN@0
JVia014E600@51L020/=0000000=3@/05ADC00/;2@0:2PP02PT700h=2`0:2@L00P0>2PT01@091@@0
30L700l;2P0>3@/03`h<008040l=00T03`h<01HE4`0>3@`07ahL00/:200<2`T040l=00/:1P0<2`P0
0P0=30X0<P0=30/03@/<01<A4P0A3a403@/>00/9300?3A405A@J028V<@1<Deh06QhW01<H7P093A40
5ATJ00`>3@0<3@`03`l?00L5200=2`l040hC00L72@0<30`04a<C01@D500D51D04Q8D00/;3@071P/0
10<800d<4@081`d030/A00D21`0D3Q80618D018<3@0C2`T02000018>2`0:2@L01@D3024S9@0<4A@0
10P900d<3P0<2P/03@/<00l=3P0>30d03@/<0P0>30d02P0B41407A/L00`:2`081PL05aDH00h<3`0B
41<040hA00`:3@0>30l200X82`0G00/9300=2`h03`d@010>4P0E4aP03@/@01`J7`0<2Pl02`T>00h<
4@091``01`D:01DC600A3a@03@/@00401016A4T06aTN00X93@0C4AH06aTN01DC600C4AH00P0<2Pl0
4@0>31402PP=00d:3`0E41H061<I00h93`0500H02`H<00d83P0?2Q0040/A00/6300>2@l05Q4G014?
500=2a002PP=008030X?00D02@L<018@5@0:20d03`dB01HD6@0200`:3`0900<1100:20/02@L:00d;
3P030@@06aTL01DC5P0>30l02PP;00803@/>00l03P`?02<Q900H5QT03P`?014?4P0@3Q403`d@00P6
2@0100803@/>00D31P091`X02PP;00/93P0=2a000P0>31406`0=2a002`T>00`:3`0;2@h01`D:01HD
6@091``0:2H[01@C601DDeP09RDZ01TH7@0=31400@0400/93P0:1``03`X@010;4@0?2@l04PdC00h9
3`0<2Pl03@/@00`:3`0;2@h02PP=00/93P0400`:3`0D00d;400:20/03@/>00h<3`0F51L04a4D00T7
2P0<2Pd040hA00X82`0>30l02PP;00`:3@0@2`l03PT=00d8300>2@d03`X>010;3`0>2@d300d83080
30L;00d061<G014<400Z9BT0Yj:V018=4@0;1PX040/?01PC5`070PH03PT=01@?4`0300803`X@0080
3PT?00@040/A02DP9P0A31803`X@0`0=20h00`0?2Q003PT>00`72`0300h93@0300`72`0=20`03PT=
00803PT=00D03@P<00`72`0;1P/04@`B01<>500200h93`0G00d83P0910X04`hD00L2200?2Q002@@:
00h93`0>2A403@LA00`6400>2A4040/B00d83`0;1Pd01`8800/62P080`L05A0D01<>4P0;1P`040/B
00d83`0500L00P0;1Pd01P0Q72<0=C0g024L8`080`X03@P?00X530H03@P<0P0<1`/300d8300900h9
3@0;1`P04@d>00`82@0?2``03@T:010<3@0=2@X03PX;00803`/<00@03PX;00d92P081`D02@P40P08
1`<0100;2PH03`h:01@C3`0?3PX200<2000900P70`030P003PX;00T51P0Q7Ah030P901<?40060P<0
30P900803`/<0P0>2P/0500?2``02PP;01/K70000000<C4a0;:a/00I61H05QDC00`9200J5QD05Q8A
00X61@0;1`P03@XB00l<5@0B3aP030T@08b:S`1<BTl03P`?0P0<2P/00`0<2`T03@`:00h=2`0300/9
2P0600d;300>30d03`d>01<A4P0@3Pl03P`=0P0<2P/0100=2``03P`?00d;3P0<2Pd200d;3P0;00h<
3`091`X04a4D00D31P0H5QT00@0201TG6P0?3A003@/>00/9300=2`h00P0>30l0100?3A004@lB00l=
400>30l2014?4P0600d;3P0?3A004Q0C00d;3P0;2@`03@/>0`0>30l07@0?3A0040hA01@B5@0P7R40
9bDX020N8@0E4aH0518G018?5@0;20l0104800X73`0B3aP040dF01@B6P0@3aD03PdC00T83P0=3180
4a8H01@C6@0A41H03PdC010?5@0A41H04a4G01@=500D3Q804`hE00804@hG00`040hI018@6`0B41/0
514J01HA600F4AL0618G01PE700C4QP051<H014@5@0;2Pl201LG6@0701HF600D51@05ADE01DE5@0A
4A404a<E01@D5P0301DE5`0401@D5P0B4Q@05QHH01HF608051@F00P05ADG01@C600C4QL04Q4F01<B
5`0D4aP04A0E01@C60804Q4F0P0D4aP00`0A41D040hA01<A500201HD5`0301TG6P0M6ah05A<F0080
518E01805A<F01@B5@0@3Q404Q8D01@D5P0B4Q@04A4C018A500?3A005Q@G01TE6@0I51P05a8F01H@
500G4AD06ADF01/G600H51D2018>3`0301DA4P0D4140510A00<0510A00D0510?018>300B3Pd04`l>
018>3@02014=3P0901LC500@2`l04@`@00l:3P0A31804PdA014<3`0<20T03PX;00805A4B1@0C3a00
0`0A3@h040/?00l:4003010;4@803`X@00`040/A00@01@0910X01`8801HA5`0H4QP03`P?00H01P0>
1`h05@hE00h73P0;1@/50109400301<=4`0B3A<03`X@00803`X@00@03`P?01073`0A1`l04@L?0`0B
1`l0300@1@`04PL=00l52P0F2a402P0501873@0N4aT0>Rle05A9C`0?10X01`0201H;4@H03`@:00@0
4PL=01<83P0?10X03P<90P0D2@l00`0A1Ph03`@<00h32`0201053@0=00l4300E2Q804`P@00l4300G
31@03@8:02dR:P1MD5L04PD<01H9400A10/0?C0g03HY<00201442`0;00d01`0<00H03`8901D83`0B
1`d02@0401T>500C20h01`0201<83P0@1@/00P0?10X200h32@0300d22?oooooooooo01;ooooo000K
ooooo`0>00l>4`0820/0BDU;0<[9cP0N7B404a<E00T83@0C4QH03`lA00/:3`0=3A003@d?00l=400>
30d200`:2`0400l=3P0@3Pl02`T:00h<3@8040h?00T03@/<00/92P0:2@/03@/>00/;3@0;2@`03@/>
00l=400B41<00P0C3Q801`0B3A404P`@014<400@3@h02`T:01PF5`0I5aP00P0A3a0600d;300a010<
3@0>2P/03`/<014>3`0>2P/020L500l=3P0<2P/03@/<018@4P0A3a8030X=00`<300A3a003@d;010@
3P0N7AT0;RhY02<T7`0>3@/040l>0000000G5AH04Q0B01<?400=20`04Pd@010<3@0<1`/04@d?01<?
400B3A403@T;018>3`0B3A403@X:01LF500d<c408B0N018A3`0<2`T040l=00d<2P081`D04Q4?00D4
0P0A40h03Pd;010?3@0200`;2@0S01@C4@0920H06APF014@3P0>3@/040l=00/:200920L020T;00<4
1P0?41801@H800l@4P0A4Q@0ATM90>c]k`1bLgD03@h@00H72@0=3Q005QHF00l?3@0410803Ph<00/;
2@0<2`T03Pd;00d9200A3@`04Ph=00l92@0C3@d03PX900d<2P0@3`d00P0A40h0900?3P`00@00014@
3P2AT8h0B4M500l>300>3@/02`X600`;200=30X03Pd;00h=300>30d05A<D01@B4`0?3@h030X=014?
4P0H5ad0TIFP0=CIgP0h?4D04aHM00d@4`0620L02`d<00T:2P0@41802`T<00d;40050`P02`/=018B
4P0:2PX03Ph>00d=3P803@d?01@04Q8D00h>400:2@h02`X?00l=4P0C41D03PT?01@?4`0=1`T040X:
014;2`0?2PX04@l@01TI6@0720/0004401@E6@0>3@h03@/<00h<3@804@l@01<03`d>01@B4`091`P0
108300d;300:20T040h?00`:3@0A3a801@<600/9300?3A0040hA00`:3@0=2`h03P`?00`:3@0;2@`0
20H:008030X?00<0518G00l=4P0F51T00`0;2@h0400@3Q<01P@9014?500=2a005aDJ00H42@0D4QL0
0@04020N8`0;2@h03@/@00/93P0=2a002`T>00h<4@0D4AH2014<4P0J00d83P0A318040/A00T42P0A
31804PdC00l:400L5ad0;RT_01<A5P0>314030X?014?500B41D040hC00`:3`0I5a`030X?00D3200D
4QL02PP=00`:3@071@P03P`?00L5200?3A0200h<3`802PP;01402@L:00P62@0B41<081hQ018@4`07
1@P03@/>00l=400>30l040hA00400P0:20/02`T<018@4`0@3Q4030X?00d;400200l=4P0300d;400<
2Pl02`T>00803P`A01003`dB00h<4@1/JVl0WifR010?500D4aP02`T>010>4`0C4AH02`T>00X6300?
2Q0040/A00l9400B3A<03@P>0P0<2Pl200/93P0300T7300;2@h030X?00803@/@00l03P`A00l=4P0:
20d03P`@00X82`0=2`l03@/@00L5200@3Q802PP=00800`0=2`l030X?00d;400?3A800`0<2Pl0900>
31403`d@00d;3P0>2@d03@P<00d82`0<20T02`L800h93@0=20`04`hB03Td>00C3Q806A@H010;3`0<
1`/050lC00h93@080`L03`X>00h93@060@L030L;00D11@0C3Q@03@P=00l:3P0=20h030L<00d8300?
2Q003PT=00`72`0>2@d03`X>00h93@8030L;0`0>2@d03@0=20`030L;00`73@0C3Q@05A0G010;4@0?
2Q003@P?00`73@0G4QP020<:00h9400910X00P0A31<0100;1Pd02P@>00d83`0?2Q4200`73P0A00T4
2P0>2@d050lC01hI7@0>2@h04PdC00P32@0;1Pd04PdD010;4@0A318020<:01HA5`21O8<02PD<00l:
400A31801P0=20`06`0;1PX030L;00d8300=20`03PT=00l:3P080`L04@`@00`7300C3Q@050lE00`7
2`0>2P/03PX900l;2@0?2`X03PX900d9200C3`h02`X600H50@071P8030/700l>2P0<2`L01PD2010?
2`0200h=2@0R00L6100=2@X05Q8C03Te=P0<20T04@d>00d92P0:1PL03`/<018>3`0@30d03PX;00`8
2@0@3Pl020L701TI6@0R8240Hf9Q018A3`061@<040d;00X60`0C3``02`L4018>3@0=2@l081dT0080
1P0B41D040hC01TG6P0=2`h030X;00/92P8030/902/03@`:00l>300=2``02`X800/92@0;2@X02`X8
00P71P081PL02`X8018@400I5aP071XK00h<3@0=2``030X;00d;300=2`h03P`?010>4@0@2`l050lC
00h93@0L5a/020<701<A500@3Q402`T<00`:3@0=2`h030X=010>4@0B41<03P`?00T72P0=2`h03`d@
010>4@0C4A@040hA00T72P0<2Pd03`d@008030X=01803@/>00l=400@3Q402PP;00h<3`0H5QT04a4D
00H41`071@X02`T>018@5@0@3A@0514H00d:4@060`X04Q0G00`;4`0C4QX201DD6P0=00h=4P0D4aP0
4A0E00h=4`0?3Q@04Q4I01@B6@0D3aD05@hE01<?5P0B3aH04PlH014@6002018A6@0C01@A6@0D4AP0
5a8H01PB600F51T03PdC00l>4`0=314030/@03De=`0F5QP05ADG01@D5@0E5AL05aLG018B4`0E5AL0
5QHF01LG600201LG6@0401HF600E5AL061PJ01LG6@804a<E00<05QHH01LF6`0D4aP00P0C4QL00`0B
4AH03`hC01PG700201DD6@8061LL00P05A@I01<A500C4A@05Q@G01TG6P0H5QT04a4D01DC5P804a4D
00/0518E01<A500?3A00410B01<C5@0?3a4051@F01XI6`0A3a804a4D01DB5@0201LB5P0801HA5@0E
41@061@E01PD5@0E4A804`l@01TE5P0N6Q/601@@4@<05a<B0140510?010<3@0>2P/05A4B00h93@0@
2`l04`hB01HA5@0B3A404Ph@01hJ6`070`@04@d>01PD5@0I5AH040`=014=3P02018>3`09014=3P0@
2a003`X@014<4P0B3A<04@`B00l:400@2a404@`B00804PdC00T02PD;01PC6@080`T03`P?0109400>
1`h02`@;00l83`0D3A@00P0A2Q406P0@2A003`P?00l83`0A2a804@`B00l:400@2a404@`B014:4@0C
2a805@/C01@:4P0A1`l03P@<00h2300D2A403@8801D:400J3aD01`0201<93P0B1`d05``B03H]<@0A
1P`050T?1`0?10X0600900@04@H<01<83P0?10X04@H<00d2200>0`/040H>01P>5P0N4a/0714I01@9
4@0;00P05P/C00/1200G31@05P/C01053@0I31<0200201062P0I31<04PL<01442`8040<:0P0>0@P0
2P0C1Pd060/B00d2200C20h01`0200`11`0M4QP02P050146300@1@/200l42P803P<95?ooool001_o
oooo00`04PlF00h;4@0E4QP0:BH]00l=4`0=2a003@XA00/93`0=2Q003``C00l=4`0<2Pl2018B500=
01TI6`0>3Q003`h@018@4`0?3A003@T=014<400?2Ph03PP<018<400B3Pl04@d>010=3P03010<3@0<
01`H6@0?2``03`/<010<3@0=2@X03PX;018>3`0@30d0Ee=D03Pd=@0A3@h05A4B0P0?2``02`0@30d0
4@d>014=3P0A3@h04P`@018;3@0A2`d04@`;014;2P0A30T04Ph<008040`=01d040/@010=4`0>3180
2``>01<D4`0>40/05aX?03/n<@3Gfl`0GF5D01DG3@0@4Pd02P`;01@D5P0A41@08AlS01lM8P0?3A80
4@lC014?500C4AD030X>00l=4P0@3Q80518F0040100>30h04A0>020O7@02010?3@0300P71P0@3`d0
3`h<00@03`h<02P040d<014=300A3@`03PX900d9200?2`X04`l>018>3@0A3@`040`;00l;2P0>2`X0
3`h=014A400;2PT02@P8018A400=30`03`h=02l_;P0M7A`040l>014@3`0;2PT03`h<00H50`0>3@/0
20L500/:200=2@P04@`<018<300>20P040P901H=3P0D3@d0:BDT01TH5P0?3P`040l=0P0=30X300`;
2@0400h=2`0K6QP0:2LU00`;2@<03@`:0P0>3@/04`0E51808B0N0040000A40l03P`<02PW:01ZJW40
UYFM024Q9P0=3Q402``;014A3`0>3P`03`l>00d=3`0=314030/B00P73@0<2Pd00`0=2``200h<3@0=
00l=3P0>30d03@/<00d;3@0<2P`030X=00d:400C41L02PL=010<4P0<20h03`/B00h;4P0200`93`08
00d;4@0>31803P`A00`:3@0:20/03@/>010>4@0=2`h300/9300B018@4`0@3Q404a4D00D31P0=2`h0
4Q0C00810`0A3a802@L:00h<3`0F51L04a4D00`:3@0=2`h02@L:00`9300>2@d03`X>0P0@2`l06@0>
2@d040/?00`82`0G4QH02PH900`72`0B3A4030L<00l:400A318040/A00l:400@2a403PT?00d83P0A
318040/A00/6300B3A<0;2L]00T42P0L5ad03@T>01<>500;1P`00P0@2a401@0<1`d040/A00h93`0O
6R004@`B00803`X@01`0100500`73@0A31802PH;00`73@0D3aD03`X@010;4@0?2Q0030L=014<4P0@
2a403PT?01@?5@0>2@l04PdC00l:400=20h06QDK00T42P091@/03P`?00T92`0B4Q@03@d?00P82P0B
4Q@03`lA0P0>3Q0200d=3`0700l?4@0=2`h03`d@00h<3`0=2`h03P`?00l=400200X82`0=00l=400<
2Pd03`d@02PV:P0_;3403PT@00d9400S7RD03`XA00h9400=20l04`hE018=500200h9400601<>5@09
10/040/B00L32@0G4QT03@P?0P0?2Q407P0@2a804@`C010;4P0?2Q4030L>00/63@0>2A002@@;010<
4@0@2a804@`B00d83`0?2Q404@`B018=500A31<03``D00/;5@0A4Qd01@L@05UHH@0f=S`04Q8G00X9
300<2`/02@P800l=300A40d03P/9018<3P803@L90P0A2`d0100?2@/03PP:00h82P0?2@/3010:3007
014=3P0?2`d03PX;00h92`0>2@`03PX<00h:2`0200h:300800h:2`0>2P`03`X>00l:400>2@l03@P>
00h93`0?2Q0200h93`0=00`73@0>2@l05a8H01D@5P0>2A0030L?01<=5`0N6B8030L?01@>600910d0
3PTA00h84P02010:4`0400h84P0=20l03PT?00h940<03PT?01<03@P>024L8P0J5A/03@T>01hI7`0E
41H04`hC00H11@0A3100If9W030[;`0A31003`X?01D@500J5AT04@`A00`72`0=20`040X=00803`T;
01X03PP:00l92`0@2P`03PP:00`6200@2P`04P`>00l92`0?2@`03PL=014:4P0T72P04@TH01@<6P0?
2A004@`:01D@2P0C3`H05A09014=200B3P/040`:00/71P0@30/04Ph=00h:2@8040`;00X0:bLV00`8
1`0B3Pd030P700h:2@091@H04`l@01HB4`0A3@h030P90P0=2@X03@0>2P/03`/<00l;300>2P/03@T:
018>3P0?2`X03`d;01@@3`0F4Q404`l>014=300@30/00P0>2PT01`0@30/04@d<01PD5P1^JF`050lB
014=3`0>2P`00P0?2``300h:2`0400l;300?2`/04@d;010<2P803`/800@03`/900l;200?2`P03`/9
0P0@30T01P0?2`T03PX8018>300A3@/040`:010<2`803`/;01004`h?010:300D3Q005@dB018;3`0C
3A403``?014?4P0=2`h03`d@00d;3P0C4A@02`T<00l=400>30l04@lB0P0>30l01@0:20/04Q0C010>
4@0?3A0040hA00803`d@00D040hA01@B5@091`X061HI00h<3`0500l=400f010>4@0B41<030X>00h<
400F51P04Q0D01DC6`0F5200518M014@5`0@3a@0410A014A4P0A4A<04A0E014@600B41/04a8L01@B
600@3Q<04Q4F01LF6`0B4AL03`hC01@C600B4AL040lE018A5P0D4QL04a4F00d<4@0A41D05A@I01@C
600F5AX06QTN01DD6@0K6Ql04A0E01hM8P0G5QX04Q8E01@F5@0G6AH05QPF018D4P0C5A<071hM00h?
4@0?41805aPJ018C5`0E5QX03a0D0P0B4AH201<B5`8051<H01T03`hC01<B5`0G5Q/05aHK01DD6@0A
41@05Q@G01HD5@0H5QL05Q@E018@4@0F51D0518C01TG600J61T05Q@E018@4@0A3a005Q@G01LE600D
4QD04Q0C014?4P0C4A@071XM00806QPK00@04@lB01PF6@0F51L04a4D0P0E4aH201@B5@0I01HD5`0A
3a803`d@00l=400O7B003P`?010>400F4Q<04Ph?01DA4P0C3a004Ph?01HB4`0A3@h040`=01LC500A
3@h0510A010<3P0C3A4030H:00/62@0D3Q807QPL014;3`02018<40804`dA00L04P`@01093`0A2a40
9AhU01dF7@0?20l04``C008050dD0P0C31<0400B2a8040T@014:4@0=1Pd0614H00h83P0>2@h06Q<J
03hg?P0C31<02P@:01@=50090PT05a0G00d7300@2Ph201@>4P0D014;3`0@2A0040T@01094@0=1Ph0
4``D00d63`080@X04PTA00d22P0C210040D=01T>5P0>1@/05P/C00`22@0=0`X0714I00/1200A1`h2
010330804@@=00T04PD>01<63`0>0PP04@@;01<63@0A1@T040@801462`0?1Ph00P0>1`h301063P80
3`D=01803`@<00l22@0@0`X04@@;01052P0A10/03`D900`01P0Q5A/0>Rdd01032P0?0PT03P480103
2P0D1`h05`XA0146300@1@/200h32@803`@:00H02`8601L<4P23N7h0=2T_00d3200C20hDooooo`00
6oooool02@0610T04@lD02XX;@0@3Q<08R0U01TG700>31403@/@00h<4@02010>4`0@00d;400>3Q00
ATI80;Ng^@0/;2h04a8D010>4@0<2Pd03P/>014<400=20`03PP<01<=4@0>2P/03`/<014=3P804Ph?
00T04@d>00d92P0@30d04`l@00l;300>2P/04`l@01DA4P0400400P0:1PL01@0L61T03PX;00l;300?
2``040`=00<04@d>00@03`X>010:300@30d04@d<0P0B3P/0900A30T04@/=014;3@0C318050dE01<@
5P0;2`d05QHF00d>2@0A4`P08bDH08V;O@18BS`030h300/<1`0C4a<04Q8D010?4`0;2@`020H900`:
3@071@P04a4D05IDE`0A3a800@0204U7BP0n?3l06aTL028P8P040`401@@200d<2P0N7A/040l=00`;
2@D03@`:00D03``;014=300@30/03PX900d92007010<2`800@0001d0;bh/00L6100D4a403`h<010?
3@0A40h03@`:00L6100?3P`030/900l>300<2`T051<A01TH5P0@3`d03@T8018<300C3@d03PP800`3
100@1`P03`P8024M700C4Q0020L500T81P0:2@L030/900h=2`02014@3P0400h=2`0<2`T02`X800`;
2@803@`:0`0>3@/050040`403Pd;00T81P0B4@l03Pd;00l=3P0000@04a8H00H52P0?3a402@T801<D
3`0>3`X03Ph=00`<3P0:2@h02PT?00`;4@0?3A003`d>0P0=2``00`0<2P/02`T:00`:2`0300d;3009
00h<3@0>30l03@/@01PF6`0=2a0040hC00D320081P/02`T>00803`dB0P0=2a004@0@3Q<040hA00X8
2`0I5aX01`D800400P0<2Pd02@L:018@4`081PT00P4301<A500P7R4040hA00P62@0E4aH03@/>0080
4a4D00H04Q0C00l=400;2@`03@/>00T72P0?2`l3018=4@0<00l:3P0>2@d03`X>00d8300300802`L:
01@?4`0@2`l03@P=00l:400A318040/A0`0>2@l00`0<1`d03`X@018=4`0200`73@0h01XE6`0G4QP0
0`0402DP9P1hLgT0;RT_00L3200E41H040/A00X52`0?2Q002`H<00`73@080`T06A@J020K8@0F4AL0
40/A00`73@0L5ad02PD;00H11`0@2a403`X@00h93`0?2Q0030L=00/6300B3A<02PD;014<4P0C3Q@0
2PH;010;4@0;1P`040`B00400P092@/01`L900d=3`0?3a402PX<00h>400?3a404Q8D014A4`0?3a40
30`>00l=400@3Q403`d@00d;3P0<2Pd03P`?014?4P0;2@`2014?4P0900X82`0=2`h03`X@01@=500:
0`X04``C01PA600B2a803PL>00804P/B0P0?20l0200C31<050lE00`73@0D3aD020<900d83P0H4aT0
3`X@0`0@2a400`0?2Q003@P>00T42P0200h93`0301LB600;1P`05Q4G00803PT?0P0?2Q003`0>2@l0
2`P?00H74P072Q<0I6M`01HF7`0G5Q`02@P=00h>4@0;2@X030X;01LF500G5Q8040l;00l92`0200`6
200300l92`0>20X03PP:00804@/=100@2P`300`82@0:00d92P0>2P/040`=010<3@0?2``03PX;00d9
2P0<20T03@T<00`73@802`H<01D03@P>00l:400A31803`X@00h93`0?2Q0050lE01<>500A31@040XD
00X43P0A2aD02@<=01PB700=1a4030H@010:500?2A<02`D?00`6400=20l01@0=20h0300:1@/0>SDk
02lZ<00300@040/A018=4`0?2Ph02@@800P31`0O6Qh030L;00h93@802`H:00@03@P<00l:3P0?2Ph0
3@P<0P0A2`d0:@0@2P`03`T;010:300A2`d03`T;00`6200?2@/04P`>00h82P0@2P`04@/;01@>3P0L
5A/02`@<01PA6@0B3@d05Q89028O400_;1T02`P0018?1P0K5`h04@d:00l;2P0>2PT030P700X61@0?
2`X03@T801XF5@0<20L0510?00T5100<20L02`L800h:2`0?2``03PX;00`82@0:1PL03`/<00@040`=
00T03`/<00l;2P0>2PT03`/:014=300C3`h04@d<00h:2@0?2`X00P0@30/02@0?2`X03PX900/7200L
61T01`<4010<3@0?2``04@d>010<3@0300l;308040`=00H03`/:014=300B3Pd040`;00d9200;1`H6
00l;2P<03`/801X03PX900h:2`0>2P/03`T;01LA5@0F41@04`dA014;3`0?2@d04@dA00d;3P0;2@`0
3`d@00<110040`D05A<F01<A500<2Pd020H900@21@0B41<0:BLZ00X82`0?3A002@L:01DC5P805Q@G
00D05A<F01<B500200<071XM01@B5@0500l=400D010>4@0B41<040hA01dK7P0G5AP02`T<018@600B
41d04Q0K018A600A41D0410B00d=3`0?3a404Q4G01@C6`0C4A`04@lK01HE6`0A41D200l>4`0300d<
4@0A41D04Q4F00804A0E01/051<H01DD6@0D4aP05A@I00l>4`0B4AH03@`A00l>4`0/:c00D4mD018A
5P0O7R<0DU5F020O900G5QX04Q@C01DG500G6AH04Q@C010B4@0B51<05QLI01DF6@0G61`03PlC01DF
6P0G61`00P0B4AH301<B5`0;01@C600C4QL051<H01DD6@0D4aP04a8G018B500H5QT04@l@01<A4P0F
51D00`0C4A80400F51D05A<D01<A4P0B41404a4B01HD5`0E4aH04@lB010>4@0C4A@061HI010>4@0F
51L07adP01DC5P0G5AP2018@4`805A<F00L04a4D018@4`0B41<04Q0C010>4@0B41<071XM00803P`?
01805a<D01DA4P0G4a@05A4B01<?400E4A80920Q01XF5`070`@04@d>010<3@0Q7Ah05a4E01H@5009
0`L03@L;01@>4P0C3A42018<40804`dA00P04P`@00/62P0T7B@0`K[106eVK@0700L04P/B00l83`80
4@XA02L04P/B014:4@0?20l04@XA00/42`0?20l050dD01<<4`0700L05a0G018;4P0;10/03`P?020I
800>1`h03PP=014;3`0B31004@/?00h8300=1Pd04@XA01L@600D3AD0610J018:5@0;0`h050/D038W
;`0h;CD03@8:00/0200J3aL04`P@00`12@0D2A405@XB01dB6P0D2a400P0B1@l301443@070103300;
00L040<<01D83`0B1@`04@@;01L;4@0301063P<04@H>0P0@1@/300l42P0901452@0<00H03`8901<6
3@0D1`h05@P?01L:4@0@0`X03`8900803P4800<04@@;0185300?10X00P0?10X02@0@1@/04PL=01<8
3P0B1`d03PD902<H7P0E2Q003`@:00L00P0Dooooo`006oooool01P0B41D02`T>01DC600100@02`T>
00d;408030X?01403@/@00h<4@0>314030X?01DE5`0o?d40Zj^]01<C5@0=30h03`d@00X82`0?30l0
4@`@00`72`0>20`04`dA014=3P02010<3@03018>3`0C3a00510A00804Ph?00X0510A010<3@0=2@X0
4@d>00h:2`091@H05a<D014=3P0B3Pl02PH70P0?2``0100@30d04@d>014=3P0A3@h200d;3P0K00h<
3@0B3Pd04`l<01<?300B3@X04@/;010:300A2`l04P/B01D@5`030`D02PP9018B3@0G6@h01`L001`N
400F60/030`201<C3P0>3Ph020H900L52@0A3a806aTL01DC5P0B41<0518E00805A<F00T08R0S00d;
3P071@P040hA00H41@0:2@L01`H401@C4@0100000P0@3`d500d<2P07010=300C3`h04`l>014=300@
30/04`l>00l;2P04010<2`0U014=30071P@040l=0450?P0=30X020L500l>300E518040l=00h=2`02
0@0040l=00h=2`0920H04Q4?00X91`071P@00P4001@@3`0=1`L040X:01<=3@0J4A8071<D00l8200;
1`H02`X8018A3`0F5A<051<A01<B400>3@/04A0>01<B400B4@l03Pd;00/:200200d<2P803Pd;0P0?
3P`200h=2`0B01@C4@0E51805A@B00/92P0>3A802`X?00h>400@410020P500h?2P0=3PT02`/800l?
3`0A4A<03PdB00X93P0>30l03P`=0P0=2``400`:2`0Z00d;300>30d03P`=00l=3P0:20/0108700P6
2@0:20`05Q@I00d;3P0;2@d04Q0E014?4P0;2@d02`T>00h<3`0@3Q402`T<01/I700A3a8040hA01@B
5@0;2@`04@lB00d;3P0L6Qd040hA00X82`081PT05A<F00h<3`0<2Pd0518E00L5200>30l03@/>00/9
300>30l02@L:00`9300<1`/03@P<100>2@d02P0910P05A0D00T5200M61`030L;00h93P0C3Q@050lE
018=4`0@2a4200l:400300X52`0910X03PT?00803PT?00P02PH;00l:40080`T05A0F02lZ<00400D0
4PdC01@?5@8030L=02404PdC00l:400;1P`040/A00d83P0300@04@`B010;4@0C3Q@05a8H00H21`0H
4aT030L=00`83@0>2@l030L=00/6300D3aD07APN00`73@0?2Q004`hD00X52`0A31804PdC01<?5@0I
5aX071`N00H6200;2`d04Q8D00/;3@0?3a400P0@41808@0?3a403@d?00/;3@0?3A0040hA00l=400<
2Pd02`T<00`:3@0J61/020H900T72P0B41<040hA00`72`090`L050hC010:3P0A2Q4040T?00L11@0?
20l04P/A014;3`0?20l03`T>018;4P0E41H03@P>02PS:@0<1`d040/A01LB6002018=4`804@`B00P0
40/A00l:400K5Q`050lE00H11`0:1P/07APN00d83P<03PT?01003@P>00`73@091Pd02P/F02@W<00b
=Ch0000700X93`0<2a402PT=00X82`0=2``05Q@D01PG5@0G4a803`T;0P0>20X200l92`0500h82P0A
2`d04@/=010:300?2@/00P0>20X07P0>2P/03@T:00`82@0=2@X03PX;00d92P0<20T03@T:00h:2`0?
2``040`=010;3`0>2@l030L=00d83P0?2Q004`hD018=4`0=20h030L=00d83P0?2Q003PT?00/63@0=
1a401`4;018<5P070@/03PPB00X43P803PPB00@030H@00T33@0:10h03@P?1@0?2Q002@0=20h06A@J
01PC6@0:1@/03`X@018=4`0;1PX03@P<018=4@0200`72`0900h93@0=20`03@P<00d8300>2@d040/?
014<400A2`d040X<00<03`T;02004@/=00l92`0<1PP03`T;014;3@0>20X040X;01<>2P0E40`050h?
00@00P0E3a4040X7010<0017A340XIn704A2;@0N6`T040`1010=200@30/03`/:00d9200?2`X05Q8A
00d9200@30/03@T801DA400:1PD03@T8014=3P803PX;0P0A3@h00`0=2@X03`/<010<3@03010<3@04
00l;300>2PT03PX900l;2P<040`;00l03@T800l;2P0A3@`04@d<00l;2P0=2@P03`/<00D10P0;1`P0
3PX;010<3@0>2P/04@d>010<3@0?2``00P0@30d01`0A3@h03`/:010<2`0A3@`040`;00h:2@0=2@P0
1P0?2`X300h:1`0<00h:2@0>2P/03PX;010:300D3Q803`T=014;3`0D3Q8040/?01@B5@081PT02PP;
0P0=2`h04`0D4QD040hA00T72P0B41<03@/>01PF6@0k>C`0IfEX02LU:00K6A`00P0300h<3`0@3Q40
6aTL00L5200E4aH04a4D00d;3P0<2Pd01@0@3Q405@0<2Pd03@/>01HD5`0_;C0081hQ00/9300@3QH0
40hI014@600C4QT04Q4F014A500?3a40410B018A5P0C4QX04Q4I014?6P0H5ad04A0E00l>4`0301DD
6@0O00d<4@0@3a@05aHK01`K800J6Ah04a8G01TH7@0100D05A@I01TH7@0G5Q/0O7^00>;QiP1FEEX0
5A@I030_=00;2Pl06APL010B4@0B514051HC018D4`0A4a804aDD01XK7@0F5aX06AXN01<D600J6al0
6AXN01DD6@0601HE6P0601DD6@0D4aP04a8G01<B5`0C4aD05A<F0P0D4Q<2010>3`0G01XH6@0D4Q<0
4a4B018@4@0A3a004a4B01DC500C4A@06ALJ01`J7@0J61/05Q@G01@B5@0@3Q404Q0C01LE600@3Q40
6ALJ01LE600B41<05A<F01HD5`0C4A@00P0A3a801`0E4aH040hA00l=400@3Q403`d@01@B5@0C3a00
0`0A3@h03P0C3a005A4B00X71`0K5aP04Ph?01@@4@0<20T02`L800`62P0400809AlS01D?4`0F41@0
2`D90P0B310201<=4@08018<400F3aD0100402LP9`0?2@l07QLN01XC6P0A2Q42010940804@XA0180
3`P?0109400>1`h030D<01H?5P0G41L02P<:018;4P0G41L0614H00T22@0@2A001P0601<=4P0A2`l0
4P`@00l93@0<1PX200`5300E014:4P0600L01@07018:5@0C2aH030D<00d22P0O51`060dE01T>5P0A
1Ph04`P@00T01P0E2Q802@0600l4300;0PP04`H@01853`0B1@h04@@=008040<<00H04`H?01P;500K
3QH050L@01032P0E2A4301053@0401443@0@1@d040D=01052`<03`@:00<040D901862P0A10/00P0A
10/00`0@0`X0304600P00P0201032P803P4800<03`8901032P0?10X00`0?10X0200A1P`04PL=0105
2`0<0`L01`0200P00`0@1@/01`025?ooool001_ooooo00L0OWb1034_=0081P/05aDJ00h<4@0B41D0
3P`A008040hC00/03`dB00h<4@0>31403@d?00l?4@0E5AL0410B00h=400?3A003@/>014=4@02010;
3`0D018<400A2`l061@E018>3`0?2``040`=01<?400F4Q<04`l@00d92P0@30d04@d>00l;300@30d0
4Ph?00l;300@30d03@T:018>3`0A3@h200l;300^010<3@0A3@h04@d>00l=3`0<3A003@hA00h>3`0A
40h04A0<01<@3@0C3P/04`X;01892`0B2@h04PP@01<;4P0?2`l05A4B00h;200=2`@03``2018@1P0K
6@l06AH>010=2P0=2P/03@P<010>4@0F51L07adP018@4`0:2@/0:bT/030_<@0G5AP01`H8010>4@0D
4QD03P`?018@4@1VIF<051<A014@3`0=30X05QDC014@3PD03`h<00<040d<014=300B3Pd00P0@30/0
0`0C3`h040`;010<2`03010<2`08014=300:2@L04A0>038a;`0D4a4030/9010?3P0920H200d<2P0K
00P71@0A40h03Pd;00D40`0F5A<04A0>030_;@0M71X040`;018<300@2PX04@/;020G600W7Ql06a<D
01@@3`0>3@/03`h<01/J600I61H01`H400h=2`0<2`T02`X800`;2@0=30X030/900<03Pd;0P0?3P`0
2`0@3`d04Q4?00L6100>3@/030/901@C4@0A40l02PX;00/;300<30/02P/700802``700H08B8M00h?
2P0;30P0410?00h>3`0<30d200`:2`803@/<0P0?3@h00`0<2P/03@/<00d;300200h<3@0@00l=3P0[
:BX01@<5010>3`0B4140BDM903Tg>00>30h04Q0B014?400;2@X02PP:00`:300A3a800P0300`:3@80
;B/^00D040hA00`:3@0A3a801P@702PV:@02014?4P0?00X82`0E4aH020H9018@4`0>30l0518E00`:
3@0=2`h02`T<00l=400:20/03P/>010;3`0?2Ph03PT=00803@P<00X03`X>01HA5@1ED5@040`?01LB
5P0910P04@`A010;4@0B3A<04@`B0P0>2@l0EP0?2Q003PT?018=4`0J5A/05A0F00l:400>2@l04@`B
010;4@0>2@l030P=00H21`0A318030L=00X52`0M61h04PdC00`73@0=20h04`hD02/V;00H4aT06QDK
00d83P0?2Q001@0601@?5@16@DL071LM010;4@0A31803@P>010;4@0T7bD0;bX`01HA5`0?2Q004`hD
00l:400B3A<040/A014<4P0H5aT02`/=00d=3`0@41803Ph@014A4`0@41803`lA00/;3@092@/02PX<
00`<3P0A3a804a4D014?4P0?3A003P`?00l=400<2Pd06QPK01dK7P0A3a802`T<01LB5P0O6A`04PT<
01L>4@0B2@d03`H901L>4@0A20`04PT=0189300A20`04PT<014:3@0<1P/03`X@02/V;00F4AL03`X@
00`73@0@2a403`X@100>2@l02@0B3A<040/A010;4@0F4AL0XIbR03`g?@0?2Q003PT?00d83P0200`7
3@0>00X73@0L72D0<30j00P84@0;2a<03`lD00`;4@0;2@h040hA010>400=2@T03PX901@@3`0@2P`2
014;3@<040X<0`0?2@/0200>20X03@L900d72@0C3a004@d>00l;300>2P/03@T:1P0>2P/01@0>2Ph0
3@P>00d83P0=20h03`X@00804@`B00<03PT?00d83P0?2Q000`0=20h02@0B3A@01`8901HA600@2a80
4`hE00l:4@0=20l030L>00d83`0200h9400300l:400>2@l03PT?00<03PT?00l040/A00d83P0>2@l0
40/A00d83P0?2Q002`H:00d8300B3A401`86014<400@2`l03@P<010;3`0A31000P0<1`/06`0A3100
3`T;00l92`0>20X03@L900h82P0?2@/040X<00d72@0?2@/040X<00h82P0A2`/03`/200h:0@0@2`H0
2@@201LB3`0I5@`0?3TW09jLQ03moN40V9Ml02LU4@0A3@<04@h9010<2`0200d920804@d<00T040`;
00`81`0?2`X04Ph=00h:2@0?2`X04Ph?00h:2`0?2``00P0B3Pl00`0?2``03PX;00l;300300l;3004
00h:2`0>2PT040`;010<2`803`/:00<040`;00h:2@0@30/00P0A3@`02`0@30/03PX900l;300?2``0
4`l@00/7200A3@h03@T:014=3P0@30d03`/<008040`=00<04@d>018>3@0?2`X00P0>2PT0200?2`X0
40`;014=300?2`X03PX900l;2P0@30/04@d<0`0>2PT0100?2`X03`/<00l;300B3A4201<>4P04014<
4P0=20h02PL<00h<3`804@lB01D01P@702HT9`0k>C`04Q0C00`:3@0Z:2/040hA00l=400:20/08AlR
00P62@0H5QT02`T<010>4@0H5QT00P0301LE600A3a801`D803Le>00@3Q401@0A3a802`0C4A@04@lB
00X82`0F51L04@lB00X82`0B41L03P`G010?5`0C4QT04a8G00804Q4F00`04A0E010?5@0@3aL04A0H
01@B700A41H03`hC01hM8P0_;S<0:BP]01@C600B4AH2014@5@0K01@C600E51T051<H01dL8@0=3140
5QDJ01<B5`0B4AH0DE1E09bKX00l>d006APM01/J7`0<2a005QDJ01LI6@0F61L04aDD014B500B4aD0
51DG01DF6P0B4aL06a`P01PI7P0J6b00414F00805aHK0`0F5AX00`0E51T05aHK01HE6P0301@C600;
01DE5`0I5aX04a4B01dK700V92D071XK00h<3@0E4a@04a4B014?400B41400P0E4a@03@0G5AP06QPK
01TG6P0F51L0518E018@4`0G5AP061HI01`J7@0C4A@05aDH01@B5@0C4A@00P0E4aH201@B5@0;01DC
5P0A3a804a4D01TG6P0C4A@05aDH01XH6`0M6AX05a<D014=3P0B3Pl00P0F4Q<0300H51D06QHG092<
S@1fLW<07a/L02DQ8P0D3a80=c4e085kO`0G4AD0;BL[03li?@804P`@0P0C3A401`0B310040T?01H?
5P0D3A@05a0G01<<4`0G41L00`0@2A02018;4P0V0109400>1`h06A8I0109400B2a803@H=00l83`0F
3aH03PL>00/52`0D3A@02PD:010:400C31804@/?018<400@2Ph03@L;00d63@0@2A403`P@00l:400@
2A80200;028L9@0g;CH03P<;01D:4P0800D060dE06=HH00M4QX03@<:01D:4P0B1`l05P/C03db>P0B
1Q0201453`8040@>00L03`<=01<74@0E2A<05P/D0186400?0``040@?00804P<>01004P<=01<33@0B
0`d04P@<01442`0@0`X040@801052@0A1PX04`P;0185300@0`X03P8801032P0A1@/04PP<0`0@0`X3
00l22@030146300@1@/03P<900<03@8800H03`@:020E6`0>10T02@0401062`0@1@/Dooooo`006ooo
ool01`0H5QT03`d@00d;3P0F51L03@/>01XH6`0?3A000P0B41<04@0?3A003P`?010>4@0I6A/03@d?
014A4`00008040lB00l=400A3a804PhB00l:3P0E41@05Q0D00l93@0B3Pl04@d>008040`=0P0A3@h0
200=2@X040`=01DA4P0B3Pl03`/<018>3`0@30d071PI0P0C3a001@0B3Pl030P900l;300?2``040`=
00804@d>00D03`d@00d?4`0<41<03PlA00l@3P02010?2`0D014<2@0C2P/050/<01L<400J3A@05@/@
01H@500A2`d06QDC01/F4P0F4@/04Ph6018=1`0C3PX04@/:01@>400A2`l02`L;00/92P0:20T200/9
2P0>00X82@0<2P/07Q`M00800@0F51D01`D600<10P0E4a<051<A01HE4`0<2`X00`8007QgM@1PGed5
00h=2`0300h;2P0>2PT03`/:00803@T800D04@d<018>3@0A3@`04@d<010<2`0200l;2P0B01dL6P1<
BdT0QhJ403Th=P0>3@/02PT801XI5`0A40h020L6028Q7`0;2PP03Pd;01TH5P0A40h051<B04E4@P0A
40h03PX90P0>20P0400;1@D040L801H=3P0D3@d01@4000l>300A40h01@@200d<2P0G5Q@051<A00l>
300<2`T03@`:00l>300=30X200h=2`803`h<0P0@3`d04P0I61H03`h<00d<2P0=30X02`X8010?3@07
1P@040l=00h=2@0D4`l03Pd900h=200Q81/04Q4<010?2`0?3PX02PT7018@4@H03@/<00@03P`=00d;
300=2``03@/<0P0<2P/01P0D4a401`H400l>300:2@L05aHD00T81P803@`:01l030/900d<2P0=30X0
3P`=00d;3P0B41<03P`?00`:3@0?3A002PP;010>4@0=2`h06aTL075_LP0X9RT00@0203Pf>@081PT0
3@/>00`:3@0B41<01@<600d;3P0>30l03@/>00l=400:20/04@hA01D@500C3Q8040/?00<03PT=00L0
20<701D@500?2Ph05a8F018=4@080`P030L=00803PT?0P0<1`d02@0?2Q0040/A01<>500I51X04PdC
00l:400C3Q@040/A01@?5@02014<4P0:01XE6`0<1`d04@`B014<4P0K5Q`050lE00d83P0F4AL030L=
01/F70802PD;01X03`/@01dH7P0D3aD030L=01<>500E41H03@P>00`73@0=20h03`X@01D@5P0M61h0
3PT?00l:400@2a403@P>00L2200:1@/0=c8h0<6o`P1<BTd02@L:00800`071@P040hA00h<3`803@/>
0P0<2Pd0100=2`h02`T<00d;3P0<2Pd200/9300>00`:3@0?3A00:BLZ02XX:`0I5aX03`d@01`G6`0J
4A@06a4B03@Z:`0U6a`04@T900`20`0C2@X301882@0:01<92P0A20/05a4E018=4@0400<03@P<00`7
2`0F4AD040/?00l:3P8030L;01/03@P<00h93@0@2`l03PT=018=4@0G4QH05A0D01/F6P0@2`l03@P<
00`72`0=20`03PT=00`:3`1_KWH0AdM?00L73`0B4AP04a0G00X73P0C4AH05A0D01LB5P0?2``03@T:
01<?400>20`00P0B31000`0?2@d03PP<010:3P0200h830@03`T=00<04@`@00l:3P0>2@d00P0=20`0
2@0?2Ph040/?00l:3P0>2@d03@P<00`72`0<1``030L=00d83P0200h93`0D00d83P0>2@l030L=00d8
3P0@2a4030L=00d83P0:1P`04PdD00X5300O6R4050lF00P32P0400H03`XA01TD6`0F4AP02PD<00/6
3@0>2A0500d83P0>00X52`0@2a404@`B00X52`0>2@l05A0F00l:3P0<1`/02@@800`72`0=20`040/?
00`72`0=20`300h93@0300l:3P0@2P`03`T;00<03PP:01l040X<014;3@0=1`T03PP:00l92`0>20X0
4@`;00h:00091@0050l8018=2P0D3`/07AT@020M2P13@BX0_KbP05ME?00L6PH01P80010=200=2@P0
2PH500l;2P0D40l02PH5014=300@30/03PX900X61@0@30/03PX900803@T:00D03PX;010<3@0@30d0
3PX;00l;3004010<3@0400l;300>2PT04@d<014=30803PX900<04@d<010<2`0?2`X00P0>2PT02@0?
2`X040`;00X61`0E4A803`/<00d92P0<20T040`=00l;300300h:2`803`/<00<04@d>00l;300?2``0
0`0>2P/01`0A3@h03PX;00d92P0>2P/040`=014=3P0>2PT00P0?2`X05`0@30d040/?014<400;2@`0
3@/@01<A5P081P/03`dB02<Q9P0B41<03@/>01DC5P0<2Pd00P0300H41`0W9BP03P`?01dK7P0610L0
3@/>00l=400>30l02`T<008030X=00P040hA00/9300I5aX030X=03Tg>P10?T407Q`O010>4@D04@lB
00L04Q0C01@B5@0?3A004a4D01@B5@0<2Pd03P`B00803`hF00<040lF014@5P0C4QP00`0@3aD2014@
600401<B6P0G5Q`040lD00l>4`8051<H00T05QDJ01@C600B4AH04A0E01<B5`0D4aP04a8G00l>4`0F
5AX00P0H5a`0500N7B806QTN02<R9`0B4AH061LL00T83@071P/04A0E01LH6P0F5aT05AHH01@E6@0C
51P04Q<G01PI7P0G61d061PP00`<500B4QX05QLL0P0G5Q/00`0F5AX05A@I01DD6@0201@C60@05A@I
00d05ADG01XH6`0C4A807A/L02HT9@0N71d03`d>01LE5P0D4Q<04a4B01DC500F51D04a4B00805aDH
00X05A<F018@4`0B41<0518E01DC5P0F51L06aTL01@B5@0M6ah06aTL100D4QD06P0H5QT06aTL01/I
700:20/05A<F01@B5@0G5AP03@/>01HB4`0E4A8040`=014=3P0C3a003`/<01<?400L61T0WYZK08N3
Q00?2``0510A02@N8P0500<0<2X^00h8300D3Q8020860P0B310201<=4@07018<400H4AL03PL>01XC
6P0?2@l0100400T22@02014:4@0B0109400B2a804``C018;4P0=1Pd08Q/R01D>5@0?20l01`0701XC
6P0T7B@0>34h014:4@0U7RD02P<:01TB6@0<1P/040X>0P0C3A40500@2Ph03`P?00h73P0=1Ph05@hF
020H8P0400L01`0:02LN9`0=0PX05``D01<8400<0@T04PT?02@I8@0I3QH03`@<00T01P0700@071<I
0P0?0`d301043P0701454@0@11003`<?00l33`0C1a<050PD01<64`0201H44P0401H44@0F11005@D?
01D53`8040<:00`04@D90147200B20T050X;01@73P0B1@`03P4800`01P0B1@`060/B00l22@0@0`X3
01442`0301032P0@1@/03`@:00803P<90P0?10X01P0L4AL0@CHl0146300:00D0304700X01ACooooo
000Kooooo`07010>4@0>30l04Q0C00`:3@0?3A000`4400`:3@02010>4@0L00d;3P0<2Pd03P`?00T9
2`0>3Q005aLI00l?4@0A4A<04Q0C01<A500A3Q403PT=01PC5`0G4AD03PP<00/7200?2``04@d>018>
3`0?2``03PX;00l;300J5QL07ATJ01<?400>2P/04`l@010<3@80510A00<040`=00X61`0D41400P0?
2``0700@30d04@d>014=3P0?3A003A4E00`?500<41<03Q0?00l?3@0?3PX040`9018<300E30d06PlC
01lB6@0G3A806Q@H00d72@0@2P/030L400d8100E40/04Pd901PC400B30d04@/=01LA5@0B3A02018@
4@0@00d;300>30d04Q0A01DC500l>S/07adN01<A4P0I5aP061HG00h<30030P006aXH00/:200E5180
>3Le02d/:PD03@`:00<03P/:00l;2P0@30/00P0?2`X0100B3Pd04`l>018>3@0A3@`200l;2P0500h:
2@0B4@l03Pd;01dL6P0:2@L00P0<2`T07P071P@00@0001LF501EE5807ahL00`;2@020@003`h<04I5
@`24Ph406aXH00T61@0;1@D04`d=01LA4@0C2P/04PT:00l8200A3@`04A0>00`;2@0:2@L03Pd;00D4
0P0A40h03@`:00/:200=30X03`h<00`;2@803Pd;0P0?3P`2010?3@0B00`;2@0;2PP030/901<B400=
30X05aHD00d<2P0=30P01`H201@C3`0920@040l:00`;1`0@3`/06aXF01HE4@0920@04Q4?0P0?3@h2
00d;300400`:2`0;2@X03`d>00h<3@803@/<00`030X;00/92P0<2`T04Q4?00T81P0?3P`03@`:010?
3@0<2`T02@P600X91`0?3P`2014@3P0J00/9300<2Pd03`d@00d;3P0<2Pd03`d@00d;3P0H5QT00@02
01dK7P040PD05Q@G0:bZ[@0b<3<06QPK00h=3`0k>C`04@lB00h<3`0?3A003@/>010>4@0:20/03``?
018=4@0A3102010;3`804@`@00L05a8F00<00P0J5AT01`8601HA5@0<1``03@P>00803`X@00@03PT?
00l:400@2a4030L=0P0910X0:00:1@/04PdC01/F700910X01`88010;4@0400D040/A00T42P0A3180
2`H<00H21`0>2@l040/A00T42P0?2Q004`hD00<0100B3A<030L=00X52`0G4QP03PT?00<0100O6R00
3@P>00h93`0C3Q@04PdC00/6300@2a402`H<00@01@0A31809R4W01XE6`0=20h0=c8h0;6_/P0f=3L2
018@4`0400X82`0@3Q402`T<00d;3P8040hA00<03`d@00d;3P0<2Pd00P0?3A001@0=2`h03P`?010>
4@0A3a803`d@00<030X=00X020@500`31P0=0`@06Q0A00`20`0B20T07A<D01<92P0B20T04@L80P0C
2@X09P0@1`P02P@801D@50070PH081/O00h93@0910P050lC018=4@0@2`l03`X>014<400B3A407APL
010;3`0<1`/03`/>00<00P0K5QX040/?00d8300<1`/03PT=00l:3P0>31403`lF018B6P0;2a<01@@:
01@A600@3A@02`T>00X52@0?2Ph03`X=00d92P0A3@h030H:0P0A2`l200d72`0400h8300?2@d03`T=
010:3P804@/?00D04P`@00d8300<1`/030L;00d8300200h93@0N00`72`0=20`03PT=00l:3P0@2`l0
3`X?00l:400@2a404PdC010;4@0>2@l030L=00T42P0:1@/03PT?00T42P0:1@/06A@J02@O9P070PT0
30L>00T42`0;1Pd03`XA01lJ8@0`:c809B0W00d83`0<1`h04@`B1@0?2Q004`0@2a402`H<00`73@0=
20h02@@:00h93`0@2`l03`X>00d8300H4aL03@P<010;3`0?2Ph02`H:00`72`0C3Q805A0D010;3`0A
2`d00P0@2P`08`0?2@/040X<014;3@0A2`d03@L900h82P0?2@/03@L9014<2`0A3@@02@D001HA300B
30`030L401HB2`0M6P/06QL403dk900W9A003PX000l;0P0>2PL030P700/71P0E4A0071PG00h:2@0A
3@`04Ph=00d920050@0040`;00`81`0<20T03PX;00804@d>00@040`=00l;300@30d04@d>0P0B3Pl0
0`0A3@h040`=00h:2@02018>3@0500l;2P0>2PT04Ph=014=300?2`X00P0=2@P02`0?2`X04@d<00d:
2P0D414030P9014=3P070`@04@d>00l;300>2P/03@T:00803PX;0P0?2``02`0@30d04@d>010<3@0=
2@X030P9014=3P0>2P/03@T:00h:2`0@30d04@d>00803`/:024040`;014=3P0A310040hA014?4P0?
3A804a4F00T7300S8RL0C4]@01DC5P0A3a802@L:018@4`0@3Q40D4iA09>AU00N71l01`H801LE600C
4A@04Q0C00d;3P0H5QT03`d@010>4@0A3a805Q@G01LE600A3a804Q0C00T72P0I5aX01`0A3a804@0C
4A@030X=00/9300E4aH04Q0C010?500@3aL03`hF00l>5@0@3aD04a8H00h=4`0?3Q@04Q4G01<B6P0B
4AT04A0G008040lD02<051<H014@5@0<2a004A0E00l>4`0C4QL071/P01lN8`0K6Ql03`hC010?500B
4AH05QDJ01<B5`0@3a@06APM01@C600B4AH05A@I010?500B4AH051<H00l@4P0@4A<051DH01LH700F
5a/04a@H00h?500Z:S40?Ce502XZ<P0H62003PhF01XI7`0201TH7@0501PG700G5Q/05aHK018A5P0D
4aP00`0F5AX02P0F5QP05A<F01LE5P0D4Q<03@/<014?400S8B8061HG01DC500D4Q<201HD5@0=018@
4@0@3Q405aDH01`J7@0K6A`05A<F014?4P0J61/05A<F01LE600I5aX0;bd`03<a=00201@B5@0J01<A
500E4aH06aTL01lM800d<SD02PP;00l=400B41<06QPK00`:3@0>2P/0510A018>3`0G4a@061@E01<?
400D41404`l@020L7@0/:2T030P900l;300D3Q80618F01`F6P0C3A4201D?4`804P`@0P0C3A40200B
31004``B00H01P0F3aH03`P?02@M900M5Qd0=Bhe0P0A2Q40:@0C31<050dD018;4P0@2A008AXQ00d6
3@0A2Q4030D<0109400400@0614H01lH7`2ITYT05PlF00@0100@2@l040X>01@>4P0E3a<04@/?0109
400@2A4050dE00T22P090`/05PhI0149500@1a002@0601883`0H3AD05P/C01@94@0:00L03P<;00l6
300H3AD0304901053@0>0P`03`<=008040@>00P04@D?01864P0E2AD04PHB01454`0G2aT06@dK01D7
5`8060HF018060HE01P6500G1a805`LB0103300@0`X04@@:01462P0B20T050T<00X0100>0@P04PD<
01032P0>0@P03@0700l22@0A10/4018530<03`@:00T040D;01873@0C20h0;b@Z05Y?E@0>0`T04@H<
01@93`0<0@L05?ooool001_ooooo00<03@/>010>4@0@3Q400P0?3A005`0B41<030X=01<A500K6A`0
>SPk01HD5`0<2Pd0410B018B500=3@l0GUiP02/Z;0091`X04a4D01@A500:1@T04`hB01H@500G4AD0
4Ph?014=3P0@30d03`/<00803PX;00d04@d>01/G601XI6D05Q8C00L3100D41403`/<010<3@0D4140
4Ph?01PD5@0B3Pl0510A00804@d>03@04Ph?01<?400B41<06R0T05IKG`18CE006ahM01TI5`0N7QX0
4a0=01@?300F3`d07aHG01D:3P0D30l04P`@010:300B30d06Q@C00L20P0D3``05A0=01<=300A2``0
618D01LA5@0@30h04Q0A00X82@0>30d03`d>018@4@0C4A80=C<d01<A4P0>30d04a4B00P61`0@3`h0
4A0>00h=2`0<2`T040l=01<B400A40h03@`:00/:200=30X04A0>010?3@0@3P`040`;0P0?2`X01@0@
30/04`l>018>3@0A3@`04Ph=00803PX900L08QhM00X91`0H5aD040l=00`;2@0?3P`030/900803Pd;
00X04Q4?04U8AP0J6AL03Pd;00`;2@0>3@/051<A01DD4P0D4a404Ph=0`0A2`/201<:2`04018;2`0=
2@P030/900h=2`8040l=0P0?3P`300d<2P803Pd;00h02`X800l>300=30X030/900X91`0A40h02@P6
00h=2`0@3`d03@`:00/:200<2`T030/7010?2`8030/700@03`h;00d<2@0=30/03@`9100=30P02@06
1@@04@l@018@4@0?3@h02`T:014?400K6AX03P`=00P61`02010>3`0900l=3P0?3P`03`h<00l>300=
30X030/900X91`0;2PP03@`:008030/900`03Pd;00l=3@0>3@l0FeUL07ekOP0?3A002@L:01TG6P0>
30l03@/>00`:3@0>30l2010>4@0O02XX:`0F51L04@lB00l=400X9RT03`d@014?4P0=2`h03P`?00`:
3@0=2`h0:bP[010<3`0A31003PX=01<>4P0D3a<030L;00h93@0B3A403PT=00`72`0>2@d04@`A00l:
400;1P`03`X@01@?5@0:1P/03PT?00l:400200h93`0?00l:400A31805a8H01HA5`0C3Q@04@`B00`7
3@0?2Q005A0F01lJ80080`T050lE00P32@0=20h040/A00804@`B00X03`X@010;4@0F4AL04`hD00d8
3P0?2Q0040/A00/6300=20h040/A0P0?2Q000`0>2@l03`X@010;4@03014<4P09018=4`0C3Q@050lE
01DC5P0?3A0071XM014?4P0;2@`03@/>008030X=01h03P`?010>4@0<2Pd03P`?00l=400=2`h02`T<
00d;3P0>30l030X=00h<3`0<2Pd02PP;00/9300?3A00510B014;3@0D2``02P@401L>3`0=1@H04``<
01@;300B2P/040T901482@0A2@T040T:014<3P0@2`l200l:3P803PT=00X05Q4E02<N8P0300805A0D
00d8300F4AD03@P<00h93@0?2Ph040/?0P0A3100500@2`l02`H:010;3`0>2@d05Q4E05IDF00C4AL0
2`X@00d<4P0=2Q4030X?00l=4P0A31803PT?00h93P0?2@d04@/?018<400>20`030H:0P0A2`l01P0E
3a<071HJ014;3`0?2@d03PP<00d72`803PP<01P040/?00d8300>2@d04@`@00l:3P0@2`l03@P<00/6
2P0=20`04`hB00l:3P0?2Pl030L=02<N901AC5804`hD018=4`0A31803PT?01D@5P0=20h05A0F02PS
:@0J5A/200`73@804`hD0P0?2Q006`0H4aT0?CPn04E0AP0@2a402PD;00l:400D3aD03`X@00`73@0@
2a402`H<010;4@0<1`d03`X@018=4`0810T04PdC00L21P0H4aL040/?00h93@0<1`/04PdA00l:3P0B
3A403`X>00d83002014<400I00l92`0=1`T03@L900l92`0>20X030H800d72@0?2@/040X<00l92`0>
20X040X;014<1`0D3`/03`X;018;4@0>20h050h?01<>1`0D40<05a<501HB1P0C3PL040/900l;2@05
00l;2P0>010<2`0>2PT030P700d9200?2`X04Ph=00l;300<20T03`/<014=3P0>2P/040`=01HB4`0B
3Pl200d92P0>010<3@0C3a004Ph=00`81`0B3Pd03PX901<?3P0?2`X03PX901<?3P0<20P03@T8024M
700/:2L2014=3P0@01<?400?2``03PX;018>3`0?2``05Q8C00`82@0C3a004Ph?00h:2`0?2``03@T:
00`82@0=2@X03PX;00l;30H040`=00d04@/=01<=3`0@2P`04PdA018@4`0>30l02`X?00l>4`071``0
2`/@02PY;P1lO8405aDI00<03@/>01X03`d@01hL7`0T8RD05A<F00l=400B41<03P`?01@B5@0F51L0
>3Hi01HD5`0C4A@03@/>014?4P0E4aH04Q0C014?4P0?3Q003P`?014?4P0?3A003P`?014?4P0>30l0
3`d@018@4`804@lB00X04Q0C014?4P0A3a8040lD010?5@0?3Q@040lF01<B6P0?3QH04a8J0P0@3aL0
0`0E51X05QDK014@5P0601<B5`805A@I00/051<H018A5P0B4AH04a8G01PG700E51T051<H01PG700I
61d05A@I01HE6P0201LF6`0801<B5`0A41D05A@I01TJ7P0F5a`05aPM01@E6P0?41D201DE7@0f01PH
8@0R8R`051@N01DE800P82X05aHL01/J7`0F5AX05A@I01PG700B4AH05QDJ01DD6@0F5AX061LL01LF
6`0C4aD06ALJ01TG600G5AH07Q`M01DC500H5QL07A/L01DC500B41405Q@E01DC500G5AH040hA01DC
5P0B41<05A<F02<Q900Y9bX05aDH01@B5@0F51L0HV1S020N8@0D4QD05Q@G01TG6P0F51L05A<F01HD
5`0C4A@05A<F01hL7`0>30l0518E01TG6P1@CU4061@E0P0A3@h01@0D41405A4B01<?400D41404`l@
00805a<D00P04`l@01@@4@0F41@05Q0D01D?4`0B31004`dA01H@50D04`dA00<04P`A018;4P0C31<0
0`0D3A@00`0C31<04P/B018;4P02014:4@050109400C31<05a0G01<<4`0B2a800P0I4QT03@0C31<0
3@H=018;4P0O61l04P/B00d63@0B314040X>014;3`0B310040X>00l83`0@2A000P0=1Ph03`0?2140
2P<=01<;5P0B21403P<;01D:4P0B1`l050TA01473P0C21004PL?01053@0?10`040D=01<840020188
4@0N020F7`0C2A@03PH?01@95`0D2AP04@HE01055@0C21P05@XJ01@86P0G1a/03@0A01T96`0>0100
5@HF01<44@0K3AT05`XD0185300A1P/04@H:00l42@0>0@P04@@;01032P0>0@P04@@;00h1200?0PT0
4@@;0P0J3A@03P0B1P`04@@;00l42P0D2@l060dC00h32@0@1P/0;B8X0;:W[@35_<407Q<I00l62P0?
10X02`065?ooool001_ooooo01P04a4B018@4@0>30d02`T:00d;300@3Pl04a4B00h<3@091`P06ALH
00`:2`0D4Q<03@d?01@D5P0E5AL0>CTk00`;3P0@3Q403`d@00T52@0?2Ph04@`@00P21P0C3A42010<
3@0A014=3P0B3Pl04Ph?01<?400?2``030P900P41@0K5aP06QHG00L3100D41403@T:018>3`0H51D0
7a/L01LC500C3a000`0A3@h05P0B3Pl040hA04mCF@3lool0hnOZ02`^;P0M7A/020T400h=2@0=2PD0
6A@@02`W900I41404`d>01DA4P0;1`P0J6AU01PD4`0G4a8040`;01<?3P0G4a@201<?400G01LC500C
41400@000040000A40h05aHD010?3@0;2PP05QDC00L6100D4a404A0>018A3`0@3`d03Pd;00d<2P0<
2`T04A0>010?3@0>3@/03@`:00`;2@0=30X00P0?3P`01@0@3@`03`/:00l;2P0?2`X040`;00804Ph=
01004@d<018>3@0?2`X02`L600h:2@0H5aD0:2LU020O7@0E51804Q4?01@C4@081`D06APF00X9200>
3@/06APF0P0<2`T01@0>3@/04a8@01<B400@3`d03PX900<04@/;0P0C2P/02@0B2`/040`;00d<2P0>
3@/03`h<014@3P0B4@l02`X800d<2P0200l>300900d<2P0;2PP01`H400l>300E51804A0>00l>300@
3`d04A0>00804a8@00`04A0>018A3`0C4Q003@T600l;200>2PL04@d<01@@4@0<20T03`X>00l;300?
2`X300l;200300/:200Y9bP0>SPi00807A/L01/0:BLX06UWJ00:20T00@0000P71`040P<030X;00d;
30081PL040h?00X82@0@3Pl05A<D00d;300>30d030X;00P61`0:20T03P`=00h<3`0I5aX09B<V00/9
300>30l02@L:00h<3`0=2`h00`0<2Pd01P0=2`h03`d@00L5200F51L020L900d;3P802`T<00X02@L:
00l=400@3Q404@lB04E1A@0M61`020<7014<400;1PX02PD90P0D3a<02P0E41@04@`@00d8300>2@d0
4`hC01@?5@080`T04@`B00h93`0U82H2010;4@803`X@00D040/A018=4`0N6Al071LM010;4@0200l:
400D010;4@0B3A<06A@J00T42P0?2Q0020<900l:400E41H04`hD00l:400<1`d03PT?01HA5`0=20h0
40/A00l:400=20h040/A00l:400@2a4200l:400300h93`0?2Q0040/A00<03`X@00L040/A014<4P0C
3Q@01P4500X52@0;1PX04PdA00803PT=00P04`hB00`72`0C3Q802@@8010;3`0B3A407Q`O01LE6080
4@lB0P0B41<200`:3@0A00d;3P0>30l03`d@00l=400B3Pl02`L801<?400I4aD04Pd?00l;300A2`d0
4@`=00l;300A2`d04@`>018>3`0@30d00P0?2``300h:2`0500P41@0C3a0020@5010<3@0?2``00P0=
2@X00`0>2P/03`/<010<3@03014=3P0B010<3@0:1PL04Ph?00T51P0D4QD03@/@00X83@0>31403`dB
00d83P0>2@l040/A0109400?20l040T@0188400C2A404``C0P0A2Q4200h73P0501<<4`0D3A@04@XA
00l83`0>1`h00P0<1@`0=00@2a403PT?00h93`0@2a403`X@010;4@0;1P`00`0401XE6`0K5Q`01@06
00h93`0=20h04PdC02HQ9`0910X03`X@00X52`080`T04@`B00/6300<1`d06A@J01D@5@0>2@d03@P<
00l:3P0<1`/03@P<014<400V8BD050lC00h93@0F4AD01`8600h93P0;1P`03@P>010;4@0;1P`02PD;
00d83P0@2a404@`B01D@5P0R7B<02@D:01@?4`0910P040/?00h93@0500@200`72`803`X>01`03@P<
010;3`0>2@d04P`>01<=3`0F41806A<E01PB500C3@l03PP:010:300B30h040X<00l92`0@2P`05Q0@
00/51@0@2@l03PHC00l7500>1`h04@/;018=1`0D3`T04`h:014;3@0?2@d03`/<1@0?2`X03P0C3`h0
4Ph=014=300A3@`04`l>01DA400=2@X03PX;014=3P0>2P/02PH7010<3@0A3@h040`=0P0>2P/200l;
300501@@3`0B3Pd05A4@00h:2@0C3`h00P0@30/01@0:1PD06aLF00h:2@0B3Ph0Ee=B00804`l@00d0
510A00l;300=2@X04@d>01@@4@0G4a@05Q8C04]7B00W8b@071PI010;3`0?2Ph03PT=00803`X>00<0
40/?00l:3P0?2Ph0100?2Ph0100C3@l040X>00X4200<1`/200l=4P0>00l>4`0L7B804A8G014C600:
3A@01@P=00d;3`0;2@`040hA00h<3`0<2Pd020H900/9300<2Pd2014?4P0D00X82`0=2`h00`4403lm
@0081PT05aDH00L5200D4QD00@0201/I700<2Pd00@0201lM800:20/03P`?00d;3P0A3a803`d@010>
4@0B41<2014?4P0<018@4`0A3a804@lB01<A5@0C4QL04Q4G01<B6@0B4AT040hI01LE800C4A`040lG
0P0B4AL00`0?3Q<04Q4F018A5P04018A5P804a8G0P0B4AH0100C4QL051<H028Q9P0M724301PG7005
01@C600F5AX05QDJ01DD6@0C4QL00P0D4aP04@0I6Ql05aLO014A6@0C4a/05QHN00l?6@0Q8B/0410K
02LW<`0U9C406QXW028R;P0I61h06aXO01PG700G5Q/06APM00805A@I0P0G5Q/07P0F5AX05aHK01XJ
700J61/0?cdn02/Y:P0F51D040h?01lM7P1?CDh06aTJ028P8@0I5aP05A<D02HT9@0N71l071XM018@
4`0@3Q406ALJ01lM800100807adP01LE600P7R404a4D01dK7P0I5aX08R0S01`J7@80518E00X05A<F
01LE600D4QD05A<F02LU:00S8B@081hQ028N7`0C3a004Ph?0P0K5aP00`0G4a@05Q8C014=3P0201<?
4003010<3@0B3Pl050hB00805Q0D200C3A400`0B31404P/B01<<4`0201@=500301<<4`0D3A@04``C
00804``C0P0B2a80100M5Qd07aPO01<<4`0@2A0201/D6`0301@=500B2a804P/B00<04P/B03D050dC
00`62P0;1@T04`dA00X4200:0`X04@XB00h73`0@2A403PL@00l74P0C2aH05`dF01X?5`0=0`X07A8J
01T>5P0@1`d050TA01<8400B1`l04@H>01873`0D2A4050XC01<94P0C2a@03@8@00`13`0@1AD05@XK
0187600>0aD03`<G01866P0E2Al060`T00h26P0I3B<03P8H01H:7P0D21T03P8@00l33`0@10l040<<
01032P0B1@d04@@;01032P0<00H03P4801@73P0201032P0A01@73P0900<02`0501@73P0800801`02
0146300F2a402`0601hC6@1BAdd0mncb07aaM`07008060dC00h32@0?10X05?ooool001_ooooo01P0
3P`=00l=3P0>30d03P`=010>3`0A3a005A<D010>3`0<2P/03`d>00/92P0E4a@05QHH00/;3@0B4Q@0
8b<U03`k?@0>30l02`T<014>4@0G4QH04`hB00/52@0C3A43010<3@804@d>03`04Ph?01hJ6`0T8240
4Ph?03Pd=@070`@05a<D00l;300=2@X040`=018>3`0G4a@040`=00h:2`0?2``040`=01<?400E4A80
4a4D03/mA@3Gf^40_[o402DV:00F5QH00`@000/:1P0@3`X04Pl:01PD4@0A3@`05a<C00/92P0:1PL0
JfQY00l=3P0D41403``<010>3`0E4A804@h?00l=3P0D414051<B00X91`0I61H071/I010?3@071P@0
4a8@01TH5P0B4@l081lM010?3@0C4Q002@P6010?3@0F5A<03@`:00P71@0<2`T200h=2`0500d<2P0>
3@/03`h<00h=2`0?30/00P0?2`X2010<2`0I014=300B3Pd040`;014=300B3Pd04@d<00l;2P0>3@/0
6QTG01@C4@0?3P`03Pd;00l>300100002`X801DD4P0510802@P600/:200A40h04Q4?01<B400B4@l0
40l=010<2`03014;2`804`X;00@04P/;01<?3P0@3`d03@`:0P0;2PP03@0<2`T03@`:00l>300@3`d0
3`h<00h=2`0?3P`03@`:00h=2`0100003`h<01@C4@020@000P0@3`d03P0?3P`03Pd;010?3@0A40h0
30P500h:1`0A3@`06ADF01dH700C3Q803`X@00l:3P0?2``03`/:0P0?2`P01P0E4a@09B<T02XX:@01
000020H701TG60803@/<01T0:2HW038`<@0A3a002@L800X92@0;2@`04@l@00l=3`0?3A003`d>00d;
3@0>30l03`d>00/92`0;2@`03`d@00P72@040PD02`T<01<A500F51L020H900h<3`0=2`h030X=00<0
2`T<00P03@/>00`:3@0@3Q402`T<01HD5`0=2`h02`T<00L520802`T<01D02@L:01dJ7@0=20`04@`@
00/62P0@2`l03@P<014<400D3a<05A0D01<>4P0?2Ph040/?00d83@0>2@l00`0401`G7@0300@04`hD
00X62`0@2a400P0?2Q001`0@2a404PdC01D@5P0A31803PT?018=4`0@2a400`0>2@l04@0:1@/04@`B
00l:400=20h030L=00d83P0@2a403`X@00d83P0<1`d02@@:010;4@0>2@l030L=01@?5@0A318040/A
00803`X@00<03PT?00l:400@2a400`0>2@l04@0?2Q0040/A018=4`0=20`05Q4E00`72`0H4aL050lC
010;3`0C3Q804PdA00l:3P0:1@T0=S4e020K7`0E4aH04@lB00<03@/>0P0;2@`04@0=2`h03`d@00l=
400?3A003P`?00<1100B3a4061HG00h93@091@P05aDF00l:3P0>2Pd03@/<00l:3P0@30l04Ph?0080
3`/<0`0>2P/01`0=2@X04@d>01@@4@0B3Pl03@T:00l;30070`@00P0>2P/0200?2``040`=010<3@0@
30d03@T:00h:2`091@H04`l@0P091@H01@0>3A802`T>00h<4@0>31403@P>00803`X@0`0@2A020188
400:01L@5`0D3A@04@XA00d63@0;10/03@H=01@=500A2Q4040T@00l83`803PL>1@0?2Q003P0@2a40
7QTO00D01P0C3Q@00`0401dH7P0>2Pl02`H<00`73@0?2Q001P4700`73@0?2Q002PD;0P0A31809`0;
1P`02@@:00X52P0=20`03PT=010;3`0;1PX030L;00d8300P6al05Q4E00X52@0?2Ph02PD9014<4@09
10X03`X@018=4`0:1@/030L=00d83P0<1`d020<9055<DP2FTIL09R4W01PC5`080`L03`X>00X52@0;
1PX04`hB00/62P0?2Ph040/?00l:3P0A31003@P<00d72@0300l92`0E014;3@0<1PP03PP:010:300B
30h040X<00h82P0?2@/04P`<00`61P0@2A001`0<00h64`0<1@h03`T9010;1`0A30H04@`9014:3`0?
20l03`/<00L03`/:0P0>2PT02@0@30/04@d<00T51P0@30d05A4B010<3@0810D03@T:00l;3003010<
3@0>00l;300>2P/040`;018>3@0D40l03@T801<?3P0A3@`030P700d9200B3Pd040`;01@@3`0Z9RD2
018>3`0:01@@4@0@30d03PX;01<?400=2@X020@500l;3016@T<08QhO01<?40H040/?1P0=20`0400?
2@/04P`@018<400@2`l02PP=00P62`0@41@03PlD00021`0;3a<0314G01TL8@0=2`l02`T<010>4@0=
2`h200/93009014?4P0?3A003`d@00h<3`0;2@`040hA00T72P050`H03@/>00804a4D00L05aDH0040
0P0F51L03P`?01lM800A3a8061HI00803@/>00@04@lB00l=400@3Q404Q0C0P0A3a803`0B41<04@lB
014?4P0A41@03`hC010?5@0D4aX04a8J01@B7@0B41/040hI00l>5P0B4AL05A@I01HE6P06014@5@<0
4Q4F01404a8G01@C600E51T071/P01LF6`0C4QL05A@I01PG700G5Q/04A0E01LF6`0H5a`04a8G01DD
6@0J6Ah061PP01LG7`02014A6@0=01PH800D51h0:2Pb01hN:@0R8Rh0@d=?01lN:`0@41`061LM01PG
700F5AX05A@I01HE6P0201DD6@0H01TH7@0G5Q/05A@I01PG700N7R001`D801PF5`0C4A806ALH020N
7`0W9BH0clg>03Tg>00A3a006aTJ02XX:@0D4Q<05Q@G01PF6@0E4aH04Q0C010>4@0>30l05A<F0P0C
4A@0400@3Q40108501dK7P0N71l081hQ01TG6P0E4aH05Q@G01DC5P0C4A@0108500400P29QhX0Ti6D
00400P0K5aP201<?400501TE5P0K5aP06ADF01XF5`0D41400P0E4A800`0C3a005A4B01@>4P0201H@
500301D?4`0B31004P`@00D04`dA00<04``B018;4P0C31<00P0D3A@00`0C31<04P/B018;4P02014:
4@8040T@00L050dD01<<4`0@2A004@XA01<<4`0>1`h030D<008050dD01403@H=01@=500D3A@030H;
00l93@0Y8bL0B49602PR9P0=1Pd02@89018;4`0E3QH02@8;01P@6`0?1a802`<:01053@0201873`04
01P=5@0=0`X04`P@01873`<04@H>01H04`P@01884@0E2a@03`L@00/03P0?118060dM01<86@0A1QL0
3P8F00l36@0C1ad060dT01D=9@0;0Qd05PhV00`46`0C2b004PPJ00h34`0B1Q@04`LD0P0@0`d01P0F
2A<04`H=01@73P0A10/03`8901@73P804PD<01405PT@00`01P0;00D04PD<00/01@0D2@l03`@:00`1
1`0:00D04`P>02PM8`21MW`0:B0T00L00P0L4AL03`@:00T0100Dooooo`006oooool05P0<2P/03`d>
018@4@0C4A8040h?00`:2`0B41403`d>01DC500:2@T03P`=00l=3P0;2`d04a<E00`<3P0D51H071/M
02XX:`0@3Q40:2DX01hI7@0C3Q8200h830<040`=0P0?2``03P0>2P/0:BDV00T51P0G4a@061@E00d:
2P0C3a003`/<01PD5@0J5QL03PX;014=3P0=2@X040`=0P0A3@h07`0B3Pl04@d>00l=400D4ad09bH`
020O9@0D4aH02@T900l@2`0=3PP03a0:00`<1`0=3PT02@T500h=2`0D51@04a8B014A4@0>3Ph05QDF
01<B500A4A8040l?014A4@0B4Q8051<C01PG5@020@005A@B014@3P0I61H00P0?3P`02`0;2PP02@P6
01XI5`0<2`T04Q4?00d<2P0?3P`03Pd;01<B400M71X06APF00803`h<00H040l=00l>300=30X03Pd;
00l<2`0?2`X4014=300901<?3P0B3Pd03`/:00l;2P0B3Pd04@d<010?3@0D4a403@`:008051<A00<0
3`h<03Pg=@0O7Q`00P0>3@/01@0Q81h03@`:01<B400B4@l03Pd;008030/900@040`;014;2`0A2`/0
4@/;0P0C2P/0200B2`/04Ph=00l>300>3@/03@`:00h=2`0?3P`02`X80P0>3@/200/:200400l>300B
4@l03@`:03Xi=`8030/901T05A@B00h=2`0=30X030/900d<2P0>3@/03@`:00l;200@30/04@d?01LB
5`0K5Q`04PdC00l:4P0?2Q403`X?00l;3@0?2`X03`/900X82@0<2P/05A<D00L51P0d<S<0F5IG0080
3@/<01H01083014?400B414030X<00`:3P0D4QL03@/?018@50050`P0518F00l=4@0:20d03P`@00d;
400:20d03P`@014?4P0=2`h04Q0C00T72P0A3a802@L:100=2`h200/9300B010>4@0:20/04@lB00d;
3P0K6A`0;2X]018@4`0<2Pd040hA00h<3`0:20/05A4E010;3`0G4QH030L;01@?4`0<1`/03PT=0`0?
2Ph200h93@0;00d83@0H4aT040/A044l@P0D3aD030P=00h93`0@2a403`X@00h93`0@2a400P0A3180
400>2@l040/A014<4P0<1`d03PT?01<>500:1@/04@`B00d83P0D3aD04@`B018=4`0A318040/A014<
4P0B3A<2014<4P0601D@5P0A31803@P>010;4@0=20h040/A0P0?2Q00100>2@l03`X@010;4@0@2a42
00l:400G00h93`0?2Q0040/A00`72`0D3a<030L;018=4@0A31003PT=00`72`0:1@T04@`@00l:3P0Z
9BT08QdQ00d;3P0?3A004@lB018@4`0@3Q402`T<00`:3@0?3A000P0@3Q40400?3A003@/>00T8300?
3Q801PD901@C600[:Bh03PdA00`:3`0;2Ph02PX=00/:3`0=31003P`@00h;3@0?2``200h:2`803@T:
00H030P900X61`0>2P/02@D6014=3P0<20T400l;308040`=00L03`/<00`82@0A3@h040`=00d92P0D
41405Q@H00803@/@0P0>2@l01@0A318040T@01094@0A2Q804`TB00804PPA00@03PL>014:4@0?20l0
40T@0P0B2a8300l83`040109400A2Q404P/B00l:408040/A0P0?2Q005P0=2@h061<I06AOI@0R7B<0
30L=00P42@0F4AL04PhC02/V;00@2a403`/@01DA5P0>2Pl03`X@00T42P0<1`d03@P>00T52P0>2@h0
30L;00h93@0A310200d8300C014<40060PD03@P<010;3`0:1@T04@`@00h93P080`T03`X@00h93`0=
20h050lE00h93`0G4QP04@`B02XU:`1@Be405Q4G014<400200l:3P0400d8300Q7200:RDY00d83080
4@`@00L040/?018=4@0?2Ph03`T;018<3P0>20X03`T;0080618D01<03PP:00l92`0A2`d03PP:00d7
2@0=1`P030L3014<2@0@2Ph04``E01094P0?20d03`X800l:1@0@2`@040/7010;2`0@2Ph03`/<00D0
3`/:100=2@P200l;2P0500`82@0D414071PI01PD5@0?2``00P0@30d0500A3@h04Ph?018>3`0B3Pl0
4@d>00`81`0?2`X040`;00d9200H51<040`;014=300?2`X040`;01<?3P0?2`X02@D400h:2`0?2``0
4`l@0P0A3@h01`0F4Q<03`/<014=3P0D41403`/<00d92P0<20T00P0@2`l2014<40P040/?00l04`/@
018<400D3Q804PdC00`:3`0<2a002`/@00X<4@0>4QL0JFie0;Nm`P0`=CT04a4E00d;3P0?3A000P0=
2`h06@0@3Q405Q@G01<A500C4A@04@lB00`:3@0D4QD04a4D034_<P0@3Q404@lB00/9300@3Q4061HI
00T72P0F51L020H903`k?@0F51L03`d@00h<3`0A3a803`d@010>4@0B41<00P0A3a803`0B41<04@lB
014?4P0A41803`lA018A5P0G5Qd040hH014?700B41d04@lK018@6@0D4aT05QDJ01TI6`06018A5P80
4a8G00P04Q4F01<B5`0D4aP05A@I01PG700E51T04a8G01LF6`806QTN00T02PT>01LF6`0L6b004Q4F
01HE6P0Q82H071`T01/K8`0G5b400P0D51h02@0H62@04a<O02TY=P0Q82h07ah/01PG9P0G5b<06aXQ
01TH7@0301PG700<01XI7P0G5Q/06QTN01PG700F5AX061LL01`L7P0I5aX05Q@E01@B4`0F51D040h?
0P0T8R<02`0G5AH071XK00/92P0F51D0518C01HD5`0E4aH05Q@G01@B5@0B41<05A<F0080518E00`0
4Q0C01TG6P0?3A006QPK024O8P0G5AP04@lB01LE600J61/05A<F01HD5`0D4QD201/I7005024O8P0C
4A@04`l@01HB4`0E4A800P0A3@h00`0C3a006ADF01@@4@0201DA4P0301<?400E4A805@lC00805@lC
00<05Q0D01<=4@0A2`l01@0C3A40200C3A804``C01@=500D3A@04``C018;4P0C31<050dD0P0C31<2
018;4P804@XA01`050dD01D>5@0?20l03`P?0109400D3A@05@hE00l83`0E3QD050dD014;400;1@T0
3@L;01TC5`0<1PX02P<:014:4P0<1@d06Q<K01<;5@0;10h04PXE06UPJ@0S62005P/C00l4300B1`l0
4`P@0P0A1Ph301053@0N01463P0?1`h0614I00d6400=1A803`LD0108600A21X04@PK01487@0C2B40
60hV01lG<00G5C402P/X01HD<00;1b404PdU00l97`0A2Ad04`TK01855P0?01004@4?01L7500D1a00
60/B01D83`0=0@L03`890P0>0@P01`0A10/05@P?01<63@0?10T04`H=00h52@0=0PP00P0?10X0200>
0`T03`@:01L<4P0B1`d040D;00T0100?1@X03`@:5?ooool001_ooooo0P0=2``05P0@3Pl04a4B014?
400<2P/03`d>00h<3@0P7Ql02PP901DC50091`P051@F00/;3@0E5AL03@d?00X92`0610L01`D801DA
5@0B3A404@`@00l93@0C3A4200l;30<040`=00d04@d>00X61`030000510A00l;300G4a@03@T:01<?
400J5QL071PI018>3`0D414040`=00804`l@03404Ph?010<3@0<20T02`H:00h;5P0K62<06AHM01@C
5`020P805aPC010C3@0<3`P02`h701<G400:30L02P`800/=2P092`X051HF00/<3P010P@051DG00l@
4P0>3a403a4A00lA400H6QL06QTG02LV8P1YJ6@0:2LS004000030P005A@@01LF4P0>3@T061LC014@
300C4Ph040l<00h=2`0920H04a8@024P7P0K6QP03Pd;00l>300A40h040l=008030/901P03P/:00l;
2P0A3@`04Ph=014=300@30/03PX9018>3@0@30/030P700l;2P0>2PT02PT700d<2P081`D03Pd;00/:
200920H03`h<01PG5@0G5Q@03`h<01LF500@3`d300d<2P0300`;2@0;2PP03@T800<04@/;0P0C2P/0
1@0B2`/03@T800`;2@0>3@/04A0>00804Q4?00@01`H4010?3@0D4a404A0>0P0<2`T0>00920H040l=
05mNG00L6aT03Pd<018A3`0>3@/03@`:00l>300A40h040l=00/:200?2`X04`d>00l93@0?20l04@XC
00d5400@21D040TB0109400@2Ph040X;00l;2P081PL040h?01<A4P0?3@h040h?01<A4P0>30d05Q@E
00X82@0G5AH05A<D00<1100=2a404PlF00L42`0A3QD040dD06MTJ`0N6b801P<:00T63@0>2a8030T@
010>4`0:20/06aTL04=1A00H5QT0518E00/9300<2Pd03P`?0P0?3A0200d;3P0800P62@0A3a804Q0C
00`:3@0l>Sd0MWAg00h<3`081PT200d;3P0900L5200G51L030L;00P31`0>2@d050lC00T4200G4QH0
50lC00804`hB00X04PdA014<400B3A8040/A00T42P0D3aD02`H<00d83P0E41H03@P>0P0<1`d01P0>
2@l03`X@00l:400<1`d03@P>00l:40802PD;01<03PT?00d83P0Y92X04@`B00`73@0=20h04@`B00d8
3P0:1@/03@P>010;4@0A31803PT?00`73@0?2Q004PdC010;4@0C3Q@040/A00803`X@00L03PT?00l:
400@2a4050lE01<>500@2a403PT?00803@P>01D03@L;00l93@0E3a<030H:010:3P0B310040X>00`6
2P0D3Q803PP<00@00P070PD01P@700L520091`X02`T<00X82`071@P03P`?00l=400@3Q400P0?3A00
0`0>30l020L<02TZ;`0201hO900405EFF`0;314030dB00`=4P802P/@00@02``A00`;400<2Pd03PX;
0`0=2@X01@0<20T04@d>010<3@0@30d03`/<008030P91P0?2``0100>2P/03`/<01@@4@0>2P/2014=
3P0701<A500<2Pd03@/>00l:400>2@l040/A00l83`0301<94P804@L@00L050dE01H?5`0@2A403@H>
00`53@080@T03`P@00803PL?0P0?21003P0@2A403PT@014<4`0@2a803PT@00l:4@0I51/01P48040k
@P0<1`h07APO00<01@0:1@/02`H<0P0<1`d0300X8bT03`X@00h93`0D3aD04@`B01@?5@0=20h01`88
01TD6@0B3A4030L;00h93@803@P<00P04PdA00`72`080`L04@`@01@?4`0@2`l03PT>00@01@803PT?
018091lU034/<P0E41H0100500D01P0A318030L=01HA5`0>2@d05A0D00/62P0>2@d04@`@01HA5@0>
2@d04@`@00l:3P0=20`2010;3`0C00T31@0>20X02P@600X41P0D3Q004P`>00l92`0A2`d04P`>00h8
2P0<1PP03@L8018=1`0>2@<04@`:04@n@P0E3a<03`X900l:100200l;000300l;0P0A2`T04@/=00H0
3`/:00<03PX900l;2P0@30/00`0@30/01@0=2@X030P9010<3@0@30d030P900<03`/<0P0@30d0700A
3@h04Ph?01@@3`0B3Pd04@d<018>3@0O6aX040`;01DA400>2PT0510?01<?3P0<20L05A4@00d92P0>
2P/04@d>00l;300>2P/04`l@018>3`0300003PX;014=3P0G4a@02PH700l:3`0@2a42014<4P0300l:
400>2@l03@P>00D03@P>00l04PT>010:3P0E3a<04PdC00`:3`0>3A8020T>00`?5P083A<0@4I<09RO
Y@0I7R804A0D00`:3@0@3Q400`0?3A005@0@3Q403@/>01<A500E4aH03@/>00l=400=2`h0Cde@018@
4`0J61/03@/>018@4`071@P07adP018@4`0d<SD0_[bo02d[;P0@3Q403`d@014?4P0200d;3P04010>
4@0A3a804@lB018@4`804@lB00`04A0A010@4P0F5AX07A`S00l=600?3AX04Q0M01<A7P0C4Q/04Q4G
014@5@0A4A<6018A5P8051<H00D04a8G018A5P0B4AH04a8G01TH7@0201HE6P0G01/J7`0M72406aXO
01LF6`0O7R<06QTN010?500D4aP04a8H01DE7@0<31H051@N01lO:`0F5R8051@P01`K:@0C4R005aHT
00X96@0L6b/05QHR01hM9@0H5a`00P0J6Ah00`0H5a`07QdR01XI7P0301PG700Y01LF6`0D51H09B<V
018@4@091`P061HG00l=3P030@8020H701PF5`0J61T04a4B01HD5@0M6a`03`d@00d;3P0B41<04a4D
01DC5P0N71l07A/N01@B5@0W9BP06QPK01@B5@0;2@`061HI01@B5@0A3a805aDH01TG6P0E4aH0518E
01<A500M6ah04Q0C00T72P0F51L06ADF01XF5`0H51D00`0D41401`0B3Pl03`/<01<?400D414040`=
014=3P0F41@00P0B31000`0E3a<050hB018<400501<=4@0701<=4P0D3A@050dD01@=500C31<04P/B
01<<4`0201D>5@0401@=500C31<04``C01@=508040T@00@04@XA00d63@0@2A0050dD0P0B2a805P0A
2Q404P/B018;4P0B2a4030H:00T31`0:10P0208600X32P0F3aH02`@<01<<500=1Pl04`/F024I902V
W:D0AS]300`32@0G31@06a0H00l4300@1@d401463P0Y01063P1BB540BdA<01084`0<11405PhK01`C
8`0;0QD03@@G01067@0@1Ql04PPQ01P@:`0/;D/0724o028VA00A4Rh051@^014<900?1ah03`HK0185
600F1AL05PDE01@34P0P4a`06`hE00l32@0>0@P050L>00l22@0@0`X04@@;00`01P0@0`X04`H=00P0
0P0B1`d060dC01D:400>0`T00P0:00D200L00P0400h32@0E2Q005@X@00L00QCooooo000Kooooo`0H
010>3P0=30/03@`;01DC4`0_;Bd051<B018A400=2`/04A0?00H5100>3@`02PP800X9200A41002`X9
00`;300B4A403@`;01<A4`0@3Pl03@X:018?40091PP04@d=0`0@30`04P0A3@d04Ph>014=3@0@30`0
510@01DA4@0A3@d03`/;014=3@0B3Ph02`L701PD500D41003`/;010<300?2`/04@d=01<?3`804@d=
03H04Pd@01<>5`0B3QH03`/B014?4`0=30h02`X:01DE500;30/04a@B00/=2`0F5aL030d<01<D4P0:
2@P03Ph<00d>300<2``030`<00h?3P0A41402`/:00X;2@0D4a405QDB00/91P0P7Q/03P`901<A3P0?
3@X03@X8018?3@0:20D04Pl=01<@3P0A3``03@/9014?3@0B40h03P`:00h;2P0@3P`03P/:01TG5@0h
=S@03`d;010>300B40h040`;00h:2@0E4A006ADD014=300@30/200d9200F018>3@0D40l0920O01DA
400;2PP04a8@00/:200E51803@`:00l>3@0C4Q003`h<00/:200@3`d03Pd;010?3@0;2PP03@`:010?
3@0A40h03`h<00`:20803`d;02P04@`<018=300B3@d04`h>00d;2@0<2`T03@`:014@3P0;2PP03@`:
00`;2@0A40h07A`J01LF500;2PP04Q4?01@B4P0:20P04a4A00h=300A40l02@P700l>3@0;2@T04Q0@
01LE5@0A3`l02PP800l92P0C3@l03PP<00d73@0B31@03`/B010:4`0?2Q803PX@00d93`0R7b<03P/>
0P0>30h0@P0:20X02`T;00h<3P0D4Q@03P`>010>40081PP02PP:00h<3P0=2`h030X>00d;3`0<2Ph0
4Q0D01/I7@1PGV807adQ00`:3P0>310040hB00`:3P0>31003P`>00X92P0M6ad02PP:010>400;2@/0
3`d?014?4@0>30h040h@00d;3@0@3Q003`d@00h<3`0610L05Q@G01TG6P0<2Pd04Q0C00H41`0B41<0
2@L:00P62@0=2@d05a8G00h93P0A314050lD00X52P0C3Q<04PdB014<4@0@2a003`X?00h93P0?2Q00
3@P>01@?5@0@2a403PT?00d83P0?2Q002`H<00`73@803PT?03804@`B01<>4`0@2`h04@`A01LB5P0E
4A<03`X?00h93@0E41<0:RDZ01/F6P0@30h03@P=00/6300<1`h040/A01<>500B3A<03PT?01PC6@0@
2a403`X@01<>500>2A0030L>00l:400>2@h03`X?00h93`0=20h040/A010;4P0B3A@050lF014<500B
3A@03`XA010:3`0?2Ph05A0D00`62P0>2@d040/?01<=4@0<1`X05a4E04M2AP0K5AT03PX=014<4080
3`/?00<040`@014=4@0@3100100@3100:@0?30l03P/>01PG6P1?CU003@/>00T72`0>3A409R@Z01@B
600?3AD02`TC00`:500=2aD02`TA00X8300@3@l030T;00l<3P0@3@l02`P:00X72@0=2P`03P/=010=
3`0<2@/03@X;00l;2`0>2PT03@T900l;2`0B3Ph04`l?00h:2`0E4A804`l@010<3P0C3a403@T;00l;
400>2`l03PX?00804@`B00X040/A00l93`0@2Q404@/B014:4P0@1`l03@L>00h83P0A2a803`T>0P0?
2A001`0=1`h04@XB014:4P0?21003`L@00l6400>1`l01@0>2A006P0<1`d040/A00l:4@0>2A003@P?
01D@5`0>20l04P`B01L?5P0>2@l050hD00X42P0?2Q004@`B00X730081@X02PH<014>4`0O6al04`lA
00`82P0<1`X030P:00d92`0<20X04`hA0P0@2`h0600?2`d02PH8018=4P0<1`d03`X@00`73@0J5A/0
7aXP00`73@0;1P`04@`B01@?5@0<1`d03@T>00d72`0@2Ph03@P<01@>4P0>2@d04@`@010:3P0B3100
4@/?00h830803PT=01/04P`?018=400@2Pd03PT<014;3P0?2@`03PT<01/E600Q6ah02PD7014<3`0?
2P`050l=00`71@0G4Q80?STk01<>3`0@2`/02`L3018>200=2@<06aHC01D@3`0E41803PX:00l;2`0@
30`00P0A3@d00`0@30`03`/;010<3003014=3@07010<300C41002PP700h;2`091PH03P/;01DB4P02
00l=300900h<2`0>2`/03`d<010=3@0@30/03PX900d9200>2PT05Q8A008030P701403`/:00h:2@0>
2PT04@d<010;2`0A2@d03`P;0108300?1`X03`P9010;300C3@d04@d;018>300@30X04Pl<00h:2@02
00h:3`0?01<?500@3A403@T>018>4`0?30l03@X>00h;3@0@3A003``>00h:3@0A310050lC01lK7`0V
92P04Q0D00804A0D01<01PD:00`=4P0@4QL04A<H014B5`0?3A8040hB018@500?3A4040hB018@500A
3a<03@/?00h<400@3Q803`dA014?4P0B3a4030X<00803`d?01402`X<018A4P0<2``04A0A00h>3`0B
4a@04A8C01DE5P0@3a403`h@010?400>3@l03`h@014@4P0@3a404A0A01<B5002014@4P0F018@4P0@
3a405A@G01XI7@0C4QP04A8I00d<500?3QH04Q4G01<A5@0B4A<04A0C01@C6@0F5AX05A@I01<B5`0E
51P05ADG01@D5`0C4aH05A@I01HE6P8051<I02X05QHI018C500C51D06Q/K01/K7P0H61`04Q8G01@D
6@0B4QT04a8J01PH800H5b406QXY01@B900N7Bh0=SE503hmC@1BDF006aXX01PH9@0I62D05aHR01@D
800J6RD07A`T01PF7P0H5ah05aLN01HH7P0I6b405QPN01PJ800H5ah05QDL01HD6`0D4aP03a0B03Lh
>00F5aL04a8B01HE5@0A410201HE5@09014?400B41404Q0A01LD5@0C4A<05A<E01PF600J61X04a4C
00805aDG01h0518D04=1@`0[:B/06ALI01LE600E4aH09B<W028P900D4QH06aTM00h<400D4QH03`dA
01DC5`0J61`04@lC01LE600E4A804`l@018>3`0D41404Ph?01DA4P0B3Pl04@d>018>3`0G4a@05A4B
010<3@0E3a<2018<400301D?4`0D3Q804`dA00@04`dA00h04P`@01D?4`0@31404P`B018>4`0@2Q00
4P`A014;400G4AH04@X@01@=4P0@20h050`B01D=50804P/B00L05PlF01<<4`0@2A005@hE00l83`0>
1`h05@hE00803`P?01804PXB01@;4`0E3AD04`/C0109400@2Q403PPA00h:4P0B3QH05A4J06EPJP0d
<SX06a@L01463P0B20l050TA01463P0D2A4301873`804@H>03404`P@03H]=014?4@04@L@01hB800A
1aD040@G01477@0A1b403PXT010?:`0@4Rh061hj02`jE01?GWP0A51/01hXA@0J8D00414b01@B<00E
3R`05`dV01T;800E21X050DD01lC700H31@03`@:01453@0G2a804PH=02HJ800H31402`4501H:3`0P
51X04@H;01052P0@1@T02@0101042@0C1`/03`@701<8300B20/040D800`21@0=10H05``?01Cooooo
000Kooooo`0600@30@0<2`T020L500H50`0H5aD02PT7100>3@/200l>300=018A3`0H5aD04A0>00l>
300B4@l030/900/:200920H07QdK00`;2P0D4a40ATE3018>3@02014=308040`;0P0?2`X07@0;1`H0
3@T801@@3`0D40l04@d<00T5100L61L02`L6038^;@0O6aX0510?01`H5`0F4Q406QHE014=300;1`H0
3@T:010:3`0A31803@P>010;4@0A3a@03@/@00d<401?CU<04Q4F00d=4@0?3Q<03`h@00D03Pd;00/0
3`h<01HE4`0G5Q@03Pd;00`;2@0>3@/03`d;014=300B3Pd040`;00h:2@0300l;2P804@d<0`0@30/0
8`0?2`X03PX900h:2@0>2PT03`/:01@@3`0300008QhM01LC4P070`801P8102<O7P0A3@`06ADD01dI
600D40l04`l>01HB4@0I5A@02PH500d9200F4Q402`P700h=2`0100003Pd;0040000>3@/03@`;010?
3@0?3P`03@`:00`;2@0=30X040l=008030/90`0=30X00`0<2`T03`h<00l>300200l>3005010?3@0B
4@l030/901XI5`0B4@l00`0>3@/02`0920H03@`:00L6100<2`T051<A00D40P0=2``030X;01@B4`0E
4a@03`d>00<03@/<01805Q@E01LE5P0?3@h03P`=010:300C3Pl03@T:00d8300A3Q403@/>00H42@0I
5a`01`H;00/:4029R8h0;B`a00h<4@0>30l200d;3P803P`?1@0<2Pd0700=2`h04Q0A00P61`0;2@X0
3P`=00L51P030@8020H700H41@0;2@X03P`=00l=3P0A3a0040h?014?400>30d03@/<00h<3@0<2P/0
2PP901/I6P0F51D04@l@00H41@0<2P/03@/>00h<3`091`X201HD5`0=00H41`0?3A004@lB00L5200=
2`h0518E01`H7@0?2Q004`hD014<4P0<1`d03@P>00h93`0500l:400A014<4P0=20h02`H<010;4@0<
1`d02`H<00h93`0<1`d06QDK01@@5@0300@04`hD01`H6P0B3Pl03`/<010<3@0A3@h00P0?2``01`0>
2P/03@T:00h:2`0?2``03@P;00d83P0=20l00`0?2Q402P0=20l04@`C00`73P0>2A005A0G018=500>
2@l050lC00h93@0<1`/200`73@0801<>500I51/05a8I00H22P0:10h00`0701@?5`0?2Q0200l:3P<0
40/?00L04PdA014<400:1PT0;bX^00l:3P0@2`l03PT=00803`X>0P0@2`l00`0A31003`X>010;3`02
010;3`0?00l:3P0=2@X07QXI00/71@060P4030P901@@4`26PHL0<bhe018<5`0=1a<03PPF00/5500L
5R8081hS008020H901<00@0200/9300?3A002PP;00/9300?3A004Q0C01<A500A3a0030P700d91P0>
2PL040`;014=300B3Pd05Q8C01LC500A3@h03@P<00804@`@00<04@`B010;4@0>2@l00P0>2@l00`0<
1`d03PT?010;4@02014<4P0300l:400>2@l03PT=00<03`X>0P0>2@l06P0B2a<04``D018;4`0A1a80
40HA00l74P0?2Q403PT?00d83P0<1`d02PD;00h93`0;1P`050lE018=4`0@2a405A0F00h63@0A1`l0
4PP@018:4@0A2Q4040T@014;4P0B3A<03P`A0P0=2a000`0>31403`/?00h:2`0200h:2`803`/<0180
3PX;00d92P0>2P/03PX;00d92P0?2``040`?00h93`0=20h03`X@014<4P0@2a403`X@010;4@0A3180
40/A00l:400=20h600l93@0T010:3P0B310050hB010:3P0>20`03@L;018=4@0<1`/03PT=018=4@0@
2`l03@P<01/F6P0300805a8F02<N8P0>2@d030L;010<3@0>2P/05Q8C01DA4P0;1`P040`=00`82@0B
3Pl03`/<024M7P0A3@h0<bl`010<3@0>2P/02`L800X61`0<20T03@T:1P0?2``03@0920H05QDC00h=
2`030P003`h<00d<2P0920H03Pd;014@3P0?3P`03@`:00h=2`0?2`X00P0>2PT06`0?2`X040`;014=
300>2PT04Ph=014=300>2PT03`/:01H@4P0C2A004PL=0146300B1`/04PT:01<:2`0C2`T04@`800d8
100>2`H04@h700h:1`0<2Pd02`T<01<A500@3Q403@/>01<A500200d;300=00h<3@0?3@h02`X800T8
1P071@P06ALJ00/9300H5QT020H900X82`0?3A003@/>010>4@0200l=4006018@4`0@3Q<04@lD010>
4`0?3A8040hC0P0?3A801P0A3a@040hC00d;400>31403@X<01@@4@804a4B00D03`d>00`<300B4Q80
3`l?00h@3`0200lA400600hB4@0@4Q804A4A010@400?3`l0410@0P0B4Q8200h>3P0N014A4@0?3`l0
410@01HC5@0G4QH05Q@G01DD5P0A4Q@03Q8C00`@4@0=4A804A8D01@B5@0C4A@04a0D01`I800K6R80
5A@I018A5P0E5AL051@D01PH600G5aL05aLI010?5@0<2a405aHM01LH6P0D5QD04aDD0P0F5aT0400C
51P0414F014A6@0C4ad051@P01DE8@0H5bH0518W01TG;@0S8CP06AL/01`K;@0l>d`05aHT01HF8P0D
51h301<C6`8061DP01805QHP01LG8@0E6B804aLP01@H8@0H6b@051LP018@6`0A3aX04Q4I00d>400X
:bX02`d<01<E500E5QH061PH00/;2`0D4a<201DC500?01PE5P0F4Q<09R@U01LE5P0X9RL0B4I703@b
<`0:20T05aDF01@B4`0H5QL05aDF01DC500I5aP04Q0D00808AlT01T040hC01lM8P0<2Pl07Q`Q010>
4`0F51T061HK01<A5P0I5aX05Q8C01@@4@0C3a0061@E014=3P0E4A8061@E01HB4`0B3Pl07ATJ024M
7P0H51D05Q0D01<=4@0A2`l04P`@00804`dA0P0B310201<=4@0/018<400E41@04@lB010>4@0>30l0
40hA01HA5@0B3A407ALK00d72`0@20d02`8701D<4@0E3A<04P/B01<<4`0D3A@04P/B0109400?20l0
2@8900d63@0@2A004@XA01L@5`0D31@05`dH01T?6P0G3QT04PXE014;5@0B31H05A8K00L43@0K6R80
fMSP09FEW@0C3A@08QLO03X_=`0H3AD01`0401483P0A1Ph201873`0U01053@0?10`04PL?02@K801S
FF408aHP01814@0G1QP05@PJ00`0600I42/03P`Z00489@0>73T07S5=055ZP02fcnD0/lSQ06]jV@0m
BV`0=ciS01LI?`0C4S@04``Y0188800@11P050LG0104400@10h040D=00l4300>0`X03P<90146300>
0`P02`0400d21P0200l4200:00P0000>0P@02P0000X0000900006Ph@01D92`0?0`D03P8401041P80
20005?ooool001_ooooo00T03`h<01DD4P0E518040l=00T81`0A40h03@`:00l>300@3`d00P0A40h0
3@0@3`d03Pd;00/:200T8b4061LE030_;@2NWI/0>cXh00h=2`0;2PP04A0>018A3`0D4a400`0B3Pd3
014=30803@T801`030P7014=300=2@P04Ph=01@@3`0H51<04Ph=020L6`0;1`H01`<200`81`0@30/0
20@3018>3@0H51<020@501<=4@0B3A4040/?018=4@0B41<040hA01DC5P0N7R004A4C01HF60061PP0
4a8C1@0>3@/0500A40h061LE01XI5`0B4@l03Pd;00l>300?3@/04@d<018>3@0@30/03PX900l;2P0>
2PT04`l>01LC4P0A3@`030P7018>3@0D40l03`/:0`0@30/06@0?2`X04Ph=00<0000>2PT04@d<01hJ
6@0C3`h08AdL010<2`0C3`h0510?01<?3P0A3@`02PH501/G5P0;1`H06QHE020L6`0/:2L03@`:00L6
100F5A<06aXH00l>300H5aD01P0>3@/200d<2P<030/900<03@`:010?3@0@3`d00`0?3P`06`0A40h0
4a8@02d/:P0M71X02`X8014@3P071P@03`h<01LF500920H03`h<020O7@0;2PP030X;00h<3@0B4140
4@l@00h<3@0@3Pl02@L8014?400G5AH04Q0A00`:2`0B41404@/=018=3`0200h:2`0:014>400>30l0
7A/P00P730030PL04a8H01TH7P0920d03`dB00l=40803P`?0P0?3A0200/9300^00`:3@0>30l03P`?
00l=400<2P/04a4B014?40081PL04a4B028P8@0D4Q<02`T:00`:2`0=2``03P`=018@4@0;2@X02PP9
00T7200?3@h040h?00/92P0<2P/08R0Q01`J6`0B41401`D6014?400<2Pd03@/>00/9300>30l030X=
00H41`0<2Pd0?S`o00h<3`0B41<02@L:00l;3`03008050lC00h93@070PH050lC00h93@D03`X>00l0
4@`@00d8300;1PX040/?00l:3P0=20`040/?00D0100300807APL01/F6P0>2@d04@d?014=3P0>2P/0
0P0?2``02@0>2P/03@T:00`82@0;1`P03@T:00l;300>2P`03@P>00h93`0200l:40<03PT?00H03@P>
01<>500F4AL04@`B00l:400A310200/62P0:010;4@0?2Q003`X@02`W;P1:AD`04`hE00`6400I4ad0
:R@]00l:40803`X>0`0>2@d010080`L050lC00`82`0?2Ph200h93@0300d8300>2@d03PT=00803`X>
00<040/?00l:3P0@2`l00P0@2`l0500?2Ph03@T:00H20@0B3Pd02PH501PD5@091PP0>SDk03Lb>@09
0`h03`TE01D?7@0H4R00@ce909NEVP0G5AP03P`?02PV:@10?T40518E0P0>30l0300?3A0040hA00d;
3P091`P02PH500h:1`0B3P/04Ph=00h:2`0=2@X05a<D01<>4P8030L;00`04@`@010;3`0C3Q@040/A
018=4`0A31803PT?00l:400>2@l040/A014<4P0B3A<2014<4P8040/?0P0A31002`0@2a403`X@01<<
500D3AD04P/C01084`0?1a8040PC00h9400?2Q403PT@008030L>00X040/B00<01@0<1`h040/B00P3
2P0A31<02`<;01063P0A1`l04PXA0P0A2Q400`0A2a8040/A00d;400300`:3`0D00d:3@0>2P/03`/<
010<3@0A3@h040`=00h:2`0<20T03PX;00d92P0<20T03@T:010<3`0?2Q003PT?00l:400@2a403`X@
00h93`0?2Q02014<4P8040/A1`0?2@d05P0A2`l04P`@010:3P0>20`03`T=010;3`0;1PX03@P<018=
4@0>2@d02PD900T42016@DD0CDQ<00@00`080`L04PdA01<?400=2@X040`=014=3P0;1`P200h:2`0;
01DA4P0A3@h02`L803Pd=@3;alP06aLH01DA4P0=2@X02`L800d92P0A3@h01P0>2P/030071P@0:RTW
018A3`0;2PP05aHD00`;2@0?3P`030/900L6100510802`X8018A3`803`/:00/03PX900l;2P0@30/0
4@d<010<2`0D40l04Ph=00l;2P0@30/05@lA01@:400201<83P0M0189300C2P/050/<01<>2`0A30T0
3@P500h;1P0B3`X04@d:00/92`0<2Pd03`d@014?4P0@3Pl03P`=00`:2`0@3Pl04@l@010>3`0?3P`0
40l=00l=400b<3<02`T<00l=400<2Pd040hA00l=400=2`h00P0@3Q405P0>30l04@lB010>4@0>30l0
3`d@010>4@0?3A003@/>00h<3`0A3a804Q0C00l=400>30l03``>01LC500C4A804Q0A00d;30051@D0
30`<00l?3`0?4A02010B4@0300hB4@0@4Q804Q8B00@04A4A00`04Q8B00h>3P0=3@d0410@00h>3P0?
3`l05Q@F01TD600G5AP05QDG018C5@0>4Q<200lC500A01<C5@0C4A@04Q0C018>4`0A3QD04A0H00h=
4`0?3Q<05ADG01HF5P0D51@05aLG01PH6P0?3Q@04A0F02/Z<@0E5QX00P0E5QP04@0E5QX051DI01<D
6@0A4AT04Q8J01@D7P0F5R005aLQ01LG900Q83807A/`01`J;`0Q7c@0<S5301TH9`0G5R@05aLR0080
5QHN00@051DJ01<C6`0I5R406aPS0P0K6bD01@0G6b@05ATR01HJ8`0E6B805APQ008061HQ03406APP
01PI6`0B5A@04A<B02<U900C51@06QXJ00l?3`0E51@05Q@E01PF5`0K61T05Q8C01/I6P0@3Pl05aDF
02`Z:`0N71d02`T:01DC500C4A805Q@E01DC500D4Q<05aDF01<A500B41<05Q@G014?4P0N71l04Q0C
014?4P0E4aH06QPK00X82`091`X05Q@G01LC500B3Pl04@d>01XF5`0C3a005Q8C01DA4P0B3Pl03PX;
01PD5@0O6a`06ADF00805Q0D00@05@lC01<=4@0@2Ph03`T=0P0A2`l01P0B31004`dA01@>4P0@2`l0
3`d@018@4`803P`?01L050lC010:3P0I4aL040X>01TA5P0A20d04`X?01493`0A2Q404P/B01<<4`0A
2Q403`P?01D>5@0M5Qd08AXQ01<<4`0@2A004``C00d4300C2A805P`E01@<500201094@0Z00d83`0@
3A@07Q/R00d;4@1?CU@0=C@j00`53@0;00P04`T@01T>5P0F2a<04PL?00l4300A1Ph04`P@01463P0@
1@d04@H>00H0100Z82P04`H@01H55@0O3R00?2a101lA:P0O5S4061Hd01PO?00]>5@0<dAP08VO]P3M
lol0k_oo0=;Qo`20SJl0?D=X01XJ?P0D434040TU01<:7`0C21T05@TF0P0A1@l05P0A1Ph040D=0105
300?10X01`0201D:3`0@1@T0200100/1100=0PH04@D90104200F2Ph0710D00h31P0E2@d04`L;0147
2@0800002`0301/?4`0D20`Dooooo`006oooool0200A40h02@P6014@3P0>3@/05QDC00h=2`0@3`d0
4A0>0P0@3`d03P0?3P`03@`:00/:2@0D4a4092<Q01HE4`13@T00^[Zh03/j>00D4a403@`:00h=2`0@
3`d03@`:1P0B3Pd0400A3@`05A4@018>3@0A3@`030P701@@3`0A3@`01P8201XF5@0810<06aLF01DA
400A3@`02PH6010<2`0C3`h2010<2`04010:3P0@2`l040/?014<40803`d@00<0<S0c09ZJW00S8bD0
0P0@41800`0=30`03Pd;00h=2`0200h=2`0Y00l>300@3`d04Q4?01@C4@0B4@l03`h<00h=2`0?3@/0
4@d<018>3@0@30/03PX900l;2P0A3@`0510?01HB4@0B3Pd03`/:01@@3`0F4Q404`l>01@@3`0E4A00
510?01<?3P0?2`X04@d<01/G5P0?2`X08alN01XF5@0C3`h061@C01<?3P0>2PT0510?014=300@30/0
5A4@00l;2P0;1`H00P0C3`h0200D4a403@`;010?3@0?3P`04Q4?00l>300=30X03Pd;0P0@3`d01`0>
3@/03@`:014@3P0@3`d03`h<00h=2`0?3P`00P0A40h00`0@3`d03`h<00h=2`0200l>300=00`;2@0J
6AL03Pd;00`;2@0@3`d02PT700P71@0@3`d02PT700P71@0@3`d051<A00/92P0200l=3P0;00d;300>
30d04Q0A00/92P0A3a004a4B00l=3P0>30d040h?018<3@0A30d00P0@30d02P0@3@l03`d@00/93@0>
3A404a8G00`<4@0?3Q@02@P=010>4@0?3A0200h<3`0300l=400@3Q403@/>00D03@/>00L03@/<00`:
2`0;2@X02`T:01`J6`0[:BX05aDF00803`d>00/03@/<00X82@0=2``05aDF01PF5`0B41403P`=00d;
300;2@X040h?01DC500200d;300D00X82@0B414030X=00h<3`0A3a8030X=00X82`0@3Q4030/=051>
D@0I5aX02`T<00l=400C41<0?3Lk018=4@0@2`l02`H:01LB5P0=20`700l:3P0=014<400?2Ph03PT=
00l:3P0>2Pd04`hB018=4@1GDUH0EE1D01@?4`0=20/03`/<00h:2`0300d92P803`/<00@03PX;00l;
300A3@h03`/<1P0>2@l200l:400A01<>500B3A<03PT?01@?5@0@2`l03@P;01HA5@0P6b006QDJ00h9
3`0>2Pl07APN018=500>2A408Q`U02XU;@0?2Q000P0?2Ph02@0>2@d03@P<00d8300E41@030L;01@?
4`0@2`l03@P<00h93@0200d830803PT=0`0?2Ph3010;3`0]00l:3P0=2@X03`/<01LC4P0<20P05a<D
014=3`1LEed0<B`c010:4`0?2A@03@LD00P33`0Q6bH0<S0e00d;3P081`T03@/>00h<3`0:2@/030X=
01<A500A3a802`T<00l=400J61T03@T800l;2@0@30X03`/:00d92P0<20T03`/=00d8300:1@T03`X?
014<4@0=20d03PT?00d83P0A318040/A00d83P0@2a403@P>00803PT?00@04@`B018=4`0B3A<04@`@
0`0B3A42014<4P03018<4`0C3A@04P`C008040TC01004@XD00l94P0:1@d03@P@01D@600D3QL04`hF
01H@6@0A2a@03@P@00h94@0@2a<04P/B01063P0A1`l04PTA0P0B2a800`0A2a403PT?00`:3`0300`:
3`0300d93@0>2P/040`=00804Ph?00P04@d>00l;300>2P/040`=00l;300=2@X03PX;014<40<040/A
00D03`X@00h93`0=20h03@P>00h93`0200l:4003010;4@0?2@d03`T=00@03`T=00H03PP<010:3P0A
2`l040X>00l93@0B310200d8300700l:3P0;1PX020<701<>4P0@2`l06ADH01lJ7P0200l:3P0600h9
3@0@30d02`L800h:2`0D41404Ph?0P0?2``02`0;1`P040`=01dI6P0C3a00:BDV01TE5P0F4Q<04@d>
00l;300@30d04@d>00H03`/<00H030/9020O7@0;2PP04A0>01@C4@0=30X2010?3@0401<B400E5180
4A0>00T81P804@d<0P0?2`X01@0@30/04@d<00l;2P0@30/03PX9008030P700D03`T901<93@0C2@d0
4`T=01893002014:2P0=010:2@0@2`P040`9010<200?30L03PX700l=3P0@3Q003@/=014?4@0A3a00
2`T:00`:2`0200l=3P0D014?400H5aH07A/L01<A500V92L03@/>00l=400>30l04@lB00l=400>30l0
4Q0C010>4@0>30l040hA018@4`0>30l04@lB01<A500A3a8600l=400>01hK7@0W8b@0518C00l=3P0D
4Q<04A4A018B4P0>3Ph03a4@014C4P0@4Q403A4@010B4P0D51@201<C4`<04A4A00X0410@01<C4`0H
61P04a<C014A4@0E4Q@05A0D01<A500D51H051DG0`0?4a@0900A4Q@04a4D01<A500D4AD04@hE01/J
8P0O7R@051<H018B500C4a@05ADF01<C500C4QL03`hD018A5`0W9Rh04Q<J01HF7`0F5ah05ADN01LG
800D51d05QHO01DE7P0E5Al06ATR01XJ8`0I6B<071//02<R<`0E52D08B0`04M6E00U9C4061PS01XJ
8P806Q/P01<061TM01HG6`0K62406aTT01PH8P0G5b405aXS01XN9`0L82T05APQ01@G800G5B00518M
01DD700E5QP051LF028T8`0Y:bX04a@C00805QHF00/05aHG01HD5@0I5aP06QLH010<3@0F51D061HG
01<A4P0D4Q<04@l@01lM7P02018@4@804a4B0P0D4Q<0<@0K6A`0518E01LE600B41<061HI01HD5`0G
5AP03`d@01hL7`0C4A@05A<F01HD5`0H51D05A4B018>3`0G4a@040`=01HB4`0D41404`l@014=3P0E
4A805a<D01<?400A2`l0618F01XD600G4AD04P`@014;3`0B31004@/?018<400D3Q805Q0D01D@500E
4aH04Q0C01DC5P0@3Q403`X>01D@500K5AT030H:018:3`0?1P/05PdB01@<4P0B2a800`0C31<07@0B
2a805@hE00/42`0=1Pd04@XA0109400C31<040P?01<9400D2Q<050`C018;4@0@2A4050hE00D11@0?
2a804@lD00X93@0:2@h05@hE01873`0G3A@03P<;00l4300B20l03P<;01463P0D2A404PL?008040D=
01P04`XA01473`0F2A<05PHF01<75@0N3b<07@lX00l77P0b<4/07R8n034iE@1WMY00`]C^0>_lo`3^
oOl0c=Sb071iV`0c=e/07Adn01DB<00?22404`XL01<85`0B1Q4201453`804@H>01@04PL>01873@0@
1@/06PlD00l4200<0`D05@X>00`11@0:00<04@D;00X00`0=0PP02`4501L:400E2a003P@801/>500S
5Qh04PH<01052ACooooo000Kooooo`0600l>300F5A<071/I00P71@0U92806aXH0P0>3@/00`0=30X0
3Pd;010?3@02014@3P8051<A0P0C4Q001`0F5A<06aXH01/J600510804Q4?014@3P0920H00`0A3@`3
018>3@0J01<?3P0810<02`L600l;2P0G4a8030P7018>3@0@30/04Ph=01HB4@0300003PX9028N7@0L
61L03@T8018>3@0I5A@02`L6018<3`0C3Q805a8F01HA5@0@3Q404@lB01`J7@13@dD200h>400500D5
1`0?3Pd03`h<00l>300>3@/00`0=30X00`0:2@L02`X800l>300200`;2@0:00l=2`0A3@`04Ph=010<
2`0>2PT03`/:018>3@0A3@`040`;014=30804`l>00@04Ph=014=300A3@`04Ph=0`0A3@`0500=2@P0
4`l>00l;2P0:1PD040`;01@@3`0I5A@04`l>00d9200B3Pd040`;00d920060P405A4@00l;2P0P71/0
5A4@00h=2`0`;bd0:2LU0P0100001`0?3P`03Pd;00l>300@3`d03`h<00h=2`0<2`T00P0A40h3010?
3@03014@3P0?3P`03Pd;00<03Pd;01/040l=01HE4`0?3P`02@P601LF500@3`d04a8@00l>300I61H0
1`H401@C4@0_;R`05A@B00X82@0?3@h03@/<00`:2`0?3@h03P`=010>3`0?3@h030X;00h<3@0A3a00
2PP901<=3@0?2P/00P0@30d0200>2`d040hA065OHP0I5a/07ahS010?500920d01PD:0P0?3A0200h<
3`803`d@00h040hA00l=400>30l03@/>00`:3@0;2@`040h?00h<3@0A3a003P`=00L51P0610D03P`=
00`:2`8040h?00P030X;00d;300B41406ALH01<A4P0<2P/03P`=010>3`<03`d>010071XK00h<3@09
1`P03@/>014?4P0B41<03@/>00l=400F51L04Q0C01DC5P0>30l03`d@01/I700D41@0FUEI0P0@2`l0
0`0A310050lC00d8300500l:3P0900`72`0>2@d040/?00`72`0=20`03PT=01@?4`0B3A402PD90080
30L;00L04PdA01PC5P0?2``03`/<00d92P0<20T03PX;00804Ph?00D040`=014=3P0A3@h03`/<00l:
3P0200h93`0F00d83P0>2@l03`X@00/6300:1@/03@P>00l:400@2a4071LL01@@4@0?2``04@`@01HA
5@0D3a<04PdC00h93`0300@04@`C00X5300J5A`061<K010;4@8040/?00X03PT=00d8300=20`04`hB
00l:3P0>2@d020<7018=4@0>2@d03@P<0P0>2@d200l:3P03010;3`0?2Ph040/?008040/?01`03`X>
00d92P0N6Q/02PH600d9200Q7Ah03PX<014<40060@L02@@<00`6400>21804@/G018<5P091``01PD7
00<1100>30l03`d@00/930091`X04a4D010>4@081PT03`d@028P8@0@30d03PX90P0<20L0300>2P/0
3`/<00X52@0>2@d030L;00l:400A31803PT?01HA5`0M61h05a8H00h93`8030L=00@03@P>00`73@0=
20h03PT?0P0@2a42014<40804PdA00<04@`B010;4@0?2Q400P0@2a8200h84P0=010:500E3aT030H@
00l94`0F41X04P`F00L32`0F41X02@<=01LA6`0I4ad00`0701494P0201473`0601083`0A2Q404P/B
00l9400<1`d02`T>0`0<2Pl00`0=2Ph03`/<010<3@02010<3@803`/<00/040`=014=3P0?2``03@T:
00h:2`0@2a0040/A014<4P0?2Q003@P>00h93`02010;4@0400d83P0:1@/02PD;00T42PL03`T=0140
40X>014;3`0>20`03PP<018<400:1@T03@P<010;3`0<1`/03@P<02@O8`080`L071LK01@?4`030080
4PdA00/62P0200`82@07010<3@0F4Q<05A4B010<3@050@80510A01PD5@0200H20`0700T51P0;1`P0
3@T:00l;300@30d03PX;00`82@06010<3@0<014@3P0;2PP020L500l>300=30X04A0>00T81P0<2`T0
40l=018A3`0A40h03Pd;0P0B3Pd3010<2`03014=300@30/040`;00803PX900<03`/:010:2P0A1`/0
0`0B2@`06P0?2@T03PP8018<300D40d06ADB01LC400A3PT04@d:014@3P0A3a0040h?00l=3P0B4140
5A<D010>3`0<2P/02@L800X82@0A3a005A<D00l=40050`H03P`?010>4@0=2`h03P`?0P0?3A001P0B
41<040hA00`:3@0>30l04Q0C010>4@804Q0C00<04@lB018@4`0@3Q400P0=2`h02`0?3A0040hA00/8
2P0B3Pl040h?00d;300K6AX0<c<c030`<00?3`l03a4@0080418A00<03Q8A00lA4@0B4Q800P0B4Q83
014A4@06018B4P0G5aL07AdM01HF5P0A4A404A0A0P0?3A000`0B4aD051PI014E5P0200lC500T010A
4`0B4Q@0518E01LC600C4QX08B0X02TX;`0H5a`040lD010@4P0K6ad05ADG01<B5`0B4AL040lE014@
6@0A41h05QDU01LF900K6RP08b8`01/K9`0O7b/06QXT01DE7P0H620071`T01lO9`0E5B4071/Y01HF
8`0A4Ad03@dG028R:`0E5Ad05QLL0P0F5a/0100F5aX051DI01XG800K62<201LG8@0b01dP:@0W:c@0
6QhW01<G800G6R<06QPS01PF8@0P7bL05AHH01/N7@0H6QT04Q@C01@E5@0J6QX0410@01DD500E4a@0
5aDF01TF5`0C3a004Q0A010>3`0B41406aTJ014?400?3@h040h?01<A4P0A3a004a4B01DC500B4140
5Q@G01PF6@0E4aH04a4D01@B5@0G5AP04@lB02HT9`0k>C`0518E00h<3`0?3A005a<D01HB4`0D4140
6ADF010<3@0C3a0301PD5@0501HB4`0C3a004@d>01D?4`0C3A400P0@2Ph00`0I4aL081XN01@>4P02
018<400401<=4@0F41@04@`@01PF6@803@/>00T05Q@G010;3`0K5AT0:28V01XD600Q6Qh060lD01H=
4P0B2Q000`0C31<201@=500G02lX;`0U7RD04``C01@=500<1@`03`P?018:400A20d04PT>01@<4@0C
3A404@/?010:3P0F4AD061<G00T420030@@02PD900d6300800D06PlG01H;4`0J3aL00P0?10`07@0A
1Ph04`P@01463P0@1@d04@H>01H<500G3AD04PHA00/0300H2QT05@LJ00T04`040180;2U1010B:`13
BF40SiZd05ESOP2JZ<D0f>?o08jG^00f?5h05QPh014>;@0;1b802P@H01465P0A1a804PL?00803@4;
00/03@8:00h32`0>0`X03P<900T0100<0@H040D901/@500O51P02`0600h12P0201<63`0501/>5`0?
10/0200401853P0M4aT00P0800@00`0E21402`07ooooo`0Cooooo`006oooool01@071P@04Q4?01<B
40040`4051<A00804Q4?00L040l=00d<2P0=30X040l=01<B400?3P`01@@200804Q4?00P020L501LF
500@3`d0HV5O01TH5P0:2@L05A@B010?3@<040`;02404@d<018>3@0B3Pd04Ph=02<O7P0Y9B@02`L6
01TE500810<0510?00/71P0=2@P06ADD00<0000O6aX0AT91044m?00E4A00510?01hJ6@03000050h@
01LC500N6Q/071PI018@4@0C4A803`d>00P8200<30`01`L703@d=00K6aX00P0@3`d01`0>3@/030/9
00`;2@0>3@/030/900/:200?3P`00P0;2PP01`0@3@`04@d<018>3@0@30/03PX900l;2P0@30/00P0?
2`X5014=30<040`;00D04@d<00l;2P0J5QD040`;00h:2@0201HB4@05014=300@30/03PX900`81`0>
2PT0100?2`X02@0;1`H03PX900X61@0J6AL0]KBb06ASH@061@<08b8P014@3P03010?3@0300h=2`0=
30X030/900803Pd;0`0?3P`06@0>3@/03@`:00d<2P0=30X03Pd;00l>300A40h07QdK01TH5P0@3`d0
5aHD00d<2P0B4@l020L500d<2P01000030/9024P7P0920H02PP900h<3@0;2@X03@/<014?400:20T0
0P0@3Pl01P0:20T030X;014?400:20T050h>00l:2@804@d<00D03@X:014?400X9RT0?Sdo00l?4@02
014@5@0301<B5`0>30l03P`?00803@/>1`0>30l04@0=2`h030X;01TG600J61T02PP900T7200B4140
518C00l=3P0A3a003`d>00/92P0<2P/01P@500d;300;2@X03@/<00804a4B01L040h?01<A4P0F51D0
9R@U01<A4P0;2@X03@/>014?4P0>30l030X=00l=400A3a803`d@00L5200?3A004Q0C00T72P091PP0
81`M014=3P0;1`P04Ph?01@@4@0800l;300F00`82@0=2@X05A4B01<?400=2@X02@D6010<3@0B3Pl0
3PX;00d92P091@H03`/<010<3@0>2P/030P900l;300A3@h03`/<00h:2`0@30d04Ph?014=3P803`X>
0`0=20`0100?2Ph030L;00X52@0=20`2010;3`0>01LB5P0?2``02`L800`82@0=20`030L;00l:3P0A
318040/A00l;400300D05A0G00H2200B3A<2014<400500l:3P0>2@d03PT=00P31`0A31000P0B3A40
0`0D3a<03@P<00h93@0200l:3P8040/?00<04@`@00l:3P0@2`l00P0@2`l0200?2Ph03@T:00<0000W
8b<05Q8C00<0000?2Pd04PdA0P0E41H03@0B3A@03`XA00X53P0910/03P`A010>4@0W9BP00P0300L6
200@3Q403@/>014?4P0<2Pd00P0610L05`0=2``03PX;00d9200<20L03@T:00h93@0?2Ph040/?01<>
500?2Q003@P>014<4P0B3A<06aHL02TT:P0J5A/03PT?014<4P0=20h040/A00h93`0=20h03PT?0080
40/A00@040/?014<400A31004@`@0P0@2a402P0;20l03@XA00`9400;214030TB00d:4`0D3QX04@/G
010:5P0A2aL200l95@0>01H@700H4Qh0CTQD03dg@`0@2QH05PhG0188400A1`l040P?0109400A2Q40
3PP>00X52`0:20d200/93P0500X83@0>2Pl040/?00l:3P0>2@d00P0=20`03`0>2@d040/?010;3`0>
2@d030L;00d8300>2@h03`X@014<4P0?2Q003@P>00l:400A31803`X@00d83P0200/6300300`73@0?
2@d03`T=00@03`T=0`0A2`l200h8300=014;3`0?2Ph03@P<00h93@0=20`03PT=01dH700>2@d01`86
00X62@0C3Q804@`@010;3`03010<3@804@d>00T03`/<01<?400=2@X02`L8018>3`0N6Q/02PH700d9
2P0?2``00`0B3Pl00`0@30d03`/<00l;300400l;300>018A3`0<2`T040l=00`;2@0@3`d04a8@00`;
2@0F5A<04a8@00T81P0;2PP06APF01<?3P0B3Pd4010<2`0L014=300@30/03`/:010<2`0A3@`04P`<
01892P0C2P/050/<018<300@2PX03`T901DA400F4Q406aLF01LF4P0B4@d051<?00h=2@0?3P`04Q4?
00l>300F5A<092<Q014@3P0=2``030X;00d;30803P`=00<04Q0C00T72P0E4aH00P0B41<0200C4A@0
3`d@00l=400C4A@040hA00`:3@0=2`h040h?0P0A3a004@0?3@h040h?014?400?3@h03@/<00l=3P0A
3a0040h?018?400P71d071XK00l=3P091`P0410@01TI6@0?3`l03Q0?00803a4@00D03Q8A00lA4@0?
3`l04A4A018B4P02014A4@0b018B4P0A4A404a<C01LG5`0B4Q803`l?018A4`0A3a@040hC01<C600D
61/03a@G014F6@0@5AP04A<G014@5@0B4AH0518G00T8400B4QX061TO018C5`0A4QH04Q<E01DF600A
4Q@051DI01TJ7`0F5Qh05QHQ01@C8`0H5bT06APZ02<R<P0^;Cd08b<`038b?P0X:38061PQ01@D700G
61d06AXO01PH8P0N7RX04Q8M01XJ900E5Ad06ATP01DF6`0E5QX201@E6@0Y01DF600E5QX06aPQ01hL
9`0K6bD061PR01/O:00T:3405ATR018E7P0J7BH07Q`W01lL9`0^;CD08b@X01`N800E5QP03PlA01DE
5`0B4Q@03`lA01HE600G5AP05Q@G01PD600E41@05A<D01TG600G5AH06aTJ01@B4`0N71d040h?01@B
4`0A3a004a4B01HD5@0B41405Q@E01PF5`0@3Pl0100E4a@0300n?3d0EE=D01XH6@0E4a@06aTJ01LC
500A3@h0510A02<O800F4Q<04Ph?01DA4P80510A01/04Ph?014=3P0C3a005Q0D01D?4`0A2`l03`T=
01PB5P0O6Ad05@lC01<=4@0B31004`dA01D?4`0B3A40FeUL06e[KP0_;C005A<F010;3`0F4AD09R0T
01lI7@0/92T07aHK01L>4`0@20h00P0A2Q402P0B2a804``C01<<4`0M5Qd040T@00L01`0:0`X03@H=
018;4P0@20h200h5200@0149300A2`d03`T;01<=3`0A2`d01000010:300A3@h030H801<;4@0W72@0
=b`d00h32`0700@060dE01463P804PL?020040D=00l4300B1`l04`TB00H01@0<0`d04`LE00h2400E
21X09AT]01H=8P0C3bD071db01/P=P0e?5D0;cQE04QCL@1dO9/0CU=c03DhF@0K6cX030TV00T5700=
1aT04PLE01063`0C20h03@8:00h2300>0`/03`@<0105308040D;01403`@901<8300H3A405@X>00`1
1`0@0``0200501853`0K3QP03@0:028E7`0800D0NFaf04i1B`0800D0300900h12`0Dooooo`006ooo
ool0600=30X03`h<014@3P0A40h040l=01@C4@1/JfT09B@R00/:200B4@l03Pd;010?3@0C4Q003`h<
00X91`0920H04Q4?01<B400;2PP0:2LU00/:200A40h03@`:00/:208040`;00P03`/:018>3@0B3Pd0
3`/:01@@3`0d<2l0?c/j014=30804Ph=00h0;BTX02XV9@091@@03`/:01LC4P0A3@`05A4@00h:2@0@
30/03`/:010<2`0F4Q404P`>014=3P80510A0P0>30d00`0?3@h051@D01<C4`0200h>3P07010?3P0>
3@/04A0>010?3@0:2@L03`h<014@3P0200h=2`07014@3P0>3@/03@`:018?3P0E4A004Ph=00h:2@02
01<?3P0400d9200>2PT04@d<018>3@803`/:00`040`;018>3@0A3@`040`;014=300B3Pd04@d<018>
3@0:1PH05A4@01<?3P0;1`H2010<2`0A014=300@30/040`;01<?3P0>2PT0510?00d9200@30/03@T8
01HB4@0J6AL0?Sdk03Th=P0?3P`02`X800`;2@0@3`d00P0<2`T01@0D4a402`X8010?3@0=30X03Pd;
00<03`h<00<03Pd;00/:200<2`T0100>3@/00`0=30X03`h<00`;2@0200h=2`804Q4?01/03@`:014@
3P0<2`T02PT801LF500;2@X030X;00d;300?3@h03P`=00/92P0>30d040h?00`:2`0;2@X03@/<00/9
2P0C3@d03`X9010<2P0@30/03P/:010>3P0B4180AdI803@d=P0=31000P0:2Pd0500?3A0030X=00L5
200@3Q403P`?010>4@0>30l04a4D00h<3`0=2`h040hA00h<3`0@3Pl03@/<00h<3@0?3@h03P`=00l=
3P0>30d030X;0P0>30d200`:2`8040h?00`03@/<00l=3P0@3Pl02`T:00d;300A3a004a4B01/I6P0A
3a003P`=00d;3P0?3A0200`:3@0400h<3`0<2Pd030X=014?4P<02`T<00@04@h@00X71`0I5AH03@T:
0P0?2``01@0=2@X040`=014=3P0@30d04@d>00804`l@00X04@d>00/7200A3@h0DDe>01hJ6`0:1PL0
3`/<010<3@0<20T02`L8100?2``0100>2P/03@T:00l;300A3@h300l;308040`=0P0?2Ph01@0>2@d0
3@P<00h93@0?2Ph02PH900<040/?01T04PdA00l:3P0<20T03@T9014=3@0A3@l03`/=010;3`0@2a00
4`hC00/6300F4AP04@`C00d83P0B3A404@`@00l:3P0B3A403PT=00h:3@0<1`/03`X>00`72`0?2Ph0
3@P<008040/?00@04@`@00h93@0>2@d04@`@0P0@2`l200l:3P8040/?01d03PT=01@@4@0=2@T04Ph?
014=3P0C3a402@D800l:3`0=20d03PT?00`73P0=20h050lF00/93@0D4QD0?3Xm01PF6@0?3A002@L:
00/9300>30l02`T<014?4P0O7B003P`?00h:2`0>2PX03`/;00l;3@0200l:3P0505=>D`0a;3804PdC
00h93`0A31<00P0B3A<00`0K5Q`04PdC00`73@0200l:4003014<4P0?2Q003PT?00803`X@00<040/A
010:3P0A2`l00P0A3100500B3Q@04Q0E00d:4@0<2Q002`T@00`;50051@`040lG010;5P0B31L040XE
00d74P0?2A@04@/F01DA6P0l=T40@ce8038/=`0C3AP040PA0P0C2A403`0A21003`P?0109400>20h0
5A0F00l=4P0D4QL0=S@i018@5@0@31403`X>00h93@0=20`02`H:00`72`0200h93@0@00l:3P0>2@d0
3@P<00d8300=20d03`X@00d83P0A31802`H<02@O9@0e<3H03`X@00d83P0>2@l040/A014<4PL03`T=
00P04P`@014;3`0?2@d03`T=010:3P0B3A403PT=00`72`803@P<00T03PT=018=4@0?2Ph04@`@01/F
6P0D3a<040/?018>3`0C3a000P0?2``01P0>2P/03`/<00l;300<20T05a<D010<3@803`/<00P02`L8
018>3`0=2@X03`/<01@@4@0:1`L03`/<00h:2`804@d>01@03PX;00l;300=30X03`h<014@3P0:2@L0
40l=00l>30081`D07ahL02LV900C4Q002`X900h=2`0?2`X04`l>01HB4@0I5A@03@T8014=30803PX9
01l03`/:010<2`0A3@`040`;014;2P0C30/050d<01<=3@0A30`04@`;014=300=2PT05Q@B00d<2@0C
4a003`l:00l>2P0=30P04Q4<010?2`0C4Pl07QdJ010?3@0;2@X030X;01<A4P0C4A<040h@014?4P0B
41<02PP;00<04@lB00h040hA014?4P0<2Pd04a4D00H51`0C4A@03`d>010>3`0?3@h03P`=010>3`0A
3a003`d>00h<3@804@l@01003`d>00h;300@30d03@/<01@B4`0]:b`0>SXj01DE5@0?3`l03Q0?00lA
400>40l041@C01<E500G5aL04Q8B0`0A4A40<00E5AD0410@010@400A4A403@d=00h>3P0E51L04@lE
01DD6@0?4AH061/O018G6P0T:B`05Q/O00hB5P0D5AT051<I018@5P0A3aX04A4K018B6P0B4aP061TM
01<D600E5QT051DH01<D6@0E5Ad05aLO01LF8P0F52P07A/`01@B:00Y:3X0=SE502h]?00g=d<0:RXd
01PH800F5a`061TM01<D600>3aD08b<Z01HF7P0E5A`061TN014B5P8051DI00/05AHJ01LH6P0H6A/0
5aPL01XG800L6B@061PR01HF800C5Ql05ATR01TM9P0201DH8@0N01HD7`0D4Qd06aXR01TJ7P0C5AL0
4Q<E03@e=`0J6ad04Q8D01LG6@0G5QT061HI01HD5`0D41@06QDI01LE5P0C4A806aTJ028P8@0G5AH0
5A<D01@B4`13@D806QPI01PF5`0B41405A<D01LE5P0D4Q<03P`=0P0F51D01@0C4A805Q@E01@B4`0O
7Ah040h?00805Q@E00L05a<D00h:2`0F4Q<0:RHW024M7P0B3Pl05A4B00804Ph?0P0C3a00100D4140
5@lC01PB5P0H4QH201D?4`805Q0D0`0E3a<0:`0F41@08ahR0;:`/`3Zj>/0FEMJ018@4`0C3Q804`dA
01PB5P0?2@d04``@01<:3`0F3A805@dC00h73P0?20l04``C014:4@0D3A@06a@K01TB6@0F3aH05@hE
01<<4`0@2A0030H:00h62@0?1`X04P/>018<3P0C2`h04PX=01XB5@0A2P`040P;014:300A2@`050X?
00h32`0I3QH04`P@01L<500C21000`0B1`l0<`0@1@d04@H>01<8400@1Pl040LA01<9500K41h04@DC
01P<7@0B1aT040LI01PC9@1JEf/05aPZ01HJ;P0R9D807RA103XmG00a<U40<S5?010=:@0?2R804@XP
018;6P0B21<04@L?01873@0C210030<:00h42`0C21003`D;01@93`0K41H02`8500h31`0;0@@03P@7
00h52@0G2Q<04@@>01L:500;00P0718I07AWL@0X6bD09a/T01P;5@0;00P04@@>01853`0Dooooo`00
6oooool05P0<2`T03Pd;018A3`0@3`d03`h<01LF501RHEl07ahL00T81P0D4a403`h<00/:20051080
2`X800d<2P0E51804Q4?0040000;2PP03@`:00h=2`0@3`d2014@3P0300h:2@0A3@`03@T8008040`;
00@030P7018>3@0A3@`05Q8A0P0>2PT01`0E4A008QhM05QDD`0G4a8040`;01PD4`070`801P0@30/0
100C3@l03PX;00h:2`0@30d200h<3@0<010>3`0>3Ph03@d=00`<300?3`l04A4@01LF50020@003`h<
01lN700920H02`X80P0?3P`03`0>3@/02`X800/:200=2PT04Ph=014=300B3Pd08alN02@P7`0B3Pd0
30P7014=300F4Q40510?014=3006010<2`804Ph=00P040`;00l;2P0?2`X040`;00l;2P0A3@`040`;
00d920803`/:01803PX9010<2`0C3`h03`/:00`81`0;1`H020L500T81P0C4Q0030/900/:200?3P`0
4A0>010?3@0C4Q003Pd;00L6100920H600h=2`8030/90`0=30X00`0<2`T03Pd;00h=2`0400h=2`0<
01<B400;2PP03Pd;04e<BP0K6QP02@P601@B4`0>30d03`d>00d;30091`P03@/<0`0?3@h06`0>30d0
30X;00X91`0A2`/040/800h:1`0>2PT03P`:00h=2`0<2P/04Q4B018B500=3@l02`/=00d=3`0610L0
6ALJ01lM800100802`T<00h<3`0C4A@061HI00l=400>30l04Q0C00d;3P0300d;300400`:2`0:20T0
2@L800h<3@803`d>00/03P`=00d;300<2P/03P`=010>3`0;2@X03@/<00h<3@0:20T030X;010>3`02
018@4@0300l=3P0=2``03@/>00H03@/>00D04@lB00d;3P0@3Q4061HI00h;3@0201<?400E00h:2`0@
30d040`=00/7200<20T04@d>00T51P0300002@D600/7200300006aLH010<3@0Y9BH00`00018>3`0>
2P/03`/<00d92P0<20T03@T:00803`/<0P0@30d200l;300600h:2`0?2``040`=00l;300=2@X03`/<
1P0>2@d01`0L5a/07aXN00l:3P0>2@d061<G02<N8@0?2`X00P0@30/2010<3@0O014<400<1`/03`X>
00T42P0K5Q`05A0F00d83P080`L06aHJ00l:3P0<1`/04`hB02@O8`0B3A406aHJ01LB5P0=20`04@`@
010;3`0<1`/02`H:00X52@0@2`l04`hB00P31`0D3a<04PdA014<400B3A404@`@00h93@0400l;300D
00l;3@0?2Ph03PT=010;3`0>2@d030L;00d83@0A310030X=00h<3`0?3A003P`?00`:3@0:20/02@L:
010>4@0610L02@L:024O8P050`H300l;30<03`X>00l0BDA:03Ha=`0E41H03@P?014<4`0<1`h030L=
018=4`0?2Q002PD;00`73@0A31803`X@00h93`0=20h00P0>2@l06@0?2Q003@L;010:3P0@2Ph03PT=
00`:3`0=2a003PdC00P73@0G61d02PXB01TI8@0000L040`D00l94`0=20l03@P@00h84P0>214040/B
03La>`090``04`hE014;5@0D31@00P0C2A403P0A2A003`P?00l83`0A2a4030L=0040101FE5T0f]SM
05MEFP081@T040/?014<400@2`l03`X>0P0@2`l500h93@0900h93P0F4AL03PT?010;4@0400D04@`B
02dX;P0B3A<040/A00803`X@00<03PT?00l93@0?2@d0100?2@d01P0;1@T03@L;00l93@0D3Q80618F
018<408030L;0`0=20`05P0>2@d02`H:00T4200;1PX04PdA01<>4P0>2@d030P900l;300A3@h03PX;
00H20`0`;2d0@cm001TE5P0<20T0510A00/7200:1PL03PX;034];P0T824200d92P0301HB4`0@30d0
3PX;00804Ph?00<03PX;010<3@0=30X01@0=30X03P030P003`h<00l>300P7ad02`X801@C4@0E4A00
40`;00<0000400009B4P00T5100>2PT03`/:0`0@30/01@0?2`X040/8010;200A30T04P`<00804@d<
00d03P`:00`;2@0C4Q003@`:01<C4@0;30L04a<<00d=1@0E50l07QdH00/:1P0M71P040l=00803`d>
00D040h?014?4P0B41<030X=01PF6@0201<A500800800`0@3Q404@lB01@B5@0<2Pd04a4D01LE600C
4A@200h<3@0400l=3P0@3Pl04@l@014?40803`d>01L040h?00l=3P0?3@h0514B018>3`0>30d03@/<
01HD5@0^;Rh02PX:00l?3`0@4Q404aDD010B4@0A5A@0418B00P8200?3`l07QhN00l?3`071`L04a<C
01HF5P0201DE5@1^010@400B4Q805A@G00h=4`0H6Ah04aDJ01@I7@0>4aL07b@X010E6@0<3a@051DJ
010A5P0?3QD05QHP00H64P0I6B8030dB01<D6@0H6Ad06Q/O01/L800H6Ah06ATQ01dM9`0F5B806QP]
02PV?00K6Bh08R4c038a@@0o?d`08R8/01PH800?41H051DI01LH700@4A<051DJ01XK800B4aP04A8G
010A5P0C51P051DI01HG6`0I6Qh06a`P01dN8@0O82@06aPQ01XH8`0H62805aLQ01DH8@0D62404aLP
01<F7`0D5b0061HQ01PE800D4a/03a0D01XL7P0L7Al0^[^m051AD`0G5aT07AdO01HE600K6A`06QPK
01HC5P0R7B40>cTj02HT9@0M6a`05aDF00/92P0=2``01`D6051>C`0J61T06ALH010>3`0J61T05A<D
01@B4`0G5AH06ALH01HD5@0C4A805Q@E01LE5P0E4a@04a4B01DC500G5AH07ATJ01@@4@0F4Q<06ADF
01PD5@0>2P/04`l@010<3@0A3@h0510A01<?400@30d201D?4`@050hB00<04`dA01@>4P0E3a<00P0E
3a<03`0J5AT0=38e04a:C@0G5AP040hA01`G6`0K5QX050hB018<400B2`l04`X?01@;400Z8RP081TP
014:4@0301@=500701D>5@0B2a8030D<01<<4`0E3QD04``C018<4@0200l92`0401<=3`0?2@/040L:
018930804@P;00H04PT<01<:3@0D2@d04`P?01<8400F2a<201@94@0301P=5@0A1Ph04@H>00<04@H>
03404@H?020F8@0:0Pd04`TD00X03@0=0Q004PXG01D:6P0C2aX0208A02LS<P0<21L040hN01DB;@0>
3RX071Tf01XF<@0H52l030LO00h66`0@2A/03PHD00h43`0A1a004@H>01<74@0L41X05``D00X01`0?
10/03P<9020E6`0800807A8F01462P0800404PL=01@7400?0P`05@PB01033@0:00L07A0J00h12`0<
00T03`8<01D84P0C1Q002P0701Cooooo000Kooooo`0Z00l>300=30X040l=010?3@0>3@/04A0>00h=
2`0A40h030/900d<2P0@3`d02PT700h=2`0C4Q0040l=01LF500;2PP07ahL010?3@0?3P`03Pd;00l>
300A40h04Q4?00l;2P0B3Pd040`;00l;2P0@30/03PX9014=300C3`h02`L6010<2`0E4A004Ph=01TE
5@1HE5<05a<B00h:2@0L61L030P71P0@30/0200A2`/03PX900l;2P0B3Pd03`h<00d<2P0?3P`03Ph<
0P0=3@/01`0@40h02PT800L6100Q81h03Pd;00D40P0H5aD00P0?3P`01@0>3@/030/900`;2@0=30X0
3P/:00<04Ph=00T071PG01/G5P0>2PT03@T8018>3@0H51<05Q8A018>3@0?2`X00`0@30/2014=3080
4`l>00<040`;00h:2@0?2`X00`0A3@`01@0?2`X03PX9018>3@0?2`X04@d<00804`l>00<03`/:00d9
200=2@P00P0B4@l02P0920H030/900`;2@0;2PP03Pd;00/:200C4Q002`X8020O7@0<2`T600h=2`06
00l>300>3@/03Pd;00d<2P0>3@/03`h<1`0>3@/03@0E5180H5mM0=GDdP0];2X01@@201LE5P0@3Pl0
3@/<00/92P0:20T03P`=00l=3P0@3Pl00P0?3@h0100=2``030/9014;2`0@2`P200h:1`0400h<2@0>
3@/03Pd;00h=308030`<01403@d>00h>400?3A001P@700T72P0=2`h03`d@010>4@0B41<0518E00h<
3`0@3Q404@lB00`:3@0>30d03@/<00`:2`0300/92P0300l=3P0>30d03@/<00<03@/<00P03P`=00l=
3P0<2P/03@/<00h<3@0;2@X030X;00d;30803P`=0P0=2``600d;3P0?00`:3@0>30l030X=010>4@0F
51L03``>014=300@30/030P7010<2`0A3@`03`/:00d9200B3Pd05A4@00802PH500@040`;00<0000H
51<040`;0P0300004P0B3Pd03`/:010<2`0=2@P02`L600`81`0>2PX04@d>018>3`0C3a0040`=00h:
2`0<20T03PX;00l;300>2P/03@T:00l;30H03PX;00H02`L800h:2`0:1PL05A4B00l;300A3@h2014=
30<040`;00D040`=018=4@0<1`/03@P<018=4`0200X52`0D00/62P0M61`04`hB010;3`0910P040/?
01D@500Q72007aXN00h93@0=20`04PdA010;3`0<1`/04@`@01dH700N6Ad02PD901D@500B3A42014<
4003010;3`0=20`03`/<00D03`/<00H03PX;00l;300>2P/03@T:00h:300@2`l300d;3P<030X=00P0
4a4D01HD5`0K6A`030X=00X82`0A3a803PX;00h:30803PT=0P0>2@l02@0I51X04PdD00H1200=20l0
7QPR00`73P0>2@l04PdC00l:400201@?5@0400/6300?2Q003PT?00d83P803PT?01003`X@014;3`0E
3a<05@lC014<400<2Pl02`T>00h=4`0I6Ql0VibQ02`]=@082a8092@/00h:4@0>2A003PT?0P0=20l0
6@0@2a801@0601D@5`070PT04`hD00X5300F3aH04`TA0188400A2A0040T@00l83`0@2Q006QDK00`:
3`0S8BH0JVQ]02<Q9P0;20d04PdC01<>500B3A<040/A018=4`0A31801@0>2@l00`0<1`d05A0F00h9
3`02014<4P0500@01@0>2@l04@`B018=4`0?2Q000P0>2@l600l93@803PP<00@03@L;01D?4`0K5AT0
4`dA0P0;1PX200`72`803@P<00P02`H:00d8300?2Ph03@P<00`72`0?2Ph040`=00d92P8040`=00/0
1P8303/g>01SGf00:RHW014=3P0J5QL04@d>01DA4P0:1PL05Q8C01<?400300`82@0600l;300>2P/0
4@d>014=3P0>2P/03`/<1P0=30X03P0@3`d051<A00<200030P00?C`j01LF500E4A005Q8A01PD4`0C
3`h0C4Q702HR8@0A3@`040`;100?2`X2010;2007014<2@0A3@X04@d<014=300D4a4040h?00D51@02
00/;2`0>00d=2`0<30<03Ph404i>AP28R8007A`G00T8100A40h05Q@E01DC500@3Q403`d@018@4`0>
30l200l=400<00/9300?3A00>cTl05QFF@030@@04a4D00T72P0>30l01@<600h<300?3P`040l=0P0A
40h00`0@3`d03`h<00l>300300l>300n018?3`0@30d030X;01<A4P0610D04A4A00`<300@41004Q@C
01HH5`0B51<04ADD01LI6@092@T071`L03dm?@0O7al04a<C01PH600F5QH051@D01<C4`0>3Ph0410@
01DE600B4AL04A8G01<E6P0>4aL05ahQ00hF6@0;4aH04aLK01LH7@0@4AH04Q4H01`L9P082QH07B0X
01XM8P0L7b@03a<F01DI700G6ah06A`Q01`O9P0N8BX051HS01LF:00Q7c@05QDX014@8P0Q83009bHc
01`L9P0F5Qh0414G014B5P0C51P0414C01PI7P0L7B8201<D6@0Q014B5`0E5Q/051DJ01TJ7`0K7240
6Q/P01hO900T9BX06AHO01TF8@0G5b405QHP01<G800B5Ql041@M018E7P0F6B806aTT01TF8@0C4QX0
8B8W018D600J6al09BHZ01XJ7P0I61d06aXO01PF6`0M6b0071XO01PD6P0P6al08R0Q00805A<D00/0
5Q@E01DC500M6a`071XK03lm?P0P7Ql06QPI00d;300C4A805QDC01TH5P0201`K6@0301DD4P0A40h0
61LE008051<A01005A@B01@C4@0C4Q008alP01`H6@0I5AH040`=014=3P0E4A804`l@014=3P0B3Pl0
510A01<?400B3Pl050hB0P0C3A40100B31004@/?014;3`0A2`l2018<40804`dA0180CDQ<0490@`0M
6ah05A<F01/I700>2@d04P`@01D?4`0B31004@X>01<:3`0F3A80:20V01`E700>1`h040T@018;4P0D
3A@2014:4@0500h73P0A2Q406Q<J01L@5`0B2a400P0>20`0100B31003PP<00h52P0A1``201873@80
4`P>00@050L>01<83`0C21005@XB0P0D2A400`0G31@040D=01053@0301053@0G01053P0D2QD0610M
01L?700<11405PhK01L?700800d05@dJ00X44@090a4030HD00l:600B3B@030PS00h:8`0C3RD06QD/
00l97P0=1QP040LH00l44`0=0`h00P0@1Pl200L01@0F00d22P0800D04`P?01T>5007008050T>00T0
0P0700005``@00L00P0@0``03P4:01@7400H2a@04@@=00/01`0<00P03`<;01443@0W6R<070lH00l2
2aCooooo000Kooooo`0401@C4@0?3P`04A0>018A3`803`h<01802@P701@C4@0A40h02`X800d<2P0?
3P`040l=00`;2@0I61H09RDS02LV902>SH/061LE01@C4@0>3@/030/900h=2`0?3P`2018>3@0@010<
2`0?2`X04Ph=01@@3`0?2`X05Q8A00P40`0D40l061@C00h:2@0A3@`06aLF00X61@0C3`h0510?01LC
4PH040`;00L04@/;00l;2P0@30/04Ph=00l>300=30X03Pd;00<03@d;01T04A4?01@C4@0?3P`010<1
014@3P0G5Q@030/900h=2`0=30X03Pd;014@3P0D4a404a8@014?3@0C3`h0510?018>3@0D40l040`;
00d9200B3Pd04`l>01@@3`0B3Pd04@d<00<040`;00@04@d<018>3@0B3Pd04Ph=1@0A3@`05`0B3Pd0
4`l>010<2`0B3Pd05a<B018>3@0E4A004`l>00l;2P0=2@P04@d<01`H5`0J6AL081lM00h=2`0C4Q00
3Pd;00X91`0H5aD02@P600h=2`0A40h0?C`j00L03@`:00H04A0>010?3@0?3P`03Pd;00l>300A40h6
00h=2`0:00P71P0?3P`0;bh/06QWI@0B4@l04a8@00l=3P0>30d03@/<00`:2`<03@/<0`0>30d03`0=
2``030/9014<2@0@30P03P/700h:1`0>30T03Pd:00h=2`0;2`X03@d=014A4@0B4Q<03Ph?00D31P02
018@4`0601LE601HEUT03@/>00l=400>30l02`T<0P0>30l02@0:20/03P`=00`:2`0<2P/03P`=010>
3`0B414040h?00d;300200`:2`0300d;300>30d03@/<00H03@/<0P0<2P/0100=2``03P`=00l=3P0<
2Pd200d;3P<03P`?0P0@3Q401`0<2Pd03`d@00l=400=2P/03PX900l;2P0A3@`00`0@30/0300;1`H0
4@d<02<O7P0L61L04Ph=00d:2@0@30/04`l>00d:2@091@@06QHE00l;2P804Ph=00@040`;00d9200=
2@P040`<0P0A3@h01@0@30d03PX;00d92P0<20T03@T:00803`/<00<03PX;010<3@0?2``01@0?2``0
1`0>2P/040`=01@@4@0U8B805A4B010<3@0?2`X00P0?2`T00`0>2PT03@T800d92P0200l:3@0;018=
4@080`P03@P=014<4@0A310030L;00/62P0G4QH03PT=00l:3P0=20`00P0D3a<00`0<1`/03@P<010;
3`02010;3`07014<400J5AT06aHJ00h93@0A31003`X>00h93@02010;3`0300h93@0?2`d03`/=00H0
3`/<0`0?2`/01@0?2``040hA00l=400>30l03@/>00803`d@00X02PP;01@B5@0610L0518E03Tg>P0:
20/03`/=00l;3P0?2Ph03`X?0P0?2Q003`0@2a40>3<j03dh?`0:10d050hH00/63@0C3Q@03`X@00d8
3P0R7B<07aXP00X52`0?2Q003PT?00d83P0200h93`0I00l:400B2`l04P`@014;3`0?2Ph03`dB014?
500<3180=SLl07QkP01_LgT06QlU00H93P0>2Ph040/@010<3P0@2`l03`X?010<3`0?2`d03PT>00h9
3@0H51H01@4501093`020188400@0149400@2A0040T@00l9400:1@/01@<800d;400E4aP01@@8014>
4`0@2a404@`B010;4@0>2@l03`X@010;4@D03PT?00`03@P>010;4@0:1@/03@P>018=4`0<1`d03PT?
010;4@0C3Q@03`X@00`73@0>2@l600l93@0601@>4P0F41@05@lC014;3`0C3A403`T=0P0=20`200h9
3@@03`X>01D03PT=00`72`0<1`/040/?01@@4@0B3Pl03@T:01HB4`0A3@h05a<D020L7@0?2``040`=
00`82@0=2@X040`=01DA4P0;20P04@d>01TE5P0F4Q<01`0?2``600l>300B00/:200C4Q0020L501DD
4P13@T00:bXX00d9200<20L05A4@00d92@0M6AP0>3@c01@@3`0A3@`03`/:00h:2@0@30/040`90P0@
30P05@0A3@T04@d:010>2`0@3P/02PT701LG5`071`L04A4B010@4@0<30X04A4801dM4P1lO740a/Jn
03<b;@0@3`X03`h;014?400@3Pl03P`?00l=4003010>4@0>00X82`0;2@`04a4D03Tg>P1CDE@03`d@
01@B5@0>30l03`d@018@4@0?3@d04A0>018A3`0A40h2010?3@1Y014@3P0@3`d03`h<010?3@0A40h0
4Q0?01DA4P0@3Pl05A<D018@4@0<30`04Q8B010@400B51<06A/J01@F5@0@51<05QPH00h>3P0A4A40
8b<S01DE5@0?3`l051@D01<C4`0E5AD06ATI01DE5@0C4a<04a<G01HE700@4AL05QXO00H;400C6Ah0
3ADI00`C600B5a`05APN01<C6P0B4QT03`lK01DG8`0O8R/0FEaS038e>P0G6Ql04aLK018E6@0D5ah0
6ahW01dP:@0J72P06APW01hM;@0G5RD071/Y02TY=@0H62806a/S01/L8@0I6Ql05QLK01DF6@0H6A/0
51DJ01LH7@0F5a`07AhT01PH7`0G5ah04Q<I01/K8P0L72<061PO01LG7`0K6b@06aPS01XG8P0H6280
5aLQ01DH8@0C5b006AdV01LJ8`0F6B806QPS01XG8P0F5Ad04Q<H01@F6P0B4aL0C4eA028R9`0G5Q/0
51<H01DD6@0J61d061HK01DB5`0I51P061HI01LE5P0I5aP061HG00804@l@00<05Q@E014?400A3a00
0P0D4Q<0200H5QL05A@B01LF500H5aD05aHD01<B400A40h06QTG0P0C4Q00100G5Q@051<A010?3@0J
5QL201HB4`804`l@00@06ADF01<?400D4140510A0`0E4A801`0E3a<050hB01@>4P0C3A404P`@014;
3`0C3A400P0B310201@>4P0J02<N8P0B41<0518E01<A500D4QD040/?01D@500C3A404P`@01<;400C
2Pl050/@01<;4@0=1Pd05@hE01@=500;10/040T@014:4@0F3aH050dD014:4@0H4AP050dD00`5300>
20d2014:4@0:00l83P0H3QL06a0H01873P0C1a0050L?01@63P0D1Q004PH?01463P804PL?0P0C2105
01463P0Q01463`0@1Q40Bd=@01dF8P0@21D030@A00d64@0;1@l03`LC01<:5@0700X05`hH01<85P0B
21d05@`S01@;800D2al05`hQ01886`0=0a@040HE00l44P0=0Pl040HB01054@0B21006`lI00h52`0D
2A404`T?00/01P0F3A40308600804@L:00h03@<601<8300B1@/040@:00h11`0C1Ph05PT@00d21P0:
00D04PH<00h21`0W6R805`/A01@83ACooooo000Kooooo`0801DD4P0B4@l04a8@018A3`0>3@/04A0>
01<B400=30X2018A3`8030/901`04A0>00l>300510802`X800P71@0T8b404a8@010?3@0<2`T03@`:
010?3@0B4@l04@d<00`81`0?2`X040`;00l;2P0@30/04@d<00l;2P0;1`H03@T8014=300E4A00510?
01XF5@0>2PT0510?0P0>2PT6010<2`0801<=3@0?2`X03`/:014=300=30X030/900l>300>3P`200d=
2`08010@3P0X9bD06APF01hM6`0W9R@04a8@01LF500?3P`200d<2P0;018A3`0C4Q003Pd;00d:2@0A
3@`04`l>01DA400D40l04Ph=014=300@30/00P0?2`X01P0B3Pd05A4@01@@3`0@30/04@d<018>3@80
4`l>0P0B3Pd01P0E4A0061@C01HB4@0D40l04@d<018>3@8040`;01@04`l>010<2`0>2PT040`;018>
3@0A3@`040`;018>3@081`D03`h<00h=2`0@3`d03@`:014@3P0@3`d03@`:01@C4@0;2PP07ahL00/:
20H03Pd;00H040l=00l>300?3P`03Pd;00l>300@3`d600h=2`0>00P71@0@3`d051<A00@30@0B4@l0
0P4000`:2`0?3@h03@/<00`:2`0;2@X01P@500/92P0<2P/200d;300;00`:2`0;2PP04@`9010<1`0>
2`H03PX700h<200>3@T03@`:00`<2`0@41000P0D51@02@0>3Ph02PP;00/9300D4QD00P03038`<`07
1@P03P`?00l=400400h<3`0300h<3@0=2``030X;00<02`T:00<03P`=00d;300<2P/0100<2P/01P0;
2@X03P`=00d;300<2P/03`d>00h<3@803@/<00L03P`=00l=3P0@3Pl02`T<00`:3@0=2`h03P`?0080
3`d@020030X=00/930091`X03@/>00T72P0>2`/03PX9014=300G4a804`l>010<2`0<20L03PX901DA
400>2`X01@4000`81`0?2`X04@d<00l;2P0F4Q402`L6014=300C3`h04@d<018>3@0@30/03@T800h:
2@0A3@d040`=00h:2`8030P900H03@T:00h:2`0?2``040`=00l;300>2P/9010<3@0700P41@0@30d0
2`L800h:2P0A3@`04@d:010<2@02010<2`0Q010<3@0;1`P03@T:00T4200B3A406A@H00X62@0?2Ph0
2`H:01D@50060@D04`hB00`72`0@2`l03PT=00/62P0>2@d03`X>00/62P0:1@T03`X>00/62P0:1@T0
3PT=00d8300?2Ph03PT=010;3`0C3Q8050lC01<>4P0?2Ph03`/=00@03`/<00L040`=00l;2`0@30/0
4@d<010<2`0>2PT02PP900802`T<0`0<2Pd01P071@P02`T<00P62@0C4A@0;2X]00X82`<040/?0`0@
2a40200G4QT0DTeD069MI00B31H01`4;01D@5`0;1Pd050lE0P0>2@l01@0C3Q@04@`B00l:400>2@l0
3@P>00803PT?00h03`X@01483@0>20`030H:00d8300C4AH05QDJ00@52P0E61d05a`P01dS:@001`d0
5AXN00l=3P8040`=0P0A3@h06@0<20T0510A00`82@091@H061@E01HB4`0F41<04@L?0188400A2A00
40T@014:4@0A2a406A@J01@B5`040`L01`D:00l=4P0A3A<040/A014<4P0@2a403PT?00l:400@2a40
1@0>2@l0300?2Q0030L=010;4@0B3A<01P4700`73@0C3Q@03`X@010;4@0>2@l03@P>00h93`H03`T=
00<03PP<01D?4`0F41@00P0=1`/00`0B31003`X>00l:3P03010;3`0K014<400C3Q8040/?00`72`0?
2Ph04@`@00l:3P0810D05A4B00h:2`0<20T03PX;00l;300B3Pl04@d>01<?400@30d07QXK00`82@0;
1`P04@d>018>3`0<20T020@5014=3P0?2``04@d>00803@T:00<04@d>00l;300=30X01@0=30X03P0<
2`T04A0>00h=2`0F5A<04a8@01LF500E4A0061@C00P40`0B3Pd03`/:01dI600B3Pd04@d<0`0@30/0
1@0A3@X03``700l<1`0@3@P04@d:00803`h:00d040l=010@400000004Q8D06EVJ01VJ6D07AdC0082
000M7A40<C4W00L7000C4Pd03Pd900802`T:01003P`?010>4@0@3Q403P`?01LE600<2Pd04Q0C00<1
10081PT01P@701@B5@0?3A006ALJ00d;3P0K6AX040l=0`0A40h05@0@3`d04A0>014@3P0@3`d03`h<
010?3@0A40h05Q<C01LC500C4A802`T:01PF5`0820P03`l?010@400A4a8061XI01DG5P0?4a804Q@D
01`L700201@D500f01XJ6P0A4A404Q8B00l?3`0C4a<071`L01TI6@0E5AD05QHJ01TI8@0=41L04ADL
02DZ<01>EE/05ahT014H7P0?51X04aHM01@G7P0A4AX06Q`X00T;600b=3l0j>_b09>FW@0L7b@082<X
01TL8@0E61l06A`U01TK9`0J72T06a/W034a>`0K6bH05ADO01<C6`0H6Al061TN01XK800K72005aPJ
01HG6@0J6ah05AHK01PI7P0N7b@0;2`d028R:P0K6b<05aLO01`L900L72H061PR0P0D51h0:`0K62<0
6QPS01PH8P0G5b405APQ01@H8@0R9Rl06QdV018E7P0E4ah061HQ01TH800M7R<05aXM01/L800J6al0
410D00`;400C4QL05aDJ01TG700G5AX05Q<H01PC6@0E4aH05A<D01@B4`0E4a@06QPI024O800h=SL0
928S01/I6P0E4a@04a4B014?400G5Q@05QDC01@C4@0C4Q005A@B01PG5@0I61H00P0B4@l00`0G5Q@0
5A@B014@3P0201DA4P0:018>3`0H51D05Q8C018>3`0C3a005A4B01HB4`0E4A805a<D01PD5@L05@lC
0P0C3A405@0D3Q805Q0D06AOH`1IEeX08R0S01<A500K6A`03`X>00h93@0A2`l04P`@01@<4@0C2Pl0
4@P=01<;4@0<1@`03PL>018;4P0E3QD05PlF00l83`03018;4P0<01D>5@0C31<03PP?00h9400@2A40
30D=00L0200D2Q<06PlH0186400C1Q0050D@0P0D10l01P0E1Q004`P@01<8400D2A405@XB01@94@D0
4PL?03404PL@00H01`0=1A802`<@00D02P0N5R<0:20[01L?6P0<1@d040P?00X0200B1Q003P8=0103
500E2Q/05``L01<86@0;01006@hM00h34@0A1Q@03`@B00d2400A1Q@04@HE02/O:`0700D050XA01X?
5`1ZGfH06@hD02HK8@1MDUL050T=00L0000H3A401`0000`0100B1PX04@D900l31`0=0@D02@0100P0
000A1@T02@0101862P0;0@<040@801Cooooo000Kooooo`06014@3P0B4@l051<A010?3@0<2`T04Q4?
0P0=30X0800>3@/040l=00l>300;2PP03@`:018A3`0<2`T03`h<01LF500D4a404A0>00h=2`0<2`T0
3@`:010?3@0A40h040`;00h:2@0F4Q406QHE00l;2P0;1`H04@d<010<2`0O6aX04`l>00X61@0F4Q40
30P701/G5P0>2PT04@d<0P0?2`X6010<2`0I01HA3P0@30T03PX700l;200<2`L02`X6010?2`0>3`X0
3@h900`=200?40/0GUiJ065PGP030P004Q4?03`k>@0M71X04A0>00d<2P0<2`T040l=01<B400?3P`0
3P/:010<2`02014=300E00d9200<20L03PX900l;2P0>2PT03`/:018>3@0D40l04`l>010<2`0A3@`0
4Ph=01<?3P0D40l04Ph=014=300C3`h05A4@01@@3`0C3`h040`;00804Ph=00`03`/:014=300A3@`0
3`/:014=300D40l04@d<00l;2P0=2@P04A0>00h=2`0C4Q0200`;2@0700h=2`081`D02@P6010?3@0?
3P`030/9014@3P0800h=2`<03`h<1`0>3@/03P0J6AL02@P601LF50081`D030/901<B400<2P/040h?
00/92P0:20T03P`=00X82@0<2P/03@/<0P0>30d0200=2``030/9014<2@0@30L03P/600h:1`0>30P0
3Pd90P0=30X02`0=3@/03`l?014A4@0@4100:bT/00P62@0<2Pd09R@W00`:3@0J61/030X=00803`d@
00<030X=00d;3P0@3Q400`0=2``00`0<2P/02PP900T7200400d;300800/92P0:20T030X;00X82@0?
3@h03P`=00`:2`0@3Pl200d;300800h<3@0?3@h03`d>00l=3P0;2@`030X=00d;3P0>30l300l=4009
00`:3@0:20/03@/>00L5200?30`03@T600h:1`0C3``03`/800803PX700@04Ph;01LC400=2@H03`/8
0P0D40d0300:1P<03@T601LC400B3P/03@T600l;200>2PL03`/800h:1`0<20D03@T6010<30803`/<
0P0>2P/01`0?2``040`=014=3P0B3Pl040`=00l;300A3@h01P0@30d01`0=2@X05Q8C018>3`0B3Pl0
4`l@00h:2P0?2`X00P0@30T2010<2`0Q014=300>2P/04Ph?00`82@0C3Q8030L;01hI7@0c;S800`02
00l:3P0<1`/06QDI01@?4`0B3A403`X>00d8300@2`l03`X>00`72`0;1PX040/?00h93@0=20`04@`@
00l:3P0A31003`X>010;3`0B3A404`hB018=4@0?2Ph03`/=00@03`/<018040`;00l;2P0@30/04Ph=
014=2`0=2@P020H700X82`0<2Pd03@/>00`:3@0;2@`04a4D00`:3@0Q7b804Q0C00@21@0E4aH300l:
3P<03`X@00/030L>00l94`0M5b402@@=00<01`0P6b804`hE018=4`0=20h02PD;00`73@0200l:400H
00h93`0=20h03PT?00h93`0?2Q004`X?014;3`0@2Ph04@`@01DC600G5Q/04Q<H00001@011PX04aTO
00XA5`000@D03P`<00h:2@0=2@P03`/:014=300?2`X04`l>0P0;1`H00`0D40l07ATH01XD5`020147
3`0@0149400A2Q404@XA00X52`0=20h03`dB00h<4@0C4AH05A<H00T52`0@2a804@`C010;4P0>2A00
3`XA010;4PD03PT@00D03@P?00/6300B3A<04`hD00d83P0201@?5@0300h93`0=20h03PT?00803`X@
1P0?2@d01P0<1PX04P`@018<400=1`/040X>01<=4@803PT=0P0?2Ph2010;3`0401<>4P0A310040/?
018=4@804`hB00L02PH701<?400>2P/03PX;00`82@0D41404@d>00802`L800<020@5018>3`0810D0
0`0@30d01@0D41405a<D018>3`0>2P/04@d>008030P900<04@d>00h:2`0=30X01@0=30X03@0I61H0
4Q4?00d<2P01000051<A00@30@060P403PX9014=300D40l05Q8A00@0000@30/00P0A3@`2018>3@05
014=2P0?30H03``7010=200A3PT00P0?3PX0800<30X02`/;00X:2P0_<380e]OK0=cNg@0[;20030`0
01<C1`0B4PP04Q8:00h=200A40`0518C01<A4P0?3A003`dB018@5@0B41<040hA00H41`0B41<02PP;
01@B5@0F51L02@L:00h<3`0B41<00@02010>3`0B4@h04A0<0P0@3`/0@00A40`04Q4=018A3@0@3`/0
3`h:010?2`0B4@d05Q<C00`82@0D4Q<03`d>01XH6@0=3@d051@D018B4P0A4a806A/J01LI600A5A@0
418B018B4P0=3@d03`l?01@D500>3Ph03`l?00h>3P0?3`l05QHF01DE5@0B4Q805aLK01/K8`0>4AP0
4QHM055FG02FWZ@0624V01DL8P0B5ad051LN01DH7`0D51d03@lK018F8P0T:380JVme03]0AP0W;300
82DY01LL800E6R0061`U01HJ9@0H6bL09bLa04I6CP0T92d08b<[01<D6@0M7R<05QLL01LH700H6Ad2
01HG6@0;01PI700K72406a/S020P:00];CD08R8Z01/K9@0L72H06QXT01LG8`0E5B400P0F5R8201TF
8@0I01LG8@0F5R004aLP018F7`0O8b`05a/T010C700C4A`061DP01TH800@4AH06A/P01@E6P0G61d0
51@J02TX;P0D4aT061HL01PE700F4aX061@K01TD6P0M6ah071XK01DC5002010>3`0>01<A4P0J61T0
6ALH014?400E4a@06ALH01HD5@0F5A805QDA01DD400C4Ph05QDA01TH500G5Q8201<B3P0@01HE4@0E
51004a8@01PD5@0M6AX04@d>01TE5P0K5aP0510A01<?400G4a@05Q8C01DA4P0G4a@06QHG01<=4@80
50hB0P0F41@0400G4AD05Q0D01<=4@0B310050hB01H@500L5a/02@L:01DC5P0C4A@02@L:00/62P0G
4QH04`dA018<400C2a0201<:3`0701<;4@0<1@`03`P?018;4P0G41L06Q<J018;4P0200l83`0501@=
500A2Q404@XA014;4P0;1@l00P0;0`h03P090@`03P@?01<84`0B1Q804`DB01<44@0C0a00508@01D6
400C21004PL?01@94@0E2Q804`P@1@0A1Ph01`0A1Pl060dK00X24@0?2AD01P0<01@>6P0F4AX00P0>
1`l05@0E2Q<05`XC01H94P0=0@X03`<A01H96P0T62L0:1//0186500J3Q`040@B0186500@1AD03P<C
01875`0B1aP01`0701hB700E2Q801`04028G7P0200L00P0=01H;400;00@02P0300P00@0L4AD02`01
00l31@0C1`T04PH801041P0D20X040@601451`0200h2100300d10`0?0`Gooooo01?ooooo000Koooo
o`0D014?2@0B40/04a0>010>300?30/04Q0?010<3`0D4A003``;00d;200B40X040h900h<2@0=2PP0
4Q0=00d:200>30T03P/901<A3P0@3@/2014>300=00d:200>2`T04@d<00h:2@0J5QD06ADD01LC4P0:
1PD040`;01DA400U8B006ADD00/71`02018>3@0501<?3P0?2`X03`/:014=300J5QD0100A3@`2010<
2`0901<?3P0C40h03@X800d:200C4Pl03@`9010?300<30T03Ph:00803@d900<061@B01PB4@0E3`h0
0P0C3@/01@0C3`d040`:00l;2@0>2PP04@h<00805A<@00D04@h;00h:200@30X04Ph<010<2P03014=
2`0;018>300@30X03`/9014=2`0A3P`02PL600d;200C40h03``:010=2`0?3@X00P0>30T200l<2P07
00l=2P0@3@`05A8B018?3`0C41003``<01HC4`02014>3P0;010=3@0>2`/03``<018?3`0B4@l02`X8
00h=2`0?3P`07QdK01HE4`0@3`d00P0=30X07`0D4a402`X800h>300E5Q<02``8010@300<30T051@A
00d<2P0>30T03`d:014>300A3@/040`:010;2@0B40h03`h<010?3@0C4Q0040l=00d<2P0K6QP0:BPV
00d<2P0F5A<03@`;00X91`0<2PX03P`<00/92@0<2PX00P0@3`h02`0A3`l03@/;00`;2P0>3@`03`d=
00/:200?3@X03`d;00`91`0=2PP03P`;00803@`;00l030X:00X9200<2``04A0@00l>3P0;2@/03`d?
014?4@0H5QP03@/=00L51`0<2P`03`d?010>400=2`d00P0<2P`00`0?3@h02PP900h<3@03014?4005
00d;300:20T03@/<00h<3@091`P00P0=2``01@0<2P/03P`=00h<3@0=2``03`d>00802`T:00@030X;
00d;300=2``030X;0`0<2P`0=P0=2`d03P`>00h<3P0I5aT0518D01<A4`0K6A/01P@601lM7@0>2`T0
2@L4010=2`081P<040h;00l<2P0>30T03``:01DB400P7A/061HC00/81`0>2PT05a<A00/71@0@30X0
3`/900`81P0:1P@03PX800`91`0:1P@04`l=00`:2P0920P03Pd>01PE5P0:1`L07APJ018:3@0F3a40
:20S024L7P0D3a0061@E01<?400D414030P9010<3@0B3Pl04@d>00`82@0B3Pl03@T:00T51P803PX;
01804Pl?00T6100Q7Qh02`P801@A4@0@3@d02@H701LD5@0f<c@04PhA00T6200i=SP0OGUk02DQ8`0>
2@`04@`?00/62@0:1PP200d92`0:01<?4@0J5AP06ADG01@@4P0>2`h030P<01DB5@0=2Pd03``?00h:
3P<03P/>00H03``?010<400?2`l04PdB014<4@0?2Pl300h93P0O018>4@0@2`l0510C01LC5P0X8bH0
2PH900/72`0?2`l04PhB01<?4`0@3A003PX>00h;3P0>2Ph03@X=00l<3`0D41@01P<600P52@0B3Q<0
2PH;00h;40091P/03``A014=4`091@/030T?014=500F4QX0<blf01dH7P02010;4@0:01<>500>2@h0
2`H;014<4@0>2@h03`X=010<3`0A31404`hB00l93@<03PT=00/03``@010>4P0:2Pd030`A010A5P0>
3a@01PL;010A500@30d04@T;00h92P0201092P0U010:2`0>2@X03`L901092`0>2@T05@h?014;3P0?
2@l040P>00h83P0?2@l040X@01D?500:1@X030P=01<?50091@X04`lD00h:3`0@2a003@P>010;4@0;
1P/04@`C010;400?2Pl03`XA00l:400>2@h03@P>00/6300C3Q@03`X@00`83@0A318030L=00h93`02
00d83P0:00l:400@2a4040/A010;3`0@2Ph03`T=00h8300>2@d03`X>010:3P804@`@00D040X>014;
3`0@2Ph040`>00h9300200l:3@0>00d82`0=2@/03PT<00l:3@0>2P`04`hA01LB5@0@30h04Ph?00h:
2`0?2``05a<D00h:2`0=2@X2014=3P0<01LC500>2P/03@T:01DA4P0<20T040`=00/7200@30d0510A
00`82@0?2``04@d>0P0=2@X0100A3@h03PX;010>300@3P`2010=30803`d;00h05a@C00d:2@0I5aD0
30X900h;2P0?3@/0510?00h:2@0G4a802`L6014=300<20L03`/:014=30804`l>06X04Ph=00l;2@0>
30T04@l<01@B3`0>2`T03Pd:00h=300?3Ph040l@014@400E51H0JfY/06IUIP0D4`d04A0901DE3P0;
2PH05A@A00h=2@0B4@l06QPI01PF600D4QD04@lD00l=4@0A3a004a8A00P61P0A3`l040l>00d;2`0@
3`h06ALG014@3`0?3Pd05A@C010?3P0A40l040l>010>3P0A3`l04A0?01<A4@0B410040l>00l>3@0A
3`l04a4A01DC50061@D03`h>01@C4`0?3Ph020P801HF5P0D51@04A8A01HG5`0G61L051DE01@F4`0D
5A403Pl;01TJ5P0M7Q/04a@B01<D4`0D5A@04a@B01HG5@0F5aH05AHF01@F5`0F6Ad05APL01/O8`1;
D580Jg9e018I700B61d04aLN018D7`0A51l0414O02ha@P0X;3d07B8_01LK9@0N8R/04aPN01LK800B
5Q/06QhW028S;`0G6RL05QLV01@G8`0V:S@05QTS028V;P0G6b405aTN01DH6`0E5a/05aPL0P0J6b00
1`0G5ah05QLP01HH800G6B407QlW01XL8`0H6B000P0K72D0300G62<03@lI02d^>@0L72L05QDO01TI
7`0F5ad04Q8K01DF7`0G6b<06a`V01`N:080:2Pc00L05aHS01TH900G5Qh04Q8G01XJ800F5Q/06QXP
008051<I01<05aHL01TG7@0E4aX061HM01<A5P0D4QD05aDG01PF600F51D05A@D01<B4@0E51<07A`I
01HE4P0G5Q<05QDB018A3P0B40`061<@00805Q<@00D06ADB01TG4`0G51405a8?01DC3`0201PD4@0Y
01LC400E4A805A8C01<@4@0L6AX05a@F01<@4P0A3Q004a0B01TF600F4QL05a@H01TF6P0B3Q804@/?
014>4@0F4QD05A0D014=4@0C3Q8050hB010<400B3Q805A0D01HA5@0A3A405@lC010<400J51P05@lC
01<=4@0D3Q804P`@018;400D31405@hB01<<4@0E3a@07QPM01XC6@0A2a000P0C3180B00B2a404@/@
01@=4`0?2@h040X?01@>5@0=1`h030@>01@=5@0@2A4040LA01<;500>0``04`PC01874@0O4a`09QTT
01@94P0C1a0040D?01863`0C21404PL@00d32P0C21003`D;01463@0C20l04@D=01053`0D2aH03PD?
01074@0<0`d03`H?00d4300D2Q8040H=02lS;00`92`05PXC01@95@0<11408AHT02TM:`0E2QP04PLB
01454P0G2aP04@DB00`23@0>10l04`HC01H:4`0>0`X03`@;01463@0?10X04PL=00h32@0?1@T02P44
01072P0@1PX040D901472P0=10H03@<500`2100<0PD04PH9014520804@@700<0408601841`0;0040
5?ooool001_ooooo00P04a07018?200B3`X04@d<014=3@0@2`l04PdA018>3P804Ph;0P0B3`P04P0J
5a806QHC00L3000F4Pl04Ph;01dI5P0?2`P030P501DA3P0H51405A4>01HB3`0?2`X04@d<00T5100A
3@`01P8101TE50H04@d<00L03`/:00d9200>2PT04Ph=01@@3`0E4A004`l>00<04Ph=0P0A3@`0300C
4Q002PT701<B400J6AL01`H400/:200@3`d02`X800l>300@3`d03Pd;01@>30@05@/:00<050`:01<;
2@0B2PP00P0@2`P200h:1`804Ph;0P0@30T00`0A3@X040`900l;2002010<2@0:00l;200>2PL040`9
01dK5`0C4Ph030/7010?2`0<2`L04A0<010?2`D03Pd900H03@/:010>3`0A3a002`T:081nO`1ZJ6T5
00h<3@0700l=3P0:2@L02`X800l>300B4@l08R4O01LF500300h=2`0f00`;2@0;2PP02@T700010009
3PP0>C/f01PI500@4@`05aHB010<2@0A3@X04`h;010;200?2PL04P/9014=300<2`T040l=01HE4`0B
4@l040l=00X91`0M71X01`H401XI5`0>3@/040l=00`;2@0;2PP030/900d<2P0@3`d04A0>00d<2P0A
40h040l=00d<2P0>3@/04a8@01DC500X9RL07Q`M00h<3@040P<02@L800h<3@0<2P/020H700`:2`0?
3@h01P@500X82@0<2P/03@/<0P0>30d01P0=2``03`d>00l=3P0A3a004Q0A00h<3@8030X;00X071XK
03<a<P020@402`T:00l=3P0;2@X040h?004000091`P02`T:1`0=2``01`0>30d04@l@01<A4P0:20T0
81hO03hl?@0>30d00`0<2P/300d;300D01TG600G5AH0Cde>01hL7@0D4a803@`:0040000:2@L020L5
00`;2@0@3`d02`X800X91`0@3`d04a8@00l>300<2@P03PX9010<2`0C3`h2018>3@0H01HB4@0C3`h0
1000018>3@0F4Q409b<R00`;2P0K7A`01PH600L51P0810D0NG1c038X;00B1`/08QTL01L?4P080P@0
510A00<0000@30d05A4B00X61`0C3a001P<30`0?2``300h:2`0B00L51P0=2``0N7Ig00h<3@081PL0
4@l@01@B4`050`@08R0Q00l=3P0I5aP030X;01hJ6`0;1`P01`@401<?400@30d05A4B0P0?2``02`0D
41406QHG01PD5@0>2P/02@L:01LE600H5QT01`D800X82`0?3A003@/>00<03P`?0P0?3A00100@2a40
40/B00h9400>2A0200l:4@0800`73P0:1@`05A0G018=500R7B@040/A00`72`0>2@d2010;3`0300h9
3@0<1`/03`X>00803PT=00L03`X>00h93@0;1PX04@lD00P62`091``03P`A00803@/@00l030X?00X8
3@0:20d030X?010>4`0B41D05Q4H010;4@0<1`d03@P>014<400C3Q804@`@00`82@0?2``00P0A3@h0
1P0C3a003`X>00d8300<1`/03@P<00l:3P8040/?00D03`X>00h93@0?2Ph03`X>010;3`0301<:3@05
0189300@1`X05@`?01482`0<0`H00P0F3A000`0C2Pd04`d@00l:3P0300h93@803`X>00d02PD901dH
700/9b/06A@H010;3`0910P04@`@00L21P0@2`l030L;00T4200A31003`X>008040/?00`03@P<00`7
2`0B3A804`hD00H11`0@31402@@:00H11`0C3Q@030L=00h93`0?2Q02010;4@03010;3`0?2Ph03PT=
00803@P<0P0>2@d00`0@2`l04PdA010;3`0200h93@0>014=3P0>2P/040`=018>3`0?2``04@d>01HB
4`0A3@h03PX;01LC500O6a`05a<D010<3@0<20T200h:2`0300H20`0A3@h04@d>00804Ph?0`0?2``0
1P0M6AX02@D601XF5`0A3@h040`=00d92PH03`/<0P0@30/200l;2P0800h:2@0=2@P00`0002/W9P1I
EE@0920O01@@3`0A3@`200l;2P05010<2`0A3@`04Ph=018>3@0@30/00`0B3Pd09`0@30/03PX900<1
0P0610D03`d>00h<3@0E4a@04a4B010>3`0?3@h030X;00/92P0>30d04A0>014@3@0>3@/04A0>010?
3@0?3@h04Q0A00`:2`0>30l071XM03@b=@0W9BX040hA00l>2`0H5a<02`X601hM6@0R8Ad010<000l>
2P0=30P02`X600d<200B4@d051<A00l=3`02010>4@@04@lB00L040hA014?4P0A3a804Q0C01@C500B
4Q804A4A00@04Q8B0P0?3`l0100F5QH06ATI01@D500@4@h201DH4@0:01HH4P0?4@`030h901DG4`0D
5Q<05ALD01DG5@0E5aH05QPG01@G5`805ATJ05L041@D01@H5`0L82404aLJ01<F6`0D5R004aDR01DG
9P0L7S00^;[?09jS]`0P9CL020/J028V<@0>4Q/04aHM01@G7P0S8bd08b<_01TH9P0H62P041<R014G
9@0E72L05a/V01DJ800F6b005ATL01<G6P0F5a`06a/S01`L900F5R008R@`02<U<@0M82T05QTP01LJ
8@0D5a`05aXO01@G7@0I72<020/D02HY<`0>4AX030dB01TJ7P0@4AH08B8W00`=4`0X:3007AdW07Mg
PP0`<3`0FeYX01`K:P0H62@06aXR01LF700D4aT05A@J01PG7@0G5Q`051<I018A5`0I61h06QTO02<R
:00F5AX0928U01TG6P0C4A@05Q@E01HE500B4@l05A@@01HE4@0F5A0051@<014A2@0@3`X0510=01/F
4`0M61D06aHC01TD4@0H4a000`0G4Pl201PC400I01LC4P0D4Q<06aTJ01TG600A3a002@L:01@B5@0E
4aH05Q@I00L52P0F51T04PlF00l=4P0H5QX05A<F01LE600@3Q404Q0C020N8@0@3Q404Q0C00l=400A
3a804Q0C018>4@0201D?4`0401@>4P0C3A4050hB01@>4P<04P`@0`0C3A402@0>20`03@L;00d72`09
0`L03@L;014;3`0@2Ph04`dA01@>4P02018<400b01093`0F3aH03`P?0109400_:2l09QlV01094007
00L040T@00d63@0N5ah0:24X01@:500F2QH04@DA0186400C1a404PH@00`12@0B1`l03`@:0146300C
20h050T?01@94@0C21004@H>01053@0C21005``D00T01P0D2A402`4802DJ8P0Q5Qh03P@<01<95021
NHH07AHR01<85P0<0@l040LA01P<600700L03@<;01/>5`0>0@X04PD>00h32@0?10X201052`0900l4
2P0>0`T02`0600T0100I3Q@05@X@00d4200C2Pl03@@700802`D700T03@@700h41`0>0`L0200001H:
3@0:00008Q4G01@62@0/6b405?ooool001_ooooo00P04Pl6014>1`0A3PT040`;010<300?2``04Ph?
018>3P804Ph;0P0B3`P02P0F4`h08alL00`81@0O6aP03@T701lK600D40d04@d:01DA3P0D40d200l;
2006018>3@0N6QT02PH501HB4@0:1PD040`;1P0A3@`01`0C3`h03PX901<?3P0L61L05a<B010<2`0C
3`h00`0B3Pd2014=300C03Dd<P0100001`H401DD4P0100006APF00l>300<2`T03`h<014@3P0@3`d0
50h=01H<2`0G3@`05Pd<01@<2P0B2PP04@/8014<2@02010;20803PX700D04Ph;010<2@0<20D03PX7
01<?3002018>2`0;01<?300B3P/04`l<01@@3@0C3``081hJ01DD400;2PH030/700d<200A40`01P0>
3@T01P0@3Pd02`T:01`J6`0610D0M79c06i/K@<03`d>0`0>30d01`0920H02PT701@C4@0?3P`04Q4?
00l>300@3`d00P0?3P`05P0>3@/03@`:00d<2P082PD04A<>03do>P0C50l0004000P71@0@30T04@d:
018>2`0@2`P03`X7014<2@0A3@`030/900h=2`0=30X02`X800l>3001000200`;2@0;01HE4`0=30X0
3Pd;00l>300<2`T02@P600P71@0:2@L030/900/:200=30X00P0?3P`09P0@3`d04A0>00T7200C4A80
4Q0A01@B4`0B41403@/<00X82@0;2@X030X;014?400H5QL04a4B00P61`0<2P/03`d>010>3`0>30d0
30X;00h<3@0<2P/03@/<00l=3P0>30d030X;00l=3P10?Sl0Kfe^01hL7@0F51D02`T:00d;300@3Pl0
5Q@E00h<3@071@H02`T:200=2``01@0C4A8020H7028P8@1;BDX03P`=00<03@/<03003P`=00l=3P0=
2``08b4R01DC500=2``00@0000L61P0?3P`04a8@00d<2P0O7Q`030/900P71P0<2`T02PT700h=2`0A
40h03`h<00l=2`0:1PD030P7018>3@070`802PH5014=300J5QD02`L600d9200810<05A4@00P81`05
1`H030`<01<A4@0O6a`0M6]^02hT:00C20`04@P;00X31@070@<03@T:010<3@0E4A8061@E00<0000?
2``2018>3`804@d>01@03`/<00h:2`0>2P/0518C00h<3@0J61T00@0000d;30040P<04@l@00L51P0<
2P/02PP900h<3@0:20T02PH700T51P0<20T03`/<00d92P804Ph?00/040`=00l;300A3@h040`=00X6
1`0;2@`01@@600400P0C4A@05A<F00<1100200l=40<03P`?00@03@/>00d83P0?2Q003`X@0`0@2a40
100H4aT02@D:01@?5@0I51X2018=4`D03PT=00@03@P<00h93@0>2@d03@P<0P0<1`/02`0>2@d06aTN
00D3200E4aP03@/@018@5@0<2Pl02PP=00`:3`0=2a003P`A008030X?00d04@`C00h93`0<1`d03@P>
014<400C3Q803PT=00/7200?2``040`=00h:2`0@30d03PT=00803`X>00H040/?014<400A310040/?
00l:3P0>2@d200l:3P03010;3`0B2@`04PT<00804`X=00D04PT<034X:`0h;c804`X=00/31@0200H0
0003018<3`0?2Ph040/?008040/?00h03`X>014<400<1`/061<G020K7`0C3Q8040/?00d8300B3A40
2`H:018=4@0E41@00`02018=4@<03`X>00T03@P<00`72`0?2Pl03@P>02<N9018@dT08QdS00L2200:
1@/00P0=20h0100>2@l03`X@014<4P0>2@d200l:3P803PT=0P0=20`06P0?2Ph04@`@00h93@0=20`0
3PT=010<3@0>2P/040`=018>3`0?2``04@d>02dY:P0P71d04`l@014=3P0>2P/020@500l;300:1PL0
3`/<014=3P0300004Ph?010<3@0>2P/03@T:0P0@30d02@0=2@X00`00014=3P0A3@h01@4204M3A00G
4a@03@T:00h:2`0200l;3003010<3@0A3@h03PX900803`/:00l03PX900d9200<20L030P701@@3`0U
8B00100000/71P0D40l03`/:010<2`0A3@`04Ph=01<?3P0D40l00`0@30/300l;2P07028P8@0?3@h0
40h?00d;300C4A802`T:00`:2`02010>3`0@00l=3P0>30d03`h<010?300>3@/040l=00l>300>30d0
4Q0A014?400@3Q403P`?014?4P0>31401`D8018@408040l=00D02`X900X91`0B4@l05QDC010?3@02
00h=2`04010?3@0B4@l040h@010>4@@04@lB00<040hA014?4P0B41<00P0B41<01P0A41405ADE01@D
500=3@d051@D01DE5@804A4A00`0410@014A4@0B4Q80410@00h?2`0520403a8;01TK5@0;3@P03Q0;
01DG4`0F61D301DG5P1F01@F5@0D5aL05QXM01TM7P0E6AT04aLF02P/;@0C5aX05APM01@G800C5B80
6Q`[02/]?`0d=dX0BTmR01hS=01DF6@05QXU01HK8P0?4QT051LN01/K9@0G5b<051<Q01PI9`0E62L0
5Q`Z01TO:P0I7BP061dS01PM8P0F6Qd051PK01DF6`0I6B406a/S01PH8P0J72P071hZ01TL9@0E61l0
5QTP01@G700L7b@04QDK01/N9@0C5Ql04aHP00hA6P0Q8RL061TM00/<4@0?41D0=SHm00001`0N7RP0
7alZ024Q;@0L6bT092<a00H64P0K6R805aHK01@C600E51T05QDJ01DD6@0L6b004a8G01DD6@0G5Q/0
81lT010?500/:Rd06aTL014?4P0F51D061LF01<B400G5Q805QDA01DD3`0C4Pd04A49014@2`0G4a42
01TE500301LC4P0F4Q4061@C00805A4@01l05Q8A01LC4P0G4a805a<B01@B4`0F51D02`T:01HD5@0C
4A@0518E01DC5P0R82D030X?01LE6P0=2Q40=C<h01@B5P0@3Q403`d@014?4P0>30l02@L:014?4P0B
41<040hA014?4P0B41<040`?018<400D3Q804`dA00804P`@0P0C3A43018<4009014;3`0C3A403`T=
014;3`0I4aL03`T=010:3P0C3A4040X>008050hB01@04@/?00l93@0A2Q004``C00/42`080`P040T@
01D>5@0H4AP02P<:014:4@0>1`h04@XA01XC6P0B2A805@TE0104400D21805`/E01<74@804@H>01h0
4@H<00h32@0;00H03`@:01873`0A1Ph040D=01463P0C21005``D00X01`0G31@0308901463P0<0@T0
3PD<01@:5@2;Pi008ATV01/A700B21<050XE0186400800H05PXD01853P0<00P03P<:00h32@0?10X2
01052`0:00l42P0>0`T04@H<01P=4`0:00D01`0201D:400H3a@03@@700`51`803@@700P03P@700h3
1`0G2`l0304301H7300;00004`D801D42QCooooo000Kooooo`0>014>1P0A3PP040d8010<2@0?2`X0
3`/;014=3@0A3@`04@d:014>2@0A3PP04@h7010=2`0B3P/201PD4@0301@@3@0F4Pl04@d:00804@d:
00T040`900h:1`0=2@H071TH01DA400F4Q404@d=01HB4@0C3`h01P0@30/01P0B3Pd03`/:01<?3P0I
5A@05A4@010<2`804@d<0P0@30/200l;2P0@04I5@`0@3`h04Q4?00d<2P0<2`X04a8@00d<2P0;2PP0
30/9010?3@0A40h04`d<01H<2`0H3`d05`l=01@<2P8040X70P0A30T2018>2`0301<?300@30T03PX7
00804@d:00l040`9014=2P0C3``04@d:00l;200C3``05A4>01<?300C40d02`X600h=2@0B4@d03Pd9
010?2`0=30P01@0>3@T01P0=30X04a4B018@4@0E4a@04Q0A01TG608040h?00X04@l@010>3`0?3@h0
3@/<010?3@081`D04Q4?00d<2P0;2PP03`h<0P0<2`T07@0=30X03Pd;00l>300B4@l0@D8m010A3P0;
3@P02``701<D3`0=30T03`d9010>2P0B3P/040/800l:1`0@30T03PX900/:200<2`T02PT701<B400U
92806APF00`;2@0C4Q003@`:00`;2@0B4@l03@`:008030/900h03`h<01HE4`0K6QP06QTG00d<2P0>
3@/06QTG01TH5P081`D040h?01HD5@0@3Pl03`d>00h<3@802`T:00T03@/<00`:2`0?3@h0518C010>
3`0A3a0040h?00l=3P0>30d00P0?3@h04P0=2``02PP900X82@0<2P/03P`=00d;300?3@h02@L801DC
50091`P02PP900l=3P0<2P/02`T:00`:2`0=2``04a4B00X82@H03@/<00L040h?00/92P0=2``03@/<
00h<3@0B41403P`=00803@/<03803`d>010>3`0@3Pl0<Bl`020N7`0G5AH02PP900d;300G5AD01PD3
018A3`0J6AL03`h<00P71@0C4Q0040l=00d<2P0>3@/040l=014@3P0A3Pd030P700X61@0=2@P030P7
00l;2P0B3Pd02`L701@@3`0F4Q40>3@c00X61@12@D003@l>01HF5P071@D03`/<014:2`0D2Pd05``@
00d41`0D30l0618D00h:2`0@30d02`L800d92P0e<C803PX;00`82@H03`/<01d03@/<01TG600@3Pl0
2`X:01@B4`0<2P/02PP901HD5@0<2P/03P`=00@30`0C4A803PX;01<?400B3Pl03@T:00h:2`0=2@X0
4@d>00l;300<20T03PX;010<3@0A3@h030X=00d;3P0>30l02@L:01HD5`02010>4@0700l=400>30l0
3P`?00d;3P0<2Pd03@P>00l:4002014<4P0K00l:400=20h0?cY001DA5P0<20d091lU01/F700>2@l0
4PdA014<400@2`l04@`@01@?4`0G4QH03`X>014<400?2Ph030L;00h93@0C3Q803`dB00h<4@0@3Q<0
3@/@00/93P0=2a0030X?00<03@/@00X02`T>00X83@0?2Q404PdC01D@5P0C3Q@03PT=00/62P0?2Ph0
30P90P0A3@h01@0>2P/03`/<00l:3P0@2`l04PdA00<04`hB00<040/?00l:3P0>2@d00P0?2Ph0100@
2`l03`P;0149300B2Pd2018;3@0I01P@4`0Y8B@06A8D01TB500K51H03`L:01D@4`0?2Ph04@`@018=
4@0A31003`X>010;3`080`L030L;00d8300910P040/?018=4@0>2@d04`hB00`72`0F4AD03`X>00h9
3@0300l:3P0:00d8300>2@d04@`A00X52`0?2Q008AdR010;4@0910X03`X@00h93`803@P>00@03PT?
014<4P0=20`03PT=0P0@2`l0200>2@d030L;00d8300>2@d040/?00d8300<1`/03`X>0P0@30d01@0?
2``03PX;00d92P0=2@X05A4B00802PH700`04Ph?00l;300B3Pl04Ph?00/7200A3@h06ADF00T51P0@
30d03`/<010<3@0A3@h200h:2`0800l;300D41404`l@00`82@0E4A80EE5B01<?400<20T200h:2`0G
010<3@0A3@h04Ph?00l;2P0@30/04@d<010<2`0?2`X03@T801@@3`0:1PD04`l>018>3@0C3`h02@D4
00h:2@0?2`X040`;014=300B3Pd04`l>010<2`0?2`X00P0>2PT02@0?2`X040`;02/Y:P0?3@h03@/<
00h<3@0G5AH02`T:00l=3P02018@4@8040h?01X04A0>010?300=30X040l=00l>300>30d04Q0A00l=
3P0=2`h03P`?018@4`0C4AH04a4D00h<300=30X02@P6014@3P0>3@/040l=00h=2`0<2`T04Q4?01<B
400@3`d04A0>010>4@804@lB0P0B41<2014?4P1I018@4`0D4QD0518E018@4`0C4Q<04a<C01LG5`0J
6QX051@D01<C4`0D51@05QHF01LG5`0@41004a<C028R8P0i>SL05aTC00T;1@0C5Q004aD@01PJ5P0E
5a@05QPE01HH5`0E5aH051HE01@F5P0F6A/051PK01<G6@0C5aP041@D02P/;@0D61/05aXO01PK8`0C
5B405aTV02PZ>P0G6RX03Q@S01@J:01=DE`092Pa014F700G6R0061/Q01@E700D51d06a/V01/L:00L
82d06b4_01/R;@0H72L05Q/Q01DJ7`0H71l05QXM01HG700H62006QXR01XJ900C5B4061XV01dP:@0M
82L07b8Y01TL8@0G6Ql05QTO01@G7P0J7BH05QPS01hQ:P0E5A`05AHJ01HG700R8bP0CTmE02d]=@0F
5R009RH`02<S;P0h>4D06a/X01XJ9@0G5Q`00P0D4aP0100E51T05QDJ01DD6@0L6b0201TH7@0E01HE
6P0P7b@06QTN01XH6`0F51H04a4C01@B4`0G5QD05aHD01@C400D4`l04a8>01@C3`0E51005QDA01LC
4P0E4A005Q8A01DA400H51<07a/J00805A4@01<05Q8A01LC4P0G4a8061@C018@4@0P7Ql02`T:01HD
5@0D4QD04@lB01DC5P0M6b0061HK01LE6P0a;SD0_kg209FCU`0C4A@05A<F008040hA00<05aDH018@
4`0B41<00P0C4A@0200B41<04PhB010:3P0?2@d05a4E01dG6`0I4aL050hB0`0C3A40400B310040X>
010:3P0=1`/06Q@H02hX;00G4AD030H:018<400C3A4050hB018<400@2Ph04@/?010:3`0E3QD201<<
4`0401D>5@0@2A004``C00l83`804``C02P030D<014:4@0B2A8040@@00l33`0G2aD06`lI01P<5P0B
1`l03@8:01P=4`0B1`d03`@:01D:400B1`l04@H>00l4300>0`/03`@<01873`0@1@d04`P@00d22P0G
31@05P/C00h4300E2aH02P@?01H>6P0600L0?cE00107400?0`d06`lI01863`0@1P`050L@01<63`0>
0`T03`@:0P0@1@/02`0?10X03P<900T0100A1``03`D:01<83P0=10P03`@:00d41`0=1@L03@@70080
3P@700L03P<700/10`0C1PX03P4500h00`0N3a@04P@701Cooooo000Kooooo`09018?200A3PP04@h9
010<2@0@30X03`/:010<2`0@30X040`900<040d800D0HUiK01TE4P0F4Pl03PX702PT8@02014=2P0;
01HB3`0C3``04Ph;01@@3@0C3``0RHF407QdL`0<20L04`l>010<2`0>2PT01P0A3@`4010<2`03014=
300C3`h040`;008040`;01003`/:00h:2@0>2PT05QDC01@C4@0I61H030/901HE4`061@<04A0>00l>
300=30X04Q4?01@C4@0D3P`05P`;0P0F3P`01P0D30X040/8014<2@0B3@X040`900l;20<03@T600<0
5a<@01hJ5`0I5A800P0=2@H0300A3@X03`/800d91P0?2`P04`l<01DA3P0A3`/02`X6014@300=30P0
20L300l>2PH03Pd900H03@`9014?400>30d02@L8018@4@0D4Q<200l=3P804@l@00/040h?00h<300D
4a402PT700h=2`0<2`T03Pd;01<B400G5Q@05A@B018A3`02010?3@0G014@3P0S91l010D000h?2P09
2PD051D@01LF4P0>3@T03`h:018>2`0?2`P03PX7010<2@0?3P`03@`:00/:20081`D03`h<020O7@0>
3@/020L601@C4@0>3@/00P0<2`T200d<2P0800`;2@0>3@/04a8@01HE4`0@3`d04Q4?014@3P0?3P`2
00d<2P0E0040000?3@h04Q0A01<A4P0?3@h02@L800d;300?3@h030X;00/92P0>30d02PP9014?400>
30d02`T:00d;300C4A8061HG01<A4P0?3@h03P`=008040h?00d03`d>00X82@0?3@h02PP901LE5P01
00001P@5010>3`0>30d0BTQ902`Z:`0E4a@02PP900L03@/<00D05Q@E00/92P091`P03`d>00X82@03
00`:2`0A00h<3@0?3@h040h?010>3`0=2``02@L801/I6P0L6Q/01@@3014@3P0I61H0<2l]018A3`0=
30X02@P600h=2`0<2`T00P0;2PP0100<2`T02PP600d9200A3@`200l;2P0B00`81`0@30/00`0001`H
5`0M6AP0DDe<00X61@0H5aH00`D40000000I5aL03PX;020G6P0B20/05P/?00X1100@20/0618D0P0B
3Pl05`0=2@X06ADF06MSI00R7Ql040`=00`82@0=2@X03PX;00l;300@30d04@d>02DS900a;c003`d>
00d;300F51D03`d>00X82@0G5AH01`D601DC500:20T03P`=00803PX;010030P900d92P0A3@h04@d>
00l;300>2P/03@T:00`82@0=2@X03`/<01`J7@0:20/01@<6020N8@1OGF00518E0P0?3A0300h<3`04
00d;3P0@2a4040/A010;4@803`X@00L03@P>01XE6`0F4AL02PD;01`G7@0F4AL01`8800<03PT=00@0
40/?01<>4P0F4AD040/?0P0A31004@0@2`l04@`@01<>4P091``030X?01@B5`0>31402`T>00P62`0?
3A803@/@00/93P0<2Pl03@/@00h<4@0E41L04@`B00803PT?00@040/?014<400B3A403PX;0P0B3Pl0
1P0?2``040`=00`72`0<1`/03@P<00h93@803`X>00<040/?00l:3P0>2@d00P0?2Ph00`0@2`l03PP:
010:3003014;3@08010:300Y8bD09R0R01H@4P0E3a402@<500/5200?2Ph3010;3`0A00l:3P0A3100
3`X>01@?4`0A31002`H:00h93@0?2Ph02@@8018=4@0D3a<00`0201hI7@0<1`/03`X>00h93@0=20`0
0P0>2@d01`0<1``04@`B01<>500C3Q@050lE014<4P0?2Q000P0>2@l0100=20h03PT?00l:400>2@d2
00l:3P803PT=0P0=20`01P0>2@d03`X>00d8300=20`040/?00`82@<03`/<0P0C3a002@0F4Q<04`l@
01<?400@30d02`L800T51P0I5AH04`l@00h:2`0200d92P0<010<3@0?2``0510A01HB4`0=2@X030P9
01<?400U8B802PL701XF5`0E4A802`L80P0=2@X01`0>2P/03`/<00l;300@30d04@d>00l;2P0A3@`0
0P0C3`h0200@30/03@T801@@3`0=2@P0100000/71P0<20L06ADD0P0>2PT200l;2P8040`;0`0?2`X3
010<2`0600/92P081PL04Q0A00l=3P0A3a001`D60P0>30d02@0=2``03P`=014?400C4Q003`h;00d<
2P0?3P`03Pd;00d;3002014?400A00d;3P0>30l030X=00X83@0=2`h04Q4@00d<2P0H5aD020L600l>
301<BdT06QTG00d<2P0@3`d04A0>018A3`0G5AH00P0A3a84018@4`03014?4P0B41<04a4D00804a4D
01@051<E00l?3`0F5QH08b<S010@400>3Ph04a<C01HF5P0O7al06ATI01<C4`0K6a/0:b`Y01TK5P0A
4`h051HA00h@2`0A4a005ALD01HH5@<05ALF02P051DG01<E600@51L04aLJ01HJ700A5AH041@E014E
600E6A`05QTQ010B7P0?4Ah051HU01XM;00:41`04aTT01dQ:P21QX`0;34e01XM8P0E61d04a@I01HF
7P0I6B405QPP01@H900C6BL051/V01@H8`0D6Al05Q/P01LK7P0F6Qd05aPM01LG7`0I6B406a/U01HH
900L7RX082</0P0P8bX06P0J7B804QDJ01LJ800;3QD03a8K01LI900N8BX07alW01dN8`0G61d0414F
01`M8`0E5Ad06ATS02`/=P0S8bd03`lI030`>`0L72H04a8H018A5P0C4QL05A@I01HE6P0E51T04Q4F
0P0G5Q/03@0?3Q<06APM01XJ700A3a806ALI01/I6P0F51D04a8A01DD4P0G5Q@05QDC01DD400C4Ph0
0P0A40`01P0B3Pd06QHE02DQ800Q7A`061@C01`H5`H05a<B00d0518C02DS900H5QL07adN01PF6@0C
4A@04Q0C01LE6P0C4AH05aDJ02DR:@1kNGh0HV1T008061HI01/03`d@02`Z;@0100804a4D018@4`0E
4aH0518E018@4`0F4QD04@/?00h8300H4QH081XN01/E6@0D3Q804`dA01@>4P0E3a<04`dA018<400E
3a<040X>00d72`0B31002P@800l93@0E3a<00`0@2Ph03`0D3Q806A<G01hH7@0F3aH03PL>00l93`0@
2A004@XA01<<4`0?20l03PL>00l83`0<1@`03@H=01<94`0201864P8050PB00X04`LA01P=5@0?10`0
5P/A00P00`0=0PP03PD901D:4P0D2A404PL?0P0@1@d05@0?10`040D=01463P0A1Ph02P0700T01P0@
1@h02@0:00`44@080@/01P0702XP:`0900P03`<=00L01@0>1@/07Q4J00P0100>0@X03P<900l42P02
01052`0800l42P0>0`T01`0200`31`0>0`T07Q<I00`31`07008300d41`<03P<700H040@800`2100V
6Qh03P0405]<D@0^7b@Dooooo`006oooool00`0C40/04Pl;018>2`02014=2PD040`90P0@3@P04P1P
G5T08AdJ01@@3@0A3@X07ATF014=2P0E4@h06QHC01@@3@0A3@X04`l<014=2P27Ph80PWim00/71P0G
4a80510?00D100H04@d<00<04Ph=01<?3P0C3`h00P0C3`h00`0D40l04Ph=018>3@02014=308040`;
00`02PT700H50`081`D02`X800h=2`0E51804Q4?014@3P0=30X04Q4?01@C4@0B3@/201@<2P0=01<=
2P0B3@X04Pd:018=2P0B3P/04@d:00h;200;2PH02PT500d:1`0E4@h06QHC01HB3`0200l;20804Ph;
0P0A3@X0200E4@h06QHC01LE4@0<2`L04A0<00h=2@0=30P04Q4=1P0>3@T05@0C4Pl02`X801DD4P04
0`4020L501<B400=30X03Pd;014@3P0B4@l04A0>00l>300@3`d030/7014@300:2@D03`h:01<B3P0K
6QH06APD01DD4002014@300>018A3@0;2PH00P4001PG4`020@001`H200/:1P0>3@T03`h:010?2`0?
2`P03PX7010<2@0B4@d200l>2P0500T8100510002PT500/:1P0>3@T00P0A40`08P0:2@D01PD1014@
3P0?3P`02`X800T81P081`D01`H400T81P0=30X030/900P71@0920H03Pd;01@B4`0=2``020H701<A
4P0B41400@0000T7200?3@h03@/<00h<3@0D4Q<04a4B00d;300<2P/02`T:00d;300B41405A<D01@B
4`0@3Pl200l=3P0400h<3@0<2P/04a4B00X82@802@L800P01`D601DC500@3Pl04a4B065OH00]:b`0
40h?00/92PH03@/<00H02@L8014?400<2P/01P@500d;300C4A8300/92P0400d;300?3@h040h?00X8
2@80518C00T00`4200`:2`0=30/09bHT00<2000R8Al03`h<010?3@081`D00P0=30X08@0<2`T02PT7
00/:200=2`T03PX9014=300>2PT01@4000l;2P0E4A003`/:01`H5`0@30/07ATH00<0000<2`X061XI
00410@091`L00`0001@;3P0@1PX060dA01482`0A2P`050h@01<?400>2P/00`0000`82@0X92D03PX;
010<3@0200l;30@040`=00/00`0003Lc=00C3a006aLH014=3P0?30`02@D601/G600A3@h0510A00X6
1`02018>3`0B010<3@0?2``03PX;00`82@0@30d03@T:00h:2`0?2``03@T:00`82@0=2@X020H901@B
5@040PD00@0201TG6P0100803@/>0`0>30l200l=40803`X>0P0>2@d2010;3`0600@00`0?2Ph04`hB
01LB5P0>2@d020<7100>2@d2010;3`803`X>00/040/?018=4@0B3A4040/?00d;400R82D0GUaQ00l=
4P0A3a@01`D:00l=4P0300h<4@0700l=4P0@3Q<04`hE00h93`0;1P`030L=014<400201@?4`0600h:
2`0@30d040`=00l;300A3@h03PT=0P0<1`/01P0=20`03PT=00l:3P0@2`l03`X>00h93@803`X>00<0
40/?00l92`0@2P`00P0A2`d02@0@2P`05@lA01/E5`0B30h01@0100d72@0D3Q004`hA00l:3P0300h9
3@0600l:3P0B3A404PdA018=4@0:1PT01`860`0?2Ph01P0N6Ad0BDA800<00P0K5QX03@P<00h93@80
3@P<00P03PT=00l:3P0@2a003@P>00l:40091@X02`H<014<4P803PT?0P0?2Q0200h93`03010;3`0?
2Ph03PT=00803@P<0P0>2@d01P0?2Ph040/?00h93@0>2@d04PdA00/720<03`/<00@0510A01<?4008
10D03@T:0P0@30d02`0D41405Q8C01<?400L61T07ATJ00/7200B3Pl03PX;00l;300A3@h04`l@0080
3`/<00L04Ph?00H20`0?2``04@d>00@00@0?2``03PX;00H03`/<00d03@T8010<2`0B3Pd04Ph=00l;
2P0;1`H04Ph=010<2`0<20L081`K014=300>2PT04@d<00<040`;0P0?2`X00`0>2PT040`;018>3@02
018>3@0U010<2`0?3@h05A<D01XH6@0<2P/03P`=00d;300;2@X03P`=010>3`0B41405Q@E01TH5P0?
3P/030/900l>300>3@/03@/<010>3`0;2@X04Q0C014?4P0;2@`07adR03Dc=P0=2``01@<402LU9P0D
4Q<09bDV092>S`0T8R<04@l@01<A4P0A3a003@/<01<A4P02014?4P804Q0C0P0C4A@3018@4`0F01<A
500D4QD04Q4C00l?3`0D51@05aLG00d=3@0>3Ph05ADE01LG5`0I6AT05QHF00l?3`0=3@d02@X800d?
2P0B50l06adI01@F4`0<3P/04aDC01@F5@<05AHH01l05QLI01<E600E61d06AdP01TM7`0J7Ql061`M
01@H6`0F6Qd05aXR01@F8P0B52004QDR01TM:@0=51h05A`U00T=5P0_=3X05a`P01HI7P0C5Q/06AXO
01PI7P0A4QL04aDL01LK9`0F72X05ahY01PL9`0H7B<06b0U00805QXM01l06AXO01PH800I6B406a/U
01@F8P0H6RH06A`U01TL8`0N8BP07R4V01TL8@0H6b4051LN018E7P0G6B@07R4Z02HV;P0I6Ql0824V
00X;401;Be804A4I010@600F5Qh04a<K01`L900G5b002PXB01<B5`0B4Q@04a<E00805ADG00h04Q8D
01<C5@0D51H04a<E00/;3@0B4Q@03@d?01@B5@0I5aP06QPI01LE5P0C4A804@l@01DC50805QDC00P0
51<A014@3P0@3`d04@l@01PF5`0S8B807Q`M01@B4`8061HG0P0G5AH07P0F51D05A<D01@B4`0E4a@0
518C01HD5@0]:b`081hQ01<A500>30l061HK01HD6@0G5AX030T@01LE6P0G5AT05Q@G00D31P0/:Rd0
ZjV/061NH@0D4QD04Q0C01HD5`0D4QD04Q0C01DA500C3A404@/?018<40@04`dA01P05@lC01LA5@0F
41@050hB01PB5P0D3Q8030H:00X4200>20`06A<G01XD600?2@d040X>014;3`0C3A405a4E01LA5P0=
1Pd09b0W04Q1B00C31<010040109400A2Q4200d63@0>0109400>1`h040L@01864P0D21@04@D?0104
3P0B1Q007Q<K01873`0B1`d01`0201D:400E2a0201<8400701873`0A1Ph040D=01053@0A1Ph040D=
01@94@0200X01`0?01063P0;0@`0610K00P22`0F31D02`4:01073`0=0PX01`0401L<500A10/09APO
00/01@0>0`T03`@:008040D;00P03`@:00h32@0O51X02`8606QMH`1oM7X030<701`A5`@03P<70P0?
0`L01P0A1@T06@lA00P0000=0@D040H800P001Cooooo000Kooooo`0A00h:1P0E4@h02`L601@@3@0Q
7AT0510<010=2@0A3@X04Ph;014=2P0B3P/03@T501LC400A3@X04Ph;020L6@0A3@X00P0>2PL04@0E
4@h04@d:01<?300G4a00510=01HB4@0E4A005Q8A010<2`0=2@P05a<B018>3@0@30/04@d<01@@3`0C
3`h04Ph=00803`/:02<04@d<01<?3P0@30/03PX9014=300H51<040`;018>3@0;1`L04@d<010?3@0<
2`T03`h<01<B40071PD04A0>01<B400:2@L03`h<010?3@0:2@L05Q8@01@>2`0C30X04P`9018=2P0C
3``050l<01@@3@0A3`/040h;00`;1`0?3`/03@X700h:1`02014=2P8040`90P0?2`P0200A3@X04Ph;
01<?300F4Pl0514>00/:1P0n?CT0CDa80P0H5a<2010?2`803`h:0P0=30P0200>3@X03`h<00h=2`0D
4a405A@B00`;2@0>3@/04A0>0P0B4@l02@0E51804A0>00d<200=30P040l;00`;1P0?3PX040l:00d<
200200l>2@0700`;1`0E51003Pd8014>2`0;20D04a0=00/:1P02018A3@0800l>2P081`D04A0<00/9
1@0?30T03`d900h=200=30P2010?2`0600h=2@0?3PT03@`8014@300>3@T040l;0P0>3@T01`0A40h0
30/9010?3@0D4a403`h<014@3P0@3`d00P0<2`T02`0?3P`04A0>00h=2`0>30d03@/<014?400D4Q<0
8AlP030^;`0>30d04@l@00803@/<00D040h?00`:2`0@3Pl03@/<00`:2`0200h<3@0B00d;300A3a00
3P`=00/92P0=2``03P`=00/92P0?3@h020L701DC500;2PX03P`=00`:2`0;2@X0518C010>3`0920P0
518C100=2``02@0>30d03`d>00l=3P0:20T0518C00`:2`0A3a0030X;00X82@0300`:2`0@00h<3@0=
2``03@/<00h<3@040P<03P`=01@B4`0<2P/03@/;01dL6P0P7ad0[JbZ030_;@081`D040l=00l>30@0
3Pd;00<040d<00d9200<20L00P0>2PT0A@0Q7A`08alN018>3@0<20L03PX900d9200?2`X030/:00lA
400;2`/03P`=00h:2`0?1`T050X=01462P0C2Pd04P/=00`6200A3@h03PX;00`82@0E4A8020D500d9
2P0C3a004@d>00d92P0@30d03`/<010<3@0?2``040/<01PC5@0<1`T02PD600l:2`0B3@h040/<01D@
4P0@2`d04Pd?00l:300?2P/02`L8014=3P0?2``03PX;010<3@0D41403PX;00T51P0B3Pl02PL701/G
600?2``03`d@00h<3`0@3Q403`d@00/9300B41<040hA00`:3@0?3A003@/>00h<3`0A3a803@P<010;
3`0200l:3P<04`hB00D03PT=00l:3P0@2`l03PT=010;3`0400l:3P803PT=00`04PdA00l:3P091@P0
3`X>018=4@0>2@d03P`A02XX;@1RH6D03`dB018@5@0>314600l=4P0800d83`0?2Q0050lE010;4@0@
2`l03`X>014<400;1`P2018>3`0500d92P0@30d04@`@00l:3P0@2`l00`0A3103010;3`0@00l:3P0>
2@d03PT=01<>400;1PL04@`>010;300@2`d03@P900/61`0B3@h04Pd?00l:2`0A30d03@P:00h93@<0
3@P<01D03PT=00`72`0@2`l03@P<00l:3P0<1`/04@`@00/62P0E41@09B0T04i9C@0A310050lC00d8
300H4aL0CdY>00l:3P0;1PX05A0D010;400=20h00P0C3Q@03P0>2@l040/A00h93`0:1@/04@`B00d8
3P0C3Q@03@P>018=4@0N6Ad0>SDi010;3`0B3A4030L;0`0?2Ph200d8300@00l:3P0?2``05a<D02HR
8`0A3@h03PX;00l;300D41405A4B01<?400:1PL04Ph?010<3@0:1PL06QHG02XV9`805a<D00D03`/<
00`82@0=2@X04Ph?014=3P02010<3@<04@d>00<030P901@@4@0710@00P0@30d3014=3P03010<3@0@
30/040`;008040`;00P03`/:00d9200D40l04Ph=00T5100F4Q402PH601<?3P8040`;00D04@d<018>
3@0B3Pd040`;00d92002014=300A01<?3P0?2`X04@d<00d;300?3@h04@l@00d;300I5aP08AlP014?
400H5QL02PP901@B4`0=2``03Pd;014@3@081`D00P0>3@/0500=2``04@l@00l=3P0=2`h04@lB010>
4@0?3A8040hA01<A4`0;2@X040h?00h<3@0:20T061HG010>3`0;2@X03`d>018@4@0?3@h040h?0P0A
3a802P0B41<04a4D01<A500D4QD05Q@G01DC5P0B41<05A<F01HD5`0C4Q@201DE5@0C018B4P0D51@0
5ADE01HF5P0>3Ph061PH00h>3P0Q8B405QHF01HG5P0J71P04Q@@01<E4P0G6AH051HD01HH5`0D5QH0
5AHH01HG6@0201@E600n01HH7@0H6b004A@I01@H6`0E6A/05QXK01@H6`0F6Qd05aXP02DX<@0D5b40
4aHR01DI900?5Ql06R4Y030d?00F6R8051PO01@G7@0I72808R<X01`M8@0G61d07R0U01TM:@0H7R`0
6b4/01dQ;00K82H05a`Q01HJ7@0W:bh08B8W01PH800J6R806ATS01hP;00L7RX061/T01LJ8@0I72<0
6QdR01TL8@0G6R006ahU01@G800M82X0=cY301LG7`0H6Al05aPN01<D6@0R8bP05QLM018B6@0P82L0
4a<J00l?5P0G61h071dR01HE6P0F5QP201DE5`0301<C5@0A4A<04Q8D008051@F00@04Q8D01TI6`0H
61X05Q@E0P0C4A803P0G5AH061HG01@B4`0E4a@04Q0A01@C4P0F51D04a4C018@4@0F51D05aDF01XH
6@0F51D04a4B0P0G5AH0100E4a@06QPI01XH6@0E4a@201<A4P<05aDF01P05A<F01LE600A3a808R0U
05=AEP0A3a@06aPO01HD6@0D4QH05aDH01`J7@0E4aH0CD]>02DS9P0C4A@03`d@01<A500E4aH05aDH
01@@4`0F41@0618F01D?4`0A2`l201<=4@03018<400C3A405@lC008050hB01404P`@014;3`0B3100
4`dA01D?4`0G4AD05Q0D00d72`0<1`X04`dA014;3`0>20`040T?00T32@0<1@`071DL01D>5@0200l8
3`0A018;4P0>1`h03PL>014:4@0?20l03`H?0104400C1a<04PH@01043P0B1Q004`P@00h32`0A1``0
5P/A034V;01SF5h00P0?10`401053@0B00d22P0<0`T03`@<01D:4P0M4QX060hE00d3300?21403PL@
00h43@0B21403@<;01873`0?10`03@<901L:4@1WFV405P/?100@1@/200l42P0B00l52P0B1`d06PlE
02LL8P0C2@h02P4500/2100>0`L04@H:00l31`0@10P06@dA00`1100D2@`04PP:00l41`0B1`/03P86
5?ooool001_ooooo00X0<Rh[014=2P0D40d02PH301DB3@0;20<03``701<@300>2PL01`<00P0@30T0
4@0C3``01`@2014=2P0K5a@02@D401/G500@30T0510=014=2P0C3``0510=010<2@0?2`X040`;00d9
200A3@`05A4@0080510?0P0A3@`0400B3Pd040`;00h:2@0A3@`03`/:014=300B3Pd040`;00l;2P0F
4Q409R8Q01`H5`0<20L08AdL01PD4`0?3P`2010?3@0H00h=2`0;2PP02@P600X91`0P7ad05A@B01PG
5@0I61H02`P701@?300B3@X04@`9018=2P0C3``04Ph;00d<200<2`L03Pd901XI5@0N7aX030/7014=
2P0C3``04Ph;0P0?2`P0500>2PL03`/8018>2`0D40d04Ph;010<2@0@3PX01`H203<b;P16AD404Q4=
010?2`0=30P040l;00l>2P0>3@T03@`800`;1`0=30T03Pd;0P0?3P`200h=2`0B00X91`0=30X03@`:
00@30@0@3`d051<@00l>2@0<2`H02`X500h=200?3PT03Pd801XI500>3@P03@`702HU8011@3/081lJ
0P0@30T04`0A3@X03`h:00l>2P0@3`/0B4M302PW8`061@806APD00`;1`0@3`/04A0;010?2P0?3PT0
3Pd800l>2@0@3`X020L200X9100<2`H00P0;2PD01`0<2`H030/900l>300>3@/02@P6014@3P071P@0
1P0>3@/01@0=2``030X;00<10P0R82408AlP00804@l@00d03P`=00@20`01000071XK05YHF@0C4A80
3`d>00`:2`0=2``03P`=00/92P0@3Pl03`d>00802PP900P030X;00X82@0A3a003P`=014?400<2P/0
40h?00`:2`H03@/<00@03P`=00d;300<2P/030X;0P0=2``01`0A3a000@00014?400A3a004a4B01HD
5@0>30d00P0=2``0300>30d030X;00X82@0>30d030X;00d;300>30d03@/<00h<300A40h03Pd;05IE
D`8040l=0P0>3@/01P0<2`T03@`:00l>300?3P`03@/900`81`803@T800D03`/:018>3@0A3@`03@T8
00h:2@0300l;2P0@010?3P0O8B00:BTY01@B4`070`@071<F00l52@0?10P03`H901<;3P0O6A/09b<T
00d92P0>2P/040`=00h:2`803@T:0P0E4A80500<20T0100100H20`0E4A8030H8018<3P0<1PP071HH
01dG6@070P<050h@01PB500K5AL05Q0B01<=3`0F41802`L801@@4@0@30d03@T:0P0?2``02@0:1PL0
<2`]03di>P0F4Q<0;BTZ01hJ6`0@3Q403`d@00h<3`0300d;3P0800<1100:20/03P`?010>4@0200<0
30X=00d8300B3A4200h93@03010;3`0:1@T03`X>00D03`X>00@040/?014<400A31004@`@0P0B3A40
1`03008040/?02<N8P0E41@02`H:00h93@0;2@h00P0A3a@200/93P0/00h<4@0:20d02`T>00/93P0<
2Pl03@/@00h<4@0<20h00`0400/6300=20h03`X>00P31`0=20`04Ph?01`H6@0F4Q<030P9010<3@0=
20`02`H:00d8300?2Ph03@P<00`72`0@2`l04@`@018=4@0C3Q804@`@010;3`0>2P/020@501@@4@0A
3@h03`/<01LC500A3@h02@D600`82@0A3@h0510A018=400>2@d300l:3P0E00h93@0=20`06A@H00h9
3@0D3a<01`8600H11@050@@02`H:010;3`0B3A403PT=00/62P0?2Ph02`H:04E0A00>2@d02@@800H1
1@0=20d03`X@00803PT?0P0=20h0300?2Q0020<901HA5`070PP04PdC00/6300910P0BDA807MbMP03
00802`H:010;3`803@P<0`0>2@d08@0?2Ph00`0000H20`0G4a@01P8300l;300>2P/030P900d92P0C
3a002`L801<?400;1`P040`=00`82@0D41403`/<01<?400I5AH061@E018>3`0?2``01`<4018>3`0J
5QL03PX;010<3@0A3@h040`=00l;300=2@X03PX;010<3@03018>3`03010<3@0E4A004`l>00804@d<
0`0B3Pd01P0>2PT03@T801TE500=2@P03PX9010<2`<04@d<0P0@30/01`0=2@P0510?018>3@0E4A00
3PX901<?3P0@3Pl00P0=2``03@0>30d04@l@018@4@0>30d05A<D00<10P0C4A802PP901@C4@0];2T0
5A@B00d<2P0>3@/00P0D4Q<0100B414040hA00l=400>30l200h<4@0700l=3`0C4A80518C010>3`0E
4a@03`d>014?400200l=3P0301<A4P0D4Q<04a4B008040hA00@04@lB018@4`0B41<04a4D0P0H5QT0
200C4A@05Q@G01HD5`0D4aD051@D01<C4`0F5QH061PH0P0G5aL0200L71`0:RXZ01PH600>3Ph04Q8B
01LH5P0C5A8051HC0P0E5a@0;P0E5aH051HF01@E5`0F5aT05aPK01@E6@0E5QX051HL01PK8P0A51/0
71lT018F6@0G6a`09BT/01<G6P0H6b0030lF014D7@0Q92l07B4Z01@K8`0Q:300E5QQ01HJ8`0I7BH0
5QTR01XM900K72805aPM01TJ7P0J72406al[01LM:`0G7BP0720[01`Q9`0H7B8061`O01LK7P0I6Ql0
71`T014A6@0F5R006Q`X01PJ9P0H6b@201/N9@0C01LJ7`0C5Q/05aXP01XM900C5Ql0418M01`O:00D
51h061PP01<C6`0B4aP06AXO01XK800F5a`07AhS01LH7@0A4QL04a@I01<D600201LG6@0C01DE5`0D
51H051@F01<C5@0?3a404a<E01DE5`0F5QP08R8T02l_;`0J61T04a4B014?400F51D06ALH01HD5@0G
5AH04@lA01@B5@0201LE600=01TG6P0C4A<030X;00h<3@0H5QL06QPI01HD5@0H5QL0518C01LE5P0J
61T061HG01LE5P0401DC500E01PF6@0J61/040hA024O901QGf@05A<H014>5@091``071XN02PV:@0K
6A`02`T<01TG6P0;2@`04a4D01LE600L6Qd040hA01@B5@0D41<04P`@00@04`dA00<04P`@014;3`0A
2`l0100B31003`0A2`l04`dA01<=4@0C3A404@/?01@>4P0?2@d04`dA02DO8`0P6Qh0618F01D?500@
2A003`P?014:4@0200h73P04014:4@0<1@`030D<00l83`8030D<00<04@PA01864P0B1Q800`0B1Q00
1P0R5al050TA01873@0D2@l0200302LL8P803`@<0P0@1@d201463P0?00h32`0A1Ph0308901053@0K
41P05@/C01@:4`0=1Ph03PL?00`22`0800L05`dE02/P:00Y7R@06PlE0080200200<050P<01052`0@
1@/00P0?10X200h32@0;00T0100:0@D04`P>01P=4`0F2a4050T?01452@0?0`L04@D900l31`0>0PH0
0P0E2@d01@0F2`l04PL;01052@0@1@T0304501Cooooo000Kooooo`0H09FAT00H518081`I00/80`0D
4@`03@X300/80@0A3PP0514<00h:1`0C3`d05Q8A01XF4`0H51403@T600l;200L61D02`L400l;200B
3P/03`/8014=2P0B3P/03`/80P0@30/0100810<04@d<01HB4@0=2@P201<?3P0[018>3@0@30/03`/:
010<2`0B3Pd040`;014=300C3`h04@d<00l;2P1EDE002`L601TE50091PD06QHE00`81`0=30X03Pd;
00l>300>3@/02`X800T81P0A40l03@`:014@3P0h=cD051<A014>2`0C3P/04Pd:014<2@0A3@X04Ph;
010=2P0C4Ph05A@@01hO6P0H6A@030d801<A3@0B3P/0510=018>2`03010<2@804@d:00@04Ph;014=
2P0@30T040d:0P0?3PX00`0C4Ph040l;00d<200600h=2@803`h:00h03@`800`;1`0=30P040l;014@
300B4@d05QDA00P70`0L6aL09bHR00h=200=30L030/600h=20803`h900P00`8000H5000;2PD02@P3
01TH4`0=30L03`/8010;20<040`900X03`h:0040000100001@H201PI500:2`H05aPC01<B3@0B4@`0
4A0;0`0?3PT0100;2PD03@`700d<1`0>3@P200d<1`0600`;2@0;2PT00`8001LF500<2`T01`H41P0?
3P`01@0:20T0=S@e00h<3@0F51D03@/<00804Q0A00L03@/<01TG600F51D03@/<020N7`0B41403`d>
00803@/<00@03P`=00/92P0>30d04@l@0`0=2``01`0;2@X04@l@00/92P0A3a003@/<00l=3P0:20T0
1P0=2``0100>30d03@/<00`:2`0;2@X200X82@0703lm?P0J61T02@L800H41@0L6Q/00@0000h<3@02
00d;300B00h<3@0<2P/02PP900d;300C4A802@L8018@4@0C4A802`T901<B40081`D030/900/:200E
518030/900h=2`0<2`T03@`:0P0?3P`01`0>30X03PX900l;2P0>2PT03@T800`81`0=2@P00`0?2`X0
3P0@30/04@d<01PG5P0620L02@T900P61`0<20T05Pd@00`41P0D2@d03`H900h72@0Q6ad07a/L0P0=
2@X08`0>2P/040`=010<3@0>2P/01001014=3P0?2``06QHG018>3`0810D0208401TC5@0A2`d02084
00h82P0O6A/04@/=01@>400G4A<04`d?014;3@0D3Q003PX;018>3`0E4A803`/<00`82@0=2@X04`l@
01lK700W8b@07QXK01`H6@0J5QL03P`?00<03`d@00P03P`?00`:3@0=2`h040hA00X82`0E4aH04Q0C
01DC5P803PX;00@03@T:010<3@0D41403PX;1P0?2``300h93@803`X>00d040/?00l:3P0B3A402@@8
00`72`0C3Q804@`@00`:3`0@3Q<03`dB00X83@091``02`T>00<030X?0`0>31403@0A31<040/A01HA
5`0A31804@`@00`72`0>2@d06ADF028N7`0H51D03PX;018>3`0A31000P0>2@d01P0@2`l03`X>00h9
3@0?2Ph040/?018=4@804`hB00X04PdA00/92P0;2@X04Q0A00l=3P081PL03P`=00`:2`081PL03`d>
0P091`P00`0D41<03`X>010;3`02010;3`0600l:3P0<1`/050lC00H11@0>2@d03@P<0P0E41@01@0=
20`02PD900l:3P0910P020<700803`X>00D050lC014<400J5AT030L;01D@5@0200l:40<03PT?0P0@
2a405`0M61h030L=018=4`0>2@l05Q4E00D0100D41<07QTM03<^<P0;1`X030L;00d8300?2Ph04@`@
018=4@0D3a<061@E01@@4@091@H01`<401HB4`0=2@X030P900804`l@00D030P901<?400=2@X04`l@
00T51P0200/7200<01<?400I5AH0100101@@4@0F4Q<00`0001TE5P0300003@T:00l;300@30d04@d>
0P0@30d0100>2P/03`/<010<3@0A3@h2010<3@0401@@3`0C3`h04@d<014=30804Ph=00D04@d<010<
2`0C3`h08AdL01DA4002010<2`0>01<?3P0A3@`03`/:014=300E4A002@D4018>3@0?2`X0510?00l;
2P0C3`h04@l@010>3`0?3@h200h<3@0?00d;300;2@X0518C00h<3@0C4A803@/<01PG5@0?3P/040l=
00d<2P0@3`d020H70040000C4A804@lB00803`d@0P0?3A80300?3A004a4D018@4`0B41<06ALJ00d;
3P0B41<040hA014?4P0E4aH05Q@G01DC5P804@lB0`0B41<0100D4QD05aDH01LE600D4QD201HD5`0E
01DD5@0E5AD051@D01HF5P0H61P05aLG01DE5@0?3`l00`<301PH600E5AD07QhN01HG5@0D5Q<061XI
01/M700I6aX05QLI01@E5`0F5aT061TM00805aPL03L061TM01DG7@0K7RD04aHM01hQ9P0B5QT06QhO
01PL7@0:3Q405QTN01LJ8@0X:c80@TE>00022`0M92`03QDM02X^>@0G6bH041@O020R;P0K7RL06a/T
01XK800G61d05ALK01XN:P0G7B/061hY01/O:P0L8BL06QlT018F6@0C5aX05aPM01PH800V9Rh08R8/
01<E8@0D5R8061/T01TL8`0H6b805QTN01XM8P0M82H092L^02<V;`0H6bD04QDN01@D7P0F5Qh04a<K
01<D6@0K72407b0U00806Q/O00H051DI018C5`0D5AP04Q<E01PH6P0F5QH201<C4`@051@D00d04Q8B
014A4@0K6a/09bLW01XH6@0D4a804Q0A01DC500F51H04a4D01TG6P0C4AD05A<H00805aDJ00@06ALJ
01HF600A4A<04Q8D0P0F5QP0200D51H05ADG01DE5`0B4Q@04a<E01@D5P0B4Q@05aDF0P0D4Q<05@0F
51D05Q@G01HD5`0G5AP02`T>01XH7@0C4AH040dD014?500B41@06aTL01HD5`0N71l09bDX00h<3`0?
3A004Q0C01TG6P0>30l04Q0C01DA5@02018<40804@/?00<04P`@01<=4@0C3A400P0C3A45018<400:
01<=4@0B31004P`@00h830080PH030H:01TC5`0B31002`D900h73@<03PL>01@02`@;00l83`0B2a80
30D<00h73P0B2a803PL>00`5300A1a404PHB01454@0@10h04@D?01@84P0;00P01`0400l42P0G3180
5@X@00d420803`@<0`0@1@d0500A1Ph03`@<01873`0<0PT0304901<8400=0`X050XC00H01`0>1`l0
4PP@00T01`0`9Rh0JEiT02dR:007004060`@01D93@0;00<03`@:0`0>0`T200d2200B00P00`0C20h0
40D;00L00P0M51P0CT=901L;3`0@0PH040460104200>0PH02`0300d21P0700004PL;00`31P0=10L0
2P445?ooool001_ooooo01@0GEUI010<2`0B3P/02@H300d:100?30@03P/300`91@0N6aH0510=00l;
2P0h=3<0DTi;01HB3`0:1P@05A4>02HR7`0C3``04@d:010<2@<03PX700P03`/8014=300A3@`04`l>
00l;2P0@30/05a<B014=30805A4@01004Ph=01DA400H51<04`l>014=300B3Pd0510?018>3@0@30/0
@3`k018?3P070`<061@C00`81`0A3@`03Pd;0`0?3P`200h=2`0B010?3@0F5A<0?C`j08f<RP0;2PP0
518?018>2`0B3@X04@`9014=2P0A3P/03`d900/:1P0C50l0QHJ108N8P`0J6aH03`l;0P0B3P/00`0@
30T03PX700l;2002018>2`0;014=2P0@30T03`/800l;200>30P05QDA00l>2P0?3P/03`h:00X91@0A
40`00P0=30P0100>3@T03`h:010?2`0?3PX500h=2@0400X91@0920@040l;00P70`806APD00`03Pd8
00h=1`0=3@H03@d600l>200@3`T03@`601/K500T91d020P300d<1P0F5@l3018=2P804@d:01T040h:
01HE4@0=30P06Q/F00d>2@1@DD`0QXN2018A300A4@X04A0:00l>200>3@L030`5010?2@0>3PL03Pd7
00h>1`0=30H02@P3018A3@0=30X061LF05EDDP0A40l04A0>00<03`h<0P0>3@/0300=30X020H701/I
6P0A3a002PP901<A4P0@3Pl02`T:00/:2P0;2@X030X;00h<3@<03@/<00@03P`=00l=3P0?3@h040h?
0P0<2P/02P0>30d061HG01HD5@0>30d04@l@00P61`0?3@h02`T:00d;300<2P/800d;30803P`=0P0=
2``01`0a;c00;R`]014?400:20T04a4B018@4@0>30d00P0=2``01@0>30d030X;00X82@0=2``04@l@
008030X;00@03@/<00h<30061@<03Pd;0P0B4@l01@0:2@L040l=00h=2`0<2`T03@`:00803`h<00<0
4@l=014=300?2`X00P0?2`X00`0>2PT03`/:010<2`0200l;2P0?010<2`0B3Pd0:RTX00/=30092@T0
3`d=01XF5`0;0PD060hA01@93@0<0`H040T;010:300C3a003PX;008030P901804@d>018>3`0>2P/0
2`L801DA4P0A3@h0=C4b02hZ:`0<20T050h@00d6200<10L06a@F018;3@0F3a403PL901082`0A2P`2
00l82P0?014:300C3a002`L801<?400>2P/040`=014=3P0>2P/02`P800h:2`0@30d04@d>00`82@0=
2`h03`d@008040hA00h03`d@00d;3P0?3A00GeeP06ESIP0D4QD04a4D00l=400T824061@E010<3@0A
3@h04Ph?00h:2`H03`/<00@03PT=00l:3P0?2Ph03`X>0`0@2`l05@1?BTh05Q8E01<>4P0>2@d04PdA
010>4`0B41D04@lD00h<4@0<2Pl03@/@00`:3`0;2@h030X?00h<4@0=2a002`T>010;4P0Y92X0:RD[
010;4@0200h93@09010;3`0C3a0061@E01DA4P0?2``040`=01<>4P0>2@d03@P<00803`X>00<03PT=
00l:3P0?2Ph0100?2Ph03@0>30d030X;018@4@0C4A803@/<01<A4P0B41402@L800`:2`0B41402PP9
00`82`0>2@d00`0?2Ph0500>2@d03@P<01PC5`0:1@T04@`@00/62P0?2Ph07APL01XE6@0@2`l05A0D
00d8300;1PX03`/>03@_<`0V8BD030P;014<400D3a<03`X?0P0?2Q003P0>2@l03`X@010;4@0?2Q00
4PdC01PC6@0=20h04PdC00h93`0>2@d03`/>018=4@0<1`/03@P<0`0>2@d03P0@2`l04@`@018=4@0C
3Q80:BDV02DQ8P0>2P/05a<D00/7200A3@h040`=01LC500<20T03PX;0`0A3@h02`0<20T0510A00l;
300@30d03`/<01@@4@0>2P/0=C8b02XW9`0@30d04Ph?00804@d>0`0@30d00`0?2``03PX;00h:2`02
00l;308040`=1`0@30/04`0?2`X03PX901`H5`0D40l030P700X61@0?2`X040`;00h:2@0F4Q408QhM
010<2`0D40l02@D400l;2P0@30/04Ph=00l=3P0@3Pl00P0A3a003`0>30d03@/<014?400R82405Q@E
00l=3P0C4A801`H401@C400920H040l=01@C4@0C4A805Q@E00l=3P0200l=400:014?4P0B41D04a4F
014?4P0B41<03P`?010>4@0J61/03P`?01@B5@804@lB00<05A<F01@B5@0C4A@01@0B41<00`0D4QD0
5A<F01DC5P0301DC5P0401DD5@0E5AD05ADE01DE5@805QHF04<051@D01LG5`0M7Ad04a<C01XJ6P0>
3Ph05AHE01<E4`0E5aH061XI01LI600E5QP05AHI01XK7P0J6al05AHK01LH700I6Qh06A/R01PK900A
51d06A`R010C600F6Qd05ATJ01`P8@0G6Qh0<3<j01DH7`0F6R<07B4[01<J8`0D6bD07B4]01hR;`0X
;3T08bDc01PJ:00I6BD08B4Y01`M8P0I6b0061`X01PN;00K8Rd07R8]01dR:00J7b@06AdP010D5`0M
7R<06a/S02HV;P0X:3804aDQ01`N:P0U:3406A`S01<F7@0I72405aXO01@G7@0C5Qd04aHO01<E800A
51d05QHP00805aLO00l061TN01hO900U9R/07b0T01TJ7@0D5AL05QLI01LI6@0D5QH061PH01DE5@0B
4Q804A4A01<C4`0F5QH00P0G5aL03@0D51@04Q8B01<C4`0G5aL05aHD01@C4P0D4Q805A<D01HD5P0E
4aH06aTM01HC600E4QP00P0C41H02P0G51X061LJ01LG6@0I6A/051@F01<C5@0H61X05ADG01XJ700F
5QP201DE5`0K014A4`0H5QL04a4B01@B4`0G5AH05A<F014?4P0E4aH06QPM014?500E4aP05Q<J01TG
700G5AT040hA01@B5@0C4A@04Q0C01PF6@0E4aH04a4D014?4P0@3Q405Q@G014=4@0E3a<04`dA0080
4P`@00@04`dA01@>4P0D3Q8050hB0`0C3A46018<400401D?4`0D3Q804P`@014;3`802`D900L03`P>
00d63@0@2A004@XA0109400H4AP06Q<J00803`P?00l04@XA00l83`0?20l04@LA0104400C1a<050PB
01<74@0B1Q0040D=01D:4P0E2Q002`8601L<4P0?1PX01`0@1@d04@0B1`l040D=01463P0E2Q804@L?
01063`080`T03@H=00l53@0:0@P08APN02XO9@0E2Q0040H901D93@0<0P@04@D800H03`@:018040L;
01883@0@1P/03`@:02PN8`1?@TT04`@90182200B0`P04`@901852P0?0`L04PL;00l5200B20/03`H9
00`51P0<1@LDooooo`006oooool04`050@8061@D00X60`0H51405A8;01LD2`0=2P4040d601HC3P07
0`80:BDU08Z6Q`0]:BP01`<1010<2@0H51405A4>01dI5P0H51400P0C3``2014=2P0701@@3@0?2`X0
2`L601DA400?2`X07QXI03di>00201HB4@0@01DA400B3Pd04Ph=01<?3P0B3Pd040`;014=300C3`h0
4@d<00l;2P0E4A003PX900<0001@C4/06QHE00<000803Pd;00X03`h<010?3@0A40h04A0>00l>300=
30X01`H4024P7P0E51803P`9100@30T0200>3@T02`X601DD400F5a806Q/F03dn>@0:30L03@d80P0@
30T01@0>2PL030P500h:1`0A3@X040`900@03`/800L04a4=00`;1`05100040l;018A3@0:2@D02`X6
00803@`800D03Pd900l>2P0?3PX03Pd900d<2002010?2`0D00l>2P0=30P040l;018A3@0@3`/04a8>
018A3@0;2PH03@d500h>1P0?3`L03@d500h>1P0A4@T051@<014A2@0B4PX02PX201<C2`0@3`L301@?
30<04Ph;00L01`H201HE4@0=3PX051HA028T7`0Z;2H03Pl900803`l701803Ph600d=1@0;2`<030`4
00X:0P0=3@D04A4901<C2`0?3PT01`H2018A3`0D4a409B@R014@3P071P@03`h<00h=2`0=30X200`;
2@0?00/:200E4a@0:BLX04E3A00>30d02`X:01@B4`0610D0:RPY01lM7P0:20T02@L800L51P081PL0
3@/<00803`d>00h040h?018@4@0=2``02@L800/92P0D4Q<040h?00D3100@3Pl030X;01DC500;2@X0
30X;00l=3PH03@/<00@02`T:00h<3@0@3Pl040h?0P0?3@h01@0`;Rl0I69S01<A4P0E4a@04a4B0080
3P`=0P0=2``00`0>30d030X;00X82@0200d;3004010>3`0;2@X02`T:01<A4@802`X800L01`H400l>
300=30X04Q4?00h=2`0<2`T03@`:00803`h<00@040d<00d920091@@02`L60P0@30/400l;2P0>010<
2`0A3@`03Ph=010B4@0l?3`030X:038^;`0B2@`040H901@93@0:0@@05PlA00L10`0A3@h200d92P0A
00h:2`0@30d040`=00h:2`0?2``061@E00h:2`0F4Q<04Ph?010<3@0<0`H04`X=01L>4@0800801P00
05YAE00C2Pd00P0B2@`201482`0?014:300L5QP02PH7010<3@0>2P/07ATJ00h:2`0@30d02PH700`8
2@050@8030P901<?400<2Pd03P`?00<03`d@00@03P`?01<A501kNG`0S8Z=0P0A3a80100<2Pd081`M
01<?400>2P/200l;3003014=3P0?2``03`/<00@03`/<00<03PT=00l:3P0?2Ph00`0@2`l01P0910P0
7APL01<>4P060@D07aXN059=D@803P`A00@03`dB00h<4@0<2Pl030X?0P0;2@h03@0@3Q<05Q@I01DC
600B41D03@P?010;4@0A31803`X@01<>4P0910P04@`@00X61`0;1`P00P0@30d0100>2P/040/?00d8
300=20`200l:3P0400d8300D3a<04PdA014<40<040/?01`03P`=00X82@0@3Pl03`d>020N7`0J61T0
2`T:018@4@0?3@h03@/<01<A4P0<2@/030L;00d8300>2@d03@P<00`72`0K5QX0;BP/01@?4`0?2Ph0
2PD901@?4`0K5QX04@`@00X52@0@2`l03PT=0P0=20`01P0F4AD061<G00X62@0300803@P<00X62P<0
3`X@00h040/A014<4P0>2@l04@`B00h93`0=20h05A0F01HA5`03008030L;00h93@0910P01P4501<>
4PD03`X>01d03PT=00h:2`0C3a0030P901@@4@0300004`l@00X61`0@30d03`/<02PT9@0H51D03@T:
00l;300;1`P04@d>00P41@0:1PL040`=01DA4P0<20T06QHG00L310050@805Q8C01DA4P0C3a0040`=
00l;300200h:2`803`/<00H03PX;00l;300A3@h04@d>010<2`0B3Pd301<?3P0F018>3@0?2`X04Ph=
00P40`0B3Pd03PX900/71P0>2PT040`;00l;2P0>2PT04`l>01`H5`0V8R40920O00l;2P0B3Pd04`l>
010<2`0<2P/03P`=010>3`804@l@014040h?00h<3@0L6Q/03@/<014?400i=cP07ahL01@C400L6aT0
?3/i038a;`0A3a0040h?01HD5@0D4QD04a4D018@4`02018@5@07014?4P0D4QD05A<F00h<3`0E4aH0
4@lB01@B5@02014?4P80518E100C4A@2018@4`0401@B5@0C4A@04a4D01HD5`80518E00l05A@E01<C
4`0E5AD051@D01<C4`0D51@07alO018B4P0G5aL0;bl_07EeM@0a<C406AXJ01LI600F61L00P0G6AP0
:00I6Q`061TL01`M8@0K72004Q<H01LH7@0I6Ql05ALO01<E8@0M82T051LN02lb=`0E6A`04aLH00/?
400F6Qd04A@I02<V;@0e>4402@dH00XA6`0E6bP05aXY04Y=GP1=D6406Q/]01<D9P0E52807AdW01hN
9P0L7R@0720/01TO;@0G7BP05ATT01HK8@0K82D05ATL010D5`0I6Ql201HF7P0D01/K9@0F62@08B<_
02P[=00G6R4041<J01TL8@0H6b0071lU01TL8`0G6R<061/U01HI8P0D51h051@L01LG7`0G61d06AXO
020Q9@0N7b<201HG6@0501PJ6@0F61L05ALF01DE5@0D51@00P0B4Q80200D51@05ADE01DE5@0G5aL0
6QXJ01TI6@0G5aL051@D0P0E51804P0F5A<05Q@E01LE5`0G5AP06ALL01HC6@0G51/05Q<J01/H8@0Q
7RD0<S4e00d=3`0>3Q006QXL01PH6P0F5QP061PJ014A4`804Q8D01d051@F01TI6`0F51D0518C01DC
500F51D04a4D014?4P0C4A@07adR01LE6P0<2Pl03P/B01@B5`0D4QH0518E01<A500O7B00518E010>
4@081PT06QPK01LE600@3Q406ALJ01@@500F41@05@lC01@>4P0201<=4@<050hB00<04`dA014;3`0A
2`l00`0B31001@0A2`l04P`@018<400?2@d030H:00803`T=00@02`D900T31`0=1P`03PL>0P0?20l0
0`0<1@`040T@01@=500200d63@0;0109400=1Pd03@H=0107400C1a<06PhJ01`@6P0J3QP05@TC0146
3P0700@00P0D2@l0100700806@hD01463P0A1Ph301053@0600l4300A1Ph04PL?01873`0A1Ph040D=
0P0>10`0300B2a8040T@00l53@0C2A4030@800d2200>0`T02`0401D93@0M4AD03`D600l42P<040D;
0P0A1P`04P0900@02P4501D:400K41H04`P>00`01P0@0@H06PT?01H52`0@0@H040<7010420070000
3@<700H0000U71l01P0101LA4aCooooo000Kooooo`05014<400=2PX00`00018>2`0?30D00P0;2000
300@3@H03``701DA4011?Cd0L6a]00<0000H51404@d:01LC400E4@h02PH301TE4P804`l<00X04@d:
010<2@0E4@h040`;00h:2@0C3`h03`/:01/G5P0`;2/0510?0`0B3Pd03`0@30/03`/:014=300?2`X0
4@d<018>3@0@30/03`/:00h:2@0A3@`04Ph=01LC4P0B3Pd03PX900`;2@0200d<2P0900l>300A40h0
4A0>00l>300C4Q005A@B00X91`0@3`d040d;008040`900X04@d:010<2@0>3@T0410<00d>2@0>3`X0
?Slj0:V[YP1EEe80410;0P0A3@X0100>2PL03@T600l;200@30T300l;208040`900L04@l;00d<2007
1P803@`801DD400?3PX02`X600D03Pd900l03`h:00h=200>3@P03@`700h=200?3PT01PD000l>2@05
100040l:00D4000?3P`03@d500l?1`0@40P00P0=3@D02P0A4@T04Q8:014A2@0D50`01PH000`<100>
3@D04`h;01D=2`0C3P/2018=2P09010<2@0;2PH05A@@010A300?4@`00P@000lC300=3PP03`l70080
410800`03`l700d=1@0>3PH030`4010@200F5Ph06ATA01DD3`071P803@`:00P71@01000200T81P80
40l=00L03Pd;00d<2P0<2`T02`X800/92P0510@071XK00804a4B00X01083010>3`0D4Q<02@L800L5
1P0B41405A<D00X82@0?3@h040h?0P0>30d03@0?3@h030X;00h<3@0<2P/03P`=00d;30081PL03P`=
01@B4`0Q7b004@l@00/92P0?3@h01P0=2``03@0<2P/03P`=00l=3P0?3@h03@/<00`:2`0?3@h081hO
01@B4`0;2@X00@0001DC500>30d00P0=2``01P0>30d030X;00X82@0=2``03`d>00h<3@805Q@E00X0
3`h=01@C4@0@3`d03`h<018A3`0C4Q003@`:00h=2`0<2`T03@`:0P0?3P`01P0?3@/030P700X61@0?
2`X04`l>010<2`803@T801@03PX900l;2P0?2`X03`/:00l?3P1OHF00emOG038`<@0=2@X050/>01lE
6@0N4aL03PD801@=3`090`D02PH700d92P0>2P/040`=00h:2`803@T:00H00`0000/7200?2``02PH7
00D10P070`@20189300F00l62@0D2`h03PD801H=400D2`h04PT<01072P0?1PT040L:00l82P0L5QP0
20@5010<3@0F4Q<0;RX[00d92P0F4Q<00`0001@@4@0810D01@42014=3P<03@/>00l03P`?00l=400@
3Q403`d@02HT9`0^;2l00@0200T72P050`H03@T:00/7200@30d04Ph?014=3P0E4A801P0?2``200`7
2`803@P<0P0>2@d01P0G4QH02PH901LB5P0H4aL03`X>00`72`802`T>01@03@/@00h<4@0=2a0030X?
014?500@3Q<04a4F01TG700F51T04@lD00l:4@0;1P`030L=01@?5@0J5AT03@P<018=4@0>2P/030P9
00h:2`804@d>00P04@`@010;3`0A31004`hB018=4@0@2`l04`hB014<408040/?02H04@`@018=4@0C
4A802PP9018@4@0N71d0JfUZ06QVI`0O7Ah071XK01PF5`030@80518C00l<3P0=20`03PT=00l:3P0>
2@d03@P<02TT:012?D407QTM00X52@03008020<700h93@0;1PX02@@800`72`0?2Ph03PT=00`72`03
00803PT=00l:3P0>2@d04`hB010;40<03`X@00h040/A014<4P0?2Q005a8H014<4P0?2Q006A@J02HQ
9`0N6Ad040/?01LB5P0J5AT01P4500`72`H03`X>00H03PX;01LC500A3@h03@T:018>3`0@30d200l;
300E01<?400k=cP07a/L010<3@0C3a002`L800h:2`0;1`P03`/<01<?400=2@X06aLH01HB4`030000
6QHG010<3@0D41404Ph?010<3@0?2``040`=00804@d>00l040`=00l;300?2``04Ph?01<?400@30/0
4Ph=01<?3P0D40l04`l>018>3@0@30/061@C00h:2@0E4A000P0A3@`02@0B3Pd04@d<00h:2@0>2PT0
4@d<01<?3P0O6aX08QhM010<2`0201@@3`0E00d9200=2``03P`=00l=3P0@3Pl04@l@010>3`091`P0
4a4B018@4@0E4a@0@T1102PW9@0B4@h01PD301@C4@0E51804@l@01PF5`0E4a@04a4D00804@lB0P0A
3a@02P0@3Q<06ALL028P9@0B41D040hC018@5@0C4AH04@lD018@5@0G5AX201PF6`80518E00@04a4D
018@4`0B41<0518E0P0B41<02`0G5AP0518E01@B5@0E51H051@D01HF5P0E5AD04a<C01DE5@0D51@0
61PH00806QXJ00<0:b/[00P8200E5QD00P0I6aX0100J71`06a`N01/L7P0H6A`201/L800k01<D6@0K
72407b0U01PJ8P0A4al07R4Z02@W;P2>TIH0:2`_02@X:@0J7Ql07B4T018E6P0R9BX0<SHn02T]>00<
4ad05Q`Y02/^?`0C5RT05aX]01PI;@0H6B/05aHU01TI9@0N7RH06Q`R01XN:P0K8Bl07R@_01`P:`0H
7B<05a`Q00hB5@0O8bH05aPM01DE7@0Q8BT06ATS01DG8`0I6bL06QdV01@G7P0@4aX04aHK00`?500B
5A/04QDL01@G800G6R@041<L01DE7`0D51`06ATQ01PI7P0E5Q/06a`P01XK7`0D5AL00P0G6AP00`0C
5A<051HC01<C4`0501<C4`805aLG01d05QHF01DE5@0B4Q803Ph>01LF500I61H061LE01LE5P0F51H0
5aDH01PF6`0E4aT05a@K01HC700M6R<09B8Y03<b=`0A41D04Q4F01XI7P0G5Q/061LL01DD6@0>3A80
6QTN01TH7@0A41D05aLI01<A4P0201HD5@0E01@B4`0C4A@04a4D01LE600@3Q<020H;01`J7`0?31<0
518G01<A5@0=2`h02`T<01<A500G5AP0<2ha01XH6`0<2Pd0518E014?4P0E4aH05Q8F00805@lC00@0
50hB018<400A2`l04P`@0P0C3A401@0B310040X>010:3P0A2`l04`dA00<04@/?0P0C3A402@0D3Q80
5@lC01D?4`0E3a<04P`@010:3`0<1@`02`@;00d63@0200X32P0B00h73P0=1Pd04@XA01L@5`0A2Q40
3@H=00l63`0C1a<060`H01X>600I3AL05PXD01dB6P0<0@T060dC01X?5@0700804`P>0`0A1Ph0200@
1@d03`@<00l4300?10`040D=01873`0@1@d03P<;0P0<0PX02@0?20l040T@0188400H3QH04`X?00X0
0`0K41@06@hB00d10`0201D92`803P<90P0?10X201052`0B00/01P0B1`d05@X@00d2200:0@D040<:
00l01@0J2@l05@@:00l01@0?0PH03@4500/0100C2@`04`X=05UCE@0D3Q00>C<e5?ooool001_ooooo
01h0:RHT00/71@0K61@04a0:00l<1@0U8QX04a08014>1`0<2@<06aPD02TV8`0E4Pl04`l<01@@3@0>
2PL0510=00h:200D40d05A4>010<2@0D40d04`l<00h:1`0@30T04@d;010<2P0C3`d04Ph<00d91`0E
4@l200l;2@1B010<2P0A3@/04@d;014=2`0>30T0518?014?300J61H04Q0=00l=2P0A3P`04a0>01DC
400Z9bD0E55?01`I5`0=30T030/800h=2P0@3``03`h;010?300A40d03`h;00`;200B4@h03Pd:010>
2`0F4a002PP5010>2`0B3`l020L601<B4@0G5QH03Pd=075aKP2j_;L0DE5=018A300B3`/04@d9010<
200?30P040d900l;1`0A3@T04Pl;010=2@0@30P04@d900h:1`0B3``05A8?010>2P0H5Q8071TF014?
2`0F4a004@h;00`:1`0A3`/040h:018@300?3@L02`T300/9100?3@P04@l:00/91@0D4@d03P`801DB
400=2PH071XF00h=200=3@H03Pd700l>2P0@40T0410:01@C3`8040l900@03Pd901@D3@0E4`l04Pd:
0P0B3@/01P0A3@/040`:00l;2@0A40d01PD400l?308030d902L03a4=01XK5P0:30H051H@00`<1`0@
40/02`/600l?2P0?3PX04Q4=01@C3P0B40`04a0=00h;300>2Pd04Pl?018@400=30/0410>00l?2`0?
3P`040d<014<2`0A2`/040/:00d;300?3Pl03Pd=00`;2`0;2PX05aHF014@4@0;2PX04Q4B00X92P09
20T02`X:00`;2P0>30`00`0=30/200`;2P0:014?3`0?3@d03P`<010>3P0@3`h02`X9018@400K6QT0
?C/k00X9208030X:01803@`;00h<300=30/03@/;00d<2`0=2`/02`T900d;2`0A3`l03P`<00/92@0?
3Pd02`X900X9200>3@`02PT800`:2P0?30`200h;2`0600l<300>2`/03@X:00h;2`0?30`03P/;0P0H
5AD02@0?3@`03Pd;00T81P0@3`d03@`:00h=2`0<2`T02`X800d<2P0200l>301i00X91`0B4@l04@l=
018?3P0?3@/03P/:01PF500;20L03@X900d;2@0>2`X03`d;00h;2P0>3@/0<C4^07QhM`0Q7Qd020@2
00l:2`0D3@d0614@01492`0B3@`04`h=018>3P0=20P03`X:014;2`0?20T03@P900l92P0D30h03PT:
01092`0@20X040/;014;300;1@H05A0@00`61`0E3@l050l?00h82@0B2``04`h?018;3@0A2@/04`h>
01<<3P0D41402PH7010<3@0H51D0:2@U00l;3004004071PI05UEEP0B3Pl05a<D00/7200B41003`h=
00`;300920/040hB018@500A3a<020H900d:300B3`l03P/:018=2`0?2PT03`/;01<?3`0B3Ph03@X:
00d:2`0>2``030T;00d<3@0@3@l03`d>00l<400>2Pl03``@00l<3`0C41804Q0?00h<2P0@3@`03P`;
00T6200=2Pd02PL;010<4`0;2@l02PP=018@5@0U8bP04Q0D00T72`0?3A4030X>010>400@3Q402@L;
00/:3@0;2Q004Q4F00h=4P0K6Al03P`B00d<400K6Ah06aPL00`83@0<2@d03PX?018?4`0200l:3P80
40/?00@03`X>010;3`0=20`03PT=0`0?2Ph06P0>2@d040h?00`:2`0B4140B4I70=;@d@3Zj>T0De5B
01<A4P0A3a002`T:01TG600<2@/040`@01@A5013@4<040`@01<@4`0;20/040d@00`8300@3A003PX>
00l<3`0>2Ph040/@0P0>2@h0300E41D08A`Q00/62`0<1``04@`A010;400=20d03`X?00/62`0A3140
40/@00l:3`<040/@02P05A0E010;400;1P/04@`A028M8P0;1PX04`hB01D@500?2Ph04@`@00l<3`0>
2`h03@X=010>4@0W8bL03`hA01PE600;1`P04@d>00l<30060P<08QhO00d92P0G4a@02`L801HB4`0Z
9RL0510A010<3@0J5aP02`P900l<3@0L6AX09b@U00h;300?30d02PL8010=3P0A3Pl03P`<0`0@3@h4
014>3`0i018?400@3@h04Pl@014>3`0?30d05Q<D00l=2`0A3``040h;00h<2@0=2`P03``:00d;200E
4Q0040h;01TG500D4@l03@/8014>3@0@3@`03``;00l=2`0@3P`040d<00d;2@0B40h04a0?00h<2P0@
3P`04@l=00l=3P0A3a004Q0A014?400E4a@030X;00h<3@0@3Pl05A<D00l=3P0M6a`03P`=01DC4P0A
30d04Pl?01<?3`0B3@h03``=010<3P0A2`h040d?014=3`0C3A004@h@01<@4@0G51D07AXK00804PlA
00/05a@F01<@4P0@31404PlC01TE6P0J5Q/05aDI01@C5`0C4QH05A<G01@C5`0201<B5P804Q4E00D0
5QDI01DC5`0E51P05QHG01HF5P0201LG5`805ADE00L05QHF01hN7P0D51@06QXJ01HF5P0E5AD06a`L
00805APH0P0E61T0@`0E61X051LJ01XL800K7B405ALL01hP9P0R92X07R0X01@G7`0F6B40;C0f096D
V@0_<SH061/O01PL800D5a/071lT01@G700G6R4051PS01/O;@0L82l0;C1001lR<`0N8C806A/Z01TL
:`0I72P06a`V01XN900I72404QLQ01`S;P0Y<3X09B/c01`Q:P0C6Al061hS018F700@51/07R4Y01DH
800C5b0061XV01LH900F5b805aTS01PI8P0E5ah05aTQ01DG7P0@4AT0:R`d02DW;`0?41T05ADM01@D
700J6R<04a<L01DF7P0J6b805aPO01DF6`0G61/05QLJ01<D5@0D5AH00P0C4a@301@D5@0;01<C500B
4Q<051@E01<C500E5AH061PI01@D500M71`061LF01/K6P0G5QH00P0C4Q<0=`0G5QL051<G01<B5P0E
4aP061LK01`K7@0H5aT05ADF01HF6@0C4QL051<H01XI7P0J6Al05A@I04E4B@1=C4l05aLG01@D5@0C
4QD04a4E018A4`0E4aL04a4E01PF6P0G51P0510F01LC6@0d<CH06A<J010=4P0C4A@061HI01dK7P0=
2`h0G5UL0<W5b@13@4<02@@801@>4P0H4QH04`dA01@?4`0/:2`030L:01LB5P0B31002@D8018<400A
2`l04P`@01L@500B2Pl03`P<01@=4@0D3Q400P0@2Pd02`0A2`h040X=01TC5P0H4QD02`D800h82`0=
1`X04`d@018<4@0?21003PL?008040TA03004@XA02HO9`14?DD06A8I01PA6@0C31<04``D00l63`0@
10l04@HA01H:5`0C1a@050PE01L;5`0D21804@H@00l42`0>1@T03P@900l42`0@1@`04PL>01<83`0A
1Pd040D<00d22@0B1`h050T@00l42`0E2Q403`D;01473P0:0`P04`X@00/1200@1Pd03@<800l42@0F
2a004`P=00d21`0B1`X04`L<01lD6`0:0@H050T@00`2200>0`X200`21`0A02HL8@0b9b`07A8G00d4
1`0I3A40300201/:3P0?0@<04@8601<5200?0P<04PD801851`0E2@X0@cLj00l51@0T6AT05?ooool0
01_ooooo00L0XIjG01dJ5@060`003P/401TF3`0D4@X04@h7008040d600<04Pl801<@2@0@3@H0100B
3P/201<?300?00/7100G4a006ADB00l;200=2@H04@d:018>2`0=2@H03`/801@@3@0M6AH0=C4^014=
2P0C3``04Ph;00<040`902@04A0<0040000=30P0ATE1038a;@0L6aL02PT700L60P0;2PH02`X701dL
60061@403Pd900d<200C4Ph05A@@01<B3P0E510030/700X91@0H5a<03Pd901@C3`0<2`T04a8=00l>
2P0B4A0030X;02DS9P1kNG`03P`?0040000X9RH05QDA028Q700G5A02014>2@03010=200?30L03``7
00803``70P0>2`H0100@3@P0514<01`H500B3P/200l;200J01<?300F4Pl06aLD03<_;00T81d04@d:
00l;20060P003@X501PE3P0I5Pl040d800h;1P0@3@P07QXG01HB3`0C3`h03@T800T5100Q7A`05aHB
018A3@0=30P04A0<01<B3P0A40`200l>2P<03Pd900<03`h:014;2`0B30`00P0A3@`0<P0@30/03@`:
014@3P0>3@/030`:00/;2@0=3@/07b0M0=7Cd00L8Ad0004002DW900J6aT02`/900h>300@40h051<A
018A3`0?30/0510A00h8300?2@l040/?00l=3P0=3@`030`:00h?2P0?3`/04@d<018<300E2``050/<
00h<3@0<30`03Ph>00/;2`0:2PX05ADE00820P0D51@020P801<C4`0G5aL03@d=010?3@0?3P`02@P6
00P71@0=30X04Q4?1P0=30X03`0A40h05aHD01XI5`1FEE<03@`:00h=2`0<2`T03`h<010?3@0?3P`0
3Pd;00l>300<2`T020L500`;2@0201HE4`07018A3`0>3@/01`H400X91`0<2`T02`X8018A3`0300h:
2@<03`/:01804Ph=01LC4P0=2@P03@T800h:2@0=2PT03@`:00`;2@0?3P`03Pd;00X91`071P@06aXH
01DD4P061@@05A@B01HE4`0510<201XI5`0401LF500100006APF00d<2P803`h<00T02PT700/:2009
20H02`P601<?300E4@h03`/800T50P0;1`@00P0=2@H300h:1`03010<2@0@1`P040L800@04@P90`0E
30d02@0D2``04`X;018;2`080P8040`;00/71P0<20L03@T800T5100301DA400600l;2P0810<02@D4
01HB4`0C3a004Ph?0P0F4Q<05@0@30d06ADF00d92P0S7b001001018>3`0@3Pd04A0<00d>2P0820H0
10@600T82`0E4aP03P`A00d93@0=2@P03`/8018>200A30H040/700l;2@0200h:2@0C00l<300>30d0
9B<T010?4@0820X02`/=00d=400>3A801@8901@B5P1BD5405Q@E00T81P0920<03Pd800d<2@0=30X0
30X=00`:3P0200/83`0N00l=4`081P/04Q0E00<1100J61/03P`?010>3`0K6AX030X;00X82@0<30h0
4Q@H00P;400L7b@0UIJK01@E6P0E5Q/04a8H01DD6P0@3aD03``C00X73P0?3A804`hB00<00P0<1`/0
61<G00`72`0;1PX03`X>0P0>2@d200l:3P0E010;3`0F51D081hO01hL7@0`;Rl0R8J70:VWZ00b<340
3@/<01@B4`0;2@X04Q0A010>400A3a8030X=05IDE`0:20/02`T<00d;3P0;2@`030X=00803@/>01/0
30X=00X72`080`T01P47014<4P0U82H0@Se301@?5@0R7B<01`8800/630070PP01@06018=4P0B3A40
4@`@010;3`0?2Ph030L;00h93@0910P03PT=018=4@0@2`l030L;00h8300?2@d00`0>2@d0400=2`h0
108501@B5@0B4Q@06ATK03Xj?00O7b408AdN00X61`0C3a005Q8C00D10P0K5aP02PH700L3100G4a@2
00/7200L01@@4@050`@03@/<00/92P0>30d04@l@01LE5P0L6Q/02@L801/I6P0>30d05aDF00d;300?
3@h040h?014?400@3Pl03P`=00`:2`0@3Pl030X;00L51P0<2P/04@l@00`:2`0<2`T03`h:00h=2@80
3@`800<03Pd900/:1P061@800P0C4Ph00`0=30P05A@@00l>300500l>300<010?3@0F5A<04Q4?018A
3`0N7A/04Q4?028P8@0>30d07A/L00H41@0;2@X081hO0P0B41402P0C4A80518C01DC500E4a@04`h?
01@>400E3a4050h@014;3@0@2P`501@>400?01<?3P0C3`d0510=01@@3@0F4Q406aLF01lK6P0E4A80
40`=018>3`0H4aL05a8F018@4`0@3a@04A0E00@051<H0P0C4QL0100D4aP05QDJ01LF6`0F5QP201@D
500301DE5@0F5QH05QHF00805aLG00H061PH01XJ6P0I6AT061PH01LI6@0D61T301<G600]01@H6`0C
5a/05aXO01PK800E61h06A`S01`O9P0K7R@061/P01HI7P0L7b@08RDZ01HI7P0I72404aHK01LJ7`0A
51T051LL01LJ800D62@05aX[01`O;P0R9C@09b/g030d?`0J7RT05a/V01`P:@0O92X06b0V01`Q9P0D
6b<05A`T01/R:P0N9Bd06b8Z01LN9P0I82P061lW01TP:00=51`020lG02H/=00F62@061PT00<06ATU
00/061PR018B700F5Ql071`T028R:P0Q8RP05AHK01DE7@0@41T05aLQ014A7@0201`L:00601PH900G
5b005QLL01DF6P0D5AL04a@F1P0F5QP02P0B4Q@05QHH01<C5@0C4aD05aLI014A4`0J6QX04Q8B01PH
600D51@201PH600:01HF5P0C4a<04Q8B01DE5@0F5QH05ADE01XJ600G5aL05QHH01@C6@804a8J02`0
6QTQ00l>500L6b009RHW01LG5@0:2PP06aXN010?500K6Ql0?ce201LE6P0:20d07QTO01PC6@0G4QP0
6A8I01<<4`0=20h07a/O00l=400>30l05A<F01lJ7P0T7b<06Q@H01<=4@0I4aL05@`A01T@5@0d;c<0
_[bo02/Y;00>30l04Q0C01TD600L5QX07ALK018<400A2@h04PT>020G700W82<05a4C014;3@803PP:
00<02P@600h82P0D3Q000P0B30h0700F418050h@00X42@0>1`l03@H>00h73`0B2a<05@hF06URJP39
`/X0<2Ta01<<500K51`03PL?018:4P0B1Q006PhJ01@85P0@0a@07A0Q0186500?0a402P0901873`0K
41H060dA00l42P0@1@/20146300A00l42P0>0`T04@H<01L<4P0M4QP04PL=01P=4`0;0PH01`0202LL
8P1MDUP06PlE00L00P0G318040D;01873@0A1P`00P0>0`T05P0C20h01`05028F800A20h02P0701<8
3`0D2@l030470189300:00<01`0001lD601SEe/0GDiA01@61`0V5QL05@D601H61`0;00004`<401H6
1`0G1`P201D51P0301H61ooooooooooo01;ooooo000Kooooo`0`02/X8@0=2P@06aPA00`90P0:1`40
514:00l<1@0@3@H04Pl801@A2P0C40T03P/401DA3P0D40d04Ph;014=2P0C3``0510=00/7100H5140
510=018>2`0E4@h04Ph;014=2P0>2PL03@T6010<2@0K5a@0=30]018>2`0@30T04@d:018>2`0A3@X0
40`900h=2@0I61@05A@@010?3@0510004a8>010?2`0=30P051<?00X91@0F5A403`h:0P0>3@T09@0E
51005aHB01<B3P0D4`l02`X600h=2@0R8Ad03@`801@C3`0I61<020L20040000C4Q404Q0A00L5200l
>Sd03@/>00X82@0F5A@01@@001PG4P0A3`X0514<01HC3P0C40/040d8014>2@0I5Q404a0;00d:1@0A
3PT03``701<@2`0T8Ad05a<@00l;200B3P/00P0A3@X0500?2`P06aLD01@@3@0@30T06ADB01DA3P0C
40/07AXC028O600A3PT030T4010=200A3@X01P8000d9200B3Pd040`;03Pd<`0L6aL05QDA0P0?3PX2
014@30803`h:0`0@3`/00`0?3PX04@/;018<3002014=3004010<2`0=30X03`h<00`;2@802PX800l0
30`:01/L6P0];b`041DA01HH5@000@00IFIS01hN700=3@/03Pd;018A3`0A40h03P`:01<?400?2@d0
0P0?2Ph06`0>30d03@d<00`>2`0?3`d040l=018>3@0B30`04``=018<3P0>30d03Ph>00l?3`0;2`/0
20P800h>3P0C4a<03Ph>00820P00000010@4018B4P0;2PP03Pd;00d<2P0920H02`X801<B400600`;
2@0900h=2`0:2@L00P40020O7@0510803`h<00`;2@0?3P`040l=00803Pd;00T03`h<00d<2P0920H0
3@`:01DD4P0D4a4040l=00/:20061@<00P0<2`T01@0:2@L030/900d9200=2@P03PX900<03`/:00H0
4Ph=01lK6P0=2@P04Ph=01DA400=2`T200`;2@0C00h=2`0=30X02@P600/:200920H00@0001PG5@01
00001PD300l>30081`D081lM00T81P061@<030/900P71P0C4Q0051<A00d<2P0200T81P0300`:1`0?
2`P030P500803@T60P0;1`@01@0=2@H030P500h:1`0>2PL03@T600804PT:100A20T201D<3@8050/<
00l04`X;018;2`0?2@T05A4@01LC4P0;1`H04`l>018>3@0810<0100000h:2@0C3`h02`L601<?3P0F
4Q<00P0C3a0201HB4`0E014=3P0I5AH01@4200X71`0>2P/0510A00h;2`071P803@h:018B400@4180
3@`?01DC600D4QL04@dA00l;2P0@30T04Ph8018=1`0A30P040`:00803PX902X03P/;00d;300^;2d0
51<D00P82P0<30h03@d@00/:3`0;2@h08AlS0>k/k@24PX<05QDB00d<200>3@T03Pd:00h=2`0=2`h0
3@/?00d;400200H040dC00h<4@0C4AH0:2HY06=QI00<2Pd02`T:028P8@091`P03`d>00X:300;3A40
00<601LK7P1JFel071/P0000100<2a003`dB01PF6`0?3A8200/93P0O05]FFP0F4AD04`hB018=4@06
0@D03PT=01@?4`0?2Ph03@P<00h93@0B3A4050lC00l=3P091`P040h?014?400Y9bP0@T1101DC5009
1`P0518C00/92P0<2P/020H802DS9P0K6A`05Q@G014?4P0?3A001`D800`:3@0200d;3P0@00`:3@0;
2@`05a<G01LB5P0?2Ph03PT=00l:3P0O6Qh050lC071[K`12?D403`X>02@O8`0?2Ph02`H:014<40<0
3@P<00L02`H:010;3`0F4AD081/O01D@500=20`030L;008040X>02803`X>00h93@0>2@d030X=00T7
2P0<2Pd05ADG065QH`3Zj^`0G5aN00X61`091@H030P901<?40091@H02PH700h:2`0?2``04Ph?00P4
1@0>2P/02PL701HD5@2:R8T0:BLX01LE5P091`P030X;0040000?3@h00`8200L51P0N71d061HG0`0@
3Pl0400>30d030X;00X82@0E4a@06QPI00d;300<2P/04Q0A00H41@0>3@/03@`:00h=2`0?3P`03Pd;
00`;2@0L6aT2014@3P0300P71@0C4Q001PD300H03`h<00`040l=02PW9@0A40h051<A02@S8@0?3P`0
O7Yk00@20`0:20T07Q`M00l=3P081PL2010>3`@04@l@00H04Ph?01<?400C3a004`l@014=3P0@30d5
01@@4@0=01@@3`0?30X04Q4=01@C3`0C4Q00518C01DC500C4A803`d@014?4P0F51L05aDH01DC5P03
018A5P0300l>4`0=314040lD008051<H00@05A@I01HE6P0G5Q/05QHH0P0C4a<01`0D51@05aLG01TI
6@0H61P05aLG01PH600J6QX00P0I6AT03@0G6AT04aLH01<G600B5QL04aLH01@H6`0B5QX051LL01LJ
7`0E61h05aXQ01PK8P0H6b400`0G6Ql01@0B5AX051LL01PK800E61d071lT00804aHK00/05aXP01XN
:P0H6bX05aXY01`P;00R9S80:2`h01TM:00G6b@06QhW01`Q9`0201XO9@0702`c>`0N9Bd06B0X020W
;`0L8b/05QdU00P?5`0200L>5P0500/B6P0U;3@0MG^301LI9@0I6BD00`0J6RH04`0I6B<07alW01`L
900X:3003@hC01<D6@0A4QL04a@I01TI800J6R8030`F014A6`0J6R@05aLQ01HF7`0E5Q/051DI01<D
5P0B51<01P0D51H09@0E5AL05aLI01@D5P0C4aD051@F010@4P0J6QX051@D01<C4`0>3Ph061PH014A
4@0G5aL051@D018B4P0E5AD051@D01<C4`0G5aD05QHF01DE5`0F5AX05QDM01LF7P0H5al04A0F01@C
600;2``0410>01LG5`0M72000`8700H52P0B4AH02PP=01@B5`0G4QP00P0E41H201H?5P0J01D@5P0:
1`X06ALJ01HD5`0E4aH04`hB00d8300=1`/06A<G01XD600E31406a8G01@>4P0k>C`061HI00X82`0J
61/01`8600`72`0C3A403PP<00d62P0:0@H04PT>01dF6@0E3a42010:300P014;3@0?2@/040X<00d7
2@0C3@l02`D701D?4@0?2@/03PL=00l83`0>1`h040T@01<<4`0E3QD0:24X04i7CP0400@0204800l8
3`0D3A@02`8:01T=5`0M4Ad03`<A0186500E21T05`/I01X>700@10l03`@<01P=4`0=10H201052`80
3`@:01`04@H<01<83P0A1P`040D;01L<4P0@1@/04PL=00d3200C20h04@H<02/P9P0C20h04PL=00L0
0P0>0`T040D;0146300?10X03P<901052`1QEEl0YYZT03@Y<@0@1@d04`P?01dB600D2@l03PD80P0<
0@D02`0C20`0:AdQ01T:3@0N4A802`0001X:3@0D10L070`?01821@0E1@P05PH9008050@700<05@D8
ooooooooool04_ooool001_ooooo00L04@h:00`91@0B3`T03P/5018?2@0@3@L04Pl9008040d70100
4Pl901<@2P0A3PT061@A01DA3P0A3@X040`9018>2`0D40d04Ph;01<?300=2@H081`I028N6`0B3P/0
4`l<0`0B3P/01@091@804`l<014=2P0<20D03PX700804Ph;014040`9014@300920D03`h:01DD4009
20H03`h:00/:1P0F5A4051<?00d<200E51003Pd9010?2`0?3PX051<?01<B3P0300d<2003014@300U
92002`X6008040l;01d04Q4<01HE4@0>3@X07Q`M06ESIP0P7R403`d@00H41@0J6AH040l;01@C3P0?
3@X05A8=01TF4@0E4Pd04@h901@A300S81/07AXE01DB3@0J5a803P/600`9100H51002`L400d91P0E
4@h030P500l;2002018>2`07010<2@0?2`P04`l<010<2@0;20<0514:01LD3@0200d:1@09018?2P0A
3@X04@d:01@@3`0A3@`03@T8018>3@0C4Ph04A0<00D03@`800L03Pd9010?2`0@3`/03`h:00h=2@0A
2`/04P`<00804@d<01h040`;00d<2P0@3`d03Pd;014A3`0@40h02`/900`=2`0>40d01P/7034c<009
2`P0414?00/;2P0>3P`030/900l>300@3`d03``;018>3@0A2`d040/>00d;3@0>30d03@h>00h@3P0=
3Pl03Ph=00h=300?30`2010;300400`:2`0>3Ph0410@00h>3P8030`<00X01`L700P8200F5QH0410@
00`<300;2`/03@`:00/:200?3P`04A0>200=30X0100@3`d03`h<00/:2@0;2PP200h=2`0B00`;2@0=
30X03@`:00/:200<2`T03@`:010?3@0;2PP030/900l>300=30X02@P600h=2`0=30X030/900d<2P0D
4a401PD30P0=2@P09`0>2PT03`/:00l;2P0@30/07a/J01/G5P0A3@`040`;00l;2P0:20H02@P600X9
1`0<2`T03@`:00`;2@0>3@/04A0>00`;2P18AdD040l=01@C4@0i>3H08R4P03@c<@0R8Al04A0>00H5
100C4Q005QDC01TH5P0@3`d030/900h=2`0@3P/04@d:00l;200@30T03`/800h:1`02010<2@0500d9
1P0?2`P04@d:00d91P0?2@T00P0@20T300l720804@X:00X04@T:01082@0@20T03`P8014=300E4A00
7a/J00d9200I5A@071PG0P0A3@`0FP0?2`X04Ph=01HB4@0=2@P04@d>00l;300>2P/040`=014=3P0?
2``030P901HB4`0B3Pl03@T:00l;300=2P/040l=00`<2P0<30`03`lA04M6BP19Ad`07A/P01LD600A
3@h040`<010;2@0@2`L04Pd:014=2`0?2`X03PX900d:2P0<2P/0518C00h=3P0@41804Q8D00`<3`09
20d04@lD00`:3P15@d@04Q0A01DD4@0;2PH03@`800d<2@0=30X03@/>00d;3`0=2a0030T@00/93`0@
3Q<05A<H01HD5`0o?D005Q@G081nO`30_[l0@Cm000`:2`0?3`l03a0D01`O8P22Q8P05aPL00h=4P08
1``02`T>00h<4@0A3a@03``A01`H7P0>2a003`/>00h:3@0B3A404@`@00/62P0>2@d04`hB010;3`0>
2@d03`X>014<400B3A404@l@00l=3P804Q0A00h04a4B01DC500E4a@03`d>010>3`0=2``02@L8010>
40081PT02`T<00h<3`0A3a8030X=01@B5@<03@/>0P0;2@`0600B3Q802`H:00/62P0@2`l03PT=010;
3`0;1PX06aHJ00P41`0S7R804@`@00/72P0E41@04@`@00h93@0B3A4040/?00`72`0D3a<040/?00d9
300A31005Q4E00l:3P804P`@00<040/?00l:3P0>2@d00P0<2Pd0300=2`h0410B04i>D02`/;40>SXl
010<3@0H51D040`=01<?400:1PL04@d>018>3`803PX;00l03@T:00`92@0A3@h030X;051>C`0I5aP0
3P`=00L51P0@3Pl09B<T07QfM`0G5QH0518C014?400<2P/01P0@3Pl02`0B4A4040h?018@4@0>30d0
30X;01HD5@0I61H04Q4?00d<2P0?3P`040l=00803@`:00D03Pd;00P71@0?3P`0A4=1014@3P0600l>
300<00`;2@0`;bd05QDC00l>300B4@l04a8@014?400I5aP04a4B014?400C4A804Q4A0P0B4144014?
40H04Ph?1P0E4A804@0E51405QDB01DD4@0B4@l040h?014?400B418040hA014?4P0E4aL05Q@H01DC
5`0C4QL04Q4F020O900V9BX07A`Q008051<H00H04a8G01@C600D4aP05A@I01LG6@0F5QH201@D5003
01HF5P0H61P06ATI008061PH00@06ATI01XJ6P0J6QX06Q/L0P0G6a`01`0E6AX051PI01<G6P0C5QX0
5APM01PK800H6b400P0F6B001P0H6b4051LL01HI7P0M82D05APM01XM8P806A`Q00X08bH[01LJ7`0E
61d06A`R01`P;00H72T051PU01LK9`0J7RT06AdX0P0L82T02P0J7RL061dS01PM8`0H7B<0;38i01dS
:P0H7RD07R@[01TO9P0F72<2010F7@0M01HL8`0G7B@05A/R01/P:00G6BD06QXV01`L:00L72L06a/V
01XJ900O7bL05aLO01hO9@0I6Ql061TN01DF6`0F5a/04A8F00d>500C51X061PQ00l?600F5Ql05QLL
01@E600C5AD04aDC018D4P0E5AH01@0E5AL0100D51H05aLI01LG6@0E5AL201@D5P0A01DE5@0F5QH0
5ADE01DE5@0R8R805QHF01PH600E5AD051@D01DE5@0B4Q804A4A01HF5P0E5AL051<H01DD6P0E51`0
0P0F5Ad07P0I61h061LM01@D5`0E5AH06QXK06m_L`0N7B8030/@01HE6P0@3Q<05Q@I01LC6@0I51X0
5Q4G01<=500F41H06A@J018@4`0C4A@07A/N00l=400O6Qh0AT5502HP900C3A405a4E01T@5@0J4AH0
5@lC01`J7@804Q0C03D05aDH00/72P0E41@05Q0D01<=4@0H41D05@`A00l62`0H41@07ALI01H@4P0C
3@l04P`>00h82P0C3@l03PP:01H@4P0B30h04`d?00h82P0D3A804P/B014:4@0@2A003`P?0109400D
3A@0100401XC6P0>1`h081TP09VBV@1?ADh05PXD01464@0G2aT0;20^01/?7P0H3AX04PHB01874@0F
2a<04`P>01872`0@1@/03`@:00h32@0A1P`05P/A01dB600D2@l02`460146300200d2200901L<4P0?
10X02P4501@:3`0900@04@H<01873@0=0PP03P<900@040D;01P0ACU306YNJ00N4a/01`0400d22@0G
318050T?00d31`0>0`L040D901062@0E2@d04`H803h_<@0C0`H06P`>01851P0J2Pd03`0201821@0C
0`H04@4401000`0A0@@Dooooo`006oooool02P03000040d801PE400E4Pd03``700`9100D4@`040d8
00h;1P0@3@P201<@2`0301HB3`0D40d04@d:008040`900H04@d:00`81@0G4a004@d:010<2@0E4@h2
01<?30802`L400L05Q8?010<2@0C3``0510=010<2@0>2PL03`/800803PX702X03`h:01HE4@0D4`l0
0P4000<2000@3`/04Q4=01<B3P0Q81`061LC00d<200K6QH03`h:00d<200B4@d04a8>014@300C4Ph0
1`H400P70`0B4@d03Pd900l>2P0K6QD02PT400P70`0?3P/0;Rd[0:RVY`0V9BL09bDV01@C4@0D4a00
2PT40040000=2`H03``7014>2@0?30L03@X500l<1`0D4@`2010=200801PE400B3`X040d8018?2`0:
1P<0510=01PD4@0<20D2010<2@0C00L3000=2@H04@d:01DA3P0K5a@04a0;018?200>2`@03@X5014>
2@0@3@P01@4000d91P0<20L040`;01dI600I5A@03@`800h=2@0300l>2P0300h=2@0<2`L030/700<0
3@`800<030/7014;2`0B30`00P0A3@`0100@30/03@`:01<B400>3@/200/;2@0K00X:200>3`d03Q0=
00/@300A4a004Q@A01HG5@030`403`l=00X:200=30X040l=010=300C3`h040X:014<3@0?3@h03Ph>
00d?3`0>3a404A8D010A4`0@41003`l?014>3`0A3@h02PP900803Ph>00l03`l?018B4P0>3Ph01`L7
00l?3`000000410@01TI6@2ZZZX0:2LU010?3@0;2PP03`h<00h=2`0?3P`01P0>3@/03`081`D03Pd;
00l>300;2PP03Pd;0081000?3P`040l=00h=2`0<2`T03Pd;00l>300=30X030/900d<2P02014@3P80
40l=00D01PD300`;2@061@@05A@B00T81P0600l;2P0U01PD4`0810<03`/:00h:2@0<20L03@/900d<
2P0>3@/030/900T81P0:2@L01PD401DD4P0<2`T04A0?010?3@0I61H03`h=092?S@0`;bd02PT70040
000C4Q003`h<00h=2`0A40h03@`:00`;2@0>3@/03@/8010<2@0A3@X03PX700/7100<20D04@d:018>
2`03014=2P0300l;200=1`L03@L700803PP80P0?2@T00`0B30`04@/;014;2`03010:2P0=00T5100<
20L04Ph=00/71P0?2`X04`l>00@0000>2PT02`L601LC4P0`;2/09B4P00l;300300h:2`0F00l;300@
30d03`/<01/G600A3@h02@D601PD5@0B3a0051<A00h>3@0@41001PH804a;CP0i=c`05Q@I018>4`0@
2`l04@d>01<>400C3@d04@`9010<2P803PX903<03P/;00d;300?3@h03`h?010@4P0=3@l02`/>014@
5@0M6b0020H900X82@0G5AH01@@302@S7`0<2`L030/800`:2`0=2``03@/?00d;400;20l03P/A01PF
6`0G5AX07A/N02l]<00D4QD0LW1a0;Fc]00e<c@00`4200l?3`0O7b8010D903<d>0082@d06aXO04m>
D`0<2Pl05aDJ00h<4@0@2a405A0F00<0100@2`l01P4500<00P0<1`/061<G01@?4`0?2Ph00P0@2`l0
0`0?2Ph030L;00/62P0200/92P0B00@20`0;2@X04Q0A00`:2`0C4A804Q0A01<A4P0A3a0020H700L5
1`0H5QT05aDH00L5201BD5<0@T1300T72P0=2`h030X=0P0;2@`0100<2Pd04@hA00h93@0E41@2018=
4@0C00D0100:1@T05Q4E00l:3P0?2`h05Q4E01`G6`060PD040/?01LB5P0W8RH071LK00/62P0=20`0
6A@H01/F6P0=20`03PT=010;3`02014;3`06010;3`0?2Ph03`X>00d;3P030@@03@/>0P0<30h04@08
20X06QXL014=3P0A3@h01`<403hj>`0B3Pl05A4B00<0000;1`P04`l@00l;300;1`P0Ad=402<Q8P06
10D04@l@008040h?00L03@/<00P61`0L6Q/0518C00/92P0=2``030X;00<040h?00h04Q0A01@B4`0F
51D0DDm@01lM7P0F51D06ALH00X82@0=2``05QDC014@3P0=30X03Pd;018A3`8051<A00D04Q4?01LF
500=30X05aHD00`;2@0600l>3003010?3@0D4a403@`:008040l=00L03`h<01@B4`0@3Pl01@<400`:
2`0?3@h06aTJ00<04@l@0`0B41401P0B3Pl04@d>014=3P0B3Pl04`l@01@@4@D05A4B00<04a4B01@C
4@0D4a400P0C4Q003`0F51D061HG01<A500C4A@04Q0C01@B5`0E4aP051<H01HE6P0A41D08R4V02/Z
;`0O7R<04a8G01@C600201<B5`8051<H00<05aLJ01PH600G5aL00P0E5AD00`0F5QH061PH01TI6@02
01TI6@0<01XJ6P0K6a/06ahN01XN7`0I7Ah061`M01DI6P0C5aX05ATM01LJ7`0H6b006QdS0P0E61l0
400I72805APM01DH7@0J7B805aXO01HI7P0G6Ql05APM01hQ9P0F6Ah05APM01HI7`0J7RT061`W01HJ
9P0G6bH201PL9`0801/O:00L82T05a/T01@I7`0G72806AhT01dR:00K82H301TN900P01HK8@0X;C<0
9R/a01XO9@0;41H0314G01dR:00G5b4061PT01`L:00L72H06a/U01PH8@0A4AT06a/R01@E6P0F5a`0
4A8G014B5P0G61X09RLZ01TJ7P0F5a`05AHL01TJ7`0G61d05QLJ01DG5P0D5Q<04aD@018D4@0F5QH5
01HF600=01<C5@0F5QP06ATK01HF600C4aD06ATK01HF5P0B4Q805QHF01LG5`0P82005ADE01LG5`03
01DE5@03018B4P0?3`l05ADG008051<H02h05A@J01HE7@0F5Ad071/S024P9P0a<3H051<H00h>400H
61X03PlC01HE6P0I61d06QTN01PF6`0T8RL05Q@I01/F700I51X05A0F01LB600I51X0;R`_00/9300?
3A006QPK01HA5@0B3A406Q@H01@>4P0L5QX04`X?01D<4@0>2Pd03@/>01<A500=2`h05Q@G018=4@0;
1`X04@/?00L11@0?20`06A0E01893P0D31006A<E0P0C3@l0800E3a404P`>01<=3`0J51H03PP:00X4
1P0=1`T0618D00/5200=1Pd03PL>00l83`0@2A004@XA00h73P0G41L03@H=00X32P0;10/08Q/R01XA
6@0B1Q0040@@01D95`0T62H08aLU04m3D@0V6RH02`8901H;4@0>0`L020010P0@1@/200l42P0?0146
300C20h04`P>00h32@0E2Q00304700T0100?1PX04@H<00T0100<0`L0304701T>500<0`L03`@:0080
3P<901/04@H<01873@0A1P`050PB00L01@0C210050TA00l42`0700802@0401@93P0H3A404@H:00T0
0P0800006P/>00/0000W5aX03@00020@4`0?00804@4401@41`0E1@P04`<601821@0C0`H05?ooool0
01_ooooo00L06aPC018?2`0<2@@05Q<>018?2P0<2@@04Pl:008040d800<04Pl:01<@2`0A3PT00P0B
3P/04P0A3@X040`9010<2@0?2`P030P501HB3`0E4@h02`L400d91P0B3P/03`/800X60`0810404Ph;
010<2@0E4@h04`l<018>2`8040`901404`l<01HB3`0;2PH02`X600h=2@0D4`l061LC01@C3`0;2PH0
1@@0014@300D4`l02PT501LF4P0@3`/02`X600l>2P02014@300C01<B3P0G5Q803Pd900T8100A40`0
2@P401<B3@0>3PH05A@?014@3@010000;2X[01TG601mNg`0BDQ600l>2`0F5A0010<001<B2`0200d:
1@803P/600@03``700d:1@0=2PD040d80P0B3`X04`0C40/0510<010<2@0G4a005Q8?018>2`0E4@h0
510=00h:1`0D40d03`/800X60`0A3@X03@X5018?200@3@H040d801<@2`0?30L00P0H5140100B3Pd0
3@T800l;2P0?2`X2010?2`0400l>2P0=30P03Pd9010?2`803Pd90`0=30P00`0>3@T04@/;018<3002
014=300J010<2`0=30X03Pd;00T81P092@L02`/900X:200>3``03Q0=00D:1P0>40d0418?00P91P0H
61H0410>00X91`0=30X040l=014?3@0D40l03`T9014<2`0@3Pl0410@00h?4P0:3Q4200lC5P803a0B
00X03`l@00l=3P092@T03Ph>00/;2`0=3@d04A4A00`<300820P0410@0P0<30`0200:2PX0EeMG02<R
800@3`d03Pd;014@3P0<2`T040l=1P0=30X01P0C4Q004Q4?00/:200=30X05A@B00l>308040l=00P0
3Pd;00`;2@0=30X03`h<00/:200<2`T03@`:010?3@804A0>00L030/900H50`0/:bT05A@C00`;2@0:
2@L04Ph=00804@d<00T040`;00l;2P0>2PT030P700T5100>2PT05A4@01@@3`0?3@/00P0?3P`0300<
2`T02@P600/:200@3`d04Q4?00T81P081`D02@P600l>300U9280`;nm05ACD@803`h<00P06aXH00D4
0`0<2`T03@`:00X91`0=30X030/900`91`803`/800l03PX700`81@0=2@H03`/8014=2P0B3P/040`9
00l;200@30T03@L700h8200?2@T04@/;018<300C3@d00`0A2`/2010:2P0=00l92@0>2PT040`;00h:
2@0C3`h03@T800h:2@0F4Q406QHE014=300@30/06aLF01DA400300l;300G00h:2`0?2``04Ph?00l;
300B3Pl05Q8C01LC500H51D03``=00d<2P0A4@l07alM00P8200R8B<03@/>010>4@0?2`l03`X>014<
400D3Q804`d?010:2P0?2`T00P0>2PT0:00?30`03P`=01@B4`0?3Pl03Ph@00d=3`0;2Ph03PdB0040
0P0G5AP01083010>3`0?3P`010<100`;2@0=30/03@/<00h<3@0?3@l03`dB010=500B41H05A<H00T7
300D4QD04@lB00/:300H5QL0?cdn00X82@091`P02`/;00d>400F5aT0004300410`0Q7b808b4T01<A
500H4aL200l:3P0800`72`0=20`02`H:00h93@0C3Q805Q4E00d830070PH2010;3`0G00l:3P0>2@d0
30L;00`72`0D4Q<01`D600X82@0E4a@04@l@00/92P0<2P/03`d>018@4@0?3@h030X;00d;3@0@3Q40
1@<601LE600^;2l0:2HY010>4@0<2Pd00P0;2@`06P0<2Pd03@/>00/82P060P<04@d>00`82@0H51D0
2@D601<?40070`@00`0001@@4@070`@04@d>00h:300?2Ph04`hB02@O8`0J5AT02`H:014<400[9RX0
<2/_00`72`0500@04PdA0P0@2Ph3010;3`0L00l=400H5QT02`T<00T92`0G5aT02PX<00L72@0Q7Ah0
0`0003lk?02h];D0;RX[00d92P0U8B80<Rh_02<O800>2P/00`0001hJ6`0:20T071XK00P71`0E4a@0
6aTJ00`:2`0@3Pl00@0001HD5@803P`=00X02PP9014?400@3Pl03`d>010>3`0C4A80518C01lM7P05
10@01P@50P0A3a003@0D4Q<03`d>014?400@3Pl03P`=00l=3P0A3a0020H700T7200D4Q<040h?00`:
2`0L6Q/01P0?3P`03`0>3@/03@`:00/:200:2@L05A@B010?3@0A3a006QPI01PF5`0F51D00`4200l=
3P0=2``03P`=00l=3P02010>3`07014?400@3Pl03`d>00h<3@0@3Pl04Q0A01<A4P06018@4@0E00l?
3@0A4@l0410>010@400C4aD05ADG01HF600F5AX05A@I01@C600E51T05QDJ01TI7@0A4QH05QLK01TJ
7P0B4aL04A8F01HG6`0E5QX051DI00805AHJ00<05QLJ01DF600E5QP00`0F5aT03@0H6A/06AXL01PI
6`0H6A/06AXL01XK7@0I6ad05QXK01LK700H71d05QXK01DI700H6al00P0H6b00;P0I72804aHM01DH
7`0H6b4061/P01LJ7`0C5Q/05APM01HI7P0H6b0051LL01/N8`0F6Ah05aXO01LJ800N8R/0720Y01LK
9@0A5Ah041@M01<G800E6B805a/T01<G800B5ad06AhT01`Q9`0O92X08BH/01/P9P0H7B<07R<Y01DJ
80083A<04AHL01/P9P0F6b4051TO01HK8@0F5R005aLQ01/K9@0L72H06QXT01LG7`0I6B4201XK800@
00h?4`0P8BD030dA01<D5P0d=SH08B8T014B5P0;31007AhS01PI7P0G61/05QPG01DG500D5Q404aD@
01@D50D051@F00`05QHH01PH6P0K6ad05QHH014A4`0H61X09RHV01@D500E5AD04Q8B01DE5@0>3Ph3
01DE5@1101HF5P0B4Q80410@01DE600E51T05QDJ01PG7@0J6Al06aXP01hM8`0P7bD0A4=9020O9009
20d07QdR01XK7`0;31006AXN02//<00Q82D02PT>014?500D4QL05Q@I01XE6`0K5Q`071LM01`J7@0G
5AP05A<F01TG6P0I51P050lC00l93@0I4aL06aDI01483@0H3a@08A`P00400P0L6Qd03P`?01HD5`0G
4QH05Q4E01LA5@0D3Q807aLL02DL8@0J4AH04@X=010:300=1`T04@/=01H@4P0E3a405Q0B01PB5004
0000:R@V00T31@0J51H03@L:00h8300?2@d00`0A2`l0500<1PX071HJ00L11@0D3Q806A<G00P21P0>
1@/04PL?01<74@0A1A403`<?01@85P0^8Rh050PD00T01P0E2Q005P/?01L<400?10X040D;0P0A1P`0
4P0?10X03P<90146300?10X04PL=00T0100@1@/07A8H00h32@0C20h050T?00L00P0;00H05``B0146
300?10X03@88014630804`P>01<0710J00L01@0@1Pd04`P@01<83`0B1`d03P<900d31`0900802001
00h41`0F2Ph02P0001`=4P0H2@h070dB01T<3`0B0`P04@87008050D:00<04`@90183200C10T05?oo
ool001_ooooo00L03@X8014>2P0D40`05a@@00l<2@0<2@D030P40080514=00@05a<?01<?2`0>2`L0
4Ph;0P0A3@X2018>2`0>010<2@0C3``040`9014=2P0B3P/03`/8010<2@0B3P/04@d:00l;200B3P/0
3`/8014=2P0@30T2018>2`0@01<?300F4Pl06ADB010?2`0>3@T040l;018A3@0D4`l04A0<018A3@0@
3`/02`X601@C3`0B4@d03Pd9018A3@8030/702@03@`800h=2@0?3PX0;bhZ01hM6@0=30P03Pd900X9
1`0B4P/04A4900d<1`0@3`X05aHC00/92@0>3@`07QdK01XI5`0=30L02`X500l?1`0>3@H04Pl:01@A
300B3`X0514<01DB3@0A3PT04a0;01@A300@3@P04Pl:01<@2`0@3@T02`L400`81@0>2PL201<?3009
018>2`0=2@H040`9018>2`0>2PL05A4>01<@2`0A3PL04a0900804Pl:00/04@h9010<2@0B3P/040`;
00h:2@0:1PD0510?00l>2P0B4@d040l;00/:1P0200h=2@0600l>2P0@3`/03Pd900d<200?3PX040l;
0P0B30`09`0A3@`040`;014=300?3P`04A0>00d<2P0?3`d06ATG018B400<3@/02@/800lD400V:2D0
418?01HG500=3@/04A4?00/:200<2`T03`h<014?3@0B3Pd03PX700l=2P0<30X0410B00d?4P0;41<0
3A8G00lF6P083A005AXM00d@4@0;30d02`/;00l?3`0<30`02`/;00d=3@0200`<300?00/;2`0C4a<0
>CTi08B4Q00E5AD03@`:00`;2@0B4@l04a8@00d<2P0>3@/040l=00`;2@0=30X03Pd;00803@`:00H0
3Pd;01<B400=30X03Pd;00`;2@061@@300h=2`0300d<2P0>3@/03Pd;00803`h<00`04Q4?00l>300<
2`T03Pd;00d<2P0F5A<0>CPf028Q7`0@3`d05A@B01PD4`0B3Pd3010<2`803`/:01<0510?010<2`0@
30/03`/:00`9200<2`T03Pd;00`;2@0;2PP03@`:00h=2`081`H05QDC010?3@0:2@P030/900d<2P0I
61H03`h<008030/902@02PT700l>300<2`T04A0>00/:2@0?3P`030/900h;2@0>2PL030P500l;200B
3P/03`/800/7100B3P/03@T600`81P0?2`P03PX700X51@0J5AD03@P801<>3P0A30/07APG00X51@0B
3@`03PT800`71`0E40l03PT800l;2P0A3@`03@T801@@3`0A3@`200l;2P0R010<2`0A3@`03PX900h:
2@0B3Pd030P9010<3@0=2@X05Q8C00d92P0@30d03`/<014=3P0I5AH04@d>00P41@0@3@h03`h<014A
3P0F5a<00P<0010@3`0A40l040h>014>400?2`d040/?01<>4P0@2Pd030H6018>300>2PT05a<B00`9
2P8040h?00`03@`=01@D5P0P82804Q4E00L72P0>30h03@/<00l=3P0@3Pl03`d>00h=300?3@l300l=
3P04010>3`0@3Q002@L<00/83P8030X?01D04Q0C00L5200B41<0:bTZ03dk?00E4a@02`T:014?400=
3Q0030`>00T92`0B4A<02PP;00l=400@3A004@`@010;3`0C3A4050lC028L800B3A400P0=20`03`0;
1`X03@P<018=4@0C3Q803`X>014<400D3a<03`X>00`72`0;2@X030X;018@4@0;2@X03P`=010>3`02
00/92P0500d;300;2@X03`d>01TG6@0N71l00P0;2@`04@0=2`h03P`?00/9300<2Pd03@/>00X82`0<
2Pd03`d@014>400A3@h0510A00`82@0B3Pl02@D600X61`0E4A804@d>00803`/<034040`=014=3`0A
31003@P<01<>4P0>2@d030L;01D@500I51P05A0D00l:3P0B3A403PT=010:3P0A2`l03`X>00h93@0A
31003`d@018@4`0>30l03`lA00X:300B4Q@030`>00/8200G4a@03`/<024M7P0>2P/04`l@00/7200D
41403`/<01@@4@0>2`/05A4B010>3`0>30d03`d>00`:2`091`P03`d>010>3`091`P06QPI01PF5`0<
2P/04Q0A008040h?0P0?3@h2010>3`0400/92P0A3a004a4B014?40<03`d>00<04Q0A014?400?3@h0
0P0<2P/03@0H5QL0518C010>3`0A3a002`T:010>3`0=30X03Pd;00d<2P0?3P`04Q4?00h=2`0<2`T0
0P0B4@l020061@@05aHD03He<`0A3a004a4B00d;300C4A803P`=0P0A3a02018@4@804a4B01L0518C
018@4@0A3a0040h?018@4@0C4A80518C014?400C4A805A<D01<A4P0B41405Q@E018B4@0I6AP07AdL
00l?400K6ad04A4C01HF6@0I61d05aHK01DD6@0201DD6P804a@H00d04A8F01<D600J6al06a`P01DF
6P0I6Qh05QLK01TJ7P0H6Ad05AHI01@E5`0F5aT061TK00806AXL01L061TK01DF600J6ad08b@V01TJ
700L7Al05aTK01@H6@0E6AX061`M01TM7P0G6ah06A`P01TL8@0J7B806A`R01DH7`0G6R405aXP01LJ
7`0H6b004aHK01HI7P0201XM8P0H01LJ7`0I72405APM01LJ7`0K7R<06b0V01XN9P0G72<05ATQ01HK
8P0M8BT04ADM01hR:P0G72<06QlV02T]=@1>DeX06QhU01/O900D61h06alT02HZ<00J7R@06alT0P0F
6Ql05`0K7bD06alT01DI7`0F5R006ATS01dM9P0H62406ATQ01DE700L7B803a0D01LH700D5AT0;c0d
01LH6P0I6Q`06a`M01LH6P0I6Qh061TN01DF6`0E5QX05QLI00805ALD00@05QPB01HH4`0F5QH051@F
0P0G5aT02`0D51H06ATK01PH6P0H61X06a/M01LG6@0C4aD06ATK028R8P0F5QH061PH00806ATI00<0
61PH018B4P0D51@00P0E5AD201@D500901HE6P0H5a`06aXO01dL800N7B8081lS01TH700H5a`05aHK
008061LL00P03`hC01@E6@0G6Ad04Q@H02<T:00E5AX04A4E01HD6@805A<H00D05Q8H01DB5`0E4AL0
5Q@G010>4@0201HD5`0E01<>4P0J5AT05a4E01TC5`0D3Q805@`A01T@5@0@2Ph07A/N00d;3P0E4aH0
20H9018=4@0F41@0;RP/01<=4@0A2Ph05@`A01P?500B2`h04`d?00804@/=00T040X<00h82P0?2@/0
3`T;00h82P14?T0050h@01<=3`0A2`h00P0?2@d05`0E3a<03PP<014;3`0@2Ph0208601@>4P0=1`/0
4`dA01PB5P0;0`T0<bP`0187400P52004@DA01864`0>0Ph040@>01<73`0?10X03P<701061`0@1@T0
4@H<00804`P>00P04PL=01052`0B1`d04@H<00l42P0<0PL060dC02HK8@<04`P>00L03@8801052`0<
0PL04@H<01052`0>0`T040D;00804PL=01P04PH@01@84P0>10/03`@<00h42P0>0`T03`@:00l42@0?
10P040D900l4200:0@<040@801852@0=0P@05@L<01041`0E1``04@@800l21P0F2@d040<700l31P0A
0`PDooooo`006oooool0100?2`P03PX700d91P0>2PL3010<2@0800L30@0@30T03@T600X60`0H5140
4Ph;010<2@0?2`P2014=2P0400h:1`0B3P/04@d:010<2@803`/800L040`9018>2`0>2PL03PX7018>
2`0A3@X03`/800H04@d:00P03@`800l>2P0=30P02`X600X91@0;2PH03Pd900l>2P8040l;00<03`h:
00h=2@0A40`00P0=30P03@0?3PX040l;00l>2P0G5Q802`X600@3000<2`L03Pd900P80P0:2P003Ph6
010?2`0?3PX00P0<2`T03`0>3@/03Pd900h=2@0>3PH03Ph4014?200A3PT03``700/80`0<2@@04a0;
014>2@0=2PD03``700h;1P02014>2@07010<200?2`P03`/801<?300F4Pl05A4>018>2`0200T50P04
01DA3P0@30T03@T6014>2@804@h70`0B3`X02@0>2PL04Ph;01@@3`0D40l01P8101<?3P0B4@d020L3
00d<200201DD400700X91@0C4Ph05A@@014@300=30P03`h:00d<200201@>3P0U018>3@0@30/040`;
00h=2`0:2@L051<A01<C4@0?3`d02@T7018C400A4a0000<003Li=P082PL030d;014A3`0?3`d03@`:
00`;2@0=30X03`d;010<2@0=2PD03`d800P81P0?41802@dB00XA5`042a408bX`00hE6`0?5aX010X;
00@82@0<3Pd0410@00l?3`0200`<300900h>3P071`L03Ph>00d=3@0B4Q806QXJ0000000=30X03`h<
00@040l=00H051<A00d<2P0?3P`03Pd;00`;2@0>3@/200d<2P0500X91`0<2`T03@`:00/:200>3@/0
0P0=30X09@0>3@/03`h<00l>300?3P`03Pd;018A3`0?3P`02PT700d<2P0>3@/051<A018A3`0>3@/0
4A0>01LF500E4A003PX900`81`0?2`X040`;00l;2P0<20L040`;01HB4@0C3`h040`;00h;2P0>3@/0
3`h<00d<2P0;2PP03@`:01@C4@0=30X030/900T81P061@<00P0?3P`200/:200<00`;2@0=30X03@`:
018A3`0100004a8@04M6A00l>cT061LE00L50`0A3@X04`l<0P0@30T04`0?2`P030P5010<2@0C3``0
6aLD01PD4@0<20D05a<B00<0000M6AP02PH503Hb<@1;AdH0510?010<2`0;20L01P8100/71P0A3@`0
0P0D40l200l;2P0d01LC4P0I5A@02PH500d9200?2`X03PX900d9200>2PT03`/<01@@4@091@H0510A
00H20`0@30d03@T:01HB4`0N6Q/0510A00h:2`0A3Ph051<?00l@2P0E5Q002``6010@2`0<2`H03Pd9
01<A3`0@30d03`/<014;4@0<1PX03@L7010<2P0?2`X04Ph=01HC4`0>30d08b4R01DD5@1bLW@0^[Zl
04e<D00M7Al040h?00l=3@0>30d03@/<00d;3@0=2`h03`d@00h<3`803@/<00@03Pd;00l=3P0<2Pl0
3`dC0P0C4AH03`0>30l040hA01<A500@3Pl0518C00X82@0D4Q<0:RPY034a<`0@418030`>00d;3P0:
20/03P`?00h93@02018=4@8040X>02/04@/?01@?4`0?2Ph03PT=01PC5`0K5QX05Q4E00D0100G4QH0
6QDI01LB5P0M61`09b8V00d;30071@H03P`=00/92P0C4A802PP900/92P0?3@h05Q@E010>3`0<2P/0
5Q@F01<A500<2Pd03P`?00T72P0:20/040hA018@4`0A3a802`T<00`:3@0>30l03``>014=3P0@30d0
3`/<00h:2`0=2@X03PX;00804@d>01h03`/<014=3P0D414050lB01@?4`0G4QH05Q4E00h93@0=20`0
4@`@00h93@0?2Ph04PdA00h93@0?2Ph04P`@01D?4`0@2`l02`H:00l:3P0@3Q40<c4d08N5R00@4180
0`<500h>40092@/03@T:00`82@0=2@X200h:2`0E00/7200A3@h04@d>010<3@0A3@h040`=01<?400>
30d03@/<00l=3P0C4A805A<D01<A4P0B41403P`=01PF5`0>30d040h?01<A4P0>30d03`d>008040h?
00<03`d>00h<3@0>30d01@0>30d2014?40<040h?00<03`d>010>3`0>30d00P0=2``02P0?3@h040h?
00d<2P0@3`d03`h<018A3`0F5A<04Q4?01LF500;2PP2014@3P0800h=2`0O7Q`040h?00h<3@0@3Pl0
4a4B010>3`0>30d6018@4@0401<A4P0B41404Q0A018@4@804a4B01h04Q0A01<A4P0G5AH05A<D01<A
4P0G5aL06QXJ00/;2`0A4A40?Si001@D5P0K6ad040lD014@5@0B4AH05A@J01HE6`0D5AX0414E020Q
9@0I6Qh06Q/O01LH700:2`l06Q/O01HG6`0N7b<03PlC01<D600N7b8201TJ700H01PI6`0G61X05aPJ
01LH6P061`T07AhP01HG6@0=3Q005aPJ01PK700E6AX05QXK01PL7@0J7Ql061`O01PL800K7R<071lT
01TL8P0E61l05QTP01HI7`0E61d05aXO0P0I724201PK800501TL8@0J7B8061/P01TL8@0L7b@00P0F
6al04P0F6b405a`R01PM8`0J7bD05AXP020U:`0A5Q`05ATR028V;`0c=cl06QdT01/N8`0H6b006A`Q
01hQ9P0I72406QdR01LJ7`806A`Q01/04aHK01@G700I6B407AdW038b>P0W9bl071`T01PI7P0I6Ql0
5AHK01LH700K720071dQ01PI6`0D5AL04Q<D01@E5`0>3a<04Q<H01DF6`0D5AX05QLJ01DG5P0D5Q<0
51HA01<E400M7Ad00P0G5aT00`0C4aD05QHH018B500201DE5`0E01PH6P0F5QP051@F01XJ700E5AD0
5QHF01TI6@0K6a/06QXJ01LG5`0D51@05aLG01HF5P0B4Q804A4A018B4P0E51P05A@I01PH6P0K6a`0
6a/K008071`L00`030`<01LG6@0A4A@081lT028S9`0D5QX020`?010D5`0P8BD0414E01HG6`0D4aP2
018@5@0:01HD6@0L6Ql07adR01hL7`0D4QD05aDH01HD5`0<1`/05A0D01LA5@805Q0D01@05PdB01<:
3`0B3A404a4D018@4`030P@020H901LB5P0J51P0>cDi018<400B2Pl03`H;01XA5P0A2@d040X<014;
3@0C3@l04P`>014;3@8040X<01d04P`>01@>400B30h04@/=010:3@0=1`/03PP<014;3`0E3a<04`dA
01hH700=1`/02`D900d72`0;1@T01002020H7P2n/k/0>2le00X0200N4Qh04PHB01454@0A1@l04@H=
01052@0@1PL040H601052@0201052`0300l42P0>0`T03P<901803`@:0P0?0`d200l4300400l42`0?
10X03@8800d21`8030450P0>0`L600l31`0600P0000A1@T020000104200C1`/0A3Pl5?ooool001_o
oooo00l04@d<01<?3P0?2`X030P701<?3P0P71/0GUYI01HB4@0J5QD06aLF00l;2`070`804`l<010<
2@0?2`P00P0@30T0100=2@H04Ph;014=2P0A3@X2010<2@0700l;200A3@X03`/8010<2@0B3P/040`9
00l;2006014=2P0701@C3`0L6aL05A@@010?2`0B4@d03Pd900l>2P03010?2`0E00h=2@0=30P03`h:
00d<200>3@T040l;00l>2P0>3@T05QDA014@300;2PH05A@@01HE4@0@3`T03Ph4018B2P0B4@`04A0<
01<B400B4@l03Pd;00803Pd901<03Ph600h>100A3`P03@X500`9100@3@P02`P300h;1P0B3`X040d8
018?2P0A3PT0514<01<@2`0B3PX04Ph;014=2P0C3``05A4>0080510=01<040`901<?300S7a`07ATF
01DA3P0@3@P03``5010=1P0A3PT04Pl:01<@2`0A3@X0510=00h:2@0B3Pd03`/:01LC4P0G5Q803@`8
008030/700D051<?00l>2P0H5a<06APD01@C3`0200h=2@0a00/:1P0D3Ph050h>01<?3P0A3@`040`;
00`;2@0;2PP04a8@014A3`0D51803Ph<00@50`0B51407R<O01HH5@0h>SL0?d0n00h>300=3@/03`h<
00h=2`0=30X03`d;018>2`0=2P<03`d700P81P0>3a402PlC00dD700D6b<0GVM^04I?E00I8bD031DE
014G5`0=3`h0410@00l?3`0>3Ph03@d=00l?3`0>3Ph04A4A00P820010@402`/;01`L7002010?3@07
00l>300@3`d04A0>018A3`0@3`d03Pd;00l>300200d<2P0?01<B400?3P`040l=00`;2@0?3P`04A0>
00h=2`0?3P`030/900X91`0;2PP03@`:00l>300>3@/02`X800803Pd;00T030/900d<2P0?3P`03Pd;
00`;2@0:2@L03@`:014@3P0?2`X00P0<20L200l;2P0D00h:2@0=2@P03`/:018>3@0D40l040`;00/9
1`0>3@/040l=00h=2`0=30X03Pd;00`;2@0920H02PT701HE4`0B4@l010<100H5100:2@L200/:2080
30/901h03`h<00@30@0?3P`0A4=1034`;P0B4@l030T701DA3P0K5a@04Ph;00d91P0@30T04@d:00`8
1@0G4a00920M01PD4@0?2`P04Q4?00X91`0i>3H020L501PG5@0H5aH02`X800X91`0A40h03`h<018A
3`0G5Q@2014=308030P70P0B3Pd00`091@@02`L600h:2@0200d9200]00h:2@0>2P/0510A00d92P0D
41402@D601PD5@0=2@X0510A01/G600C3a003PX;010>3@0?3PT03@h701`M5@0G6@h061T?01lO5@0;
2`<04Q0<014=300?2``040X@00d72`0G4A403`/9018>3@0300005a@D00@20`0@3Pl05A@E0:JVZ03o
ool0GeiR00`<3P0A40h03`h;00`:2`0;2@X03P`@010>4`0>31403@/>008030X;00X03@`:00h=2`0C
4AH02@L=00H42@081P/03P`?01<A500>30l02PP90P0;2@X02@0?3@h05Q@E01@D50040P<01@<4010>
3`0=2@X0100100h:2`02018<3P0D010:300A20/040X<00h93@0=20`03PT=01LB5P0J5AT05A0D00l:
3P0A31003PT=00d8300910P02`H:010>3`071@H03P`=00`:2`0?3@h200`:2`0:018@4@0H5QL04@l@
00/92P0:20X020H900/9300A3a802@L:00X82`8040hA00`03P`?00X82`0=2`h030X=00d:300A3@`0
40`;00l;2P0>2PT03@T800l;2P0>2PT200d9200900/71P0?2`X03`X=010;3`0G4QH04`hB00l:3P0@
2`l04PdA00802PD901@040/?00/62P0=20`040X>018<400=20`020<700/62P0<2Pd06ALJ07ajO@0<
30h020P:00d=3`0:2P`03PX;00l;300A3@h040`=00l;308040`=00D030P900l;300?2``06ADF00h:
2`0200/92P0<00d;300A3a004a4B014?400E4a@04Q0A00h<3@071@H05A<D00/92P0>30d03`d>0P0@
3Pl00`0?3@h03P`=00h<3@0500h<3@804Q0C0`0A3a800`0@3Q404@lB01@B5@0200d;3P04014?4P0=
2``03@`:01<B40804A0>00h05QDC01DD4P0D4a402`X8010?3@0F5A<04A0>00P71@0A3a003`d>010>
3`0B414040h?00h<3@H04Q0A00<04Q8B014A4@0@41000P0A4A400`0B4Q8051@D018B4P0201HF5P0?
01@D500E5AD06Q/K02@U9`18BD/0OGj0018C5`0;31004A8F00h?500A4QL05QLL01LG7`0F5a`071lR
00804aLJ01803Q8E014E600L82<06QhQ01@H6`0W:bh03Q8E01`P8`0K7b80720S01XN8@0F6Qd051PK
01<G6P0L82<01PX=01XN8@0E6A`2024U:00B01TM7`0F6Q/05QXK01PL7@0J7Ql061`O01PK7`0K7R<0
71lT01XM8`0E61l04aHM01HI7`0H6b006A`Q01XM8P0I724061/P0P0K7R<05@0M82D07R4V01dP9@0J
7B8051TM01@I700D6Ad05AXN01HK7`0H7B406AhT01@I7`0N8bT0720Y01XN9`0B5A`05APO01`M8P0J
6b004a@I01@E6P0201TJ7`0901/L8@0N7b@05aPM01<D6@0K72405QHN01LG7`0`<3P09RL/00804a@I
00<04A8F01@E6@0F5a/00P0G61X01P0E5QP04a@F01<D5`0A4QH0414F01DE70805AHK00X05AHI01HH
5`0E5a@051HA01<E4P0A4A4051@F01HF60092@/05aLI0P0E5AL04@0D51H05QHH01DE5`0C4aD06ATK
01DE5@0F5QH061PH01/K6`0J6QX05aLG01PH600J6QX061PH01@D500B4Q804a<C00804a<E014051@D
01`L6P0O81/071dH01XK5P0B4Q00:b/Y018B4`0C4aD04Q<E018E600K7b807b<V038f>@0^;c<06AXN
01DF6P0201<B5`0301LF6`0O7B808b4V00805aDH00D040hA01@B5@0?2Ph061<G01LA5@0201H@500A
01H=4P0D2a003@P<00h<3`0N71l061HI01@B5@0H4aL03`T=02/U:@0>20`04PX?00X11P0D2a004PX>
010:300A2`d00P0C3@l2018<3P<04@/=0P0@2P`04P0?2@/040X<01TC5@0>20X04`d?00@0000910D0
1P02014;3@0>20X04P`>00D00@0F3Q80>Rle01X?5`0E2A<050PB01P<60804`LA00X04PL>01462P0A
1`P040H600h31`0?10X04@H<01052`0?10X03P<94P0?10X200l33@803`@<00P03`@;00l42P0;00H0
2`0500/0100<0@D03P<700l420H03`8900H07a8I01062P0G2Q402`0501@73P0H2a8Dooooo`006ooo
ool04`0D40l05A4@010<2`0>2PT05A4@01hJ6@1RGUd071PH01<?3P091PD04`l>014=300E4@h04`l<
018>2`0C3``04Ph;010<2@0A3@X00`0B3P/0100@30T03`/8010<2@0B3P/201<?308040`91P0A3@X0
1`0;2PH04Q4=00/:1P0C4Ph05A@@00P70`0A40`00P0@3`/04`0?3PX03Pd900h=2@0>3@T03@`800h=
2@0@3`/03Pd900`;1`0A40`03`h:01@C3`0<2`P02PT500l?200B4PP04A4900/;100?3PT00P0I61D2
00h=2@0A00h>1`0>3PH03Ph4010>1P0=2PD05A8=02@Q700E4Pd03@X500l<1`0A3PT04a0;014>2@0D
4@`04a0;00l<200@30T01@0?2`P01P0:1P<02@D201@@3@0C3``03@T600d:1@8040d60`0@3@P0500<
20D05A4>00l;2P0B3Pd04`l>018>3@0A40`01`H301<B3P0;2PL05aHB014@300E51005aHB018A3@0=
30P03Pd900`;1`0A2`/04P`<0P0C3`h0100B3Pd03`h<018A3`0?3P`200d=2`0700L71P0Y:RP0?3dk
00lD400;3@X0?T0m04A5@P0200`<2P804A0>01003Pd;00l=2`0D40d03``4010>1`071`@03@h@00hD
6P0J8b`0CEIP0=OOi`3@f^00GFM/020[;00A61P0418A0P0@410300l?3`08038b<P0l?3`05ADE00@4
100B4Q802`/;014@3P0@3`d200h=2`0800l>300A40h030/900h=2`0?3P`030/900l>300F5A<2014@
3P0600d<2P0>3@/03`h<00`;2@0@3`d03`h<0P0>3@/200d<2P03010?3@0=30X03@`:008040l=00L0
3`h<00`;2@0:2@L02`X800h=2`0=30X030/900@03`/:00P03@T800`81`0B3Pd04@d<00`81`0A3@`0
4Ph=00l<2`D03@`:00L03Pd;00`;2@0C4Q003@`:00P71P0C4Q003`h<00D03@`:00/030/9014@3P06
1@<040l=00X91`0>3@/02`T701DA3P0I5A804Ph;00h:1`02010<2@0J00d91P0:1P@05Q8?00d91P0A
3@X020L5010?3@0S8R002PT800/:200=30X020L501<B400@3`d020L5010?3@0;2PP05A4@01<?3P0A
3@`03`/:00h:2@091@@030P700h:2@0@30/200l;2P0]014=300?2``05Q8C01TE5P0E4A802PH701@@
4@0<20T040`=01<?400@30d03PX;00l=300B4PT05QP;01TK300W:AX0<C<T01TJ300C4`L04a8901@A
3@0D40h050lA01@>4@0D3Ph04@`:01HB4@0?2`X03``<018@4@0H5QL04Q4B03De=`1FEUP0:2L[014A
4`0>3@/03Pd:00h=2`0>30l03P`@00h<4@0?3A803`dA00803@/<01D03`h;00l>30091``03``B00d;
400>31404a4D00L5200>30l04@l@00h<3@0?3@h03P`=00T8200:2@T030X;00X82@0G51D06ADF00h:
2`0A30d00P0A2`d07`0C2`h04`X=018<3P0>2@d040/?00h93@0B3A404@`@00`72`0>2@d05a8F00d8
300A31003PT=018=4@0=2``02`T:00h<3@0=2``030X;018@4@0>30d02`T:00`:2`091`P030X;010>
400:20/01`D800h<3`0@3Q400P0>30l01P0=2`h02`T<00l=400I5aX05Q@G010=3P8040`;0P0?2`X0
4@0>2PT04@d<010<2`0@30/04@d<00`81`0=2@P03`X<010;3`0A31003`X>01<>4P0D3a<040/?01D@
500C3Q803`X>008040/?02H04`dA014;3`0>2@d05A0D01XE6@0>30l04@lB00L6200?3a4030`>00l?
4@0=3@l03PX;018>3`0E4A804Ph?014=3P0D41404`l@00P41@0@30d04Ph?01PD5@0G4a@06QPI01HD
5@0@3Pl03P`=00l=3P0@3Pl04@l@00/92P0A3a003P`=00l=3P071@H03P`=00l=3P8040h?00<03`d>
00h<3@0?3@h01@0?3@h7010>4@0B018@4`0F51L04Q0C00l=400H5QL03`d>01DD4P0@3`d030/900l>
300@3`d03@`:01DD4P0A40h03@`:014@3P0C4Q004@l@0`0B4142014?40H04a4B00<04Q8B014A4@0@
41000P0A4A40=`0B4Q805QHF018B4P0D51@05aLG01@D500@410061XJ00/<3P0G61X05AHI010A5@0G
61`05AHJ01@E6P0H6Ah05aPN01HF7P0J6b007R4U01TM800B5QT06QhQ01lS9P0F6Qd01PX=01hR9@0C
5aX03Q8E01`P8`0J7R406alR01PL7`0D61/04aLJ01@H6`0C5aX09RX]01lS9P0K7b805ATL01HJ7@0F
6Q`05a/L01HJ6`0H71d06QhO01XN8@0H72006A`Q01/N8`0L7bD06A`S01LJ8@0H6b400`0I724201LJ
7`0701hQ9P0K7R<06A`Q01/N8`0L7b@061/P01HK7P0201DK700i01HK7P0G71l061dQ01lT:P0?51X0
>3e3024U;P0C5b006AdU01XK800K720061TN01<D600B4aL05aPM01DF6P0F5a`06AXN01/L800M7R<0
92DY01`L900D51`061PO01XK800R8bP06Q/P018C5`0F5aX05AHI018C5@0E5QP06a`N01@E600E5Q/0
4Q<I01/K8P0E5Ah04A4J01@D7@0@4AH051DH01LH6@0E5aD05QPF01PH6@0G5aT07QhP00d=3`0D51H0
820R01PH6P0F5QP05aLI01DE5`0D51H06a/M00804a<C00D05ADE01LG5`0H61P05ADE01LG5`0201XJ
6P<061PH03005aLG01XJ6@0K6aP07R0H02HW7`0Y:R407b4G01lP6@1VIf00:b/Y00l?3P0Q8R<05QXM
00T>4@0Q9RT0][Zm0:na]@0W:Rd05aPL01LF6`0F5AX05A@I01HD6@0F5AX05aDH038`<`0D4QD05Q@G
01TD600F4AD05Q0D01LA5@0F41@060lD01D<4@0H4QH040hA00l=400N71l0518E010;3`0A31006A<G
00d72`0E3A802P4601483@0D3A02014;3@06018<3P0C3@l04`d?01@>400B30h040X<0P0?2@/02@0@
2P`04P`>00X41P0D3Q0030H801dG6@0E4140O7Ih03Xd=P0200l92`0D01D?4@0A2`d03`L;0148300C
2@l07Q8L02`P:P0I3AP05@TC01@94@0D2@l04PL;0147200@1PH03`@801052`0C20h050T?01873@0@
1@/B00l42P803`<=0P0?10`01P0?10/03`@:01052`0?10T03P<700d21P803P<71P0?0`T01P0@10X0
5``A01L;4P15>cl0<RP]02/O9ACooooo000Kooooo`0=01<?3P0?2`X03PX9010<2`0A3@`03PX900l;
2P0<20P02`L600<0000E4A005Q8A014=2P0200l;20804@d:00P03`/8014=2P0C3``0510=01<?300@
30T03`/8014=2P804`l<00<04Ph;014=2P0B3P/01P0A3@X00`0C4Ph04A0<018A3@02024P700301DD
400A40`03`h:00803Pd90P0?3PX04@0>3@T030/700`;1`0?3PX03Pd900`;1`0A40`03@`802h]:@0]
;2P06APD00`;100@40@04Q8800l>200:2@@02`X600803Pd900h03Pd800h>1`0>3P@03Ph2010?1P0=
2PD03``701PE400A3PT030T400l<1`0C40/04Pl:010=20804a0;00P040`8010<2@0A3@X03`/800h:
1`0?2`P0510=01DA3P804Ph;00<0510=01HB3`0E4Pd00P0B3`P04`0@3@P03``700l<1`0F4Pl030P5
018>3@0A3@`00`0004Q4@`1XIf<061LC00d<200E510040l;01<B3P0=30P03`h:00d<200;2PH00P0?
3PX0200>20P03`T9014=300B3Pd04`l>014@3P0=30X02PT70P0@40h07@010@00:2TV02/]:P000P00
4A<@00lA3P0>3``03@d;00`<2P0?3P`040l=00l>300?3@/04@d:00l<0`0@40L01`T400`@4@0@5Q`0
7RHa03M1C@2c_/T0[kc404UDFP0>6A/00@/:010A4`0?3`l03Ph>00803`l?00L030`<00/;2`0H61P0
51@D00H61P0410@02PX:00803`h<0`0=30X01P0>3@/04a8@00l>300?3P`02PT700T81P803@`:01/0
3Pd;00`;2@0@3`d051<A018A3`0>3@/04A0>018A3`0A40h03Pd;00`;2@0=30X04A0>00d<2P0<2`T0
3Pd;00d<2P0:2@L030/900h=2`0A40h03Pd;00`;2@0A3@`04Ph=014=300>2PT00P0=2@P02P0>2PT0
30P7014=300?2`X03PX900h<2P0<2`T02PT700`;2@0=30X200`;2@0701PG5@11@3h0>CPf01XI5`0N
7A/03Pd;010?3@0200l>30803Pd;00L04A0>00H50`0:2@L05A@B0040000M71X03@X8008040`901`0
3`/8010<2@0>2PL020@101<?30091@804`l<00d91P0=2@P00P4003Xi=`061@<010<1010?3@071P@0
2@P600L6100@3`d06APF00P71@0=30/09B4P01`H5`0B3Pd03PX900d9200A3@`03PX90P0?2`X200`8
1`0700l;2P0@30d03`/<01<?400@30d0510A02PT9@02014=3P804Ph?02804`l@01<A3`0F5PX051L6
034d8@27RWL0[:jK05IGA@0`<B407ahA01HC300F4Pl04`h?014;3@0;1@D03PX8014=300D40l01P<3
00h<3@0=2``03Pd>01hN800?3a40410C00@41P0;2PP03Pd:010?3@0A3a803`dA00`:3`0@3Q<040hB
0P0>30d02P0@3``040l=00l=4P0=2a404Q0E00T7300D4QD040hA00l=400?3@h200X82@09010>3`0C
4A804@l@01@B4`0>30d04@d>01@@4@0?2``03`T;008030H800H04@P;01072P0=1`T03`T=018=4@0@
2`l2014<400=00d8300B3A406QDI00d8300H4aL02PD900H11@0;2@X061HG00l=3P0=2``02`T:010>
3`0200X82@0@00`:2`091`P02@L800/92`0?3A004Q0C00X82`071@P04Q0C01HD5`0=2`h02`T<00h<
3`0E4aH04Q0C00d:2PD03`/:00@030P700d9200A3@`03`/:0P0@30/02P0>2PX030L;00h93@0B3A40
3@P<00T4200:1@T04PdA010;3`0:1@T2010;3`0?01@>4P0A2`l03`X>01`G6`0R7B403`d@00`:3@0T
8RD020P:00`<3P0D51H02`/=00/7200=2@X040`=00803`/<01004@d>00/7200=2@X02PH7018>3`0>
2P/081`M02DS900O7Ah0518C00l=3P0@3Pl04Q0A01@B4`091`P04@l@0P0;2@X00`0D4Q<03P`=00l=
3P02010>3`0300l=3P0>30d040h?00D040h?0P0>30l300l=400=010>4@0?3A003P`?018@4`0@3Q40
30X=010>4@0E4a@05aHD010?3@0=30X040l=00h=2`02010?3@05014@3P0E518051<A00T81P0A3a00
0P0C4A800`0B41404@l@018@4@0601@B4`0301<C4`0B4Q804A4A00804Q8B01L04a<C01HF5P0E5AD0
4a<C01@D500B4Q803Ph>00`=3`0F5aT02``>01HG6`020`L07AhR01HG700@4AH05AHK01DE7@0F5Qh0
6QdR01HI7@0=4A@0=3Pk010D5`0201DI700H020T9`0D61/06QhQ02<W:P031`X06alR01DI700D61/0
4aLJ01@H6`0F6Qd05ATL030d=`0U:B`04QHI01@H6`0O8bH06QhP01PL7@0F6Q/061`M01XN7`0J7R40
6A`P0P0H6b00200L7bD07B0W01`O9P0J7B<06A`Q01PK800G6Ql05QTN0P0G6Ql201DH7@0301PK800K
7R<07B0T008061hN03805adM01LL7`0H7B006AhR020U:`0G72807b@Z01<G800O8b`051PP01hO900I
6Qh05aPL01PI7@0F5a/05aPL01XK7`0H6Ad05AHJ01dN8P0T9BT07QlS01hO900K6b<06AXO02X[<015
AT/0;Rlc01LH700F5aX04Q<E010A4`0F5aT07b0R018C600E5A`04a<K01dM9`0C4ad0;bli024Q:`0D
51d05AHK01HG6`0B4aD05ALF01dM7`0<30h02PX<01@D5P805ADG00<06a/M01PH6P0G5aT00P0E5AL0
2`0L71h05QHF01DE5@0E5AD061PH01TI6@0H61P05QHF01PH600G5aL04a<C00804A4A01@06Q/G01/L
5`0N7aT0828F0494=`1UIeT0@D<f02T[7P0j?34061TD028S7P092`X05Q/M020U:00E6Qd0?41304A8
B`0K7b804Q<G01@C60@05A@I00L07Q`O03`j?@0K6A`05Q@G01LB5P0?2Ph05Q0D00805a4E010060lD
01H=4P0C3A403@/>01/I7019AdX0<Blb018=4@0A310040X>018<400E3Q804PT>01@;400E3A404`d?
0`0B30h0100C3@l050h@01<=3`0A2`d200l92`8040X<01`01@01010:300@2P`04@/=01D?4@1nN7X0
=2h`00l92`0>20X030H801D?4@0F3A40304701H;4@0F2a<03`<=01dA6`0C1a404`P@0187300A1PX0
4@L601061@0=0PH03P<901052`0A1P`040D;4`0?10X200l33@803`@<00H03`@;00l42P0E2Q004`P=
01052@0>0`L200d21PH03P<900H01`0200X11@0;00H0LVM]04@i?`0=0PPDooooo`006oooool04@0D
40l04Ph=014=300D40l04`l>010<2`0H51<04`l>01@@3`0I5A@061@C00L30P0?2`P03PX700l;200A
3@X04Ph;00804@d:00/04`l<01@@3@0C3``040`900l;200B3P/0510=018>2`0@30T04Ph;01@@3@06
014=2P0700`;1`081`<02PT5018A3@0@3`/030/7010?2`0200h=2@0400l>2P0@3`/04A0<00l>2P80
2`X600d03@`800h=2@0=30P02@P400d<200Z:BD08R4M00l>2P0<30@04A4501<C2@0D50d040l:0080
3@`800T03Pd900h=200>3PL03Ph400h>0P0A3`L040d800`9100=2PD00P0?30L04`0B3`X05Q<>01DB
3@0@3@P05A8=01HC3P0A3PX040`9018>2`0@30T03PX7010<2@0?2`P03PX700l;200<20D02`L400d9
1P0@3@P00P0B3`P3014>2@0>01TE4P0>2PL030P700l;2P0;1`H0BdM606i]J@0M71P02`X600T8100;
2PH051<?00/:1P0=30P200`;1`8040l;0P0A2`/03`0@30/04@d<018>3@0A40h030/900d<2P0?3`d0
6QXH00l?3@020`401`T601<H50082PP061XG018C400200`<2P0B00d<2P0>3@/040l=00l=2`0=2@H0
30T0018B2@0<3PT03Q8C00`B6@0D72L03ALS04=@FP14DET05R<Y00HB500640l03a0B0P0=3@d200h>
3P0500/;2`0E5AD01PH6014A4@0C4a<00P0:2PX0500?3P`040l=010?3@0?3P`03Pd;00d<2P0B4@l0
30/900d<2P0<2`T02@P600/:200?3P`04A0>00l>300D4a405aHD01HE4`0=30X03Pd;0`0?3P`200h=
2`0301HE4`0A40h02`X800<03@`:0`0>3@/06P0=30X03Pd;00l;2P0A3@`040`;00d9200>2PT040`;
01lK6P070`8040`;00`81`091@@03P/:00`;2@0;2PP03@`:00l>300=30X030/900l>300L6aT03@`:
00<2000>3@/030/90P0?3P`04@0>3@/03@`:00d<2P0>3@/09B@R00l>300=30X00@00018A3`0A3``0
3PX700l;200=2@H03`/800h:1`0:1P<05A4>00804@d:00L03PX700`81@010000@d90018A3`0P7ad0
61LE008040l=00L04A0>00l>300<2`T00@0001DD4`0L61L05A4@00804@d<00X03@T800l;2P0A3@`0
4Ph=010<2`0=2@P030P700l;2P0<20T020@50P0?2``0700I5AH0;BTZ018>3`0A3@h040`=01<?400E
4A80518@01@D200P8a00IFQC0=OJa@3mo^X0XZB?0493<@0T91H05A8901HC3P0C3Pd040X<014;2`0>
2@L04Ph=00/71P0L6AT0108301HD5@0;2P`200d=3`0700d=400D51H030/700h=2P0>3@/03`d@00l=
4@0200l<4`0?00l=4@0=2``03@/<00l>2`0?3P`0108701TF701NG640=cDj00d;3P091`X03P`?010>
3`0B41403P`=008020H70`0:20T0100=2@X02`L800L3100?2@/200d41`8040L:01H03@L900h8300@
2`l03@P<00h93@0@2`l03@P<010;3`0A31004PdA03lj?P0/9b/06QDI00h<3@0W9BH04Q0A00d;300:
20T03`d>00/92P0=2``04@l@0P0=2``03@0:20X03@/>014?4P0;2@`020H9010>4@0A3a803@/>00`:
3@0;2@`03`d@00`:3@0:1`L01@0?2`P07P0=2@H05A4>01DA3P091@8040`9014=2P0<20P02@@800/6
2P0@2`l01P4500l:3P0Q72004@`@00`72`0A310030L;00h93@0A2`l040X>00`72`0A31005A0D00/9
300100807Q`O00D51`0@41804a<E00X:30803PX;00h03`/<018>3`0C3a004Ph?00`82@0U8B802`L8
010<3@0<20T05Q8C01HD5@0C4A803P`=00d;30803P`=00P04Q0A00h<3@0@3Pl020H701<A4P0D4Q<0
3P`=00l=3P8040h?00<03`d>00h<3@0@3Pl01@0@3Pl0100?3A003`dB010>4`0@3Q<2014?5008018@
5@0F51T03@/@01HD6@0R82D02`T<01LE5P0F5A<200l>300901@C4@0@3`d04a8@00`;2@0B4@l06QTG
01PG5@0@3`d04@l@0080518C0P0A3a000`0C4A80518C01@B4`0401@B4`0401@D500C4a<04a<C01<C
4`8051@D00<05aLG01XJ6P0E5AD00P0C4a<0700?3`l041<D01HJ6`0<41406alR00/?4P0G6ah09BP]
00/>5@0=41L04aHM01@G7P0H6b004aLK020U:01nPhH07b@W00hC5P0B5aX07R<V00X?4P0i?T4051TL
01HK7P0F6al04aPL01@I7@0E6Qh201HK7`0J01@I7@0C61`0EEYN01`Q9@0H7B406QlS01@H6P0H71d0
5QXK01PL7@0J7Ql06alR01XN8P0H6b005aXO01XM8`0L7bH06QdT01XM8`0J7B8061/P01LJ7`0H6b00
6A`Q01HI7P0H6b0301/N8`0301dP900I7al061hL00<05adM05H061dP01PM8@0J7b<041DK01DI8P0S
9c005QXT01/L8@0G61`06AXN01XK7`0F5a/061TM01`M8@0K72005aPL01`M8@0R8bL06AXN01`M8P0H
6Ah06Q/P02<T:@0c=3T092DY01DF6P0D5AP04A8D014C4P0E5aH06a`N01DF6`0I6B805ADO01/K9`0L
72P0IFEa02/[=`0H62405aPM01PI7@0D5AL06AXL01HF600T92H01`L900l?4@0F5QP05aLI01/K7@0G
5aT05QHH01@D5P0C4aD06a/M01HF5P0D51@05ADE01LG5`0I6AT061PH01DE5@0H61P05aLG01@D500B
4Q804a<C01/K600H6A<08B8J02la9@1jO6h0_l:a09jPTP0b=2L0Ce5601hO600J6aH08bDR01HK7@0<
4A@03A8E01dQ900H71l08RHY01@E6@804Q<G00D05aHK01/J7`0M72405A<F01lM800201LE600301<>
4P0F4AD05Q0D00805a4E00<06A0E01L>4`0D3a<00P081PT04`0H5QT05aDH01D@500D3a<040X>01H@
500D314060lD01H=4P0D31005@lA01<=3`0B30h04@/=018<3P0C3@l050h@018<3P0A2`d00P0@2P`0
4P0>20X03@L901@>400C3@l01@0100@0000=1`T02`D701TC5@0=1`T05Q0B010:300@20/01`0001L<
4P0:00L04@H>01P>5P804@H>00H04@H;01052@0@1PD040H500h31`0>0`T200l42P8040D;4P0?10X2
00l33@803`@<00H03`@;00l42P0C20h04@H;00l4200>0`L200d21P0300h32@0>0`/03P<;00<03P<;
00H06PlG01L<500<0@T01`0400d32P0H3ADDooooo`006oooool0<P072`l04QDF00T;3@0B51H02`/=
028R8@0=30/04A0>00l<2P0>2PP03@P501HB3P0>2PL040h:014>2`0=2`L04Q0<014?2`0@3@X04@l;
018?300A3`/03`d900l<2@0B3``04Q0<01<@3@0>30P05Q<@024O6`0L6QH030X600h<200C40d040d:
00l=2@0@3`/03@`800h=2@0?3PX040l;00T8100@3`/03Pd900d<200?3PX04A0<018A3@0B3``040d:
0P0?30T0@`0@3@X040h:00l<2@0K6AD0?c`i00d;1`091`<04Q0;00l?1P0;2`804Q4;00l>2@0A40/0
3`h:010?2P0?3PT03@`600h>1@0?3`H04A4900h>200C4@`03Pd8014A300:20D040l:00`<1`0D4Pd0
40l:00`<1P0:20H04@h:010=2P0A3P/03`d900h;200?30T03`d9014>2`0C4@d04@h;00l<2@0?3@T0
30`701PI4P0?3`X03P`7014>2P0C40`030P5014=2P0?2`T04A4=018C3`0>3``04Q8>00X:200>3PX0
20P400h>2P0<30T03`l;00/;1`0>3PT03`l:014A3@0G5a800P0?30X02`0?3@X03``:00l=2P0?3P/0
2PT601@C400A40d03Ph;010@3@0<30T0414?00803Pl<0P0<30X0;@0?3`d03@d;00`<2P0=30X03`h<
00l=2`0<2PL030`700l@300<3`d03A4A00dC5@0C6Ql03A@J00hE6P0B6Qh04a/M00/C500;4A003@l>
00d=3@0;2`X02@T800h>3@0=3@`04A4@00/;2P0>3Pd03@d<00`<2`0?3`d040l=010>2`0C40h04a8?
010@3@0?3``03@h:00T:1`0;30T02`h:00/=2@0=3P/03Pd<010?3P0200l=3@0400h=300<2`X03Pd<
00d<2`8030/:02H03`d=014@3`0?3`h051<B01LF5@0?3`h020L6010?3P0A40l03@`;00X:2@0=3@`0
2`/:00d=300>2`/03``<00/8200<2@T040d=00l<300V8b<03@X:010=3@0>2`/03@X:00h<2P0@3`X0
3Pd:00l>2P0=30P040l<00T81@0@3`X040l<00d<200=30L03@`9010?30D03@`:02l03Pd;034`;P0?
3P`03`h<01@C4@0920H03@`900H60`0A3P`02`X800d;20081@@040d;018?3@0D40h03@T800/71@0?
2`T05a<A010=2`0:20H040h;00D30P0<2@L01`D401XG5@0<2@L02`P603@a;`1nNgT03`/900h;1`0B
3``05A4?018>2P0?30T04`l=01<?2`0A3P/03`/900h;1`0?2`T04@d;00h:200=20L03@P900h:2002
018=3P1J010<2P0>2@T03`X;014=2`0D3`d06aX>03Dd901ZJeL0blbh0?Geh@2@TG`0>CLV024N400A
3@H04Ph:01<>3P0C3@l050h?00l:2`0F4A403`X;02hY:P0D4A802`H800l<3P0;20X04PlA00/82P0=
2P/03@`800l>2P0>3@X030/:00d<300@3Q003`d?00h=3@0=30/03@`900h=2@0>3@/04@lB00h<400e
<cL071XN00T72P0E4aH07adP00`:300>30h030X<01LE5`0@3Q00JfYZ018A4@0?3Ph040h?014>3`0=
2P/040`>00l:300=20T05@d@01@<3`0<1PP04Pd@014<3`0?2`d040`>00l;3@0<1`X03@P;010;3P0?
2Pd07QXL018=400<1`/04@lB020N8P0A3a4030X=00T72`0;2@`04Q0B00X8300=2`h04a4C00d;3`0@
2`d03PT80P0A30`2014>3P0c00X82P0C4A@04a4E01XJ7@0m?D005AHI00`;3@0?30X03P/;00d;2@0>
2`T03``<01DB4@0S81h07Q/K00/91`0B3`d04Pl?00l:2`0?2Pd040T<014;3P0<1`X06Q@G02`W:P0H
4aH04Pd@01LD5P0?30h04PhA01<=4@0D3Q804@/?00h8300?2@d03PX>01lJ7P0300<04@hA00d:3@07
10L04a0C00d92`0;20X030T;00l<3P0A3Q003@X<018?4@0/:B/04PlA00804@h@00@040d?00h<3@0>
30d03`d>0P0@3Pl02@0?3@h030X;018@4@0@3Pl03P`=01TG60081PL03`d>010>3`0200h<3@03010>
3`0<2P/040h?00803`d>01<040h?014?400B41403P`>014?4P0A3a4040hB014?4P0C4A<040hB01HD
5`0>30h06QPL02/Y;00E4aD0514B018@3`0>30/03`d<00804a4@00l05aDD010>3@0B3`l04a0@00l=
300>3@`051<D01dL700C4Q<03@`=01<B4P0C4Q<04a8B018A4@0B4A800P0E51@0100D51@051@E018C
500B4a@201@E5P0701@D5@0E5QL06ATJ01@E5P0A4A804a<D01<D5@02018D5`0>01@G6@0=3a<06A`O
00lB5@0X:Rh04A<H018D600H6Ql05ALM018E6P0G6al051PL03Xn@P0E6Ad201HJ7P0701XN8P0b=SX0
E5QL01<G6`1OHfL0<cPl01HK7`0301LL800501HK7`0G720092T]07^0Q00i?T800P0F6al0F@0J7b80
7B4S01`P8P0L828061`N01HK7P0I7R406alS01@H700F6Qh06QhR03Tm@P0V:Rl06B0S01TM8@0J82@0
61hR01XO8`0M8BD06R4T020U:@0R9R/06b4U01HK7`0G71l05QXM01XN8P0O8bL03Q8F01/O8`0G71l0
6alS01HK7P0I7B805ATN01HJ7`0F6Ad04A<G01LJ7@0N82@04QDH01HH700D5aX05aXM024T9`0I71l0
71lR01LI7@0L7B406QXM01XJ7P0D51T05ADH01PH6`0H6A`05aPJ01HG6@0G61P06AXK01XK7@0G61d0
61XP01@E700E5Ql071dV05AEGP0V:3807b4Z01PJ8P0L7R@05aTO05=EFP1jOH00@DA501TM7P0?4A<0
5aTK01/K7@0G5aT061PJ01DD5P0G5QT051<F01HE600C4a@04a@E018C500C51D05QHG008051@E0300
71dN01XK700F5aP071dN024R8`0M7A/06Q/F02<T7@0o@CD0YZRJ0?ool@3Ce<D0CU1302@V6`0R8ad0
>CTg018D500E6A/04QLF024T8`0Q9B40=3Pb03Li<@0J71H06a`H01`L6@0I61T06aXN01/I7P0J61d0
1`H:01<B5P0I61`04a0C01TF6@0D41@05a8D018=400H4Q@05PlB01H@5@0?2a004@dC010=4P0C4AD0
5aDK00d:400B3a<2014?500;01@B5P0E4aP040`@01D?4@0D3Q003`T;010:300C3@l05@lA00l92`0@
2P`00`0B30h05@0>20T04@/<010:2`0@2P/04P`=01H@4@0@2P/04`d>00h82@0A30`03`T:00H10@0E
30h03@@601472P0E2`l02`8501@93`0@1@X04@H;01872`020147200D01061P0C20d0:b0W01883P0E
2Q4040D<01873P0>0`X04@H=01873P0=0PT030880105300E2Q003`@:00d3200B1`d04`P>00h42@0A
1P`201052`<03`@:00P040D<00l42`0>0`T03`@;00l42@0>0`P03`@900l420@03P<700`03`<800l3
2@0?0`P03`<:00l32@0?0`P03P@:01042`0>0`L05@TA01052`0?0`PDooooo`006oooool04P074QP0
214F02Pb=00@61/03Q8D0414A@0A4a803`l<00d<200A3PT05a<>01XG400B3P/05aHB01hM6@0M71P0
4Q4=00d<20L03Pd901@030/7010?2`0<2`L05A@@02@S7`0R8Ad03Pd9014@300B4@d03`h:01<B3P0@
3`/051<?00`;1`0=30P05A@@01PG4`0@3`/03`h:00h=2@803`h:00@040l;018>2`0C3``04Ph;0P0@
30T0800A3@X06QHC00T50P0W8b004Ph;01DA3P0E4Ph04a8=01DD3`0>3@P03@`700h=20071P@00`80
00`;1P0B4@`04A0;010?2P0<30L03Pl9010A2`0<3@L05AH@01/L5P0<3@P04a@>00T:100720D061TC
0083000;2`H03@`80P0<2`L200/:1P0C00d<200>3@T03@`800d<200>3@T03`h:018E40001@0030h9
01DD400K6QH05A0=018=2P0@30T03@d900d>2@0=3`X03A8<00P:1@0200P9100=024R7@0R8ah030d8
00h?2P0A4Pd03Pl:010A300:2`H06a`G01HE4@0E51004A0<00h=2@0200d<200600l>2P0@3`/04A0<
010?2`0A40`040l;0`0?3P`200h=2`0300d<2P0>3@/03Pd;00<03Pd;01D03@d;01PJ6@0A5A@02@d<
00L;2P0830/02`l>0001000N8R4010P70045100@51<020X900P81P0/;2X01`L500l?3@0=3@/051@B
00l?3@0<30X00P0>3P`03`0<30X040l=00l;200<20D03`/800`;1`0920@030d800d>2@0A4`h03A8<
00H<1P083`P03A8>00d<3@0200l=3P0300h<3@0=2``03P`=00803`d>01H03P`=00d;300>30d040h?
00`<30092@T04a<C00L71`0410@04Q8B00`<300;2`/03Ph>010@400?3`l04A4A01TG600H5QL03`d>
010>3`0C4A803@/<0P0>30d0300?3@h03P`=00h<3@0C4Pl02`X500H5000=30L051<>00D4000;2PD0
0`8000X9108030/600<04a8=00l>2`0=30X00P0<2`T0700=30X03Pd;00d<2P0=30X03`h<01@C4@0E
51804a8@00P81`071`D05QHD00L71@0H61H051<A00`;2@0=30X04@d<00h:2@0;1`H03`T900@0000=
2@H03`/800d91P0Q7AX05A4>01HB3`0D40d200l;200800H2000Q7AX04a0;014>2@0?30L03P/600l<
1`0B3`X2010=200<00l<1`0>2`H03@X500`9100@2`P05Q4>01@?300400004`h;010;2P0B3@X04@`9
0P0?2PL04P0B3@X05Q4>01hJ4@0S7a<06QL8048o<01bKeh0?c`[01hK300H50T04Pd7018=2P0C3@l0
4P`@01@>400C3@l04@/=010:30804@/=1@0?2@/01P0>2P/03@`:00l>2P0>3@T03@`800`;1`<03@`8
0P0>3@T06`0?3PX03`h<00l=3P0=2`h02`T<00`:3@0>30l03`d@01DC5P040PD02`T<014?4P0]:bh0
71XM02@T9000000030`<00L71`0:20T05Q@E01<A4P0E4A804Ph?01/G600L5QP04P`>010<3@0200l;
300:010<3@0>2P/030P900l;300=2@X040`=00l;300;1`P03@T:014?4`8040hC02403`dB00h<4@0?
3A805A<H00`:3`0?3A800@0400`:3`0g<C<03@P500d50`0C3P/02@D200`81`0>2``01`D800/:3`1D
EET0ZJZ^0452AP092@`03P`=00`:2`0;2@X030X;00h<3@0?3@h05A<D018@4@0:20T04@l@018@4@0>
2@/00P0A20/01P0B2@`04@P;00l92`0?2P`040`=014=3P803`d>00D03P`=018=4@0B31004P`@014;
3`02010:3P0C00@00P0E3a<05a4E01@>4P0J51P06aDI01HD5`0:20/030X=00h<3`0H5QT04@lB00l=
400200<02@L:01<A50091`X02`T<010>3`03014?4003010>3`0?3@h03@/<00804Q0A00<05aDF01lM
7P0B41400P0@3Pl01`0<2P/03P`=018@4@0=2``030X;00h<3@0A3a000P0B4140100A3a004a4B01DC
500D4Q<201<A4P0401@B4`0>30d040h?01<A4P80518C01@04a4B018>3`0D41409B4R02<O800B3Pl0
510A01XF5`0G4a@05Q8C014=3P0@30d06QPI02PX:00`<30061PH014A4@0J6QX04Q8B01DE5@804Q8B
00H04a<C018B4P0A4A403a0B00d>400>3a42014B500:00l@4P0B4aD04Q<E018C5@0@4A<04Q<E01<D
5P0F5a/05aPL01PI7@806AXN01<061TM01XK7`0E5QX051DI01LH700F5a/051DI01LJ7`0E61d071lT
01DH7@0A51T051LL00`?500D5a`061/P00<62`0Y;340720T008061dQ00h05AXN01PM8@0G720051TM
01TN8P0M8RH051TM014F6P0K82@092T/01HK7P0;41<041DH01PM80805a`O01X082DX010E600O92L0
;34d05EJG@0/<SD05QhQ01@L7`0I8B@05QhQ01LO8P0D71l04ATL01HN8@0J8RD05AdP01@L7`0S9Rd0
4aHM018E700:3A80=STn00L:3`0D61/05ATL01LK70<061`M00X03a<F02DY;00K7b802`lB018F6@0N
8RD06alR01`P8`0Z;S406QhQ0P0M8B@01P0C4aD05ADG01LG6@0E5AL04a<E014A4`@05QHH01`061PJ
01PI6`0?41@061`O01LK7P0F6Ah05APN00T<4`0M82L041<K00lB6`0A51d09RTb0823RP2e^[d0;cLf
01HL700:41003a@D01<G600C51H04a<E00h<3`0E4aH04Q0C01PF6@0B4Q@05AHH0P0C51H0E`0E5QP0
4A8D01LH6P0R8bD07AhP01@E5`0G61X06a`N01XJ700N7Q`0824K02`^8`1KGDl0VYf<08nAPP0/;R40
5QP=01`M6@0K6ad03@h@020R9@0H6QT06adH03<g:`2c]JL0_L2_05aOC`1CDdT0CTi601DD4P0B3A40
8R0U030^=00K6Ql04a8G01DD6@0F51L03`d@01@B5@0D414020@5010<3@0A2`d04PdB00h9400A31<0
5Q8I00T63@0B4AL0;Bdb010A5P0B5AX0=STn051EF@0G72004Q0D01H@4P0G4A<050h@010:300?2@/0
3PP:00X41P0?2@/04P`>01<=3`0F41803PP900h8200@2PX04@/;010:2P0>20P030H600T30`0;1@D0
4@/;01@>3P0C3@d03PL700h41@0H3Pl02@0000P0000D2P/03`D601061`0301882@0C01462@070080
;B8Z00d42P0C21002`0800h32`0@1@d02@0600X11`0I3QH07A8J01053@070080200301L<4P0A1P`0
6@hD00`21`0300h32@0400l42P0@1@/04PL=00l420803@8600<03`@801462P0@1@T01P0>0`L600l3
1`0400d11@0D20`02@0101@8308040@85?ooool001_ooooo01802A8G04UBEP3Dg=d0Ifia01DJ6`0:
3Ph0<C<a01hN6`0@3`/0514<01LC3@0B3`T03@X701DD400=30P071/G00l>2P0A40`700l>2P0C00`;
1`0@3`/040l;014@300H5a<04A0<00l>2P0B4@d03Pd900/:1P0A40`03`h:00X91@0>3@T092<O00d<
2@0>3@T03`h:010?2`02014@300500l>2P0>3@T03`h:010?2`0?3PX00P0=30P200h=2@0:00l>2P0;
2PH051<@00d<200?3PT010<002TX8`0920D040l:00d<1`804Q4<018040l:00l>2@0<2`H03@`701DE
3`0720<03Pl903Hg<@061`4051D?00h?2P0A4P`06Q/E00h?2@0B4`d01PL3010@2`0A40`3010?2`0=
00l>2P0>3@T03@`800d<200?3PX040l;014@300?40/0=S/e0822O@0H5a<04A0<010<2@0200l;2004
00d=200<3@P02`d800/@2P803a0;00d03Pl:02@U800T9B004Q<>00/<1`0A4Pd02P/6010A300D5A00
30d:01HE4@0C4Ph03`h:008030/70P0?3PX200h=2@0900l>2P0=30P03`h:00h=2`0?3P`04Q4?014@
3P0?3P`03@`:00D03`h<01D03Ph<00`=300;3@`02`d<00`>3@0>40l03a4@014C4P0f>3L051HE00H8
1`0B51<03a4@00h>3017AdD020P601TI5`092@L03@d;00h>300<30X00P0?3`d03`0<30X03`h<014=
300B3@`0510?014=300@3P`06ATG00d>300C5180418?00P;200:3PX04A<@010?400200h<3@803@/<
01<030X;00d;300@3Pl040h?00h<3@0=2``03P`=00l?3`0:2PX05ADE00d=3@0D51@01PH600L71`08
20P04A4A00X:2P0=3@d030`<00804@l@00@02PP900h<3@0B41403@/<0P0>30d04P0?3@h03P`=00h<
3@0;2PP03Pd9014@300920D051<?00T81P0?3P/040l;00h=2@0=30P03Pd900d<200=30T03Pd;00d<
2P8030/902803@`:00l>300?3P`03Pd;010?3@0B4@l04A0>010?3@061PD0;Bd[01LG5@0?3`d040l=
00/:200=30X040`;00l;2P0=2@P03`T9018>300:1P@04Ph<02/W901FDTl05A4?00d91P0=2@P04@d:
01dI5P0H514030P601DA3P0D40d04@d:0P0?2`P0100A3@X030P500d91P0>2PL2010<2@0O018>2`0L
61L01P8201<?3P0=2@P03`/;014=300F4Q405A4@018>3@0@30/04@d<01@@3@0C40L05A<701/I2`0O
7@l081h@01lM3`0C4@<04Pl501<@2`0D40h04`lA010;3`0A3@h04Ph?014=3P0@30d03PX;00`82@06
00l;300:00l>300<2`T030/900h=2`0@3`d03Pd;00`;2@0=30X03Pd;00l>30804A0>01/03`d?00d;
3P0;2@`030X=00h<3`0?3A0040hA00L5200=2`h040hA01hL7`0@3Q404A4A00P820071`L04Q8B00P6
1`0A3a005aDF01@@4@0>2P/040`=014;3@0:10H03`/<018>3`0A3@h00P0>2P/03P0?2``040`=01<?
400G4a@04Ph?00h:2`0A3@h040hA00d;3P0<2Pd03@/>00l=400>30l04Q0C0P0?3A0060050`H05aDH
030^;`0<2PP02PD601DB4@0F4a<0514B00`:2`071@H040lA00h>3`0T92D03@`>00d;300>30d030X;
00/92P0<2P/03P`=00/92P0=2``03P`=00/92P804@l@00@03`X;01482`0A20/04@X<0P0?2@/00`0?
2P/040`=014=3P0200l=3P0400h<3@0C3Q804PdA018=4@803`X>00X03PT=00l:3P0C3Q802PD901<>
4P0A31003PT=010>4@0<2Pd0:bT/0P0?3A001`0>30l04Q0C010>4@0T8RD04Q0C00`:3@0?3A000P0@
3Pl2014?4007010>3`0?3@h03@/<00l=3P0=2``040h?01LE5P02014?4007018@4@0=2``03`d>01@B
4`0?3@h03P`=014?400201DC500501<A4P0A3a005Q@E01<A4P0B41400P0C4A800`0?3@h03P`=014?
400201DC500E01<A4P0A3a00518C014?400T8R<08R0Q010>3`0G5AH04a4B018@4@0H5QL04@l@01LE
5P0k>CX092@T028R8P0B4Q80410@01@D500>3Ph051@D00804Q8B00P051@D01<C4`0B4Q8051DG018C
5@0C51H05QLI01DF608051DG00H04Q<E01@E5`0F5aT051DG014B500D5AT301DF6P0H01@E6@0C51P0
7AhR01HG6`0C51P051DI01HG6`0G61d07R4X020S:P0?4QT05aXQ01/N9@0E61l04aHM018E700L7bH0
4aHM01XM900G6b4061dQ01LL800D6Ad061dQ0P0J7b<05`0M8RH0724U01LL800H7B408RL[02@Y;00K
82<082DX01PM800E6Qd07B8U01LL7`0T:B`05AXM01`Q900F6ah08bP[01TP8`0G7b80620S01dU:00L
92L06R8U00804a/N0P0H82<00`0G7b8072@W01LJ8@0201/N9@0501XM8P0f>Ch08RDZ01DI700F6Qd0
0P0G6a`201HJ6`0E024U:00D61/0720S05aPH`0`=3L05a/N01XN8@0G6ah06QhQ018F6@0E6A`061`O
01PH6P0I6A/071`N01lO8@0L71h051@F018B500D51H05aLI008061PJ01/05aPJ01LH700F6Qd05ATL
01DH7@0F6Ah05APM01PK8P0B5A`06ahU01PK900B5Ah05QTP02X^<@0@4a@051PI01HI6P0A4a@06AXL
01DF600A4Q@061PJ02<S9@0F5aT06ATK018C5@0F5aT00P0D5AL0>P0F5aT04Q<E01HG6@0L7Al061TK
01LH6P0F5aT051DG01/J7`0I6AX06a`H024R6P0R91L0;BlR03Hh:P0J71805QL@020P800F5QT071dQ
01`O8@0H6QT092HQ06Y]I03cmNP0oooc09>EQ`0Q8AL0:2LR01`K6@0K5QX061HK02h/<P0R8BH04Q4F
014@5@0F51L03P`?02XX:`0R7Ql0510A01DA4P0C3@l050hC01D@5P0A31805A8G00<11P0M7240IfI[
01<D60092Ph0LWIi0=3De`0n@TD04@lB010:300?2@/3010:3007018<3P0?2@/050h@014;3@0?2@/0
5a4C018<3@0600l92@804P`<00/03@L700l92@0@2PX040T901@<300@1`L060h?01@:2`0@1PL03`D6
01061`0301882@0C01882P0<0`L05P/A01<83P0E2Q003P<901873@0D2@l03`@:01<83P0R5ad091TO
01D:400H3A<0308701<93P0=10P0@SLm01lD6P0201052`<03`@:00L040D;01052@0>0`L03P<70105
2@0C20`04PL;00H03P<71P0?0`L01P0>10H04@H901<82`0>10H0714D00d31ACooooo000Kooooo`0?
00@<3`0g?d80UibO03m4A`0@5AD061XI01LG5@0?3``02@P400`9100?30L040d801XI5@0_;RX020L3
00<040l;1`0?3PX00`0<2`L03`h:018A3@02010?2`803`h:00`051<?01HE4@0B4@d04A0<01<B3P08
1`<061LC03Th=00@3`/030/700h=2@0@3`/2014@300700h=2@0=30P03Pd900l>2P0>3@T030/700/:
1P0200d<200B018A3@061@4030/700P70`0^;BP09RDP059AC00F5A0030/600P70P0F5A0040l:00P7
0P0?3PT040l:00/:1@092@@02``60P0>3`T03@0<3@L05QLA07amM`0U9R001PL100h?2@0@4@/05AH@
00/;1P0=30P03Pd900l>2P0>3@T00`0=30P02P0>3@T040l;014@300A40`05aPC00X?2@0e=c8030/7
00H50@0:1P<2010<2@0D00h>2@0=3PT030h900T>200;30L04Q<>00X;1P092PD01@H100P9100A4Pd0
2``7018C3P051P405aPC00d>2@0920@02PT500`;1`0=30P200h=2@0;00`;1`0;2PH04Q4=01DD400>
3@T030/700`;2@0>3@/04A0>018A3`0?3P`01P0=30X00`0<30X02`/;00`>3@0200h@3`0@00d?3P0;
3@`03a4@00d?3P092`X03a4@00`>3@0E5aH00@4001HF50061P@030`:00/;2@0=3@/03`l=00h>3080
4Q8@01P03Ph<010?3@0=2@P03`T9018<300?2@T040`;01XI5`0?3P`03@`:00`<2P0=3@/030`:00X:
200>30d030X;00d;300?3@h02`T:00P61`0=2``040h?014?400>30d200d;300B00T92@0;2`/03`l?
00d=3@0B4Q802`/;00d=3@0820P03Ph>014A4@0@41002PX:00/92P0>30d02@L8010>3`0G5AH04a4B
0P0>30d04`0?3@h03P`=00h<3@0?3P`05A@@00L60P0@3`/03@`801/J5P0920D0O7]g079aK@0B4@d0
4a8>00L60P0@3``03Pd;00d<2P0<2`T00P0=30X0100?3P`03@`:00X91`0;2PP200`;2@0G00h>301I
FEL0k^k/03lo?@0000000`8000l>300<2`T03@T800h:2@0?2`X03`T901DA3P0;1`@00`0001DA3P0<
20D02`L400l;200G4a004@d:00T50P0G4a000`0@30T300l;2004010<2@0=2@H03@T600l;208040`9
00X04@d:010<2`0;1`H0I61O02TU900H51<05a<B01HB4@0E4A004Ph=0P0?2`X03`0?2`T04a0900l=
0@0C4@D061H:01XH300M6`l05186014>1P0?30L040`;014<3`0?2Ph03@T:00l;3002014=3P0300l;
300=2@X03`/<00D03`/<00D040l=00`;2@0<2`T040l=014@3P0700h=2`0F00l=400=2`h02`T<00`:
3@0>30l03`d@00/9300:20/03P`?00l=400B41<02@L:00T92@0G5aL0410@01<C4`0@3Pl0518C00`:
2`0=2@X030P901DA4P8071HH00<03PX;018>3`0A3@h00P0>2P/02`0A3@h030P9014=3P0E4A803`/<
00`82@0@30d05Q@G018@4`0?3A003P`?00803`d@01L06QPK01DC5P0:20/04@lB00L520091`X02`/;
00/9300a<3805aDF0040000A3a000@0000L51P0?3@`04a8@00`82@081`L03P`=00`:2`0;2@X030X;
00h<3@0200d;300:00l=3P0>30d040h?00h<3@0?2P/04`X=014;3@0B30h04@/=010<3@804@d>00@0
3@/<00`:2`0=2``03`h?0P0B3A400`0A310040/?00l:3P0200h93@0A010;3`0H4aL00`0201<>4P0R
7B4040hA01<A500o?D005Q@G00l=400A3a802`T<014?4P0U8bH030X=00l=400=2`h00P0?3@h3014?
400=010>3`0E4a@0518C010>3`0?3@h04Q0A010>3`0C4A804Q0A00d;300>30d04@l@00/92P0201@B
4`0501<A4P0D4Q<05A<D01DC500@3Pl00P0=2``01@0A3a004Q0A00h<3@0D4Q<04a4B008040h?00L0
4Q0A01<A4P0D4Q<0518C00`:2`0:20T04a4B00805Q@E00`02`T:01<A4P0C4A803@/<01HD5@0K6a/0
3@d=01DE5@0B4Q803Ph>01LG5`0A4A4200l?3`<04a<C00<04A8D00l@4P0@4A<00P0C51H0200A4Q@0
51DG018C5@0E5QP061TK01@E5`0@4A<05aPL0`0H6Ad201HG6`806AXN00H061TM01HG6`0E5QX05AHK
01DH800G6R<2010C700<01@G800E62406ahW01`O:00N8BX06QdV00lB6`0G6b4061dQ01LL800D6Ad0
6AhR100K82@04P0J7b<061dQ01HK7`0G7R403aLJ00dE600K8bH09Bd`02@/;`0G7b806b<V01@L7`0I
8B@04a/N01PP8`0I8B@05alR01`T9`808BT/00d0620S01@L7`0C6ah05AdP01XR9@0L92L051`O01HI
800Q92/06A`S01`O900K7R<041<H00805a/N00T05a/L01HJ6`0E6AX051PI020T9`093A0041@G051D
E`0;3a800P0G6ah00`0H71l05QXM01LK7P0201HJ7@0301/K7@0H61X05aLI00806ATK00@051@F014A
4`0D51H05aLI0P0I6A/0600G61X04A8F01<G6P0g>ch0>3`o01HJ7P0C5Q/06ahS02@W;@0<3aH08B@[
018E7@0F6B007QlS020Q8`0A4Q@05ADG018C5@0L7Al05aPJ014B500J7Ql0;2d_01`O80804a@F02L0
5aPJ01DF600E5QP05aPJ01<D5P0E5QP04a@F010A4`0G61X06a`N01LH700N7B<05aLI01LG5`0O81X0
:BXR02HX7@0R91X06Q/E01@E400I6AX030/A01LH7@0E61X08B<R02T[:00h>c80SHn20;bn/@15AcX0
8B4G02TX8`0C4A4061<G01`J7`0E4aX030/@01<B5`0E51T00P0D4QD04P0?3A003PX;00T51P0A3@h0
3`T;01<>4P0L5ad040/A00l;4@0=2a006QPM051?E012@DH06Q/O01PI7@0`<CD01@H:01<@4`805@lA
00X050h@00d72@0?2@/04`d?00`6200A2`d04`d?01`F600/9RP081XK0P0?2@T04`0>20P03`T900l9
2@0?2@T02P@400`61P0=1`L0208201TC4`12>SX06a4B01882@0=0`@0200001L=3P0D2P/04`T:0188
2@0@1PL00P0?1@H00`0E2Q00200301<83P0200`11`0@00l42P0;00H03@8801052`0=0PP02`0600`1
1`0>0`T081DK01873@1BAdd0l^O]06mTJP0B1`d04@H<01052`<03P<900<050T=01872`0?10P00P0@
1@T700h31`H03`<700H03@4500T00@0Q5AT0200003HZ;P0G2`lDooooo`006oooool04P0>4aL0314D
028X:0083Ph020/;01<E500A4@l04a<@01<B3P0E4Pd061D@01`I500:2@D09B@P00`;1`0>3@T04A0<
00d<20H040l;01803@`800/:1P0=30P03`h:00h=2@0=30P040l;00d<200@3`/05QDA018A3@0>3@T0
4Q4=00X91@0=30P04a8>00P70`0L6aL200l>2P8040l;00D03`h:00h=2@0>3@T03`h:00h=2@0200`;
1`0300d<200;2PL051<?008051<?01l01@@001LF4`030P009bHQ00d<1`0K6QD0;B`W04M6@@0a<2/0
4Q4<00L60@0:2@@04A0;01LG4P0<3@L03Pl901PI4`0?40X03Pl90:2QV`0c=2h01`P201<D3P0A4P`0
4Q<=00L7100>3@T03`h:014@300@3`/03`h:00803Pd901h03`h:014@300A40`04A0<01XK5P083@L0
3a0;00/<1`0E510061@A018>2`0A40`04A4<010A300>40/03@l:01<D3`0F5a803a0;01HG4P0C50l0
30d800X;1P0720<04a@?00H70P020`004A8=00`;1`0=30P200l>2P0=00h=2@0=30P03Pd900`;1`0F
5A406QTE014@300=30P030/900d<2P0?3P`040l=00l>300700d<2P0D00`<300=3`h03a4@00lA400>
40l030h=01DG5P0>40l0008100X<2`072@P0004000h>30071`D04A4?00X:200?3`d02`/9010@3P0?
3`d201<C4@0V00l?3@0A40h040`;010:2P0A2`/03PP800/61P0B3Pd03`h<00X91`0;2PP03`l=00d<
2P0920H030X;00T7200<2P/040h?00l=3P0<2P/03@/<010>3`0?3@h03P`=00d;300>30d0410@01DE
5@092@T00`<30000000D51@03`l?00X:2P030`<04A4A00`<300;2`/2018@4@0400`:2`0@3Pl05A<D
010>3`803P`=01003`d>00h<3@0>30d03`h=00h=2@061@403`h:0040000<2`L0:BPT0=gLf03Cd/h0
9RDQ01LF4P0:2@D02PT60`0<2`T06P0=30X03Pd;00h=2`0:2@L02@P600`;2@0?3P`040l=00/;2@0I
6AL0Ph>101dM6`0E5A<03`h<00d<2P0;2PP030P700h:2@0@30/040X:00`81@0>2PL0510=02/W9006
0P002`L40P081040100?2`X02PH300h:1`0F4Pl200h:1`@03`/800d04`l<018>2`0A3@X03`/800h:
1`0=2@H00`0001LC4P1/J6L0=c<b03hj>@0k=cH040`;00803`/:014040`;014=300B3P`03P/401HC
2P0C40L040d401@A200F4`X05Q<<014>200=2@H03PX9010<3P0@2`l03PX;00l;300:010<3@803Pd;
00@03`h<010?3@0@3`d03@`:0P0?3P`200h=2`0800d<2P0=2``03`d@00d;3P0;2@`030X=00h<3`0?
3A0200X82`0600d;3P0@3Q403`d@00`:3@061PH04A4A0P0820P02@0S8B802@L800/92P0>2P/03`/<
01DA4P0L5QP07QPJ00d92P02010<3@803`/<030040`=00/7200>2P/04Ph?00l;300<20T03`/<01@B
5@0A3a803P`?00d;3P0<2Pd020H900D31P0:20/040hA01<A500D4QD04a8D01@D5P0B4Q@061PJ01DE
5`0?3A005Q@E01<B400I5A@03@T800@0000A2`/04a0@00h<3@0<2P/02`T:00`:2`0>30d03@/<00/9
2P0>30d040h?014?400@3Pl04@`>01<:3@0B30h04`d?018<3P0@30d2018>3`0600l=3P0>30d03`d>
010@400?3A004@`@0`0@2`l05@0?2Ph05Q4E00<00P0>2@d040/?00/62P0?2Ph03`d@00D31P0K6A`0
30X=010>4@0:20/04a4D00400P0?3A005aDH010>4@0;2@`03P`=00l=3P03014?4007010>3`0B4140
4Q0A014?400@3Pl04a4B01@B4`02018@4@803@/<03T04@l@00`:2`0E4a@04a4B014?400B4140518C
01DC500?3@h03P`=00l=3P0A3a004a4B018@4@0D4Q<04@l@00h<3@0?3@h0518C01LE5P0>30d05aDF
00`:2`0:20T05A<D014?400F51D03P`=01@B4`0J61T04Q0A00P61`0K6a/03@d=01TI6@0D51@030`<
01LG5`0D51@04A4A010@400C4a<04Q8B014A4@0B4aD0414C014B500D5AL04a@F018C5@0D5AL04a@F
01@E5`0E5QP051DG018C5@0H6Ad00P0I6Qh0100J6al06AXN01PI7@0F5a/201/L800601PI7@0E5QX0
5AHK014D700C5Ql061/T0P0B5Ah0500H6b@07B0Y02@W<00P8b`08RD^01DH8@0K7bH06AhR01PM8@0F
6al06AhR01XO8`0N8bL082DY01`Q9@0N8bL08BHZ020U:@0M92L06b<V0P0C6ah03`0=5AP04a/N02/c
=P0E7B002A4D01@L7`0I8B@0620S01@L7`0F7R406R8U01dU:00N9RT05AdP01PP8`0201LO8P0M01`T
9`0O9bX051`O01`Q9`0I72<05QTP024T:@1gNWl0:bhc01@H6`0E6A`05a/L01PL7@0I7Ah061`M00/?
4P0T:2/09RX]02lc=P0K7b804QHI00hB5@0D61/041@G01@H6`0>4QD041@G01TJ700H61X00P0D51H2
01DE5`0P01@D5P0F5QP05aLI01PH6P0I6A/061TK020T9`0M8B@0?D5403a0@`0K7R8071lT02d`=@0f
>Cl02PdD01hQ:0082a<05aLO00d<4@0C4aD030`>01@D5P0I6Q`06a`N01LH6P0A5AH03Q8C01/O800F
6a/041@E01@E5`0H6A/201HG6@1401PI6`0D5AL061TK01@E5`0>3a405AHH01TJ700F5a/07A`R01XI
7P0L71h06AXF024R700L7AL07b0J01LH4`0B4Q005QDI01<B600H6Ah04ADG01LI600M7a`05aXB038d
:@1EEdX0;BlT01HF3P0J6A@08AlO01PC5`0:20d05Q@J00d<4@0I61d061LL018@4`0D4QD05A<F01LC
500D41406ADF018<3P0C3A006QDK01<>500B3Q@04@lD00`:3`0l>Sl0E5=H01DD6@0<3A405QLK01@E
6@0?3@l030H800l92`0H4Q@04@/=010:300E3a403@L900l92`0>20X05@lA028L7P0I4a@500l92@0@
010:2P0:10@030H6014;2`090`<06aDE06aTI00c:BX02@4100l51P0K4A8050`<01H<3@0E2``04PP9
00l51P803P@500@04`P<00L00P0@1@/02P050P0A1P`0300F2a404PL=00l42P0C20h05@X@01873@07
00804@H<00`11`0/8BL0TXN=040e>`<03P<900D03`@:01052`0B1`d050T=01872`0300l4200300`1
1@0>0`L03P<700@03P<71P0?0`L01P0;00<05P/>00T00@0C1`/0710D01P<41Cooooo000Kooooo`0B
01XN800?4a@04QHF018E5@0B51<03a4?00l?3@0>3P/03Pd900h=200?3@P03``7014@3@0>3@T05QDA
01<B3P0>3@T03`h:1P0@3`/02@0>3@T040l;00h=2@0?3PX04A0<018A3@0A40`03Pd900d<2002010?
2`0@00h=2@0?3PX03Pd9014@300?3PX0?chj06a[I`0A40`03`h:00h=2@0?3PX040l;014@300>3`X0
3a0;00h?2P8030d800P03@h901<D3`0A4Pd04A8=02HW8`0<3@P04A4<010?2P803`h900H02@P400h=
200C4Pd03@`700`;1P0B4@`200/:1@0?00h>2P0J6aD03Pl:00d>2@0:2`P03Pl901hO6@0;30H030d:
00h?2@0C50h02P/500h>2@0?3PX04A0<00804a8>01T04A0<010?2`0@3`/04A0<018A3@0A40`040l;
018C3P0:30T04a@?010A300>3`X03@d900h=2@0>3PT03a0;00h?2P0<3PT02``700X;1P0A4Pd02``7
00`=200:2`H03Pl:00803@h900T051D@05QIE00A4Pd03@h9010?2`0?3PX03@`800`;1`0=30P00P0?
3PX00`0:2@D04Q4=01HE4@0200d<200400/:200<2`T030/900`;2@803Pd;1P0?3P`00`0<30`03@d=
00h>3P0200l?3`0900h>3P0<30`02PX:00T92@0B4Q8030`<01<C4`0>3P`030`:00803`l=00@03Ph<
00/;2@0>3P`03Ph<0P0C4a402`0>3P`03`h<018>3`0?2P`04@`>018<3P0=2@X03PX;014=3P0B3Pl0
4@d>008040`=00L03``=01XH6@0=2``02PP900h<3@0?3@h03P`=00803`d>01003P`=00`:2`0>30d0
4@l@00X:2P0820P03Ph>04A4A00F5QH0=SHf028R8P0S8b<00P82010@40030`<0410@0P0G5AH0100>
30d040h?018@4@0=2``200h<3@0?00l=3P0>30d03P`=00h<300920H03Pd;00l>301XIfD05A@B014@
3P1=C4X0E5=A01<B400=30X040l=00<02`X800@03@`:00l>300A40h03`h<0P0;2PP06`0=30X03`h<
00h=2`0=3@/03`l=00`<2`0=3@/02PX800L6100>3@/02`X800/71P0?2`X04@d<010:2P0B3P/03PX7
00`91P0:1P<06QHC00h:200B3P/05a<@00h:1`0:1P<05A4>00h:1`0301<?3P06014=300?2`X03PX9
014=300@30/04@d<0`0@30/01P0B41401`D6018@4@050`@07A/L04Q6A`<03P`=01403`d>010>3`0@
3`h030/600`<1P0A4@X051<=010@2P0=30H04A0<00h=2P0>30`03`d>010>400?3A004Q0A014?4003
00h<3@0300l=3P0>30d03P`=00@03P`=00D02`T:014?400D4Q<04@l@00d;300200`:2`0300d;300>
30d03`d>008040h?00D03`d@00d;3P0;2@`030X=00h<3`0200l=400<00h<3`0=2`h03`d@00/9300>
30l03`l?01<C4`092@T092@T07AbL`0E4a@03P`=0`0@30d03P0C3@l05Q0B00h:2`0=2@X03`/<018>
3`0@30d03PX;00l;300<20T04@d>01<?400@30d04@d>0`0>30d06@0=2``02`T:00l=3P0<2P/03@/<
00h<3@0?3@h05A<D00l@4`051`/03a0D05QIG@0j>ch020H900X8200A3@d03PX8014;200@2@L04PX8
00l;2@0>30d030X;00/92P0<2P/00P0>30d200`:2`0400l=3P0>30d03P`=010<3@804@/=00T04Pd>
010<3@0@30d03P/<00l=3P0D4a<051@D018B4P0=3@d00P0=2`h200h<3`0F00l=400@3Q406QPK06]Y
K00f=3L03@/>01<A500=2`h03`d@00X82`0@3Q404@lB01LE600>30l03@/>00h<3`0@3Q404@lB00/9
300@3Q403P`=00l=3P@04@l@0P0>30d3010>3`0901<A4P0?3@h04@l@00h<3@0@3Pl05Q@E01<A4P0>
30d040h?00804@l@00D03`d>00d;300@3Pl04a4B018@4@0200l=3P04014?400E4a@0518C018@4@<0
4@l@0P0A4A401P0C4a<04Q8B010@400C4a<0410@01LG5`804a<C00`05aLG00h>3P0C4a<04Q8B00l?
3`0A4A40410@00d=3@0C4a<04Q8B01<C4`0H61P201TI6@0?018C5@0@4A<04A8D01@E5`0C51H04Q<E
01@E5`0E5QP04a@F014B500C51H05QLI01HG6`0G61`061TM00<06AXN00<05AHJ01XK7`0K72000P0H
6Ad04P0I6b0061`V01/O:P0N8Rd082@_01/O:P0I7BP04ADP01hR;@0G6bH092Pc01HJ9@0G72<06QlS
01/P900H7B406AhR01PM8@805a`P00H05Q/O01hS9`0T:Bd07b@X01LN8@0V;S4201TQ900J024Y;01B
FUd0O8B701dU:00L92L06b<V01XR9@0O9bX06b<V01`T9`0I8B@05AdP01/S9P0I8B@05AdP01TQ900F
7R405AdP01XR9@0H82<0724W01hS:@0E6R004AHJ03Xo@`0J7b<201LL7`806AlO0P0H7Qh03@0C5aX0
7R8U01LK7P0B5QT05a/N01TM800G6ah082@W01PL7`0L82<04aLJ01`P8`0F5a/00P0G61`2018C5`08
01@E6@0H6Ad05aPL01HG6`0G61`06AXN01XK7`0D61T201HJ6`0;01LK7P0F6Qd051PK01DH7@0K7R<0
4QDJ01DH7`0C5Qd061TN01XH7@0J5aX00P0J61/02P0M7Al04Q<E00/?400Q9BH051XJ014H600@61P0
4ALG01<G600I6Q`201HG6@0501TJ700E5QP051DG01HG6@0C51H00P0G61X07P0C51P05QLM01PI7P0U
9R/06Q`M01dO7@0G6AD06A/H01dN7`0N7b805AHK01/K8`0C51T04aLI01@F5@0C5A<071lJ01DF3`0M
7aD06a`E01/J5P0?3P/05A@D00l:3P0M6al04a4G01PG700D4aP04A0E01LE60805A<F0240510A018>
3`0E4A803PP:01HA500A3a804a4D01@B5@0>30l040hA01HD5`0C4A@01P@701LF6@0:2P`03`hA028O
8@0L5QP030H801<=3`0E3a404`d?01H@4P0>20X040X<014;3@0@2P`04@/=00/51P0>20P040X:018<
300@2PX00P0>20P02@0@2PX04P`<010:2P0>20P03`T901L?400E2``04PP901<92P020147200H01@:
2`0C2@X04@L800l51P0@1PL04@L800l4200<0@D040H900d21P0I3Q803P@701462P0@1@T040H900h3
1`0=0PH03@<600l62P0@1@/040H;00l52P0M4QP03`@:0P0@1@/300l42P0601052`0A1PX03`@800d2
1P0>0`L03`@81`0>0`L600l31`0301462@0>0PH03@<500803`D700<03@<5ooooooooool04_ooool0
01_ooooo00P0418A01TK6P082PL02`/9010@3P0?3`d04Q4?02@S7`8010<001X04Q4=01DD400A40`0
3Pd900d<200>3@T04Q4=01DD400@3`/03`h:00H50@0<2`L04a8>010?2`0:2@D030/7014@300@3`/0
51<?00d<200C4Ph05A@@01@C3`0>3@T02`X600d<20H03`h:00d04A0<010?2`0?3PX03`h:00h=2@0=
30P04A8=00d>2@0F5a801`P500P9100I6QD03a0;00802@X500D03Pl:00l@2`0D50l00@0000l>2@02
00h=200500@3000>3@P03`h900l>2@0<2`H00P0@3`X01`0:2PD04A8<00l@2P0@4@/03@h801<D3P0;
30H01@0<3@L01@0<30L03`h:00l>2P0;2PH03Pd9008040l;0P0>3@T04@0A40`03@`800d<200=30P0
4a@?01@E400720<020T401DF4@092PD03a0;00X;1P0=3PT01PL200`=200:2`H02@X500803@h900/0
2@X500h?2P0<3@P03Pl:018C3P0@4@`03Pl:00d>2@0>3@T02`X600`;1`02010?2`07018A3@0A40`0
40l;018A3@0F5A405A@@00h=2@0200l>308040l=00P03`h<00h=2`081`D05aHD04A3@@0[:RP02PT8
010?3@802`/;00H0000000X:2P0@410020P800l?3`0<30`200T92@0300`<300?3`l030`:008030`:
00d03@d;00l?3@0?3`d02`/900l?3@0820H01@D300`<2P0A4@l01P@500`92P0F51D00`0000804@d>
00P040`=01DA4P0?2``03PX;01HB4`0810D040h?00h<3@<03@/<00l03P`=010>3`0P7Ql061HG014?
400C4A803`d>018B4P0G5aL03@d=07inOP0J6QX07AdM01<C4`0>3Ph00P0:2PX03P0<30`03@d=00X8
2@0=2``030X;010>3`0;2@X04@l@00T7200?3@h040h?00h<3@0<2P/03@`;0P0?3P`02@0A40h04Q4?
00h=2`0?3P`01`H400H50`0G5Q@020L500h=2`0600d<2P0700`;2@0;2PP03@`:00l>300>3@/03@`:
00`;2@0200P81P1300`<2P0?3`d030/900`;2@0>3@/040`;018>3@0A3@`03`T900L3000=2@H04`l<
00`81@091@803@T600l;200@30T04@d:00h:1`0=2@H03`/801LC4P0>2PT04@d<01@@3`0<20L04Ph=
01XF5@0@30/04Ph=00`81`0;1`H03PX900T7200@3Pl03@/<01DC500<2P/0?C/l01<A4P0I5aP03@/<
01DC500;2@X03@/;00d<200D4`l05A@@00d<200;2PP04A0>00T7200?3@h06aTJ010>3`091`P04@l@
05mMGP0B41406QPI01TG600>30d03`d>018@4@0@3Pl03P`=00d;300200`:2`0600h<3@0<2P/02@L8
014?400E4a@01P@50P0<2P/02P0200406QPI00`:2`0R82403P`?00l=400>30l03@/>00h<3`0@3Q42
00h<3`0800`:3@0>30l03@/>00P62@0?3`l04A4A01HF5P0C4a<200d;300900`:2`0B3Pl04@d>00`8
2@0=1`T03`T;00/7200=2@X03PX;00<040`=1P0=2@X01P0>30d040h?00h<3@0@3Pl03`d>00`:2`D0
3P`=00d03@d@00T<4@0L7B40<C8f01hO8`0B41<03P/<00d9200F4@h0614?00T1000=1@804`h<00D0
3P`=01l02`T:01@B4`0C4A806aTJ00T720081PL030T:00`82@0B3Pl03PX;010<3@0D4Q<03P`=010>
3`0?3`l03@d=00840`0D5AD05aDH00400P0?3A002`T<00400P0E4aH07adP0:f[[P1;BD`02@L:00l=
400B41<04a4D008040hA01P02@L:01LE600Y9bX04a4D00400P0?3A007Q`O00H41`0=2`h05A<D00/9
2P0?3@h04Q0A01TG600B414061HG00/92P0=2``05aDF01@B4`0J61T01@<4018@4@0?3@h201LE5P03
01@B4`0B41404a4B00804a4B0P0D4Q<01@0C4A804@l@018@4@0E4a@05Q@E00804Q0A01@05A<D00d;
300?3@h05Q@E00l=3P0D51@061PH01<C4`0=3@d03Ph>01PH600?3`l07AdM01@D500C4a<0410@01HF
5P0I6AT061PH00/;2`80410@00L04A4A01hN7P0410@07QhN018B4P0[:b/03`l?00H051DG00L092DW
03<d=P0I6Q`06Q/M01HG6@0E5QP061TM00804a@H01H05aPL01@E6@0@4AD07QlS01@E6@0M7R804a@H
01HG6`0L7b@05Q`U02L^>01MI6h0QhjH02H]=`0J8B/02Q4K01PO:@0R:C<04QTS00T@6P0A5ah07R<W
0P0I7R801P0O92P0:Bhb01TN8P0P9BT092T]020U:@808BHZ01P06b4V01HO900D7B805b0U01`U:P0N
9b`08R/`01hW;00H8BH06b@Y01hW;00K92T07BDY01TQ900C6ah05alR01TQ900H82<05QhQ01/S9P0I
8B@05alR01/S9P0L92L201PO9@0?01@K8@0E7B0072@W01@L7`0K8bD05AdO01DN7@0G81l04a`K018I
6@0E6A`05a/N01XN8@0K7b806AdP00<05QXM01807B4T01`P8`0D61/04QHI01PI7P0J6b005QLL01<D
6@0H6Ah05AHK00h?500N7b@05aPM01<D6@0G61d07QlS01HJ6`0F6QX201DI6P0:01@H6P0D61/04ADH
01LK7`0E61d03a8G01PK800=3Q<07A/P01/H6`8061HI00T05ADG014B500G6a`07b@U02X`<00F7ah0
3QLF010F5P0E6AX00P0F5aT02P0G61X06AXL01TJ700L7Al04a@F01PI6`0J6ad04A8D010A5@0L7B<2
01TJ7`0F01`M800L7Al06adL01PI6`0F5aT061TM01/L8@0D51`03PlD01DI6`0F61L051HE018D400F
5a8061TC01<D3`0J6AD05QDC00l=3P0G4QH07Q`O01@B6@805A@I02L04a8G018@4`0C4A@05A<F01LC
500E4A804`l@01D?4@0F4Q@04Q0C00l=400=2`h03P`?014?4P0B3a802`H:01`G6`0c;S802`T<00H1
1@0J5AP050h@010:300C3@l05@lA018<3P0?2@/04`d?01H@4P0C3@l03PP:00d72@0?2@X05a4A00X4
100D3Ph0100001@>3P0A2`/00P0>20P03`0=1`L03PP800h8200B2P/04@L800l51P0D2P/05@/<00h4
1@0=0`@04PP900l61`0N51D03P@501D;300201052@804@H:02004PL;01<8300>0`L040D900h31`0E
2Ph040D900l4200?10X03@8800`11`0A1P`060dC02<H7P0A1P`040D;00h32@0=0PP03P<90146300F
2`l02P0301L<400>0`L040D900l4200F2`l0304501H;3`0J3a<03`@800d21P803`<70P0@10P20145
2@060104200?0`L03P8600h21P0?0`L040@85?ooool001_ooooo00<02@T900X;200?3`d00P0>3P`0
1`0A4@l0<S4]04E4@00Q81`051<?00`;200100000P0=30P01@0>3@T03`h:014@300A40`02`X600<0
4a8>00`030/700@3000@3`/03Pd9010?2`0=30P04A0<00/:1P081`<01`H200T8100<2`L2010?2`H0
3`h:00@040l;00l>2P0?3PX03`h:0P0>3@T04P082@D010D002HW8P0E5Q408B8M00P910092PD03@h9
00h?2P0<3@P03a0;01<C3P0510005A@?00l>2@0K6QD051<>014@2`8040l:00T03@`700l>2@0?3PT0
3`l900X;1@0310001PL100d>20082@<01P0=3PP07P0=3@P04Q4=01@C3`0@3`/04A0<01<B3P0B4@d0
3@`800`;1`0@3`/03Pd900l>2P0C4Ph03Pd900l?2P0B4`h03Q0;018D3`0C5A00418=00`=2P0H6A@0
5QLB01@C3`0@4@`030d800d>2@0@4@`03Pl:010A30803@h9010030d800T:1@0A4Pd092DP014@300>
3@T030/700d<200<2`L02`X600D400061@4030/7018A3@0D4`l04A0<0P0<2`T200h=2`0@00d<2P0<
2`T05QDC00/:200J6AL02`X800L6100K6QP02PX:00h>3P0G5aL0410@00X:2P0D51@03`l?00h>3P80
30`<00@03Ph>00l?3`0=3@/03@d;0P0<30X200h>300?00L71@0<30X05aLE01@D4P0820H030`:01@D
500E5AD04a<C00L51P0H5QL01@<400l;300<20T03PX;00805Q8C00<020@5010>3`0>30d00`0=2``0
4`0>30d04a4B01hL7@0E4a@03`d>010>3`0<2P/030`<010@400Y:BT04A4A01TI6@051@D03@d=00X:
2P092@T02PX:00h>3P0?3`l00P0D4Q<05P0@3Pl04@l@00T7200>30d040h?014?400>30d030X;00d;
300=30/03`h<014@3P0@3`d04a8@01LF500B4@l061LE01/J60071PD03@`:01hM6`0B4@l400h=2`0?
00l>300=30X030/900d<2P0?3P`03Pd;00d<2P0?3P`03@d;00T91`0820H03@d;014@3P0C4Q004A0>
008040`;03404Ph=01<=3@0;1`@04@d:01LC400B3P/03`/8014=2P0?2`P040`9014=2P0>2PL03@T6
00l;200@30/03@T8014=300C3`h04@d<01dI601mNGP0<bl^00d9200I5A@03`/:00X61@0R82400@00
01HD5@010000518C00X92@0200404@l@018@4@091`P04@l@00h<3@0;2PP03`h<00<10P0:20T04Q0B
00X82`0@3Q404@lB00D31P0100803@/<00807A/L00D03`d>00L51P010000518C00L51P0500h<3@0=
00d;300D4Q<04Q0A010>3`0G5AH06QPI00d;30050`@03@/<00l=3P0;2@X04@l@03Hd=@0200h<3`07
00d;3P0<2Pd03P`?00l=400;2@`030X=00X82`0200h<3`0800T72P0>3Ph03`l?01@D500B4Q803P`=
00l=3P0=2``2014=3P0600l;300>20X03`T;00`82@0=2@X03PX;200?2``01`0>2P/02PP900/92P0:
20T03@/<00h<3@0=2``01@0>30d03@0>3a403PlC00/<400C51P03`lA00/9300C41403PX901D?3`0J
5A804`h;01H>300C3`d01@0>30d0?P0@3Pl02`T:00/92P0:20T04@l@01<A4P0A3Pl04Ph?01@@4@07
0`@06ADF01TG60081PL03`l?03Hf=P0C5A@05QPG00/=30092@/061HI01@B5@0b<3<05aDH00/9300B
41<04a4D01HD5`0E4aH01@<6010>4@0<2Pd01`D800l=400>30l0518E01TG6P0@3Q405Q@G010>4@02
00<02@L:01HD5`0?3@h081hO01@B4`0J61T03P`=04U7B00X9RL06aTJ01DC500G5AH040h?018@4@0K
6AX06ALH00/92P0C4A805A<D018@4@0@3Pl04Q0A0`0C4A806P0B41404@l@018@4@0E4a@061HG01HD
5@0@3Pl0;B//01/I6P0E4a@061HG01@B4`0=2``05ADE01hN7P0O7al061PH00l?3`0;2`/07QhN01PH
600@410061PH010@400:2PX04Q8B0P0P82002@0C4a<051@D01TI6@0G5aL07QhN01LG5`0>3Ph0820P
010@400601@E5`0701hO8@0Z:bd05aPJ01XK7@0F5aT05aPJ01LH700301TJ7P0Q01XK7`0L7B405AHJ
01<D600L7B405aPL01`M8@0M82D07b@^01DL9P2^]K`0dm[T03a3C@0D6bD09B`f02<Z=00B6B<0<CQ2
030g@@0G7B@0;c@h020U:@0F6al0724U02/`=00M8RH082DY028W:`0O92P08BHZ028W:`0N9RX072DZ
00806B8W00<06R<X01/T:@0K92T00P0J8bP301`U:P0301hV:P0K8bH05alR00806b<V01T06R8U01TQ
900I8B@06R8U01/S9P0M9BP08BT/00lF700I82H06R4W01PP8`0D71l06b<V020X:P0L92H06R<R01LP
7`0D7A`06R<R01/O8P0L82<07B4T01`P8`0I7B0051PK00807B4T0180720S01hR9@0O8bH07R8U01DF
6`0G61d04a@I014B5`0D5AX04Q<H01/L8@0<3A80:R/`00D62`0J6b004Q<G01PL7@0H71`201LK7009
01LK7@0F6Qd04aLJ01PK7`0G6Ql04aHK024T:@0K72005Q@I00805Q@G00/05aDH01LH6P0I6Q`04QHG
02T];P1cNGT02a4A028Z:@0B61P05a/L01PI6`0301LH6P0S01PI6`0W:2X05aPJ01<D5P0G61X06AXL
01dN8P0J6b0061TN01LH7@0I6Qh061TK01LH6P0L7Al06Q/O01`M8@0O82D061TN018C600E6AX05QPG
01@F5@0B51405QHD01PI500G61<06QTG01HE4`0?3@h050lC01PF6@0E4aT051<H01<B5`0B4AH00P0C
4A@06`0?3A004`l@01@@4@0E4A806Q@F01XG6@0F51L04a4D00l=400=2`h03P`?01HB5P0@2`l02PD9
01@?4`0@2`l03`X>01H@4`0C3@l03`T;014;3@0D3Q004@/=00l92`0B30h05@lA01<=3`0200h82P07
00h82@0@2PX01000014;2`090`<05Q0@014;2`0200h8200500d71`0>20P03PP801082@0@1PL00P0A
1`P0200@1PL03P@500L0000O5AH03P@50147200:00404@L80P0?10P301462P0>01052@0D2@d04`P<
01872`0?10P03P<700d21P0?10X03P<900`11`0?10X050T?01/@5P0@1@/200l42P0?00h32@0?10X0
40D;00X00`0700002P4301L<400C20`01`0001T>4P0@1@T06@hB01dB5P0C20`04@H:00804PH:00H0
4@D90104200@10P03`<70104200?0`L200h21P0300l31`0@10Sooooo01?ooooo000Kooooo`0?01TH
5@0?3`X092<O01@C3`0C4Ph03`h:00<2000G5Q802PT500h=2@0D4`l05QDA00/:1P0>3@T03`h:0080
40l;01<03`h:014@300A40`030/700h=2@0C4Ph051<?00l>2P0=30P040l;00d<200B4@d030/7028Q
7@0@3`/030/7014@300D4`l030/700H03`h:00<03Pd900l>2P0?3PX00P0@3`/05P0@40`04Q@?03Xl
=`33aL00DE=>01@F4@0E5a803a4<010B3@0<3PT0418=02`^:@0W9b8030/601DD3`0:2@@05QD@01@C
3P0<2`H04Q4<014@2`0>3@P200l>2@07010@2P0<3@P0414;00h?2@0V9b400@80010A2`0500h?2@09
00/;1P0>3@T04A0<014@300D4`l04a8>010?2`0<2`L02`X600803`h:00l04A0<01LD4@0A3`/03Ph9
00`=20092`H0310;00X?2@0C61802`d800X:200:2@D04a4=00d=2@0:2`H00P0>3`X00`0;30L03@h9
00`=200200h?2P0C00`=200B4`h09RLR018A3@0A40`03Pd900d<200?3PX03@`801DD400G5Q806APD
01@C3`0?3PX03Pd900/:200<2`T03Pd;00l>3003010?3@0300/:2@0@3`d03Pd;00804A0>00H0IVAU
01<A4P0@3Pl05A<D01`J6`0C4A8200l=3P8040h?0P0?3@h200l?3@0300d=2`0<30X03@d;00803@d;
01<03Ph<01/K6@0H61H02PX8010A3`0<3`l02`d?014D5@0<3Q002`/=01<C5@0=30l01PD800/9300<
2Pd02PP;01<A500@3Pl03P`=00<03@/<02003P`=01HD5@0F51D03`d>00h<3@0=2``020H700l?3`0C
4a<0E5AD00d=3@0E5AD03Ph>01<C4`0@41003`l?010@400B4Q804a<C01@B4`0C4A803`d>010>3`08
1PL03P`=014?400?3@h03@/<00l=3P0C4A805Q@E00l=3P802`T:00X030X;00d;300@3Pl02@L800`:
2`0A3a003`d>00X82@0B4A004A0>0`0?3P`0100@3`d03Pd;00d<2P0=30X300l>300P00`<2P0:2PP0
30`:018B400C4a404A0>01@C4@0F5A<04`l>018>3@0E4A006A<C00`81@0?2`P04Ph;010<2@0?2`P0
40`900l;200@30T04@d:00h:1`0=2@H03`/800h:2P0@30d03`/<00d92P0?2``06ADF01`I6@0>2P/2
010<3@0N01@@4@0@3@h04@lB01LG6@14A4H03@d?00T92`0>3Q004A4C00@41P0?3a404Q8D00l?4@0<
30d03@d=00X:2`0J6Ad02`/>010?500=3A802@P?018A5P0<2`l03Ph@014A4P0;2`/05aLG00P8200E
5AD04a<C0P0<30`0300:2PX03@d=00l?3`0@41003Ph>00`<300@3Q403@/>00`:3@0@3Q404Q0C00/9
30804a4D00P030X=00@21@0C4A@02@L:00l=400=2`h02`T<00d;3P803P`?01<03@/>00l=400>30l0
518E01HD5`0A3a80410@00h>3P0A4A403`l?00h<3@0A3a003`d>00h:2`0@30d04@d>010:300=1`T0
40`=00@03`/<00<03PX;010<3@0B3Pl00P0C3a002`0@30d03`/<00h=2`0?3P`030/900l>300C4Q00
4A0>010?3@0?3P`03Pd;00803@`:00d02PT:00`<3@0=30h03`l@014@4P0=2`d03@/<00L61@0:1`L0
40d<01<@3`0E41003P/<00D03P`=010030X;01<A4P17ADH07Q`M018@4@0<2P/04@h?018>3`0?2``0
4Pl@04I4A@13@D8040l@01@D502?T8l0@4910P0=3`h03@0<30h04A4C018B500O7b4061PJ00l?4@0B
4Q@04a<E00l?4@0=3@l05aLI02XZ;00V92L00P0>30l0800B41<03`d@00l=400<2`d05Q@G00d<3P0M
6ah05aDH00l=400H5QL020L701DC500610D02`T:020N7`0M6a`04a4B00h<3@0@3Pl03`d>01<A4P1G
EEH0>3Hg00l=3P0>30d04@l@01DC500=2``040h?01<A4P0D4Q<04Q0A0P0?3@h0200C4A805aDF01TG
600E4a@03`d>01dK700<2P/03`d>0P0F51D06@0H5aP03Ph>014C4P0H6QT071hM01dO7P0J71/07AlN
01@F5@0=3`h0418A01<E500`<S4092@T01@D500U9BD04a<C018B4P0A4A406a/K01PH600F5QH05aLG
010@400E5AD00P0D5AL301DF60805QLI02806a`N01HG6@0J6ad061TK01XK7@0J6al07QlS01`M8@0I
6Qh06Q/O01dN8P0G61`06Q/O01TJ7P0F5a/06a`P014D6@0W;C@09Rde0499D@1lPh/0<cY201`S:`0C
6R80:C0h07=jPP0P9bl06B0X020V;00_=3P08BHZ01/P900M8RH0:2da0P0O92P201`Q9@07024V:P0P
9BT07bL[024Z;`0O:2d06b@Y01TR9`0201XS:00601`U:P0N9b`07BH[01/T:@0L9BX07BDY0P0I8B@0
100L92L06R8U020X:`0R:Rd201PP8`0Y01/S9P0E7B006b<V01HM8`0M92X05A`R01dU:00>5QT05AdP
01<K7@0D71h06b@S01XS8P0E7Qd05b0O01PL7`0I7B006alR01XN8@0H71l05ATL01@H6`0I7B006alR
02<W:P0[;c806QhQ01LJ7`0I724061/P01DH7@0F6Ah051LL018E6P0J7B8061/P01DH7@0N8BH07R8U
01LK700G6aX00P0F6QT05P0F6QX05ATJ01PL7`0I7B0061`O01@G700Q92T071lR01/K7P0L7Al05aLI
018B500C4aD06AXL01@E5`0K7Al0:Bd^01TK7@0K7b00828T01TJ700H6A/401HG6@0J028S9@0H6A/0
5AHH01PI6`0I6Q`06a`N01LK7@0D61/05ATL01HJ7@0E6AX04aLH01PL7@0F6Qd061`O01XN800E6A`0
4ADG01DI600F61L051HE018D4`0F5QD061PF01HF5@0E4a@201<A4P0601HB4`0E4aH05Q@J018A5P0A
41D04Q4F0P0E4aH06@0@3Q40510A01@@4@0E4A806A<E01PE5P0C4a<04a4B014?400?3@h040`=00d9
2P0@30d05@lA018<3P0G4A<050d?00l92`0A2`d03`T;014;3@0C3@l04P`>010:300A2`d00P0B30h2
014;3@06018<3@0B30`02`D5014;2`0=1`L04@/;0`0>20P04@0=1`L03PP800h8200?1`L040H70188
2@0@1PL03`D601061`0I3a00AS`m024G600C2@X03`D601061`0A1`P04PP9008050X;00T04PP90106
1`0A1`P0308301D;3008000060h?01`B500?10X00P0>0`T200d2200300l42P0>0`T03`@:00804@H<
00h040D;00l42P0?1PP04PL;00l5200B1`/03P@701062@0B1`/0304501<8300E2Ph03P<700`21@80
50P<00H04PH:01452@0@10P03`<701452@0@10P200l31`030104200A1@Wooooo01?ooooo000Koooo
o`8040d801@06aPC00/80`0M6aH03`h901TH500H5a<02`X601<B3P0D4`l03@`8014@300?3PX03@`8
00h=2@0@3`/04a8>00`;1`0A40`04a8>00`;1`801PD100`02`X600d<200A40`03`h:018A3@0:2@D0
7ahJ00X91@071P8040l;01HE4@0=30P600l>2P803Pd900P03`h:010?2`0@3`/0414<00d?2P0;3@P0
AdU401`N6@802P`700l01@L3010B3@0B50l030h900H80`0:2`H02@P300/:1@0A40/03`h901DD3`0>
3@P04Q4<014@2`0>3@P00P0@3`X02@0C4`h03@h800/<1P0M7QP0HV=M028S7@0=3PP02``600`=1`03
00d>200V014A300A40`03`h:01HE4@0P7a/06QTE014@300>3@T03@`800l>2P0=30P03Pd900d;1`0A
3@X03`l;010A300G6A@03Q<=010E3`000P00:bdX05iMF@0E51001`@300X91@0@4@`06a`G01DF4@0<
3@P0414<00h?2P0=3PT03Pl:00d>2@0:2`H010D100h=2@0@3`/200d<200<018A3@0@3`/030/7010?
2`0C4Ph03`h:00d<200@3`/030/900d<2P0?3P`040l=0P0A40h0100=30X04a8@00T81P0920H200l>
300702HT9@081PL040h?00@20`0@3Pl00`4200`:2`0400h<3@0400`:2`0?3`d03`l=00d=2`<030`:
01@020P6014A3`0820H010@200/;2@092`P01@/;00`B4P0010@0318B00/?40062P/030l@00P92`0C
4aD06ATK00T92`0H61X040h?00h<3@<03@/<00@03P`=018@4@0>30d02`T:0P0?3@h02`0;2@X02PX:
01LG5`051@D0;Bd]00`<300410@0410@00d=3@0<30`02`/;008030`<0P0<2P/01@091`P03@/<00T7
200@3Pl02`T:00803@/<00P03`d>018@4@0;2PX02@L801@B4`0G5AH030X;00h<3@<04Q0A00H01`D6
01/I6P0100002PT8010?3@0>3@/200d<2P0500h=2`0?3P`03@`:00d<2P0>3@/00P0?3P`05@0?3`d0
3@d;014A3`0Q8Al08b<Q01DD4P0;2PP030/900`81`0=2@P03PX900h8200C3``04@d:00l;200@30T0
4Ph;01@@3@0>2PL03`/8010<2@0200h:1`0H010<2@0<20T02`L800d92P0C3a005a<D01PD5@0Q7Ah0
2PH701TE5P0M6AX02PH700/82@040PD03`lA010@4P0F5QP02PX<00l?4@0D51H061PJ028R900P8280
2`/=0P092@/06@0L6al01@@901/J800=31@04a8J01<A70081`h04A0E02<S9@0@414030`<00H61P0G
5aL03@d=00P8200=3@d03`l?00d=3@0?3`l0410@00l?3`0<30`020P800l=400=2`h00P0>30l01P0=
2`h03P`?00d;3P1?CE000@0201lM80803@/>00L03`d@00`:3@0<2Pd03`d@00h<3`0<2Pd03P`?0080
40hA01405aDH01TG6P0D4QD04Q8B00h>3P0?3`l02`/;00X82@0=2``03P`=00d92P0>2P/04@d>00l9
2`0;1@L04Ph?010<3@0400h:2`0<00l;300@30d04@d>014=3P0?2``03PX;00l>300@3`d02`X800X9
1`0=30X03Pd;0P0?3P`03`0>3@/03@`:00d<2P0?3P`02PT7010<3@081PD02PP901<A4P0?3@h02PP9
00/92P0=30d020P800`:3@0600h<3@09014?400100007adN00L61P0M6a`03@/<00T8200I5aP081hO
00803`d>03<05ADE01<C4`0G5aL04aDD00H:2@0Q9B@07R4P00T92`0@41807AdO00@41P020P@04A4C
00@41P0=3@l030`>02@T9P071`T0D51B03@b=@0F51L030X=010>4@0?3A004a4D01lM80010080<Blb
08f;SP0V92L03@/>00<10P0L6Q/03P`=01@B4`0C4A804@l@028P8@0K6AX0518C010>3`0>30d040h?
00T7200?3@h04@l@01XH6@0C4A804Q0A00/92P0?3@h00P0C4A809P0A3a003@/<010>3`0B41404a4B
018@4@0A3a0040h?01<A4P0V92D06ALH00h<3@0E4a@051@D01PH600?4A0030h=014C4P0F61L05ALF
00d?3P0D5QD04aDD00h@3`0D5QD0AdU803<c<`0<30`07alO01<C4`0F5QH04A4A03Lg=`0:2PX0410@
00`<300R8R80410@0P0D5AL00`0E5QP05QLI01HG6@0301LH6P0501XK7@0I6Q`06Q/M01TJ700K7200
0P0H6Ad07P0I6Qh05aPL01DF6P0H6Ad07QlS01/L800P8BD0<34e02<V:`0N9R`04AXO01<L8@0h@DH0
5b0U014J7`0C7240;SLl07^4R@0B6b003AHK014G700I7R804QLK01TN8P0K82@08BHZ01XO8`0K82@0
5a`P01TN8P80724U02H06B4U01TT:P0K9R`06bH/01XU:`0L9bd09S4g02D`=P0M:2h06RD[01`W;@0K
9R`07RHZ01dU:00K8bH07RHY020X:`0]=CP0;SHi024Y;00P:2/08b/^01XR9@0M9BP04a`Q01PQ9P0B
6b007RPZ01LQ8`0Q:bd08B//01/U9P0K9B@082XY01`V9@0E7ah05AXM01LK7P8061`O01H05a/N01HJ
7@0F6Qd07b<V024U:00X;2l0;c<f01LK7P0E61d05QTP01PK8P0E61l04QDL01<F7@0J7B@02PdD02HY
<00=41L06QdT03@g?00F6QT05QXH0P0E6AP0500D61P051PI01LK700G6ad06AdP018F6@0F6Qd03a<F
010D5@0F6AX05ATJ01DF600K71h09bPZ01`M7`0D5AL0824S01DE5`0H6A/051DG0P0B4aD01P0C51H0
51DG01HG6@0G61X051DG01LH6P806AXL00P05AHH014B500F6QX05QXK01PL7@0L82406alP01TM7P80
6QhO01d06alP01`P800I7Ah05a/J01DI600F61L051HE018D4`0F5QH061PH01<C500A3a004Q0A01DC
500G4a@0518E01HD6P0@3a@03`hC01<B5`0F51L05A<F01@B5@0F4Q<0510A018>3`0C3@l04@h?00h>
3P0300l=3P04014=3P0H4a@06Q@F01D<3`803PD800<05@X>01L@4P0D3Q000P0B30h201<=3`0;014;
3@0?2@/03`T;014;3@0B30h04`d?00l92P0;1@D040X:00l92@0C3@d00P0B30`200h8200?00d71`0>
20P03PP8018:2P0A1`P040H701D;300F30d04@L800L0000U6a`03PD501@:2`0=0`@03`D600804PP9
0P0C2@X02P0A1`P03`D601882@0<0P<06@l@00`20`0Q5aP09adN00d2200>0`T201052`0400h32@0=
0PP03@8800h32@804@H<00D040D;00h32@0<0@D06a0D00l4200200d21P0701T>4P0B1`/040D901<8
300D2@d040D900l4200801452@803`<70P0A1@TDooooo`006oooool03P0?30L0514<018?2P071000
61HA00/:1@081`<02@P500/:1P0F5A404A0<00L60P0C4Ph040l;0P0=30P0100A40`051<?00l>2P0@
3`/201<B3P0>01PG4`0P7a/03`h:010?2`0C4Ph040l;018A3@0:2@D051<?00L60P061@4030/7014@
300;2PH600l>2P0H00h=2@0?3PX03`h:00l>2P0@3`/03a0;00/=200F61<05aTD01XL5`0>40/01`T4
00d?2P082PD01`T400d?2P0H6QD06AXE010?2P0920<04A0;00L60@0B4@`030/60P0A40/03@0>3@P0
4A0;014@2`0;2`H030d700/<1P041@40;BhX00`=1`082@<02P/500/<1P0<3@L00P0=3PP01`0A4@`0
40l;00`;1`0C4Ph07QdI01LF4P0?3PX00P0>3@T08`0A40`03@`800`;1`0?3@T03`/800/;1P0D5A00
6A/F0045000D6A<02a0:010B3@0P7a/00@0001DA3P0920@03a0;01XK5P0D5A002``700h?2P0<3@P0
2@X500X;1P0B4`h05QLB01@E400=30P04A0<00`;1`0:2@D04A0<00d<200920@02`X600<03Pd900@0
40l;00X91`0;2PP03@`:0`0>3@/00`0<2`T05aHD00/:200200`;2@0600h=2`030@804a4B01/I6P09
1`P04Q0A1`0=2``200h>308030`:0P0=3@/050061P@05aLE00`<2P0820H04A4?00H81`0A5aL0CeQG
01DN7@0740l03Q@D00lE5@0<41401@H801PI6`0c<cD04A4C010@4P0@3Pl03P`=0`0=2``03@0>30d0
3`d>00d;300=2``03`d>010>3`0?3@h03`l?00H61P0O7al06ATI01LG5`0>3Ph00P0;2`/03@0<30`0
3Ph>00l?3`0@41003`d>00h<3@0:20T03@/<00T7200A3a0030X;00l=3P0>30d00P0<2P/03`0@3Pl0
4Q0A00d;30030@807A/L05iLG@1EDe@02PP9010>3`0<2P/05aDF0040000I61L04A0>00h=2`0200`;
2@0300h=2`0?3P`03Pd;00803Pd;01L03`h<010?3@0B4Q003@d;00X:200D51806QXH018A3`0;2PP0
30/900l;2P0A3@`040`;00d71`0A3@X03PX700d91P0A3@X04`l<014=2P0=2@H03`/8010<2@0200h:
1`0U010<2@0B3Pl02`L800d92P0A3@h030P9010<3@0H51D01P8300T51P0>2P/040`=01@A4P0>30l0
2PX<01LG6@051@L05ADG010@4P0>3Q0061PJ07emO`2?Si408R8T00X:300@41801PD901<B60020@T0
CD]F02DS;P0;2A@03@/E02TX;P0o?T<05aLH00d=3@0201@D500400L71`0@41003Ph>00H61P<03`l?
02T03Ph>00/;2`0820P040hA00h<3`0@3Q403P`?00`:3@0A3a804Q0C01`J7@0I5aX00@02055?DP0T
8RD03`d@00d;3P0>30l04Q0C00h<3`0:20/030X=00h<3`0=2`h04a4D01@B5@0?3A004A4A00d=3@0>
3Ph02`/;00T7200<2P/03`d>00l;300@30d04@d>010:300>20X04`l@010<3@0200h:2`0300l;300@
30d03PX;00D03PX;00D04A0>01@C4@0>3@/02`X800d<2P0600h=2`0=010=300?2`X050h>018>3@0<
20L03PX;010>3`0;2@X030`>01HF60061PP01@D700h=3P0500h<3@0?00l=3P081PL08R0Q00T8200C
4A805A<D01TG600200400@0000h<3@0J61T051@D00820P0B4Q803@l>00801@T800/04QHE00`<3P0D
51H020P:03/k?@0i>C/04A4C01<C5@0H61X051@F0082100200`<3P0301hL7`0;2@`030X=008040hA
01404@lB01DC5P040PD01@<602HT9`0610L03@/>01<A4P0J61T0518C01PF5`071@H040h?01lM7P0L
6Q/05aDF018@4@02010>3`0801<A4P0G5AH05aDF01/I6P0?3@h04Q0A00d;300?3@h2018@4@05014?
400?3@h04@l@01<A4P0B41400P0@3Pl0600B41405Q@E03<a<P0O7Ah03P`=01@B4`0?3`l051HE014C
4P0@4Q404A<B010B4@0:30/03Q0?01<E500G6AP06Q`K014C4P0P8R406QXJ010@400L71`03Ph>01@D
508061PH00H07alO07YjNP12@T808B4Q01PH600D5AL201DF60<05aPJ02H06AXL01/L7P0M7R0061TK
01hO8@0G61X06Q/O01DF6P0H6Ad07QlS01`M8@0I6Qh06Q/O01dN8P0J6al071dQ02TZ;P0O8bH051`P
020Y;P0M9R/05QlT01<L8@0S;34082T^014J7`0Q:Rl04Q/P02D^<`0K8RL08BHZ01HK7`0L8BD07b@X
02P]<@0O92P06QlS01LL80<06AhR00<05b0U01LR:00K9R`00P0K9R`03P0O:S00:cHl02Pc>@0M:2h0
6B@Z01hY;`0M:2h07RL/01/S9P0H82<06b<V01hV:@0X<3<09Rha0P0M9BP0300R:Rd07RHY01dU:00@
6Ah06B8W01dV:`0A6ad04adO01/U9`0d?Sl09Bl`01LQ80806B<R00H05R0O01dR9@0M8B@07B4T01XN
8@0H71l201LK7P0C01/O8P0F6Qd051PK01TM800B5QT05aXQ01PK8P0L7bH061/R01<F7@0E61l092L^
0454B`0<3aH01`XA01`O9P0@4aP061`K01PM6P0201LK6P0=01LK6`0F6Q/05ATJ01DI6`0K7b805ATL
01LK7P0A5AP04aLH01DJ6`0E6AX051PI01XM7P02028S9@0501DF600X:2X0410B01/K7@0@41800P0A
4Q@0400B4aD051DG01LH6P0I6Q`061TK01XK7@0E5QP05aPJ01XK7@0H6A/05QXI01LK6P0J7Qd07B4R
01/O800I7Ah201PL7@806AdL0P0G6aX09`0E6AP05QPG01@F5@0B51<05QHH01PH6P0F5QP0518C01<A
4P0D4Q<04`l@00l=400E4aT03`hC010?500E51T05Q@G01@B5@0B41<0510A01<?400B3Pl050h@01@A
4P0A4A404@l@00l=3P0>30d04@d>02DP8P0Q6ad040L:01L>4@0J4A@05``@01L>4@0E3a4050h@01<=
3`03018<3P03010:300>20X040X<00804`d?00H04P`=00h8200E3`l03PP801D?3`0;1@D300h8200@
00d71`0>20P03PP8018:2`0A1`P040H701L=3P0I3a004PP900P0000A1`P02P4201<92P0=0`@04@L8
01061`803`D60`0>10D0200D2P/03`D601@:2`0800004`T:01@:2`0>0`L03`@:0`0A1P`00`0?10X0
3P<900l42P0201052`803`@:00H02`0401D:3P0:0@<03`@801H=3`0<0@D201872`0401<8300B1`/0
4@H:01052@803`<70P0@10P401452@8040@80P0A1@TDooooo`006oooool0300C3PT04`l901<@2P0C
40/03@X5018?2P0E51005A@A018A3@0C4Ph030`800l@2`D03`h:00d03Pd9014@300=30P03`h:018A
3@0P7a/0;RdY01DD4@0@40d04Q8=01<B3P0N7AT06QTD00<04A0<00<03Pd900d<200?3PX01P0?3PX0
2`0A40`040l;00l>2P0?3PX03Pd900d>2@0<3`T02@`700`?2P0O8ad020X60080310:00X03a<=00hB
300:3@P01`/600X<200G5Q403@`700l>2@0G5Q40:bXU0`0@3`X02P0?3PT04a8=01@C3P0@40/0414;
00h?2`0?40/01PL200`=1`0A4P`200`=1`0700h?2@0?40X0414;00h>2@0?3PX03Pd900`;1`02010?
2`0J00d<200;2PH03Pd901@C3`0@3`/03Pd901LE4@0@30T03Ph:010@3@0=3`X0<SPb08F;Q@1BEe40
3a4<00h=2P0B4@d03PX8018A3@0<3@P03Pl:014B3@0>3`X02``700l@2`0>3`X200`=200;00l@2`0E
5Q402`X6014@300?3PX040l;01XI5@0H5a<051<?014@300?3PX00P0@3`/00`0<2`L03Pd;00h=2`02
00l>300:00h=2`0=30X030/901@C4@0>3@/05QDC00`;2@0=30X04@d>01<?408030P90P0>2P/01P0C
3a004@d>00h:2`0>2P/04@d>014?40803@d;01P030`:00d=2`0?3`d03`l=010@3P0D51804A4?00d=
2`0>3P`03a4@01TP801nR8P05R0P00H?3`0P:2T01Pd>00`A4`052@/01`X<01/L7`061PT0410B010>
3`0>30d300d;30803P`=00/03`d>014?400?3@h03`d>014?400D51@04A4A00@4100F5QH04a<C014A
4@0200d=3@0N00h>3P0?3`l03`l?010@400?3@h03P`=00X82@0>30d02`T:01<A4P0=2``03P`=00d;
300;2@X03@/<00l=3P0<2P/03P`=010>3`081PL030X;01LE5P091`P05Q@E00/92P0;2PX04Q0A040o
?P0D4a404A0>0P0>3@/00`0@3`d04A0>00l>300200h=2`0;00l>300A40h04A4?00h>300<30X02@T7
00X:200=30X03`h<00h=2`0?2`X00P0A3@`01P0?2@T02`L400/7100B3P/06aLD01XF4`803@T600L0
3PX7010<2@0>2PL03PX7014=2`0C3`l02PH600804`l@02H020D402HR8P0L61T04`l?018>3P0<20T0
4@d=00l<3@0<2Pd04a<F00T93@0:2@h04A0D00/;3`0<2Pl030/?020O8`0A41D02PT=00d<4@0A41D0
2PT>01HE700>3AD0P7j:02LU<P0>31P05Q@N010?5@0L6b002@T:01@D500A4A40De=C02`/;00B4Q80
3Ph>014A4@803Ph>0`0=3@d03@0=3@h04Q0C010>4`0B41D03P`A00/93P0D4QL06QPM00h<4@0<2Pl0
4Q0E02l]<P0B41D00P0>30l01`0C4Q@05QDH00h=40071PT03Pd@00l>400=30h00P0@3Q40<@0:2@`0
2`/<00X:2`0>3`h03@d>00`;300?3Ph04A0A01DB500E4Q<04@h@018=400D3a004Ph?00l;300>2P/0
3`/<014=3P0B3Pl04@d>00h:2`0<20T03@T:010<3@0A3@h03`h;01HE4@0A40`03Pd900l>2P0>3@T0
30/700d<200?3PX040l;014@300>2@H06A@A00/5100E3`d05A4?00L30P0W92D040hA01@C5`0d=3P0
61TM00P93@0@41<01`0>30d08@091`P03P`=00d;300<2P/040h?00`:2`0?3@h03`h>00`<300?3`l0
3Pl>00/=300<3Pd041<B00<5100A51<03`lA00H6200C4aD0AdM903lo@@0;2`d051@F00@41P0B4Q@0
2`/=01@D5P0>3Q004Q0C00l=400D4QD030X=010>4@0201<A50804Q0C00d03P`?01<A500C4A@0:RPZ
03Le=`0C4A805Q@F010>3`0D4Q<040h?018@4@0C4A8040h?00804Q0A00@03`d>00h<3@0C4A807adN
0P0E4a@2010>3`0<014?400B41404Q0A018@4@0A3a005aDF01TG600F51D04a4B018@4@0E4a@061HG
0P0B41404@0G5AH04a<C01<E500A5A@041@C010C4P0?4a803A4@014D4`0F6AP04QHE01XM700@51<0
2P`;01<D4`0D51@0410@008051@D0P0C4a<0A@0N7Qh0LW9b03lo?`0Q8B406QXJ01@F5P0E5aL05QLH
01LH6P0H6A/06AXL01TK700P8b@071lP01@F600S9BL05API01TK7`0K72006A`O01TJ7P0J6al06QdP
01/M800M7R807R4T01PJ7@0J6al04QHI01PQ900E7R404adO014K7@0Q:bd05R0R010J700D7R005b4S
01XT9P0H8BD06B4T028W:`0F6al07R<W01lT:00W;3007R<W01`Q9@0M8RH07R<W01LL800I7R8072@Z
01`W;@0P:c407bX`01/V;00N:Bl092le028]<`0N:Bl06bH/01hY;`0Q;3809Bhc01lX:P0K8bL082P[
01hW:P0201/S9P0A01TR9@0H82<06b<V01`U9`0D71l072DY01<M800O:2`072HX03U3A00F82808R`]
01XT9@0F81l0628Q01LQ800H8B000P0L8B@02P0L82<06QlR01TN8@0I7B007R8U020T9`0Q9BP061`O
01<G6P0H71l201PM8P0=01hS:00J7bD04aPM01HK8@0a=S`0RHjC020U:P0I7R@06QlT01XO8`0G6a/0
5a`I01HK600201HJ6@0901DI6@0I7Ah051PJ01TM800C5aX061`O01HJ7@0F71`051/K008051XJ00T0
51TJ01<G600D5AL051@F014@4P0P7R405Q@G01`J7@0F5QP00P0E5QP04P0F5aT061TK01TJ700F5aT0
6a`N01HG6@0H6A/06a`N01TJ700G71X05Q/I01LM6P0H7Ad051TI010F5P0E6Q/05Q/K01HL6`805AXH
00P05Q/I01DJ5`0F61L051HE018C5@0F5QP061PJ01<C5@805A<F01h04a4B01<@400B4140518H00l>
4`0A4A@05aHK01HD5`0B41<04@lB01@@4@0C3a004Ph?01@?4@0D4A804Q4A010?400A3a005A8C01TE
5P0J5AL050h@01@;3P0N5AP08ALK01P=4@0C2`d05Q0B01D?4@0B30h200h82P0E018<3P0A2`d03PP:
010:300C3@l04P`>01H@4@0=1`L050`=01@=3@0[9BD05a0@01092@0>20P03`P800h71`0>20P03`P8
0108200@1PL04PP900<04`T:01<05@/<01882@0C2@X02`<30147200M4a@04`T801881`0@1PD03`D4
01471P0E2`X040H501471P0@1PD04PP700h4100>10D040D900804@H<01D04PL=0146300@1@/04@H<
01052`0?10X03P<900l42P0A1P/04PL;01052@0D2Pd0@3Di04Xo@`0;0P@03@8600l4200>0`L03045
00d21P0<0@D00P0@10P01P0?0`L03P8600d11@0=0@D04PH:01452@8040@800<04@D901862_ooool0
4oooool001_ooooo01006ADB01hM6@0F5A4020L300`;1`0@3`/03`h:01HE4@0@3`/03@`8010?2`0;
2PH051<A00d<2P081`D06APF0`0?3P`01@0>3@/020L500l>300=30X05QHD008041@C01@04aDB00H6
0`0B4@`05Q<<01<@2@0;20403@X501<B3@0?40/02P/601HF3`0A40/03Ph600h=1`0@3`X04A4900h>
1`0>3@P03Ph600h>1`803Pd800X04a@?0001000>3`X0@44l01HG4P061`803a0;00`=200=3PT0414<
0P0>3`X02P0=3PT02@X500d>2P0L7AP0EUMB01PI500:2`H04Q<>01<D3`0<3@P200l@2`0<00d>2@0<
3@P02``700d>2@0?40/03Pl:00/<1`0<3@P04A8=018C3P0=3PT02`/60P0@3`X0@@0>3@P040l:00h=
200<2`H04A0;01DD3`0K6QD05aHA010?2P0H5a@09RDS014A400@4100BTY804Q:B03SiN@0Ngej020P
7`0I6AT03Ph<014@3`0?3PX02`X600h=2@0;2PH04A0<010?2`0A40`02`X600d<200D4`l04a8>018A
3@0920@05aHB00l>2P0I61@020L3018A3@0>3@T02PT500T8100@3`/04Q4=00X91@0<2`L04A0<010?
2`0<2`L03@`800/:1P0@3`/071/G02l^:P0X9b<04a8>01@C3`0>3@/03`h<010?3@0?3P`03@`:00/:
200A40h040l=00803Pd;0P0?3P`00`0E5A<03@d;00d=2`0200h>300@01<C4@0>3P`0410>014A3`0@
40h04A4?01<C4@031@@06QdL014C4P0B51<030h=00H81`0?4A00418A00l?3`803Ph>00@0410@018A
3`0B4@l040l=0P0=30X01`0>3@/040l=00l>300B4@l02`X80040000?3P`00P0>30d03`0;2@X04a4B
01<A4P081PL01`D600d;300D4Q<02`T:01<A4P0G5AH03Pd;00l>300B4@l03Pd;018A3`0300d<2P0?
00h=2`0=30X03@`:00/:200?3P`02`X800d<2`0=30X01`H400/:200?3P`040l=00d<2P0:2@L02`X8
00803`h<00X03Pd;00l>300A40h03`h<00h=2`0<2`T00@0001<B400f=C<07QdK0P0<2`T0400@30/0
3@/900`81`0=2@P040`;01DA400F4Q403`/:00/71P0:1PD04`l>01@@3`0C3`h03`/:00`81`0=2@P6
010<2`0L00/:200>3@T04a8?014@3P0>3@T04a8?00d<2P0=30P03Pd:00l>300A40`04a8@00/92P07
1@H03`/>00/62P0B414030T;010;3`0:20T05A4D00`72`0D4Q<020D801HC6P0B3aP020D>00L43@80
3P/D00d030T@02dZ<@0J61d05Q@G01<A500D4QD0=CDg0>CTiP1<C4h05ADG00d=3`030`D030`>0080
410B00D03@d?00`<3P0>3Q003`d@00h<3`0200d;3P0S00h<3`0?3A0040hA00l=400F51L061HI02d[
;P0=2`h01PH800d=3`082@/05QPJ00@82@0:41004AHF00<7200720X05aPJ00L72@0@41801@P900`=
4@0A5AH02@X=00L8300C51H03a0C08>4R02?T9806a`O01@E6@0820X03P`=00`:2`0:20T00P0?3@h0
10091`P03`d>00`:2`0<2P/200d;300300`:2`0<2`T03`h<00802`X80P0:2@L500l>300C00l<2`0?
2`X040`;018>3P0?3@h03P`=00l=3P0A3a0040h?00d<3@0<30h03Ph@00h=3`0B41405aDF01@B4`0;
2@X02@L800h<3@02018@4@0N010>3`0=2``02`T:00/92P0D4Q<05Q@E00L61P0?3@h0518C00L51P0K
6a/0;B`/01DE5@051@D03@d=00d=3`0?3a404A4C00d=3`0<30h04A4C00T92`0820X061PJ00L72@0I
6A/030`>00/:3`0B4AH03PdB0P0A41D0100@3a@02`X?00`;400?3Q<3014@5@0600X93P0b<CH030/?
01LF6`061PP04A4C0P0=3@l0:P0A4A405ADE01@D500B41403`d>014=3P0D41405Q8C01DA4P0B3Pl0
40`=01DA4P0D41402@D601HB4`0I5aP04@l@01LG5`0E5AD051@D01DE5@0B4Q803`l?01HF5P0E5AD0
51@D018B4P092@T05QHF01@E500E5aH04a<C00l@3`0B51<05QHF01XK6P0D5QD04a<C01@E500A4a80
51HE01DG5P804A<B00`051HE01DG5P0A4a8051HE01PJ6@0L7Qd05aTH01<E500H6QL071hK01dO700I
7A`201LK6P0a01@I5`0J82004QPH01dS8`0C61/07B8U01PM800J7R405a`O01/O8P0I7B004aPK014E
600R9RT02a0C01TM800M8B@041DH01HM7`0B5aX04a/M01PP8P0H82<0<CXn03Dn@`0K92T05AlS01dX
;00H8bT04a`P02@/;`0>5QT07bLZ00XB5@0S:bh07RHY01dU:00C6ah082P[01hV:@0@61/06b<Z02Tb
>`0J8b`06b@]01dV;`0N9c008BXc020Y<P02024Z<`0D020Y<P0O:3408BXa01/V:P0E7RD05R0T01`W
:`0L9R/07bT[01`W:@0N:BX06bDV02Da<@0F824082X[01DM7`0K8bD08RX/01PQ800J8R<201XS8P04
01lX9`0J8b804a`K01@M70807BDW02@05AdO01`T9P0I8B<05Q/N01LL7`0X;C00:2`_01@H6`0F6Qd0
61`O00lC5P0D61/06alS01XM8P0G6ah04aLK01@G700L7b<05a/N01HI7P0K7b<06alR01PL7`0E6AX0
6QhO00dA4P0C5aT041@G01DI700H71l06AdP01XN8@0H71l04ADH01<G6P0E6A`201HJ7@0>01DF6P0C
51P06AXN01PI7@0F5a/06aXO01<B5`0L6b006a`N01PI6`0E5QP051DG01HG6@0H6A/201LH6P805QLI
0P0E5QP0900J72005QLK018F6@0D5aX06AXN01XN8@0F6Ad05aPL01PL7`0F6A`05AHJ01PI7@0A4Q@0
5QHH01`L7P0B4Q@04A4C01hN800^;S006a/M01`L7P0G5aT03`lA014?4P0F51L06ALJ01PF5`0F51H0
5A<D01HD5@0E4a@04Q0A01@B4`0B41404a4B01HB4P804`l>01804@d<014;2`0C3@d0618B00d71`0D
3Ph040X:01TC4`0600005Q0@014;2`0@2PX050h>00h8200?2@T050h>00d71`0:10@2014;2`0<00d7
1`0?1`P04@P901D;300B20T030<401882@0D2P/04@P901<92P0C2P/04@P90P0@1PL60147200500L0
000H3Pl060h?01@:2`0?1PL00P0@1PL0100D2P/06@l@01P>3`0A1`P600l51P0=01052@0C20`03@<6
00l4200H3A403@@600h31`0=0PH04PL;00T00P0L4AD03P<70104200201041P0300l31@0>0P@03P84
00803P840P0?0`D201041P0600h21P0@10P03P8600h21P0@10P03P861P0?0`LDooooo`006oooool0
100@3`/030/700P70`0@3`/300l>2P0S01@C3`0?3PX03@`8010?2`0=30P02PT7018A3`0C4Q002PT7
00`;2@0@3`d020L5014@3P0?3P`02`X800D40P0?3`d01`h>010D4`0<4@d0410<01`I500=2P<05148
010=1P0C40T06APC01XK5P0H6A<05AD>014A2@0>3PH03`l7014A2@0B4PX01P0>3PH0600<2`L01`H2
00H50@0K6QH02PT501<B3P0>3@T04A0<010?2`0>3@T03`h:01<C3P0E5Q402``700X;20061`80;BhY
00d>2@0H6A@030d800P9100>3`X01`P300`=20803@h901803Pl:010A300A4Pd03a0;014B3@0D5A00
2``700D60@0>3`X04Q8=00h=200=30L04A0;01XI500G5Q403`h900d<1`0?3PT2018A300g00h=200<
30T03@d=00P820061PH06a/K01HF5P1nOWh0MGEe03dm?@071`L0410@00h>3@0B4@d02`X601@C3`0?
3PX00@0000`;2@0>3@T02`X600d<200>3@T030/7014@300=30P04a8>00/:1P061@401`H200X91@0?
3PX040l;01TH500T8al08R4M01@C3`0@3`/04a8>014@300=30P03Pd900T8100?3PX04a8>020O6`0L
6aL03@`8010?2`0>3@/03`h<010?3@0?3P`03@`:00/:200300l>3008010?3@0B4@l04a8@01`L6P0C
4a403`l=00d=2`0820H200X:20803@d;0P0<30X03@0>3P`02PX805eMF`0H61H04a<A01/K6@0@40h0
3Ph<00l?3@0@40h03`l=00`<2P0;2`T00P0@3`d04P0>3@/030/900`;2@0>3@/040l=00`;2@0>3@/0
4Q4?014@3P0C4Q003P`=010>3`0?3@h04a4B010>3`0;2@X040h?00h<3@803@/<00P04Q0A00H41@0G
5Q@05A@B00h=2`061@<02PT7018A3`803@`:02<03Pd;00d<2P0=30X03`h<014@3P0?3P`01@@300l>
300G5Q@03@`:00l>300@3`d03Pd;00X91`0<2`T03`h<00h=2`0=30X03`h<010?3@0?3P`03@`:00L6
100/:bT05QDC0040000J6AL020D400l;2P0@30/03PX900`81`0>2PT030P700l;2P0201<?3P0801HB
4@0E4A002`L600d9200>2PT03@T800h:2@0B3Pd6010<2`0600`;1`0>3@T03`h:00`;1`0:2@D02`X6
0P0@3`/02@0?3PX03Pd900h=2@0?3P/071PI01/G600?2``02PH7014=3P0200l;300M00L3100<20T0
2`L801dI6P0J5QP06aPO014>5`0D4AX05a@M01<@600@3A@02@L<01PF6`0A3a@04a4D00X82`0?3A00
61PJ06EUI`0U9BL03@d?010@4P0G5aT03@d?010@4P0?3a403@d?00`<3P0?3a401P0=2`h200H41`04
01@B5@081PT04a8D00l=408030`>01/02@X<00dA4P0;4A404AXI00P?3`0>4Q<01PX;00P92`020P@0
4Q8D00`>4P0830l02PhA00L;3P0A5AP08RHY02DY;03IgN00em_N028U:00010L0414C00l>3P0?3@h0
3@/<014?400B41400P0>30d200/92P0800`:2`0;2@X02`T:00/:200?3P`030/900l>300@3`d600d<
2P0500d<2`0>30d03P`=00l=3P0<2P/00P0;2@X0300=2``03P`=00/92P0:20T02`T:00h<3@0@3Pl0
4Q0A010>3`0;2@X02PP900`:2`803@/<0P0>30d08P0?3@h020L7018@4@0C4A8061HG010>3`071@H0
40h?01HD5@0O7Ah04a4B00/92P0?3@h02PX<00`<3P0@41804Q8D01DE5`0K6ad0?Cdo01DE5`0?3a40
DU9D05QHFP0I6A/04A0E01<B5`0A41D03@`A00`;400>3A8030/@00d<4@0@3a@2014@5@06010?500b
<CL0D4mE01lN8`0M72402PT>0P0C4aD0;`0A4A<03`l?014A4@0A4A403`l?00l=3P0A3@h04`l@01@@
4@0C3a0040`=01PD5@0=2@X0510A01LC500J5QL02PP900/;2`0?3`l03Ph>010@400D51@0410@01<C
4`0=3@d01`L700T92@0B4Q806QXJ01DE5@0B4Q804a<C018B4P0?3`l0410@00`<300D51@0410@00d=
3@0@41004Q8B01<E500D5QD04Q@C014C4P0B51<04aDD008051HE00P05aTH01XL6`0E5aH04Q@A01LI
5@0J71T06adJ01LL60805a/J00T03Q@B01dV9@0=5QD072DT01dU9`0?5aT08BHY02@Y;00O92L00P0K
82<01@0I7R407b@W028W:P0F6ah05AXM008061dP0P0G71l0A`0I82806R8T01TQ901HH6@0DU]P01TR
9`0H8RP04ahT018M8`0V;c@0GfMZ03]3AP0J8RD05QhQ02@/;`0I8B@08RX]01HN8@0J8RD07BDX01DM
800H82H07RL`01DN9`0J8b`0:34j03@mAP0^=d007RL`01lX<@0N9c006b@]01`U;P0N:2l06bH/01TT
:P0J9BX072L[01/V:P0O:R`09S4c02Te=@0E8B406bLW01/V9`0`>CP072DT01XS8P0L9B@06R<R01LP
7`0f?ch0:S<b01/T8`0F7ah05AhM01TR8@0<5QL04Q`M01TS900Y<C<08RX/01LO8@0K82<09R/^02@X
:`0H71l06alR01LK7P0C5aX05QXM00806QhQ00@061`O01DI700J7R406AdP0P0A5AP03`0F6Qd04ADH
01`P8`0J7R405QXM00`@4`0D61/07B4T01PL7`0F6Qd05ATL01HJ7@0G6ah051PK01DF6P0201HG6`80
5AHJ0P0C51P01`0B4aL04a@H02HW:`0T9BT05QLK01TJ700G61X00P0E5QP0100G61X061TK01DF600G
61X401PI6`0401PI7P0G61d05QLL01LH7@8061TN01<0C4eB01hO900B4aP051DJ00d>4`0720`07QhP
01TI6`0J6Q`04a<E01/K7@0/;2h0XJ6S01`L7P071`T03@d?010@4P0O7b40518C00805Q@E0`0C4A80
1`0B41403P`=01@B4`0H5QL04@l@010<300B30`00P0C3@d01@0B30`050h>01/E5@0X8R806Q@D0080
4P`<00D04@/;01<=3@0B30`040X:01<=3@0200h8200A01@>3P0@2PX03PP801<=3@0B30`03`T901<;
300G3@h04`T:00l51P0H3Pl05P`=00l51P0B20T04`T:01@:2`0B20T01`0A1`P01P0=0`@0;bDV00L0
000:00404`T:01X@4@803@<400@04@L801@:2`0C2@X03@<41P0?1@H0300700004@H:01@93@0;00@0
3P<701X?4`0P5AT01`0000P00@0A1PX0200100d31P<040@600@03`<500h2100>0P@03P840`0?0`D2
01041P8040@80`0?0`L00`0=0@D03`<700l31`0400l31aCooooo000Kooooo`0A00d<200E5100>STe
00`;1`0<2`P030/700l>2P0A40`03Pd900`;1`0A40`04a8>018A3`0>3@/03Pd<00l>300>3@/00P0=
30X0300@3`d02PT700d<2P0K6QP0<c<a06adL`0830/010P400l@300>2`H0514:010=10804Pl800T0
4A0;01<D3`0E5Q404Q4;010@200>3PH04108018B2P0C4`/01@0>3PH06`0>3PL040l;014@300:2@D0
3`h:00T8100G5Q803Pd901<B3P0B4@d030/700h=2@0?3`X04a@?00P9100B4`h01`P401DF4@092PH0
3Pl:00/<1`0A4Pd03a0;00P9100>3`X03@h900h?2P0500d>2@0S00`=200A4Pd04a@?00l@2`0>3PT0
3`h900`;1P0A40/06QTD01HE400>3@P030/600/:1@0=30L040l:014@2`0>3PX02`/8018B3`0E5A<0
2`/800h?300B4Q002PX701<C400C4a403Ph;00/;20061@<05aHB00/:1`0B4@d040l;014@300B4@d0
0P0@3`/0300<2`L02@P4018A3@0E51002PT6018A3@020@004Q4=00l>2P0=30P02`X600h=2@805A@@
00T030/700h=2@0?3PX03Pd901<B3P0F5A403Pd901<B3P0<2`L00P0@3`/00`0;2PH03@`800h=2`03
00l>300A00h=2`0=30X03@`:00h=2`0?3P`04A0>01@C4@0F5A<04A4?00l?3@0@40h03`l=00`<2P0@
40h03Ph<010@3P0?3`d00P0=3@/200h>300;01XJ6@0?3`d051@B00L71@0>3P`03@d;00/;2@0>3P`0
4A4?00`<2P061P@00P0>3@/06`0=30X030/900h=2`0@3`d06QTG010?3@0>3@/030/9014@3P0;2PP0
30X;014?400F51D03`d>00X82@0?3@h01`D6010>3`0?3@h02PP9014?40081PL04A0>00P71@0B4@l0
<S4_01DD4P0300d<2P0=00h=2`0=30X03@`:018A3`030P404Q4?03He<`0C4Q002`X800l>300>3@/0
3`h<00h=2`0200d<2P0A00h=2`0=30X030/900d<2P0>3@/03@`:00`;2@0>3@/02`X800d<2`0>3@/0
3@`:00h<2P0?2`X040`;00l;2P0>2PT00P0?2`X2010<2`03018>3@0H51<0510?00@040`;00<04Ph=
01PD4`0@30/01@0@30/01P0>3@/040l=010?3@0?3P`040l=00h=2`803`h<0P0>3@/0800?3P`040l=
00d92P0E4A802`L801`H6@0A3@h0510A00h:2`0=2@X04Ph?014=3P0G4a@03PX<01dJ8@0<2A80KFYc
07=`M`0C41L05a@K014?500<2Pl03`dB01DC5P0=2`h04Q0C014A4`0B4Q@061PJ00<31@0F5QP04Q8D
0P0@41801P0=3@l030`>00d=3`0@41802`T<00d;3P803`d@02@03@/>00/9300F51L03@/>01@B5@03
0P@05Q@G059@D`0J61/03@d?00T:300<41401P`<03<i>@0X;Bd0310A00dA4P0L7Al03Pd@018A4`0@
4A<03@h@00h?4@0:2P`04Q8D01dN800>3Q00>c`n03dn@00B4aD02PX<00`=3`0<2P/040h?00d;300<
2P/200h<3@803`d>0P0>30d200d;300300`;2@0>3@/03@`:00803Pd;00<03@`:00h=2`0>3@/00`0>
3@/02P0>3@`03P`=00h<3@0>30d030X;00/92P0<2P/040h?018@4@0@3Pl200h<3@0600l=3P0=2``0
2`T:00d;300?3@h03P`=0P0=2``200`:2`0A00h<3@0@3Pl05A<D00800@0I5aP0;B//01@B4`0E4a@0
3P`=00l=3P0<2P/03P`=014?400@3Pl06ATK01DE5`0B4Q@00P0A4A<00`0>3Q0061PJ00H6200201@D
5P0801DE5`0>3Q004Q4F00/:3`0B4AH03PdB00l>4`0B4AH200l>4`<040lD00/03`hC00T83P0Q82H0
2`X?01@C600<2a0051@F018B500?3a403@d=00l?3`02018B4P8040h?00P04@l@018@4@0@3Pl030X;
01`J6`0B414081hO01/I6P805A<D01P04a<C018B4P0A4A405aLG01hN7P0I6AT03Ph>014A4@0T92@0
9BDU01DE5@0D51@06a/K01<C4`0E5AD061PH01DE5@0B4Q804a<C01TI6@0F5QH051@D01LG5`0H61P3
01DG5P0401@F5@0G6AP06Q`K01HH5`805ALF01@05QPG01DG5P0D5Q<05aTE01TK600H6QL05Q/G01PL
6`0I7A`06R0N010F5P0I7al041TH01XR900K8bD06QlR020U:00I7R405AXM01TN8@806b0S02D06QlR
01lT9`0H7B005a`O01dR9@0J7b807b@W01hU9`0K8bD06b<V01`U:@0N9b`07bP]01lY;`0R;C<082/a
01LP9P0`>3/06b<V014I700K8bH0;3@g01TQ900N9RT072@W01/S9P0P:2/07RHY01dU:`0O:3406b@]
01hW<00^=d008b`e01lX<@0K92d072D^00806b@]00T072D^01`U;@0N9bh08R/b024Z<00M9R/07RL/
01hX:P0J92H00P0J92D06P0[=CH08B//02Pa<00G81l0624P01TR8@0M9RD06R<R03U2@@0X<C00624P
01/T8`0M9RD06B8Q024[;00O:BX0628S01hV:00I8B<072@V01`Q900O92L07B4T01XN8@0K7b805ATL
0P0F6Qd0100H71l06QhQ01TM800F6Qd201PL7`0D01HJ7@0H71l05a/N010D5`0D61/05QXM01`P8`0/
<3<082@W00hB5@0L82<05ATL01<G6P0D61/05QXM01LK7P0G61`05QLK01@E6@0C51P201DF6P07014B
5P0P8BD04Q<G01`M8@0T9BT05QLK01DF600201HG6@0601LH6P0F5aT05QLI01@E5`0G61X06Q/M0P0K
71h00`0J6ad061TM01TJ7P0201XK7`0E01PI7@0G61`0ATM;01dN8P0A4QH05AHJ01`M8@0P8BD051@F
01dM7`0T92H06a/M01@D5P0I6A/0;Rh`010@4P0D51H05aLI00l?4@0A4A<04Q0A0080518C00X04@l@
010>3`0A3a00:bTZ01TG600J61T07A/L010>3`0=2@T04P`<0P0D3Ph02@0C3@d05@l?01LA4@0`:RX0
6A<C014;2`0>20P06Q@D010:2P0200l92@0401<=3@0B30`050h>01D?3`8040X:00X04P`<00h8200?
2@T050`=0147200=0`@05@/<0147200>1@D05@/<0`0C2@X00`0B20T04@L80147200501472006034W
:01gKFh060h?0147200C2@X03`D60P0A1`P00`0C2@X050X;01<92P0700l51P0<01<8300=0PH03`D8
01462P0<0@D04PT;00X10`0E2Ph04@L:00l4200A20X03P@70`0@10H00`0?0`D03P8400h2100200l3
1@8040@60P0A1@L20104200301862P0A1@T03`<700L03`<75?ooool001_ooooo02D020L3018A3@1;
BTH02PT501@C3`0E51003`h:00h=2@0=30P030/700l>2P0E51005QDC061OG@0=30X030/901lN700H
5aD020L500l>300E51804A0>00L6100E5A<07B@T010D4`0730P0410<01TF4@0>2`@0514801HC300C
40T02`X500`=200?40/03`h900803Pd800<040l:018A300C4Pd01P0>3@P0600A40`02@P400`;1`0G
5Q803@`800P70`0@3`/03Pd900l>2P0@3`/03`h:00`<1`0A4Pd01`P3014B3@0720<01PL2018C3P0;
30L04Q<>00L81@0N7aX0<34/00d>2@D030d800L04A8=00/<1`082@@0824L02d^:@0J6aH02PX50080
4Q4<00<030/600d<1`0>3@P00`0=30L06P0A40/04a8=018A300@40/03Pl900`=1`0310000@8000X;
1@000@002``6018C40041@00414;01DF4@0>3@T030/7010?2`0P7a/04Q4=07UhM00I61@04A0<00d<
200?3PX03Pd90P0@3`/02`081`<04a8>014@30071P8020L301XI5@0E51003@`800h=2@0B4@d051<?
00<030/700T051<?01XI5@0B4@d04a8>00`;1`0=30P040l;00l>2P0<2`L01@0>3@/01`0?3P`03Pd;
00d<2P0=30X03Pd;00l>300@3`d00P0?3`d0600A4@l03Ph<00/;2@0?3`d02PX800`<2P0;2`T02@T7
00P81P092@L02`/901<C4@0B4Q002PX8014A3`0?3`d04A4?00T91`0:2PP03`l=00h>300;2`T03@`:
00l>30803Pd;01X040l=01<B400920H020L500l>300920H03Pd;01HE4`0B414061HG01hL7@0D4Q<0
3`d>01TG600M6a`02`T:018@4@081PL03@/<01PF5`0D4a403@`:00L6100H5aD02@P601PG5@803@`:
00X03Pd;00d<2P0=30X01`H500h=2`0=30X04A0?014@3P071P@02@P60P0>3@/300l>300=00h=2`0;
2PP02PT700`;2@0=30X030/900X91`0=30X04A0>00`;2@01000010<1018?3P0300l;2P08010<2`0?
2`X03`/:00h:2@0<20L040`;01dI600P71/2010<2`0300d920091@@02PH500L040`;00D02@P600h=
2`0=30X02`X800h=2`0500d<2P0@00h=2`0@3`d02@D600`82@0J5QL0BTI7038^;`0n>S/04@d>01HB
4`0>2P/020@500X61`0D3a803P/B00/940805a@K01H03@`A01HD6@0<2Pl04@lC00d;3P081PT03`d?
00h<3@0820X04Q8D00`<3P0;2`d0K6a^09:BU00B4Q@03`lA00/;3@0<30h03Ph@00l?4@0<2Pd03`d@
0P0A3a807P0?3A0030X=00H41`0=2`h04@lB00X82`0;2@`07adP00X82`0G5QT01`P:00dA4P0Y;bl0
_/C408jDU00>4Q<01`/<01XJ700;2@`030X=010?4@0C4A@04Q8D00`;3@081PT02PX<01LF600F51L0
4a<E018A50802@L:00@0518C01LE5P0B41403`d>0P0@3Pl00`0:20T03@/<00d;300200T7200300X8
2@0=30X030/9008030/900<02`X800h=2`0?3P`0100?3P`0100?3@d03P`=00h<3@0?3@h2010>3`0X
00h<3@0=2``03`d>00h<3@0;2@X02PP900d;300;2@X02PP9014?400E4a@04@l@00h<3@0?3@h03@/<
00`:2`0>30d04@l@00/92P0G5AH03`d>01TG600C4A800@00018@4@0>30d030X;00h<3@0?3@h03P`=
010@4P0=3@l02`/=00l?4@0A4A<03`lA010@4P0B4Q@02PX<00P82P804A4C00H06APM00h=4P0?3Q<0
40lD00h=4P0:2@h2010?50@03`hC00H04a8H01dL8P0F5AX061LL018A5P0>3Q0200d=3`0K00l?3`0C
4a<04a<C010@400C4A804Q0A01<A4P0D4Q<04Q0A00d;300610D06aTJ03`j>`0Z:2T040h?00l=3P0F
5QH04Q8B00h>3P0D51@06QXJ01<C4`0J6QX04A4A01XJ6P0I6AT03Ph>00805QHF01403@d=010@400D
51@04A4A00h>3P0D51@04Q8B014A4@0F5QH06QXJ01<C4`0C5A@0418A01<E500D5QD06Q`K02<U9003
01@F5@0401DG5P0G6AP06A/H01TI5P<06A/H00h06QhM01`P7`0c=cH0<CLg01PN7P0N92@0?DE701/S
9@0I7R4061dP01DJ7@0I7R40724T01XO8P80724T04D05a`O01/P8`0J7b805AXM01dR9@0O92L06b4T
01PP8P0L92L0;CDi020Y;P0E7R<08R`b01XU:`0H8bT08R`b01PQ9P0M9R/0;3Dj07N0Q@21RXl06b@Y
01PQ9P0L9BX06R<X01`U:P0O:2d06R<Y028/=@0[=Ch05R0Y02<]=P0L9Rl0:38k01/U;P0G8BX07BL`
02<]=P0Q:c@07BH^020W;`0S:S807bH]01XQ9`0Q:2h0620S02H^<@0_=cT05QhP01/S9@0P:2X05b0O
01`U900[=3<09c0_01hW9P0Q:RT06b@S01HO7P0J8b808BXY01hW9P0I8R405R0Q01TS900K9BH082PZ
01@L7P0E7Al00P0L8B@07P0N8RD06alR01HJ7@0F6Qd04QHI01<G6P0H71l06QhQ01PL7`0C5aX061`O
01TM800E6A`04ADH01DI700P92L06alR018F6@0830l06QhQ01@H6`0>4QD06alR01HJ7@0J7R406alR
01HJ7@0G6ah06Q/O01PI7@805AHJ00X05aPL01PI7@0@4AD0:BX^01XK7`0H6Ad07AhR01hO8`0E5QP0
5QLI0`0G61X00`0E5QP05QLI01PI6`0201TJ700301LH6P0F5aT06a`P00<06AXN00T06Q/O01/L800M
7R806AXN01DF6P0?41@06AXN02LX;00C4aD00P0B4Q@0600>3Q004A4C01LG6@0N7R004Q8D00/;3@0C
4aD05QHH010@4P0B41405A<D01@B4`0B41404@l@018@4@0E4a@04@l@01HD5@0J61T05Q@E01@@4@0D
3Ph05Q0@01@>3P804@/;00L040X:00d71`0F410040X:01@>3P090`<05a4A00<04`d=01005@l?01LA
4@0D3Ph03`T9010:2P0A2`/03@L700l92@0H41007A<D0147200F30d06a4B00h41@0B20T04`T:0P0B
20T80147200601H<3@0U6a`04`T:01061`0B20T030830P0>10D0100?1@H03P@500h41@0>10D600l5
1P803P<700@04PL;00P00@0?10P0DdQ<0P0?10P0100>1@L0:b0T01052@0F3@l301041P0400l31@0>
0P@03P8400l31@<040@60P0A1@L01P0=0@D0304401@8300E2@d04@D901<72`H03`<75?ooool001_o
oooo00T04a8>00L60`0J6AD04A0<01<B3P0<2`L03`h:00d<200?3PX00P0>3@T06P0D4`l03Pd;03He
<`0100002@P600D40`0C4Q003Pd;00d<2P0A40h03Pd;00L6100H61H0;C@d00`@3`0<4@d04A4=01TF
4@0B3`P04Pl601@A2P0B3`P03@`700d>2@0@4@`03`h90P0>3@P00`0@3`X04A0;018A300600h=200H
00l>2P0;2PH02PT500d<200?3PX03Pd9010?2`0=30P03Pd9014@300?3PX03Ph9014B3@0<3@P03Pl:
00X;1P051P402``700X;1P0F5a802P/603Tj=@14AD002P/60P0<3@P0100=3PT04A8=01@E400B4`h2
00/<1`0<01DF4@0L7AP05aPC00l?2P0C4Pd05A@?00h=200=30L04A0;00l>2@0;2PD03@`70P0A40/0
800?3PT03`l:010A2`0B4`d02``600`=1`0>3`T07b0J038c;@0Z:bD02P/5014B300;30L05A@@00l>
2P0>3@T02`X60040000m?3P05QDA00h=2@0:2@D03`h:00h=2@0=30P010<001<B3P0=30P07A`H00L6
0P0C4Ph02`X60P0:2@D03`0=30P03Pd900h=2@0@3`/04A0<010?2`0B4@d05A@@00h=2@0?3PX030/7
00d<200@3`/03`h:00/:1P0200h=2`803@`:00D03`h<010?3@0?3P`03`h<00d<2P0200`;2@0400d<
2P0:2PP02`/900l?3@803@d;00@05QHD00/;2@0=3@/030`:0P0;2`T03P0<30X01@D301DE4`000000
2PX800`<2P020P004Q8@00X:20092@L03@d;00l?3@0>3P`03Pd;0P0?3P`0300>3@/04A0>01<B400B
4@l03`h<018A3`0F5A<02@P600X91`0>30d0518C01HD5@8040h?00d05Q@E044o@0071@H03`d>00`:
2`0:20T04a4B010?3@0;2PP01`H4010?3@040`4030/900803@`:00d03Pd;00d<2P0=30X03`h<01`K
6@0B4@l03Pd;01@C4@0?3P`04a8@00h=2`0=30X03`h<008040l=01803Pd;00`;2@0;2PP030/900d<
2P0<2`T03Pd;00d<2P081`D05A@B00h=2`061@<040h<00l;2P0>2PT040`;014=300@30/200h:2@04
00/71P0:1PD04`l>01LC4P<03PX900<030P700d9200B3Pd01P0@30/02@0<2`T05A@B01<B400:2@L0
3@`:00`;2@0A40h040l=00h=2`0200`;2@0W00/:200H51D03`/<00X61`0L61T0100100/820070`@0
4`l@00l;300<20T01`<400X6200100D040dE01HC6P0C41L04@hD00d;400;2@h0518F010>4@050`H0
40h@00d;300D51H04Q8D00`<3P0K6ad0GEeO08J6R00B4Q@03Ph@00`<3P0=3@l03Ph@00d=3`0>30l0
40hA00804@lB02L040hA00h<3`0?3A005aDH014?4P0D4QD04@lB00`:3@0>30l03`hA00L72@0G6A/0
5a/L08N=S@1VK6`020`=00d>400?3a401P@700X82`0A3a804PdA00l=400>2Ph03`X>010>4@0B3a80
1P4500@21@0C3a<061<G01HD5`0B4140518C010>3`0>30d03`d>00d;300>30d00P0C4A801`0>30d0
3@/<00l=3P0<2`T02`X800h=2`0@3`d00P0A40h500d<2P0:00h<300>30d03P`=00l=3P0A3a004a4B
014?400>30d040h?00h<3@8030X;00H03P`=00`:2`0;2@X04Q0A01DC500A3a0300`:2`0K00h<3@0A
3a00518C00l=3P0H5QL03`d>00`:2`0?3@h01@<400h<3@0?3@h04@l@00h<3@0=2``03P`=00h>400<
30h03@d?010@4P0B4Q@04a<E00000P0S8bD03Ph@01XJ70030`D03`lA00803`hC00H01`H;01<B5`0@
3a@061LL010?500?3Q<200h=4P0800l>4`0@3a@03`hD00d<4P0:2@h030/@014@5@0F5QP2014A4`0H
018B4P0D51@04Q8B00d=3@0C4A804Q0A01@B4`0E4a@0518C00l=3P0E4a@04a4B02@R8`0M6a`0518C
00h<3@0C4a<04Q8B00h>3P0A4A405ADE00l?3`0H61P03Ph>0`0?3`l01@0J6QX05ADE00l?3`0A4A40
51@D00804A4A0`0G5aL02P0M7Ad08b<S01`L700A4a803a4@01@F5@0C5A@05ALF01hP7`0D5QD201DG
5P0501HH5`0I6aX06adJ01PI5@0J71T00P0K7AX02`0J7Qd0720O01PL6`0P9RH041HF01LM7@0S:bd0
2Q8D01dR9@0J7b805a`O00806QlR00D05AXM01PM800G71l041DH01TN8@0201lT9`0I01hS9P0M8RD0
6R0S01TQ8`0L92L06b<W01HO900J8bP07bT^01TT:P0H8bT06bD[01dV:`14CE809Bhc01hW;00h@DH0
6B8W01`U:P0M9R/072DZ01TR9`0P:Bh08R`c024[=00202/e?P0Z04E?F00M9c006bD^01`V;`0H8R/0
7RPa02H`>@0T;SL082P`01lV;P0P9bl06b8Y01PO9@0Q:2h0620S024Y;00Z<S@0620R01hV:00L92H0
7bPW02`e=00kA4<0;CHe01hW9P0R:bX06b@S01PQ800J8b8072DT01XS8P0M9RD07bTZ01hX:@0M9bP0
8RX/01PP8P0T;2h08bP[01lT9`0R9RT082@W0P0H71l05P0B5QT05ATL01XN8@0H71l05QXM01@H6`0H
71l05ATL010D5`0?4aH092P[04=7BP0Q9BP0:blb028V:@0J7R4051PK01hR9@0J7R405QXM01lS9P0P
92L201HJ7@0301XK7`0I6Qh05aPL00<05aPL00H05AHJ020Q9@0M7R807QlS018C5`0A4QH201PI6`80
5aPJ0P0F5aT00`0I6Q`061TK01LH6P0201LH6P0J01HG6@0K72006AXN01PI7@0I6Qh06Q/O01/L800C
51P061TM01lP900J6al030dA00P93@0@41806ATK01dM7`0H61X0410B00d=3`0A4A<02@T;01HF600H
61X0410B01DE5`0C4A8201DC500I01<A4P0B41404Q0A01hL7@0D4Q<03`d>00T7200:20T04Ph>01D?
3`0G4A405@l?014;2`0?2@T040X:00H0000G4A404P`<01PB4P0400006A<C01PB4P0G4A404P`<01<=
3@02018<3003010:2P0A2`/05Q0@00804P`<00T04PX;020F5`0:004040H7048h>@0[8B8040H701<9
2P0B20T00`0A1`P00`0B20T04@L8014720030147200701061`0700003`D600L0000B20T040H700l5
1P0201061`803`D600<04PP900l51P0?1@H0100?1@H0300<0@D03@8601@93@0?10P040D903/`=00<
0@D081DI01hC5`0700002@0201@93@<040@600<03`<500h2100>0P@00`0@10H201451`070186200>
0PH0304401D93@0F2Ph040@801@8300600l31aCooooo000Kooooo`0?00X91`0D4`l051<?010?2`0?
3PX04A0<00h=2@0=30P04Q4=010?2`0<2`L04A0<01PG5@0:2@P04a8@008030/:01<02PT8010?3@0?
3P`040l=014@3P0R8Al0A4A20=?KfP0[;bh05Q/G00d>2P0A3PT03@X3018?1P0A3PL040d600d<1`0=
3PT03Pl:00@03`h90P0@3`X600h=200O014@300@3`/04A0<00d<200?3PX02@P500l>2P0B4@d04A0<
00h=2@0?3PX03`l;00/<1`0C50l03@h9018C3P0>3`X02``700l@2`092PH04Q<>00P91P0J6aH0=3D`
014B3@0>3`X030d800h?2P0B4`h04A8=00/<1`0200X;1P0900`=200>3`X0410;018A300A40/03Pd8
018A300C4Pd040l:00803Pd800P03`h9010?2P0?3PT0410:00D6000=3PL05aP@00T:0P803a0800P0
1`P400h?2@0A4PX0414900d>1`0?3PX02`X600l>2P8040l;0P0A40`03@0>3@T040l;010?2`0<2`L0
40l;01/J5`1@Cd/03@`901@C3`040`403`h:00h=2@0=30P00`0>3@T200d<2005014@300B4@d040l;
018A3@0?3PX00P0>3@T200d<200:00l>2P0>3@T03Pd;00h=2`0<2`T03@`:00l>300A40h040l=00l>
30<03Pd;00P03`h<00/;2@0;2`T03@d;00/;2@0=3@/06ATG00/;2@803Ph<00T03@d;00h>300@40h0
2PX800h>3@0>3P`03@d;00l?3@0:2PP00P0=3@/08P0<30X02`/900/;2@0<30X03Pd;00l>300>3@/0
30/900h=2`0@3`d03Pd;00d<2P0;2PP0D4m=03Lf=00C4Q003@/<014?400<2P/03`d>01DC500C4A80
8R0Q00X82@0C4A803@/<00`:2`0>30d03Pd;00`;2@0@3`d04a8@010?3@0:2@L200d<2P0U00h=2`0=
30X03@`:00h=2`061@<03`h<018A3`0510803@`:014@3P0=30X030/900l>300B4@l04A0>00h=2`0=
30X030/900d<2P0>3@/03@`:00l>300:2@P05aHD02h]:`0L6aT04Q4?014>3@0@30/03PX9010<2`0B
3Pd04@d<00l;2P0D40l05A4@010<2`0200l;2P03010<2`0A3@`04Ph=008040`;00<04`l>010<2`0@
30/0100@30/01P091`P061HG01PF5`0:20T03@/<014?40803`d>01403P`=00`:2`0<2P/03@/<01@@
4@0F4Q<03`/<00T61P0F4Q<04@d>03/g>00f<S<04@d>00l;300=2@X04`hA00l=4P0200`9400600h<
4@0@3Q<04a4F014?4P0:2@/061HH0P0=2``0100B4140518E00h<3`0;2@`200l=400701PF6@0B41<0
3`d@00l=400A3a8040hA00`:3@0200l=40803P`?0P0?3A009@0>30l04@lB00d;3P0D4QD030X=010>
4@0B3A402`T<010@4P0=3Q00310A00dA4P0?4a@03@h@01DF600=30h0514D00h93@0?2P`04`d?018=
3`0B30h04@/=00l:2`0@2``050h@01HA4`0=20X050h@00d92P0<2P/02`T:00X82@0?3@h040h?00/9
2P0@3Pl00P0F51D01@0@3Pl03`d>014?400=30X02PT700803Pd;00<03`h<014@3P0>3@/0100>3@/0
1P0?3Pd03`d>00h<3@0=2``03`d>010>3`804@l@00P040h?00d;300<2P/03P`=010>3`0=2``02`T:
00d;308040h?00<03P`=00`:2`0=2``00`0?3@h0200A3a002`T:01@B4`0@3Pl020H7014?400<2P/0
3P`=0P0?3@h09P0>30d040h?014A4`0B4Q@04A4C00d=3`0<30h03`lA01<C5@071`T03`lA00X:300Y
:B/0<30b01<B5`0X9b`040lD01PG700@3a@0=C@i00l>4`0>3A803@`A00h=4P0@3a@04a8G01XI7`0=
31804A0E00`;400B4AH0410B01@D5P0B4Q@04A4A01<C4`0E5AD051@D0P0?3`l01@0B4Q8051@D01<C
4`0?3`l06ATI00804A4A01403Ph>01LG5`0@41003@d=01<C4`0A4A40410@01<C4`0?3`l0410@018B
4P0A4A404Q8B01DE5@0D51@05ADE01<C4`0201HF5P0?01<C4`0F5QH05ADE01dM7@0I6AT04Q8B01@D
500F5QH05ALF01TK6P0R92<06Q`K00lA400E5aH05aTH00806Q`K00L05aTH01PJ6@0I6aP05ADB01XJ
600L71X06a`J00806adL04X05QXI01TM7P0H71d06R0P00hC5P0G71l06AhQ020U:00L8B@06QlR01`Q
900K82<09BX]02db=@0l@D@08RLZ01HK7P0P9BP07b@W01dR9@0O9RP07bLY01`T9`0K92P092db02L`
=@0M9b`06bH/01lZ<00P:Rl06R<X02L`=@0X<CH082T^01dV:`0V;c@05b0U028[<00e?T<09Rld02D^
<`0S;C@06bD^02Pb>`0Z=3d0DUaU02H`>@0K9Bh072H_01hX<@0L9Rl07BL`028/=@0R:S807B4Z01hR
:`0L82P06QlU01hS:@0Q9RX07B8V01dR9@0L8B@0:Rlb01hS9P0K8bD07bLY02Ta<`0J8R@06b<U024Y
:`0R:R`06b<U01LO8@806R8T00h07BDW01/U9P0I8b@06B<T01lW:@0H8280;cLi02X_<P0L8B@07B4T
02@X:`0K7b804aLJ01PL7`80720S0P0C5aX00`0N8RD0720S01LK7P0201PL7`0?01lS9P0_<cH05QXM
01/O8P0P92L04aLJ01DI700G6ah06alR01@H6`0M8B@07R8U01DI700G6ah05QLK00<061TM01/05QLK
01@E6@0D5AT061TM02HW:`0R8bL06Q/O04e>DP0O828071dO01LH6P0F5aT05aPJ01PI6`0K71h061TK
01HG6@0H6A/071dO01hO8@0F5aT061TK01XK7@0I6Q`05QLI01DF600I6Q`00P0E5QP01@0D5AL05AHH
01/L7P0G5aT05ADG00804Q8D00H051@F01DE5`0C4aD05aLI01<C5@0A4A<201<C5@0=01<A4P0E4a@0
5A<D018@4@0A3a004Q0A00d<300C4A806QPI01LE5P0?3@h03`/<01<=3@0201H@400<01<=3@0A2`/0
3`T901XD500=1`L03PP8018<300C3@d03`T901@>3P0C3@d03PP80P0C3@d03`0A2`/03PP800h8200G
4A405Q0@014;2`0@20P060h?00L0000G3@h0<2HW01X@4@0F30d050X;01882@02014720804PP91@0A
1`P0300E2``03@D501<92P0700006a4B0147200?1@H04@L801882@0@1PL04@L801P>3`H03`D600`0
50T=01052@0@1@T040D900d21P0=10H03PD701052@18?D40;R@W01892`0E30h301041P0300l31@0>
0P@03P84008040@60P0A1@L20186200601@8300?0`L060`@01L;3`0=0@D040@81P0?0`LDooooo`00
6oooool0300B4@d05aHB01HE4@0B4@d03Pd900l>2P0>3@T02`X6018A3@0>3@T04Q4=014@308040l=
02803Pd;00l>300A40h04a8@018A3`0A40h051<A00d<2P0J6AL092@R05ELG00C5aH05a`H014B3P0:
1`806AH?01@A200A3PL040d600l>2@0@4@`04A8=01DD400G5Q80D4m;02HU8@0?3PX030/701<B3P0<
2`L02`X600l>2P0@3`/03Pd90P0?3PX07P0@3`/03`h:00/:1P0920@03@`801@C3`0@3`/03@`800/:
1P0=3@P030d800h?2P092PL02@X5020Q700720@0414<00`=200=3PT04A8=01@E400H6A@04A8=00l@
2`0;30L02P/600h?2P0A4Pd04Q<>014B3@802``700/03@h900`<1`0@3`X051<>010?2P0A40/040l:
00T80`0A40/04a8=00`;1P02014@2`0E00X:100?40P04a@<00h?1`0<3@D041490001000W:20020T1
01HG3`020`003a0800T8100<2`L03`h:00`;1`0;2PH040l;00/:1P0C4Ph05A@@00804A0<00T030/7
020O6`0h=c<04Q4=00P70`0A40`040l;00d<200?3PX00P0>3@T02@0A40`03@`800T8100?3PX040l;
00l>2P0C4Ph030/700h=2@02010?2`0600h=2@0?3PX040l;00H50`0?3P`04a8@0P0B4@l03P0?3P`0
40l=00d<2P0;2PP03Pd;00l>300920H01`L500`<2P0:2PP02`/9018B40051@<03@d;0P0>3P`01P0=
3@/03Ph<014A3`0=3@/03Ph<00`<2P802PX800@030`:00h>300=3@/030`:0P0=3@/0500>3P`02`X8
00h=2`0B4@l02`X801LF500=30X040l=00h=2`0=30X03`h<014@3P0B4@l02`T:00h<3@0:20T02`T:
00d;300;2@X030X;0P0?3@h01P0;2@X02@L800X82@0>3@/03@`:00`;2@803@`:00d03Pd;01HE4`0B
4@l03`h<00T81P061@<04A0>00`;2@0:2@L03@`:00P71@0;2PP03`h<00803@`:00X03Pd;00d<2P0=
30X03@`:018A3`0@3`d01`H400h=2`0A40h03Pd;0P0@3`d0100?3P`03@`:00h=2`0>30X200h:2@09
00l;2P0@30/040`;00h:2@0@30/04@d<00d9200A3@`030P700804Ph=01l040`;00l;2P0?2`X03`/:
01HB4@0>2PT040`;00X61@0=2@P04@d<00/92P081PL02`T:00d;300:20T04@l@00h<3@0=2``05A<D
014?40071@H04a4B01HB4`0@30d03@T:00l;300>2P/04Ph?02l[;00V8R<05a<D00803`/<00T03PT<
01<A5P0610T04Q0E01PF6`0610P02`T<00`:3@0=2`d00P0>30d0900?3P`040h?014?4P0B41<020H9
00d;3P0<2Pd03`d@018@4`0?3A0040hA00d;3P0?3A007adP03hl?`0A3a802`T<014?4P0:20/0518E
01<A500A3a8081hQ02<Q900D4QD03`d@010;3`0?2`l030`>00`=3`0;3a00310A00T=3P0;30h030`>
00d;3P803`X>00L030H800l92`0A2`d04P`>00l92`0>20X04`d?00805@lA00L04`d?018<3P0B3Pl0
3P/<00T720081PL030X;00803`d>01P06ALH00`:2`0<2P/03`d>00D3100:20T02PT700L6100;2PP0
4a8@014@3P0?3P`02PT700l>300>3@/01PD300`;2@0A40l00`4200D3100>30d01P@500h<3@0A3a02
00h<3@0400`:2`0;2@X03@/<00d;30802`T:00h030X;00d;300=2``03P`=01hL7@0:20T030X;00L5
1P0<2P/03@/<01<A4P0A3a003P`=018@4@803`d>00L04a4B01TG600@3Pl030X;018@4@0A4A<04a<E
00803`lA01h04a<E00/;3@0>3Q003`lA010@4P0?3a40410B01<C5@0S8RL09RDZ01LF6`081``03PdB
00l>4`0A41D02`X?051?E0081``00`87018A5P0=31805aHL00d<4@0A41D06aXO00L72@0A4A<0410B
010@400?3`l2014A4@803Ph>00<030`<00/;2`0=3@d00P0@4102018B4P09010@400A4A404Q8B00d=
3@0F5QH04a<C01HF5P0B4Q806ATI00@051@D00@04a<C014A4@0@41004Q8B0P0E5AD03P0B4Q80410@
01LG5`0H61P04A4A010@400C4a<04A4A01@F5@0O8B00<38a02DW9P0C5A@06Q`K0`0G6AP02P0I6aX0
6Q`K01/M6P0L6aP05QDC01PH5P0F5Q@051HE01XL6`0H6QT201PL7@0301TM7P0I7B006QhQ00<082DX
01T07R<V01/P8`0J7b80LgQk03m4A`0X;C007b@W028W:P0D6A`082DX01hS9P0M92H06B4S028Z;@0W
;c<072DZ02Xc>00T;S@06B@Z02<^=00H8bT092le01TT:P0N:Bl08bhd00807RT_00<092le024/<P0O
:S000P0V<CL0500U;cL09C8j02@a>@0R;cL08Bhf028_=`0I9Rh07R/c01l/=00Q;SH08c0h01XW;`0L
9Bd07R8[01lS;00O8b/07R<Y024V;00P9BT06QlS0P0M8RD0900F6ah08RLZ01/S9P0`>3/0<SXm01TQ
900K8bH0Ri>F06ifN@0O9bX06R8U024Y;00M9BP06B4T01dW:00O:BX05R0Q02H^<00M9BL05QhP01`Q
900M8RD07B4T01TM800G6ah061`O01lS9P0@51L06QhQ01dQ900G6ah07B4T014E600F6Qd09b/^02HZ
;@805a/N01h05QXM01LK7P0C5aX05QXM01/O8P0G6ah05ATL02DY;00>4QD082@W01PL7`0g>ch07AhR
01DF6P0C51P05aPL01/L800I6Qh05QLK01LH700D5AT05QLK01/L800H6Ad05QLI01@E5`0F5aT05aPJ
01PI6`0M7R0201PI6`805aPJ0P0F5aT0100B4aD05AHH01/L7P0J6ad201@E5`0401LH6P0E5QP051DG
01<D5P804Q<E01805ADG01XJ700H61X04a<E01DE5`0I6A/0410B018B500C4aD051@F01<C5@0B4Q@0
5aDF01PF5`0A3a005Q@E01LE5P0<2P/500l=3P0301<?3`0E3`l04`d=00804P`<0P0C3@d2010:2P09
01@>3P0F41004`d=01D?3`0?2@T02`D501D?3`0A2`/030H600<03PP800T03`T9010:2P0@2PX06a<C
01dC500C2@X06a4B01061`0J41400P0B20T0200@1PL04@L801<92P0C2@X050X;01H<3@0<0`@02@00
0P0C2@X04P0A1`P03@<400l51P0=0`@06@l@01`B4`0=0`@050X;00l71`0B20T01`0001@:2`070000
6Q0A01H<3@0900004@L800h41@`03`@800H03`<501D92`0?10D02P0001@82P0>0P@600l31@0500h2
1P0I3A408ADI01T=4@0>0PH00P0@10P01@0D20`040@800l31`0?0`L02@0101Cooooo000Kooooo`09
00h=2@0A40`04A0<00l>2P0=30P030/7018A3@0?3PX05QDA00803Pd900<030/7010?3@0?3P`00P0>
3@/03`0A40h04Q4?00L6100B4@l01`H401@C4@0@3`d00000024X:0031`H000<001<C3`0F4`h03``5
01<@1`02014>1`0<00l>2@0@4@`0414<018A3@0A40`0=SDa01TH500E510030/701HE4@0@3`/03@`8
0`0>3@T06`0<2`L040l;00l>2P0<2`L03`h:01<B3P0>3@T03@`800T8100>3@T04Q4=00l?2`0<3@P0
4A8=01@E400K71L0=3D`01HG4P0D5A003Pl:00X;1P0;30L02P/601<D3`0?40/030d800h?2P02014B
3@0700l@2`0>3`X03Pl:00d>2@0<3@P02P/600d=200201HE400A010?2P0A40/04A0;00/:1@0C4Pd0
5QD@00h=200A40/04Q4<00`<1@0?40P04a@<00h?1`0<3@D0414901<D300m?SH00P0D5@d01@082@40
3Pl800/:1P0<2`L03Pd900803@`800h03`h:00d<200A40`03Pd900/:1P0@3`/051<?00h=2@0Y:2@0
51<?00h=2@0@3`/01PD100`;1`802`X60P0:2@D0200<2`L03`h:018A3@0>3@T02PT500h=2@0:2@D0
3@`80P0?3PX200d<200700l>2P0B4@l040l=00/:200:2@L030/900h=2`0300X91`0:00d<2P0?3P`0
30/901<C4@0B4Q00410>00l?3@061P@05aLE00`<2P803Ph<00/030`:00h>300A4@l030`:00l?3@0>
3P`030`:00/;2@0<30X03Ph<00d=2`0200`<2P803@d;0P0?3P`01@0@3`d030/9014@3P0=30X030/9
00<02`X800D030/900d<2P0>30d03`d>00h<3@02014?400400d;30091`P03@/<00h<3@803@/<00@0
3P`=00h=2`0=30X030/90P0=30X02`0>3@/01@@300L610071P@03Pd;00/:200>3@/02`X801TH5P0S
8R0051<A00802`X80P0=30X02@0>3@/03@`:00d<2P0>3@/04Q4?01<B400?3P`03Pd;00d<2P0200h=
2`0500X91`0<2`T03Pd;00d<2P0=2PT00P0>2PT0300?2`X040`;010<2`0>2PT0510?01PD4`0>2PT0
1`<200/71P0B3Pd04@d<010<2`803`/:00/040`;00l;2P0:1PD040`;00d9200A3@`05Q8A01@B4`0@
3Pl04@l@01@B4`0200l=3P0800/92P0?3@h05A<D00X82@0<2P/0?3Xk01hJ6`0H51D201<?400?014=
3P0C3a005a<D01<?400?2``04@d>01DA4P0I5AH00P0502XX;@071@X040hC010>4P0C4A@03@/>0080
3P`=00X03Pd;00l>300?3P`061HI010>4@0>30l02`T<01HD5`1HEUT061HI0P0C4A@03`0A3a803@/>
018@4`0N71l030X=014?4P0C4A@02PP;00l=400>30l02`T<01LE600I5aX03@/>00/93002014<4005
00h<3`0=3@l02``>00P<3@0:3@h00P0<30h01@0=2`h03`X>00l:3P0A2`d04P`>00804`d?00<04P`>
014;3@0@2P`00P0C3@l2014;3@05014=3P0>2``02@L800X82@0=2``00P0>30d02P0K6AX04@l@020N
7`0=2``040h?00l=3P0;2PP02PT700`;2@0A40h2010?3@0<018A3`0=30X03`h<01dL6P0J6AL040h>
00h<3@0E4a@04@l@018@4@0E4a@03P`=0P0B41401@0@3Pl03`d>014?400@3Pl03@/<00803P`=0P0?
3@h04P0<2P/04a4B00T7200B41403@/<01@B4`0=2``040h?00h<3@0A3a005Q@E00h<3@0?3@h061HG
01/I6P0D4Q<040h?01@B4`805ADG00h03@d?00`<3P0B4Q@04A4C00h>400?3a40410B00h>400?3a40
4Q8D014@5@0G5Q/040lD00P730803`hC00`051<H00l>4`1>CE806APM01PG700C4QL01`H<01HE6`0B
4AH01`H;01@C600F5QP2014A4`80410@00T04A4A018B4P0;2`/04A4A018B4P0?3`l04A4A01LG5`0@
41000P0B4Q802@0@41004A4A018B4P0M7Ad03`l?00X:2P0>3Ph04Q8B00d=3@0201<C4`0601@D500C
4a<04Q8B010@400F5QH061PH0P0K6a/0100I6AT05aLG018B4P0D51@2014A4@0701LG5`0F5QH04aDD
01TK6P0S9B@06adL014C4P0301HH5`0>01LI600I6aX06A/J01XL6@0M71T061LE01XI5`0H61H06ATI
01dO7P0J71/06alP01`P8@0K7b0201TM80<07B8U01H0724T01XO8P0J7b80<3Dh01<H6`0P9BP06AhQ
01XO8P0T:B`07B8U01hS9P0Q:2X092`^030h>`0_>3`0624V01hW;00J92X06B@Z02@_=@0P:c409S4g
0P0L9bd0300O:S0082/a01hY;`0Q;3808Rdc01dX;P0Q;38092le02Lc>P0X=Cd09C8j02@a>@809C8j
00L08Bhf02Hc>`0P;CD07b`d024^=P0I9Rh07BD^00807b</01D082@/024V;00Q9R`08BHZ02<X;00h
?D00?D9502db=@0R9bX08RX]020X:`0N9RT06R8U020X:`1IHF@0@DU<024Y;00G7b807RHY01/S9P0Q
:B`00P0P:R/0500I8b@07RHX01XR900J8R@06QlR01/P8`0L82<061`O01HJ7@0H71l082@W01TM800H
71l04aLJ00dA500P92L05QXM01TM800O8bH07R8U0P0F6Qd0100C5aX06AdP01DI700C5aX201LK7P03
01lS9P0A5AP082@W008061`O00L0[K6d02PY;@0M7R805AHJ01@E6@0B4aL03@hB008061TM00L06a`P
01PI7@0B4aL05QLK018C5@0E5QP04A8D008030d?00<03PlA01/L7P0K71h00P0K71h201TJ700302X[
;@0G61X051DG00805AHH0`0G61X0300F5aT05AHH01<D5P0B4aD05ADG01TI6`0G5aT04Q8D01<C5@0F
5QP04A4C018B50804a<E00P04Q8D014A4`0E4a@02`T:01@B4`0I5aP040h?00h<3@D04@l@00<04`l@
01@>3P0C3@d0100B30`200l92@07018<300D3Ph04@/;00l92@0>20P03`T9010:2P0200X4100400h8
200?2@T040X:010:2P804@/;00H04@T901D;300900003`D600`20`0D2P/20147200400l51P0@1PL0
4PP9014720803@<401H06a4B01H<3@0800003@@401<92P0B20T05P`=00d3100@1PL030<401<92P07
00004PX:01@:2`0<0P<04@P901dC500900002@0101dC500B20T03@<4300?10P01P0J3Q007Q8D01H:
300>0P@04`L900d10`H03`<500`02P020104200E2@d040@800X00P0B1PX04@D900T00@0>0PH04PH:
01452@0G2`lDooooo`006oooool00`0?3PX03@`800h=2@02014@300500d<200K6QH03Pd901<B3P0>
3@T00P0@3`/0100?3P`03Pd;00d<2P0>3@/200l>300:01PG5@0@3`h01PD401DD4P0920H04Q8@034g
=`0F6QT01PX700h>2`804a0;01/04a07018?200B3`P040l:00l@2`0@4@`03Pd;00X91`0C4Q002@P6
01/J600<2`T04Q4?014@3P0?3P`03@`:018A3`0F5A<040l;01<B3P0A40`030/7014@300F5A404a8>
014@300>3@T00P0A40`0200=3@T03Pl:00/<1`0:2`H020T401PI50082@D04A8=0P0=3PT09`0?40/0
3Pl:01@E400>3`X02``7010A300E5Q404a@?014B3@0>3`X02``700l@2`0@4@`03@h9010@2`0D4`h0
4Q4<00h=200?3PT040l:00`;1P0B4@`05aHA00l>2@0>3@P040l:00h>200?40X04A8=00h?2P0=3PP0
3a0;00L8100X:B<02``700/<1P0:2`D03a0;00l>2P0200d<200400l>2P0@3`/03Pd900`;1`803`h:
00T03@`800h=2@0@3`/030/701`K5`0920@01`H200/:1P0B4@d00P0=30P0200J6AD06aXF00h=2@0@
3`/071/G01XI5@0C4Ph03@`80P0?3PX00`0<2`L03`h:00h=2@0200d<200400h=2@0B4@l03@`:00d<
2P@040l=00D03`h<010?3@0?3P`030/900/:200200d=2`0C00X:200B4Q002`/900T91`0<30X03Ph<
00d=2`0<30X03Ph<014A3`0<30X0410>014A3`0?3`d03@d;00`<2P0@40h03Ph<00d=2`0300`<2P07
00h=2`0;2PP020L500l>300:2@L04A0>00h=2`0300l>300400d<2P0<2`T030X;018@4@8040h?00<0
3`d>00/92P0<2P/00P0>30d200`:2`0400h<3@0>3@/03@`:00`;2@803@`:00X03Pd;00`;2P0@3`d0
3`h<010?3@0920H03@`:00`;2@0>3@/04Q4?0`0@3`d200h=2`0400d<2P0>3@/03Pd;00h=2`802@P6
00X03Pd;00l>300F5A<06APF00d<2P0:2@L03@`:010?3@0>3@/03@X9100?2`X02P0@30/04@d<00l;
2P0?2`X04`l>010<2`0C3`h04Ph=014=300@30/200l;2P0H014=300B3Pd03@T8018>3@0<20L03@T8
00h:2@0?3@l030X=00h<3`0@3Q403P`?00`:3@0@3Q402`T<00h<3`0A3a802`T<00X82`0E4A803`/<
00d92P0?2``03@T:0`0?2``0200A3@h04Ph?018>3`0@30d03P`@03@b=`050`P04@lB0P0<2Pd00`0@
3Pl03`d>00h=2`0200h=2`0W00d<2P0B3A005a8F010;3`0?2Ph07QTM04e8C00>2@d03`X>018=4@0C
3Q803PT=00d8300:20/03`d@010>4@0=2`h030X=00d;3P0A3a8030X=014?4P0B41<03@/>00l=400B
31004PdA018>4P0>3Q002@X<00L82P0;30h030`>00d<3P0?2`h040X>010:3@0D3Pl04P`<00804@/;
00T04P`<01<=3@0=1`L040X:014;2`0@2PX04@/;014=300=2``00P0<2P/0300?3@h03@/<00`:2`0H
5QL040h?00H51@0;2@X03@/<00/92P0=30X03Pd;00l>30803Pd;00/040l=00l>30081`D04a8@00@3
0P0;2PT0;2/Z00d;30091`P04@l@00/92P0200l=3P803P`=00@03@/<00`:2`0=2``03P`=0P0=2``3
00h<3@0@010>3`0=2``01P@500X82@081PL06aTJ02XX:@0e<c@05aDF00X82@0C4A804@l@01<A4P0B
41404a4B014?408040h?01403`lA010@4P0?3a40410B014A4`0@41803Ph@00l?4@0@41803@d?00h>
400A4A<03PdB01DD6@0F5AX04Q4F01HE6P0201@C600>014@5@0Z:Bh05A@I01`K800@3a@05aHL00l>
500G5Q/03`hC018A5P0G5aT04Q8D014A4`0A4A42010@4004014A4@0C5A@03Q0?00h@3`804A<B00@0
2`d<010B4@0B51<04Q@C0P0@4Q403`0B51<03@d=00d=3@0K6a/02`/;01<C4`0:2PX04A4A018B4P0C
4a<04Q8B014A4@0@41003Ph>010@400301<C4`03018B4P0H61P06QXJ00805QHF00/06ATI01LG5`0F
61L05aTH01@F5@0E5aH061XI01LI600E5aH05QPG01LI600201PJ6@0301TJ5`0N7AX06QTG00806QTG
00<06QXJ01dM7@0I6aX00P0M7R001@0H71d05a/N01TM800J7b806AhQ00806QlR0P0K82<07`0E6Qd0
6AhQ02<X:`0Q9RT06b0S02@Y;00R9bX07b@W01`S9@0J8R@082P[02</<00K92T07RL/024[<@0T;cD0
9C0f020[<@0J9B/09S4g028]<`0J9B/07BP^01hY;`0P:c408bhd01dX;P0L9bd082/a02Ld>`0U=3/0
0P0P;cH3028a>00H02He?00K:S407B`c02He?00M;3<082/b01lV;P0L8b/082L^02@[<@0P9bd09Bd`
01hV:@0O9bT08b/]01hV:00M9BL09Bd`01LO8P0L92L0620S01hV:@0O9bX0;cLj0P0N9RT0;00X<3<0
7BDX01lW:P0N:2T06R@U01dW:00D71h06b<U01hV:00F6ah061dP01XN8@0G6ah05QXM01PL7`0F6Qd0
:2`_01LK7P0C5aX08RHY038f>@0J7R407R8U01DI700B5QT05a/N01HJ7@0D61/07B4T01XN8@0E6A`0
61`O01/O8P0D61/06alR01dQ900F6Qd06QhQ01TM800L7B405QLK01<D600E5QX05aPL0P0F5a/0300I
6Qh07b0T01XK7`0C51P061TM01PI6`0D5AL05QLI02LX:P0`<C<061TK01XK7@8071dO00X06a`N01TJ
700G61X0:bd/01HH5`0C5A@051HE01<E500D5QD05QPG0P0H6QT0200F61L051HE018D4`0G5aT061PJ
01HF600B4Q@04A4C1@0C4aD0200A4A<0410B014?400F51D030X;02TW:00`;Rl04a4B1@0@3Pl01P0B
3Ph04`d=01@>3P0D3Ph04P`<014;2`<04P`<0P0C3@d0200B30`03`T901TC4`0N61P04`d=00l92@0C
3@d04P`<0`0A2`/2018<300401L?400e:b`07Q@E01@:2`8040H700@04PP901061`0?1@H040H70P0A
1`P05P0F30d03P@500l51P0=0`@030<404Hl?@0E2``04@L801882@0900403P@501@:2`0A1`P06Q0A
0107200E30d0JEmP01dD500O5AH060h?01@;2`0<0`@201061``03`@800D03@<401451`0>0`@02`01
0186200700l31@<04PH:00T03`<701452@0N4QH091PL00l41`0?0`L04PH:00/00`0?10L05?ooool0
01_ooooo00`040l;00d<200>3@T04Q4=01DD400B4@d0>3Lc01HE4@0A40`03Pd9010?2`0?3PX500h=
2`0>00d<2P0<2`T0HV5O02l^;00<2`T040l=01LG5@0=5A@05ATH01DJ5P0A4Ph02`P3014>1`0B3`H2
018?200Y010?2P0?40/03a0;00l>300<2`T051<A00/:200C4Q003Pd;00/:200>3@/03@`:00`;2@0B
4@l05QDC01@C3`0B4@d04a8>01HE4@0C4Ph03`h:00T8100>3@T030/700l>2P0B4@d0410<01<D3`0=
3PT03a0;00X;1P0E5Q403@h901LH4`0B4`h03a0;00`=200720<0414<014B3@0?40/00P0<3@P0200>
3`X04Q<>00h?2P0?40/06a`G01PI500@4@`03@d80P0920<07`0>3@P040l:010?2P0=30L04A0;01DD
3`0@3`X03Pd800l>2@0>3PT03Pl:00l@300>3P`03@h900h>2`0=3@/04Q<>00d>2P0A4@l01PL200X:
1`0A40`03Pd900d<200@3`/04A0<00h=2@0<2`L03@`8014@300?3PX00P0=30P05@0920@04A0<014@
300?3PX01@@000P71@0;2PH02@P401PG4`0I61@02PT500d<200B4@d040l;00l>2P0=30P02`X600X9
1@0>3@T040l;00l>2P0200h=2@03010?2`0A40h02`X800803@`:00d020L500T81P0:2@L01PD300/:
200=30X02`X8010?3@0<30X051@B01/K6@0=3@/02PX800802`/90P0=3@/02`0;2`T03@d;010@3P0:
2PP03`l=014A3`0@40h03Ph<00d=2`0?3`d03@d;00<030`:00T03@d;01lN700G5Q@03`h<014@3P03
0P0030/900/:200<2`T00P0=30X04@0:2@L02@P601<A4P0Q7b006aTJ00h<3@0?3@h04Q0A00l=3P0@
3Pl03P`=00`:2`0;2@X03@/<00h=2`0=30X030/900803@`:00L03Pd;01XI5`0?3P`040l=00H50`0A
40h030/900802`X801405QDC01`K6@0B4@l02`X800l>300>3@/03@`:00h=2`0?3P`04a8@00l>300;
2PP02PT700D40P0>3@/04a8@00l>300201DD4P03010?3@0?3P`03`d;00D03`/:00P030P700l;2P0F
4Q403`/:00<0000>2PT04@d<010<2`803`/:00T040`;014=300>2PT02PH501DA400D40l06ADD01`H
5`0;2@`00P0>30l02P0:20/02`T<018@4`081PT02`T<010>4@0<2Pd02PP;01HD5`0B3Pl200d92P09
010<3@0?2``04@d>00d92P0@30d05A4B01HB4`0C3a0040`=008030X=01405Q@G00d;3P0?3@l03P`=
010>3`0?3Pd03Pd;00h=2@0=30P030/900L3100E41@03@P<014<400<1`/0100300d83002018=4@05
010;3`0A31004`hB014?4P0B41<00P0:20/00`0?3A0030X=010>4@0200`:3@0Z00/9300<2Pd04@lB
00h8300A2`l04PdA010?4@0;30h02P/=00/<3P0<30h03@/>00l:3P0@2Ph040X<01@@400@30/03@T8
00h:2@0@30/04@d<00`81`0@30/04@d<010<2`0A3@`04`l>00h<3@0<2P/03@/<00l=3P0=2``02`T:
00H41@0:20T06ALH010>3`0200403`d>00l>300@3`d03`h<0P0=30X04@0@3`d03@`:00<2000A40h0
0@0002HU8`1UI6<07A/L00P61`0D4Q<03@/<00h<3@0?3@h03P`=00l=3P0>30d03@/<00803P`=1@0=
2``03@0@3Pl02PP900H41@0B41406aTJ03@b<`11?d00@T1101dK700;2@X04Q0A014?400D4Q<00P0?
3@h01@0B41404a4B018@4@0;2`d02PX<008030`>00D02`/=00`<3P0>3Q003`lA010@4P0200h>400C
014A4`0A41D051<H01<B5`0?3Q<040lD014@5@0B4AH06APM010?500;2Pl03`hC01<B5`0C4QP03@`B
018A5P0F5AX03@`A01/K7@02010@4P0;00l?3`0=3@d03@d=00h>3P0<3Pd05aTH01DG5P0;3@`02P`;
01DG5P0@4Q400P0B51<02`0@4Q404A<B018D4`1HF5P061PH00/;2`0?3`l0:2PX00d=3@0@41004A4A
00804Q8B00@04A4A010@400D51@05ADE100F5QH05P0M7Ad07alO01TI6@0G5aL05QHF014A4@0F61L0
6A/J01<E500K7A`08R@S01/M700E5aH05QPG01LI600H6QT06A/J01XJ600T8Al08AdL01dI600J6AL2
01XJ6P0701dM7@0N7b407AhP01/L7P0P8BD08bLZ01XO8P0201TN8@0T01/P8`0L8B@07B8U01TN8@0N
8bH05AXM01lT9`0M8RD082DX01/P8`0O92L07RDW01hV:00N9RT072@X020Y;P0T;C809Ble020[<@0L
9bd07BT`01LT;00d@DT0:3Dm01h[<`0J9bl08c0h028_=`0Q;SH08Rlg01l/=00M:S808Blf020_=P0J
:C006BP_0`0K:S40A@0O;SD05RD/01l^=@0/>d8082lf020/<`0P:C007BH]024Z<00U;S<07bP]01hX
:P0J92H072HW028/;@0P:R/07BLX028Z;@0L8bT09Rdc01LN900M92X072<Y01/R:00/<cT092/a01PO
9@1`Mgd0=3a001dW:00D7Ql07BLX01LO8@0M9BL0620R01DJ7@0F6ah061`O01HJ7@0E6A`05a/N02X^
<@17Bdh07b<V01LK7P0b=ST04aLJ01LK7P0N8RD05ATL01@H6`0L82<06AdP01@H6`0H71l05a/N01TM
800M8B@061`O020T9`0B5QT0=SXm01lS9P0A5AP0;C4d01TJ7P0F5a/051DI01DF6P0201HG6`0N018C
5`0J6al04A8F014B5P0J6al051DI01XK7@0F5aT06a`N02h_<@0_<3803PlA01LH6P0H6A/06AXL01PI
6`0F5aT05AHH010B4@0D5QD06A/J01LI600C5A@05ALF01<E500D5QD05ALF01@F5@0B51<04A<B0P0I
6A/01`0G5aT051@F018B500C4aD051@F01<C5@0B4Q@00`0A4A<01P0C4A8020H701PF5`0A3a000P01
00d;30D03`d>00L040`=018<300C3@d050h>018<300@2PX04@/;00804P`<0`0A2`/0200?2@T05@l?
01LA4@0?2@T04P`<01<=3@0?2@T040X:100?2@T0100=1@H0:b4R01D;300=1@D200l51P0?01@:2`0B
20T040H70147200C2@X04PP901061`0?1@H05@/<01@:2`0<0P<02`8200/10P08000050X;008040H7
00d03P@500l51P0@1PL06@l@00L0000U6a`02`8301D;300700005@/<02TO800B20T06@l@00`03`@8
00H04`L901@82P0A1@L03@4300h2100:000600l31@0301862P0@10P04@D900803P8600L05PX>01D9
3@0C1`/0300401862P0J3Q803@4501Cooooo000Kooooo`0400d<200<2`L030/700l>2P804Q4=01h0
:2LS00`;1`0?3PX030/700d<200B4@d03Pd;00l>300@3`d03`h<00h=2`0=30X03`h<02PW9@051080
5A@B010?3@0000001@X900hB4@042@D03Ph:01<@2`0>2`@04Pl6018?200C40T04A0;00l@2`0>3`X2
010?3@0?01XI5`0@3`d03`h<00h=2`0=30X03`h<00h=2`0=30X030/900d<2P0@3`/03@`8018A3@0J
6AD05QDA008040l;014030/700L60P0:2@D03Pd900P8100<3@P010D000`=20082@@04A8=00X;1P0A
4Pd03Pl:00d>2@0;30L01`P300h?2P02014B3@0A00d>2@0:2`H030d800h?2P0;30L04a@?02@U800J
6aH03a0;00h>2@0;2PD02PT4018A300C4Pd04A0;010?2P0B4@`00P0D4`h0100B4@`04A0;00l?300=
3@/300h>300:00d=2`0C4a402@T7018B400F5Q@02@T700`<2P0@3`/03`h:00h=2@803`h:00<03Pd9
010?2`0<2`L00P0;2PH05@0<2`L05QDA00/:1P0:2@D040l;01@C3`0>3@T081lK014@300<2`L03@`8
00/:1P061@404A0<00`;1`0;2PH03`h:014@300<2`L02`X600h=2@02010?2`0:00h=2@0?3PX040l;
018A3`0:2@L02`X800`;2@0A40h08R4O01dL6P803`h<01@040l=00X91`0<2`T04a<A00D5100;2`T0
3`l=00X:200?3`d02`/900d=2`0<30X02`/900`<2P0?3`d02PX800h>300@40h03Ph<00d=2`803Ph<
00l03@d;00`<2P0=3@/03@d;00h>300E51804A0>00d<2P0?3P`02@P600d<2P0<2`T03@`:00h=2`0?
3P`00P0>3@/0200B414081hO01TG600;2@X03@/<014?400<2P/03P`=0P0=2``01@0?3@h04Q0A00h=
2`0=30X030/900803@`:00L03Pd;03ln?00O7Q`05QDC0040000G5Q@03@`:008030/901L05A@B01dL
6P0B4@l02`X800l>300>3@/03@`:00h=2`0?3P`03@`:00/:200@3`d03`h<00P71@0:2@L030/900l>
300G5Q@05QDC00h=2`0?3P`04@h=010<2`0300l;2P0700h:2@0@30/03@T800T5100C3`h07a/J018>
3@02010<2`803`/:014040`;018>3@0>2PT02PH5014=300?2`X04`l>01HB4P0<2Pd040hA00h<3`09
1`X030X=00h<3`0C4A@040hA00X82`0200D31P0500L5200F4Q<04@d>010<3@0B3Pl00P0?2``03`0@
30d04`l@01LC500E4A804Ph?010<3@0I5aX08b4T02PV:@050`H040h@00P61`0?3@h03`d=00h=2`02
00h=2@0@00d<2P091@H03@P<01HA5@0K5QX05A0D02hY;@0C3Q8050lC00h93@0<1`/03@P<00/62P0=
2`h03P`?00d;3P8040hA00h020H9010>4@0@3Q403`d@00d;3P0?3A0050lC00h8300@2Ph04@`@010>
4@0=3@l030d?00`<3P803@/>00X03`X>010:3P0@2P`0510?014=300?2`X040`;018>3@0C3`h03PX9
0P0B3Pd0100A3@`04Ph=01<?3P0?3@h200d;300:00h<3@0=2``030X;01HD5@071@H0CD]<03Le=P0G
5AH04Q0A010?3@<03Pd;0P0?3P`03@0I61H04a8@00d<2P0100001@@2024O7`0@3Pl01`D600P61`0J
61T06ALH00P61`0=2``00P0>30d200`:2`0400l=3P0@3Pl040h?010>3`803`d>0P0>30d02`0<2P/0
7A/L01lM7P0Z:2T05aDF00`:2`030@803`d>01LE5P0@3Pl04@l@00803@/<00H03`d>010>3`0A3a00
4Q8D00d=3`092@/200L72@0L010@4P0>3Q003`lA010@4P0?3a40410B01<C5@0@3a@04A0E010?500=
31403PdB018A5P0:2@h05aHK00l>4`0<2a002`X?010?500=31800@0601PG702ZZJh0<C0e00l?4@0A
4A<0410B00l?3`<03@d=00T04A<B00H81`0;3@`06A/J01PJ6@072@P0418A01<E500B51<00P0A4a80
2`0C5A@0FEUI028R8P0C4a<06QXJ02l_;`0K6a/0410@014A4@0B4Q804a<C00804Q8B1P0D51@0300F
5QH06ATI01HF5P0E5AD05aLG018B4P0D5QD05QPG01@F5@0L7Qd0828Q01XL6`<05aTH03D06A/J01XL
6`0L71X09b@R02@P7`0O6aX07A`J01hN7P0L71`06a/K01dN800J6ad05aPJ01dN8P0Q9BP0720S01XO
8P0I7R406b0S01dR9@0N8bH07B8U01<H6`0I7R407b@W01TN8@0/<C@06QlR01lT9`0O9BP082PZ01lW
:P0O9b/0:S<h02H_=00R;3807bX`01`W;@0T<3L06bP`030mA@0M:S809C8j01PU;@0T<CT08c0h02@a
>@0Y=Sh0934i01h[<`0P;SH08C0g01d/<`0201PW;P0J01XY<00L:c8082lf01TX;`0Q<3L0:cY101h]
=00O:c808BXa01lX;`0Q:S008b`a01lX;@0F82805b4S01/U9P0N:2T07BLX01XT9@0S:S006b8X01`S
:@0K8RP08RT_020W;@0V;C<202T`=P0G01dT:P1hOhD0>D55028/;P0I8b@07BLX01/S9@0J8R@06b<U
01HK7P0G71l06AdP01HJ7@0E6A`05QXM01LK7P0`=3L06alR02DY;016BTd09BT/01DI700K7b800P0I
7B000`0M8B@0720S01<G6P0201DI700;01PL7`0K7b804aLJ01XN8@0D61/05ATL01LK7P0U:B`00044
01TJ7P0H6Ad0100F5a/0200C51P06Q/O014B5P0>3a<05QLK01<D600@4A<05QLI0P0L7Al01@0G61X0
3a0B01XK7@0J6ad06AXL00<061TK00L03a4@01DG5P0I6aX051HE01DG5P0K7A`04aDD00D04Q@C00@0
6ATK01PH6P0G5aT05QHH0`0D51H00`0B4Q@04A4C014A4`02018B500601@B4`0C4A807adN01LE5P0D
4Q<08AlP1@0A3a001P0B3Ph04P`<018<300B30`04@/;010:2P803`T900<040X:00l92@0?2@T00P0A
2`/01P0@2PX03`T900l92@0A2`/040X:00h820<03`T90P0>20P02P0;10@0718C00`20`0=10@03P@5
0147200C2@X04PP901061`0B20T301<92P0G01@:2`0=0`@040H701`B4`0K4A808ALH01882@0@1PL0
308301061`0J41406@l@00L0000>10D060h?01dC500D2P/04@L800L0000J4Q801`0000P0000=1@D0
300?10P00`0A1@L04PH801451`0201041PL03`<500`04@D90104200B1PX03`<700`0100@10P02`03
01@8300<00@04PH:01lC5`0<00@Dooooo`006oooool03@0;2PH03Pd900d<200<2`L03`h:01<B3P0B
4@d05A@@02TX900J6AD030/701DD400@3`d00P0B4@l01P0A40h03`h<00d<2P0?3P`030/900d<2P80
51<A00/03Ph=00lE500>4Q00310<01XK5P0A3`X04Q09014?1P0C40T04a4:018A300200h?2P0500h=
2`0B4@l04Q4?010?3@0A40h00P0=30X0<@0>3@/04A0>01<B400>3@/02PT700h=2P0<2`P03@`8014@
300B4@h04Q4=010?2`0>3@X05QDA02HU8@0J6AH02PX601DF4@0:2`H04A8=00T:1@0=3PT02@X600l@
2`0>3`X0414<00l@2`0:2`H03Pl:00d>2@0?40/05AHA01@E400?40/03Pl:00`=200=3PT051D@00h?
2P0@4@`07AdH01HE400>3@T04A0;00h=200<2`H03Pd800`;1P0;2PH00P0A40/02`0=30P030`900d=
300>3Pd03Ph>00h>3@0=3@`04Q8B00L71P0?3`l030`<00803`l>00P03`h:014@2`0B4@`03Pd900`;
1`0?3PX04A0<00d<20803`h:00X03@`701DD3`0B4@d020L300l>2P0B4@d02@P502DT800?3PX040l;
0P0=30P02@0?3PX040l;00h=2@0;2PH040l;018A3@0=30P03`h:00d<200200l>2P0=00d<200>3@T0
3`h:010?3@0=30X04Q4?00d<2P0?3P`09B@R02XY9`0A40h03@`:014@3P0200`;2@0B00/;2@1?Cdd0
5ADC01<C4@0>3P`03@d;00/;2@0=3@/030`:00/;2@0<30X03`l=00X:200=3@/030`:00/;2@0=3@/0
3`l=0`0<30X02@0>3P`0410>014A3`0;2PP030/900l>300:2@L04a8@00`;2@0300h=2`09014@3P0D
4a405A@B00h<3@0B41403P`=00d;300>30d03@/<00803`d>00L03P`=00`:2`0?3@h04@l@00h=2`0=
30X030/900803@`:01P03Pd;01HE4`0;2PP03`h<00L6100G5Q@030/9010?3@0>3@/020L500h=2`0@
3`d03`l=010?3@0>3@/03@`:00h=2`0@3`d02`X800h=2`0D4a403@`:00`;2@0?3P`200`;2@<03@`:
00D03Pd;010=300@30/040`;00l;2P0300h:2@0601TE500K5aH05A4@024M7@0C3`l040`;0`0?2`X0
8@0@30/04Ph=01DA400>2PT040`;00T5100<20L040`<00l=400?3A4040hB01XH7@0O7B404Q0D00d;
400>31003`dA014?500A3a<03P`@018>400=2@X03`/<018>3`0?2``040`=014=3P0C3a00510A00l;
300=2@X03`/<00X92`0200d;3P0@00`:2`0=2``04@l@00d;2`0>30/03Pd;00h=2P0?3P/040l=00l;
300C3A402`D9014;3`0A30l05A0D01@>4P803`T=00D071HJ028M8@0A31004a4D010>4@02014?4P05
00`:3@0?3A002PP;010>4@0?3A000P0=2`h01@0?2`l04`dA018=4@0?30l03P`?00<030`>0P0=2`h0
4P0?2`h040X>010;300>30T03@`900`;1`0=30P03`h;010?2`0>3@X040l<010?2`0?3PX03Pd:00l>
300B41403@/<00`:2`<03P`=00T05A<D05UGF00_;Bh071XK00d;300k>CX04A0>00`:200<2`T00P0B
40h03P0>3@/03`h<01HD4P0G5A<04A0>00h<2P0;2PT03@`;018A400@3`h05aHE01/I6P0>30d03`d>
0P0A3a0200h<3@<040h?00l03`d>00h<3@0>30d03`d>01/I6P0=2``06ALH01DC500A3a003P`=01<A
4P0A3a0061HG018@4@0;2@X00P0C4A80200A3a003P`=00d;300?3@l04A4C010@4P0G5aT05ADG0P0>
3Q001P0=3@l03`lA014A4`0B4Q@04a<E01LG6@804Q4F00T04a8G018A5P0?3Q<04A0E00l>4`0C4QL0
4A0E00P7300@3a@00P0C4QL01@0@3aD0410D01hM8P0B4QD06QXL008051@F00/04Q8B010@400@4100
410@01@F5@0=4A007B4P030d<`0X;2/020`;00lC4P02014E500700lC4P0@51<04aDD01PH600C4a<0
3Ph>018B4P0201<C4`03014A4@0C4a<051@D00<051@D00@071`L01/K6`0I6AT05aPH0P0F5aL02@0E
5QD06Q/J01PI6@0I6AX06a/L01HF5`0H6QT051HE01DG5P0201TK6P1;01PJ6@0K7A`05aTH01HH5`0I
6aX07AlN020Q7`0N7AX07a`K01TG5@0K6aT081lO01dL700O8200:2PY02HW9`0L7Qh06Q/N01/O8@0L
8R<06QlQ01TN800I7b80724T01`S9P0W;C008BP[02H]<00Q9bX0728U028Y:`0O9RP07b@X01TQ8`0N
9RT07bLZ01hV:`0Y<cL08BX_02H`=P0V<SP06R@/01l/<`0I9bl09S<k024^=P1;F600934i01h[<`0Q
;SH0:SLo030mA@0U<SX08Bhf02<a>00R<CP07bhe01LV;@0B8BP062L^01h]=00U=3X07R`c02<a>00[
>D008Blf020/<P0P:c408B`b020[<00N:Bd07bX^01`W:P0P:bd08bl_00807b/[03@07bX[020X;00Q
:Bd06b<X02<Z<00N9RX082L/028Y;`0K8bL08BT^020W;@0W;c<08BT^028[;P0P:R/06R<T01hV:00I
8B<0?TI801TN8@0J7b806alR01LK7P0E6A/05QXM01`P8`0J7R40720S01XN8@0M8B@05a/N01TM800F
6Qd06alR01XN8@0G6ah07b<V01LK7P0O8bD07B4T01TM800G6ah05ATL01<G6P0H71l07R8U01/N8P0L
7b<061`O01TJ7P0J6al06AXN0`0G61`07`0F5a/06a`P02`]<@0O82@0414E02l`=00/;Bl061TK01`M
7`0O828061TK01/L7P0M7R006a`N01LH6P0H6A/06Q/M01/L7P0F61L05ALF01PJ6@0G6AP051HE01LI
600F61L04Q@C014C4P0B51<05ALF01LI600F5QP00P0D51H0100E5AL051@F01<C5@0C4aD2014A4`09
018B500D51H05ADF01PF5`0J61T04@l@00h<3@0A3a003`d>00D040h?00<04Ph?01<=3@0A2`/00P0@
2PX02`0A2`/04P`<01<=3@0D3Ph04`d=01@>3P0H4Q805a4A00h8200@2PX05@l?00803`T900@04`d=
018<300A2`/04@/;0P0@2PX01P0B2P/05@/<00d3100G3@h03`D601L=3P804@L800L03`D601061`0B
20T04PP900l51P0C2@X05@/<008040H700H040L802XP8@0H3a004PT90108200@1`P200h41@0;01@:
2`0D2`/03PH600l71`0@1`L03P@501@<300c:BX03`H701hD5@0@1PL0300?10P200h3100401041P0A
1@L040@601451`H03`<500L04PH:0104200C1`/04PH:00l31`0B1PX040@800804@D90P0B1PX00`0?
0`Ooooooooooo`0Booooo`006oooool0:@0@3`d02@P600T81P0?3P`04a8@00l>300K6QP02PT801dL
6P0A40h040l=01<B400@40h03`l=014A3`0E5A<04a<A00L71@092@L03@d;00h>300;2`T020P6014A
3`0F61<03a4<014B3@0B4`d03Pl900H70@0>3PP04Q4<00X;1@0;30H0414;00/<1`0>3P`030`:00/;
2@0=3@/03Ph<0080410>01@02`/9010@3P0J6QP05ADC00d=2`0:2PP07alO014A3`0820P0:RXZ0000
000=3@`06a/K0000000P81l01PH600l?300A4Pd03Pl:00X;1P803a0;00@02@X500X;1P0=3PT03Pl:
0P0<3@P00`0=3@X030`:00h>300201LG5@0U010@3P0>3P`0410>00P81P0<30X05QHD0492@01<C4X0
2@X500`<2P0;30P07QlJ00@40P0>3P/03@h900l?3@0@4@d03a0;00d=2`0>3P/03@h900/<200=3@/0
3Pl:00h>2`0=3@/03@h900`=2@0<30X03@h900h?2`0=3@D0514800l<1@0@3@P06AHA01<?300200d9
1P0L00l<1`0C40T0514:010?1P0E50l03@h800/<1P0<3@L02P/500d>200;30H030d700l@2P0E5Q00
3@h800/<2@0D5A000000014A3`020P0051@B00L71@0o?cd051@B014A3`0F5Q@030`:018B40803@`:
0P0>3@/2010?3@0U00X91`0F5A<010<1010?3@071P@03Pd;00H6100n?S`07QhL01HF500<30/03Ph<
014A3`0=3@/030`:00l?3@0@40h03@d;018B400=3@/03`l=00d=2`0;2`T04a<A02TY9`0A4@l0410>
00`<2P0A4@l06QXH01<C4@051@<020P600d=2`0B4Q003`l=00X:200200d=2`0=00/;2@0=3@/0410>
00d=2`0A4@l01`L500`<2P092@L01`L5018B400@40h02`/900P81P0200T91`0301<B400?3P`030/9
00<02PT7018030/900/:200<2`T03Pd;010?3@0B40h030P700T81P0=3@/01PP500X?2`0l@Cd0QHZ6
014C400;2PP040l=01TE500>2`X2010?3@0400/:200>3@/03Pd;00X91`8030/900D03@`:00`;2@0;
2PP030/8014@300201@C4@0A00d<2P0:20T02PP900d;300>30d040h@00l=400>30l04@l@00`:2`0:
20T04Q0A00<10P0N71d04@l@010>3`0>30d00`0=2``0@@0<2P/00`4200h<3P1PGV40QhF600h<3P0<
2Pd03@/<00h<3P0>30l03@/<00d;3P0;2@`04Q0C01DC5P0;2@`020H9010>4@0;2@`01085010>4@0<
2Pd0518E00T72P0<2Pd03P`?00d;3P0<2Pd03`d@01<A500?3A0030X<00H41@0D4Q<030X;01/I6P0=
2`h03@T=014?4P0A31005A8E02l]<0080`L03``?01HD5`0<1`/0Ad=701PF6@0D4QD05A<F014?4P0=
2`h06ALJ00X82`0<2Pd04Q0C00@21@0J61/02@L:01<A500>30l02PP;018B500A4A<02PX<00803@d?
0140410B00/;3@0:2@`05A<F00X82`0=30/040h?00d<2P0;2@T03@/<00h=2`0A3`l03P`=00h=2`0?
3@d040h?00d;300200h>3P0500/;2`0=3@d03@d=00P8200J6QX00P0C4a<09`0>3Ph030`<024O800>
2PT03`T900l;2P0@2`/04@/;02XU900K5aH03`T9018=300<20L050h>00h:200@30T04@d:010<2@0C
3``04Ph=00`81`0C3`h06aLF01HB4P0=2@X040`=018@4@0>3Ph030`<00d=3@0?3`l03Ph>00d=3@0@
41004a<C00l?3`092@T02`/;00l?3P0200l?3@0>00d=300=3@d0410@020P8@0?3a4020P:01@D5P0:
2P`040lC01HF600410@07QhN00X:2P0C4a<2014A4@0Z00`<300B4Q80<C4a01@D500=3@h06APM00P7
300C4QL00`8701/J7`0F5AX07A`Q00H52P0D4aP04Q4F02<R9`0H5a`0410B01HF600A4A805QHH01<C
4`0>3Ph04a<C00l?3`0B4Q80410@00`<300B4Q804a@F01@E5`0f=cT06AXL01DF5`0B51<04A<B00lA
3`0@4Pl03Q0=01PJ5`0_<Bh0410>0P0A4@l00`0@40h04A4?01<C4@0201HF500A014A3`0D51804a<A
00L71@0E5AD05aPG01LI600D61L051TH01DK6`093`l0Ff1P06AXJ@0I6Qh07AdQ01TH7@0E61T00P0A
5AH0900D61T05QXK01HJ6`0C5aP06alP00P<3@0K7b0082@U01@H5`0O8Ad07AlJ02la;00J71L051HA
01HH4`0L81`0<C<`03<h=00Q9R806QlK024V8P0D71H06B8M01LP7@0I8R<072<Y01PQ9P0/=C`0:SDi
02<^<P0X<cD07RXZ02@`<00J92H06B0V01`V:@806B8W04X07BP^038oA@0P:c409c@l01XY<00P;CH0
7Rdd01X[<P0V=C`0>4M>03=2B@0_?TD0;Sa402Tf?P0U<SX09S4j02H`>@0S;CH07R`b01/Z;`0H9b`0
5B@Y01PW;00P;C<08Bhd01l]<00U<3H09c8g02<^<P0N:Bl06R@[02D^=`0N9c008b`c02@]=00Q:S00
8b`a01hW;00J8bL07BLY020Z;00O:B/092h`01/W9`0M:2T082X/01LS8`0I92D07RPZ01l[:`0P:b`0
72HX01XV9P0O:B/08BT/01XR9@0K82<0724T01LL7`0G7Ad06b4Q01XP800I7ah06AlO01XP7P0M8b<0
5a/L01/O800H71d08RHW020T9@0H71d06QhO01/O8080720Q01406alP01XN7`0K7b007R8R01PL7@0D
61T05a/M01TM800L7b@061/P010C600B5A`07R4X01LJ7`0P8BD061TK01XK7@0201<D5P0301TJ700E
5QP05AHH00806a`N00L05AHH01/L7P0Q8RH06AXN01hO8`0R8bL071dQ00D061TM00T05QLK01DF600C
5aP05QXK01@H6@0I7Ah030d?010A4`0D5AL00P0?3a401@0G5aT071`N01dM7`0C4A80518C00805A<D
0P0D4Q<0100P7Ql0:BLX00L51P0G5AH201@B4`0D01<?3`0D40l04`l>010<2`0?2`X040`;01<?3P0G
4a804@d<01HB4@0J5QD03@T801DA4012?Sd02PL601PD4`0B3Pd02PH5010<2`0A3@`200h:2@0B014=
300F4A805Q0B01@>400B30h04@/=018<3P0>20X06aDG00/51`0G4A<0100001dG6@0@20T040H700l5
1P0F30d05@/<0P0B20T00`0>10D03@<401882@0200l51P0601@:2`22O7`0<2PX00h51P0@1`P02P82
0`0A1`P30186200601T?400700004PP900/10P0F30d040H70P0B20T200d3100501061`0;0P804@L8
01061`0?1@H00P0A1`P01`0@1PL0308301L=3P0C2@X05@/<01<92P0;0@801P0>10D04P0;0@802P01
01061`0B20T03P@500X00@0:008040@800l31`0@10P04`L;00X00P0C1`/040H800P0000Q5AT03`D7
01452ACooooo000Kooooo`0501TH5P0C4Q003`h<014@3P0@3`d00P0=30X02`0?3P`00P400040000L
6aT03@`:00/;2@0:2PP030`:018B400E5A<04A4?00<03Ph<02d06ATG02TY9`061P@01`P301LH4P0H
6A<051D?00P90`0F5a403@h800l@2P0=3PP0414;014B300=3PT03Ph<00d=2`0<30X03Ph<010@3P0A
4@l03`l=00/;2@0?3`d05QHD018B400<30X04a<C09RHV01FEUH05ADE00L71`0>3Ph04Q8B00410@0>
3Ph05QHF010@400=3@/030d8010A300?40/0414<00/<1`0720@00`0<3@P07P0>3`X04Q<>018C3`0=
3@/030`:018B400D5180410>00`<2P0A4@l0410>00l?3@030`404Q8@014A3`071`D061PF00L71@0;
2`T01PH400l?3@0<30X03@d;00h>300=3@/030`:00h>2`0=3PT02``700d>2@@03Pl:01403@h900`=
200<3@P03@h9010@1P0F50P04Pl7018?2P0J5a80510=00d91P0>2PL04@h9014>1`0A3PD040l400d>
1P0200/<1P0E00h?2@0A4P`04A8<018C3@0L7AL04A8=00D6000E5Q002P/50082000F5Q@02`/:00d=
2`0>3P`04A4?020P7P0;2`T030`:00h>30071`D03Ph<00<03@`:0`0>3@/03@0;2PP03@`:0040000B
4@l05aHD00H50`051@<02@T700@40P0A4@l0410>00D50`0@40h00P0<30X01@0>3P`03`l=00d=2`0B
4Q0030`:00803Ph<01403@d;018B400U9B<030`:00L71@061P@01@D300l?3@0410804Q8@02PX9P09
2@L08B4O0000000<30X03Ph<00d=2`0200/;2@0A00d=2`0>3P`030`:00l?3@0C4a403`l=00X:200@
40h030`:00X:200=3@/0410>00l?3@0>3@/03@`:00`;2@0=30X00P0>3@/04P0=30X02`X800`;2@0=
30X03`h<014?3@0<20L02`X8014A3`0<3P/03a@@07MmN@3DfMD0BD]800d>30081`D03@T800h;2P80
4A0>01`030/900l>300?3P`030/900d<2P0?3P`040l=00d<2P0;2PP02PT600d<200?3P`040l=00l>
300@3Pl03`d>00`:2`0>30l040hA00l=400?3A401P@7018@4@0=2``030X;00l=3P0A3a003@/<0P0>
30d200d;300900l=3P0:20T04Q0A00l=3P0A3a009bDV00`;2`0<2P/03@/<00803P`=0P0=2``05P0<
2Pd040hA01<A500<2Pd02PP;010>4@0A3a801`D800h<3`0<2Pd05aDH01<A500=2`h03P`?00d;3P0<
2Pd03P`?014?4P0:20/040hA01hL7`0=2`h200`:3@0F018@4`0?3A004Q0C00d;3P091`X06ALJ00d;
3P0;2@`05Q@G00/9300[:B`03`d@00D31P0;2@`04Q0C01HD5`0[:B`08b4T00P62@0@3Q4030X=00X8
2`802@L:02L03Ph@01@D5P0=3@l01`L900T92`0:2P`0410B018B50051@L02@T;00X:300G5aT02PP9
00D3100;2@X06ALH01LE5P0?3@h0518C00X82@0;2@X03`d>014?400:20T03@d=00h>3P0=3@d0410@
014A4@0=3@d0000000D51@0C4a<04A4A00`<300A3a003`X900l92@0@2PX00P0A2`/03@0F41004@/;
014;2`0C3@d04@/;00l92@091@<04@h9018?2P0@3@T04Ph;014=2P0>2PP00P0=2@P01`0@30`04@d>
010<3@0?3Ph03`l?00d=3@0>3Ph00P0?3`l200d=3@0F010@400B4Q803`l?00/;2`0;2`X03@d;00h>
300>3Pd03Ph>00l?3`0B4Q<05ADG01LG6@061@X02`X?01HE6@0h>3X03`l?00d=3@0<30`05aLG014A
4@803`l?00d09RHV03dm?@0T92@04A4A014A4`0C4QL03`hC01TH7@0E51T01PH:0000100B4AH05A@I
00804A0E00T06QTM014A4@0G5aL0410@018B4P0?3`l0410@014A4@0C4a<00P0N7Qh01`0@410030`<
00`=4@051PT07AhP018C5@0@4A800P0<3Pd01@0?4@l05ALD01<E4P0@4Ph05aTD00805ADC01X04a<A
018B400B4Q004a<A018B400@40h05aLE01<C4@0D51804a<A01HF5P0F5aH04aLF01@H5`0C6QT04AXI
02L`;`2b^KX0]KZm03Xk?`0D51T05AHJ01TL7P0E6AX051PI01HJ6`805a/L04L06QhO02T];P0N8R<0
5a/L00hB4`0R9RD05a`G02ld;P10ACl07B8L01<H4P0I7QP06b0J020U7`0R9b40724K01/P6P0Q:240
7BHN01`U800J8b00628R01TR9`0L9B`0MX2909bY[`0nC4l09C<e01l];@0J:2P07bP]01dV:`0P:Bh0
7RL/01dX;P0R;S@09C8h028_=`0R<3P06bTb02Hd?@0P<3P07Rlf02<d>`0[>d809SDl024`=`0X=Sd0
<Sm702hk@`0Q;CD06bD^028/=@0R;cH07B`a01l^<`0S<SL08S4f020]<`0O:c007bX^020[;`0R;340
92db02D^<`0Q:S40;SM002L`>@0P:C40:S<j02D^=@03020Y;P807RPZ00@08B/]01`X:00F8R8062@T
0P0R;Rh03@0O:b/07BTY01l[:`0P;2`07BTY01/W9`0N:BX07RHY024V:P0U:Rd07B8U01DJ7@0K8B40
0P0J820201TO7@0;01XP7P0L8R006QhO01dQ8P0K7b005a/L014E5P0_<c@06AdN01XN7`0K7b000`0L
82404P0D61L061`K01`P7`0L82407R8T02<W:P0L7b@08RD[02HY<00T9bh0=3Lo00`?5P0J6al04Q<E
00H72@0A4Q@05aPJ020Q8`805AHH00L06Q/M01TJ700D5AL06AXL01LH700E5QX05aPL008071dQ00@0
5AHJ01@E6@0F5a/05aPL0P0H6Ad02P0F6Qd05a`M01lS900Q9BH0:2`]01DF600D5AL061TK01HF600C
4aD2014A4`03018B500D4Q<0518C00@0518C00@0>3Hg03Tg>00G5AH061HG0P0;2@X0500M6AP0510?
00l;2P0?2`X05A4@01LC4P0<20L03`/:01TE500=2@P030P7018>3@0U8B00Ge]J01@@3`03000040`;
01PD4`0@30/04@d<0P0>2PT01@0A3@`05A0@01<=3`0B30h04@/=00803`T;00T05a4C00@0000;1@L0
O7Ih01PB500400004PX;01061`0?1@H00P0D2P/01@0C2@X04PP90147200F30d05@/<00802P0100H0
3PD602TS8`0<1PH05@`=00`3100F3@h301061`<04@D700D03`D600d3100D2P/03083014720020106
1`804PP900H04`T:01H<3@0?1@H04@L801061`0?1@H20147200701061`0>10D03P@500h41@090000
308301P>3`0600h41@0B01P>3`0F30d0MVa]079XJ@0@1PL06Q0A00h21P0E2@d040@800l31`0A1@T0
3P8601862P0?0`L0300401P<400J3Q8020005?ooool001_ooooo00@05QDC01DD4P0B4@l03`h<0P0>
3@/2018A3`0M01@C4@0;2PP03`h<01@C4@0H61H0410>00d=2`0?3`d0410>014A3`0@40h03Ph<010@
3P0U9B<0@T9001<C4@0P8A`0P85l05mPF`0J6aH030d800l@2`0@4@`020T400h?2P0@4@`030d800d>
2@0>3P`00P0=3@/00`0?3`d04Q8@01<C4@0200h>30803`l=01D03@d;00`<2P0A4A40GemO02d];@0C
4a<04Q8B00`<300:2PX05QHF04U9B@0o?cl03`l?010@3P0?40/04A8=010A300?40/03@h900h?2P0@
4@`00P0?40/01P0C50l06Q/F01PI5@0=3@/02PX800`<2P80410>00d03@d;00l?3@071`D02`/901LG
5@0X:2H04a<A00d=2`0>3P`030`:014A3`0D518020P600D03@d;00@03Ph;00d>2@0;30L03@h90P0>
3`X2010A300900h?2P0<3@P030d800`=200>3P@04A4600h>1P0<2`H04A0;00803@`801d03`h:010?
2`0;2`<02PX1010@1P061`404A8=014B3P0:2`L0414<00h?2P0=3P`01@H1018C3`051@<0414<01TJ
5P1PH5h04Q8@00d=300=3@/02@T700l?3@0:2PP03`l=010@3P0=3@/02`/900d=2`0300d<2P8030/9
00h02`X800X91`0>3@/02`X8010?3@0Q81h04Q4?01<C4@0>3P`05QHD00l?3@071`H05QHD00h>3080
3@d;0P0>3P`0300<30X04A4?00X:200;2`T0410>014A3`0@40h04a<A00P81P071`D0410>00`<2P80
4A4?00D02@T700H6100F5QD02`/9010@3P0200l?3@0=00h>300<30X02`/900`<2P0?3`d04A4?01<C
4@071`D03Ph<00d=2`0>3P`02@T700X:200200`<2P0300d=2`0=30X03Pd;00803`h<0P0=30X04P0>
3@/03@`:00d<2P0=30X03Pd;00l=2`0<20L02`X800l?3@092`P020d901/P700i?SX0418?00`<2P0P
7ad02`P700h;2P8040l=00H03Pd;00l>300?3P`030/900/:200<2`T200d<2P0B00/:200=30T03`h:
00d<2P0<2`T03@`:014?400@3Pl02`T:00d;3P0?3A0040hA014?4`091`X05aDF00`:2`081PL05Q@E
0P0:20T03@0>30d04@l@00h<3@0=2``040h?00P61`0?3@h05Q@E018@4@0=2``02`T:00`:2`0=2``0
0P0>30d200d;300300d;3P0>30l03P`?00803`d@01D040hA00d;3P091`X03`d@01<A500E4aH02PP;
00l=400A3a803`d@00`:3@0=2`h03P`?010>4@0;2@`04@lB00H41`0E4aH02@L:00l=400<2Pd00P0A
3a805P0<2Pd040hA00l=400:20/05A<F01<A500>30l03`d@01<A500B41<04@lB00/9300C4A@02@L:
01<A500:20/04Q0C00`:3@0B41<03P`?00L72@0@418200X:300:010@4P0>3Q003@d?00H6200@4180
2PX<010@4P0<30h03`d>014?40805A<D00d03`d>00h<3@0C4A801`D600/92P0@3Pl06QPI00d;300@
41003`l?00`<300?3`l051@D00804a<C00D051@D01<C4`092@T05ADE00D41006010<2`0601PD4`0A
3@`03PX901<?3P0>2PT040d:0P0A40/01`0>3@T040l;00l>2P0>3@X040l=010>3`0?3@h00P0>30d0
200@3`l0410@00h>3P0?3`l04Q8B014A4@0@41003Ph>0P0=3@d200`<300@00`<2`0=3@/03@d;00l?
3@0@40h0410@01TI6@0=3@d03Ph@00X93P0B4AH040lC01@D5@0<30`051@D018B4P803Ph>00<04Q8B
00/;2`0J6QX00P0B4Q809@0?3`l061PJ010@4P0C4aD06ATK04=3A@0U9BL03@d?01dM7`0>3Q00Bd]=
04A4AP0>3Q003Ph>01<C4`0>3Ph051@D01<C4`0@41004a<C01HF5P0N7Qh07AdM018B4P0=3@d05QLK
010A500=3Q0071dO018D500B51<04A<B00lA3`0B514051HC010B3P0?4@`00P0E5A<201<C4@0F018B
400@40h0410>01@D4P0N7Q`01`L501<C4@0F5Q@061PH01<D500A5A@05ATH01@K6P0>5aH03aPG04iE
EP1?E5L06Q/O01hN8`0F5a/06Q`O01LK70805ATJ02d05QXK01LK700I7Ah03A4B02<W:020Q8D0ATY;
01`P7`0N8al051TE01lT800J7a/06AhJ01@I5@0J7a/05Q/G01`Q7@0O92006b0L01XQ6`0L91d0624L
020Y9P0N:2T08R/`02hg?02HXjL0bMKL055OHP0W=CL082h^01/Y:@0S;34082T^02<]<`0Q;3808Rdc
02Te?00J9bl0:CHn02@b>P0Z>4408Blh01h_=`0T=Cd00P0W>4005@0/?DD0;C]402Pf?`0W=3d0934j
02Td?P0Z=3h09Bli01l/=00Q<3D08c8g028a=P0O;S<07R/a024]<P0S;S8082/_020Z;`0S;3409Rld
02</<P02024Z<`0<02</=00O:2l08BXa01lX;@0Q:Rl08b`a01lY:`0N:2X08bd_01dY:@0Y=CD0;3Ph
0P0O:b/0400R;Rh072PX01hZ:P0Q;Bd07b/[01dY:@0M:2P072@W01hS9`0T:B`09b`_028W:P0L8R80
6R0P01TO7`0I7ad201XP7P0701`R800M8B806AdN01XN7`0R9RL07b<T03i2@`0201dQ8P806alP0P0J
7Ql0;@0K7ah05a/J01lS8P0N8R<05a/M01hR9@0E61d0:Rdc02X]=00G6R406ahV02<V;@0S92P05QLI
01`M7`0O828061TK01HG6@0E5QP05aPJ01PI6`0F5aT04a@F01HG6@0?41@05aPL018C5`0G61`07b0T
01@E6@0H6Ad06Q/O01/L800N7b<08B8V020T9`0C61T05QXK01LK700V:R/05AHH014B500D5AL0820R
01hN800201@D5P0301TI6`0D4Q<0518C0080518C0`0C4A806@0F51D030X;018@4@0>30d05aDF01@@
3`0A3@`04`l>01HB4@0@30/02`L601HB4@1bKVd0/Jf/01hJ6@0P71/03PX900H20P0N6QT030T801@@
3`0@30/03`/:014=300@30/00P0?2`X00`0A3@`04`h>01<=3`0201<=3`0?014;3@0@2P`04@/=01TC
5@0;1@L071HH00h82P0F418040P900l51P0@1PL04`T:01882@0F30d05`d>00804PP900T0308300l5
1P0T6Q/09AdM00/51@0?2@T02P420107200D30d00`0@1PL301451`0?01@:2`0A1`P0L6IW01H<3@09
00405@/<00`20`0@1PL04@L801<92P0F30d04PP90147200@1PL03`D600804@L800L040H700l51P0D
2P/0>S0a01`B4`090@4040L800H03P@50180200002TO802l/[<0/jVZ01X@4@0:0@4030040104200>
0PH03@850104200A1@T02@010106200E2@d050P<03<W:`0?0`LDooooo`006oooool00`0<2`T03`h<
00l>300200h=2`<040l=01P00@0001DD4P0U92800@0000d=2`092@L03Ph<010@3P0?3`d04Q8@00h>
300?3`d02PX800d=2`092@L0:2PV07IgLP3ooo/0iNKQ02//9`0J6aH0414<01lP6`0>3`X2014B3@03
00d>2@0A4Pd03@d;00802`/901P03@d;010@3P0A4@l03`l=014A3`0@40h03@d;00`<2P0>3P`03@d=
00@4100A4A402@T901lO7`0410@05QHF0000000D51@05aLG000000092@L02``700d>2@0<3@P200P9
10802``700L030d800/<1`0;30L03Pl:00l@300=3@/030`:00803@d;00d030`:00h>300E5A<03`l=
01DE4`0P81h0:2PV00l?3@0=3@/02`/900l?3@020P00410>00H03`l=00@03a0<00d>2@0;30L03@h9
0P0>3`X2010A300X00h?2P0<3@P02``700/<1`0C4`/05AD;01@D300A40/04Q4=014@3P0=30X040l;
014@2`0:2P802@T1010@1`0;30L07QhL01lO7P0<30`03Ph<010@3`020P802PX800d=300D51@0DU9@
034a<00F5Q@061PF00`<2P0@40h02`/901<C4@0;2`T0410>00/;2@0:2PP03@d;00H610803@`:0P0<
2`T03`0;2PP02PT7014@3P0?3P`04A0>00P71@0:2@L03`h<014A3`092@L01`L502<S8@0C4a401PH4
00d=2`0200l?3@0E00h>300<30X02`/900l?3@0;2`T02PX8010@3P0C4a403@d;00<30P071`D01@D3
00`<2`0E5A<0410>00X:2@092@L05ADC00L71P0D518010@2008030`:01403@d;00h>300>3P`03Ph<
00T91`0B4Q003Ph<00l?3@0C4a402@T700h>300A4@l051@B00d=2`092@L03Ph<00l>3002010?3@03
00l>300<2`T02`X800@03@`:00h030/9010=300A3@`03`h<014A3`0=3``02@h:00L<200@5A404A<@
00d=2`0O7Q`040`;01LE4`802`X801H03@`:00`;2@0<2`T03@`:00/:200920H02PT700h=2`0B4@l0
4a8?014@300@3`d03@`:00X91`0;2@X03@/<00`:2`0=2`h03P`?00l=400A3a<05Q@G0P0<2P/04@0N
71d03@/<010>3`0>30d040h?014?400=2``02`T:00`:2`0;2@X03@/<01HD5@0?3@h00P0100h<3@0<
2P/03@/<00803P`=0P0=2``06P0>30l030X=00`:3@0?3A004@lB00l=400D4QD040hA00H41`091`X0
3P`?01HD5`0?3A004@lB010>4@0=2`h02`T<00`:3@030@@07Q`O00l=400G5AP00`4400l=400H5QT0
4@lB0P0@3Q40600<2Pd02`T<00H41`0@3Q403P`?01DC5P0>30l0518E00X82`0;2@`040hA00/9300D
4QD04@lB01PF6@0;2@`01P@701@B5@0A3a80CTa?03De=`0@41802PX<00h>40801@D701l02`/=01/K
7@0?3a405QHH014A4`0410H01`D6010>3`0E4a@03@/<00`:2`0D4Q<03`d>00`:2`0@3Pl01`D601PF
5`091`P03@d=00h>3P0;2`/05ADE02LW9`0];Bd0IFEU0000000A4A401PH600/;2`0G5aL04@d<00D0
40`;00H0510?018>3@0U8B006QHE00D1000=2`P2014@300=00d<200@3`/04A0>00d<2P0;2PP02`T:
018@4@0C4A803@/>00`;3@0?3`l03Ph>00l?3`02018B4P0_014A4@0E5AD061PH010@400820P02PX:
014A400@4@`03@h900l?300C4a405ADC01DE50061PH05ADG010@4P0;2`d051@F01@D500A4A402PX:
00d=3@0H61P030`<01<C4`0?3`l08B4Q014A4@0G5aL051@D00L72@061PP04a<E00P82P1=CDl0BDU;
00H6200C4aD04A4C00d=3`092@/05ADG00`<300?3`l04Q8B02LW9`0U9BD00P0A4A4201<C4`0Y010@
400A4A404Q8B01@E6@0N7b800P<501`M7`0?41407R0O01PJ6@0@4Q0030h;010B3`0F61@05QPC014A
3`0@40h04Q8@01DE4`0D51804A4?01/K6@092@L03`l=01TI5`0n?S`0410>01TI6@0B4a<04ADD01HJ
6@0E71/03QLF01PQ800@5aP061dP018C5`0I6Ah04a@H01HH6`0F6Q/00P0E6AX0300I7Ah0720Q00X>
3`0R9RL06QhO05=GF00Z;Rl0720O01DJ5`0N8al082DQ01@I5@806QlK0P0L8Ad07P0P9B407B8N01TN
6P0J81`08RXU01hW900W<2d07RPX01PQ9P0S;340<Se1041>D@0^?3l07B//02Hd=00Y=cL092db024/
<P0T;cD08bhd02@a>@0b?dL0;ca402`j@`0^?4D0?TaE01`]=@0[?4@0;d990352BP80:CY202L09C<l
01l]=P0M:c@082df03E2B`0mBU<0;CY302<a>@0/>d80;Ca302<b>00L:c00934g02Lc>00T;c<09c8f
02Xd=`0W<C<092h`02@^<`0S;CH09Blh02<^=@0R;C<0;STo02@_<`0P:bl06bHZ01`W:@0O:R`082/]
01DP8P0U<380:3<e01PS9@0J9BL082/]01/V:00L9bT00P0O:R`0200M:2X06RDW01XR9@0P9BT09R/^
02DZ;@0R9bX06R0P0P0I7al01`0J81h06b4O01/Q7`0K8Al07R8S024U9P0E6AX00P0K7b000`0@51D0
7B4R01`P8@0201XN7`806alP01H09RX[01/O800K7b006AdN01@H6P0K7b807R4V00lB5`072Pl082<Z
028U;02JWJ80UiRL024R900S92H02P/=01/L7P0I6Q`05AHH01LH6P0E5QP04a@F0P0D5AL01`0B4aL0
71dQ01DF6P0F5a/07b0T018C5`0E5QX00P0D5AT04@0F5a/061TM01LK7P0I7Ql0720Q01XN7`0/<340
7b0R01LH6P0M7R00:b/]02HV:00E5AL0410B01DE5`0E4a@04a4B00<04Q0A01X04a4B01TG600H5QL0
5aDF01<A4P0=2``0518C03Xf=@0N6QT04@d<010<2`0E4A005Q8A01dI600N6QT0?CTh018>3@060P40
3`/:014=300S7ah04Ph=00D1000?2`X061@C014=30803`/:020040`;014=300A30d04P`>01<=3`0D
3Q004P`>014;3@0=1`T05a4C01@>400N61X03@L900/51`0A2P/03PD600l61`0A20T040L801D<3@0C
2P/02`8301482@0D2``03PD60107200A2@X0100000h8200F3@h02@0100l820<03`D60`0@10H03`0:
00406@l@02LM7P0O5AH05P`=00d41@0?1@H04@L800h41@0;0@803P@500l51P0A1`P040H700l51P02
0147200401061`0Q5aP01`0000l71`804PP900<03@@500h41@0>10D0100>10D04P0B20T040L801X@
4@0H3Pl03@D501061`0A1@T03P8601452@0E2@d050P<00l31`0@10P04@D900l31`0=0@D04`L;00d1
1ACooooo000Kooooo`8040l=0P0A40h02P0@3`d03Pd;00/:200F5A<040l=01DD4P0H5aD081lM01<C
4@0@40h201LG5@0J010@3P0C4a400P8000`<2P0A4@l061PF014A3`1@D4h0PH9m09ZKUP2?T8/05aPC
01@E40061`806a`G00h?2P0<3@P03@h900h?2P0A4Pd03Ph<00`<2P0;2`T030`:00h>300?3`d2014A
3`0P010@3P0>3P`03Ph<00l?3@0>3Ph04Q8B01PH600<30`03@d=018B4P1YJFT030`<00h>3P061PH0
6QXJ00`<2@0=3PT051D@01PI500>3`X02P/600`=200>3`X04A8=010A300=3PT030d800`=2@0=3@/0
3Ph<00l?3@0=3@/200`<2P0=018B400<30X0410>014A3`0I6AL02PX800<30@0820H02`/900H61009
2@L03`l=010@3P0300l?3@05010@3P0@4@d03@h900/<1`0=3PT00P0>3`X00`0@4@`03a0;00h?2P03
00`=200?014A2@0C4`T04a<<014@300@3`/04Q4?00`;2@0>3@/040l;00`;1P0;2`<0410700L71@0E
5AD061PH00802PX:01<03Ph>018B4P0V9RH0;Bd]01PH600_;bl05ADE00T91`061P@051@B00`<2P0:
2PP04A4?00h>300<30X02@T700`<2P0@40h02`/900<03@`:0`0<2`T0100?3P`03@`:00d<2P0C4Q02
01DD4P0:01<C4@0>3P`01PH402l_;@0R8R0020P600d=2`0@40h04A4?00l?3@8030`:0P0=3@/04`0;
2`T03`l=018B400<30X03`l=01PH5P0C4a402`/:028R800@40h02`/:00<30@0;2`T0:BTW01@D4P09
2@L030`:00/;2@0<30X00P0@40h0400?3`d03Ph<00X:20092@L05QHD00D50`00000030`:00/;2@0@
40h02PX800H6100>3P`03@`:00h=2`0?3P`2010?3@0300l>300<2`T03@`:00803Pd;00h03@`:00d;
2@0;2PP02`X800h>300?4@h03Q0=00dB3P0G71P071hK018B400<2`T00`0000/91`802@P600<03@`:
00X91`0;2PP00P0>3@/200`;2@08014@3P0F5A<04a8?00h=2@0?3P`03Pd;00`;2@0=2``200h<3@80
3@/>00/03P`?010>4P0B41<01@<4018@4@0]:b`030X;00h<3@0C4A804Q0A00l=3P0200`:2`0900/9
2P0@3Pl030X;00`:2`081PL01@<4018@4@0<2P/03@/<00803P`=0P0=2``0200>30l03@/>00d;3P0>
30l03`d@00h<3`0@3Q405A<F0P0=2`h01P0610L02PP;00h<3`0A3a8040hA00h<3`8030X=00X03@/>
00h<3`071@P04a4D00T72P0A3a804Q0C00h<3`0;2@`030X=0P0?3A000`071@P04Q0C00/9300200l=
400b00h<3`0D4QD04Q0C01<A500:20/030X=00T72P0B41<03`d@00400P0=2`h06QPK08F3QP1ADE<0
6ATK00h>400C4aD03Ph@01DE5`0@4180H61R0410@P1CDeD04A4C00d=3`0>30d01P@500d;300?3@h0
2`T:00d;300<2P/02`T:010>3`040P<071XK00`:2`0?3`l03Ph>00P8200=3@d06a/K020P800?3`l0
0@4101@D500?3`l030`<00H61P0@3P`2014=308040`;00L04`l>00/71P0810<07ATH01@@3`0810<0
3Pd:008040l;00d03@`8014@300B4@l05A@B00l>30091`P07adN02h/;@0O7B003`h?00h>3P0=3@d0
3`l?00804Q8B00X03Ph>01HF5P0Q8B406a/K00`<300;2`/04A4?010A300=3PT0414=0P0F5Q@06@0@
40l04A4A014A4`0>3Q0030`>00H6200>3Ph01`L700/;2`092@T05QHF00d=3@0>3Ph02`/;014A4@0<
30`04A4A01PH600G5aT0=3@f020P8P0C4aD05ADG01LG6@0N7R000`0=3@l07@0B4Q@04a<E010@400C
4a<05QHF02`/;00Z:RX051@D00/;2`0A4A405ADE018B4P0C4a<0410@010A5@0A4QD0414C05EFF00l
?Sh03a4@01DG5P0C5A<03a4>014C400C5A403@l:018B400A4@l051@B00806ATG01D051@B00l?3@0A
4@l04A4?018B400`<2h051@B01PH600E5QD04QHE01HJ6@0E71/041TH00`E500=51D06b0S01HG6`0G
5a`07AhR01HJ700I7Ah00P0H71d08P0M8B808BDV02T];P0T:2T05a/L01XN7`0:3Pl08BDV01XN700J
7a/05a`H01HK5`0Q9R807R<O020U8@0L8Ad06QlK01DJ5P0J7a/08BLS01hW8`0O:2D09Bh]01lY:P0K
9BL08BX_024/<00W=CP0;3Xk01`Z:`0]>c/0:CLh02La=@0S;S@202Ha=`0]02Ld?00a?TH0:SLo01l]
=P0U<c`0;Sa501`]=@0Z?4@0;d990352BP0[?4@09SLo028`>@0O;CH08Blh02Hc?00[>440;3U202Xg
@00V=3d0:SU002lnA@0Y>3l07Rdb024^=00R;S<08B``02Lb=P0/=SP0:S@f02D_<@0P:Rl092hg02Tc
?00F8BP08Rdc02/f?00U<3@07bX^01TT:00M:2X08B`^01lZ;00W<S@09C0b008082/]01008Rd_01/V
:00N:B/07BPZ01hY:`0O:R`07RT[01/V:00H82<0:c0d038g>P0K82<04aPK01`R8P0H7Qh06AlO100K
8Al0100A5AH08bLX01dQ8P0M8B8202@X:@0L01TM7P0H71d061`M01XN7`0N8R<08BDV02hb<`0T:2T0
6QhO01PL7@0I7Al06AdP01LJ7`0S9R/06ahS02@W;P0Z;C@0f=_P0<k?d`0b<cD0:BX/00l@4P0O8280
3@h@01DF600H6A/051DG018C5@805QLI01X051DI01/L800F5a/05QLK01TJ7P0A4QH05QLK01DF6P0C
51P051DI01HG6`0E6A`051TI01hR8`0L8240;30a01/L7P0@4A<06AXL028R900P82805ADG018B500E
5AL05Q@E01<A4P804@l@0P0B4140200;2@X03`d>018@4@0B41404a4B01HD5@0/:2L06ADD0P0@30/0
4@0D40l05Q8A00`9200D40l08alN014=300;1`H061@C00X61@050@003`/:01LC4P0B3Pd03`/:014=
300>2PT03`/:008040`;00@040/;00l92`0@2P`040X<0P0?2@/0600=1`T07aTK00h82P0400006Q@F
018<3P0=1@L03`H70107200B2@X040L801<:2`0E30d03PD600l61`0C2P/03PD600X10P0=1@H04`d=
00T4100K4Q<08aXK00d41@<040H70`0A1@L03`0=0`@03P@500P0000?1@H05@/<00l71`0D2P/05P`=
01061`0:00403@<401061`0A1`P040H700l51P020147200401061`0D2P/0308301T?40801`0000<0
7A<D00h41@0>10D0100>10D04P0A1`P040H700h41@0@1PL04PP900/10P0B1PX03@4500l31`0A1@T0
3P8600`0100B1PX040@800d11@0A1@T02P0201<72aCooooo000Kooooo`05014@3P0>3@/040l=01@C
4@0C4Q000P0=30X02`0@3`d02PT700d<2P0E5180DU5?01TI5`0C4a406ATG01PH5P0?3`d05QHD0080
410>018020P600h>300=3@/04Q8@01DE4`0R8R009BDS00h>300@40h04Q8@00h>300B4Q003`l=01@D
4P0K6aT061PF014A3`0?3`d200d=2`0300h>300?3`d0410>00803@d;0P0?3`d04P0>3P`0410>00l?
3@0>3P`03`l=010@3P0B4Q00=SHd01HF50092@L04a<A00X:2@0?3``03a0;01HG4P0H6A@03@h900`=
2080414<00D04Q<>014B3@0>3`X03Pl:00l@300200l?3@0300h>300=3@/03@d;0080410>01@02`/9
00l?3@061P@05QHD010@3P0D5180>SXh01PH5P0F5Q@02PX8014A3`0@40h03Ph<00d=2`0>3P`0410>
010@3@0=3PT02``700d>2@@03Pl:01403@h900`=200=3PT03Pl:00`=1@0>3`H0414:00h?2P0<3@P0
410>00X:200;2`T03@h:00l@2P0@4@X03a0800l?3P0200X:30803`lA00l02PX<00T92`0;2`d04Q8D
00h>400<30h09BDV05QHE`0I6AL02@T800`<2P0@40h02`/9010@3P0<30X00P0?3`d0100;2`T03`l=
00d<2P0=30X200h=2`803`h<00d04Q4?03Pg=@0B4@l04a8@010?3P081`D04A4?00h>300;2`T0410>
00X:200=3@/03Ph<008051@B00D04A4?00d=2`0=3@/02`/9014A3`0200d=2`0?010@3P0<30X02PX8
00h>30092@L04Q8@08B4PP1nOW`04A4?01@D4P0H61H0=3@b00/;2@0<30X0410>00803@d;0140410>
00h>300<30X03Ph<00P81P071`D03@d;01@D4P1MGE/07QhL00L71@092@L03@d;00T91`0<30X04Q4?
010?3@0400h=2`0300/:200=30X03`h<00803`h<00d03Pd;00/;2@092@L02`/900l@3@0>3`d03@h<
00l@3@071`D03@d;00P81P0A4@l040l=00802PT700L03`h<00`;2@0<2`T03`h<00d<2P0>3@/03`h<
00803Pd;00T03Pd:00h=2@0=30X030/900/:200>30d04@l@010>3`0>30l00P0=2`h03@0?3A402`T<
010>3`0A3a005Q@E018@4@0<2P/05aDF010>3`0:20T03@/<010>3`0>30d00P0?3@h00`0>30d030X;
01@B4`0200`:2`0300d;300>30d03P`=00803@/<01003@/>00l=400?3A003@/>00/9300=2`h030X=
01HD5`0<2Pd040hA014?4P0`;S403@/>010>4@0A3a803`d@0`0=2`h03P0H5QT0GeeP00T72P0A3a80
2PP;00d;3P0?3A003P`?00d;3P0@3Q404@lB01@B5@0<2Pd040hA0P0=2`h0:@0>30l030X=00/9300A
3a802@L:00h<3`0?3A002`T<00l=400C4A@03`d@00`:3@0D4QD06a/M00d=3`0:2P`02`/=00X:300>
3Q003`lA01lO8@0A4A<071`N00h>400=3@l04@l@00/92P0?3@h030X;014?400N71d05Q@E00/92P0D
4Q<04Q0A03Le=P0T8R<030`<014A4@0<30`02@T900803@d=00@03`l?01<C4`0;2`/02PX:0P0<30`2
010?3@803`h<00P03Pd;014@3P0;2PP03`h<00d<2P0<2`T04a8@00d=2P803Pl:00d030d9018B400D
5180410?00/;2`0:2P`04A4C01@D5P0?3a4030`=00d=3@0<30`03Ph>00804A4A01<03Ph>014A4@0E
5AD04A4A00d=3@0?3`l04A4>00d>2@0>3`X05QLB01TJ5@0D51803Ph<01DE4`092@T05QHH00X:300c
<cD0C4a<00804A4A0`0?3`l0300B4Q804a<C00h>3P0I6AT03@d=01<C4`0820P06QXJ00/;2`0A4A40
5QHF01XJ6P803Ph>0280410@01HF5P0>3Ph02`/;01<C4`0G5aL0410@01LG5`0E5AD04A4A010@400F
5QH051@D00l?3`0C4a<0410@010A5@0@4A@0:b`^08b=S`1^L7004Q@C01HH5`0G6AL03a4>00h@3@0D
5Q80418=01@D4P0B4Q0051@B01PH5P0G5aD0410>0P0D51801P0J6QP05QHD014A3`0E5A<061PH01PI
6@805QXI01T05A`K01@M700D7A`072<T018G6P0H6Ad0:2P]01`M8@0G71h06R0P01PN7P0E6a/06AlO
01hT900T:RX05A/K024W9`0F71`082HV01PN7P0G7A/07B<Q01LM6`0K8Al08bTW00807B<Q01`06R0N
01dS8@0L8R00728P020V900M9BD07bLX01dU9`0O:BX092h`02H`<P0P:bd07bd^01LU9P0K:BT06RPX
028`<@0U<3D08B`b02<_=P0S<3P09S<k02/i@@0L:S<0=TA=04IFH00Z>dD0A5EO0`0V>4801`0Y>dD0
8cDo02@e?`0Z>T@0938m024_>P0V<cl00P0^>TH02P0[>4809cDn02Le?P0Y=cl09cHm02<`=P0S;c@0
9C0d02@_<@0S;Rl2028/;@0K028]<@0F82T0<Sa504UCF`0S;S@07RT_01dX;00P:bl092lc02<^<00Q
;2h07bX/02Pc=@0V<C<09c8d024/;P0K9RP09S4c02@_<@0Q;2h07bX/024/;P0R;Bl082X/01dU:00W
;30092T/00806AhQ00/06b4Q01PN7P0I7al06b4O01`R800K8Al06R0O01LL7P0M8RD0724T020U:002
01TN8@0E01dR9@0K82<061dP01PM800J7b80724T01/O8P0P92L05a/N01/O8P0Y;C008BDX01TM800F
6Ad04QDJ01LJ7`0S9R/0?D140493AP0H6A/06Q/M00805AHH00D06AXL01@E5`0I6Q`051DG01<D5P02
01TJ700J01LH700H6Ad06a`P01XK7`0F5a/05aPL01PI7@0G61`05AHJ01LH700J6al06AdP01@I6@0F
6Q/02Ph?01PL7@0F5aT051DG01HG6@0E5AL05QHH01LG6@0F5QP05ADF01HE500C4Q02010?3@03014@
3P0B4@l051<A00805aHD01404Q4?01DD4P0=30X04Ph=01HB4@0G4a805Q8A018>3@0@30/05A4@00l;
2P0F4Q40510?018>3@0A3@`0510?014=300201<?3P0301HB4@0D40l04@d<00803PX900<04@d<010<
2`0@2``00P0@2P`06`0?2@/040X<014;3@0A2`d05Q0B01<=3`0J51H05@lA00@0000F3a004PT:0107
200D2``04PT:0107200B2@X03PD600d41@0@1`P03PD60107200B2`/020<300h8200B2@X0;2<T01L>
3`03014720<04PH800l060h?00`3100C2@X03`H601L=3P0?1@H04@L801D;300C2@X03@<400h41@0@
1PL04@L801061`0?1@H00P0A1`P01`0@1PL03@<400l51P0<0`@03P@501061`0=0`@01P0>10D04P0E
2``03`D600h51@0?1@H03P@500l51P0=0@D040@801452@0<0@@040D802HJ7P0A1@T03`@701452@0E
2@d03`@701462ACooooo000Kooooo`0U014@3P0?3P`03@`:00d<2P0?3P`04Q4?01HE4`0;2PP04A0>
01<B400>3@/05A@B01PH5P0<30/0820N00/;2@0A4@l02@T701@D4P0>3P`051@B00h>30030`40410>
00h>300@40h04Q8@00l?3@0=3@/03`l=018B40000000?clm024Q7`2j^[P0>SXh00l?3@0200h>3009
00X:200H61H0410>00T9200D51804Q8@01LG5@061P@04Q8@00803@d;00@03Ph<00l?3@0?3`d03`l=
0P0>3P`01@0=3@/02@T701/K6@0Q8Qh0414<00803a0;00`030d800d>2@0A4Pd02``700X;1P0?40/0
3@h900`=200>3P/0410>00l?3@0;2`T2014A3`04010@3P0?3`d03@d;00h>3080410>01@03@d;01dM
6`0n?S`071`J018B40051@<04Q8@0000000e=C<071`J018B400A4@l03a0<00h?2P0<3@P0414<014B
3@0;30L030d800d>2@803a0;01<03@h900/<1P0@4@T04149014B300<3@P01`L500`<300E5AD04Q8@
00X:1`082@<04Q<=00/<1P0=3@d04A4C00`<3P0@418000020080410B01l020P:00T92`0?3a4030`>
00h>3`0C4a<030`:014A3`071`D02`/900X:200>3P`03@d;00l?3@0A4@l03Ph<00H6100920H04Q4?
00@30@0;2PP04a8@018A3`0N7A/0<2l]00T81P0P7ad030/9018A3`0=3@/03`l=0080410>00L03Ph<
00`<2P0>3P`04Q8@01LG5@0Y:BL05QHD00<03Ph<00/04Q8@00h>300<30X061PF00P81P092@L04Q8@
02TY9`1ZJVP06QXH00h>300300`<2P0P00/;2@0:2PP01`L500h>300<30X05aLE00P81P0A4@l02PX8
00d=2`0@40h03Ph<01<C4@0=3@/030`:00l?3@0@40h02@T700P81P0>3P`02`X800h=2`0B4@l03`h<
00`;2@0D4a403@`:00l>300=30X040l=014@3P0?3P`201HF500?018B400000004a<A00l>300F5Q@0
410>00/;2@0?3`d05aLE00P81P0?3P`02@P600l>30071P@03`h<00802`X800H03Pd;018A3`0:2@L0
30/900l>2`0>3@T2010?3@0>00d<2P0=2``04@l@00T720071@P030X=01HD5`081`X020H901DC5019
AdP08b4R01dK700920P200/92P0:00d;300>30d03P`=00h<3@0=2``03`d>010>3`0>30d030X;00d;
30803`d>00@03P`=00d;300>30d03`d>100=2`h00`0>30l040hA00l=4002018@4`0500`:3@0=2`h0
6ALJ00h<3`0<2Pd00P091`X01@0<2Pd03P`?00h<3`0=2`h04@lB00805A<F00<03`d@00d;3P091`X0
0P0A3a803P0<2Pd05Q@G00h<3`0C4A@02@L:00P62@0B41<03P`?00X82`0<2Pd03@/>00l=400A3a80
4Q0C0P0?3A0400`:3@0E00d=3`0>3Q003Ph@00h>400<30h02`/=02DU9`0@41804Q8D01<C5@0820X0
10@6010>3`0;2@X040h?00`:2`0=2``06aTJ01@B4`0=2``03`d>008030X;00/04Q0A01@D500410@0
30`<00X:2P0M7Ad030`<00l?3`0;2`/02PX:00`<300200h>3P803`h<0P0<2`T01@0A40h03Pd;018A
3`0A40h040l=00803`h<00d03Pd;00l?3@0A4@l03`l=00d=2`0@41004a<D00h>400A4A<04A4D00P7
300000@0410A00803Ph>01X03@d=00`<300<30`03Ph>01<C4`0410@04Q8B00@4100D51@03@h:00h?
2@0<3@L03@h800l@2`0@4@`03Ph;01DE4`0=3@/05aLG00l?3`1LG5`0RHV902@T900D51@01`L700l?
3`8051@D01804a<C014A4@0@41004A4A01@D500>3Ph051@D00l?3`0;2`/051@D010@400G5aL0FUYJ
01LG5`0:2PX06QXJ00l?3`0>3Ph2018B4P0c00P8200B4Q805QHF018B4P0>3Ph04A4A00/;2`0E5AD0
4A4A014B5P0D5AP05aPJ01PI6`0G6AT05QPG00X<2`0L7Q`0828O010B3`0F61@03a4<01@D4P0C4a40
4Q8@01@D4P0F5Q@05ADC00l?3@0B4Q005QHD01LG5@0F5Q@051@B01DE5@0T9BD03a<B020T8`0Y<Bl0
6B8Q01hW9P0E71d051TL01TJ7P0K6b007QlS01/R8`0L9B@04Q/J010I600J8b806b@S00806B8Q0`0F
7ah05P0D7A`04a`I01LP7@0F7a`082TV01PQ7P0S;2T06R<P020Y9P0A6QL06R<P01@M6P0V;bh0:S8e
038j?@0P:2/0628S020Z:`0M9bP07BTY01XX:00X=SH201h/;00a020^;`0T<CP08Rlg01/X<00R;cL0
:cU202Tg@00V=3d0EfQb09^//`0eAe40:C]703E7DP0Y?DH08CDn01lb>`0V>480;3i802TkA@0[?4H0
9cE002@b?@0S<C`0=49=04UGHP0jB5<0>4IA02Le?P0S<ST0:CHl02Lc>00O:Rh07BPZ024/;00W<C00
:38a02Lb=@0gA4`0@DiF0:6^]@0S<3H082dc024_<P0O;C008S0c02<a<P0P;Rl09S@e024/<00202<^
<P0L020[;`0Q;3009S4e02Xe>@0R;C409S4e02Td>00O:Rh082X^02<[;P0Q9RX0724T01dR9@0O92L0
7bDU028X:00E6a/05Q`J01hT8P0I7ad08bTX01lW:@0L92L0D5QK04aDE`1oQhX0<c/n01hV:@806R8U
00l04QXM01hV:@0=4QH0=cXo07]nP`0W:Rl04aHK018F6P0G6ah07B4T01/O8P0G6ah061`O01XN8@0F
6Qd01P0H6A/0?P0F5aT061TK01<D5P0B4aD05aPJ01DF600M7R805QLK01PI7@0M7R806AXN018C5`0H
6Ad05QLK01@E6@0E5QX05aPL01HJ7@0E6Q/041@E014E5P0C5aP06Q/M024R900K71h05aLI01PH6P0E
5AL04a<E01LG5`0J61P02PT700l>300E51803@`:01LF500N7A/071/I01<B400F5A<05aHD00l>300D
40l05a<B01/G5P0D40l04@d<01LC4P0B3Pd040`;00l;2P0@30/03`/:010<2`0H51<02PH501TE500G
4a801P8101@@3`0@30/03PX90`0=2@P00`0@2`/04P`>018<3P03018<3P0701@>400A2`d04P`>01LA
4`0@2P`03@L9018<3@0200h8200901<=3@0=1`L03PP8010:2P0;1@D05@l?01H@400;1@D02P@40080
3PP800@03@L700H0000@1`P050/<0`0@1PL00`0A1@L04PH801@82P0600l51P0301D;300U6a`091XK
00803P@500d04`T:00l51P0?1@H040H70147200B20T05@/<01882@0@1PL03P@500l51P0@1PL03`D6
00@03@<400<03`D601061`0>10D00P0<0P<0100=0`@03`D601882@0:008300h21P0801L;3`0S5a/0
3`<70104200A1@T040@800h21P0<00@Dooooo`006oooool0200F5A<03@`:00T81P0C4Q00<C0^04U8
AP0>3@/02`X80P0D4a409P0C4Q0081lM0000000b<S00000000`<2P0B4Q00410>00/;2@0=3@/04A4?
018B400>3P`02PX8010@3P0A4@l0410>00h>300@40h051@B00X:200;2`T030`:00D50`0N7Q`08b<Q
00h>30092@L02PX801TI5`0>3P`04a<A00h>300D51800`<100`<2`0@40h01`L50P0=3@/02P0>3P`0
3`l=00l?3@0?3`d0410>00P81P092@L06QXH04I6A00k>cP2018C3P04014B3@0>3`X03a0;018C3P80
3a0;00@04a@?010A300A4Pd04A8>0P0?3`d01`0<30X0410>014A3`0?3`d03@d;00`<2P0=3@/00P0?
3`d04P0<30X04A4?01hN700>3P`02PX800P81P0C4a403`l=02@T8P0Q8Al05QHD00`<2P0C510030d8
00L80`082@@030d8010A30803@h902<03Pl:00l@2`0?40/0414<00d>200C50`04A8=00d=2`0A4@l0
3Ph>00D51@0820P04A4?01`M600>3`T051D?0000000>3Q0030`>01HF60092@/03Ph@00/;3@0<30h0
4A4C01<C5@0?3a403@d>00H6100A4@l02`/:00D50`0D51<061PF00h>300200`<2P0A00h>300=3@/0
2PX801TH5P0=30X03`h<00h=2`0;2PP03Pd;00@30@0H5aD010<101PG5@0>3@/04A0>00`<2P0>3P`0
0P0?3`d0200>3P`03@d;00`<2P0?3`d03Ph<01@D4P0<30X01PH40P0?3`d02`0A4@l03Ph<00l?3@0K
6aT03`l=00`<2P0;2`T03Ph<03<c<@0000003Ph<00<030`:00h02`/900X:200@40h03`l=00D50`0K
6aT03@d;00P81P0;2`T01`L5010@3P071`D030`:018B408030`:02803Ph<00/;2@0@40h061PF01<B
400:2@L02`X8018A3`0<2`T040l=00h=2`0?3P`02`X800h=2`0=30X01`P500`>2`0410801`L601`L
6P0:2@L03Pd;00<2000@3`d030`:00P:1`0;3@X020T601TH5P0<2`T02@P6010?3@0N7A/04a8@0P0?
3P`01@0A40h02`X800/:200>3@X03Pd900803`h<00h03@`:00h<3@0?3@h06ALH01@B5@0E4aH00@02
01DC5`0A3a8040h?01PF5`010000108301DC508030X;0`0>30d200d;300600l=3P0@3Pl03P`=00`:
2`0=2``03P`=0`0=2``01@0>30d03`d>00X82`0:20/02`T<00<030X=00P01`D8018@4`0K6A`040hA
00P62@0:20/03P`?00d;3P802`T<00<03@/>00h<3`0=2`h00P0>30l03P0?3A004Q0C01DC5P0>30l0
3@/>00l=400=2`h02`T<010>4@0L6Qd09B<V01LE600>30l03`d@0P0;2@`01`0<2Pd03@/>00l=400@
3Q404@lB00l=400>30l00P0<2Pd200d;3P0N00d=3`0>3Q003Ph@00h>400<30h02`/=018B500:2P`0
20P:00L72@061PP07alQ00P61`0=2``05Q@E00`:2`0>30d00P01010>3`0>30d04@l@00l=3P0:20T0
3P`=00@4100V9RH010@4010@40020P8000000`0=3@d02P0<30`02`/;00/;2`0:2@L03`h<00X91`0=
30X040l=00h=2`0@3`d400l>300>014A3`0C4a404Q8@00l?3@0=3@/03`l?014A4P051@L03`lA00h=
4@0>3A804A0E00`<3P0>3Ph400d=3@0G00P8200C4a<04Q8B00h>3P0?3`l05ADE00`=2@0<3@L02P/5
00/<1`0=3PT030d800`=2@0@40h04Q8@01HF5P092@T05ADE02h^;P0000003Ph>00/;2`0G5aL00`0A
4A43010@400D014A4@0E5AD07AdM01DE5@0;2`/04A4A01@D500;2`/07QhN00P8200A4A404a<C00l?
3`0G5aL05ADE00h>3P092@T0410@01@D500O7al2010@400500l?3`0D51@051@D00h?4`0@4A@00P0B
4aD02@0C5AD04aDD01@F5@041P@01`T601DG500@4Ph04Q@?01@D4P0201<C4@0301@D4P0E5A<05ADC
008051@B02405ADC01HF500H61H06ATG01@D500N7ah05a/J024U901lPh80[[Nf02Xc<P0K8R<05a`O
01hO8`0L724061TM01DL7@043@`03aPG01LP7`0A6QT04a`K01PQ800G81l06B8Q01XS8P0K92<072DT
01hW900L9B8051dJ01XS800E7Q/00P0O:2D02@0H8Ah0;CHc020Y9P27T8d0<c`k028Z;@0Q:B`07bLZ
01lY:P02020Z:`08028^;P0N;2`05bDU02hl?00K:BT0;3Xk01dZ<@0V<c/202Pe?@0@02@b>`0J:340
7c0h03Y;E@0nD5X05BLa02LiA@0R=Cl0:3a502TmAP0[?TP0:ce702XlAP0X>D<09SM101h/=`80:CM2
01X0938m02lmB00`?TT0<d5<02/i@`0Z>D00;3U102Te>P0T;c408B`^028];00S;B`08R`[02Pe>00O
;3@06RL_04UFG@0Y=S`0;ca2024_<P0O;C008Blb020^;`0M:b`08Bl`02D`=0809S4e0P0T;c<0100Y
=3P08B``01XU:@0H8bL201HQ9@0U02hh?00]=CP09R/_01dR9@0P9BP092T/020V9P0V;2`07R@T01hT
8P0P9R@06b4O020V9@0M9BL05QhQ03Lo@P0b>Sd0CEEH02D]<00O9bX09Bd`01TQ900N9RT04QXM01dU
:0041``0<C@i01XM8P0A51T0720T01HJ7@0M8B@06QhQ01LK7P0H71l06AdP01LK7P0201HG6@805aPJ
00@061TK01TJ700L7Al07QlQ0P0J6ad0200N7b4071dO01LH700M7R8071dQ01HG6`0A4QH05AHJ0P0F
5a/201DF6P0A01HG6`0D61/04QLG00lC500C5aP05QXK01hO8@0T9BL06a`N01LG6@0H61X05ADG01@D
5P0G5aL04A0>01XI5`0F5A<00P0G5Q@04@0J6AL04a8@01PG5@0A40h051<A014@3P0I61H05Q8A01@@
3`0H51<05A4@014=300D40l04Ph=010<2`0A3@`0510?00804`l>00D07ATH01DA400E4A00510?00X6
1@02014=3005010<2`0?2`X03`/:010<2`0A30d01`0B30h05`0C3@l04@/=00/51`0=1`T040X;00l9
2@0@2PX04@/;00d71`0?2@T04@/;04]5A@0F41002@@401PB4P0E3`l02`D500L10@0?2@T04@P901L>
3`0=1PH04@L8008040H700<04@D70186200D20X01P0@1PL01@0?1@H06Q0A01P>3`0=0`@040H700<0
3`D600T03P@500d3100=0`@03P@500l51P0=0`@0308300d3100?1@H00P0>10D200d3100500h41@0?
1@H040H70147200?1@H00P0F30d02P0?1@H040H700l31`0C1`/040@800d11@0A1@T06@dA00h21P0@
10P301452@0300l31ooooooooooo01;ooooo000Kooooo`0900/:200=30X03Pd;00l>300@3`d04A0>
00/:200<2`T04a8@008040l=00L07ahL01`L6P1SHf403Ph<01<C4@0<30X0410>00803Ph<00/02@T7
014A3`0?3`d02PX8014A4@0D51@03`l?00/;2`0@41005ADE010@400200d=3@0?01DE5@0820P03Ph>
00h>300820H06QXH00`<2P0C4a403@d;010@3P092@P0BTY8024Q7`010@0061PF00803@h901T03Pl:
00l@2`0?40/03a0;01<D3`0@4@`03a0;00`=200<3@T03Pl;00h?2P0@4@`030d800/<1`0<3@P03Pl:
010A300B4`h0414<00`=200?40/04A4>00h>300?3`d03Ph<0080410>00@03Ph<00d=2`0;2`T03@d;
0`0@40h04@0B4Q002@T701XJ600=3@/04a<A00d=2`0D518010@3014A3`0820H05QHD00h?2`0A4Pd0
4Q<>00h?2P0=3PT04Q<>008030d803L02``700`=200<3@P030d800X=1P0D5a00418=00P:1`0@4Q00
3Pl@010A4`082@X03Pl=00lA30072P@030h901TI5`0];B`03@d<00X:2P0<30/03@d=00L71`0=3@`0
3Ph>00/;2`0=3@`03Ph>018B40092@L030`:014A3`0U9B<05ADC00h>300<30X02`/900`<2P0?3`d0
3Ph<010?3@0=30X03`h<00T81P0R8Al02`X800P71@0B4@l03Pd;010?3@0>3@/01@@200X:200;2`T0
3@d;00<03Ph<00L03`l=014A3`0=3@/01PH401LG5@0>3P`030`:00803@d;00@02`/900h>300F5Q@0
30`:0P0=3@/00`0:2PP02@T700`<2`0300d=2`0J00`<2P0;2`T030`:00d=2`0>3P`010@201/K6@0=
3@/01`L500/;2P0<30X03Ph<00d=2`0B4Q002`/900`<2P0:2PP02`/900d=2`0F5Q@0820N010?3@05
10<02PT701HE4`0<2`T200h=2`0B00l>300=30X040l=010?3@0=3P`020d900X<2@0?40d061LE00X6
1P0D40l07A/I00D40P0D5180Q8J303e0?@0@4@h06APF0P0>3@/02P0K6QP08b8P01@C4@0C4Q003Pd;
00l>300=30X030/900d<2@0=30P200h=2`0?00d<2P0@3Pl03`d>010>3`0=2`h06QPK07EcMP0T8RH0
5aDH00X82@0Q7b00928S010>3`0A3a003P`=00803`d>00T03P`=00d;300=2``03@/<00l=3P0@3Pl0
3P`=00`:2`0=2``0100<2P/01`0=2``03`d>00/9300<2Pd03`d@010>4@0?3A000P0=2`h01P0G5AP0
81hQ01DC5P0<2Pd03`d@00h<3`@03`d@01<03P`?00/9300>30l03`d@010>4@0I5aX08b4T00`:3@0A
3a802`T<00X82`0?3A003@/>00`:3@0I5aX0518E00h<3`0A3a804Q0C00@03P`?0P0?3A001`0>30l0
3@/>00d;3P0=2`h03`d@010>4@0=3@l00`0>3Q009P0<30h02`/=00l?4@0?3a4020P:00h>400:2P`0
3`lA014?400N71d05Q@E00P61`0L6Q/040h?00`:2`0?3@h04Q0A010>3`0:20T02@L8014A4@0:2PX0
0`<301@D500:2PX04Q8B00`<300A4A40410@00/;2`0<30`03`l?00/;2@0C4a401`L500l?3@0@40h0
3`l=0`0=3@/03`0>3P`03`l=01@E4P0D5Q<03a4@00d?3P0>40l03@h@00h?4@061`T030dA00h?4`0=
3Q8061TM00X:300200d=3@0300h>3P0?3`l03`l?0080410@00d030`<00P8200B4Q800@4101<C3`0=
3PH03@h8010A2`0B4`d04Q<>00h?2P0C50l030`:00803@d;00T04a<C00l?3`0D51@04a<C00H61P0I
6AT092@T00l?3`0@41000`0A4A409@0@41005ADC01/K6@0E5A<02`/9010@3P0G5aD061PF00`<2P0A
4@l03`l=01@D4P0A4@l05ADE014A4@0E5AD08b<S01`L700A4A407alO014A4@0C4a<04Q8B01DE5@0D
51@04Q<G018C5P0A4Q@04Q<E01@F5P0F61L051HE01<E4`0F61D03Q0=018D400F61<00`0D51801@0C
4a405ADC01HF500E5A<051@B00804a<A06L05QHD01PH5P0M7Ad061TI01TM700G6aX0LGQg09fVY@0Y
<S406B0Q01LL7`0O82@07QhS01PI7@0G7Ql06b@S01<L6`0F7ah06B8Q014J6@0K92<05QlN01/T8`0G
81l051dL01/T8`0@6AP092d/01lX9`0M9RD05QlN01TR8@0N9bH05QlN02D^;@0M9RD0Hfa[02@/;P0N
9B/07B@[02@/<00T;Rl082XY028/:P0O:bP04b8O020_;01gQHD0;3Xj01PV9`0W=3/0934i02Hc?00Z
>4409C<l02Xj@`0[?4H0<T=@07:4T010DUh07Blk02Dh@`0Y?DP0:cm:02e1C00[?dX0:ce902PjAP0U
=d<08c=002XjA`0U=D808c4n02XhA@0Y=d@0:3I202Hd?`0X=cl0:CHn028^<`0N:B/07b//02@_;P0X
<S00:3<_02@a<P0a@4L0H6mf03]:D00`?d@07B`a02@c=P0S<SD09SDh02De=@0O;bl08C4a02<^<P0T
;c<08bhb024/<00R;C409C0d00<08bhb0P0K9RX05P0g@DD0;3@g02DZ;P0L8B@08BHY02@Y;00N92@0
728R020V9P0Q9bD07bDS020V900Q9bH06b<U01LO8P0J8RD06B4T01HN8@0M9BP06R8U03a4A`0841<2
01dU:00:01HN8@0L82L06QdT020S:P0H6b007R4V00lB5`0M8B@05a/M01DI6P<05QXK0P0I6Q`01P0H
6A/05aPJ01LH6P0F5aT061TK01/L7P805aPJ00<06a`N01TJ700J6al00P0I6Qh0100L7B406a`P01@E
6@0E5QX301LH700401HG6`0C5aX05Q/K01@H6@805a/L00h06AXL01dN800I6Q`05ADG01HF600D51H0
4a<E01LG5`0];2T05aHB01XI5@0C4Ph06aXF010?2`805A@@00d071/G08n>RP1UI6006QTE01HB4@0D
40l05A4@01<?3P0@30/04Ph=014=300?2`X040`;00804`l>00L040`;00l;2P0B3Pd04@d<01<?3P0E
4A004Ph=00<04@d<00<04Ph=01@@3`0C3Pl01@0B30h02@0@2P`04P`>01@>400>20X03`T;018<3P0A
2``04`d=01D?3`0200l92@08014;2`0G4A40I5iN04I0@00H4Q801000018<300L5QH2014;2`0900d5
1P090@405@`=01882@0A1`P040H701451`0B1PP050P:00H04@L800H03@<401061`0>10D040H701H<
3@0@1PL200h41@0300d3100>10D03`D6008040H70P0>10D00`0A1`P04PP901882@0200l51P803P@5
00/03`D601061`0C2@X040H7020F5`0O5AH03P@500l51P0?0`L04PH:01452@0200h21P0401452@0=
0@D03P8600l31`8040@800<03`<7ooooooooool04_ooool001_ooooo00P04A0>010?3@0@3`d04A0>
01DD4P0G5Q@04Q4?00d<2P<03Pd;02D040l=01dM6`0=3@/04A4?010@3P0?3`d01@D301dM6`030`40
71`J04e=B`0F5Q@01PH4010@400F5QH0410@00/;2`0=3@d030`<01<C4`010@403`l?01@D500A4A40
7QhN01<C4@0000002PX801TI5`0?3`d04a<A010@3P000000:2PV00`<2P0;2`T05QHD00803@h900@0
3Pl:00l@2`0?40/03a0;0P0<3@P06@0=3PT04Q<>01HG4P0B4`h051D@01PI500A4Pd0414<018C3P0C
50l061TD01TJ5@0B4`h03@h900l@2`0@40d030`:00d=2`0@40h03`l=00h>300@40h03`l=00d=2`0?
3`d00P0B4Q00500?3`d0410>00L71@0R8R0020P600h>300<30X03@d;010@3P0C4a407AdK06EUH`0Q
8Ah05aPC014B3@0>3`X06AXE03@e<00<3@P03Pl:0P0A4Pd08P0?40/030d800/>1`0;3PL03a4<00T;
20051`H06Q/M00D6200720X0C4i<01HH4`000@0030h:00l@2`0Y:RD051DA00l?3@0B4`h00P<100l?
3@0@4@`03@d:00`<2P0?40/03@d;0000000H61H04a<A00D50`1@D4h03`l=00/;2@0>3P`2014A3`0>
010@3P0?3`d02`X8018A3`0A40h030/903Dd<P0C4Q002PT700T81P0?3P`020L5010?3@0:2@L200X:
200;00/;2@0<30X03Ph<00l?3@0<30X02PX800`<2P0:2PP08B4O00d=2`0:2PP00P0=3@/0300<30X0
2`/900X:200=3@/02PX800h>300B4Q00000001LG5@0<30X03Ph<00d=2`802`/900/03@d;00/;2@0>
3P`02PX800D50`000000820N01lO7@0=3@/04A4?00/;2@0200`<2P0?00h>300;2`T03@d;00`<2P0=
3@/04Q8@00l>300B4@l07A`J01@C4@061@<030/900h=2`0?3P`030/900803`h<01003a0=00<81007
2@H02P/900d<2P1WHf80>SHe00<0000J6AL03`l=01`N6`021`<03Pl=00h=2`081`D06QTG0P0C4Q00
2@0>3@/03`h<00X91`0:2@L03`h<00h=2`0=30T03Pd900h=2`0200d<2P0<010>3`0=2``03`d>01dK
7P0?3A00JfU/010>4P0:20/05aDF00X82@01000030X;1@0?3@h01`0>30d03@/<00d;300?3@h040h?
00h<3@0<2P/00P0=2``200`:2`803@/<00T03`d>00l=400@3Q404a4D01@B5@0B41<03`d@00h<3`0=
2`h00P0<2Pd00`0=2`h03`d@00h<3`04010>4@<03P`?01004Q0C01LE600K6A`06QPK010>4@0F51L0
30X=00X82`0A3a803@/>014?4P0@3Q402`T<00`:3@0@3Q403P`?0P0?3A0300h<3`@03@/>00@03P`?
010>4@0A3a803@d?0`0>3Q00100<30h02`/=018B500820X201TI6`09024Q8`16ATP02@L8014?400?
3@h04@l@00/92P0B41403@/<00803P`=01D03@/<00`:2`0;2@X03`l?01TI6@0M7Ad04Q8B00d=3@0D
51@03@d=00l?3`0=3@d02`/;01<C4`0J6QX0410>01<C4@0410804A4?00d=2`0@40h00`0<30X03`0=
3@/03`l=014B4@0>40l02P`;00/=300>40l03PlA00T:3@0@4AD00`@801HG700:2a004Q<H01<D5`02
00d=3@803`l?01/0410@00`<300:2PX09RHV00d=3@0S8b<05aLG00/<200<3@D02``400`=1P0=3PP0
30d700X;1P0T9B003Pl:01LG5@030`402`/900D51@0B4Q80410@00d=3@0@41006a/K010@400A4A40
0P0C4a<0700B4Q804A4A018B400B4Q00410>018B400E5A<04A4?00<30@0D51806QXH00P81P0=3@/0
410>01HF5P0;2`/02PX:01LG5`0=3@d04a<C00T92@0?3`l05QHF00h>3P0I6AT03@d=010A5@0?41<2
00d>401@010A4P0A4a804A<B00d?3@0F61D05aTF01LI5@0=3`X051@B01HF500D51804Q8@01<C4@0F
5Q@04Q8@01@D4P0E5A<05QHD01DE4`0C4a405aLG01`M700A5A@06alN01TQ7`0D7A`06R<R01DL7@0G
71l06a`P01/K800O82@092d^01PR8@0A6aX0=d5003i8A`0M9bH0628Q01DO7P0L9RD07BLV01lY:00V
<2l06bDT02D_;P0L9RD051hM01dW9P0Q:bX06bDT02D_;P0F81l09Bl^00@>3@0Z=3D07bH_038i@@0X
;cD07RPY02D_;P0V<Bd0:SHa02@c;P0P;bX072/X01h/;00iAdP0938j02Xh@@0e@d`0<d5:020a>`0Y
>T@0;3e703U;E`17FVH0:Ce802m2D00V>TH202a2C@0_02a1C00_@dh0<dMB02e0C00U=d<0:c]802<c
@00J:SL093A102hmB`0[>DH0:3I302/iA00X=Sl08c0h024]<P0T;c40930`02@_;@0S;RX092l[01PU
9@0eA4/0Hg9i03]:D00K:Rl072/`01d/;`0N;C008c8e02@d=00N;Rh07bl_02Pc=`0W<SP09C0f02@_
=@0U<3H09c8h01dX;P0O:S008bhd01hY;`0G8RP05b4W01/S9P0N8bL00P0P9BP02P0O92L0728R01TO
7`0N92@07bDS01hT8P0R:2H08RPW01TQ900Q:Rl201TR9`0D01XS:00K92T07bP]069[L01:DeP07BH[
01TR9`0I82H051PQ024T;00>4AP06A`S01HI7`0O8RL0720S01<G6@0C5aP04aLF018F5@0E6AP301TJ
70<061TK00h05QLI01XK7@0G61X061TK01/L7P0H6A/05QLK018C5`0A4QH06AXN01dN8P0=3Q805QLK
01PI7@806Q/O01@05aPL01@H6`0I7Qh05QXK01LK700B5QL03a0B014B500E5QP04Q8D01<C5@0A4A<0
410B01@D500M71T03@`801<B3P0;2PH06APD00X91@804a8>00/061LC0:ZYY@1iN7@05A@@01@@3`0I
5A@05Q8A00l;2P0@30/04`l>018>3@0200l;2P07014=300?2`X0510?00`81`0=2@P05Q8A010<2`02
014=30803`/:00@040`;014=300B3Pd04Pd>1P0A2`d03P0B30h04@/=00l92`0A2`d03`T;010;2`0F
4Q404`l>00d9200>2PT040`;01@@3`0810<04`l>0P0@30/01`0H51<0RXF5061JFP0A2`/071<D01<:
2`0<0`@00P0B20T0100A1`P04@D701451`0C1`T60147200600h41@0A1`P04PP901882@0D2P/04`T:
0`0?1@H0100A1`P04PP901D;300A1`P200l51P0301882@0D2P/050X;008040H700H03`D600h41@0?
1@H040H700l51P0;0@8201P>3`0400d3100A1`P02`0300h21P@040@800@04`L;01862P0@10P03`<7
0P0>0PHDooooo`006oooool06P0F5A<04A0>00/:200920H02`X800d<2P0D4a403`h<00h=2`0@3`d0
4Q4?014@3P061P@05aLE014A3`0=3@/02`/902PX9P0M7A/02PX801HF500];B/020P601<C4@0>3Ph0
51@D0P0?3`l0500@41002`/;010@40051@D071`L00h>3P0410@02`/;00/;2@0S8b40>SXh07emN`04
10801`L500h>3@0C4a407alM01HF500E5A<02PX80P0=3PT00`0>3`X03a0;00l@2`0200l@2`0300h?
2P0:2`H02P/6008030d800H05aPC01/L5`0A4Pd0414<018C3P0A4Pd201LH4`0900l@2`0=3PT03Pl:
00h>2`0;2`T03@d;014A3`0>3P`03@d;00804A4?02`03`l=010@3P0B4Q004A4?00h>300;2`T020P6
01DE4`071`D03Ph<018B400:2PP05ADC00d=2`0C4a40Fe]I010A3@0720<02P/600P9100:2`H05QLB
00T:1@0;30L03Pl:00l@2`0>3`X030d800`?20062@803a4=00lA40072@P08B8T09fNX00O828020X9
00`>2`0I6aH02Pd60001000=3PT01`P300P910804a@?00H030d800/<1`0?40/03Pl:00P9100720<2
00d=2`0G014A3`0@40h051@B00L71@0:2PP03`l=01<C4@0A4@l03`l=00d=2`0D4a402@P6018A3`0=
30X06APF00l>300>3@/02PT700d<2P0920H040l=00h=2`0<30X00P0;2`T0700<30X03Ph<00l?3@0>
3P`030`:00d=2`0A4@l06a/I00T91`0<30X0410>00l?3@0>3P`03`l=00/;2@0?3`d02PX800`<2P0A
4@l00000014A3`0<30X03`l=00h>300:2PP02`/900d=2`0<30X200l?3@0?00T91`0F5Q@0C4a:09VI
U`0:2PP02@T7010@3P0820H030`:00d=2`0<30X03`l=00`<2P0820H02PX800802`X800@05aHD00l>
3@0;2PP04Q4?0P0?3P`05@0;2PP030/900/:20092PP041DA00lA3P0=3P/06aXH07UeM00R7Qd01`<2
018A3`061PD092HS01<H500@4@h03Pd;00D40P0G5Q@02@P600l>300200d<2P0I00/:200920H03`h<
00l>300>3@X03`h:00l>300=30X030/900h<3@0C4A802@L800400P0D4QD08b4T01LE6@050`H040h?
01@B4`0M6a`02PP901<A4P0>30d03`d>010>3`0200l=3P0700h<3@0=2``03`d>010>3`0>30d030X;
00d;300200l=3P0600h<3@0=2``03P`=00l=3P0>30l03`d@0P0A3a800`0?3A003P`?01@B5@02018@
4`805aDH00<040hA00l=400?3A00100?3A002P0B41<040hA014?4P0E4aH04Q0C00T72P0G5AP061HI
00l=400<2Pd200h<3`0601@B5@0<2Pd020H900`:3@0@3Q403@/>1P0>30l01`0?3A003P`?00h<3`0>
30l03`d@010>4@0=3@l00`0>3Q009P0<30h02`/=00P82P0V9RP02`/=00d=3`0>3Q004a<E014?4002
00404a4B018@4@081PL04a4B00h<3@0?3@h02`T:00d;300?3@h03@/<02@T900>3Ph00P8200l?3`00
00004a<C00d=3@0<30`02PX:00/;2`0D51@06a/K010@3P0?3`d01@D301HF500:2PP03Ph<0`0=3@/2
00h>300=00h?3@0;3@`02P`;00`>3@0>40l03PlA00/<3`0D5AT00@86018C5`0310T03a0E00`<3`02
00h>3P<03`l?01P09bLW01/K6`0S8b<03@d=00410@0A4A4051DA01DF3P0@4@T030d600X;1@082@<0
3Pl:02<T7`0>3`X0820N014A3`0@40h05QHF01<C4`0@410030`<00H61P0820P2018B4P<04a<C00@0
4Q8B01PH5P0D51804A4?0P0E5A<05@0<30X02`/901dM6`0];B/092@R014A3`0G5aD03`l?00/;2`0G
5aL06a/K00/;2`0C4a<03`l?018B4P0F5QH03@d=01LG5`0<30`04A8F014B5@02010A4`0@014B4`0A
4a805QPG010B400A4a007R0M00d?2`0I6aH04a<A01LG5@0E5A<04A4?018B400F5Q@05ADC01PH5P80
6QXH03H061PF01HF500D51@07b0O00hB4@0J7Qd04APG01lX9`0K92<06R4R01`Q900K72006ATN020Q
9@0K92D02Q@C014K6P0Q:bX07BLV01LQ800J92<0628Q01LQ800I8b807BLV01hX9`0Q:bX07BLV01lY
:00K9B@07bTX01PR8@0P:RT09Bl^020Z:@0J92<08bd/024[;@0l@Td0BU5K038i?`0N:2T08R`[01lZ
9P0J9b004B0K02Th<`0W=S<09S@d01d[;00X=cl0:SQ103=1BP0`?TL202Hg@@0?03Q9D`0[?DT0:ci9
02TmB00[?T`08cQ402DkAP0Z@4/0;45<02/oBP0]@D`0<DA@02XlB00^?T/0:c]800809SI300L08c50
02PeA@0]>dP0=TA@02hlA@0T<CX082`a00808Rh^01408bh[02@_:`0X<bd09c@d02@c>P0R<CP082le
01`[<00U=3T07Rd`01l^<@0W=ST0:3Ph028b<P0P<300:3<i02Ha=`0202<^=0809C0f00l0:SDk02Pc
>@0W<SP09S4g02@_=@0P:Rl061lU01hS9`0S:2/08BHY01lT9`0P9RH0:S0`02H/;00R:2H00P0Q9bD0
;00P9bH06B4T02</<@0L9BX06B8W020Y;P0E7R<0214F0:F^/P1jPhP031DJ020Y;P0<4aT06AdV03Hi
@@0I72<08RD/018E6`0J7B807R8U018F600C5aP051PG014E500G6aX051DG01HG6@0G61X06AXL01/L
7P0L7Al05AHH01XK7@0H6A/06AXL01`M7`0I6Q`04a@H024R9P0K720051DI01HG6`0E5QX05aPL0`0H
6Ad08@0G61`05ATL01DJ6`0C5aP05ATJ018F5`0B4aD05AHH01@E5`0A4A<04Q8D014A4`0@418051@D
00h=300O7QX07A`H01@C3`0R8Ad071/G01DD400H5a<030/7038a;@0L6aL030/7018>3@0I5A@05Q8A
018>3@0C3`h04Ph=01DA4003018>3@05014=300@30/030P700/71P0@30/00P0>2PT00`0A3@`03`/:
00l;2P0200l;2P03010<2`0A30`040X<00@040X<00X04`d?010:300>20X040X<00/51`0:10H05a8B
01PD4`0@30/03`/:0P0>2PT03`0<20L03PX901`H5`0:1`H05Q8A00P40`2KUYD0K6IV010:2P0B2@X0
30<401482@0C2@X04PP90147200201451`030186200@1PL040H700@040H700T03@<40147200C2@X0
3`D600h41@0@1PL04@L801061`0?1@H00P0>10D200l51P0300d3100<0P<03`D6008040H70P0A1`P0
2`0@1PL03`D600l51P0@1PL0308300/10P0?1@H040H700h41@0A1`P03`<7008040@80P0?0`L01@0=
0@D060`@01H:3P0C1`/04@D9008040@85?ooool001_ooooo01P030/900h=2`0A40h04Q4?014@3P0?
3P`04A0>01<B400?3P`02`X800d<2P0@3`d0410>01<C4@0H61H05QHD014A3`061P@03`l=010@3P0=
3@/02PX9014A3`0@40h200l?3`0?00/;2`0F5QH07AdM01DE5@0h>3P0410@00l?3`0=3@d071`L010@
400>3P`02PX800`<2`0V9R@03`l=00803Ph<00D04A4?00T91`0=3@/01`L500h>300200d>2@0300h?
2@0?40X03a0;00803a0:00h061TD01@E3`0B4`d0414<00d>2@0I6QD07QlJ014B3@0?40/0414<00h?
2P0B4`h0414<00d=20804Q8=00H03@h:00X:200<30X04a<A00h>300<30X2018B40<03`l=00h03Ph<
010@3P0820H04a<A00h>300D518030`:01<C4@0H61H02`/9010@3P061PD0410?00l?3080414<0340
3@h900l@2`0D5A007QlJ01/L5`0C50l03@h900/<1`0<3@P03a8<00/@2@0;3`/030l>00X>3@0=4100
9RTZ00dA4@0=4A001`X800@9100@4`h04a@>00X;1P0?40/02P/501DF400V9b803@h800P90`0?40/0
2``700D60@0W:2<07QhL00T91`0b<S00=3@b00h>300D51802`/900h>300=3@/02`/900X:200=3@/0
3`h<00d<2P071P@02@P600802`X80P0?3P`0100=30X040l=00d<2P0@3`d200l?3@0:00d=2`0<30X0
3Ph<00l?3@0<30X03`l=00`<2P0F5Q@03Ph<010@3P803@d;01T01`L500X:200D51804a<A00`<2P0>
3P`03@d;00`;2@0?3`d03@d;00`<2P0@40h03Ph<00T91`0:2PP03Ph<00T91`0A4@l03`l=014A3`0B
4Q00<c<a06MWI@0A4@l02PX800803Ph<0P0;2`T030092@L03@d;00d=2`0;2`T03Ph<0450?P0D4a40
30/900l>300B4@l03`h<00d<2P803`h<020051<A01DD4P0=3P`04QHB00840P0>3P`03P/:01/G5P0?
2PX05a<B00d<2P0=3@/02@/800L:1`092`P04A0>00P71@0<2`T01`H4014@3P0:2@L03`h<014@3P0<
2`T03Pd;010?3@0>3@X040l;018A3`0@3`d030/900/92P804Q0A00P02`T;014?4@0A3a803P`?00h<
3P0L6Q/02`T:00d;30804@l@00<03@/<00h<3@0@3Pl00`0@3Pl02P0=2``03`d>010>3`0>30d030X;
00d;300C4A804Q0A014?4@0?3@l200h<3P8040hA00D03P`?00d;3P0=2`h03@/>00`:3@0200/93080
30X=00<03@/>010>4@0?3A000P0<2Pd00`0?3A0040hA00l=4002018@4`0500l=400<2Pd02PP;018@
4`0>30l00`0@3Q401P0J61/03P`?00h<3`0?3A003P`?00d;3PD03P`?0P0?3A02014?4P0500l=400>
30l03`d@00l=400=3@l00`0>3Q001P0<30h02`/=00l?4@14A4H07QhP00d=3`803`lA00h040h?030^
;`1]Jf`040h?00d;300>30d03`d>014?400=2``03`d>014?400=2``0@T9202@T90803`l?00l07alO
00L71`0>3Ph02PX:00T92@0;2`/03Ph>00l?3`0>3P`03@d;018B400W9bD0410>00h>300@40h00P0?
3`d200h>300=00`=300;3`h03a8A00hA4P0;3a0030l@00hB4`0830h030hB01PK7`0/<3@0FE]O00l@
5002010@4@0K00l?400?3`l03Ph>03/k>P27QhH07alN00l@3`0d=C@03Pl?01`M6@0J6a@051@=00l?
2@0?40T0410:014A30092PD071dH00L6100C4a4051@B01DE500:2PX04Q8B00l?3`0F5QH04a<C0080
4Q8B0`0@4100;@0B4Q805ADC018C3P0@4@d04A4>010A300?40`03`l<014B3@0I6QH051DA014C3P0B
4`l051@C014A4@0N7Qh04a<C00`<300c<c<0@D5101/K6`0@41004Q8B00d=3@0E5AD04Q<F01<D5`0D
5AH051DG01<D500A4a804aDD010B400G6AH07b4N05YLF00B50l04a<A01LG5@0F5Q@04A4?018B400G
5aD06QXH01TI5`0201PH5P0?01TI5`0J6QP06QXJ01@E500M81l061`K01/R8@0F7ah082PW01XP8@0K
82807R0T01`L8@0K7R406R8R00807RLV01005AlN01@N7@0H8R40628Q01`V9@0E7ah08B/Z02dg=`0X
<S40JWAd024[:`0L9RH08B//02Tc=00H8R<08bd^0P0R;2d0C00N:2T09Bla01TR9P0nADl0<CQ202T`
>00S;C008B/[01lZ9`0Y=S40:cXf02He<@0U=3809S@d028a=@0X>4009cHo02`lA@0W>D00:ca502Hh
@@0Z?4L09CM202e0C00S=T@0:ci<02DhAP0Y?TT0;D9=02XoBP0U>D@0:3]60312CP0W>D@0;Cm:02/m
B00^?dX0=DEA02XiAP0X=D@0:3I302`jAP0T<S/08Rlg028^<`0R;Bh08Bd]024/:P0T;b/0:cHa02dj
>`0K:S408c4h01l^=00P;c@07R`b02Hd>@0W=SX0;Se102hm?P0U=CH08c8c02Lc>@0T<3H08Bdc028^
=00U<3H08bhd01hY;`0Q;3808Rdc028]<P0S;S<08B/`02<Z;`0R9bX201hS9P0P020U:00P9BL0@4E7
02dc<`0R:2L09B/Y020V900O9RD072DZ01/S:`0M9Rd05b0W01XS:@0K92X08BX_02Ta=P0V;S804QXP
01hV;00O9R`05Q/R01XN9@0N8BL06ahU01PK800J7B808bLZ01HJ700H71d061`L01@H600M8B4201HG
6@<05AHH0P0D5AL201TJ7@0;01XK7P0M7R4061TL01<D600Q8RH06Q/O01@E6@0H6Ad051DI01HG6`0E
5QX00P0D5AT0100F5a/051PK01@I6`0B5QP201@H6P0501LH6`0K71h05AHH01<C5@0E5AL00P0C4aD0
200G5aL0F5QC00h>2@0K6aD051<>00/:1P0I61<07ahJ0P0A40/00`0G5Q404a8>01XI5@02018?3P0B
01<A3`0L6QP05a@C00/81`0@3P`03`/:010<2`0C3`h04Ph=01<?3P0j=SD0<bl^014=300E4A0040`;
018>3@0A3@`040`;0`0?2`X00`0@2`/040X<010:3003010:300H014;3@0;1@L03`T;01<=3`080P@0
5a4C03<^;P0J5QD02PH5018>3@0=2@P02`L601<?3P0710<040`;00l<2`0@30/040d<01@?3P0>20P0
40X:00l61`0=10D03PD60P0C2@X0100A1`P04@H701461`0A1PP601061`0400h41@0=0`@03`D60106
1`803P@500D03`D600h41@0>10D03P@500l51P020147200500l51P0=0`@03P@501061`0?1@H00P0B
20T01P0@1PL03`D600l51P0?1@H03P@501<92P80308300@04PP900`20`0C1`/04@D90`0@10P00`0?
0`L050P<01862P0200l31`030104200A1@Wooooo01?ooooo000Kooooo`0500X:200>3P`03@d;00h>
300A4@l00P0>3P`01@0=3@/03`l=00d=2`0:2PP0410>00803@d;00X03Ph<00l?3@0A4@l04Q8@00P8
1P0?3`d05QHD00X:200@40h03`l=0P0A4@l04P0@40h03`l=00`<2P0<30X04Q8@01@D4P0E5A<05QHD
02TY9`0L71X04A4A00L71`0E5AD03@d=018B4P071`L03`l?00d=3@<030`<01<030`:00d>2P0=3@/0
3Pl:00l?300?3`d03a0;00l@300@40h0414<014B3P0A4@l03A4=04iCC`3=d/h0?T8n01XL6@0F61D0
2PX800803`h<01<040h<014=300A3@`030T601DF4@0>3`X03Ph<00h>3P0H61P03Ph?00d=3@051@D0
3`l=00`=20092PD05QHC01LG5@0B4Q002PX800803Ph<00L02`/900T91`0?3`d04Q8@00P81P0;2`T0
3Ph<00803@d;0P0:2PP09P0H61H051@B018B400=3@/02`/900d=2`0@40h04Q8@00lA3P0=3P/030`:
00/=2P0>3`d03Ph>00h@3@0@4@l0410>00d?300;30P03Ph<00l@2`0@40d03`l=00h?2P0<30T01@D3
018C3P071`D06ATG00h?2P0>3Pd04Q8@00D50`1=CD/0IfMU00/;2@0C4a402@T70P0@40h200/;2@07
01<C4@0820H02@T700`<2P0>3P`03@d;00T91`0600h>30802PT700`03`h<01DD4P0B4@l02@P600X9
1`0>3@/03`h<00h=2`0?3P`040l=00d>2@0?40/200/<1`0300l?2P0=30P03@`800803@`80P0?2`P0
200=30P020X7018D4@0D5Q<06A/H00X:200G5aD0410>0P0A40h3018A3`0700d<2P0?3P`03`h<00`;
2@0;2PP030/900h=2`0300l>3005010?3@0A40h051<?00d<200<2`L00P0?3PX06`0=30P03`h:00h=
2@0B4@d0;bhZ02LV8P0=30P030/700d<200@3@X04@d:014=300=2PT03@`:00T7200;2`/03Ph>00`>
3@0?3`h02PT700d<2P0?3P`03@`:00`;2@0:2@L02`X800d<2P0200l>300400d<2P0<2`T03@`:00d<
2P803`h<0P0@3`d02P0?3P`04A0>010>3P0<2P/08AlP018@4@0?3@h02`T:01`J6`0S8B8200d;3080
30X;00/03@/<00l=3P0B41406ALH00l=3P091`P03@/>00h<3`0@3Q404@lB010>4@02010>4`0:018@
5@0D4QL02`T<00h<3`0?3A002`T<00T72P0:20/02@L:00/930<03@/>01L040hA00l:400@2a403`X@
00d83P0>2@l04@`B01PC6@0J5A/04PdC010;4@0C3Q@030X?01@B5`0B4AH03`hC00d<4@0;2Pl02PT>
01@C600F5AX051<H010?500200d<4@0800d;400?3A804@lD014?500@3Q<03P`A010>4`0>314200`:
3`0900h<4@0@3Q<02PP;014?4P0;2@`030X=018@4`0A3a8040hA00803P`?0P0:20/02P0?3A003Ph>
01LG5`0K6a/04Q8B00X:2P0=3@d03`l?010@400<30`200l?3`0l00T92@0<30X01`L5018B400:2PP0
6a/I00d=2`0>3P`02@T700`<2P0@40h04Q8@00@40P0;2`/03Ph>01@D500B4Q804a<C01XJ6P38b<P0
:b/[00D51@0C4a<05QHF00d=3@0>40l03Ph>00h?3P0=3`h03@d=00`=3@0?4A004A4C00T:300j>cd0
VYZL00l@5P0M7BD02PT?00d<400B4Q8051@B01lP6`2:S8L061XE01DK5`1MHf401@/900d?3P0>3@T0
5Q8?00d:2@0@3`/05a<@010>300E518061HD01<?3P0>3@/0518@1@0?3`d00`0?3`l08b<S01dM7@02
01HF600>01DE5`0>3Q003Ph>00h>300?3`h03`l?010@3P0?4@l051HE0001000D61D061XI014F4P0F
6QP6014C400U01DG500:30T07R0M01`N6`0G6AH04A<@014A4@0G5aL051@B018B4P0E5A<04a<A01TI
5`0B4Q0061PF01`L6P0/;2X0410>018D4@0C5A804A<@01@F4`0J71T05QPE028T8@0D5Q<05aTF01TK
600E5a@07R0M01dM7@0D51@07AlN00/=300C5aH06AlM01XN7@0201XP7P1V01XP800J7Ql061`M01LM
6`0I7ad0728P01dT8P0M8b<06b@S01HN800K9BH0:cDf01lY:P0a>cd0:cDf02lk=`0P;2P07b/W01hZ
9`0N:RP08bl]01hZ:P0P:bd08Rd_02Ha<`0Q;30072DZ02Xa=`0U;3808bX`02/d>@0/=cT09S4c02<_
<P0S<C@07Rd`02@d=`0Q<3D08C8i02PlA00W>T4093Ln01T^<`0N<CL09CPn020c>@0R=C`0:Ca402Li
A@0T=T809SQ602LiA`0Y>dT0;T1>02`nBP0X>4D09cQ202Df?P0T=Cd09SLo02@e?00X>D00;Si702Le
@00Q;cX0<Cm802Lf?@0O;3@0;c]0028];`0M:2X09C0`024[:P0R;2/0:3<e02Ld>P0N:Bl09S4i01l/
=00T;cP092hg01h[<`0R;CH0:cDo020]=P0V<CX09cHk024`=@0L:c006bX_01/X;P0Q;c806RP[028`
<`0V<C@0:3<e01dX:P0J92H07BHU01/T8`0H8240620R0P0K8bH0<@0N9RT07BDX01`T9`0M9RD07RLV
024Z:P0K8S@061hf02@[@00Z<400728`01DL9@0N9B/06b0T01lT9`0O92P06AhR01dR9P0G72006B0S
018G6P0@5AT051TL030e>011ADP05ALK01lP90061`/07b0S01PI6`0];S007QlQ01LH6P0F5aT051DH
01@E6@0L7B404a@H03@e>P0=3Q<08b@Y01DF6`0C51P05QLK01TJ7P0J6al061TM01HG6`0I6Qh00P0F
5a/02P0H6Ad05AHJ00lC5P0<41D020/@01@G700L7b@061TN01hO8`0A4QH2018A5P804Q8D01004Q8B
01hP700?4@h06adH00h?2`0E5A<07AhI09RIU@0K6QP03@`801DD4@0>2PT04A0>01<D4P082PL030h;
0P0K6aT03@0?3`d02@T700h=2`0C4Q003`h<00`;2@0<2@P061@C01hJ6@0>2PT04Ph=01LC4P0A3@`0
0P0?2`X0100@30/04@d<014=300C3Ph201<=3`04018<3P0A2`d04@/=010:30804@/=02403`T;01@>
400E3a404@/=018<3P0=1`T040X<00d72@0H4Q@02@<5010:300G4A<040X<00d72@0A2`d03@T900h:
2@0@2PX04PT:01482@0B20T04@L800X00@0A20T02@0101D?3`0<1PH06a8C01<92P0B20T03`D601<9
2P0>1@D01P0>10D01@0=0`@04`T:00`20`0?1@H03P@500804@L80P0@1PL00`0C2@X04PP900d31006
01061`H03`D600`04@D901D93@0<00@0300401H:3P0B1PX030040106200C1`/02`0301<92`08000D
ooooo`006oooool01@0:2PP03`l=00d=2`0>3P`04A4?00803Ph<00@02`/9018B400E5A<0410>0P0=
3@/00`0>3P`03`l=010@3P02014A3`0800d=2`13@d40410>014A3`071`D03Ph<010@3P0?3`d200h>
30803`l=00h04A4?010@3P0=3@/03Ph<01HF500>3P`03Ph>00D51@0B4Q803Ph>01<C4`0;2`/0410@
00h>3P@03@d=0P0=3@/04@0>3P`03`l=00l?3@0?3`d02`/900h>300?3`d0410>00h>300H71P0N7ei
0??hm01AEU80008000`>2`0C4a403`h<00@04@d<00l05Q@@010A2`0310004Q<@00/;2`0<30h03@d?
00X:300A4A402`/900h?2P0C50h0410<01<C4@0D51800P0A4@l04P0?3`d04A4?00X:200=3@/0<30^
03Lg=@0O7ad030`:00l?3@0B4Q005ADC00h>300410804A4?010@3P0=3@/02`/900`<2P@03`l=0P0>
3P`00`0=3@/03`l=00d=2`0200X:200@00/;2@0?3`d03Ph<00h>300@40h03`l=00h>300<30X03Ph<
00l?3@0<30X04a<A00L71@0?3`d03Ph<00`<2P8061PF00d01`L600h>300C4a4020P600h>300E5A<0
410>00`<2P0=3@/03Ph<010@3P0C4a404A4?00L03@d;01<03Pd;00d<2P0A40h05A@B01@C4@0=30X0
30/900l>300@3`d03Pd;00d<2P0>3@/03@h9010A300;30L02P/600l?2P0<2`L03Pd900<040`900<0
4@`9010<2@0C5Q<00P000@00101bM740IfMU018B400;2`T300`;2@803@T800D03Pd;010?3@0?3P`0
3@`:00`;2@0200d<2P<03Pd;00D03`h<010?3@0C4Ph03@`800`;1`0200h=2@0900d<200:2@D02`X6
00/:1P0L6aL061LC00d:1P0@2`L040`900804@d:00`03Pd;00/:200@3`d03Ph>018B4P0@41001`L7
00X9200<2`T03Pd;00l>300<2`T200X91`8030/900@03@`:00h=2`0>3@/03@`:0`0<2`T300/:2005
00X91`0<2`T03@`:00P71@0D4a400P0=2``03P0:20T040h?01PF5`0A3a003P`=00d;300<2P/03@/<
00h<3@0A3a00;R`]024O800C4A803P`?0P0<2Pd03`0?3A803P`A00`:3`0<2A003@XA00l<4P0=2a00
40hA014?4P0=2`h02`T<00`:3@0:20/030X=00h<3`0200d;3P0=010>4@0?2Q0040/A00l:400=20h0
3PT?014<4P0@2a404`hD00h93`0=20h04@`B00`:3`0300d<4@<03PdB00H020L<00/:3`0<2a0030/@
00d<4@0@3a@200d;400600h<4@0=2a003@/@00`:3`0@3Q<03P`A0P0<2Pl0100>314040hC00X82`0A
3a8200`:3@0N010>4@0?3A003P`?00d;3P0?3A003@/>00h<3`0C4A@0410@00d=3@0>3Ph02PX:00/;
2`0@41002PX:00/;2`0:2PX03`l?010@400;2`/051@B01PH5P0D518010@201HF50092@L030`:020P
7P0O7ad02`/90P0>3P`0300>3Ph04Q8B01DE5@0>3Ph0410@00h>3P0g=cL05ADE01PH6000000051@D
00T92@803@d=0P0>3Ph07`0=3@d0410@00l?3`0H61P04A4A02DU9@1]KFd04a<H00X:500;2Q8051<G
014A4@0?3`d051H@02<V7`0E5a8010X5014G4`0L8R002`d;018>3@0E4A003`/:018>3@0I5A@0510?
01<?3P0D40l040`;00h:2@0@3P`00P0?40/300l?3@0:00l?3`0G5aL04a<C010@4P0C4aD051@F010@
4`0?3a403`l?010@40804A4A00P0418A00h@3`0W:BP02`l>00T=300G6aX03A<A01<E4P804Q@A01h0
4A<@010B3`0@4Pl0418?02HX9@1@DTl051HC00<50P0I6aP04A4?01<C4@0@40h04A4?01LG5@0D5180
6a/I01`L6P0820H05ADC01XJ600H61H04aDB01HH5@0C5A804Q@A01HH5@0D5Q<06Q`I010B3`0B5142
01HH5@0901PJ5`0M7Ad071`L01dM7@0D5QD06ahM01<G5P0I7A`06AhL00806AlM0P0K8Al0100I7A`0
6alN01dQ800M8b4201dS8`1]01hV:00K9BH082X[01LQ8`0V<3808bd^02Te<00M:BD07b/W028^:`0U
<Bl0:SHf02Lc=00Q;2h04A`P01TT:00T;c<06RDY01lW:`0S:S0092/a02Tb=`0V<CD082/_02<`=P0S
<SL07bhc02@f>P0O<3L083<i020f?@0T>3l093To01db=`0O=3L093Pl028e>@0S=S`09SU102Li@`0U
=D807Rhm024a@00Y>DP0;Ce<02dmBP0^?dT0;Ci702Tj@P0]?TH0<D9902Li?@0T=C`0:SY202Xh@`0X
=Sl0=49:02dl@`0V<cT0<Si302Pc=`0M:2X092h`02@^;`0S;B`0:cHh03U4BP0O:S008bhd02Xd?@0V
<3T09S0j02Xd?P0R;3H0:C<o024[=`0U<3/08c8i01la=@0P<SH08C0e01d/<@0P;S409C<f02@b=@0J
9BL06BDU01LS8`0R;B`06R<R01PQ7P0G81l06R8U01hV:@0P9bd08BP^020W;@0O9bT07BDW01dV9@0M
9BL06R0f01PM>P0T:D@0:Rm301hT<P0I82X07B8V01/P8`0201dQ900?01/O8`0L8BD082DX01dU9`0I
8B<08BHY01`Q900I7R4051PK00T;3`0@4AD0:2T]01LH70092Ph06a`N00<05QLI01/05aPK01hO8`0B
4aP08R<X069SJ00/;3@07AdU02LX;@0M7R<07AhR01`M8@0I6Qh05QLK018C5`0E5QX051DI01DF6P0I
6Qh061TM01<G6P0N8RP03a8I01XM900V:C00LW=h00d>4`0B4aL00P0C4QL201<C5@0C01<E500=40h0
71hK00L91P0E5a@06QXH00`<2P0o?cd05QDC01<B400F5A<04Ph=00l>300?4`l02a0<00dB3P0B5140
3Q0=00H81@02010@3P0400l?3@0A40h04a8@00l=2`802`L600@03@T8010<2`0>2PT03@T80P0?2`X0
100@30/04@d<014=300B3@h4018<3P07014;3@0?2@/04@/=014;3@0<1PP03PP:00l92`02010:300=
00/51`0B30h0208401D?4@0<1PP0208400d72@0:10H02084014;3@0?2`/02`X800l92@0201482@0=
0147201CBDX08QPI00d41@0;1@D03PX900d9200@1`P02`4200d3100800003`D601D;300600h41@06
0147200O5AH04`T:00l51P0E2``050X;0P0?1@H0100A1`P05@/<01H<3@0C2@X<00l51P0<0104200B
1PX03P8600h21P0A1@T03P8600d11@0?0`L02@0101lC5`0?1@L060`@5?ooool001_ooooo00/02PX8
00l?3@0>3P`03`l=018B400?3`d03Ph<00/;2@0E5A<06a/I01@D4P0200`<2P0<00h>300A4@l04Q8@
014A3`0?3`d04A4?03hn?00J6QP04a<A00X:200B4Q003Ph<1@0?3`d03`0C4a40410>00`<2P0E5A<0
30`:010@3P0F5QH030`<018B4P0?3`l04A4A00`<300@41003`l?00h>3P0300l?3`803@d;01403Ph<
00l?3@0?3`d03`l=00`<2P0>3P`03`l=010@3P0>3P`030d:01/M6P15AT<07b0M00H71@0H61H02`/9
00h>300400l>300A00l@300B4`d04a@?01<D4@0?3`l01`L9038b=00@418030`<018B400:2`H04A8<
00X:1P0?3`d04Q8@00h>300=3@/00P0@40h2014A3`0:010@3P0=3@`030`:00l?3@0<30X04a<A01@D
4P0A4@l051@B00d=2`<03Ph<00@03@d;00`<2P0=3@/03Ph<0P0@40h01@0?3`d03@d;00/;2@0=3@/0
410>00804A4?00<0410>00h>300>3P`00P0?3`d200h>300701<C4@051@@04A4?00P81`0@40h08B4O
00/;2@0200l?3@0900T91`0B4Q002@T700X:200B4Q005ADC00l?3@0:2PP03Ph<008030`:00@03Ph<
00l?3@0>3P`02`/91P0<30X04`0@3`d03@`:00h=2`0A40h04Q4?00l>300>3@/04A0>010?3@0>3@/0
30/900d<2P092PD030d800X;1P0<3@P04Q8=014@300?3PX00`0A3@X02@0B3@X04@d:00/>2`0E5a@0
4A<@01TK600P81h0:b/Y018B4002014@3P04010?3@0A3@`040`;00l>30804A0>00H03`h<00h=2`0>
3@/03@`:00`;2@0=30X300h=2`03010?2`0=30P030/700803@`800T030/7010?2`0@3`/03`h:00d<
200>3@T04@h:01<>2P0A3@X00P0@30T03P0=30X03Pd;014@3P0;2`/03`l?014A4@071`L02`/:00h=
2`0?3P`03Pd;00`;2@0:2@L02`X8100=30X300h=2`0@00d<2P0<2`T02`X800/:200<2`T03@`:00h=
2`0@3`d03@`:00`;2@0;2PX04Q0A01`J6`0C4A804@l@00`:2`803`d>0`0>30d04P0?3@h08R0Q01PF
5`0>30d03@/<00`:2`0?3A003`dB00h<4@0<2Pl030T@00d:4@0?31804@lC014?4P0C4A@040hA00l=
40803P`?00d040hA014?4P0>30l03@/>00l=400=2a003P`A00d;400;2@h030X?00l=4P0;2@h03@/@
008030X?0P0@3Q<00`0<2a003@`A00`;400300d<4@8040lD00L03@`A00X93P0;2Pl03`hC014?500@
3Q<03P`A00<03@/@00/040hC00l=4P0=2a003@/@00l=4P0@3Q<03@/>014?4P0?3A003P`?00d;3P02
00`:3@0900d;3P0@3Q403`d@014?4P0G5AP03`l?00X:2P0?3`l04A4A00803@d=0P0>3Ph0200=3@d0
410@00l?3`0;2`/03`l=00P81`0=3@/03`l=0P0A4@l05P0>3P`03@d;00l?3@0;2`T04Q8@00l?3@0=
3@d04A4A01<C4`0<30`04A4A01<C4`0G5aL02`/;010@400C4a<030`<018B4P0?3`l04A4A018B4P0A
4A42010@400H00820P0E5AD0410@00@4100N7Qh03PlB00l?5P0?3Q<03@d?01<C4@0M7QT03a0;00D7
0`0>40T0:bdX010C400F6AL03Pl=00T81P0D4a406aXH014@3P0B4@l03`h<1@0@3`d03@0A4Pd0414<
010@3P0@40h03`l=00l?3`0B4Q80410@010@4P0C4aD051@F010@4`0A4A<00P0A4A42018B4P07018D
4`0=3`h051HE03Hj>@0>4Q404QHE00lD4P02010B3`0<014C400B51404aDB01@F4`0F61D02``:01PJ
5`0B51806adJ014C400A4@l051@B0P0A4@l02P0F5Q@05ADC02TY9`0d=3804a<A01hN700@40h06ATG
01PJ5`0J71T201DG500F01HH5@0A4a005ALD01DG500C5A8071hK02@V8`0F61D0418@01/M6`0E5aD0
6A/J01TL6`0E6AL06alN01TO700H7Q/06AlM01`S800M9R<0728P01dS8`807R@T0P0L92H05P0L9BL0
82X/01/U9`0P:bd08bh`02<^;`0[=cD08bl^024];00Q;Bd08bl`02Ha=00a?400;3Ll03Q3B@0/=ch0
6bH]028/=00O9bd09Bhc02</<@0S;C8202Ha=@1602Db>00V=CX08S4f02Pg?00Q<cL08C@i024e?00W
>d80:Ce2024f>@0P<cL093Lk02`o@`0]@4H0:C]40394C`0`@Tl0:CY803=4C`0iBEH0<T9>02Lh@`0[
?4H0;Sm902XkA00/?DH0;Ci702Tj@@0Y>T<0<3m9041>F@1@GVL0>dUA02<b>@0X=C/0<Si302dh?00Q
;2h092l`02H`<@0U;bh092l`06QfN02d`<40BUQK03=0A@0f@dT0@TmF04QEG@0O;3@09S<k02@a>P0[
>44082le02<b=`0[>Sl0:CPk024`<`0Q;c8082h_02<a<P0S;S009c<c024];@0R;2`072DT01XS800I
8R406b<V01dU:0<07RD[0P0P:2X09`0P:BP07bLW01PO<@0G7C<07bHi02@Z>@0M8bh06R4X01PM800K
82<05a/N01PL7`0M82@06AhR01PM800W;c407bLY01DJ7@0H7B005Q/N01DI700J7B00414E04U:CP0Q
8RH0824U01TJ700J6ad07AhP01TJ700E5QT06Q/O01PI7P0Q8RL0?Sm401LG7`0J6R80:BX_01LH7@02
01LH700301PI7@0I6Qh06AXN00805QLK00/05aPL01PI7@0F5a/04aLJ01LK8P0<3aH05QTP030c>01l
OH807QlT01@E6@0201DD6@0D01DE5`0D51H04aDD00lC400F61D03a4>01TK600D51805aLE01DE4`0E
518030/9014@3P0I5A@04A0>01<G4`093PX02a0<010B3`0A4@l200h>300500h=2`0920H04a8@01DD
4P0?3@/00P0A3@`0100E4A0040`;00l;2P0B3Pd4010<2`04014=300A30d04@/=014;3@804P`>0280
4`d?018<3P0G4A<0618D014;3@0?2@/040X<014;3@0C3@l050h@01`F600;1@L05Q0B018<3P070@<0
3`T;01HA4P0:1@H03PP:00h:2P0;2PP03`T901482@0@1`P04@L801hD5@0<0P<03`H701@>3P0B3Pd0
3@T800l61`0<0P<050X;0P0?1@H00`0B20T03`D600l51P0400l51P060147200S6AX05@/<00l51P0G
3@h04PP90`0@1PL201882@030147200>10D03P@500@03P@51P0?1@H01P0B1PX040@801L;3`0G2`l0
3P8600l31`8040@800@040H801862P0h;3005@/=5?ooool001_ooooo00D02`/9010@3P0>3P`03`l=
018B400300l?3@0V01<C4@0B4Q003Ph<010@3P0<30X03`l=014A3`0B4Q00410>00d=2`0:2PP030`;
01dM6`0@40h04a<A00h>300=3@/04A4?01<C4@0A4@l02PX800H6100=3@/02`/900X:200F5Q@02@T7
018B400>3Ph01`L700T92@0?3`l04A4A01<C4`0@41003`l?00h>3P0?3`l2010@40803@d;00/03Ph<
00l?3@0?3`d03`l=010@3P0>3P`03@d;00h>300A4@l04a<A01@D4P0201LF50030000000D51804A4?
00803Ph<02T03Pl<00d?300>3P`03@h900h?2@031000414>01LG5`0B4Q@0A4A6018B50051@D051@B
00L80`0=3PP02PX600h>300C4a404A4?00/;2@0<30X03@d;014A3`0<30X03`l=018B40092@L02`/9
00P81P0>3P`04Q8@00d=2`0820H030`:00h>300@40h04A4?010@3P0>3P`03`l=00h>300200d=2`08
00h>300@40h030`:00l?3@0E5A<05QHD018B400;2`T500h>300D00l?3@061P@010@200X:200V9R@0
QHF3028R800B4Q0010@200/;2@0:2PP03Ph<00l?3@092@L03@d;00P81P0L71X0<30^00h>300?3`d2
00h>30803`l=00<030`:00h>300>3P`0100>3P`0100?3P`03@`:00`;2@0=30X200l>300300/:200>
3@/03`h<00803Pd;00P040l=00T:1@0<3@P02P/600/<1`0B4Pd04A0<00d<20<03`/800`040/800l;
20072`L0004000<50P0<3P/051@B02<S8@0@40h040l=00l>300>3@/200h:2@0400l>300A40h04A0>
00l>30803Pd;00H040l=00d<2P0>3@/040l=00l>300=30X200h=2@0<00d<200<2`L030/700d<200>
3@T020L300h=2@0;2PH02PT5014>2P0C3PX040`90P0?2`P0200=30X03Pd;010?3@0820P02PX:00d=
3@092@T03Pd<0P0=30X200h=2`0800d<2P0<2`T030/900h=2`0@3`d03Pd;00`;2@0;2PP200`;2@0?
00d<2P0>3@/03Pd;00l>300>3@/030/900d<2P0@3`d03@`:00d;300F51D09B<T01lM7P0E4a@04Q0A
00D03P`=00d03@/<01XI5`0F5A<0518C01<A4P0?3@h03P`?00l=400>30l03P`A00l=4P0A3a@0518G
00<040hA00@03`d@00h<3`0<2Pd040hA0P0A3a802P0>30l03@/>00h<3`0=2a003P`A00d;400;2@h0
30X?00l=4P0@3Q<300l=4P04010>4`0B41D03@`A00d<4@8030/@0P0;2Pl02P0920d02PT>00T83@09
20d03PdB01@C600C4AH04@lD00h<4@0=2a0800h<4@803`d@00L040hA00l=400<2Pd02`T<00`:3@0=
2`h040hA00803@/>00/04@lB00l?3`0?3`l061PH01`L700@41002PX:00P820092@T03Ph>01@D5002
01HF5P0<00P81`0A4@l00@4001HF500A4@l00`<100T91`0G5aD07QhL00l?3@0@40h04Q8@0P0<30`0
1@0@41003Ph>01<C4`071`L0410@00805QHF02403Ph>01dM7@0=3@d030`<00l?3`0>3Ph02`/;00`<
300@410030`<01PH600?3`l03Ph>00X:2P0C4QH04A0E00H6201UIF@03@h900/<1P0=3@H05AD=00h=
200g=S808b8N00l>2P0C4Q0030/901XI5`0V9B<05aHD01@C4@0@3`d00P0A40h02@0B4@l04a8@018A
3`0B4`h04A8=014A3`0@40h03`l=00l?3`0201DE5@0501@D5P0C4aD04Q8D00h>4@0?3a400P0@4102
014A4@07014C4P0/;Rd08R@S08N;RP0>4Q4061`K01/Q7`04018D4@804aDB02/02`d:01TK600o@Ch0
7R0M01HH5@0@4Pl03`l=01hN700L71X051@B018B400D518030`:00h>300A4@l03`l=01HF500B4Q00
71hK01LI5P0E5a@071hK01hP7@0A4a003a4>01HH5@0B51407AlL02PZ9`0C5A80828O01lQ7@0G6A@0
61dI00dB3@0H7AL07R@P01`R7@0I81T05b0K01TS700L9B007R@S008072DT0P0M9BL0200L9RL09S0b
02Pa=P0L9b/07bX^01/V:P0H9RT072X[0P0M:b`0A00S<C@0:SPk02dj@00^>d80<Sm7055NIP0lBE80
6BH_02Tc?00W<3L0<CY102`g?@0V<CL09c8h02Db>00W=CP09SDh024`<`0W=ST08C<e02<e>@0U>3l0
;3m602`oA00X>cl093Pi024e=`0[?T80;3m502Lj@P0fB5@0=TQF02hoBP0a@TX0<D9<02hoB00/?DL0
;Sm90393C@0dADl0<D9<02hoBP0dADl0>d]H03Y:E013DE`0EVA]03]9D@0V=C`0;S]102Te>P0W<SH0
92la02H`<P0U;c009c4`02<_;P1YMgL0]L?404QFE`0_?Ch09C<e0;K4a`2Q[[@0>4E;020]<`0M:S00
934h0P0U=3T08`0[>Sd0:CLj02<a=00T<S<08B`^028];`0K9bL08R`]01hX:@0P:RX072DT01XS800I
8R406b<V01`T9`0K8RP072<Y01dT:P0P:2/08BT[024Z:@0P:2P07BH_01`T<@0M9S007RD]01XQ9`0J
8R@05a`O01/P800I7Ah06AdP01`O8`0G72007B8U00804QXL02P0724T03Hk?P0P9BP07B4T01DH6`0H
6Ad07AhR01LH700M7R805aPJ01@E5`0J6ad07QlQ01/L7`0J6al06AXO01DF6`0L7B805aLO01hN9P0>
3a@06a`Q01TJ7P0F5a/051DI01<D600B4aL05aPL01PI7@0G61`05QLK01@E6@0B5QT04ADL01@G700>
4AH06ahS00`=4@0T9BT051DI0P0D51H05P0C4aD04Q8B014C4P0E61D030h;03m1?P0Q8b004A4?01LG
5@0@40h04Q4?01HE4`0I61H05A4@010?3@1OH5h07R0M00`>2`0A4a004a<A00l?3@0=30X201<B4009
02LS8P0V8R404Ph=01@@3`0C3`h04Ph=020L6`0M6AP04@d<00D040`;00@040/;00l92`0@2P`04@/=
0P0B30h00`0?2@/04@/=01@>400200l92`0C010:300?2@/05Q0B01H@4P0C3@l02`D701XD5P0@2P`0
4P`>030Z;016@4809R0R01@>40091@D02`X800l92@0A20T040L80147200201D;300:01@;300?2@T0
2@D400h:2P0H3a002P0100h41@0C2@X050X;014720L03`D600P04`T:00l51P0B20T0308300h51@0?
1@H040H700l51P803P@500<03`D601061`0@1PL0100@1PL600l51P0<0104200>0PH06@dA01X>4P0@
10P04`L;00`0100>0PH05`/?0104201JCU808ADI5?ooool001_ooooo00d02`/9010@3P0?3`d0410>
01<C4@0@40h04A4?00h>300?3`d03Ph<00`<2P0B4Q003Ph<00@0410>01T03`l=00`<2P0B4Q004A4?
01DE4`0?3`d02`/900d=2`0A4@l04Q8@010@3P0:2PP01`L500l?3@0<30X0410>014A3`0<30X03@d;
020P800E5AD03@d=014A4@0:2PX0410@00803Ph>00@03@d=00l?3`0@4100410@0P0=3@/0100>3P`0
3`l=00l?3@0?3`d300h>300300l?3@0@40h040l=00803P`:00@05Q@B00l>300;2PP03@d;0P0=3``3
00`@300D00d@2P0@4@/0:b`W07]kN@0?3`l04a<E030`<P0A4A<051@D00`<2P0<3@P051D?00d>2P0>
3P`05ADC01XJ600@40h02`/900l?3@0L71X200h>300:01@D4P071`D0;Bd[030`;P0>3P`03`l=01<C
4@0>3P`03@d;00h>30<0410>0P0?3`d0100>3P`03@d;00d=2`0>3P`2014A3`0400l?3@0<30X02PX8
00/;2@<03Ph<0P0=3@/05`0>3P`04A4?00/;2@0E5A<03`l>03Xj>02MWI/06ATH010@3P092@L0410>
00D50`0D51803@d;00L71@0B4Q002@T700`<2P0H61H020P600h>300<30X02`/9008030`:00<02PX8
00h>300>3P`0100>3P`2014@3P8040l=0P0A40h03@0;2PP03Pd;010?3@0>3@/03`h<010?3@0?40/0
4A8=00/<1`0:2`H03Ph900/:1P0>3@T00`0@30T02@0A30T040`900`@2`0:30X04Q@@00d?2`092@H0
3Pl;00l?300300l>2`8040`:00l03`h;014@3@0@3``03Pd:00d<2@0>3@X04A0=00d<2@0>3@X04A0=
00l>2`0;2PL03Pd9010?2`0?3PX00P0>3@T04`0?3PX03Pd900/:1P0?3PX04Q4=00l>2P0@3@T04Pd9
010<2@0>2PL03`/800l>300=30X04Q4?00l?3`0>3Ph030`<00T92@0?3`h0100>3@/200l>30<03Pd;
00<03@`:00`;2@0<2`T00P0<2`T200d<2P0500h=2`0@3`d051<A018A3`0?3P`00P0C4Q002@0=2``0
30X;00d;300@3Pl03`h>03Dc=00<2P/03@/<00l=3P02010>3`0>00l=3P0@3`d03Pd;01<A4@0E4a<0
40h>00l=3`0A3a8040hA00l=4@0>31403`dB018@5@0@3Q4200h<3`0A00l=400>30l02`T<00h<3`0?
3A0040hA00d;3P0<2Pd03P`?00d;400>31403@/@00/93P0<2Pl03`dB014?500=31400P0?3Q<00`0=
2a0040lD00`;400200d<4@<03PdB00H04Q4F01<B5`0@3a@03PdB00d<4@0?3Q<300h<4@803@/@00<0
30X?00h<4@0>31400P0?3A8200h<4@0A014?4P0<2Pd03`d@010>4@0=2`h03`d@00d;3P0>30l04@lB
00d;3P0;2@`03`d@01<C4`0;2`/03Ph>014A4@0?3`l00P0@41003`0=3@d0410@00h>3P0:2PX02`/;
010@3P0>3P`0410>00d=2`0Z:RP0S8b:024Q7`0>3P`0410>00/;2@02014A3`0Y018B4@0J6QT06QXI
010@3`0D51<0<S8a01`L6`0D51<0OWim02/[:P0?3`h04Q8A01DE500F5QD04A4@00d=300@40l051@C
01DE500?3`h030`;010@3`0=3@`03Pd>01HE5@0;2`X0?3di014B3@0;3@L03Pl801LF400A40`05Q8>
014=300K5a@04Q0=00l>300C4Q0040l=00h=2`0C4a400P0>3P`0100?3`d03Ph<00h=2`0@40h201<D
3`03018B400@40h0410>00803`l?00P04A4A01<C5@0C4aD04A4C010?4`0@4180410@014A4@804Q8B
00L04A<B01HH5`0>40l0RHf<0496A@0B5QD0318@00805QPE01/051HC018D4@0A4a00418?01<E4P0J
71T0?Cll020R7`10@Sl07b4N01DF500N7ad06Q/I01@E4`0C51804a@A01XK6@0B4a004a@B010A3`0G
61H051HC01PJ5`0G6aL05QXF01/O6`0M8Ad00P0C5a<08@0I71T061/H01lR7`0U:2D05aXG01hR700D
618071lJ03Hk=@12B48082HP01hU7P0L91d06b@L01XT700J9Ad06bDO01dV9@0M9RH07BHX01hW:@0P
:R/082/^024/;`0Q;34082`a01TV:`0Q;S<07B``02<`>00U<cX08Blf028`>00202Hd?00V02dj@`0^
?4H09S<m02Hd?P0/>DD0:CI002<_=`0a?D<0<3a202Xf?00R;cD07BX`02Xh>`0U=3L07Rd`02@c=P0R
<c@09cLj02Hg?P0[>d80:Sa002i1A00^@D<09STl02@g>`0U>3l09SQ302i0C@0^@4l0;T1:02`m@`0V
=cl09CHn02Pi@00X>D80:ca603A5C`0gAe@303=3D@0Z02lnB`0]>dH0:cU202lmA@0eA4/0;ca202@`
=@0V<CD09S4c02D_<@0U;c00:38a02Tf=@1BHF00?Te;02Xi>00I:2P09C@d03A3A@0eA4H07B`_02Le
>P0R<3@08Blc02/i?@0U=3P09C<f02Le=`0U<cD09C8c01/W:00R;Bh0:3<c038l?00W<C406R<S01XS
800I8Ql06b@S01lW:P0Q:B`082L]0P0R:Bl0:@0Q:B`082PZ01lX9`0O:2H08B/^020Z;P0M9RT072@U
01`U9P0N9bH07B<S01/P8@0T:2T092P[01TM800I7R807B8U01TQ8`0R:R`051TL020U:00C61/061`O
01PK7P0_<3@09BHZ01dN8P0F5a/07AhP01DF600F5aT05aPJ01DF6@0F5a/07QlT01HG700O82D07QhV
018B6P0P8BH05QLL00<061TM00l06AXN01PI7@0B4aL05QLK01PI7@0F5a/05aPL01LK7P0C5a`06ahS
01<F6`0?4aL051DI01HG6`0E5QT00P0E5AL08@0D51D04a<C014C4P0?4`l092HS09BFT`1HFUL03Ph<
01@D4P0C4a405QDC01TH5P0B4@l05Q8A01hM6`1GF5H06Q`I00`>2`0@4@h04A0>00h>300D4a403``;
00d;2@0G4a806ADD01DA400C3`h02`L601DA400^:RT09B4P010<2`02014=308040`;00@03`/:010;
300A2`d040X<0`0A2`d08@0@2P`04@/=018<3P0D3Q00618D01H@4P0A2`d03`T;010:300N61X02`D7
01<=3`0@2P`030H8010:300?2@/02@<5018<3P0@30`03@`:014;2`0C2P/04PT:01<92P0>1PH03P@5
01482@0:10@02PH507YfM@0g;Rl07Q@E01882@0200l51P030147200@1PL040H700@040H700`03P@5
00l51P0?1@H05@/<00d3100A1`P03@<400l51P0@1PL03`D601061`0E2``601061`H03`D600`040@8
01452@0A1@T04@D90104200?0`L04@D90104200900406PhB01<82`0@1PPDooooo`006oooool0300<
30X0410>00l?3@0@40h04a<A010@3P0A4@l02@T700h>300D51804a<A00l?3@80410>0P0>3P`02@0?
3`d0410>018B400B4Q0061PF00/;2@0=3@/04Q8@00d=2`0200`<2P0?00d=2`0>3P`03Ph<00/;2@0:
2PP051@B00/;2@0C4a4030`:01LG5`0?3`l01PH6010@400:2PX04a<C00<030`<00<03@d=00h>3P0?
3`l00P0=3@/00`0>3P`03`l=00l?3@0200l?3@0<01@D4P0G5aD05QHD014A3`0D4A004`d=00l;2P09
1@@06aLF00X91`0A4@l03@l<0`0;40`0400:40`03A0;018C3@0?40/0J6QV014A4@0G5aT061PJ01lO
8@0A4A404Q8@00X;1P061`404a<?00/;2@071`D200/;2@0700d=2`0;2`T04Q8@00D50`092@L05QHD
00T91`0201<C4@04014A3`0?3`d030`:00l?3@8030`:0P0=3@/01@0>3P`03`l=00X:200<30X03`l=
0080410>00P03Ph<00X:200<30X03`l=014A3`0@40h03`l=00h>30<03@d;00/03Ph<014A3`0E5A<0
1PH401DE4`0@40h02PX8010@3P0C4a40000001@D4P0200/;2@0:014A3`0@40h01PH400h>300A4@l0
2`/900h>300C4a403`l=00h>30803`l=00<03@d;00`<2P0<30X0100<30X0100<2`T03`h<00l>300>
3@/200d<2P0=00h=2`0@3`d040l=00h=2`0<2`T03@`:00T:1@0<3@P02P/600/<1`0B4Pd04A0<00l>
2P03014=2P09018=2P0A3@X03Q8<00h@2`0<3PT0418=01PI500>3`X03@h900<03`h:00<04@d:018>
2`0=30P00P0?3PX05P0<2`L02`X600`;1`0@3`/02PT500/:1P0@3`/03@`800P70`0>3@T04Q4=014@
300>3@T03`h:014@300<2`L04A0<00h=2@0B4@d040l;00h;1`0A30P200h:1`0<010<2@0@3`d03`h<
01<B400=3@d02@T900d=3@0E5AD071`K014@3P0?3P`03Pd;0P0<2`T2010?3@0400`;2@081`D02PT7
00h=2`804Q4?0P0A40h200l>300600`;2@0A40h04a8@00`;2@0=30X02`X80P0?3@h01`0<2P/03`d>
00`:2`1?CDh02PP900/92P0>30d00`0@3Pl02P0@3`d03Pd;010?3@0@3`d030/900l=3P0H5QT05Q@G
018@4`0?3A8200h<4@09014?4P0?3A003P`?010>4@0?3A002`T<00`:3@0=2`h03P`?008030X=01/0
3P`?00`;400=314030/@00X93P0;2Pl03PdB014@5@0<2a0040lD014@5@0?3Q<051<H01<B5`0B4AH0
3`hC00d<4@0;2Pl02PT>00/:3`0>3A803`hC00d<4@0<2a003@`A00d;400?3A800P0A3a@0100@3Q<0
3P`A00d;400>314200l=4P0U00h<4@0=2a004Q0C00X82`0=2`h03`d@00h<3`0B41<030X=00l=400C
4A@040hA00h<3`0A3a804A4A00/;2`0=3@d030`<00X:2P0<30`03@d=00/;2`0B4Q8051@D014A4@0D
51@04A4?018B40071`D051@B00@40P0b<S0061PF02PX9P0`<2h051@B00d=2`02014A3`0l02PX9P0W
9bD04A4?01/K6@1NGU`0<c<a018B400[:bT05ADC01TI5`0<30X04a<A018B400:2PP01PH400/;2@0@
40h04a<A00H6100B4Q002PX8018B400G5Q@01`H201dL600:2`P06Q`G00`>2@0@4P`05aPB00L60P0?
2`P06aHC02HN700I5Q<051@B01TI5`0?3`d04Q8@01HF500<30X03Ph<014A3`0<30X02`/9014A3`0D
5A004a@?018B400A4@l0410>00l?3`0A4A404a<C01HF600D51H04A4C00l>4P0B4Q@04Q8B0P0C4a<0
900D51@04aDD01/M70082PT0<CDd00`@3`0F6QT03aDC00lA3P0@4Pl04Q@A01@F4`0E5a@05aTF010B
3`0H6QL03a4>018D4@0R92406A/H01dO700F61D03Q0=018D4@0H6QL04Q@A00`>2`0L7Q/0418?02<U
8P0>40d06A/H00hC3`0I7QX061dI01<H508051TE00<04QLC01@I5@0F6aL00P0I7QX01P0D6AD03a@>
01lT7P0Y;RP0Ada606Q^I`806B0I02406B<K01/U7@0M9al07BLO01`W8@0L9RL06bDW01`V:00N:B/0
8B``028]<@0S<3<0;S]103i;D@0U<cT08c8g01DT:`0U=3l0:cU602<d?P0T<cl0:3I102@e?`0Z>T@0
;ce802XkA@0Y>4D0;C]802hlA`0X=cl0:CHn02@a=`0U<SP00P0Z=cd0@@0Z>C`08c8e01XY;00Q<C80
8c<c02Ti>@0/>d00:cXo02Lf>P0/?T00;Cm102i0@`0]@4H0:ci50312CP0_@Dl0;d1@03A5D00a@dL0
;3i202Tk@00/?D@0;d1802m0B@0dADl0=DED02loCP0`@4l0<41@02hmB`0c@D`0:CM002Tg?`0U=3/0
7R/a02di?P0/=c/092la024/;@0V<3409S0_02Ld<P0L;2T0=DE202Hf=00^?Sd07Bd/01l_;`0Q<C40
9CDe02Dd=`0K:Rd0:STl02`j?@0S<C@082ha02Le=P0V=3D08bh`02@`<00U<C408bd^02/e=00T;Rd0
7BHU008082TV00X082TX028Z;@0R:Rd07bH/020W;@0O9R`07RHY01lW:@0P:BP08b`Y0P0K9R805`0F
8Ad05AhK01TR7`0N9b@08bTY01/P800^<S<0;30c01HJ7@0K82<092T/01<K7@0R:R`04QLJ01hS9P0J
7b807B4T01PJ7P0?41@0;Bhb01HG6`0H6Ad05aPJ00805AHH00X051DG01PI700V9b/0414F01hO900C
51T06a/S01PH800B4aP05QLL0P0H6Ad0100G61`04a@H00l@500E5QX201TJ7P8051DI02X04aLJ01DI
7@0F6Ah06ahS00hB5@0E5QX051DI01PI6`0G5aT05aLG01HF5P0D51@04aDD01LJ5`0<3P/071hK01LI
5P0A4@l0410>014A3`0@3`d04A0>01XI5`0E4A002@P601@E4`0:30T04Q@A018B400B4@l05aHD04A3
@@0V8R405a<B00h:2@0?2`X0510?014=300C3`h0510?00T5100:1PD3014=3004010<2`0?2`X03`/:
014<30804@/=00<040X<00l92`0?2@/00P0?2@/04`0>20X04P`>01TC5@0C3@l03`T;00L10`0L5QP0
Dde?01`F600=1`T030H8014;3@0F41803@P900T31@0=1`T030P800h=2`0B30`00P0D2``03@0D2P/0
308300l51P0=10D0618B00X61@0E4A406Q4B00X00@0>10D03`D600`20`0A1`P01P0@1PL01@080000
5@/<00l51P0?1@H04PP900803P@500D040H700l51P0;0@802P0100l51P0600h41@H03`D600D05`/?
01X>4P0=0@D02`0301452@0200`010050106200C1`/02`0301<92`0800005?ooool001_ooooo00@0
4a<A018B400A4@l04A4?0P0@40h03`0C4a403`l=00P81P0;2`T04A4?00/;2@0<30X03`l=00h>300<
30X04a<A01hN700/;2X03Ph<018B4002014A3`0800l?3@0@40h02@T700L71@0H61H04A4?01LG5@0?
3`d200d=2`0R00h>300?3`d03`l=00d=3@071`L05ADE01@D500000006ATI014A4@0:2PX02`/;00X:
2P0820P02PX:00/;2@0K6aT09RHT01LG5@0A4@l03Ph<010@3P0J6QP0:2PV01TI5`0;2`T04Pl>01D?
3`0E4A003`/:01DA400920H03Ph<00d?30<02a0<01@02Q0<00`?2P0A4P`05AHA01DE4`0?3`l02`/=
00X:30071`T02PX:018B400>3`X03Pl9010@300=3@/0410>018B400A4@l03`l=00h>30D03@d;0100
3`l=010@3P0@40h03@d;00`<2P0;2`T03Ph<00T91`0?3`d03@d;00l?3@0:2PP02`/900`<2P0K6aT0
71`J0P0>3P`0200=3@/030`:00d=2`0;2`T02PX800d=2`0?3`d0410>0P0A4@l3010@3P0600l?3@0>
3P`030`:00`<2P0;2`T09RHT0P0<30X07`0A4@l030`:00d=2`0;2`T03`l=00d=2`0:2PP0410>01XJ
60071`D04Q8@00`<2P0];B/061PF00h>30071`D04Q8@00T91`000000410?018B400G5Q@020L500X9
1`0E51803@`:01HE4`0B4@l040l=00d<2P0<2`T00P0=30X01`0720<03a0;00L80`0>3`X02`/600l>
2P0;2PH00P0=2@H0600?2`P040/800d91P0=4@X00`H001/N5`072P<04A8<01DF400=3PP02@P301LF
4@0?3PT03P/600l<1`16AD0051<>018A300;2PL02PT4014@2`0=30L030/600/:1@8030/600<03@`7
010?2`0?3PX00P0>3@T200`;1`0700d<200>3@T04A0<00d<200<2`L03``800l:1P0300h:1`0/00`;
2@0F5A<00@0001DE5@0820P0410@04E5A@20P7l05QDC00d<2P0@3`d02PT700T81P0<2`T02PT700d<
2P0?3P`03@`:00X91`0<2`T01`H401@C4@0@3`d02`X800`;2@0=30X03Pd;014@3P0>3@/04A0>00l>
300A3a003`d>00d;300>30d03`d>00h<3@071@H03@/<018@4@0<2P/02@L800d;300H5aD200/:1P0?
018A3`0=30X03Pd;00X82@0@3Pl04Q0C00h<3`0?3A003@/>00X82`0=2`h04@lB010>4@0>30l03@/>
00<03`d@01D03P`?00d;3P0=2`h05QDJ00/:3`0a<3D05A@I00D52@0M72402@P=01PG70061@X06aXO
00l>4`0100D02`X?01PG700>3A804a8G01@C60040`P00P0?3Q<0200@3a@04Q4F018A5P0?3Q<03`dB
00`:3`091``05A<H0P0?3A807P0>31402`T>00X83@0=2a005aDJ01lM8P0;2@`03@/>00`:3@0:20/0
30X=00d;3P0?3A002`T<00d;3P0B41<00@0200l=400A4A404a<C00h>3P0820P030`<014A4@0<30`0
2`/;00d=3@0A4A403@d=00X:2P803@d;01003Ph<010@3P0A4@l04Q8@010@3P20P7h0Ng]i01dM6`0I
6AL01`L5010@3P0J6QP01`L501LG5@0S8b4051@B200?3`d01P0@40h04A4?014A3`0C4a405QHD01@D
4P803Ph<01D03@d;00`<2@0?3PX040l;00d>2@0:30L02`d800hC3P0@4Pd05ADC010=300=1`L0610>
01HC4@0820H01`L500T91`0S8b40000001DE4`0B4Q000P0@40h0200B4Q004A4?00/<1`0C50l051@B
00l?3@0A4@l0410@0P0=3@d01@0@41803`lA00h>400L71l071`N00802PX:00l0820P01LG5`0F61L0
6A/J01@F5@0C5aH0310?00hB4@0D6QP05ALD018D4@0>40d0418?018D4@0@4Pl00P0B51401@0A4a00
3a4>01DG500I6aP071hK0080418?00l05ALD01LI5P0I6aP04aDB018D4@0C5A805QPE01TK600H6QL0
4AHB01TO6`0C6AD01P`801TO6`0E6aL00P0G7AT0G@0H7QX06R0L01TO6`0F71P05Q/E01LL5P0R9b40
7RDN028Y8P0L8a`05b4I01TS6`0M:2006B@L01LR6P0S;RP072PZ01`W:`0O:Rh07RT]024/<P0R;cD0
:cTo05i]M03Ij>l0;Si501`]=00T=Cd0834m02LgAP0Y>dL0:ca902`lB@0/?TX0:ca802Hf@`0S=D40
:S]702@d@@0Y>T@07c0g02Xi@00_?TD093<j0391AP0kBTl0:STl02@d=00X>3P07Bd]02Lg=`0Q<C40
9c@j03=0AP0a@4<0EFAW04EDE`0eAdX0<D9902e0A`0Z?4P0=4EE03M:F`0`@Td0;T1402Li?@0W>Ch0
;Sm60393B`0a@T/0<D9<03A4D`0a@E00;3a;02/kB`0c@U00<3i902Hd?@0O;SH093<j02/h?P0^>Sl0
9c8f024/;P0O:R/08bd^02H`;`0U<S00:SXg02Hf<`0V=S@09SHe01h^;@0202Ti>@0502<c<`0U=3L0
8S4d02Th>`0U<c@00P0V=3D01@0X<cD09S4c01/W9`0Q:b`082X[00<08BXY02407RLT01/T8@0L9B80
72DT01/S9P0]=CP0;SDk01DL8P0Z<CL09Rha01@L7P0M9RD072DQ01/V800J9Ad07BPQ01/T7`0F7aX0
6R<P01PN7P0M8R<082@U01lS900M8B806b4Q01XO8P0G7b405QhP01PM800F6ah04QLJ01PL7`0I71l0
100J6al03P0J6ad05AHH01<D5P0F5aT06Q/N01TJ7P0D5AX07b0U01DF6`0G5al06QXR014B5`0E5Q/0
61TM0P0E5QX00`0H6Ad05AHJ01LH700201<D600801PI7@0F5a/04ADH01HJ7@0G6ah051PK014E600E
5QP201TJ700D01HF5P0A4A404A4@01<C4@0B514041@@00d?300>40d04aDB018B400>3P`04Q8@01@C
4@0C4Q004A0>01<?3P0B4@l04Q8@014A3`0?3`d200h=2`0:00l>300F4Q40510?01<?3P0B30`040X:
01<>3P0D40l04@d<010<2`803PX900l04Ph=01<?3P0E4A0061@C00h:2@0=2@P050l?00`6200B30h0
50h@00/51`0A2`d04`d?00@0000A2`d00P0E3a400`0=1`T05@lA014;3@02010:3004014;3@0C3@l0
FUAF00@000805Q0B01<040X<00P2100=2@T04A0>00l92@0=10D04@P90147200?1@H04`T:0107200<
1PH03`/:00d920070000200001061`0>10D05@/<00804`T:00X04PP90147200?1@H03`D600h41@0D
2P/0308300h41@0A1`P02`421`0?1@H03`0900004`T:01882@0E2``03@@400P0000<0P<05@/<00P0
000;0@803PD500h41@0K3a<06PhB01@8300200l31`0301<72`0A1@T04@D900@04@D95?ooool001_o
oooo0P0@40h400l?3@0L00/;2@0=3@/02`/900`<2P0A4@l03Ph<018B400D51804A4?00d=2`0?3`d0
51@B01DE4`0<30X0410>00l?3@0C4a402PX800d=2`0D51805aLE02@T8P0A4@l03`l=014A3`0?3`d0
3Ph<00d=2`803Ph<0P0B4Q801`0?3`l02@T901LG5`16ATH05QHF00d=3@0>3Ph00P0=3@d01@0@4100
3@d;01<C4@0H61H03Ph<0080410>00`03Ph<010@3P0C4a403Ph<00T91`0C4A000`4001XH5P0@3P`0
40l=018A3`0>3P`200lA3P0B00d@3@0;3P/02Ph:00h@2`0?40X030d800`=2P0>3Ph03Ph@00l?4@0N
7R008R8R014A3`0@4@`04A8<00`<200=3@/03`l=0P0@40h200h>30D03`l=0P0@40h200l?3@803Ph<
01803`l=01HF500<30X030`:00X:200@40h03Ph<00`<2P0C4a404Q8@00X:200@40h02PX800`<2P0=
3@/02`/900X:200<30X200d=2`803`l=00<03Ph<00d=2`0>3P`00P0>3P`300d=2`05020P7P0A4@l0
4A4?00h>300@40h00P0=3@/05`0@40h03@d;00/;2@0?3`d05aLE014A3`0@40h010@201PH5P0<30X0
2PX8018B400:2PP06QXH00T9200>3P`020P601dL6`0B4@l02`X800H50`0B4@l03@`:008040l=02<0
3`h<00h=2`0=30X030/900d>2@0<3@P02@X500/<1`0=3@P03`h:014@300?2`P03PX700l;200B3@X0
4@d:00/?20082`@03a8;01@G401<CDL0H65K02HW8@0F5A004A0;00d<1`0C40/03P/600l>2P0:2@@0
30/6010?2P081`803Pd800d<1`0300`;1P803@`700@040l;00l>2P0>3@T03Pd90P0<2`L01`0=30P0
30/7010?2`0<2`L02`X600h;1`0?2PH00`0>2PL02`0<2`T06APF00d<2P0>3Ph03@d=010@400=3@d0
6a/J00X91`061@<03Pd;008030/90P0>3@/02P0@3`d04Q4?010?3@0>3@/02`X801<B400E518040l=
01@C4@0@3`d200l>300500h=2`0<2`T04Q4?00l>300>30d00P0=2``01@0@3Pl04Q0A018@4@0?3@h0
3P`=00<03@/<018030X:00/:200@3`/02`X601<B3`0510403`h<02/Y:@0S8B404@lA00/92`0@3Q00
3`d@00d;3P0?3A004a4D014?4P0@3Q4400l=40803P`?01H03@/>00X93P0<31003`lD00h>4P0>3Q<0
3PhB01`L800M7B40LW9f03De>@0C4aP04Q8G00l>4`0=31402PT>01<B5`0J6Ah0@T5600h=4P0=3140
3PdB0P0@3a@0800=31401`D:014?500610T04a4F010>4`091``04Q0E010>4`0>31403`dB01@B5`0H
5Q/030X=00l=400@3Q403P`?00d;3P0>30l03`d@00d;3P0K6A`02@P:01PF6@0A3a803Ph>00l?3`0=
3@d02`/;00`<300>3Ph03`l?0P0=3@d00`0A4A404Q8B018B4P0300h>300?010@3P0A4@l04Q8@018B
400F5Q@04A4?05]KF@0820H05QHD00l@300F5Q<01PH300h>2`0D51403@h:00H0414=00<0410=010A
3@0@4@d00P0@40d06`0A4Ph05ADB01<D400?3``04A4>014B3P0A3PX04`l;01@@3@0?40`02a0=00`A
3P0<4a802a8A010D4`0D51D05Q@D01HB4P0F51<05AHD00`=2`0F5a@03@h;00`=2P0F5a@051DB014B
4002018C4@0400l@3P0E5Q406Q/F01TI5`804a<A0P0B4Q804P0A4A4051@F01<C5@0?3a404a8F01TI
6`0B4Q804a<C01DE5@0A4A404Q@C01@F5@0C5A@041@C00hB4@0C5aH0728P01@F4`804Q@A01`05QPE
01PJ5`0I6aP03a4>01@F4`0E5a@04Q@A01DG500C5A803Q4>01@H500I7AT051PD00lC3`0F6QH05QTF
01@H500E6AD05QTF01@H500?510061hJ01@J5P0E6aL04QPD01@J5P0J81`051XF0`0F71P0QP0I7a/0
728N024W8`0H7QX06b0K01PN6`0O9b806R@M01XS7`0F8A/06bHO01dY900N:R<08BdZ028]<@0Y=CX0
9c<h02Db=P0K:C008S4g0391B00gAdh0=DI=02Hh@00G:C80:C]5028d@P0W>DP0:C]:02PkB@0W>DH0
9cY702TlB00U>4808cI002TlAP0S=T009cY302@f?P0[?DD0<TA;02Pi@00Y>Ch09cLl02hm@00Q<C40
7Bd]024`<00T<c<09C<c02Hc=`0^>Sh0:cPk03e;C@0_?T40:SXo02Pi@@0[?DL0:3Y70312D@0hBe`0
<dEA02`n@`0U=Sh093Dl02Tj@@0]?TL0;Sm902dnB00[>dP0:3Q602TiA`0^?T`0<D1=02/iA00W=Ch0
9SDm02Th?`0[>3h0:cLl02Lb=P0S;S008bd_02La<P0X<S40934_02@e<`0R=3408cDc024b<P0T=CD0
:c`m02Tj>`0S=3H093@h02Df>@0Y>C`0;C/l02Xf>00T<3808Rd^024/;@0N:BX07bPX01lX9`0N9bH0
82LV01lW9@0N9R<07bPU01hW900U;Rd08BT/02D]<00S:S008BP^02/b>00[<cH08RX/02</:`0N9b<0
7BPP01XV700L9al072DP01PQ7@0N9bD06AlP01dR8`0M8B806alO01XN7P0J81l061hO0P0F7R0201XO
8P0301LL7`0G6ah06Q`P008071dQ01006a`P01TJ7P0H6A/051DG01<D5P0E5QP061TL01PI7@0Q8RL0
EUML01LH7@0I6B4061PP01@E6P0E5Q/061TM0P0E5QX0300H6Ad05AHJ01DF6P0F5a/05AHJ01HG6`0E
5QX04aLJ01@H6`0C5aX04QHI014E5`804a@F01804aDE018B4P0D51<061PF01<C4@0=3``03a8?01<E
4P0A4a003a4>014A3`0C4a40410>01<B400B4@l040l=018>3@0A40h201<C4@0@014A3`0?3P`04@h=
018@3P0C3`h05A0?01HA400I4a<06Q<C01@?3P0A3@`04Ph=010<2`0C3`h040`;00d9208040`;00l0
4Ph=01<?3P0C3`h04`h>00d72@0A2`d04P`>01<=3`0E3a4040X<01<=3`0A2`d040X<00T31@0L5QP0
0`0?2@/06`0@2P`04@/=014;3@0E3a406aDG00X51P0B30h02`D700d72@0@30`020L600X4100@1`P0
3`H70147200?1`L03`D601D<3@080P804Ph=07EaL00i<3405P`=00h51@0A1`P02P0100h41@030147
20<040H700H03P@501061`0A1`P03P@500d3100>10D600l51P804`T:010030830147200=0`@05`d>
01882@0D2``060h?0147200?1PL03@<400l31`0A1@T03`<700d11@0>0PH04@D91P0@10PDooooo`00
6oooool05P0:2PP030`:00h>300?3`d04Q8@01<C4@092@L02`/900`<2P0B4Q005QHD00d=2`092@L0
3@d;00l?3@0>3P`03`l=018B400?3`d02`/901@D4P0<30X2014A3`07010@3P092@L00000014A3`0@
40h05ADC00l?3@0200h>30803`l=00d0410>00d=3@0C4a<05ADE01<C4`061PH05aLG00l?3`0;2`/0
3Ph>00d=3@092@T02PX:00803@d;01003Ph<00L71@0@40h03`l=014A3`0@40h02`/9014A3`0C4a40
3@d;01TI5`0?3P`03Pd;00X:200I6AL0410>0P0?3`d04P0>3``030h;00d=2`0=3PT030d700`=200C
4a405QHF010@4P0;2`d05aLI01XJ6P0<30X03Pl:010A2`0;30P02`/900d=2`803Ph<1`0=3@/200h>
300400l?3@0@40h0410>014A3`803@d;00/08R8P03lo?@0820H04A4?00l?3@0=3@/03Ph<00d=2`09
2@L0410>00/;2@0200l?3@0300/;2@0<30X02`/900803`l=0`0@40h00`0?3`d030`:00d=2`0300d=
2`0600h>300;2`T030`:00l?3@071`D05ADC0P0?3`d0100@40h03@d;00/;2@0=3@/2014A3`0Z00h>
300<30X04Q8@00l?3@0B4Q0030`:00d=300F5Q@00P8001HF500Y:BL0TY6?01PG5@0M71X06aXH00/:
200C4Q003Pd;00l>300@3`d03`h<00d<2P0;2PP04a@?00d>2@0E5Q402``7014A3@0?3PX03@`800l;
200@30T04@d:01@?300E4@h0310901@G40062@80;c8[0<[;a@3oooX0Kg1Z0P0E50l02P0?3PT01P<0
01<@2`0@3`/05A@?00T80`0>3@P02PT4018A300>3@P300`;1P0400d<1`0>3@P03`h:00l>2P803Pd9
0P0=30P00`0;2PH02PT500h=2@0200/:1P0300l<200@2`L03`/800803`/801P03@`:00L61@0=30X0
3Ph>00`<300>3Ph0:b/[01HE500>3@/030/9014@3P0>3@/030/900h=2`0?3P`04A0>018A3`0A40h0
3`h<00d<2P0H5aD030/900h=2`0=30X200/:20<030/900L03Pd;00l>300=2``030X;00d;300@3Pl0
4@l@008040h?00D03`d>00d;300=2``03P`=010>3P02018A3@0300L60P0P7a/02@P400805A@B00/0
4a8@00d;300?3@h05A<D018@4`0;2@`03@/>00l=400=2`h030X=00d;3P0500h<3`0F00h=3`0F5AX0
3PlC00d>4P0720`07QlS00`=4@0D5AT0FU]O0?3am@2EUYX06Q/O02<T:00;2Pl05A@I00T83@0F5AX0
3PdB00401@0=314030/@00d<4@803`hC00T03@`A01PF6`0:20d020H;01@B5`0:20d04a4F00l=4P0>
31400P0<2Pl200h<4@803P`?00<030X=00/9300>30l00P0@3Q40300=2`h07Q`O00l=40030@@02PP;
00d=3@0<30`03@d=00l?3`0=3@d030`<00l?3`803Ph>0`0@410300h>300600l?3@0@40h04A4?00d=
300>3P`02@T70P0?3`d01`0;2`T030d8014B3@0<3@P0414<01<D3`0@4@`01P0A4Pd2010A30<03a0;
03003@h900l@2`0?40/03@h9014B3@0B4`h04Pl;01H>2`0D3``03`l>00/A4@0<5A@04QdN014L7P0>
61X051XM00P<3@0:2`d061TG01DG500A4a0020X700lA3P0I6aP06Q`I01DG500=3``030h;00d?300?
4@h03Pl:010A300A4@l0410>014A3`0A4A404a<C00l?3`0B4Q@05QHH01<C5@0B4AD0000201LG5`0H
61P02@T901lO7`0P8R4202la<00401/O7P0A5A@0310?00hD4P803a4>00D04A<@01<E4P0E5a@05aTF
01PJ5`02028T8@0601/M6P0G6AH03a4>01@I5@0C61@05AXF0P0D6AD0N`0L8Ad04QLC014F4P0B5a<0
51TE01HK5`0E6QH03A<?014G4`0K8Ad02Q0<01DK5`0I7a/04QPD01XP700L8Qh06AlK01`R7P0S:BD0
7B<Q01XP7`0M8b405A/K01/R8@0J8b00628Q01LQ7`0I92006RHT01dY9P0O:b/09C8g03A1A`0I:2d0
9C@i02<b>@0X>D00FV]c051QJ@0^@DP09CM102doB@0G:cH09SU802/nC@0]@4l0;3m=02/nC00[?dX0
:cm902PlA@0V>T<0;41902Di@P0Y?DH093I002<f?@0W>T4093Ln02Tk?`0R=3P08c8e020`<00I:BP0
9C<c01/Z9`0T<300:38e02/d>@0Y=3L0:C@f01h/;`0[>Sl09cQ002XlAP0]?dh0>4]L04EGJ`0jCE/0
:ca402Df@00Q<S/08c@n02Hg@@0Z>dD0;3e702hoB@0^?TX0:S]502LgA00X=d80:SQ302dkA00c@DT0
<d99030m@`0X=3T08B``020[;@0R;Bh09Bl`02H`;`0U<c809CPf02Dg=`0R=3@07Bl_02@f=`0P<S@0
7S0d02Dg>`0V>3`0:Sa001h^=00S<C808Rd_02<^<00R;Rh07BTY01/U9P0K92<072DT01`U8P0201dS
8@0L01lU8`0V;b`08BXW02df=@0U;C007bLZ020W;@0R:Bl07bH/020X:P0Q:B/07BHU01XS7`0N:B40
6RDM01/V7`0M9R<06b@S024Y:P0M8RD07R8T01`P8@0I7A`06AhJ01XP700I7al05QhP01LO8@806b0S
00<061dP01HJ7@0I71l00P0L7B40100J6al061TM01LH6P0F5aT201DF600:01LH6`0G61`051DJ01<D
6@0K7240;blg00h>5P0U9R/05AHK01PI7@805AHJ02L061TM01DF6P0C51P061TM01LH700D5AT05AHJ
01HJ7@0B5QT041@G018F6@0H71d06AXL01HG6@0E5aH03`l=010@3P0A4@l0410>010B3`0>4Ph04Q@A
014C400?4@h04A4?01<C4@0@40h051<A01<B400A40h04@d<018>3@0C4a4051<A018A3`0@3`d04`l>
01DA400C3`h00`0D3Ph03P0E30d050h>01HB4@0B3Pd030P701DA400K5aH05A4@01@@3`0C3`h04@d<
01DA400B3Pd040/;0P0@2P`0:00:10H040X<01H@4P0?2@/04@/=01<=3`0D3Q002`D701D?4@080`@0
3@L900l92`0@2P`03`T;00h82P0=1`T07ALI00D00@080`@0618D00T31@0Z9RH08B0N018<300B2@X0
2P4200h41@0Q5aP05`d>01482@04000061@C09VEU012>CX060h?00h61P0E2``0308301D;300?1@H4
01061`060147200;0@805@/<01@:2`0<0P<040H71`0?1@H200d3100<0147200K4A803@<401@:2`0f
;2d0V8j?01H<3@0H3Pl05`d>00l51P0=0@D03`<7100@10P600l31aCooooo000Kooooo`0G00d=2`0>
3P`03`l=010@3P0A4@l04Q8@014A3`0=3@/0410>01/K6@0N7Q`03Ph<00/;2@0@40h04a<A01@D4P0F
5Q@05aLE00X:200@40h01`L500D5100C4a400P0;2`T01@0A4@l030`:01PH5P0>3P`030`:00803@d;
01403Ph<010@3P0B4Q004a<A010@400J6QX04Q8B00/;2`020P804a<C014A4@0B4Q805aLG01DE5@0=
3@d030`<00d=2`0200l?3@0300X:200A4@l030`:00803`l=00X02`/901DE4`0G5aD03`l=05EGE00@
40h04Q<A00H6100D51803Ph<0P0=3@/0400?3P`03`l=010?3@0?40/02``600/<1`0B4Q005ADE010@
4P0;2`d020P:00L71`0<30X030d800`=1`0<3@T200`<2P<03Ph<200=3@/200l?3@07010@3P0A4@l0
410>010@3P0T9280?clm00L71@0200l?3@0600h>300?3`d03`l=00`<2P0?3`d02`/90P0@40h01@0=
3@/04A4?014A3`0>3P`03`l=0080410>0P0?3`d00`0<30X03@d;00d=2`0200d=2`0700h>300:2PP0
3Ph<01<C4@0;2`T06ATG018B400200l?3@0800d=2`0<30X03@d;00l?3@092@L02`/901LG5@0B4Q02
00l?3@0>00D50`0=3@/02@T701/K6@030`804Q8@01hM6`0510<02PT70040000A40h040l=00d<2P0?
3P`2010?3@0N00h=2`0<2`T06AXE00L81@0@4@`0004000d=200C4Ph03`h:01DA3P0F4Pl0510=01D@
3@0F4Pl02`l701LJ4@0C5Pd0=3L^0;Nh/03cm>`0FeaD014A2@0G5`l04A4900P5000E4P/01`L201@D
300@40P04Q8:0P092@401`0>3PH03@d500`<100=3@D03Ph600h=200?3PX00`0>3@T200d<200700/:
1P0920@03@`800/:1P0<2`L040d9010;1`0300l;200400d<2P0A40h04a8@00820P802PX:01D0:2PX
014@3`0A40h040l=014@3P0>3@/030/900d<2P0>3@/03`h<010?3@0?3P`03Pd;014@3P0F5A<00P40
00`;2@061@<05A@B00l>300:2@L00P0>3@/01@0;2PP03`h<00h<3@0=2``03P`=00803`d>0P0<2P/0
3`0?3@h04@l@00d;300=2``05A<C01DD400A40/02`X501PG4`01000051<?008100071P@02`T:00d;
3002014?400600/9300=2`h03P`?00`:3@0;2@`03@/>1@0>30l05P0>3@l03`hC00/<40051PX051DI
07MhO00J6al04A8F02<T:027R8`0BDY>00X;3`0D5AT05aHK010?50030PL020L<01LF6`0H5a`03PdB
00d<4@0>3A82010?500700h=4P0C4AH03@/@01<A5P0G5AX04Q0E00L52P04010>4`804Q0E01T04a4D
010>4@0;2@`02PP;014?4P0E4aH04@lB01HD5`1HEUT09R@W02DS9P0K6A`03`l?00h>3P0?3`l04A4A
00l?3`0=3@d03Ph>00l?3`0>3Ph03@d=00/;2`0:2PX03`l=00803Ph<00d03`l=010@3P0A4@l030`:
01/K6@0G5aD05QHD00L71@0C4a402@X500/<1`0=3PT03a0;0080414<1@0A4Pd00`0@4@`03a0;00l@
2`0400l@2`804A8=01h03a0;01<D3`0E5Q40510<01H<2P0C3P/03`d>00/@4`0;5AL041hP02dl?`0X
=ST03aXL01<K7@0@5AP061/K00840@031@8051HC03<e<P0>40d04Q@A00h@3@0A4a005QPE01@F4`0H
6QL051D@018C3P0C4a4201@D4P0F01DE5@0F5QH04A4A014A4`0C4aD04A4C018B5@0L71h0:b/[00L7
1`0/;2`0Ogmo03Li>00N81l092HU014E500C5aH04ADD01HL6P0?4@h0418?018D4@804A<@0P0B5140
3@0L7Q/07AlL01LI5P0D5Q<030h;01<H500D6AD02Pl;00dB3P1FFeL0];Ve01dR7P0G71P00P0A5Q80
2`0C61@04QLC010F4P0?61<07BHQ00lH4`0b>cH05b0K014J5@0J8ah07BHQ00806R<N06T07bPU01HL
700Q9RP0:Bl_01XR900L92D07bPW01TS900N:BT07BTW01TU9@0L:2L08B`^02/i?`10CeH06bXa02Ph
?`0U=Sh0834i045CFP0nD5X09SQ201`_>@0[?dX0730k02DjB00Z@4h0;D=A02e3D00/@Td0;D=>02Hl
AP0S>T808STo02PoA@0P=cd08cY002Di@P0W>d@0:Si502`oAP0eB4`0;d960312A00W=cL07bl^02Pg
=@0S<Rl0=41002Tb=00]=CP0:cHh02Ha<`0N;2l0=DA902/lA00W>D<0:ce<03M:F`11EVT0>deM0352
C00/?4T09cM302Hg@@0X>D<0;3e702hoB@0`@D/0<D9;02dnAP0Y>T@09cM102Xh@`0_?DH0=DA<03A3
BP0_?4809c<h024/<00P:bd08bh_02H`<@0V<2l09C<c020b<P0R=3H0:cdo02i0@P0H:Rd0;d5502Pi
@00[?4<09SLn02m0A`0M;C<08S0a024];@0S;bl092h_01lY:P0P:RT06R<R01/T8`0N92800P0L8R00
6P0Q9b<08R/X01`U8P0U;Rd07RHY01XR9@0O9R`09B`b01hU:`0M9BP08BT[01hW9P0P:BD07RTQ01XU
7@0K9R407RLV01`T9P0P:2X07R<W01lT9P0M8B806QhM01XO6P0K8Ad06R0P0P0G7b401@0K82<06AhQ
01HK7P0G6ah06A`O00806a`P00<06Q/O01TJ7P0H6A/00P0H6A/02`0G61X061TL01PI7@0B4aP071dR
01/L8@0<31@04a<K014B5`0E5Q/061TM00805AHJ00<061TM01DF6P0D5AT00P0H6Ad0200D5AT05QLK
01LK7P0D6AX04ADF018F5`0G6a`061XI0P0E5aH0300D51805aLE018C3P0A4Pd05QPC010D400>40d0
3a4>018D4@0A4@l03`l=014A3`805QDC01H04a8@01<?3P0C3`h04a8@01@C4@0B4@l04Ph=01@@3`0E
4A005@l?01@>3P0C3@d04`X;01482@0>20P0510?01XF5@0G4a8040`;00`81`0;1`H03`/:0P0A3@`0
3@0D40l04Ph=00l:2`0?2@/050h@014;3@0C3@l06A<E01H@4P0=1`T02`D700d72@0A2`d00P0@2P`0
4@0=1`T03`T;00l92`0>20X03@L9024K7@2QVid091hP01@>400G4A<05@lA01XF5P0B4@l02`D50189
2P0<0`@040H70080200000L03`H700T30`060P407a/J024H6@0=0`@030<300803@<400<04@L800l5
1P0@1PL00`0@1PL01`0A1`P03`D601P>3`0E2``03P@501882@0A1`P01P0?1@H0200<0P<03`D601@:
2`0M4a@03P@50147200I3a00OG=d0P0700000`0;0@801`000104200201452@0301862P0A1@T03`<7
00H04@D95?ooool001_ooooo0P0B4Q001@0@40h03`l=00h>300<30X03Ph<008030`:00<04Q8@01DE
4`092@L00P0>3P`04@0?3`d0410>014A3`0A4@l04Q8@00`<2`11@Cl08R8P00<30@0A4@l03@d;01<C
4@092@L05ADC00l?3@0>3P`0410>00803`l=0100410>014A3`0B4Q003`l?00/;2`0<30`0:RXZ01LG
5`092@T03`l?014A4@0G5aL05ADE00d=3@0<30`03@d;0P0A4@l08@0>3P`04a<A00X:200<30X03@d;
00`<2P0A4@l04Q8@00X=2P0o@cl020/8010D400420@03a0>00l?3@0=30X03``;014>3@0B3`h04Q0>
018A3@0=3PP02@X500P91P0=3@d03`lA014A4`0;2`d020P800d=2`0>3`X03@h800h>2P0300h>3080
3`l=00<0410>00l?3@0?3`d00`0?3`d00`0>3P`03@d;00h>300300h>300701<C4@0J6QP03`l=00d=
2`0:2PP03`l=010@3P0300l?3@80410>00@03`l=01DE4`0@40h020P60P0>3P`00`0;2`T030`:00d=
2`0200d=2`0400`<2P0>3P`03Ph<00h>30<03@d;00H03Ph<00d=2`0C4a402`/9014A3`092@L200h>
30803@d;0P0>3P`2010@3P0402LW9@0A4@l03`l=00l?3@803Ph<00/03`l=00D50`1JFUP05ADC00/:
200@3`h04A0>00L61@0?3P`040l=00l>300500h=2`0Q00T:1@0<3@P0=3D`00d>2P0@40`01PD200d<
200B3P/040`900d91P0B3@X05A8=010D30021@005AP?00hA2@0_<2P0A4Dm01`M5@0C4`/04A49010@
200F4``04Pl801DE3@0>3PH01PH100l?200=3@D04A4900l?1`0>3PH03@d500803Ph600<03`l700h=
2@0>3@T0100>3@T01`0=30P02PT500h=2@0=30P03Pd9018?2`0A30P00`0@30T0200>3@/03@`:018A
3`092@T04Q8B00P8200@410030`;0P0>3@/500d<2P<03Pd;02<03@`:00h=2`0F5A<03Pd;01@C4@0B
4@l0=C@b01TH5P0A40h03Pd;00l>300=30X03`h<00l=3P0>30d040h?018@4@0A3a003P`=00/92P0?
3@h04Q0A00h<3@0=2``04Q4@00d<200?3PT04Q4<00H50@0I61D03`h:00d<2P0@3`d03P`<00/92P02
00h<3@0600h<3`0?3A0040hA00h<3`0=2`h03`d@0P0=2`h200h<3`0G00l=400?3Q0051DI00X=400>
4A@02Pd@03Hh?00:3A002@`?00/=400J7200<cHi00lB5@0?41@030/@01<B5`11@4D07A`Q00`<400;
2Pl03PdB00d<4@0>3A800P0@3a@03`0=31403`dB00l=4P0J61d00@0401<A5P0:20d03`dB00h<4@0=
2a003P`A010>4`0A3a@0518E018@4`0200d;3P08018@4`0F51L0?S`o01`J7@0?3A004@lB01HD5`0>
30l2014A4@0>010@400>3Ph03`l?014A4@0@41003`l?00d=3@0<30`03`l?018B4P0@40h03`l=00h>
300?3`d2010@3P0<01@D4P092@L03@d;010@3`0>3P`0410>018C3P0<3@L051D@00l@2`0=3PT04A8=
1@0@4@`0C`0>3`X03@h800d>2@0?40/0414;010A300B4`h05QLA01DF400B4`d05AHA01HG4@0F3``0
5P/;01D<3@0?3Q002a<F00dH7@0X>3h0^lkB0<OGf@0iBDd06BHY01/W:@0?5QD05APE01/O6`0H6aP0
Ngmk04iACP0<3``0310<01HI5P0D5a@02Pd:010C400J6aH051D@01<C4@0D51804Q8@018B4P0G5aL0
5ADE01DE5`0B4Q@03@d?010?4`0@41803`l?01<C4`0F5QH06ATI01PJ6@0O8B00:bd/01<G5P0G6aX0
4ADD014G5@0B51405ALD01HH5@0D5Q<04Q@A01<E4P0@4Pl05ALD01HH5@0D5Q<05aTF01DG500>4`l0
51TE01XO6`0G71P0724M02hc;`0F6aL00P0D6AD0300G7AT06b0L01/Q7@0F7aX03QLB018K5P0H8A`0
>D8m014J5@0I8Qd06b@O01XS7P80624L07806R<P01lT9`0T:Rh0:Blb01`T:00P:2/08R/]01dV:P0T
;c4082//01`W:P0P;2h08Bla02Dc>@0Z>T40;cm602Xk@`0Y>d807c4h01la>P0Z?DL09SU404MKI@0d
B5<0:Ce802HlBP0[@Dl0;D=@02e3C`0/@Td0;DA<02a3BP0Y@4H0:41502i6BP0U?D40:41402XoB00_
A4d0:Sm802Di?`0jCE<0?4mC02Pj>`0K:b/0;3`k0391?P0S<Rh09c<a02H^<@0/=3L0;3Dh02Td=P0P
;S40=dI;02`mA@0W>480:3]902e0D@0cB5d0=dQJ03Y:F00iBEL0<d=A02`lB@0[?4H0;Sm802dnAP0Z
>d<0:ca402i0A@0_@4L0;3a502Xh@`0/>T<0;Se502dl@`0Z=cd0:3@i02Lb=P0U<3809S4b02Tc=00Y
<c809C<d02<e>00Z?3l0>Ta?05e^M010DEL0A5EM03E6C@0`@DT09CHo03Q9DP0U=Cd08c4b024];@0W
<S809c4b01hX:@0P:RT06b@R01dV900P9R@07B<P01hT8@0V;2P08BXW01hW900S;2/07RHY02@/;`0V
;C<201lV;00A01lW:@0N9RP07RLV01dV8`0M:2<06B@O01/U8`0P:2X07BDX01/S9`0K82D07R<V01lS
8P0M8Qh06b0J01`S700I7al00P0F7R001@0J7b806AhQ01HK7P0I7B006Q`P00806AXN0P0K72003P0H
6A/06a`N01XK7@0H6A/05aPK01TJ7P0/;C805aPM01HG700C4a/0:RXb01HG700E5Q/061TM0P0E5QX0
0`0H6Ad05AHJ01LH700401LH700D01DI700F6a/04QHG010D5@0@51@04aDD01DG5P0D5Q@03Ph<01DE
4`0D5A003Pl:010B3@0@51003Q0=00lA3P0B51404Q8@00l?3@0B4Q0201LF500301@C4@0D40l04`l>
00804Q4?00L04A0>018>3@0C3`h05A4@01@>3P0D3@d05@d>00805Pd>014050h>00l;2P0B3Pd04`l>
00`81`0M6AP0:2@S01<?3P0B3Pd04@d<00P40`0<20L06A@D00X41P0;1@L050h@014;3@02018<3P06
044k?@0A2`d04`d?00`6200I4aD04@/=0`0?2@/300h82P0302PS900<1PP03@P9008040X<01805Q8B
00H50`0=1`L05Pd>01892P0>10D0=B//02PN7`0B2P/03PP801@@3`0?2`X03`H700h41@0C2@X03@<4
01882@0@1PL3014720<040H700H060h?01D;300@1PL040H70147200@1PL600l51P0B01H<3@0L4Q<0
4@L80147200@1PL04PP90107200C2`/05`d>01061`0?1@H03PH601<72`0?0`L03@4500l31`0@10P0
3@451P0A1@TDooooo`006oooool0100;2`T030`:00d=2`0=3@/200l?3@0400d=2`0E5A<04A4?00d=
2`<03`l=0P0=3@/04`0?3`d04Q8@014A3`061P@05ADC00h>300=3@/061PF00L71@0?3`d05QHD00X:
200F5Q@04A4?00l?3@0D51804Q8@010@3P0?3`d00P0=3@/0200?3`l03Ph>00L71`0U9BD071`L014A
4@0?3`l02`/;0P0?3`l02@0<30`03@d;00h>300@40h03Ph<00d=2`0D51802@T701HF5002018B4009
010@3P0A4@l05APE0002000?51004QHB00L91P0:30T03@d;00803`h<00L040h<014=300A3@`03`d:
00h?2@0@4@`0410=00803@d=00T030`<01HF5P0F5QH02@T6018C3P0E5Q003`l<00l?3@0>3P`00P0?
3`d00`0@40h03`l=00d=2`0500d=2`H030`:01<020P6010@3P0@40h04a<A00l?3@0A4@l03a4>00/<
2P0;2`T03Q0=00l@3P0`<2h0<S@a028S8`0A4A404Q@C00l?3P0=3@/03Ph<00803`l=0P0>3P`00`0@
40h03`l=00h>300200`<2P0300/;2@0B4Q002PX800<04Q8@01/030`:00d=2`0<30X030`:00h>300?
3`d03@d;014A3`0;2`T08R8P00<30@0:2PP04A4?00T91`0A4@h00P<001HG4P0@4@`02``701DD4P0=
30X040l=01LF500:2@P03@`:00l>300>3@/00P0<2`T06`0?3P`040l;010A300>3`X0=3D`0083000?
3`X040l;00l>2P0A3@X03`/801<?300Q7AX0:bPS00D70@0E6140CE1702<V7P0@4``082<J04I9@@0B
4`d03@h600`<1@0A3PT03Ph600T90`0200`<100601lO6P0A4@T04a<;00l?1`0>3PH03@d50P0>3PH0
3P0?3PT03Pd900h=2@0>3@T03Ph900h=2@0=3PT030d800X:200>3P`030`:00h>300B40`040d80`0@
30T200h=2`0801@C4@0820H020P8018B400:2PX04A4?014@3P0?3P`200/:200300`;2@0>3@/03Pd;
00@03Pd;00l02`X8014@3P071P@03@`:06IVI03GemD0N7Uf01`L6P0:2PP03Pd;018A3`0>3@/03P`=
00l=3P0B41400P0F51D05P0C4A8040h?00l=3P0>30d03`d>00d;30081`H04Q4=00d<200:2@D04A0<
06ETH00F5A<03@`:00h=2`0@3`d05Q@E01TG600=2``02`T<00`:3@0=2`h200X82`<03@/>0P0>30l0
5`0?3A003`h@00D62P0C51P01PL;01HG6`0=3Q80414E00d>4P0:2`l030dA010A5@0>3a<00004018A
5P0A41D0=cHk00/:3`0O7R<01`H;00/:3`0:2@h030/@00803PdB00T02`X?00d;400>3A40J6I[02h/
<@0;2@h061HK01DC600B41D00P0?3A800`0A3a@04a4F00X83@0200d;3P0I00`:3@0;2@`030X=020N
8@0100804@lB014<400@2`l03`d@014A4@0C4a<03Ph>00P8200<30`04A4A01DE5@0@41002`/;00d=
3@0J6QX08R8R010A3@0?40/03Pl:00h?2`0200l?3@0;01LG5@030`403@d;018B4P092@T01PH400h?
2P041@00414;00T:1@0720801P0?40X09@0=3@P030/600d<1`0>3`T0414;014B300B4`d051D?01<D
3P0>3`T03Q4:00h@2`0B3@X05`h?01@>400@41<03a@H014J7`0X=S/0[/340;[<d00c@TH05R@W01PS
9@0G7ah041DA018F5@0A5A<06AhJ030d<`0B5Q@03a@@010E4P0<40l0314=02hc<00F61D00P0?3`d0
;`0F5QH051@D01HF5P0<30`03`l?01PH6P0E5AL03Ph@018A5@0?3`l0410@018B4P0G5aL04Q8B018D
4`0?4A008B<R00/?3P0H71/04QHE01<G5@0?4@h04aDB01HH5@0C5A804A<@01<E4P0J71T06A/H01DG
500?4@h04aDB01@F4`0A5Q804aTE01DK5`0A5a<041HB01TO6`0D6QH05adI01/Q7@0M8al06R0L01DK
5`0G7QL08bdU00804adE00@03QLB01XS7P0Y<Rd07bPU0P0F7a`0S@0I8b0072DT02`c>@0L8bX05QdS
014H800K92X072DZ01XS:00L9b/05R@W01`W:`0R;c8072X]04QFG00M;3<0BU]R02@e?00W>4009cY1
02@g?`0_@D/04bL`02XnB00W>dH0:Si902e3D@0aAeD0<TQE02m5D@0]@dh0;DA<02e4B`0/@dT0:d=7
0359C@0W?d<0:D5502]1B`0`AU40:D1803Q<E01gRY00Sj:V06AfN@0M;Bd09cLf02Hd<`0S<Rl08Rh/
028X:`0X<3<09c0b02Pc=@0O:Rh0;C]202Tj@P0]?d/0<4=B02e2E@0gC640>4]O03Q:F00jC5X0=DEC
02/kB00W>480:3U102Tj@@0Z>d80<3m402hm@00W=S/0:3Po02`mA`0Z>d<0:cU202Xi@00Y=Sh0:CDk
02Pc=`0U<3@092la02H`<@0W<C80:3Dg02Xl@00[?D40;Sm505IWKP0Y>D00;Se402<b>@0_?TD0:cU2
045?F00S<SX0938e02Pf=`11CDd0@de>02dg=P0N9bD072DR024W9@0R:2H07bDS020V900Y;bd07BHU
01hX9`0Q:R/07RHY02/c=P0T:c406b8X02@/;`0V;S4082TX01lX9`0G81d07BHS01TR7`0L9B<08BXY
01`T9P0H7B005Q/O01/P8P0N8R407B8N01/P6@0J7aT051XH01<I700F6ah06AhQ01XO8P0H7B006alR
01TL7`0201LH700@01XK800M7R805QLK01XK7@0I6Q`05QLI01DF6@0G61`03@hC01`M8P0C51T071dR
01TJ800F5a`05AHJ01PI7@805AHJ00<061TM01DF6P0I6Qh00P0E5QX00`0J6al061TM01DF6P02018F
5`0M010D5@0C5A@071hM02<U900c=C<03Ph>00d=2`0E5A<051@B01HF500?4@h04aDB018D4@0?3`d0
410>01@D4P0@40h05A@B01HE4`0C4Q004Ph=014=300@3`d04A0>010?3@0@30/04Ph=01@@3`0C3Pd0
100C3@d06`0E40l03@T8014=300D40l00`0001LC4P0/:2L02PH500T5100C3`h03PX9024M7018@d@0
8Q`N00P2100?2@/03PP:018<3P0P6Q`0U8j@01@>4P0@2Ph0618F07E_L`0l=SP04@/=00l92`0200h8
2P0?00l92`0:1@H081XL00@0000F41804@/=01LA4`0=20T03`/:00h61`0=10D04PT:01D;300J4140
5P`=00804PT:00H03`T901@?3`0E30d030830147200@1PL20147200301<92P0B20T04@L800803`D6
00D03P@501hD5@0?1@H02P4201061`0200d310H03`D600D05P`=02@J6`0C2@X03@<401882@0200X0
0@0;01@:2`0900003P@501<92P0D2P/050P<00h21P0<00@03`<701862P0A1@T01P0?0`LDooooo`00
6oooool0300G5aL030`<00d=3@0B4Q803`l>00/;2@0C4a4030`900X;1P0>3`X0414<00`=20802`/9
00@03@d;010@3P0A4@l03`l=0P0=3@/200h>308030`:01403`l=018B40071`D03`l=00h>300<30X0
2`/9014A3`0B4Q002`/900X:200A4@l02`/:01@D4P0Q8Al07alN01hN7002010@3P0600h>300?3`d0
4A4?00l?3@0=3@/03Pl;1@0>3`X04P0?40d04A8=00@5000F5a8010D001<D400>40d030h;00`=2P0<
30X02`/900d=2`0C4a405ADC018A3`0=30X03Pd;00l?30803@h901T030d800d=2`0=3@/030`:00/;
2@0=3@/03a0;00h?2P0=3PT04A4>018B40051@<03@d;024Q7`0D51802PX801<C4@0B4Q002@T700d=
2`0@40h03Pl;00d>2@0G61<01@H100804A8=0`0:2`H0500<3@P03a0;01<D3`0<3P/03A8>00d@3@0B
51<00@D401@G5P1`LW40nOgl05EHF@0>3a4010P900d>3`0>3P`06AXE02TZ9@0N7aX03@h90P0>3`X0
0`0@4@`04A8=00h?2P0200`=201900@3000K6QH040l;01TH500?3PX0BTU5024P700<2`L051<?00/:
1P0>3@T02PT5010@3P0;2`T061PF00l?3@0;2`P04A8=01@E400;30H01PL1010A2`0:2`D02``601PG
4`0D4`l05QDA00<2000A40`020L3014@300920H06aXF00@3000@3`/02PT500T8100>3@P04A0;010?
2P0<2`H02`X500T80`0A40/040l:00/:1@0A40/061LB00T91P0G61<0ATU2038h<@0I81T0>48i0;S0
^00H7AL00@@0018C3@0;2PH02`X500d=20061`40004001`M5`061`403a0:00h?2@020`003Pl900`=
1`0>3`T06Q/E00`=200200T:1@0?00/=200@40h0418?00lA3P000P402`h=00H:2@0@51<02@T700l>
2P0>3@T030/700L60P081`<040l;008030/700H030/800`;1`0<2`T030/700/:1P0<2`L300h=2@0H
00d<200>3@T03`h:00d<200;2PH03`h:00`;200N7A/020P601`M6`1eNWH0mogi07f5P00<4Ph04AHB
00l@3P061P@05QDC06ETHP0D4a402@P701dL6P040`403Pd;0P0<2`T200d<2P803Pd;0P0<30X0600@
40h00P8000l?3@092@T02`/;01@D50092@T0410@00@4100=3@d03`d>00h<3@0<2P/02`T:00`:2`0?
3@h04@l@00h<3@0?3@h06QPI00h<3@0;2@X03Ph@00T92`804a<E00h02PX<00l?4@0>3Q003Ph@00`<
3P0;2`d030`>010@4P0;2`d020P:01<C5@0A4A<051@F00`<3P803@d?00X020P:00/;3@0?3a401`L9
00d<4@0G5Q/0JVU^03<b=`0C4QL04A0E100=3140100?3Q<040lD00d<4@0?3Q<2014?500@018=4@0A
310040/?01`H6@0A3@h04`d?01PB500>2P/03@`=01DE5@0B4Q8020P801`L70061PH03@d=00l?3`80
4Q8B00T02`/;00L71@0B4`h04Q<=00l@2P0=3PT03a0;014B3@0A4@l00P0A4A40>`0?3a4030`>00/;
2`0?40T02P/300L8000<3@D03Pl700d>1P0@4@T04A8:00@50@0A4PX010D001@B2`0@3@H0514:014@
2P0:2@@04a8=01LH4`0?4@`03@l:00X<200?50h041DA018B400F5A<0518C014A4P0F5aT051PK01HK
7P0`>3/0BE5D028Z;@073a8072@V01@K700?5A<02Q0@00hD4`0T:RP092XZ00lE500;4@l051XI00@:
2P001P@0Jg1_00`>3@0J71/04A<B00`=3`0=3Q005AHH00l@4P0@4A<04A8D00803PlA00<04A8D01dO
7P0G6AH00P0@4Pl05P0?4@h04aDB018D4@0@4Pl04A<@01<E4P0D5Q<04aDB01<E400G61<061TD01<D
3`0A4Pd05ADC024Q7`0F5Q@04Q8B01/K6`0I6AT04A<B01@I5@0I7QX201@I5@0401HK5`0@5A4051TE
01DJ5P806b0L0:805AXF01<J4`0D6a<0620F01/R6P0G8AP05R0I01HO6P2LYj<0H6YZ01hX:@0V<380
92h`020Y;P0M9Rd0>45902</<`0L9Bh0628Z01DP9P0C7R@07BX`020_=00N;2l07bd`024_<P0Z>3/0
:CPm028a=P0R<cL08c@k01l`=`0V>3l083<j0395C00]@4P09c]402i2C@0[@E00<4EF0398EP0aAe@0
;49?02Y0B`0bB580;4=;02LnA00[@TP09ci402i5B`0^AU008cU402U0B00_@d/0JGb3055TJP0b@dT0
8c8g020_<P0Z>3X09C0b01TS900X;S808BHZ01`U:00T;c40:SDi02`j@@0hBE<0?E1N049GJ00dBV40
;TAL03U?H@0dB5<0<dMB03A6D@0V>48093Dm0310A`0W=S/0=DA9049@D`0W=CH09S@g02hnA00/?TP0
;T1:028c>`0]?TD09C@k02Hd>@0V=3L0:3<g02Pc=@0V<C<09S0b02Hb=P0W=Sd0:SU002Pg?@0V=CX0
:SPn02/h?P0Z=cd0:3Dk02dh?00a?400=dA70353A@0V>3X0V:NW0=;NgP0oBDP0:C0]02<Y9@0T:BD0
8RLT02P/:`0M8B80=3Pj01lY:`0O:R`082X/02@]<P0X<CH08R`^024[;@0M9bP08BT[024Z:@0J8b80
6b4P028X900P9R80728N01dS7`0P9R807b@P01HJ6@0G71P07b@P01hS7@0H7AL06b0J01`P7`0J7b00
6QhO01`P8@0L82806QhQ01HI7P0K7R<071lT01XM8P0L7bD08R<X01PI7@0M72407QdR01/J7`0G5a/2
01@E6@0T030c=P0420/05a/N01DI7@0A5AP03a0D01DF600H6A/05aPJ01TJ700M7R00824S018C5@0H
6A/05QLI01DF600C51H04Q<E01XK7@0G61X05ADG018B500=3@l04Q8C00l?4@0D51@05ADE01<C4`0D
51@03@d;00/;2@0F5Q@04Q4?01`K6@0C4Q004Q4?0P0C4Q001@0A40h04Q4?01<B400D4`l04a8>0080
4Q4=00/04A0>010?3@0=2PT03PX;00d92P0R7Ql03@T:00d92@0A3@`03`/:00h:2@0200d9208040`;
00T03`/:01<?3P0F4Q404`l>01@@400M6AX04Ph?00T51`0B3A400P0=20`04`0400<07QTO01<>500L
5ad0_k[0085lO`0F41004@/;00h8200:10@03@L7010:2P0Y8b<03PP800d71`0?2@T0:bDU01092@0@
1`P0100A1`P401<92P804PT:1P0@1PD0800W7A`03`D400l5100E2`X02P0001<9200=0`@040H701hD
5@0A1`P0308300l51P0700002`420147200D2P/060h?0147200A1@L040@600h2100=0@<03`<50145
1`0E2@/02@0000l31@0D20X03@<400d10`0B1PX04@@;0P0@0`X0200A10/04PD<01442`0@0`X03`89
00P00P0C20d04`H=5?ooool001_ooooo00d04Q8B00h>3P0=3@d030`<018B4@0P81h0:BTW01XK5`0=
3PT030d800d>2@0<3@L0410>00803@d;00@03`l=010@3P0?3`d03@d;0P0>3P`300l?3@07020P7P0F
5Q@02`/900/;2@0?3`d071`J01TI5`0200/;2@0600h>300=3@/03`l=04Y:B00@40l0410>0P0?3`d0
1`0>3P`03@d;00/;2@0<30X0410>00l?3@0=3@/01P0>3`X02@0E5Q40G5eH010A3P0<3@T061TD00h>
2`0=3@/03Ph<00l?3@0200d=2`0400h>300=3@/03@d;00h>30803@d;00@03Ph;00d>2@0=3PT030d8
0P0=3PT00`0>3`X03a0;00l@2`03010A300V00h>2`0C4a40410>00h>300:2PP020P600l?3@0=3@/0
3`l=014A3`0<30X03@d;014A3P0@4@`09BHQ00l@3@0;30P03@h9010A300?40/04Q<>00h?2P0:2`H0
4A8=00P:1`0:3PX041<@00T<2P0F6AL04A@C03Hi>@28Rh/0:B/]00D72`0>4A@02``?00`<2P0;30L2
010A300400/<1`0<3@P0414<00h?2P803@h902T030d800T:1@0>3@T04A0<00`;200F5A403`h:01HE
4P0B4@d03`h:018A3@0:2@D040l;018A3@0<30X03`l=02@T8P0M7A/0414=00/<1`0<3@L03a0:01DF
400O81P04a@<00h?1`0@3`/03`h:00d<200D4`l02`X600d<200:2@H05A@@02@S7`15A4009B@P00`;
200;2PD03Pd800l>2@0300d<1`0400h=200=30L03@`700h=20803`h901T03@`800T:1@0A4`h02Q0:
00LA2@0D7QH0<3Xb00P?20083@L02@X500X91@0E51003Pl901PI4`0j>cD03@h900T:100=3PP030d8
010A2`0C50h03@h8018C3@041@003Pl:008030d800l02``700/=2P0;3@X0310>018F5@093@`04aTH
00@92@0D5QD0;bhZ02XY9@0@3`/04Q4=00h=2@0;2PH01@0>3@T00`0=30P030/700d<200400h=2@03
00d<200>3@T03Pd900803`h:01<03Pd:01HE4`0;2`T03Q4>01/Q7@1;E4l09S0Z00`E400D6QH02`l;
014A3`0G5Q@0:BPV01DD4P0?3P`02@P600h=2`0?3P`030/900803@`:0`0>3@/02P0=3@d030`<01hN
7P0F5QH02@T901<C4`051@D06QXJ00X:2P0<30`200/;2`H03`d>00L03@/<010>3`0?3@h040h?00T7
200G5AH08AlR00804Q0C00H04a4D00d;3P0A3a803`d@00h<3`0=2`h200l=400C00d;3P0<30h0410B
00/;3@092@/05ADG00l?4@0=3@l03`lA00/;3@0=3@l05ADG01@D5P0A41D030/@01PG70071P/02`X?
00`;4002010?500H00h=4P0=31403PdB00h=4P0?3aD03@dB00/:3`0<2a0040`@014>4@0F4QH08QdO
01`G600B3@l05A0B01PC500?3`l03@d=00820P0A4A400`<301HF5P0A4A4051@D0P0@4100A00A4A40
3Ph<014B300B4`h04A8<00l@2P0?3``0414=00l?3@0>3Ph03Ph?00d=3P0<30d03@d<00/<1@0D5@d0
4Q<;00l@200>3`L04A8:014B3@0<3@H05QL?00`=1@0C50`04a4:018>1`0C40T0518<018A300H6180
6Q/F00T;1P082PL03Q4>01LL6013B4@0C51<020Q7@0I6QH04A4@01<C4P0A4a403a4A01DG5`0?4aD0
51PJ03Di>`0E6a`04QLH01@I600@5AD0314A01DJ6@0C61L0314A014F5P0<4A004aPH014F5P0?51@0
51HF01TJ6`0@4A8051DF01HG600Z;2`04Q@D0P0C5AD02@0A4Q<0418B01<E5@0=3``04aDB01HH5@0C
5A805ALD01@F4`0301<E4P0601HH5@0E5a@04Q@@01HG4P0F5a405QLB0P0E5Q400`0E5A<05aLE01HF
500201TI6@0401@D500E5aH05aTF01HK5`804AHB00@06AhJ01PM6@0I7QX05a`H0P0K81`04@0G71P0
6AhH01LO5@0I8AL06B0H01DO5P0F7aT05b0K02dg=P0f@4008R`]02Xe=P0H8bH0>dI;02lh?`0W<3P0
92de00806RD/05L07RT^01`Y;P0H9R/06bX^020_<P0P;c405bHX020^<@0T<cH08c8e02Dd>@0S=CT0
7c4e02/l@`0]@4L0:Se402`oAP0]@DP0:cm802m3DP0fBUX0=DYH0315D`0^@U00;T=@02i3CP0Z@4P0
9Sa402Y0AP0V>d80:d9:0358D`0[@D`0;TA?02e1BP0iC5<083<j02/m@P0]?440:cXm02lm@00b?Cl0
;cTk02he>00W;C00:C8d02Lb=00X<cH0:CPn03E7D00mD5d0@5IX03A:H00]A5`0=daN04MJH`17FV@0
;d9;02m2B@0a@TX0:CY102Hf?00_?D@0?4]?0391@`0]>Ch0<45702XmAP0[?DL093Dn03=4C00[>T40
:SPn02Pe>`0Y=CT0:SDi02Td=`0Y<cD0:3@i02Pg?P0Z>D00:CPn02Lf>`0[>3h0<ci2030k?`0[=SX0
0P0X<S@06P0[=CL0<dE902Tm?P1ZNg/0RING03i9A@0U;BT08bPT024V8P0T9b@08BDV028V9`0T:B`0
92db02<^<P0O:Rh07RT/02<^<@0S;Bl08b`^01hW:@0N9RP07bLV01`S8`0P9RD07B8N0P0M8Qd201lT
7`0801XO6P0R9b807R<N01hS7P0L8A`06QlJ024V8P0L81l201XN7`0401/O800L82806AdP01PK8080
6QdR00@061/R01XM900N8BH06APN0P0J6Ah0300H5a`06ATM01/L800L7B40:bda01`P8`0D61/05AXM
00hC5P0F5aT05aPJ01PI6`805aPJ01P05AHH01@E5`0J6ad08B8T01XK7@0L7Al06Q/M01XJ700C4aD0
5aLI01HF600D51H06ATK01/K7@0B4Q@04a<E018B500A4A<051@D01DC4`0920H04Q4?010?3@0E5182
018A3`804a8@00<04A0>018A3`0C4Ph00P0@3`/2014@30<040l=00/04@l@01HD5@0A3a0071XK014>
3P0D40l04@d<010<2`0D40l061@C01HB4@02010<2`0B01<?3P0E4A004`l>018>3P0=2@X02PL701DA
4`0;1`T01P85014<4@0L5ad08QdS040k@@0F4AP08ahU01TD600>20P03@L70P0@2PX00`0C3@d06A<C
02TS8`02014;2`0300L20P0I4a<030@500/04@L81P0@1PD04P0I3`h0=2XY01<92@0<0P809alN0106
1P0?1@H05P`=028H6@0>10D02P420147200`9RL06a4B00`3100?1@H02`4201061`8040@60P0?0`D2
01041P0702DI6`0I3@l03@8300/10P0>10D04PP900l22@0401032P0700l22@0@10X040@:01D83`0?
10T05@X?01<63@0Dooooo`006oooool200/;2`0>00h>3P0=3@d04a<B028R80092@L02@T600`=200@
4@`04Q<=010A2`0D51803`l=00`<2P0=3@/200l?3@803@d;00/03Ph<010@3P0B4Q004Q8@00L71@0:
2PP04A4?018B400?3`d092@R020P7P0200/;2@0:014A3`0B4Q004Q8@06EUH`0I6AL04A4?00/;2@0<
30X03Ph<018B40803`l=00<0410>00l?3@0>3P`01P0>3`X02@0;30L07b0K0001000B4`h0414<00/<
200<30X02@T700`<2P02010@3P0700l?3@0=3@/02PX800h>300A4@l0410>00h>2`0200d>2@0<00`=
200=3PT03@h900h?2P0=3PT030d800/<1`0=3PT03Pl:018B3`0?3`d020P60P0I6AL0300=3@/04a<A
00H610061P@03`l=0082000410804A4>0042000<3@P03Pl:01/L5`803@h901@02P/600h?2P0@4@`0
2``7014B3@0A4a0010H300/=2P0A4a00?d4n014C4P0D5QD04Q@C018C5@0F5a/01`P<00/<3`0G5aD0
4A8=00/<1`803@h901@030d801<D3`0?40/03@h9018C3P0C50l03@h901HE4@081`<02`X600L60P0?
3PX02PT501@C3`0B4@d03Pd901`K5`0@3`/0;2/W01TI5`802`/901`010@200`<2@0D5A004Q<=00d>
20082@<03Pl700X;0`0A4PX02PT501DD400H5a<0>3Lc010?2`0F5A4030/700`;200H5a<0EeIB038a
;@0:2@D03@`700h=200<2`H02`X500`;1P0@3`X04A0;0P0>3@P2014@2`0C00l>2@0D4`l0414<00d?
2P0D5a805ahG018L50094@X02a0:00hC3@0@4@`030/700/:1P0;30H08R<M075bK00L7AL00P<0010A
2`0200h?2@0800l@2P092P@06a`F00T:10092PD02``700`=200>3`X200d?300600`A3@0]<C005AXH
04iDDP0O9BD01@H40P0>3@T0100B4@d02`X600T8100C4Ph500l>2P0400h=2@0=30P03Pd900l>2P<0
3Pd90P0<2`L05@0@3`/04Q4=00h=2@0<2`P03Pd;014A3`0@4Pl03A8>00L=2@0:4`h00`T500/@3007
2PL030`:00`;2@0=30X020L500T81P0<2`T04Q4?00l>300200d<2P<03Pd;00@03`h<00@4100820P0
2PX:0P0E5AD02@15ADD09BDU030`<00E5AD04A4A00h>3P0@41003@/<00h<3@02010>3`0V00l=3P0>
30d040h?01DC500@3Pl03P`=00/92P0O7Ah09R@W01<A500>30l04@lB00l=400=2`h040hA00`:3@0=
2`h04Q0C014?4P091`X03@d?00H6200=3@l05ADG00`<3P0D51H02PX<00l?4@0=3@l02PX<00`<3P0@
41801PD:014@5@071P/06QTN01@C60071P/200l>4`803@`A0P0>3A804`0?41D030dB00X;3`0:2Pl0
3@d?00h>400>30l040h?01HB4`0=2@X030P901@B4`0E5AD03@d=01PH600B4Q804a<C018B4P0@4100
0P0000001`0A4A4051@D00L71`0>3`/04A4?018C3P0?3`d00P0>3P`0A`0@40h03`l=00h>300@40l0
4Q8B018B400?40T03a0800/<100<3@D04A8:020Q6@2CU8`00`@001XK4`000@009bPP00l>1`0D4@X0
4Pl8018@2P0A40/04A8<00h?2@0:2`H04aDB010C400;40`0B4e905MJEP0K71L05QLB014B3@0E5A<0
5ALD01<E4P0<3Pd0:Bd/00lC4`0L82404ALG00dB400B5a<05QPG014D4P0B5a<051HE00X=2`0F6aL0
4A@B00H81`093PX05aTG00H81`0I6aP03Q0>00X<2`0?4@h03a4?010B4@0A4a004A<A00h@3`0>40d0
4A<A00lA3P0G6AH04Q@A00h@3@0E5a@04aDB00805aTF00X06A/H01/M6P0I6aP04aDA01PI500E5Q00
4a@?01HG4P0H6A@051@B0P0G5aD01@0K6a/061PH01DE5@0K7A`04aDB008051TE00D04aPD014F4P0=
4Ph06b0L01LL600201TN6P0301LL600K81`05ahG00806R4J06D05QlJ01DN6@0F7a`05B0L038l>`0A
6aX04alO01TU9@0A71h09Bhc01hW;@0b>d00G6M]02Pc=`0S;S8062HY01l^<@0Q<3<06bX]01TY:P0S
<c<07bd`028a=00U=3L0:3Ll02Hh?00T=SX0;3e4069eO014Eeh09SU003=7CP0mDEX0=4ME03U<F`0d
AeH09cY802@gA@0W>dH0;T9=02a0B@0Z?TL0;d=:02TmA00^@TT0;4=<02PnB@0V?DD0;D5902i1B00^
@DL0<41503E3AP0^?3l09S@e02@_<@0S;Bh0;C@e02Ta<`0e?cl0;c/k02di>@0]?3l0<T=:03I8DP11
EFD0?eIX03I<H`0gBeX0:Se402Lh@00aA4/0=DQ?03M8D00cA4`0;Sm6024b>@0R<ST0;Sm602hmA00`
@DP08C<m02Dg@@0V>400=DI>02/j@@0Y=ch0:3Dk02Le>00X=CP0:C@h02Td=P0Y=S/0:SU002/j@@0/
>d40:cXo02`i?`0b?D40;cXn02/f>P0202Pb=00F02Td=P0/?T806bl`024b<`0U<C4092l[02H]:P0R
9b<082DQ02T^:P0R9RL0:Bd^01hT9`0V;c@09c8f02<^<P0P:bd08Rd_024[;@0R:R`082PZ01lW:@80
8BLW00/08bTX020U8@0N8al082DQ024V8P0N8al07B8N01`Q7@0N8al07B8N01TN6P0201@I5@0601lS
900N8R<07B4R01lS900O8bD07B4T0`0E61d0200G6R406ahU01lR:@0J6Al071/P01/J7`0I61d06QXN
0P0K7200300@4QH092P[00X>4@0K7b804QLJ01XK7@0F5aT05AHH01PI6`0F5aT0414C01DF60806a`N
01H05QLI01/L7P0D5AL05aLI01DE5`0G5aT05QHH01<C5@0E5AL051@F01DE5`0L71h06ATK010@4P0>
3Ph030/:01<B400K6QP04A0>010?3@0G5Q@04Q4?0P0C4Q000`0A40h04Q4?01<B3P0200l>2P03010?
2`0A40`04Q4?00804Q4?00H04a4B00d;300<2P/03P`=018?3`0A3@`2010<2`0301<?3P0G4a805A4@
00804@d<0P0B3Pd04@0A3@`030P801<?400@30d02`L800d92P0?2Ph05a8G00/630060@L06aLM00<0
1@0D3aH05A0D00d71`0>20P04P`<00<040X:00H04@/;00H0000B30`0208201@>3P0@20P;014720H0
40H5018081HE08AjN@0M4a806a4@06eSHP0H3Pd03@<401@:2`0X7Ql06Q0A0147200@1PL08QPI0188
2@0<0P<03`D600T0000:0@8301041P0300l31@0@10H040@600802`010P0F2P`0100>0`@050P:00d0
1`0?0PT20185300800l22@0=00L03`8901P;4P08008040<:00l52@08008Dooooo`006oooool0400C
4a<0410@018B4P0B4Q803@d<00`<2P0;2`T03@h:010A300A4Pd0414<00d>200E5A<0410>00`<2P0=
3@/200l?3@0800h>300=3@/03@d;010@3P0B4Q004a<A018B40092@L200h>300:014A3`0Z:RP04a<A
00T91`0:2PP02`/900`<2P0?3`d04Q8@00D50`803`l=00<03Ph<00H6100A4@l00P0>3P`00`0A4@l0
4Q8@014A3`0600h?2P0B03Pi=0082@@02P/6014B3@0<3@P08B8N01LG5@0;2`T030`:01<C4@0?3`d0
3@d;00l?3@0;2`T03@d;010@3P0>3P`03@h:0P0=3PT05`0<3@P03@h900d>2@0>3`X03@h900`=200;
30L03@h900h?2P0?40`03Ph<00l?3@0];B/0:RXX00l?3@0@40h04Q8@01lO7@0b<S006ATG00d=2`0D
5A403@h900804Q<>00<0:2TT010A300D5A000P0@4@`05P0B4`h0414<00h?2P0A4`h01PP3010B3@0A
4a00>S`i00h@3@0=3`h00`D400P92`0:2`d0:2T[00420`0820H02@X500X;1P0;30L03Pl:014B3@0@
4@`200`=200W01<D3`0E5Q40414<018A3@0920@06aXF00<2000<2`L05QDA00l>2P0<2`P05QDA03Pg
<`0F5A40?3/g01<C4@0>3P`05ADC00l?3@0@40d030d800L80P0<3@L03@h8018C2`0720802``400L6
0P0?3PX040l;034`;00<2`L05A@@014@300<2`L01@@000/:1P0920@051<?00803Pd800H030/600X9
100=30L040l:00d<1`0?3PT200h=2009010?2P0C4Pd09B@P00h?2P072@@02Pd8010G400E71D02Q4:
00801``601<04Q<>01<B3P0>3@T02``701DF400P8A/030d800d>200:2`D0414;00X;1@0?40X01`P3
00l@2P0:2`D02PT400/<1P0<3@L03Pl:00803@l:00`0;c4^0>KZj@1EFEP03a<B00X>3@0<3@`03@`8
00`;1`0B4@d02@P400H50@0B4@d600l>2P0300h=2@0?3PX03`h:00<03Pd901003@`800`;1`0@3`/0
4A0<00h=2@0;2PL03Pd;014A3`092`P041DA0088100>51001@/700X?2`0A4a002`/90P0<2`T01@0A
40h040l=00d<2P0920H040l=00803@`:0P0>3@/200l>300>00D51@0L71`03@d=010@400820P05ADE
00`<300>3Ph010@400l?3`030`<02@T900`:2`0=2``200l=3P0V00h<3@0=2``03P`=014?400:20T0
3P`=00`:2`0D4Q<071XM00l=400=2`h04@lB00l=40091`X040hA00`:3@0=2`h04Q0C014?4P091`X0
6a/M014A4`030`D03@d?00/;3@0C4aD030`>014A4`0D51H0410B00`<3P0?3a403PdB010?50030PL0
61LL00d<4@0A41D200`;400I00d<4@0>3A8040lD014@5@0?41D03A4E00dA500=3a<03@h@00`=3`0C
4aD02`/;01<A4P0A3a0030X;01<A4P0C4a<04A4A01@D500A4A404a<C01@D500B4Q805aLG01DE5@02
01@D500601<C4`0=3@`04A4A014A3`0?3`h03Ph<0`0?3`d0500?40/04A4>018B400C50l04Q<=00`=
1`0:2`D04Q<=01@E3`0>3`T0;2dW01dN600720D0BT]50001000M71D0514:010@200@3`T04a8=0P0A
4P`0@P0=3PT03Q0=01@F4`0<3P/02a0<018E400B4`d04A8<018C3@0G61<05QPC018D3`0B5140=S/g
010E4P0;3`h05A/I010C4@0A4`h05ADC01@E4@0F61<06ATG018C3`0A4`h03a0=01@D4P0>40/03Pl;
00lA3P0E5a804aDA01XL6@0C5A0061XF01@F4`0E5a805ALC018D4@0B50l05ALD010B3`0D5Q<04aDB
01HH5@0N81d061XG018D4@0C5A805ALD01LI5P0E5a@03a4=01LH4`0D5@l04a@?01LH4`0H6A@05ADC
01LG5@0C4a404Q8B01@D500C4a<05QPG01XL6@805a`H00D05Q/G01DJ5P0D6AD06b0L01HK5`0201LL
601Z01HK5`0K81`05Q`H01/Q7@0M8al06B8O01LP7@0F7a`082/W01@O6`0N:BD072PV01dY9`0O:bT0
6bDW01/U:00d?T00G6M[02Pc=@0Z=CL06bTZ01`[;00P<30072`/01XZ:P0T=3@08S0c024`<`0S<SD0
9SDj02Dg>`0W>Cd0:S]2049EG00]@4L0<4=:03M;DP0^@T/0>4]H03]>G00fBEL0:3]902LkAP0[?dX0
;D5;02e1BP0/@4T0<DE<02XnA@0^@TT0<4M?02m3C00Y?DH0:Si602m2B@0nCeH0<T5603=1A00_?Ch0
;cXl02/g=`0W<C809bl]02L`;`0a>cT0;3Pf02Te<`0Y>3T0:Sa002Tl@`0kD5d0AU]/03Y?HP0eAe@0
:ca302Th?`0X>D408c@l02Df?P0Z>d<0<45902/lA00^@4L0=TU@0311B@0]?TH08c@l02/lA00`@DT0
>DYA02dl@`0Z>Cl09SDj02Hc>@0U<cL09S@g02Td>00Z>3`0;3]202dl@`0`?dD0;ci302hk@@0^>Cd0
;3Lk02Td>080:38d00P0:C@f02<e>@0P=3D0;Sm002hj>P0Z=C407bHS02<X9080724M00H0728R01lU
9@0S:B`09Bhc02Pc=`0X<cD202D_<@03020Z:`0O9bT08BT[00<092XZ00<08BLU028W8`0N8al00P0Q
9R802@0L8Ad07b@P024V8P0R9b<07b@P01hS7`0R9b<092TU01`P8@0201XN7`0F01/O800L82806AdP
01PK800G6Ql05QTN01LJ8@0I72<06QdT01/J800N7B<07ahT01dL8P0I6Al061TN01HG700b=3T0EUUN
01TL8@0=4AD03A8E01PI6`805AHH0P0H6A/00`0B4aD04a@F01@E5`0201TJ700?01hO8@0H6A/04Q8D
01PH6P0G5aT061PJ01HF600@41804a<E01HF600L71h06QXL010@4P0>3Ph05A@C00805A@B00@05QDC
010?3@0B4@l04Q4?0P0C4Q00100A40h04Q4?01<B3P0@3`/2014@300901<B3P0C4Q004a8@018A3`01
0000928S038`<@30_[l081dM00L04@d<0P0B3Pd2010<2`0@014=300C3`h02`L8018>3`0H51D02PD9
00H21@0>2@d0=C0f04a7C@0F4AL04PdC00`72P0>20P03`T9018<30803PP800L04P`<01<=3@0>20P0
5a4A00`61P0@2PX040P900/04@L81P0@1PD04P0<0P403P@301471P0700002P0001471P0@1PL03`D6
01`B4`0G3@h05@/<0147200700002`4200h41@0<0P<03@<400/10P8040@60P0A1@L201041P0800h2
100A1PL02P0000P0000@1PL03`<500h1200A10/201<63@0801442`0>0@P04`H=00`21P0I31<06PdD
05I9D00Y72<Dooooo`006oooool0200G5aL030`<00h>3P0C4a<04A4@00`<2P0@40h03Ph;0P0;30L0
500=3PT0414;01<C4@0@40h03`l=010@3P0A4@l03Ph<00l?3@0>3P`030`:00d=2`0@40h04A4?00l?
3@0<30X04a<A01LG5@0?3`d06a/I0P0>3P`03P0A4@l03`l=00d=2`0A4@l03`l<010@3@0=3PX030`9
01<C400A4@h03`l<00/<200<30T0410=0P0B4Pl600h?2P0B00l@2`0=3PT05aPC00/<200@4@`09BDR
01dM6`0A4@l03`l=018B400=3@/02`/900h>300<30X02`/900`<2P0>3P`03`l<0P0=3PT0100<3@P0
3@h900d>2@0>3`X200l@2`<0414<00X03a0<014A3`0=3@/03`l=014A3`0<30X0410>00/;2@0=3@/0
5aLE0P0:2PP06@0@4@d01PL2018C3P0<3@X05QLB00l@2`051P804Q<>014B3@0;30L04a@?014B3@0;
3@P02``701LH4`0A4Ph04a@@00/<2P082@L05aPF00h>3`0@4180J6QZ020Q8@0;2`T00P0@4@`01P0;
30L030d800`=200=3PT030d800d>2@80414<02<03Pl:00T8100?3PX09B@P00`;2@0;2PL051<?010?
2`0;2PL07QdI02DT800920@06APD01@D4P0=3@/03`l=00X:200?40`02@X600h?2@0?40X02@X400`=
1@0=3PH0824I00l>2P0<2`L02PT5018A3@0>3@T05A@@00l>2P0=30P05A@@00l>2P0200h=2@0300d<
1`0>3@P03@`7008030/600<040l:00/:1@0<2`H00P0<2`H0700>3@P03`h9014A3@0<3@P03@h900`>
2@0830H01P`600X>200<3`X03@l:00h?2P0?3`X03`l;00h?2@092P@03@h:00h?2@092P@04Q<=00h?
2P092P@02P/5014B30092P@0414;00l>2@0=3@L200`<1`8030d800X0;c4]0::UX`0o@d403a@A00T=
30092PP05QDA01@C3`0<2`L04Q4=0P0<2`L600l>2P<040l;00<03`h:00h=2@0>3@T00P0?3PX200h=
2@0?00d<200=30T0410>014A3`0?40h041<@00/>2`0<40d02`h;00X=2P0A4Pl02`/900`<2P0:2@L0
6aXH00807ahL00@01@@300l>300>3@/03Pd;0`0?3P`01@0@3`d04Q8B03De=@0?3`l04a<C00803@d=
00H030`<014A4@0B4Q809BDU018B4P0>3Ph600d;3003014?400C4A8030X;0080518C00@04@l@014?
4P0>30l030X=0P0?3A00100;2@`03`d@00h<3`0=2`h200l=400900d;3P061PP06ATK00T92`0A4A<0
2@T;01@D5P0>3Q002`/=00803`lA00@02`/=00d=3`0A41D03`hC0P0A41D0A00=314030/@00`;400<
2a003@`A00h=4P0A41D04Q<G00lC600@51P03a@G00hC5P0>41803@lA01HH6P0;30`03Pl?01@D4`0B
4A804a8B061PH02PX:00:2PX00h>3P0B4Q8061PH05YJFP0D51@02PX:014A4@0@41004A4A00d=3P0@
41403`l@00h>3`0?3`d04A4?00d=2@0?40/0414<014B300?40X03Pl9010A2`0?40X04A8<01XK5@0E
5Q00414;018C3@03104051D?01LH4P0O81X03Pl9014A2@0B4PX0414:01HF4@0G61804a@>01<D3`0B
4a003Pl=014C400B51403a4;0`0@4@X02P0D5@h04A@>01<F400e=c405Q/F014F4@0C61<0318=00lB
3@0B4Pd201<C3P0A01@D3`0E5A005QHA01HF4@0A4@`04Q8=00X:1P0C4`h051LA00`?2@0X:R@0?T0j
01HH4P0?4P`04Q@>01<E3`0C5Q000P0@4`d02P0C5Q0051HC018D4@0F61D05aTF01<E4P0F61D05ALD
01@F4`0E5a@201LI5P0?01@F4P0D5A0051H?01@F4@0E5a805QLB01HG500K71T051DC01DF5P0L7A`0
6AXJ01HH5`0J7a/051TE00805AXF00@05a`H01hS7`0K81`05a`H0P0I7QX0;@0G71P06b0L01TO7@0L
8R407B<R01XS8@0L9B807BHS01LR7P0N:BD07bXU018N6@0N:bD06BDQ02<^;00M9bL09S0`01`X:@0N
:BT0<cm003M5A@0N;Bd08C4`02dm?00X>3P0830`028`<`0P;c8093<f02Dd>@0T=SX0:3Xn02Pi@00S
=Sd08C@k02`oAP0eBE00=4QA02m2CP0a@e00;T1=02XlB00/?dX0<4==02XmA`0202e0B@0l03=6CP0Z
?DH0;T9:02e2B@0aADd0<dM>0354BP0dAD`0?U1D03=3A@0`?Sl0:cPi02/g=`0W<S408B/Z028Z9`0R
:bL08R`W02@_:P0Q;BX07Rd/02<e=P0P<CL0;T5:03eBG`0bAUH0;Ce9045?E@15De/0;3]302`kA00d
ADh0<D=<02/mB00/?TT0:Sa902]0C00bAe<0;d5;02<c>P0^?TH0<4170392B@0X=ch0:cY002He>`0U
<cT09C<h02Ld>@0Z=S/0:cU002`k@P0]?4<0<D160350A@0^>d40;3Lk02/f>P0W<SH09S0b0P0U;c40
<@0M;S80:3Xl02<a<`0T<3008RdY024W900Q9R807B8N02hd<01PIVH0=Sdm02D/;P0S;Bl0:3<f02Xd
=P0U;c0092h_01lX:P0N9BH08RTZ02<Y:@0P9B@08RLV01hS8P0O8b407B4O02@X9P0U:BL06b0M01dQ
7`0N8b007b@Q01PL6P0I7Q/0:2dZ030d<`0M8B80720Q01/O800M8B807B4S01/O8P0L7b@06QdR01TL
8@0J7B@061/R01<F7@0J6Al00P0N7B<02`0L6b4061PN01HG700A4QL07R0U03@g?00M82D05a/P01DJ
7P0G61`061TL00806AXM00T061TL01LH6`0E5QT05aPK01/L7`0F5aX0@T=606=TI`0h>3X00P0E5AL0
3P0K6ad05aLI01PH6P0I6A/04a<E01@D5P0C4aD0410B018B4P0B4A005aHD00L61@0E51805QDC0P0B
4@l201<B4003014@3P0B4@l04a8>00@04Q4=0P0B4@l01P0?3P`04a4B014?400M6a`0H5iO03Db<P<0
510?00H04Ph=010<2`0?2`X04@d<01<?3P0A3@`200l;2P0=01@@3`0C3`h04Ph>01@@400400006aHI
02hY;@0E41@07aXO020K8@0A3A802PD;014<3`0200`61P0:014;2`0?2@T04@/;014;2`0=1`L03`T9
010:2P0A2`/03`T901082@/04@L81P0@1PD04P0>10@06A0@00h5100@1PD060h>01071P0D2P/02`<3
00`310090@403P@501882@0<0P<040H700l51P0;0P803PD501<92P8040@60P0B1PP02P0A1@L040@6
01882@0A1PL0Ed]=05U=C`0C20T04`T:01032P0A10/20185300801442`0@0`X02`45020C6P0F2a00
200201@73P0@1@XDooooo`006oooool0500Z:RX05QHF00X:2P092@T02PX900d=2`0820H03`l<01<D
3`0B4`h03Pl900X;1@0@40h03`l=010@3P0B4Q004A4?00h>300@40h03@d;0P0;2`T01@0=3@/03`l=
01lO7@0>3P`020P600804Q8@00D061PF010@3P0<30X0410>014A3`0200d=2`<03a0;00T04Q<>00h?
2P0>3`X06Q/F01<D3`0?40/03Pl:00d>2@0<3@P01P0>3`X0200?40/02``700D60@0?40/05QLB00/<
200:2PP030`:0P0>3P`300l?3@05010@3P0>3P`03Ph<01@D4P0C51000P0=3PT0;`0<3@P03@h900d>
2@0<3@P02``700d>2@0?40/03Pl:00d>2@092@H030`:00X:200A4@l07AdK014A3`0:2PP030`:00/;
2@0>3P`03@d;01<C4@0`<2d04A8=00X;1P0<3@P02@X500h?2P0F5a80<c@_02X[9P092PD03a0;00d>
2@0D5A001PL200/<1`0T9B003Pl:00l?3@0;2`T00@40010@400J6Q`030`>00l?40092@L030d80080
2P/600<03a0;00`=200A4Pd00P0C50l01`0@4@`03@h900d>2@0:2@D04A0<010?2`0920@00P0C4Ph0
1`0J6AD03`h:01hM6@0100006QTE01hM6@0C4a400P0=3@/03P092@L03Pl;00H70P041@003Pl900l@
2P0@4@T01PL0014B2P0=30P03`h:01TH50081`<05A@@0P0:2@D01P0B4@d03`h:01DD40081`<04A0<
00`;1P803Pd8028030/600d<1`0>3@P05A@?00`;1P0=30L04a8=010?2P0:2@@03a0;00h?2P031000
1`T5014B3@0:30L03Pl:00@500092PD0414<00/<1`092PD03@h801LH4P0O81X02@X500d>20041@00
;c0Z01hO6@000@004A8<00@5000<3@L03@`70P0:2@@03`0=30L0414<014B3@0B50l05ALD010C400@
5A40004001<E4@0B4@d03`h:01PG4`0920@00P4000l>2P0500h=2@0N00l>2P0@3`/040l;010?2`0?
3PX03@`800h=2@0@3`/04A0<00`;1`0:2@D03@`8018A3P0:2PP00`<1018B400210403`l=00T:1`0B
51403Ph<00L71@0@40h03Ph<01TH5P01000051<A05ACD@0D4a4040l=0P0>3@/200l>308040l=01X0
0`<302d];@071`L04Q8B00H61P0@41003Ph>01TI6@0;2`/05QHF018B4P0>3Ph04@l@010>3`0>30d0
3@/<00h<3@0A3a002`T:014?400;2@X04@l@018@4@0A3a004Q0C014?4P803@/>0P0A3a8200l=400<
00d;3P0<2Pd03@/>014?4P0D51H01PH8010@4P0G5aT03`lA07IfN00P82804A4C0P0>3Q00200;2`d0
3Ph@01LF6`0=31403PdB00811P0P7b@05QDJ0P0>3A8200d<4@0400l>4`0>3a<04aPL00hD5`802a0C
03D03A4B00lC500>4Q<03a4@00h@3`0G6AP08B4Q02<S8`0L71`0<S8b01dM7@0:2PX03`l?024Q8@1V
IVH04A4A00h>3P0F5QH02`/;00l?3`0>3A803Ph@00d=3`0=3@h0410@018B400?40/04a@>01DF400D
5@d03a0800d>1P0>3`T030d700T:100>3`T04Q<=00T:1P0J6aD05aPB00T:1@0F5a40414;00d>1`0@
4@T04A8:00`=1P0@4@/04A8<018C3@0?40/03@d;014A3`0200l?3@0O018C3@0C5@X0414900`=1@0A
4PX04A@=00d@2@0n@CX00`P200hB3P083@L04APA01@G4@0E50l04A0;01<B3@0E50l05QD@01@C3P0H
5a8051<>01XI500I61<03`l:014B300F6A8030l8010C300B5@h05aXC01@G400201DH4@0501<F3`0B
5@h05APA01HH5@0?4@h00P0C5A800`0D5Q<0?d4n01<E4P02018D4@0901DG500F61D05ALC010B3@0C
5Pl05QPC01<E400B50l05aTF00804aDB00`06adL024S8P0H6QT051HE01LL600K81`09b`X02H[9`0H
7AT04aPD01/P700I7QX201`Q7@1W01TN6P0K81`07R@T01`R8P0I7al05b0O01lX9P0W<2d09c8^01DP
6`0I91h07R/T01<P6@0/>C80:cHb02`g=00L9RD07RXX02<_;@0^>SP0=TA4024`<00Q<C0093@c01`/
:`0M;Bd08Blb02<b=@0[>Sd0;3]002Li?@0[?D40:ca302Pk@P0hBe80:ci502@h?`0^@TT0<D==02i0
C00]?dT0;T1:0312C00a@dd0;Cm90353C@0bA4h0=dUC02m1B`0bA4h0?E5H03A8C`0hCE80<TE:03A6
BP0_@D<0;chn030l?00Y=C<09C4_02La<00V;bh07bLT028[9P0I8ah0:3<]02Pd<00O;2T0:3Pg02Dd
=`0X>T00<TA>02`nBP0]?DL09C8j028_=`0^?DD0<45902m0BP0a@dh09c]603Q;F@0gCEX09C]902]2
D00[?TT0:SU003=2B@0_?TD0;Se402Pg?P0`?dH0:3Ln02He>P0V=3X0:CHl02/h?P0/>T00:CPo02Xi
@00`?dD0<3m402/h?P0202Xe>@0C02Td>00Y<cD0:S@f02Xe=`18Ee`0F6MZ02Hc=00O:BX082TV024W
900_=3006b0L01lU8@1fOgh0=Sln02@/;P0Q:bd09c4c02H`<P0201lY:P07024Y:`0O9BD08RPX01`R
8@0H71/0720O01/O7P0201dQ800;02``;`0_<c808BDT01dQ800A5A@06alN01XN7@0H71/06AdL01<G
5P0J7Ql00P0H71d05P0I7Ah06QhP01PL7`0D5a`05APM01XM8P0N8BP07B0W01LJ8@0G5Q`061LM01LF
700F5A/05aLM01XK800;31405QPM01TL8@0N8BH04QHJ00/@500H6Ah201`M8@0A01PI7@0G61`06AXN
01HG6`0L7B407b0T02HW:`2SY:P0o_oo07AdMP0A4A<05ADG01PH6P0>3Q007alQ00l?4@0A4A<00P0G
5aT02@0A4A<04A4A020O7P1FEE<0;bh/014@3P0=30X05A@B018A3`0201<B4005014@3P0B4@l04a8>
018A300A40`00P0@3`/02P0?3P`03Pd;00l>300?3@h03@/<01@B4`0610D07a`L01<?3P0A3@`200l;
2P<04@d<01d0510?014=300=2@P03PX9018>3@0E4A003PX9014=300C3`h03`/<01<>4@080`L050lC
00d83@0A31804PdC00l:3@0=1`L030H600l92@0=1`L03`T9014;2`0@2PX05@l?00d71`0D3Ph03PP8
00l71`05014720H03`D61P0@1PD0500;0@002P0000l5100D2PT01`0001071P0<0P<02`4201D;300=
0`@0308300d3100I3a00308301061`0H3Pl03P@501882@0?0`D040@60P0C1`T02P0A1@L03`<500h2
100E2``050P:01P<3P0F2P`0200001032P0?0PT200h1200800l22@0@0`X04PD<00/01@0D1`h07A0G
01/A5@0C1PdDooooo`006oooool0400N7Qh02@T901XJ6P0H61P030`;00X:20051@<02`/8010A300E
5Q402``7018C3@0A4@l02`/900P81P0;2`T2010@3P0;01HF500:2PP04Q8@00l?3@0B4Q00410>00h>
300D51801@D300h>300F5Q@00P0B4Q004P0=3@/03`l=018B400<30X01`L500d>2@0;30H03a0:00`=
1`0:2`D03Pl901lP6P0I6Q@030d700d>200?40X01`P200h?2P803a0;00/03@h900h?2P0?40/05aPC
014B3@0=3PT030d800h?2P0?40`03Ph<00d=2`0200`<2P0400d=2`0?3`d04A4?010@3P<03Ph<00@0
3@d:00`=200=3PT03a0;0P0@4@`07P0A4Pd02P/600X;1P0>3`X01`P300X;1P0C51003Ph<00`<2P0?
3`d04a<A018B400?3`d0410>018B400>3P`02PX800d=2`0A4Ph0004000/<1`0<3@P0414<01<D3`0>
3`X0Q8F005MHD`051P407QlJ00l@2`802``601L030d700d>2@0>3`X0414<00`<2P0=3@/0410>00l?
3`0=3@d02`/;00h>300=3PT02``700X;1P0;30L03Pl:014B3@082@@02``700l@2`0:2`H03Pl:00d<
200200`;1`803Pd900<02`X600l>2P0?3PX00P0@3`/03P0?3PX03@`800P81P0;2`T02@T701dM6`06
1`<02P/600`=1`0=3PP02``600P90@0;30@04A8:1P0=30P02`0>3@T03`h:00l>2P0<2`L03@`801<B
3P0A40/030/600l>2@0B4@`04A0;00<03Pd80P0=30L200`;1P0Q00/<1`092PD02@X500`=200=30P0
30d800d=2@0=30P0414<00d>2@0;30L04A8=014B300H6A<04A8<00X;1P0J6aD01`P202DV800@4@/0
6Q/E00`=1`0C50h010D000h=1@0A3PL03@X300d<1`0?3PT02P/500`=200G6A@020T7008051HC0180
414=018A3@0>3@T05A@@00`;1`061@404A0<01@C3`0@3`/02PT501<B3P0?3PX02`X7014@300@3`/0
3Pd900`;1`0;2PH200d<200B014@300=30P05A@@00L60P0C4Pl020P601<C4@0:2PP00P80018A3`0>
3P`02PX800P71@0<30X03`l=01@D4P0>3@/03`h<0P0@3`d200l>300300d<2P0>3@/03`h<00803@`:
00d03`h<00d=3@0B4Q80410@00`<300?3`l02`/;00D51@0=3@d051@D00h>3P0;2`/03`l?00<040h?
00T03`d>00h<3@0>30d03@/<01@B4`0L6Q/05aDF010>3`0=2``01P0;2@`201HD5`0=01@B5@0B41<0
3`d@00d;3P051@L0410B00T92`0:2P`071`N08Z:S00S8bD05ADG00l?4@0201@D5P0I00`<3P0<2a00
3PdB00d<4@0@3a@05A@I014@5@0=31403`hC01DD6@0D4aP03`hC010A5@0I7R802Q4D00D:3@1WK6l0
3a<D01HJ6`0?4a@01PP700`>3@0;3@`02`/;01<C4`0400l?3`0500d=3@0<30`06ATI00l?3`0<30`0
0P0=3@d0200<30`040lD02h^<00Z:R`03@d>010@400A4@l03a0;0P0;30H03`0?40P0414900l@200G
61<05AHA00`=200G61<05QLB00L8100E5Q404A8=00`=200C50l04A8=018C3002010A2@0R010A2P0@
4@/0414;00l@2`0C50l04Q8@00h>300D51805ADC014B30082P004Q<;00h?1`0<3@D061/D018E3P0C
5Pl05AXD00lD3P0A5Q004aXC00/>200K6QD06QTD018A300F5A0010<001TH4`0=30L061LB00P70P0F
5A004a<=018C3@804QD>0P0?4P/03@0A50d08RDN01LJ4`0I71D061/D01/N5`0F6A804A<@01DG500D
5Q<04Q@A02DW901FF5D00P0@4Pl01`0C5A805ALD01HH5@0H6QH04A<>01<F3`0F61<00P0E5a800`0G
6AH061XG01PJ5`0201LI60806A/J04H07R<O01dR7P0J7a/061dI01HK5`0D6AD061dI01TN6P0F6aL0
51TE01HK5`0I7QX09B/[01TO7`0P9RH02Q<B01lX9P0G81d07BPT01dX8`0I91h05B8K01TV7`0P;BH0
7bXT01hY900O:RH082`X02Da;P0Y=C<0?Ta<02<b<P0R<S809CDe01d];@0O;bl08Blb01h]<00Q<3<0
:3Ll02Hh?00T=SX0;3e402e0A`0dAdh0:ci502a0A`0[?dH0?E1G03a>F00Z?D@0?E1G0=;Uk01JKG@0
;T1:0312C00oDE/0<D==03I8DP0/?TP0<dM=03M:D01NLGD0:C/o03Y9C00_?cl0;3Xk03A0@00Z=S@0
82/X0P0R:bP0>`0a>SL0:34^01hX900L9b408RlX02Ld<@0O;bh08C0c02Tk@@0X>D<09CI002dlAP0X
=Ch0<3i702`jA00W>480=4AA02m1CP0]@4h0?e9Q03=9F00^AED0>U5Q02PkAP0d@DL0>DI<02hl@P0[
>Sl0;ci5030oAP15E5/0NHR?0350A`0^?D@0:SU002Pg?P0/>d80;Ca302hm@`0b@DH0;S]102Lb=P0Y
=3P0;cXn02hh>P0Y<cD0;3Li04QEF`10Ce80:CHh02<];P0]=S<09B/X02H[9`0R9b<08RPT024Z:@0O
:2L08R`]00807BLX00/07RHX01dU9`0Q:B/0;C<c01`R8P0M8b<082@S01lS8P0N8al07B8N020T8`02
024U900301/O7P0H71/05QXI00<06alN01@06QhM01TM700G6aX09BTZ04A8B@0F6Q/0720Q01hR900N
8RD06ahS01HI7P0D5a`05QTP01DH7`0B5A`05QDM01LF7P0J6B407A`T01dM9@806QXR01L04a@L01@G
7P0M82L08RH]01hS9`0J6b0061TN01DF6`0D5AX05QLL01PI7P0K72406Q/P01LH7@0H6Ah0Jfaa0<O8
c014A4H04Q8D01LG6@0K6ad04Q8D01LG6@0201@D5P804a<E00P04Q8D018B4P0e<c<0dm;@03/j>00A
40h05QDC01<B40D040l=01@040l;01<B3@0<2`L04Q4=014@300D4a403Pd;00l>300;2@X06ALH00l=
3P0F51D05A8B00l;2P0A3@`03`/:014=300E4A003PX901@@3`<04@d<00X03PX901DA3`0C3``04@d:
010<2P0@30/04@d<01<?3`0B3Pl04@`@0P0@2`l04`0A310040X=00l92@0=1`L03`T901D?3`0F4100
6A<C00X4100<1PH050h>00h8200B30`04@T:01061`0B20T050X;01D;300G3@h00P0B20T04@0A1`P0
3P@500l51P0C2@X03`D401<9200E2`X03P@300`20@0A1`H01`0000`20@0H3Pd02P0000/1000?1@@0
2`4200804@L800T03P@501<92P0A1`P03`D600h41@0?1@H03P@500`20`0@1PL01P0@10H0300A1@L0
40@600l31@0?0`D040@601451`0:00@03@4701442`0B1@`040<:00/01@H040<:5?ooool001_ooooo
00P04A4A018B4P0;2`/03`l?00h>3@0F5Q@06ATG00d=2P80414<01404a@?00P90`0B4Q002PX801DE
4`0V9R@08B4O00P81`0B4Q0030`:018B400:2PP03`l=00h>300M7A/030`;00h>300201<C4@0H00l?
3@0B4Q003Ph<00d=2`0>3P`0410>014B3@0=3PT03a0:00`=1`0>3`T03a0:00`=1`0C50h04Q<=00/<
1P0?40X04A8<00T:100=3PT03a0;00h?2P0<3@P03@h90P0>3`X200d>2@8030d800T0414=01<C4@0A
4@l03`l=00d=2`0<30X03`l=010@3P0?3`d00`0>3P`0100=3PX030d800d>2@0?40/3010A300700T:
1@0:2`H061TD01DF4@0@4@`04A4>00l?3@0300h>30803`l=01h03@d;00`<2P0?3`d04A4?00h>300;
2`P0414<018C3P0;30L030d8010A300A4Pd0414>00d>2@0O81/04a@?00`=2@0=3@L030d600d=1`0>
3PT03`l:014A300=30T03Pd:010?3@0@3`h03Pd<00`;2P0=3@/500d>2@0800/<1`061`@05AHA00<4
000C50l051D@01LF4P0B4@d200d<2003018A3@0C4Ph040l;008051<?00`04A0<00d<200=30P05ADC
00/;2P0;2`T02`/:0492?`0G61D03a0:010A2`0>3`T200`=1@0300l@200=30P03@`800@03@`800@0
3`h:00`;1`0;2PH03@`80P0?3PX00`0=30L030/600l>2@02018A300300l>2@0>3@P03Pd800803@`7
0P0<2`H0A`0=3PT02``700/<1`0@3PX04@h;010=2P0?30P03`d9014@300>3`X03@l:018D3`0F5a40
4a@>02@U7`0A4P`02``6010A2`0B4`d0<c@^01LH4P0<3@L02``601<D3P0@3@D04@h700h;100?3@L0
3`h900`;1P0<3@P051D@00h?2`0>40`01PP4010A3@0@3`/030/701HE4@0C4Ph04Q4=01TH500>3@T0
3`h:01HE4@0@3`/03Pd9010?2`0>3@T03@`800h=2@0?3PX040l;00l>2P0<2`L040l;00`;1`0F5A40
3Pd9018A3`0I6QP02`/900l>300F51801@81018?3@0?30/04Pl>01<B400=3@/03Pl=00803Pd;0`0?
3P`0400>3@/030/900d<2P0>3@/030/900/:200>3@/04A4A010@400:2PX02`/;014A4@0?3`l02`/;
00`<300=3@d200`<300500l?3`0@3Pl040h?010>3`0?3@h00`0>30d01@0D4Q<061HG01@B4`0?3@h0
3P`=00H03`d@00<03P`?00l=400@3Q400P0?3A004`0>30l030`>00l?4@0>3Q006ATK00D51`0F5QP0
3Ph@00/;3@0=3@l04A4C018B500=3@l02`X?00d<4@0<2a003@`A014@5@0;2Pl00P0@3a@0400E51T0
4a8G010?500C51P04ADJ00`@500?4QD0Ada?01<E5`0?4A<030l@01LH5`0U9RD0820P00h=3@0;2PX4
00l?3`0600d=3@0<30`05ADE014A4@0?3`l03Ph>0P0?3`l01`0C4a@06a/L01PH6@0?3`l04Q8@00/;
2@0>3PX00P0E5Q40A00@4@/03a0:014B300=3PX03Pl;010@3@092PH08B8N02LW900U9B80;BhZ010@
3@092@H04Q8?018D3P0@50/04A<;014C300A4`d04Q<=010A300A4Pd04A0>00h>300B4@l0518@018B
3@0I6Q<0:b`U01hO600:2`@04Q@>014D3P0A4`d041D@00hC3P0E6QD06B0J01TL5`0D50l061PC018B
3@0O7aX04A4<01@D3`0F5Q404Q8=00T91P0J6QD03Pl:01<E3`0D5Q0061/E01`O6@0J7AL051LA01HI
4`0A50h05aXD010C3@0B50h051LA014C400C5A805QPE01DG500G6AH07b4N0`0E5a@201HH5@0601HH
500A5@l051PA01HJ500E61<04aHA0P0B5Q803P0E61D05aXI01DH5`0G6QT071lN01LL600F6aL051TE
01DJ5P0F6aL05a`H01PM6@0K81`06QlK0P0I7QX0I`0K81`04ALE01hT8`0Z<2l0D5UG01/T8P0R:bP0
51lK01`W8`0G8Qd05R<M01h[9@0M:B@08B`V020[9P0N:BD07BTV01l[:@0Q;B`09cDf020_<00S<S@0
9cHh02Dd>00T<cL08c4d01l^<@0P;c809SDj02do@`0bA4P0:S]202e0A`0cATd0:Ca302e1B00^@TT0
;T5802Xl@`0^@4L0;Cm603mAF@1AHf/0@E=L02XlAP0fB580;Sm903I7DP0eAe40=dY?04ULH01GJfd0
=4I80351@@0_?ch0;3Th02Xe<`0[=c<09c4^028[9`0T;BT09Bh/02@^;00Q;2P082/V028^:@0U<Rl0
9C<c02/i>P0fA4/0<T9:02hkA`0Y=d<0:3M302hmB@0a@Td0=DMD03A6D`0]@4h0<DAC03Q>G00aAeH0
;TAE03A:G00b@dh0=415030m@P0[>Ch0;C]002Th?P0Z>Cl0Q9>J0=?RiP1@H6L0830h02Ph@00/?4<0
;ci502hmA00]?480<3m402hk@@0`>cl00P0/=c/03P0`>S`0;3Hh02Pb=00W=3X09S@g02<]<00Z<S@0
<S/h02X`;@0V:bL08BLS028Y9@0R:bX07bTX0P0R;2d03`0S;2h09Bd_02P_<00Y<340:c4a01hS8`0N
8b807b<R01lR7`0L81`06ahK01LK6P0K7al082@T01lS8`0201hR8P0?01/O7`0L82007B4Q01dQ8@0K
7al06AdM01@H6@0R9RL05a/L01TM7P0H71h07b<V01dP9@0J7B8061/P00806A`S01h05QTP01PG7`0I
62007QdU024P:00O7bL06a/S01dM9@0I6R805QTP01LJ8@0G6b805AXP01`M8P0J6b005aPM01HG700G
61d061TN024R9`0A4QL07AhS01PI7P0P8BH0:2T]020O8`0:2P`04A4C01XJ700E5AL301@D5P804a<E
00P04Q8D018B4P0@3Ph0;B`Z010?3@0D4a4030/901@C4@D04a8@03<04a8>028Q700C4Ph04a8>00h=
2@0D4a404A0>018A3`0E4a@030X;01<A4P091`P04@h>00d9200D40l04`l>00l;2P0E4A006ADD02@P
7`0K5aH04`l>00l;2P0<20L04`l=018>2`0A3@X04@d;010<2P0@30/04@d<014=3@0@2`h03`X=00h:
300?2Ph040/<01LA4@090`<050h>00d8200S7Ad0DTa<01<=3@0<1PH04@/;00l92@0A2`/03`L80147
200B20T00P0C2@X05P0D2P/040H701882@0C2@X04@L801061`0B20T03`D401<9200D2PT040H500l5
100C2@P05@/:00T0000J40l05@/:00/30P0L4Q404@L801061`0?1@H200h41@0400d3100>10D03`D6
01061`803P@500<04@L801041P0@10H0100@10H02`0A1@L040@600l31@0?0`D040@601451`0C1Pd0
3`8900d01`0?0PT04@@;00L040<:5?ooool001_ooooo024010@400L71`0E5AD08B4Q00L71P0j>SP0
VYZH02@U8@0G61<030d800L8100D5@l02`/9020P7P0N7Q`02PX800<30P0C4a404Q8@00H6100820H0
2@T7014A3`0=3@/0X:2N02@T8P0>3P`02PX800l?3@0A4@l02PX801@D4P0F5Q@00P0B4Q001P0D5A00
414;01@E3`0;30H0414;01DF40802``600P03Pl900`=1`0@4@/0414;00/<1P0>3`X0414<00l@2`80
3Pl:00@0414<00h?2P0=3PT03@h90P0<3@P01P0=3@X03@d;00`<2P0<30X03@d;00h>30803`l=00L0
3Ph<00d=2`0>3P`03Ph<00h>2`0=3PT03Pl:00@03a0;00`02P/600`=200I6QD05aPC014B3@0?3``0
4A4?018B400>3P`02PX800d=2`0@40h200h>300A018B400C4a40410>00/<200B4`h03a0;01XK5P0=
3PT010D200/<1`0E5Q405aPC00H70P0<3@P03a0;00d<1`0=3@D00P0=30L0100>3@P040l;00h=2@0>
3@T200l>300400h=2`0=2`/030d800d>2@80414<01L03a0;00d>2@041@0061TD00`=2P0;30L04a@?
04E6@@0N7AT06APD010?2`0=30P03`h:010?2`0?3PX05QDA01LF4P0B4@d03Pd900l>2P0G5aD03Ph<
00410002014A3`04000100092P@02``600`=1`802``400<02P/300d<200=30P0100=30P2010?2`0:
00d<200>3@T04A0<00d<200=30L02PT401PG4P0/:bH09RDP00@300803Pd80P0=30L0<P0<2`H02``6
00d>2@0:2`H02``7014=2P0B3@X04@`901<>2`0B3P/040l;00`<200:30L030h901PI4`0U9R0061TC
00h?2@0?40X01@H000X;1@0M7QP030d701<D3P0;30H02PX2010=1@0@3@H03``5010=1P0>3@P03@`7
00h=200<3@P02``703dn>@0Q8ah03@d9010?2`0:2@D03`h:00h=2@0=30P04a8>00P70`0920@05QDA
01DD400@3`/03Pd90P0<2`L05`0>3@T03`h:014@300E51003@`800/:1P0B4@d081lK00X91@0B4`l0
0P@10000000F51806ADD01LA4@0C3@d04P`<00`81`0920H051@B038d<@0<2`T03@`:00803Pd;0P0=
30X00`0<2`T03@`:00h=2`0200`;2@0=00h=2`15ADD0=3@d01HF5P0;2`/03`l?014A4@0?3`l03@d=
00/;2`0>3Ph03`l?00d=3@03010>3`0900l=3P0>30d03P`=00h<3@0@3Pl04@l@00d;300:20T030X;
00L03P`?00<040hA018@4`0B41<00P0B41<00`0820X03Ph@00H6200200l?4@0K01DE5`0>3Q00410B
00l?4@0=3@l030`>00/;3@0B4AH051<H014@5@0B4AH04a8G00/:3`0@3a@03`hC014@5@0@3a@03`hC
01DD6@0720d041<G00P<3`041PX02@X<00`=3`0C4aD03@d=00804@l@00<03`d>018@4@0?3`l00`0?
3`l04`0=3@d030`<00h>3P0C4a<04Q8B00l?3`0@41004Q8B00h>3@0;2`/03Ph<01HF5@0M7A/04A4?
00l?3@0F5Q@05QLB014A3P0?3`d00P0@40h05`0;2`T061PF010@3P0A4@l08R8P02LW9@0N7Q`06a/I
01hN700B4Q004A<=00lE2`0A50/04A@<014D3@0B4`d04a@>01<D3`0C4Q004Q4?01@C4@0G4a804Q4>
00802``602D04Q<=01LH4`0F61<03Q0;00d?300?51004ADC00/?3P0`=S@0FeiL01/M600H61H06AXF
01`N6@0K6aT04A8>01DG4P0=3P/0410>02PZ9@0F5a<051HC01<E400H6QH08B<P020R7@0G6AD05QPE
018D3`0H6QH04aDB01HH4`0I6aP05QPE01@F4`0A4a004Q@A00804aDB1@0B5140100B51004aPB01@I
4P0E6Q@201<H4P0401HK5`0M8Qh06b0L01TM708061`K00T05a/J01PM6@0G71P05Q/G01LL600J7a/0
7B8N01HK5`0K81`00P0L8Ad201/P701M01HL600R:2@0=C/g06igM00R:bP03QLD01dX900L9b<08B`X
024]:`0P;2X09C4]020[9`0P:bH082/W020/:P0R;Rd092la01h/;@0U<cH08c8g028a=P0U=3/08C0g
02Le>@0T<cH08C0c024`=@0Y>cl0<49604MHG`0/?dH0:Ca302`oAP0^@TT08SLl02m1A@0iBU40:S]2
02m0A`0a@TX0RY^S061aN@0^?dT0;3e704=DGP0lC5T0:CY403E9C00bATL07S8a02m2@@0eAD@0<T4n
030l>@0X<bl0;cXd02L`:`0K9Ad08BXU02</;00S;Bh08R`[020[9`0O:bT08Rh/02Lc<`0]>ch0=T=:
03A1BP0`?4P0;Ce;03A7EP0[?Td0;3i>03Y=G00dAeH0;D1?03I9F00kDEl0?E9R03I;G00aA5D0>DUD
03M2AP0/>Sd0:cPm02ll@P0/>d00;Ca202Th?`0mCUD0:3U10080=4E=0280:CU002`k@P0]?4<0;ci4
03=2A`0`?D<0;cXn02/f>P0/=c/0<S`n030j?00_>C/0:SDk02/f>P0T;S407bLY028[:00P9R<09B/W
028X900R:bH08R`[01l[:@0Q;Bd07RPY020X:P0T;2h0:S0`02L];@0O9BD06QhM01/O7P0M8Qh0828O
0P0Q8b00200L81l082@U02DY:P0T:2T08BDV01lS900J7Ql07B4R0P0P92D02`0M8B806QhO01dQ8P0L
824082@U01XN7`0M8B<0720S01/N8`0I72405aXO00<05aXQ00l06QTQ01PG7`0G5Qh06APP01PH800E
5Ad05QHN01PJ8@0G6R405APO01DI7`0H7B<07AdU01/L8@0I6Ql00`0G61d0300b<cP061TN014B5`07
20d08R<X01HG700C4aH05ADG01LG6@0M7Al06QXL01<C5@8051@F0P0C4aD0200B4Q@04Q8B01XH600G
5Q@071/I00l>300>3@/03`h<1@0D4a401P0D4`l03@`800`;1`0C4Ph040l;01<B40803`h<00T05Q@E
00`:2`15@d@06ALH01TF5P0@30/04`l>01@@3`0@30/00P0E4A001`0L61L05Q8A010<2`0>2PT02`L6
018>300@30T00P0B3P/01@0@30T03`/:00l;2P0@30/03`/<00803PX;00D03PT=00d8200M5aL04@/;
00/51@0200@0000702<M7@0@2PX03@L700l92@0@2PX05@l?01<;2`050147200400h41@0A1`P050X;
01882@8040H701<03`D401471P0C2@P04PP701471P0E2`X03@<201/A4017?C`0:AlN00/1000l<S40
4`T:00d3100?1@H04`T:01061`0D2P/02`4200803P@500<0308300l51P0A1`P01P0@10H0300A1@L0
40@600l31@0?0`D040@601451`0B1@`040<:01442`0B1@`040<:00/01@H040<:5?ooool001_ooooo
00P051@D01HF5P0=3@d03Ph>01HF5@1hN7H0g]kL03Hg<`8030d802L03@h900/<1P0820H05QHD01hN
700I6AL03`l=00X:200<30X05aLE01`L6P0<30X04A4?010@3P0/;2X020P601DE4`0>3P`030`:01<C
4@0?3`d03Ph<00`<2P0A4@l09BDS038c;P0N7aP07b0H018C2`0A4PX04Q<;00L8000=3PH03a0800h?
1`0A4PX03a0800X;1@0@4@`00P0A4Pd02@0?40/0414<014B3@0E5Q40414<00d>2@0<3@P03Pl:00h?
2`0300`<2P0400d=2`0>3P`03`l=00h>30803@d;0P0>3P`00`0>3P/03@h900h?2P0200l@2`0<00h?
2P0=3PT030d800h?2P0B4`h03Pl:00d>2@0@40d04Q8@01<C4@0?3`d030`:0`0>3P`05P0A4@l0410>
00d=2`0>3P`05ADB01TJ5@0;30L03@h9018C3P1LGEP04Q<>00/<1`0?40/02@X500`=200=3PP03Pd8
00h>1P0=3@D03@`700h=200@3`X300l>2P803Pd;00<03@`:00`=200=3PT00P0@4@`02`0?40/03@h9
04E6@@25QX405aPC00@500082@@03Pl:01LF4P0D4`l040l;00803`h:00P03Pd900X91@0@3`/04Q4=
010?2`0>3@T03`h:00L71@803@d;00H07QhL00X;200M7QT020T300T:100;30H200d>1P0300`=1@0=
30P03@`800D03@`800/04a8>00h=2@0<2`L03`h:00`;1`0@3`X020L300D4000A40/06APC00X91002
00h=20803@`700`030/600/<1P0;30L02@X500X;1P0?2`P04@`9018:200B2`T04Ph;00h=2@0<30L2
00/=200801PI4`0[;2H0414;00/<1P0C50h01`P200l@2P000@02014B300@018C3@071`004@h6014=
100B3PD04@h7010=1P0A3PL03`h900`=1`0;30L0?Chi024R7@0=3@P04A0<00X91@802`X600T020L3
00l>2P0<2`L02PT5014@300N7AT05aHB00/:1P0>3@T00P0=30P00`0>3@T03`h:01<B3P02010?2`0A
014@300O7QX040l;010A3@072@H0:RXX04I4@P0B3Pd0100001482@0@2PX04Ph=014@3P0>3P`06A/H
00`;2@0=30X00P0>3@/200d<2P0300h=2`0?3P`040l=00803Pd;00H040l=03@d=00U9BD03`l?00/;
2`0?3`l2010@40803Ph>0P0C4a<01@0<30`040h?010>3`0@3Pl03`d>00803P`=0P0@3Pl0100?3@h0
30X;00`:2`0>30d600h<3`0;00l=400@3Q4040hA010>4@0?3A003@/>00410`0?3a402`/=00h>400?
3a400P0;2`d01`0=3@l030`>00`<3P0@41805QHH014@5@0D4aP00`0A41D03`0920d03PdB00d<4@0?
3Q<03PdB00`;400C4QL01`P=00`=4@0F5a/06a/O01XJ70051@L03`d@014?400201PD5@0300l;300:
20T03`l?00<03`l?00<03@d=00`<300<30`00P0B4Q803`0@41004A4A01@D50092PH030`:00l@2`0E
5A<071`J014A3`0B4Q00410>00l?3@0A4A004A4A014A3`0200h>300:01@D4P0?3`d00P8001DE500g
=cD09RHT02DU8`0F5Q@00P8001@F40803A<902d03Q<:00lB2`0@4@/04A8<010A300@3`d04@l=014=
300B3Pd04Q4>01PI500I6QD05QLB01<C4@0C5A805aTF010B4@0;3`h03a<C01/O801eNg/0fn3O04eB
CP0A4a804QHC01dR7P0I6aX03Q8?00P=2@0D61D03Q0?00X?2`0=3P`05ALF018D4@0C5A<06Q`K01`N
6`0F61H06A/J010B3`0D5Q@05ALF01TK600G6AL00P0E5a@0100C5A804Q@A01HH5@0O8Ah2010B3`0=
014C400B51404aDB01@F4P0K81X06QlH01DJ500A5Q004QLA01PM6@0Q9R806b0L01HJ6@0201/O7P03
01@H5`0K81`06QlK00806AhJ00D06b0L01`Q7@0D6AD06AhJ01`Q7@0201/P700G01`Q7@0O9Ql0:S4Z
02T`:@0W<2/06b@O02D^:`0K9R8082XY04E?CP15DE408bl_01dY:@0Q;2P08B`Y024[:P0Q;Bd092l`
02@_<@0S<C@09cDj024`=`0O;SD00P0S<CX0I@0W=CT0:3Lj02Lf>@0V=CX0:C/o02i0A00oD5L0<4=:
02i1B00`@dX0=DU@02a1AP0_@D@0;3i202Li?@0eAd/0<T=:04AEG00dADd0=dQB028c?@0b@dd0<T9?
03=4CP0bADP0?4i@02Xl?00a@D00<d5102Pg=00/>3D0:C@`030k=@0U;RP072<L02</9`0Z<cD09Bla
024[;00O:BP07RPY02@_;`0]>3X0<Se103E0A`0g@D/0=T1<0311C`0cB5T0;D9C0355EP0fBe`0<4EF
02m3D`0fBEP0>diM03e@G`0fBEP0<T=C03U7D@0c?T00:cHj02Hb=P0W=CP0;3To03=1B00U=3/0>DYB
03A5CP0Q<cd09cU302Xj@P0/>d80;ci50391A`0d@dP0;S]102Xe>@0Y=3P0;3Lk02`f>00Y<cD0;SPj
020[<@0U<3@09Bha01hV:00P9R@09BTW02@Z9P0R:2@08R/V02<];00O:bT08Bd]024[:P0T;B`0;38b
02hd=00Y;bl08RHU00807B4P00T0828O024S7P0R91l092HR01hR8@0Q9BH092PY024U9P0N8R<00P0L
82402`0N8R<082@U01lS900M8B806QhO01hR8`0M8B8061`M018F5`0L828041@G00806A`Q00H061/P
01LJ8@0H6b806A`S028P:`0L6RD201HD7`0;01PG8@0G5b4051@N01TK900I72D05QTR01LK900K82H0
71`T01/K8`0I6B400P0H62003@0G5al05QHN01HF7P0R8RX09RH^059BFP1;C5404a<F01PH6P0E5AL0
5aLI01HF600@41800P0D51H201<C5@08018B500B4Q805aDE014@3P0>3@/04a8@01LF50030P05018A
3`0D018A3@0F5A0051<?01PG4`0A40`040l=00`;2@0A40h05Q@E00/92P10?Sl0518C020M7@0E4A00
3`/:01<?3P0D40l05A4@00h:2@0B3Pd2010<2`0;00l;2P0;1`H04@d;010=200A3PT04Ph:010<2@0>
2PL03`/9014=300@30d00`0?2``03P0:1PH02`D501H@400F41007aTI01hH600;1@D02@<300l92@0=
1`L02@<3014;2`0B2P/04PP90P0A1`P201061`0400h41@0A1`P050X;01882@8040H700<040H50147
1P0B20L00P0B20L02@0D2PT03P@300d30P0P5QD04`T800L0000@1PD03`D600d3100200l51P0600d3
100@1PL04`T:01L=3P0D2P/03@<40P0@1PL601041P0:01451`0@10H03`<500l31@0@10H04@D700h1
200=00L03P4801032P804`H=1P0@0`XDooooo`006oooool0<@0e=CD0:2PX00/;2`0@41004a<B00h>
300X:2H04Q<?00l@2`0>3`X051D@00/<200C4a40410>00X:2@092@L03@d;010@3P071`D0:BTW038b
<00A4@l0410>014A3`0F5Q@020P700/;2@0@40h04A4?010@3P0>3P`04A4?010@3P0=3@/03`l=01<D
3`0>3`P03a0800d>1P0@4@T04A8:00h?1`0A4PX03a08010A2@0A4PX03Pl700`=1@0?40/00P0@4@`0
300>3`X03a0;010A300E5Q40414<00d>2@0<3@P03Pl:014A3P0A4@l0410>00l?3@<03Ph<0`0=3@/2
00h>300400h?2`0>3`X03Pl:00l@2`803Pl:00P030d800d>2@0=3PT03Pl:00d>2@0>3`X0410=010@
3P<03`l=0P0@40h200l?3@0@00`<2P0820H02`/900l?30092PD0414<01<D3`0>3``04a@@00L8100H
6A@04a@?00T:1@0>3`X0414;00l>2@803`h600L03P`600l=1`0@3PT04@h;010>2P0@3@X03``;0080
3P`:1P0=3PT02@0I6QD0;c0[00X;200C50l04Q<>00/<1`0<2`L02`X600d<2002010?2`0>00h=2@0<
2`L02PT500X91@0=30P03Pd900`;1`0=3@/03`l=014A3`0000004A8?00d>2@0@4@/200d>200300l@
200A4PX0414900H03@`800/02`X600h=2@0:2@D040l;01LF4P0:2@D01`H201dL5`0G5Q402`X500`;
1P0300h=20803@`700h030/600/<1P0<3@P02@X500/:1P0@30T04`/90189200D30X05A0=010<2@0>
3PX03a4<00d?2P803Pl902@03@h800h?2@0310003Pl900l@2P0720@05aPB00`=1`0A4P`04A49018>
1P0@30<05107014>1P0?30D04a0900d=1P0D50h03@h800`=2@041@803@d8014@300<2`L03@`800h=
2@0;2PH040l;014@300?3PX040l;01/J5P0F5A403Pd9010?2`0?3PX300d<200B00`;1`0?3PX05aHB
00/:1P0E51006APD04Q9A@0?4@h020P701TG5P0@2PX07aHG01<:2P0D2``04P`<014?3@0:2PP030h;
0P0>3@/300l>300C00h=2`0?3P`040l=014@3P0?3P`03Pd;014@3P0A4A4030`<00h>3P0D51@0410@
00/;2`0@41003`l?010@400C4a<04Q8B00d=3@03010>3`0600l=3P0>30d03P`=01<A4P0B41404@l@
0`0@3Pl6010>4@80518E00`04a4D018@4`0@3Q403P`?010@4P0;2`d020P:00X:300A4A<02@T;010@
4P0>3Q0200`<3P0700h>400A4A<05A@I01PG700F5AX05aHK01DD6@0300`;400A010?500?3Q<030/@
010?500>3Q<04a<H00`:3`0=31404@dA01<?4`0A3A403`X<010;300A30h040/<00h92`0?3Pl00`0?
3`l0600=3@d030`<00d=3@0?3`l0410@018B4P0C4a<04a<A00d>200A4P`0414<00d>200B4`l02PX7
01@D4P0>3Ph03@d>010@4@0F5QL061PI00l?3P0E5A<04A4?00`<2P803`l=03/05aLE00`<2P0A4@l0
5ADC00`<2`0A50h03A@:00hD2P0?50/041<<010B300D5@l04a<>018A3`0F4a804`l>01@?3`0D4Q00
4a@@00`=2@0F5QD06a/J00d?3@0@4Q806Q/L01<G6@0E6A/05a/M04iDE@2IWYl0;C8b00dB4@0A5QH0
3a@C010E5@0L8B0051TI01<H600F6a/0EEYI02X_;`0E5QL04aDE018C500D5AH05QLH01DG5`0M7Ql0
4aDE01LI6@0H6AX071dN01TK6`0A4a005ALD01XL6@0G6AH05QPE01XL6@0201@F4`0B01DG500F61D0
5QPE01LI5@0M8Q`06b4J01HL5@0@5Pl03aD?01@I5@0F6aL051TE01<H5`0G71/06QlN01PM700H7AT0
6AhJ0P0J7a/0100I7QX05a`H01HK5`0I7QX201/P700F01dR7P0P9Al07RDL028Y800H7aP04Q`D024Z
900H8A`082XY01/U9@0_>C/0<Cdn020[;P0R;C008R`/02<];00S;Bd08Rh_028]<00Q;340:SLm02@b
>P808c4k02T0938n02Xh@P0V=3P09cHi02Xi?00]?440;T1402m1A@0/?D@0>diE03U<D`0/?dH0<TI=
02i3B00Y>ch0:S`o0394A`0/?T80>T]B03U:D@0cA4`0>DYD04MHHP2P/;`0DF5^02/lAP0eAdX0@eEE
06]mO@0Z>ST09SDb02Th=@0S;b/09C0Z02Td;@0V<2P08bXR028[9P0[<cL08b`a024[;@02028/;P0O
02H`<P0^>C/0<3Y102dg?`0`>T@0<Sa802dnC`0/A5L0AUic05M/P00lDV<0=T]M03A8F@0_@U40=dUI
03I8E`0^?dh0=TME03I3C00`>S`0;3Lj02Xe>@0V<cH0:cPn02lmA00Y>3l0=DI>02dnA`0[?DL0>DaE
02doAP0203=2B@040350AP0`?d@0:CHl02/f>P80:C@h01P09c4c028/;P0W<C<0=d57034k?`0X<3<0
9BX]02<Y9`0R9R@092XV028X900S;BP09Bl^024]:`0P;Bd082TX02L_;P0]<c<0:Bl^02@Z:@0S9bH0
92PV02<W9@0R9242020R7@0=020R7P0L82007R8T01lS9@0M8B<0720R01dQ8`0Q9BL082@V01dQ8`0L
82806alQ01XN800201XN7`0701LK700O8b@06alQ018F6@0I72406ahS01XM8P0201PK8P0=01/N9@0M
6bH061HQ01DC7P0F51l061LQ01LG8@0I6B<071dW01/N9`0I72D061/T01PL9@0201PH800<01TI8@0H
620061PP01PH800I6B4051@L018B6P0D51`07alW01PI7P0F5AT05QHH0P0E5AL0100F5QP05aLI01@D
5P0D51H201<C5@08018B500B4Q805A<C01DD4P0>3@/04A0>01DD4P0G5Q@5014@3P05014@300G5Q40
4A0<01<B3P0<2`L00P0D4a400`0?3P`05Q@E00d;300201HD5@0302`Y:@0F4Q4030P700804`l>00<0
510?00d9200D40l00P0B3Pd00`0@30/030P7014=2P02010=200F010<200?2`P03`/8010<2P0A3@`0
40`<00l;2`0>2P/03`/<01@?3`080P8040X:014;2`0:10@05@l?00l92@0@2PX06Q@D01@>3P0<1PH0
4P`<018:2PD04PP900L040H701882@0C2@X04@L801061`0B20T04@L6008040H50P0A1`H0200@1PD0
5`d<01061@0?1@@030<301<9200D2PT040H70P0M4a@02@0>10D03`D600l51P0G3@h07A<D01L=3P0>
10D04@L800l51P0601041P0701451`0@10H03`<500l31@0@10H04@D700`01P020185300300l22@0D
1`h07a8I00H040<:5?ooool001_ooooo00`06ATI01LG5`0K6a/03`l?00T9200;2`T061PF00`=2@0:
2`H05QLB010A300?40/200X:200@00`<2P0>3P`03@d;00T91`0D51803Ph<00d=2`0A4@l05ADC00H6
100:2PP06QXH00P81P092@L06QXH020P7P803`l=0P0>3P`0300@40h04a@?014B300>3`T04A8<00h?
2@0<3@L03a0:010A2`0<3@L03Pl900l@2P803@h800/030d800d=2`0=3PT02`/800`<2P0=3PT030d9
00`<2P0<3@P030d900`<2P0300/;2@0400d=2`0>3P`03`l=00h>30<030`:00@03@d;00l?3@0?3``0
3Pl:0P0?40/03P0>3`X03@h900d>2@0;30L02P/6010A300G61<04a@?00h>2`0<30X02PX800d=2`0A
4@l0410>0P0D5180@@0>3P`03@d;010@3P0?3`d02``800X;1P0A4Pd01`P301PI500C50l02P/601DF
4@0?40d04a@?00H70P092PD03`h:00l>2@0?3@P03``700d<1`0?3@P04Ph;00l>2P0?30X03`/:00d;
300?30`03Ph<00d>2@0;30L02P/600/<1`0>3`X06AXE00H70P17B4<00040010A300?40/04Q4=00l>
2P0=30P030/700/:1P0920@06APD00l>2P0<2`L04A0<01<B3P0>3@T03Pd;00h>300:2PP05aHD00d=
2P051P405aHA010@2`0;30H03@`700h>1`0<2`H03@`700D03@`800`040l;00T8100920@071/G02PW
8`0>3@T030/6018A30071P401@@000l>2@0;2PD200h=20803@`70P0<2`H08@0=3PT02``700`;1`0B
3@X05@d;01@<2P0P61H07QTF01DA3P0=3@T02``700L80`0?40X01@H000l@2P0S91h02``600h?2@0:
2`L05AH@00<4000C50h01PL100X9100A3PH040/501<@1`0A3PL03``501<@2@0=3@D06APC00P81@02
014B3@0300T91@0A40`03@`8008030/700P01`H200d<200;2PH03@`8018A3@061@402@P4014@3080
3Pd901L03@`800h=2@0?3PX03@`800T8100=30P030/701HE4@071P803Ph;010@3P061P@03``;018<
300;1@D060l@00h8200;1`H03@d;00X<2@0;3@X03@d;00l>3002010?3@803`h<00<03@`:00h=2`0?
3P`00P0=30X01`0?3P`03`l?00/;2`0@41005ADE01<C4`0G5aL00P0@4100100>3Ph030`<00`<300>
3Ph3010>3`0400l=3P0>30d03P`=00h<3@803@/<0P0>30d00`0<2P/03@/<00d;300400d;3P1A00h<
3`0?3A003`d@00h<3`0>30d030X;00@41P0?3a4061PJ00X:300;2@`03@/>00T72P0;2@`040hA01DC
5P0H5QT05aDH018@5@0E51T04a8G01@C600C4QL02PT>00/:3`0=31404a8G014@5@0=31403`hC00h=
4P0>31400P0301XH700:1@T04@`@018=4@0A3@h040`=01@>400B30h03@T:00l>3P0?3`l03`l=00l?
3P0=3@d030`:010@3`0;2`/03@d;01<C4P0C4a<04A4?018A300A40/040l:00h>2@0G5Q803Pl:018B
400E5AD04Q8B010@4P0H61X0820R018B3`051@<020T400l?300A4@l061PE03Lh<`1:BTP03a0<0001
000D5180310:00lE2`0?50d041@=00804A@=02X04aD?010A300@3`d051<A00h=2`0A3@`04a<@028S
7P0K6aT0410>00X:200:30/051HE01/M700=4A003Q8B01HJ6@0>4Q<08RLU00P>300@51<04aPF01<I
5`0E6AP0;S<a00hD4P0O92800`L601lU8`0F6QT051HE01DG5P0G6AP051HE01<E500E5aH04aDD010B
4@0F61L03a4@010B4@0D5QD201PJ5`0<01LI5P0F61L051HE01<E500F61L05QPE01DG500D5Q404aD@
014E3`0=4P/03aL<0P0C6Q803`0C6Q<051XE018H500H7QX06b4O01<I5`0D6QP07B<Q01@H5`0H71/0
720O01dQ800J7a/05adI01TN6P0201XP700N01/Q7@0O9R0092/T01TS6`0]=bl03aPC02Tb;@0G8Ad0
8bhZ01/U900N:2P05b4S01/V:00X<cL08bhb020Z;00R;2h09C0b02Lb=P0Y=CX0:3Dk034nAP0S<CT0
9cQ002Pi@`0O;c/09SM102He>@0O<C<08C<e0P0V>3`08P0U=c/0;3e402Lj@@0Y?4<0<TE<03e@E`0`
@dT0;Sm00391A00Z>C`0<D1302Th?@0W=S/0?4]B03=2B@0`?TL0MXB=02@b>`0a@4L09CDe03=1@@2l
b/X0EFAQ02Hb<00M:BD09C0[024/9P0R;2@0:38[02<Z8`0G7AT08BT]01hX:P0S;Bl202Pb<`0X02Tc
=@0b?D40=3m502di@P0_>dL0<3a:02a0D00V?e<0Dfb006AlS`0^AEL0;T=D02m3E00U>4L0?U1N04=D
HP0a@Dh0=dMD02/h?P0V<S809c<c02/f>@0S<C@08Bhd02Dc>`0gADh0CUmW03i@FP0Q<cd0<dE?0312
B@0d@dX0<3m602/j?`0_?T<0;Sa002hi?@0W<SH09C0c02`f>080:cDg00X0JgEg04aDE`0R:Rd08BHY
02T_;`0Z;Rh092XX028X9P0T;BX09Bl^0P0Q;B/05P0O:2L0:2h^02dc<`0S:BL07R@R02DY:00P92<0
7b@P020R800N81d07b4N024R8@0S9bP08bLZ024U:00M8B@0720S01lS9P0T:2/082@W01XN8@0H71l2
01TM800K01`P8@0F6Q/08RHW03Lk?00E6A/061`O01@H6`0G6al05QTN01@G700E61d06a`Q01HG700H
5ah07A`T020N:@0P7b/071`X01PH900H6R@06A`U01XM900J7B<061/P01@D700F5Qh05aLO008061PP
00d05QTP018B6P0L72@06ATQ01@E6P0<3A8051<I01HE6@0B4Q@05ADG018B500?3a405ADG008051@F
0P0C4aD2018B5006018A400J6AL040l=01/J600C4Q0030/91P0B4@l08@0A40`04a8>01TH500?3P`0
40l=00d<2P0B4@l030X;01<A4P040`<04a4B024M7@0A3@`03@T801@@3`0>2PT040`;00l;2P0F4Q40
4@d<010<2`0?2`X03@T801@@3P0A3@X03`/800d91P0>2PL03`/:010<2`0>2PT03@T800`8200200`8
2@0J00l:2P0G4A403@@500/51@0C3@d03`H701092@0<1PH05@`=01092@0=1`L050/<0107200A20T0
4PT:01<92P0C2P/050X;01882@0A20T04@L800h41@0>1@H04`T:0147200@1PD300l5100;00d30P0B
20L02`4001<9200?1@@03P@301471P0700007aDF024G600:00400P0@1PL01P0700003@<400`30`08
00004@L801882@H040@600`04@D701041P0?0`D03`<501041P0A1@T02P02020C6P0X6b806`hE00d1
1`0=00L601032QCooooo000Kooooo`0300h>300?3`d03`l=00<03`l=01800P8001HF500A4@l0410>
01DE4`0=3@/03`l=00`<2P0820H02@T700l?3@0@40h03@d;010@3P0=3@/05ADC00<30@0A4@l200h>
30803`l=00@03Ph<00d=2`0A4@l03`l=0`0>3P`02@0?3`d03a4<00`>2@0=3`X02`d800X<1`0>40/0
51HA00h@2`0200/=200h014C3P0M7A/05QDC00/92P081`D04a4A01<C4`0;2`T02`/:01PJ6@031@80
4A<A0001000>40d030h;00h@3@0=3``03a4>018D4@0D5Q<0418?00d?300;3@X030h;00/=2P0@4Pl0
2`d:00L91P0@4Pl03a4>00d?300?4@h04A<@01LI5P0H6QL02`d:00T;200=3``020X700h@3@0C5A80
1`T601DG501VJ6D02P`9010B3`092`P061XG0043000:2`L03a0:00d>200:2`D02``601LH4P0?40X2
00d>20804A8<00l030d701LG5`0000004a8B00/:200<3@P030`9018A3@020`004a<A0040000;2`d0
3`hA00d=2`0;2`T00`0=3@/03`0G5aD02`/901`L6P0I6AL0410>00h>300820L03a0;00`=200H6A@0
1PL2020Q700I6QD03@h900`=200200/<1`0C00`=200>3@T04Q4=01<@3@0C4Ph040`900P60P0;2PH0
3PX700X71@0<2`L04@d:014>2P0A40/051<>00/<1`0<3@L0414;00P90`0500X;1@0;00/<1P0=3PP0
2PT400`;1P0:2@@04A0;01TH4`0>3@P08b8M00l>2@0;2PD00P0@3`X0400<2`H03@`700/:1@0;2PD0
3`d800l<1`0=2PD08b0K01hK5P0C4Pd051<>00T80`0E50l03@`700l>2@0=30L200h=200j00/:1@0=
30L02`X500/:1@0=30L03`h9010?2P0B4@/0104000/;0`0?3PT04A0;00T80`0>3@P03`h900h=200?
3PT03Pd800`;1P0:2@D040l;00/:1P0920@051<?01<B3P0H5a<06aXF01<B3P0A40`04Q4=00l>2P0;
2PH03Pd901LF4P0@3`/02`X600h=2@0@3`/03Pd900d<200C4Ph04Q4=00`;200:20T02@L800h<3@0F
51D040h?00P61`0C4A802@T900P92@0P8R4030h=00/;2@0>3@/02`X801<B40803Pd;00H02`X8018A
3`0@3`d02@P600d<2P0@3`d200/:200@00h=2`0@3`d04Q4?01<B400E51802PT700h=2`0A40h051<A
04i=B`0@3`d03`h<010?3@0=30X02`X801<B40<040l=01L03`h<00h=2`0>3@/02@T700d=2`0>3Ph0
3Ph@00l?4P0B4AH03PdB00/;3P0>3Q003Ph>00`<2P0@40h02PX:00l>3`0A3a0040h?018>3`0D4140
5a4C01TB500201XA500901`C5P0O5Q/030L=01dK800C4AH020H;00d;400B41D0518G00804a4F00L0
3`dB00/93P0B41D02`T<00d;3P0?3@h04@lA00804Q0A02/03`d>014?400A3a00510A018>3`0<2P/0
3@h:018B40041@003a0<00X:200<3@P0410=00L71@0:2`H05ADB01DE4`0A40`03PX701HB3`0G4a00
3P/9010<2`0G5Q@040l=018A3`0C4Q004Q8B00l?3`0>3P`03Pl900l@2`0?40X03@h900h?2P0?40/0
5aPB01PI500@4@`05AH@01<D3`092`D03Q4:00802`d800d02P`701XL5`0U9b805QPC00T:1@0A4Pd0
6AXE01DF4@0B50h05QTB01PK500E61404aH?00804QD>0P0A50d03`0C5Q0051L@018D3`0A50l04AH@
00lA300K7aT0<cPb02la;00J7QP05Q/E01DH4`0A4`h03Q<=01<E400401@F4@0301HH4`0G6A@06adH
00805ALB00H061XE01LI500I6aH041DA014F4P0A5A@200hB4`09014E5P0C5aP06alN00X?2P0C6140
3Q@:01HL400D6Ph05A/?00805adC0P0G71D01P0D6A<06AhH01LL600E6AP06QhM01HJ6@@06b4Q07P0
6b4O01TR7`0D6QH072DO01`V7P0G8AT05B0G01/V800X<S@0624V02dg>@0F828072LX024]:`0M:BL0
8Bd[01DQ8@0L:2P08Rd_02Ha=@0R;3D09c4j01PU;@0X=Cd09cDm01h]=00V=ch08c@k024d>P0S=S`0
8SHl01db=`0W>cd0:Ca002@g>`0U>3`0;D1602i1A`0U>3h0:3U103m@F00jBe<0V:Va05ASJP0gADH0
:CLh02/i>P0gADH0>TQ90390@@13DE80=dE602Pf>@0Y=cX0;ce002`h>00]>3<0:S<^06I_JP15CTT0
9RlZ02</9`0R:bH08b`W02L]:@0[<Bh0:Bl[02L]:`0R:b/06b<U028[:P15Cdh0C5QF03I1@P0b@4<0
;3]002lmAP0`?T/0<D5>03E9E`0[@U80>e9R03I=G00W?T`0>DmM0315DP0V>DL0>dmJ045DH00bA4h0
<D==02Xj?@0]>CD0:3@b02Hd=00V<cT08c0h02Xh@@0`?TT0;Sm902dnB00Z>dD0<T==03I6CP0^?D80
=TE:02ln@`0[>Sd0;C/n02Td>00Z=CL0:cHg02Tc=00X<S<0:S@e02L`;@0]<c409R`/02DZ;@0N8bH2
02@Y;@0602H[;P0T:R/08b`[02Pa;P0V;bX08RPX0P0S9bP0300R9RL08BDV024U9P0^<S<08bLV01XN
7P0h?3/08bLV02<V9P0F6Qd08bLZ01XN8@80720S00X092P[01`P8`0K7b8082@W01hR9@0G6ah06alR
01XK7@0G61X0824S0P0I6Q`0:`0K71h04Q<E028S9P0H6Ad06AXN01XK7`0L7Al06Q`K01PJ6P0H6Ah0
5QHN01dM:P0^;C/05A@R01HF8`0G5al05AHK01HH600H6A/07QdR018A600X9bl07AdW04Q:D`0K7bP0
4aHO01<D700D5AX061LL01LG6@0F5QP061LL01LF6`0I61d051<H018A5P0F5AX04A0E00X93P0A41D0
5QDJ018A5P0H61X00P0E5AD01`0C4a<04Q8B01DE5@0G5aL03@d=01@D500=3@d00P0C4a<0400E5AD0
5QHD00`<2P0F5Q@04A4A00T7200A3a0040h?018>3`0D41404@d>010<3@0D41404@d>00l;300@30d2
018>3`0701<?400;1`P03@T:014=3P0F4Q<06QHG018>3P02014=300R010<2`0?2`X03`/<00h:2`0?
2``03PX;00X61`0>2P/04Ph?01D>3`0A2@L05P`;01891`0@20H060h=01<:200A2@L0718A00/20@0A
2@L07A<B00d51P0@2P`04@T<01482`0>20X03`P:00X1100:10H040T;00L00@0C3@l04@X;01472080
40H700@03`D600h41@0>10D03`D60P0=0`@00`0A1`P04PP900h41@0301061`0;00l51P0>10D03P@5
01<92P0700005@d=0147200@1PL02`8300l4200=0PH00P0?10P01@0<0@D040D900/0100=0PH040D9
00804@H:00d040D900h31`0:00<03P<701052@0A1PX04PL;00/0100<0@D02`0400h31`0@1@T02@02
01Cooooo000Kooooo`0>00l?3@0A4@l04a<A018B400?3`d03@d;01HF500=3@/0:2PV00d=2`0B4Q00
51@B00h>300?3`d3010@3P0700d=2`0<30X03`l=00X:200B4Q001@D3014A3`0200h>30803`l=00@0
3Ph<00d=2`0A4@l03`l=0`0>3P`06@0?3`d03Q0=00`>2`0?4@h0418?00h@3@0?4@h06A/H014C400F
61D02P`9014C400?3`d04a0A010>3`0A3a0030X;00/;2`0@41003@d=00T:2@0>40l02@/:01DI600;
3@/00P0A4a000`0>40d02`d:00/=2P0300`>2`0300lA3P0@4Pl03Q0=00803Q0=03<030h;00X<2@0;
3@X03Q0=00lA3P0>40d0418?014C400<3P/03a4>01TK600A4a002P`900lA3P0A4a003Q0=01DG5008
2PL03@l=014C400:30T051HC00h?300:2`D0414<00X;1P0<3@P04Q<=00d>2@0<3@P03Pl9018C3@0C
50h0414<00T92`0D4aP051@E010@400<30X051D@014B3@051P403@d;0410@P0@418051@G010@400>
3P`03`l=00d=2`0:2PP00P0@40h02`0F5Q@0410>00L71@0A4@l03`l=01DF4@0720<04Q<>00T:1@0Z
:bH0>c`g00803@h90P0<3@P200d>2@0E00`;1`0>30P04a4=01<@3@0A3P/05Q<@00`:1`0@3P/04@l;
00l=2@0=2`L02`X600T:100M7QP02P/800h?300@4@`0LgA^01`M5`0B4`d03a0:00805QLA00X030d7
00h=200=30L03Pd800l>2@0=30L02`X500h=200920<02PT40P0?3PT200d<1`06010?2P0?3PT040l:
01TH4`0P7aX03@`70P0?3PT0200=30L03Pd800l>2@0@3`X03`h900X91@0=30L040l:0P0?3PT00`0=
30L030/600d<1`0200h=200Q00l>2P0;2PD03Pd800/:1@0?3PT04A0;00h=200?3PT030/600/:1@0=
30L03Pd801<B3P0T8al07ahJ00d<200;2PH02@P501@C3`0F5A4040l;00h=2@0?3PX03@`800T8100;
2PH04Q4=00l>2P0<2`L03@`800l>2P0<2`L02PT500803Pd901P02`T7010<3@0>30d03`d>01@B4`0@
41003Ph>01`L701/KVd0?T0o02HX9`0C5QD0410>014@3P0>3@/04Q4?01<B400A40h02`X800l>300>
3@/030/900l>300>3@/600d<2P0<00l>300>3@/03@`:00`;2@0A40h07QdK01DD4P0?3P`04Q4?01/J
600G5Q@030/90P0B4@l2014@3P8040l=00l03Pl:018B3`0B4Q00410B00d<400;2Pl03PdB00`;3`0@
41004A4A00d>2P0@4@`04A4A00h>3P0?3Pl00P0E4Q<04`0C3Q0071LH028K7@0N51P05P`?01<9300H
3a8040/?01lM8@0K6Ad04a4E014?4`0:20`02`T=00`:3P0@3Q803`dA00d;3`0B41<0100@3Pl01@0>
30d03@/<00d;300E4a@0518C00803P`=01<04@l@00d=2P0I6AH03a0<00d=2P0=3PX0414=00h?2`0@
4@d03`l<00h>2`0A4Ph05QDB01TD500B30`050h>01DA400D40l05Q8A00<040l=0`0?3`d00`0@4@`0
4Q<=014B3002010A2`0?00h?2@0A4Pd04a@?010A2`0G61805QLB014C3@0A4`h02`d8014C3`0<3PT0
5ALB02`^:@0K7AP0418=00804aD@00D03Q0;00hA2P0B5@`051L>018E3003014D2`803a8900`04A@;
01<F3@0B5@`041<;01@F400C5@l0418<01LI4`0D5Q003Q0:018E3`0D5Q02018E3`0301@G4@0C5Q00
4aD?00804aD?024051H@01DH4P0G6A<06adG01TK5@0C5@l051LA01<F400C61805AXE01HK6@0B5QL0
4ADG01HJ7@0@51D06QhM014F4@0K81P04QP=01@J3@0G7A005adB01HL4P0F6a<05Q`C01LL5@0F6aD0
61dG01@I500C61D06b0M01dQ800I7al00P0K82<0N@0K8B406R4P01LP7@0F81/05b4K01TT700L:1l0
7BXP01/W8`0<61h08Rdg01dY;`0Q;C<082d^04EBDP0S<Bh072TW028`;@0Q;Rh082`]02@a=00T;cP0
;SY402Tf?`0[>D8093<k02/l@`0U=Sd08C<i020c=`0R=cT09cdn02Pn@00V>cd0:3e002@i?00T>3`0
:3]002Lj?`0/?d@0:3To02Xk@@1PL7L0a]?F07n<T@0f@D80DeiN034l?00T;bh09c8b04A?CP0f@D00
:SDe02@_;`0T;bh09c8b02Td<@0]=Bd09B`U02he;P0]=2d0:S0/02L]:@0R:2@07bDS020V900V;2X0
:S0^02/a;`0Q:RT092d[02@^:`0X<bl09S8`02Hc<P0^?D00=dI;03a=EP0eAE80=4ID03U=F`0]A580
?UES03U@G@0gCUX0;dEA03U>F@0aAE00<dMA0313C@0[?DL0<D==02lo@P0a?CT0:STf02Hd=@0W=3X0
:3Ln02/i@`0]>dH0;cm<0351C@0[?4H0;3e603A4B`0gAT/0;Se204MFFP14DeH0:SPk02Lb=00Z=CL0
;SXj02`f=`0X<S<09Bl_024W900U:bL0;38a034f>@0Z;c<00P0V:c401P0X;C<09R/^02D[:`0W;B/0
8RPT02<W9P808bLX03L08RHW024U9P0Q9BH08BDV020T9@0V:R/0?D5202HZ:`0K7b007b<U01`P8P0N
8R@05a/M02HZ;00J7R007R8T01`P8P0N8R@06alQ01PL7P0L82806Q/M01hO8@0J6ad092DW024R900J
6ad07QlQ01/L7P0H6A/06Q/M01LH6P0Y:bX06Q`I01LH600H6Ad06ATQ020P;@0];3`071/[01PH9@0N
7RH05QLK01/M700F61H0518G01dK8`0L6b<0:BTc06a`NP0O8bh03a<L01DI7`0I6Qh05aHJ00805Q@E
00D05aHK01PG700J6Ah05QDJ018A5P0201HE6P0:01PG700<2a003`hC01PG700@41804Q8C018B4P0@
41003Ph>010@40804a<C00D03@d=01@D500@41003@d=010@400201@D500300h>3P0;2`/04@l@0080
4Q0A00D04`l@010<3@0C3a0050h@014<3@02014=3P09018>3`0C3a004@d>010<3@0A3@h06QHG01DA
4P0>2P/04`l@00<04@d>00@040`=00l;300?2``03PX;0P0?2``01@0A3@h05a<D01DA4P0B2``03`D5
00804`T900X04PP801H<300C2@T03@<300P0000D2PX04PX900l51@0D2`d03PP:0`0=1`T01`0>20X0
4@/=010:300>20X030H800l92`0a:bd00P0@1PL01@0?1@H040H701061`0@1PL050X;00804PP90P0D
2P/401061`0;00l51P0>10D03P@501061`0Q5aP0<BLX00T10@0=0`@04PT901052@0>0`L00P0@1@T0
100?10P05@X>01@93@0A1PX200d21P0>00h31`0?10P04@H:01<8300B1`/02@0201<8300<0@D03`@8
01<8300>0`L02P0300l4200A1PXDooooo`006oooool2018B40804A4?00P0410>00h>300<30X051@B
00l?3@0;2`T0;Rh/00X:20802`/90P0>3P`0200<30X0410>00h>300B4Q002@T700l?3@0:2PP0410>
0P0>3P`200l?3@0300h>300=3@/0410>00803Ph<00<03@d;00h>300>3P`00P0?4@h06@0@4Pl030h;
010B3`0H6QL0KFm/05YLF@0R92404A<@01@F4`0A4@l0514B01HD5@0@3Pl0518C01@D500;2`/04Q8B
028T8`0P8R401@L600/?3P0<3`d02`d:00h@3@0A4a000P0<3P/01`0=3``02`d:00/=2P0@4Pl04A<@
010B3`0=3``00P0?4@h00`0;3@X04A<@018D4@0400d?300700`>2`0A4a004A<@01DG500H6QL030h;
00/=2P0200h@3@0>01`N6`0620D04aDB0002000A4a004A<?00H70P0A4Pd01@H1010A300=3PT030d8
00/<1`0=3PT200h?2P0Q00h?2`0Z:R`0BTU>01XJ6`0H61P02`/900`=200G61<03@h900/;2@1;Bdd0
3@d?00l?4P0;2`/02@T700`<2P0?3`d030`:00l?3@0;2`T04A4?01@D4P030`403Ph<01lO7@0];RT0
0`@000@50P0F5a807AhI01<D3`0>3`X03@h9008030d801L03@h900h?2P0=3PT03@d8010A300A40`0
3Ph9010A300J6AD03`l;00T:1@0@3`/04a<?00P9100310003@h8014B300U9R003a0:02@U7`0I6Q@0
30d700X;1@02018C3@0:00H70@0=30L030/6014@2`0@3`X02`X5010?2P0:2@@03@`700h=20<03@`7
00d030/600l>2@0=30L030/6018A300H5a803Pd8018A300G5Q403@`701DD3`0:2@@01PD1008030/6
00H040l:00l>2@0;2PD03`h900h=200=30L300`;1P0401<B3@061@001PD0010?2P802`X500P030/6
01@C3P0E50l02`X500T80`0<2`L02@P400d<20802PT500D05A@@014@300?3PX04A0<00h=2@0200`;
1`0:00h=2@0<2`L030/7010?2`0B4@d04A0<010?2`0A40`040l;00`;1`803Pd9010030T8018>3`0B
41403P`=00d;300<30`0410@01@D501JG5/0?Cln020R8@031PD05QHD00l>30081`D01@@20P0;2PP0
1P0?3P`03Pd;00h=2`0B4@l04a8@00h=2`803@`:00X03`h<014@3P0B4@l04a8@00l>300>3@/02`X8
00d<2P0@3`d04A0>0P0:2@L0100A40h04a8@00d<2P0<2`T2014@3P8040l=0P0?3P`0200>3`X03a0<
00d=2`0;2`d02`/>00d<4@0>3A802PT=0P0<30`06P0;30P0414<01<C4`0A4A40410@018B4P0C4A80
4Q0A01HB4`0J5QL06A<E01<=3`0D30l0618D01PC5`0F51L03`d@018@4`0P7R408b4T00/9300<2Pd0
4Q0C01<A500A3a80518E0P0A3a00100@3Pl03`d>00`:2`0;2@X300l=3P1400`:2`0?3@h05A<D010@
3`0G5aL01@D301LG5P0>3Ph02PX800h>3@0C4a<04A4?00d=300C4a<06QTG02TT900F41004`d=010<
2`0<20L02`L6014@3P0=3@/030`:00d=2`0?3`d0410>010A3@0B4Q004A8=010@3@0@40h0410=014B
3@0A4@l03Pl;018C3P0B4Q003Pl:01<E40072@@051HA04A6@@0T9R402`d800X<1`0;3@P04Q@?014C
3P0B50l051LA01<F3@0B5@`04A@;00`?1P0>4@P04aH=018E300@4`X04A@;018E300A50/03Q4;01@F
4@0F61<04aD@01LI500J71L201DG4P0501HH4`0D5Q404A<>010B3@0D5Q40100C5A006@0D5Q405ALB
02<U800Q8ah05ALB01XL5`0H6QD03a@>01<H4P0E6QD03a<B00hB4`0E6AX05QXK01hR8`0?51405a`F
010E3P0E6a406QlH01TN5`0E6Q<051TC01DJ4`0H7AH00P0G71H201DJ501o01XO6P0L8Ad06b4Q01dR
9@0O92L07bDU01dU8`0J8b00:cHb01`W8@0G8Q`07R/R020]900G8b406RL]02Ld?02V/kT0?Ta?01/Y
:P16E5@0<T4n020_;00Q<2d072XZ024_;`0L:Rd0:CHn028_>00Y=Sl0;3Y3028a>@0T=C`08c@k024d
>00P<cL083Df02<h>@0T>CX093Tl02Pm@00U>Sd09cXn02Pk?`0T=c/0:ce002<e=`0jC4h0;C`o0350
@`0`?Sl0=T0n04QBD@0[=S809C0]02Xd<`0d?c/0;3Hd020Z:@0S;RX08B/Y020Z:@0X<Bh09RlW01lV
7`0R:B809RdV01`R7P0/<Rh0:Bl[02H/:P0W;B/0;38`030f=00a=cD092d/01XS800S;BT082/W01HR
800U<S40;3`l03Q7BP0nCeL0=4E?02m1C`0fBUP0;TEC03mFI00mE640Bf5^02i4C`0jCeX0=DUD03A8
D@0fBE<0<D==02doB@0[>ch0;c/i02dk>`0Y=cT0:3Dk02`k@P0b@4X0<Cm:02`lB@0X>D<09SM102Xk
@`0W=ch06RT^03=2A`0jBDd0;Se0028`<`0Y=3H0:cHh02di>@0Y<c@09Bl`028/;00`=S@0:2h/02/`
<P0Y;S80:2da02/`=P0202T^=00402<X;00Q9RT092XZ024W9@<08bLX04408RHW024U9P0Q9BH09RX[
01lS900I7Ah0720Q01LK700O8b@07B4R01HJ6`0Y;Bh061`M02hb<`0J7Ql07R8S01dQ8P0K7b006AdN
01PL7@0L82407b0R02//;P0A4Q@092DW01dN800F5aT06Q/M01dN800J6ad07AhP01<D5P0J6ad07b4P
01LI6@0G61d06ATQ01XJ9`0O7Rh0:2Lg01hN:`0V9Rh05aPM01hO800B51<08AlT01<A6@0N7RH05APQ
01<G8@0:3QT03a<L01DI7`0J7R407AdP01/I6P0I5aP05QDJ01LF6`0K6Ql05QDJ018A5P0E51T04a8G
020O900201<B5`0V01hM8P0C4aD05QHG01DE5@0C4a<0410@018B4P0D51@05aLG01XJ6P0;2`/06a/K
01lO7`0C4a<030`<014A4@0@41003`l?010>3`0=2``04Q0A01<?400<20T05a<D01/E5`0?2P/040`=
014=3P0E4A80510A014=3P0@30d05Q8C02DQ8P0N6Q/040`=01@@4@0B3Pl2014=3P0Q010<3@0?2``0
3`/<00`82@0=2@X03`/<00h:2`0A3@h03`/<01492`0?1@H04PP901@:2`0E2``05`d>0147200@1PL0
8ALH01H>3P0=0`@05`d>00/51P0?2@/03PP:00l92`0@2P`04`d?01@>400<1PP04`h?00@0000B30h0
3PP:00803P@500@03`D601061`0A1`P04@L80P0C2@X201882@0301061`0>10D040H7008040H700`0
3`D600h41@0>10D05@/<00L0000;0@8050X;01P>3`0<0P<03`@800d21P0>0`L200l4200501L<400E
2Ph04PL;00h31`0<0@D00P0=0PH02P0B1`/02`8401@93@0700004`P<00/0100=0PH04@H:00d21P0<
0@D201052ACooooo000Kooooo`0H01@D4P0A4@l03Ph<00d=2`0?3`d04A4?00D50`0H61H02@T701LG
5@0J6QP051@B00X:200@40h06ATG01DE4`071`D01@D300L71@0>3P`01PH400l?3@0B4Q004a<A0P0>
3P`200l?3@0400h>300=3@/0410>00h>30<03@d;02803Ph<00d?300B51404A<@00`>2`0J71T0:R`Y
0=SIe`2e]k@0=SPe01LI5P072@H02PX8024N7`0n?3d081hO00X82@0C4a<03`l?00L71`092`X01PP7
03Dg=P0830/030l=00D710092`P03a4>00X<2@092`P03a4>00h@3@0<3P/03@l<100?4@h200h@3@05
014C400>40d02P`900h@3@0?4@h00`0>40d02P092`P051HC01/M6P0<3P/02`d:018D4@0;3@X030h;
00d?30041P<200T;200601LH500?40/03a0;00@5000B4`h061TD0`0@4@`05`0>3`X03@h900h?2`0U
9BL0B4M<00l?400?3`l01@D3014B3@0B4`h02P/600P81P0K6ad01`L900X:3@0=3@d02PX800`<2P0?
3`d03@d;00h>300?3`d02`/9008030`:00P05ADC02/[:@1CE4l071dH00T:1@0?40/03@h900P91080
3Pl:0P0<3@P200h?2P0H00l@2`0;30L03@l:00h?2P0:2`H02P`70001000=3P/02`d800/<1`0?4@`0
3a0;00`=1`0?40X02``60001000:2`L030d700h?2@0:2`D02@X400`=1`0=3PP02P/50P0;2PD02P0?
3PT03Pd800/:1@0?3PT03Pd800l>2@0=30L02`X500d<1`0?3PT300`;1P0?00d<1`0<2`H02PT400`;
1P0?3PT051<>00X9100A40/010<001HE400E50l040l:00l>2@0>3@P02PT400<03Pd800L03@`700`;
1P0;2PD02PT4010?2P0A40/05QD@00800P4000T020L200`;1P0A40/030/600h=200B4@d02@P400h=
2@0B4@d00P0A40`01`0<2`L03`h:00l>2P0?3PX030/700d<200?3PX00P0=30P0100?3PX04Q4=018A
3@0@3`/2014@300H00`;1`0>3@T03`h:01@B400P71d07Q`M018@4@0;2@X02@T900H61P0@41002`d<
00X<2`051`H02`h=00l?3@0A40h081lM010?3@0=30X05QDC010?3@0<2`T03@`:0P0B4@l0400?3P`0
3Pd;00h=2`0@3`d04A0>018A3`0C4Q0040l=00X91`0?3P`04A0>00X91`0A40h06APF00l>300;2PP2
010?3@0400h=2`0?3P`03`h<00l>30803Pd;00T03@`:00h?2P0=3PX02`/900X:300A41@061LL01<B
5`0<2`l00P0:2PX06`0=3PX05AHA00`>3@0B51<051HE018D4`0G5aL07alO018@4@0@3Pl04Ph?01DA
4P0H4a@05a<D02DS9P0G5AP01`D800H41`0?3A004@lB00d;3P0:20/03P`?00l=400<2Pd03@/>00l=
3P03010>3`803P`=0P0;2@X04P0C4A805A<D00d;300;2@X04A4A014A4`0820P04a<D00L72@0H61P0
3`l@00l?4@0@41004Q8C01HF600J61T06QHE014=308040`;02004Q4?01PG5@0A40h03@d;00`<2P0=
3@/03Q0=00lA3P0?3`d04A4A010@3P0?3`h03`l?010@3`0@40h0410@00l?3P0A4@l04Q8B01<D4@0B
50l051HA00d?2P0H6QD020X501@F4@0A4`h04aD@01DG4P0@4Pd03a4<018D3P803A0900<03a8;00/>
1`0>4@X00P0G6Q<03P0C5Pl04QD>014D3@0@4``04aD?01HH4`0D5Q404Q@?01@F4@0C5A004Q@?01HH
4`0H6QD05QPC0P0C5A000`0F61<05ALB01DG4P0201@F4@0B01DG4P0=3`X06adH01/M600@4Pd05QPC
01DG4P0>4``04AH?01<H4P0?51003Q8A01DI6@0C5aP07R8S01<G5@0N8al05a`F0P0J7aT01@0H7AL0
5Q/E01DJ5P0F6aD06AhH008061dG0P0I7QL01@0H7AH05a`H01/Q8@0M8RD07R<V00807BHU01/06b@Q
03Q3?`0S;bT06BHO024^9`0V<b`07RXX02Hc>@0P;CH0IG9h01DS9P0T<S<06BLW02Lf<`0R<Bl07bd]
028`<@0[>C/08Bhd02Tf?P0S<3T0:cU202Th?`0S<cX0:3U001la=@0R=3P00P0T>3T0C`0S=cP08CHi
02<f?00X>d409cY002`n@P0/?T00:3Xl02`l?@0c@d<0;Shn02hl?00hATH0>TU603<m>00/=C80:C8]
02H_:`0_>3D072DP02Xc;`0Q:RL09BhY028[9`0N9b@092dX02<]900[=Bd09BlW02Tc:`0X<B`06R<N
02D^:@0T;BX09Bh[02Pa;P0W<2d09Rl/02</:@0L9B808B/X020[9`0S;b/0=45002Ph>00/>ch0=4E<
0393C@0`@U00<dQE02i6DP0jD5d0>4iK04AJI`0^@Td0<dMA03=7D00dAU00>deF03A7CP0Z>d<0:3Hj
02Xf=00[>CT0:cTk02Xg?@0/>d80<3i8034oBP0^?dT0:ca602hoA`0b@d/0=4A;03]:C`0c@TL09cHj
03I5B00S<C@00P0/=cT0400Z=SH09Bl`028/;@0T;Rl09bd]01`R8P0U:R`08BHZ02H[<@0a=S`0:Rle
02P]<`0P9BX07R<V02@Z:P0V;2`302<W:00>028V9`0Q9BH08BDV020T9@0O8b@09RX[028V9`0P92D0
720Q01/O800M8B80<CDf01`P8@0Y;Bh201dQ8P1?01hR8`0J7Ql061`M01TM7P0K7b007AhP02`];`0?
418071dO01TJ700K71h04a@F024R900D5AL06AXL01dN800H6A/07AlN01HG600F5a`05aLO01PG900K
6RP08b8`01XJ9`0O7bL05aPM01hO800F5aT040hC028P9`0C4a/03A0I01`O:@0G6bH051PQ01@H7P0G
6ah07AdP01XH6@0E4a@05QDJ01LF6`0J6Ah05QDJ01<B5`0G5Q/03@`A01HE6P0B4AH04A0E01<B5`0C
4aD04a<D018B4P0@41003Ph>010@400B4Q80410@01HF5P0J6QX030`<00l?3`0N7Qh061PH00`<300C
4a<04Q8B00/92P0?3@h04@l@01<?400=2@X06QHG01lI6`0B3@h04@d>018>3`0201DA4P03014=3P0@
30d04`l@00807a/L00<05A4B01HB4`0A3@h00P0A3@h02`0@30d03`/<00l;300?2``0510A01HB4`0>
2P/03@T:00l;300C2`d03PD600<04@P900T05Pd>0107200F3@h02@0100d41@0C2P/01`0000l82@0@
2P`00P0?2@/0200@2P`050h@048l?P0B30h0>S@f02<M7`0E3a403@L90P0?1@H00`0@1PL04@L80147
200201882@804`T:00<04@L800l51P0>10D00`0@1PL01@0?1@H03P@500h41@0F30d0308300804PP9
00@04@L800h51@0=0PH02`040`0>0`L0300E2Ph040D901052@0@1@T03`@800h31`0=0PH07A8F00X0
0`0F2`l03`@800h31`80304500D03P<700l4200E2Ph060dA00h31`0Dooooo`006oooool200h>300<
00d=2`0>3P`0410>010@3P0I6AL0Bd]901PH5P0@40h0410?00T91`0D51802`/90P0<30X0100B4Q00
:2PV01PH5P0P81h2014A3`0401<C4@0:2PP03Ph<00h>30803`l=00H03Ph<00d=2`0?3`d03Ph<00d=
2`0<30X200d=2`0O00/=2P0A4a004Q@A010B3`0M7a`0;2h[09VKV022Q8408bDR01<E4P082PL04A4?
01PE5P0R824040h?00l=3P0C4a<01`L7010@400>40l02@/:04=5A00D5aH06A`J00d?300B51406A/H
00h@3@0;3@X04Q@A014C400200h@3@803a4>00T0418?00`>2`0<3P/03a4>00X<2@0@4Pl051HC010B
3`0A4a000P0@4Pl07`0>40d030h;010B3`0?4@h03@l<014C400@4Pl030h;01lQ7P1=Cd`04Q@A01<E
4P0<3P/03Ph<00l@300K6aP09BDR00H60`0F5a<051DA01DE4P0D51403a0<00l?300A4Pl03Ph@01LF
6`0=3@h0?clo03/k>@0D5A000P0>3`X0200>3P`01@D7014A4`0B4AD05aLG010@3P0=3@/03Ph<0P0<
30X02`0?3`d03Ph<00h>300C4a402`/901hN700E5Q400P<000d>2@0?40/020T400803a0;00T03Pl:
00d>2@0=3PT03Pl:00l@2`0<3PT01`/500/?2@0=4@/00P0:3@P08`0G6QD02Pd900hB300/;bX0<CD`
00P:1@0B4`d03Pl;00`=1`082@H07b0K00P9100=3PP03Pl900d>200<3@L03@h8010A2`0920<03`h9
00X9100<2`H04Q4<00X9100>3@P030/600/:1@0<2`H03Pd8010?2P0=30L03`h9010?2P0A40/03`h9
00803@`700X02`X500d<1`0A40/040l:00h=200[:RD07ahI014@2`0<2`H03Pd80P0=30L300h=2007
00d<1`0<2`H04A0;01DD3`081`<03Pd800`;1P0201lN6@803Pd800`02`X5010?2P0C4Ph01`H200/:
1P0=30P03`h:01@C3`0@3`/03@`800`;1`0?3PX200d<200T00h=2@0=30P03@`800`;1`0A40`040l;
00/:1P0?3PX040l;00`;1`0>3@T040l;010=2`0C3`l04a4A00h=300@3Ph0410?00h>3@0V9RD02@/9
01@F500>40h04ADB059BD00J6AP020L500/:200@3`d03`h=010?3@0<2`T03@`:00l>300>3@/04a8@
0P0A40h0400@3`d03Pd;00h=2`0=30X04Q4?00l>300B4@l040l=00X91`0B4@l0:BPV01HE4`0;2PP0
6APF01dL6P0@3`d200l>30803Pd;0P0=30X0200?40/0410=00h>300>3Q005A@H01/J7`0E51T03`hB
0P0>3Ph05P0@4@d061TD00X<2`0C5A@051HE018D4`0I6QT09BHV01<D4`0?3`l03Pd>014@4@0B4140
3`d>02@R900L6Q`05A<E01<A4`0@3Q003@/=01XH6P0A3a42010>400400h<3P0?3@l03@/<00l=3P@0
40h?00H03P`=01@B4`0T8R<0928S014?400=2``200l?4P0B014A500E51P0FUYM03Ti?00A41@03@`@
00h=4@0C4QH051<G01<C5@0B3Ph04Ph=01<?3P0@3P`04a8@01XI5`0@3`d03`l=0P0?40d200h@3@03
010@4@0B4Q<04A4B0080410A01/04A4B00l?400?3a004A4B018B4`0D51D04Q<A03Pj=@1YJfH071hI
01HG500E5a8051HA00d?2P0?4@`04aD@00lA300>40/04aH@00lB2`0>4@X051L@01<F3`0I71D07b8K
01LJ4`0C5Pl00`0B5@h03`0C5Q004A@@00dA300A51005ATD01@G4`0B5A404QHA01DI500D61<05APD
01PL5`0F6AD05ATD01@H4`0201<F4P0P01@G4`0?4`h051PC01@H4`0B5A4051PC01DI500C6@l04QT>
01<I400C6A805A/E01HK600@5AD06b0P01<H5`0N8b805A/H01HL6@0F6a/05Q/J01HL6P0G71T061hJ
01XP6`0I7aT05adG01XP6@0L8QT05QdD01HM5P0I7ah201PO802001PQ800J8b806R@S02D_;@0J9R<0
5R<M01/Y8`0P;RP07B`Y01<P9P0U<cX07B`_02Lf>@0N;Bd08c8b01TX9@0S<S407Rd/02Dd=@0O;C00
@e5G02Le?@0V=3`0:CQ0020`=`0Z>T40;Sm501d_<`0S=ST09cXl02Lj>`0V>SX09c/m02@f?@0V>3l0
9cTo02ho@`0_@480:S/k02/j>@0Z>SP0:cPe03E3?@0[>C<0:SL`034j<P0U;BL0<CXb02D]9P0^=S00
82PP02D^9`0S:bD08b`T02@]9P0S:bD08BXR02La:00`>S80OXR004mID@0j@ch0:S<^02D^:@0T;BX0
9Bh[02Pa;P0V;b`09Bh[02</:@0X<Bd08R`X020[9P0b?SX0=dA202@d=00W=ST0<49803E6D00fB5@0
=DYG03M>FP0dBUL0=T]H02m4C`0nDUd0;d==03A7D@0_@DX0<TA<02doA`0V=cl0:SPl02Hb<@0V=3D0
;3Xl02ll@P0_?DH0:cU302`jA@0^?dT0;Sm80352BP0_@4L0;Ce301l^<`0_?T<0=TE905ETI`0X=ST0
;3Li02/f>00X=3@08bd^028/;@0T;Rl0:Bha024V:@0h?D00:Bhd02H[<@0/<CL0:Bhd02P]<`0Q9R`0
82DY02H[;`0X;S0302<W:00l028V9`0Q9BH08BDV02DY:P0P92D092PY01PL7@0S9bP07B4R01/O7`0V
:RX0;S8b01hR8P0O8b<06AdM01XN7P0P92@06alO01TM7@0K7al06AdM01XK7@0O82805AHH01TJ700J
6ad07AhP02@U9`0[;2h0414C01<D5P0L7Al05AHH01DG5`0E5QT06AXO01TI8@0I6B@081l/03LgA00^
;ST06a/S020Q9P0D5AP04a@F01PG700K6b803`lG01/N9`0H6bD051TT01HK900E6R004aLJ01@E600H
61P06QTJ01LF6`0F5AX05aHK0P0E51T05@0J6Ah0@T5602TX;@0C4QL05A@I00h=4P0G5aT051@E01@D
500C4a<04Q8B01DE5@0H61P0Bd];05EEE@0820P06a/K02l_;`2/[:`09BDU00d=3@02010@400D00h<
3@0D4Q<040h?01<?400B3Pl05a<D01/E5`0E41404`l@018>3`0D41405A4B01<?400@30d03@T:01DA
4P0F4Q<04Ph?01<?400>2P/2014=3P0Q010<3@0?2``03`/<00l;300B3Pl04@d>00h:2`0A3@h040`=
00h82@0?1PP05`h@01D<3P0@1`T05@`>01482P07000071<E03L^<00D2`d03@D601@<3P0@2P`03@L9
00`6200>20X04@/=01D?4@0=20T0618D00@0000<1`P03PP:00L04@L800D04`T:01D;300B20T04@L8
01882@0301061`0A00l51P0>10D03P@500X10P0D2P/030<400P0000G3@h03P@500d21P0<0@D040D9
01462P0=0PH04@H:00h31`0?10P00`0@1@T01`0?10P030<501472P0:0@<04@H:00d21P0C20`00P0>
0`L0100A1PX06@hB01`A5@0@1@TDooooo`006oooool02@051@<02`/9014A3`0B4Q003`l=00/;2@0F
5Q@03`l=01@D4P0200d=2`0=018B400;2`T03Ph<01/K6@0H61H03@d;01HF500<30X06ATG00h>300@
40h05ADC00T91`0200h>30803`l=00@03Ph<00d=2`0?3`d03@d;0`0<30X07P0=3@/03@l<00/=2P0>
40d03@l<00/=2P0>40d04Q@A010B3`0H6QL0418?00lA3P0A4@l04@h?00l=3P0A3a003P`=00/;2`0?
3`l04A4A00X<2`0>40l03@l>00lC4P0=40h020X700h@3@0G6AH02`d:00P:1`<03Q0=0P0A4a003@0?
4@h030h;00L91P0<3P/04Q@A00X<2@0R9240:R`Y014C400@4Pl03Q0=01<E4P0B51400P0<3P/04@0=
3``02`d:00L91P0;3@X03a4>0001000V:2D03@h<0001000F61D02``900d=2`13@d40K6aZ00X:200;
2`T03@d;00803`l=0P0;2`T0400@40l02`/=00d<4@0=3@h0410@00X:200D5A002@X5014B3@0<30X0
5ADG010@4P0;2Ph05aLG00l?3@0;2`T200h>300;010@3P0;2`T061PF00d=2`071`D092@R0:NWY@0C
50l00@8000`=200B4`h00`0?40/06@0>3`X03@h900d>2@0>3`X03Q0;010B3@083@L02a0:00dB3009
3PP01``600/@2P0@5@l00@H00003000;40X0314;00X;1@0=3PP020T301DF400>3`T04a@>00l@2P0<
3@L00P0:2`D02@092P@020T300L60@0B4@`02@P3014@2`0S8Qd04A0;018A300200l>2@0S010?2P0=
30L02`X501<B3@0F5A004Q4<00/:1@0>3@P04a8=018A300:2@@01@@0018A300920<04Q4<00`;1P0@
3`X03Pd800l>2@0=30L02@P300/:1@0=30L03Pd800l>2@0>3@P03@`700`;1`0;2PD030/602d/9`0C
4Pd040l:00l>2@030P000P0@3`X03P0=30L030/700/:1P0E510040l;00P70`0@3`/04A0<00/:1P09
20@03Pd900/:1P0<2`L03`h:0P0A40`08@0?3PX04a8>010?2`0;2PH04A0<01<B3P0?3PX04Q4=01DD
400D4Pl0510?014@3P0=30X03`h<00h>300<30X02`/900`>2`072@H04A<@00lB3`11@Cl03Pd;01DD
4P0?3P`00`8000l>300F5A<04Q4?01<B400A40h03`h<01/J6002010?3@804A0>00h04Q4?01<B400H
5aD06QTG00X91`081`D07QdK02h]:`061@<02PT701@C4@0C4Q003Pd;018A3`<040l=00/03`h<00h=
2`0>3@/030d8010A3@0@40h03Ph@00`<3`0<2a003@`A00/:3P0200l?3`0;00`=2@0?40/04Q@C010B
4@0<3Pd02P`;00/=300>40l03a4@014C4P0?4A000P0<30`0300?3`l04@l@00d;300=2``03`d>018@
4@0E4a@07A/L014?400=2``03P`=00`:2`803P`=00<03`d>010>3`0@3Pl00P0>30d06P0;2@X02@L8
014?400>30d030X;01@B4`0@3a@04Q4F0000100d<cP0knkc03Th?@0B4AH03`hC00d<4@0;2Pl030/@
00d=3`0A3Ph04@d<01HB4@0D4a404Q4?01<C4@0?3`d0418?0P0A4a000`0>40d03@l<018B500201<C
5@04014A4`0B4Q@05ADG01@D5P804Q8D00T03`lA010@4P0B4a804A<>03m1?00:30P05aTD01@F4@0?
4@`00P0@4Pd04@0E5a804Q@?014C3P0E61803Q4:00/>1`0?4P/02@`500hA2P0H6a@04QD>00lB2`0@
4``04aH?01@G400D61<04AHB00<041DA00H04AHB01@I5@0C61@04QLC00lD400@5A4301<H5005014F
4P0@5A4041DA010E4@0G71P00P0A5Q80GP0D6AD04QLC01<I500D714041P;00lG300E71@061lG01DK
5P0d>SP0=C/i01HL700E6a/03aDE01/Q8@0B5aX04aPK01HL700I7al06R0N01XP7@0J81`05A`E01LN
5P0I81P05alD01dT700J8b005b0O01DN7@0F7ah06R@S01hX9`0F8R006bLU01l[:@0N;BX07RdY01d[
:`0Q<3<05bH[02Pg>P0J:RX0:SXi01/[:P0L;2T08S8`01l_;`0_?T40;3/o0:Fd^@11D5L08S<j024b
>@0_@4L0AUQL02Li?@0S=CT09SPj02@f>00Q<c<0838b02@f>00W>3l09CHm02He>P0/>cl0;3`l02Pf
=P0Y>3@0:SHb02@a:P0S<2L07BXQ024]8`0R:R8061lG024X800W;RH08BPP02H]9@0T:b<0:2lW02@[
8`0[<RX0;C@/02D/900U;bH0;CL_09jXX01HHUX0DU]F02lh<`0T;BP2020Y9P0o02D^:`0Y<Rl0:S<`
02/d<@0Q:RD092hY030k=@0c?c/0934^02/k>P0eADD0>T]A03E6CP0gBED0>D]H04AJI`0hCU/0@eQS
0355D01SMh00>diG03U;E@0bAD`0<dE<02/lA00R<c/0;C/o02Da<@0R<340:CHk038oA`0c@DX0>TQB
041>F@0iBU@0;Sm702m0A`0]?TD0;cm502/j?`0W=S/0=DA804iMH00X=ST09S4c02Pc=@0Y=CD09S0a
02<];P0R;2d08RL[01XO8`0g?4008bP^028W;@0^<cP09b`b02P]<`0V:c409R/_02T^<P0U:Rd08bLZ
00808bLX06008RHW024U9P0Q9BH09RX[01hR8`0Q9BH04ADF02@X:@0K7b005QXI020T8`0N8R40720O
01lS8P0I7A`061`K020T8`0L81l06AdL01/O7P0F6QT08B8T01HG6@0N7b407AhP01XK7@0A4Q@051DG
01PI6`0E5QP07QlQ01XK7@0L7Al05aPJ01/L7`0N7b@06ATQ01LG800P82`0;Bdi02XZ<`0;2a<0824V
00l@500I6Qh04a8H01/K8P0G6R4092Pa00`A6`0I82X03A@L01PN900F6ah04A@F02@T900c<c<061LL
01@C600E51T04a8G01HE6P0L6b00QXF:04Y9CP0A41D05QDJ018A5P0G5aT03Ph?00l?3`0>3Ph03`l?
01<C4`0F5QH061PH01LG5`0E5AD03Ph>01@D500H61P03`l?014A4@0=3@d0410@018@4@0<2P/040h?
018>3`0E4A804@d>010:300E41804`l@014=3P0B3Pl201@@4@07018>3`0?2``05Q8C014=3P0;1`P0
40`=00l;3002014=3P0R010<3@0?2``03`/<014=3P0@30d030P901LC500S7b006ADF00X51`0D2`h0
91/N02<J7@0F3A0060lB0189300A20/03@@701TA4`0D2`h02@0301D>400D3Q0040X<00h82P0?2@/0
4P`>03/e=`0d;S002@@501/E5`0B30h02PD601<92P804PP900T04@L801061`0@1PL02`4200h41@0A
1`P03P@500d3100?1@H00`0@1PL00`0?1@H03P@500h41@0201<92P0401892P0;0@802@0000h51P80
3P<70P0D2@d0100=0PH03`@801<8300@1@T200`11@0>00h31`0A1PX04@H:03/`=00;00@040D900d4
1P0=0PH02P0300h31`0=0PH03`@801<8300?10PDooooo`006oooool00`0B4Q004A4?00l?3@0300h>
300<010@3P0>3P`030`:00`<2P0>3P`0410>01DE4`0;2`T02@T700`<2P0=3@`00`<10P0>3P`02P0J
6QP04A4?00l?3@0;2`T03Ph<00l?3@0=3@/02PX800d=2`0A4@l200d=2`0E00`<2P0>3P`01`L5014A
3`0?4@h030h;00/=2P0<3P/03Q0=00lA3P0A4a004aDB018D4@0>40d03a4>018B400A3Pl03`d>00h<
3@0?3@h03Ph>00803`l?00H04Q@C0001000D5QD051PG020S8@0=3``200/=2P0600d?300?4@h03a4>
018D4@0A4a002P`90P0@4Pl01`092`P02P`900h@3@0A4a002P`900/=2P0@4Pl00P0:30T0900T9R<0
51HC0043000:30T02`d:00X<2@0;3@X03@l<00lA3P0A4a005aTF00840@0A4a004Q@A00lA3P0<3@X0
3@d;014A3`0F5Q@05ADC00h>300J6QP02`/9014A3`0@40h02PX800`<2`0@41803`hC00l?400>3Ph0
3`l=010A300B4`h02@X500l?3@802`/=01003@`@00L71`0;2`T01@D300l?3@0A4@l03`l=00`<2P0@
40h03`l=018B400Q8Al0ADE300l@2`0=3PT030d80P0>3`X0700;30L00P<001@E40092PD020T400X;
1P0;3@P02@/600T<200F6aD01@X400@910062`D020d700X?2@0320801P/501<H4P0H7AL061TC00d>
200@4@/03a0:00P90`0A4P`05AH@00h?2@0<3@L300d>200f010?2P0<2`H02PT4018A300@3`X02PT4
01<B3@0B4@`03`h901@C3P0G5Q4010<000l>2@071P402`X5010?2P0B4@`020L200`;1P0D4`h02@P3
00h=200A40/03Pd800/:1@0H5a802@P303He<0081`8040l:00h=200?3PT040l:00l>2@0<2`H02`X5
00h=200<2`H04A0;01TH4`0G5Q404Q4<010?2P0=30L030/600d<1`0>3@P02`X600X91@0=30P02PT5
00L60P0920@03@`80P0A40`04@0>3@T04A0<014@300<2`L03Pd9014@300@3`/03@`800l>2P0A40`0
3Pd900P70`0A40`02`X601@C3`0?30X04@d<00803Pd;00T040l=00h>30092@L05QHD00L91P0=3``0
004000dA3@0?3`d00P0A40h0100?3P`03Pd;00d<2P0>3@/400l>3003010?3@0=30X03Pd;00803`h<
0P0>3@/02@0920H06aXH014@3P0D4a404A0>055@CP0B4@l03Pd;00`;2@02014@3P0G00/:20071P@0
40l=010?3@0E51804A0>00`;2@092PD03Pl;00d=2`0:2P`0410C01`K800H5a`051<G01PH600C4a<0
2PX701@E400B4Q804A4A010@400?4A000P0>40l00`0=3`h030h=010B4@0201@F5@03014A4@071@H0
3`d>008020H700D04@l@00/92P0;2@X030X;010>3`02018@4@06010>3`0<2P/040h?010>3`0>30d0
3`d>0P0B41407P0=2``04Q0A01<A4P0?3@h04@l@00h=4P0D4aP04A0E01/J7`0S8RL07A`Q00h=4P0F
5AX040lD00`;400B4AH051@F00h=300B4@l05A@B01<B400<30X02PX8010A3`0<3P/0418?010E4@0D
6AD03a4>00h>408051@F0P0@41800`0B4Q@04A4C014A4`03014A4`04018C4@0A4`h04A<>010B3@80
3a4<01D04Q@?01DG4P0C5A00418=00lA300A4`h05ALB01<E400D5Q403@l:010B3@0H6QD0418=014C
3P0?4@`04Q@?00lA300>40/05ATD00H<200;4@d00P0G7AT0;@0E6aL020h:01TO6`0D6QH03aDA00/A
3@0C6AD05adI00/A3@0A5a<06b4M014G4`0>51003aDA010F4P0B61@05A/G01LM6@0I81X06b8J01<M
4P0?6A003AL>00`F3@0C7AD031D@01TR7@0@6AL04a`K01<K7@0B6Q`07BDW00L?4@0S;2`04Q/J01TR
7`0H8Ad0624L018L500H8QT06B<J00lI3`0G8AP06B8O01TR8@0301PR8@0/01LS8@0L:2P062DU020^
;P0L:RX072XY01XX:00J:B`07Rdb02@c=P0V=SH08c<b01`/:@0R<S409CDe02Lg=`0U=3L09C@j02He
?00M;SD0:S]202Lh?`0T=SX09SPl024c=@0M;c409SPj024c<`0_@D4093Hf02Lf>@0Z>Ch08S4f028`
<`0U<cD08Bl_01hZ:00W=2h0:SD_02D`:00M:Ah07b/Q02<_9@0L91`201hU7@0701lV7P0Q:20092/S
02H]9@0S:R8092/S02P_9`0202/b:P0802Ha:00U<2P0:cH^02Td;00W<R`0;3La024/9P0U<2`202Lb
;P0_02Pc;`0Y=300;CHa02D^:@0T;RP0;CP`038o>00T<Rh0:3Pg02Ti>@0_@DH0>4UA0312CP0gBUH0
<DE@03I:E@0jCUT0BemX0;?5c`1NL7T0=4M>0393B`0[>d80:cY104EDF`14DUH0?DQ:02Xh>`0c@DD0
:SLo05QVK`18EV00<Cm:02dnAP0[?4@0:ca302dnA@0a@TH0;Ca102Xi?P0b@DD0;C`o03=1A00U<380
9S4c02Pd=00Y<c@00P0X<S<01`0]<SH07b@X02<X;00/<CD09BX^02H[;`0Q9RX00P0U:Rh02@0V:bl0
:c0d02T^<@0V:Rd092PY01hR8`0P92D092PY01`P8@0201hR8`0501/O800N8R<08RHW01/O800O8b80
0`0L81l201PL6`0[01HJ6@0N8R4051PG02<W9P0V:RT07B4P01/L7P0O82802@X<028S9@0H6A/06a`N
04m@DP0F5aT06Q/M01`M7`0C51H061TK01/L800M7R<06AXO01HF7P0L72D09RH`02XZ=00L72D05ADM
01HG700F5a/06Q/O01PI7P0H6Al06A`S028V;`0F6bD01PlH00TB6@0G7B<061dP00`@4P0Y:bX0B4Y9
01PG700401LF6`0U01HE6P0N7B807A`Q00d<4@0A41D061LL00l?4@0H61T02`/;018B4P0=3@d04a<C
018B4P0E5AD04A4A00d=3@0D51@03`l?018B4P0K6a/02PX:00H61P0A4A404@l@01XH6@0B414061@E
01<?400>2P/03PP:00`72@0D41404@d>00h:2`0A3@h03`/<01<?4005014=3P803`/<01l03PX;00d9
2P0A3@h03`/<00h:2`0?2``07a/L00/7200@30d03@T:00`7200B30h0Qh6303hh>P0F41802P@600h8
2P090`D03`T;014;3@0<1PP04`d?03H`<P0E3a403PP:00@0000:10H05Q0B02TS9@0M5aT03`T;0080
2P@600L03PP:01L=3P0:00406Q0A00L0000<0P<050X;00H040H700H04@L800l51P0<0P<02`4200d3
100@1PL600l51P0800`11@0A1PX05P/?01462P0?10P04PL;01462P0;00@200d21P0>00l4200J3a<0
OW=g01T@4P0D2@d04PL;01052@07000050T=00d21P0A1PX0200101D:3P0A1PXDooooo`006oooool3
00h>300500l?3@0A4@l04Q8@018B400@40h00P0>3P`07P0@40h04Q8@00/;2@0<30X02@T701<C4@0?
3`h030`:01dM6`0>3P`04A4?00l?3@0@40h02`/900h>300?3`d03@d;00`<2P0>3P`0410>018B400`
<2h03Ph<014A3`0C4a402`/900h@3@0=3``030h;00d?30<03Q0=01404A<@010B3`0>40d030h;00h>
300A3Pl03`d>00h<3@0?3@h03Ph>00l?3`0;2`/04aDD0412@@0>3`h03a<B00X=2`0300d?300300h@
3@0?4@h030h;008030h;00@02P`9018D4@0E5a@04Q@A0P0<3P/0600>40d02`d:00/=2P0=3``05ALD
01HH5@0;3@X03Q0=018D4@0=3``030h;00d?300>40d03a4>010B3`0?4@h020X801dO700@4Pl01@L5
01<E4P0=3P`03@d<00l?3P804Q8A00D03`l>00d=30092@P071`K01LG5P0200d=300K00l?4@0>3A80
3@d>00d=3@0=3@/03a0;00d>2@0@4@`04A4?00L72@0B4Q@03PhA00/;2`0>3P`02`/9010@3P0:2PP0
3Ph<00d=2`0A4@l03`l=00P81`0820H04A4?00l@2`0=3PT030d800803Pl:00l030d800l@2`092PD0
414<014B3@0@4@`02@X5010B3@0?4`h03A4;00D90`0=4@/01`/501HI5020Q7h00P0@50h02`1ZKVP0
418=010A2`092P@03@h800h?2@0:2`D04a@>00L80P0=3PP03a0:00803@h801803a0:00h=2@0M71L0
2`X501DD3`0=30T0CTe801`K5P0;2PP03@`700X91`0@3`X04Q4<01HE400@3`X030/6014@2`0;2PD2
010?2P0;00l>2@0D4`l03`h:00/:1@0B4@`030/6018A30061@0081lJ00`;1P0?3PT00`0<2`H04@0>
3@P04A0;018A300:2@@030/600d<1`0>3@P040l:014@2`0=30L03Pd8010?2P0?3PT03Pd800h=2@0=
30P03Pd9008040l;00D03`h:00d<200@3`/040l;00d<2002010?2`0300d<200>3@T03`h:00<040l;
01P03Pd900d<200C4Ph0:bXV051?B`0A40d04Q0=01<?3@0A40d03@`900X91P0;2`P03@d:01@E4@06
20@03@l;00`>2P0?4Ph02`/900d<2P0?3P`04Q4?01<B400E5183010?3@<03`h<0P0>3@/300l>300h
00h=2`0D4a401PD301HE4`040`4040l=010?3P0B4@l03Pd;00d<2P0@3`d04A0>00`;2@0D4a403Pd;
00/:200A40h02@P702<R800L7AP04A4>00X:200=3@l04a<F01@C600T8bP05A@H01<C4`0B4Q8030`9
010A300B4A804a4A014@4@0A4100410@00l@3`0B4a80414A010B4@0A4a803a4@00/=300>3@`03`h=
00l=3@0I5aL081lN00l>3@0>30`04a8A00X8200A40l07ahM00d<2`0>30d2014?400?010>3`0A3a00
4a4B00l=3P0;2@X03`d>010>3`0=2``03P`=00h>4@0B4AD030/?010?4`0C4aH03@`@00803`hB01<0
4A0D00h>4@0>3Q4051@F018A400=3@/030/900d=2`0B4Q0051DB00lA3P0F6QH08RHR01@I5@041`@0
4aPD01<C4`0B4Q<04A4B0080410A1P0A4A800`0A4Q404A<>010B3@04014C3P804aD@00/04A<>00lA
300A4`h04aDA01DG4`0F61@09RPT01XL600<3PX051HB01PJ5P0201HH500C00lA3@0=3`/05ATF010F
4`0D6QL04QPE01@J5`0H7Q/051XG014F4`0G7AX05Q`I01PN6`0@5A804ALD00lE4P0E6aP07B<P01TO
7003010F4`804QPE04/04aTF01@J5P0A6Q<03QP?014K4`0D7QD04A/B01<M5@0F81P0624K018K5`0>
5aH03aLH01TQ8`0D71d05b0P01<L700H8B00624O01TR7`0J8al05AhI01PQ6`0H8Q/04adE01dV800I
8al06R@R01XT8`0K9R@06bLV01`X9`0F8b<06BLW01/Y:@0Q<30062LW01`[;@0L:bh072`_020a<@0R
<c808C8`01`]:P0N;bh08S<b02<d=00R<cL08c<i02@e?00X>d409STn02Li?P0V>Cd093Hi02Li>`0X
>S/0:S/l02@e=@0^?ch0:SXj02hm?@0`?T00:3Df02Ld<`0Y=SD0:3<`02Da;00Q;BH08R`T020[8@0M
:1d07bXO028/8@0J91/00P0L9A`02`0L91`07bLO024Y8@0M9Qd08R/R02H_9P0X<2P092`T020Z8@0U
<BL08bhV0080:3<[00D092lY02D`:P0U<2X0:C@`02/f<P0202Xe<@0R02/f<P0T;BP09BlX02Pc:`0T
;bL0:3D]02Dc;@0W=c@0:CTi0352A`0a@TX0;Cm903M:E@0cAe80?51J03U=EP0V>D<0BEaT045CF`0h
BU80<D5902lnA@0^?D@0:3Lm02Tf>P15D5<0<Sm4034nA@0X=Cd0>TQA02`jA@0a?dX0;d180311B080
<49600T0;d1402ln@`0a@4D0<T550350@`0`?T40<3/m02`g>@0W<c<00P0Y<c@01P0Q:b`09b``01dR
9P0Z;c80<3Dg02<X:@<09R`[00T092X[02P]<00[<3@092T/02@X:`0U:BX08RHW020T9@0S9bP00`0N
8R<04@0L82407R8S028V9`0L824092PW020T8P0P9B8082@R01`P7P0L8Ah07R8P01PL6P0I7A/06QhL
03@h=P0M8B007QlQ00806Q/M02806AXL01XK7@0R8bD0HfAV02HW:@0E5QP05QLI01XK7@0F5aT05QLK
01/L8@0J6b005QLM01@D700F5Ql07AdV01LG7`0G61h05aPM01<D6@0C51P04a@I01`N900F6B004QHO
00lG800W<3T0:C8i01LO900H7B0041@F020R8@0G6AP04a8G0P0D4aP301DD6@03014@5@0I61d05QDJ
008051<H01h04Q8D018B4`0F5QH05aLG01@D500G5aL03Ph>01<C4`0B4Q803@d=010@400?3`l06ATI
014A4@092@T04a<C01@D500;2PX04Q0A010>3`0F4Q<04`l@018>3`0E3a405a8D02<O800M6AX0510A
014=3P0<20T600l;300@010<3@0A3@h04@d>018>3`0F4Q<04Ph?00h:2`0?2``02PH700l;300B3Pl0
3PX;00h92`0B3@l0BTA7028L7`804P`?00<04@/>00`62@0=1`X00`0@2Pd04P0B30l04P`>010:300@
2P`04@/=00l92`0A2`d03@L900h82P0A2`d03PP:00d72@0D2P/0200001071`10=SL03`L700l61PH0
40H700H03@<400h41@0A1`P04@L801061`0>10D600l51P0800X00`0?10P04`P<00l4200=0PH03`@8
01872`0>0`L200l4200>00h31`0C20`0I5UM01/@500?1PP02`8401@93@0?10P030<500l5200?10P0
40L901052@0<0PDDooooo`006oooool00`0B4Q004A4?00l?3@0300h>300B014A3`0@40h03`l=00l?
3@0@40h04A4?00X:200I6AL04A4?01`L6P0<30X02`/901LG5@0<30X04A4?00l?3@0D5180410>0`0>
3P`02@0=3@/03Ph<00l?3@0I6AL0Cdm=01HF500:2PP05ADC014A3`0600d?300F010B3`0B51404aDB
014C400>40d03Ph<014>3`0?3@h03P`=00l=3P0>3Ph03`l?010@40010`802P`;030b<@0<40l02@`:
00d?300?4@h0418?00lA3P803@l<00X03Q0=014C400D5Q<04Q@A00lA3P0D5Q<04A<@00`>2`0>40d0
3@l<0P0<3P/050051`@0418?01<E4P092`P030h;00X<2@0<3P/03Q0=010B3`0?4@h03Q0=00T;2008
2PL04Q@A00X<2@0C5A80<cDb00L81`0=3@d030`<0P0=3@d01`0>3Ph0;Rh^01@D50061PH02@T9010@
400B4Q800P0>3A804P0=3@h030`<00d=2`0>3`X0414<01@E400K6aT01`L900D51`0?3a8020P800X:
20092@L0410>00X:200?3`d020P600`<2P803@d;00<02`/900`<2P0=3PT01@0=3PT09`0@4@`03Pl:
014B3@061`803a0;018C3P0;30L06adH0084000:2`H04A8=014C3P0C50l0>S`g0001000];RT0=3D`
01@E400?40X02``600l@2P0@4@/03a0:01DF40092P@03Pl900d>200<3@L03@h800X;1@05100030/6
00<2000?3PT00P4002HU800@3`X03Pd801HE400200d<1`0E00`;1P0A40/020L2018A300g=S405aHA
01<B3@0920@05A@?03Lf<@0S8Qd01PD000/:1@0>3@P03`h900/:1@0:2@@04A0;00d<1`0@3`X03@`7
008030/600X03@`700h=200>3@P03@`700`;1P0=30L03`h9014@2`0;2PD03@`70`0@3`X01@0=30P0
30/700h=2@0>3@T03@`8008030/70P0@3`/0700=30P040l;010?2`0?3PX03Pd900`;1`0@3`/04Q4=
00l>2P0A40`03Pd900X91@0^;BT0IFAP01dL600?3@T04@d:010?2`0C4Ph040l;00l@2`0@4@`05aPC
018D3`0C5A001PP300hB300A4@l2014@3P8040l=00@04A0>018A3`0A40h040l=0P0>3@/00`0=30X0
3Pd;00h=2`02010?3@0;00l>300>3@/03Pd;00X91`0510<061LE01<B400>3@/040l=00h=2`0=30X0
0P0?3P`05@0>3@/040l=00h=2`0=30X040l=00H50`0D4a408B8M018C3`0;2`T0410B018B5@0<2a00
61LL00l?4P0@41004Q8B010A3@0D4`l04@d>018=3P02014=3P<03`d>01803Ph>00d?3P0>40l03Q0?
00h>3P0E51803`h<00d<2P0F5A<06APF00P71@0<2`T040l=00L6100>3@/06aXH00l>300>30d3010>
3`<04@l@00<040h?014?400B41400P0A3a009`0@41004Q8D00l?3`0B4Q<05ADG014A4@0?3a002@T;
01DE5@0D51D030`>018B4P0?3P`04a<A01HF500E5A<0418?00h@3@0=3``041DA014F4P083@T0;C8^
08N<R00O81d05ADE018B400B4Q40410@010@3`0B4Q004Q8B018B4@0B4Q004Q8B014B3P0?4@`0418=
014C3P02018D3`80418=0P0B50l2010B3@0H014C3`0C5A8061XG01`N6`0>40d02P`9010B3`0B5140
418?014C400@4Pl04Q@A01`Q7P0;4@l03aDC01LM6`0@5Q@04QPF010F500Q9bD06R0N010F500A5aD0
4aTG0P0E6aT0100?5A<041HD01PN700I7ad201<I5`8051XH04D05A/I01@L6@0C71T04AXG01@M6@0E
7aL041XA00lI400;5@`0218901TS700Q:RL0;SLf04]DD`0>5aH06B8O014J600E7Q/03aPE00dF4`0C
71T05AhK01lX900Q:RL06B8N01TR7`0G8Qh06B<Q01XT8`0K9bD07BTX01hZ:P0A7al07B//01XX:@0_
?cl093<e0391A00O<C<07S0`01lb<00R=C<08cHc024d<00N<Bl08SDd02@f>00T=SX09CHm02Dh?`0W
>T0093Pk02Pk?`0cATX0=dY<02`n@00W>CT0:CXj02<c<`0P<2l07bh^02Dc<`0^?CT0:3@`02Da;@0V
<b`09S4[02D`:00P:b<00P0L9Qd0100N:1d082PM01lW700K9A`301`V7@1001hX7`0P:R409BlV02@^
9@0S;B@092hU02Pb:@0Z=R`0:3@Z03M2>P0d?cL08bhV02D`:P0`>cD0:SD_02hi=@0_>SH0;STe02dh
=00^>CD0B55<02<]9@0[=Bd0;STa02Tf;@0P;RL093@a02Ti>00dATT0<45803Q:E01[OXP0AUYU03Q<
E@0hBeD0>4YD02e0A`0gBE00B5UQ055PI`0a@4L07B`c02He>P0c?d@0<Se102dj@01?G6<0<d1903A2
C@0e@dh0=49;0393BP0bA4T0<49402i0@P0Z>Sh0;ci30391AP0[>Sh0;Se002Xh>`0[=SP0:3<e02Da
<@80:38c01X09Bl`030e>00R9bX0:Bh`02dc<@0R:2@0:C0Z02H/:00W;BT09bdZ02H/;00V:bh08RLZ
020T9@0T:2T08RHW01dQ8P0O8b@07R8S01`P8@0M8B80720Q01hR8`0Q9BH07B4Q020T8`<07B8N0P0I
7QX06P0P9B405AXF01/P701CF5@0`/O302ld<00P8B<07QlQ03dn@00O82806Q/M01TJ700^;c408b@V
01PI6`0>3a406a`N01lP900F5a`071dR01dN8`0I6Ql051@K018B6P0G5al05ADL0P0I6Ql201@E6P0<
02//<@0Y;380724W01DL900@6240=3e608VBV@1jPXL09bla01DJ700N81l06Q`K0P0E51T04@0F5AX0
61LL01TH7@0I61d05aHK01<B5`0B4AH02`X?01@C600T92H06QXK00L71`0R8R806ATI00X:2P0G5aL0
3Ph>008061PH01D04a<C00`<300H61P092@T010@400820P03`l?01PF5`0?3@h03@/<01<?400A3@h0
510A01H@4P0A30d05a<D01<?400A3@h0510A018>3`0D41401@0A3@h2018>3`0N014=3P0D41406QHG
01@@4@0<20T06aLH00h:2`0D4140100100T51P0<1`T030H:00l93@0;1@T01`4501<=4@0@2Ph02@<7
014;3`0=1`/04@/?01`F6P0K5AP04`d?01D?4@0?2@/0100000h82P0B30h03PP:0P0=1`T0200:10H0
3@L90147200=0`@06a4B06=IFP0P5QL03`D61P0@1PL01P0<0P<03`D601<92P0D2P/04PP900h41@H0
3`D600T03P<701052@0C20`040D900l4200A1PX0304500/0100=0PH00P0?10P03@0>0`L01`0000l6
200I3Q802@0200/2100=0PH02`0400X10`0A1PX03P<700/1100;00@05?ooool001_ooooo00<04Q8@
014A3`0?3`d00`0>3P`200l?3@803Ph<0P0?3`d0300:2PP09BDS008200061P@051@B00L71@0=3@/0
3Ph<01TI5`0?3`d04A4?00l?3@<03Ph<00T03`l=00h>300=3@/03Ph<028R80010@005QHD01LG5@0<
30X01P0=3``07@0@4Pl04A<@014C400B51403a4>00h>300A3Pl03`d>00h<3@0?3@h03Ph>00l?3`0D
51@05aTH014C4P1IFeX051PG00`?3@0=3``0418?014C400?4@h03@l<00lA3P0=3``02P`900`>2`07
2@H02@/80080828O03<03a4>00D710051`@02P`9018D4@051`@00`D200h@3@0A4a004aDB00lA3P0;
3@X03@l<00h@3@0=3``030h;01@F4`0P8Ql0008001DG500@4Pl0@TA1018C4@0>3Ph03@d=00/;2`0<
30`03Ph>01HF5P0@41005ADE00P820061PH03Ph>010?500?3Q<03Ph?00h>3P0>3P`0414<00L80`0=
3PT03@d;00L72@0H61X04a8F014A4@0B4Q0030`:014A3`0>3P`00P0<30X01@0>3P`02`/900T91`0;
2`T0410>00H03@h901@020T4010A300=3PT02``701HG4P0@4@`05QLB034a;0051P4040l;00L71@0>
3`X02PT501@D4@0J6aH00@00014A3@0=3PT030d700X;1@8030d700h02``600d>200=3PP02P/500D6
000:2`D0414;00P90`0@3`X03`h901@C3P0@3`X04a8=00<200803Pd801402PT400/:1@0I61<04Q4<
01DD3`0<2`H04a8=038a;00?3PT02PT400`;1P081`807QdH018A300920<05aHA00l>2@02018A3004
00T8100C4Pd03@`700d<1`<03Pd800D02`X500X9100A40/02PT400/:1@02010?2P803@`700/030/6
00d<1`0?3PT04A0;01<B3P0H5a<06QTE010?2`0510001PD100/:1P0200l>2P0E00`;1`0?3PX03`h:
00l>2P0>3@T03@`8010?2`0B4@d03`h:00`;1`0D4`l04Q4=00/:1P0920@01PD100/81`0?2`P03@`8
01HE4@0D4`l03Pl:00804Q<>00L0004000lA300C5A003Q4<01<C4@0C4Q0040l=00<03@`:00<04Q4?
014@3P0@3`d00P0>3@/00`0=30X03Pd;00l>3003010?3@0;00l>300>3@/06APF01HE4`0M71X02`X8
00h=2`0@3`d03Pd;00`;2@0=30X00P0?3P`0500:2@L04a8@00d<2P0@3`d03Pd;00D40P0F5a804Q8?
00l?3@0@41803`lB00`;400:2@h03@`@014A4@0@41003a0<01DD400?2@/04@T<0P0@2P`0400?2``0
3@/<00h<3@0?3@h03Ph>00d=3@0>3Ph03`l?01<B400?3P`02@P600/:200>3@/02@P600d<2P0<2`T2
00l>3005010?3@0H5aD03@/<00d;300>30d0100?3@h00`0@3Pl03`d>00l=3P0200l=3P0T00`<2`0>
3Ph03@d;010@3`0B4Q80410>00X:2@0C4a<0:2PV02<S8P0;2`/020P600`<2P0D518061PF01HF500=
3``020X700dB3P062`L010T500D;1`0a=c<0RXn;01TJ5P0@40h03@h9010@3@0@40h0414=018C3P0B
4Q004Q<?018C3P0B4Q004A<>0P0@4Pd2018D3`0301<E400@4Pd0418=00804Q@?00X04A<>018D3`0B
51005ALD02LY9P0D5Q<02`d:01XL6@0A4a005QPE0P0B51409@0D5Q<071hK03]0?@0L9B80214>00hG
500330T031DB01HO700G81d07RLT051IEP0L9B805QlL014J5`0B6aP03AHC00`E4P0C71T05QlL00lH
5@0@6AH04AXG01<L6@0D7AX05AhK01HN800B71d04QdJ018M5`0>6A4041`B01HR5P0?6a4051lF00TD
3P084`l00P0F8Ad0;00B7AL05R4L00dH4P0A71H07bXV018M6@0D7a/06RDQ01/U900G8Al05b8N01<N
6P0D81d05B4O01HR800H9B@05bDU01TW:00J:B/03ahQ02Th>`0`?d<0CUeP01d_<@0L;Rh072l]01ha
;`0P<bl07c8^01lb<00S=C@093Hh02@f>P0T=C`09CPo028e>`0V>ch093Tl0396A`0jCDl07Bl_02<e
=@0Y>SX0:3Pg0P0O;Bd03P0U=340:CD`02@_9`0Q;2@082/S024[8`0P:R408bdT020W7`0N9Ad07bHN
01hU7@0M91`072LO0`0N:B40100Q;2@092lW02Pc:`0W<RX202D`:00702Xe;@0_>S80;3T_03M4>`0d
@CP0:CH]02Pe;P0202dj<`0a030l>00a?CT0;c/g02hj=P0_>SH0HVaU02dg;`0V<BP0;CT_030m=00Y
=c00<40m03=3@P0Y>ch08c@k045CG@2;WJL0BUaV03a>F00cADh0=DQ?02Xk@`0_@4L0>T]B03]:D@0]
>d40;3To02/h?P0Z=S/0;cXn03]8CP1NJg80=T=<02Tg@P0^?4H0<Cm80352B@0b@dT0<49402m1@`0/
?400<T5603=2A`0Z>Cd0;3/n02/i?00U<3809c8d02Lc<`0202@^;`0A02Tc=00_=3L09B/[02X`;`0e
>cL0=3/d03Y1>P0V;BH0:C0Y02Xa:`0T:RP08BLW02D[:`0M8B808BDV020T9@0K7b000P0M8B801`0J
7Ql07B4R01dQ8P0M8B808BDV01dQ8@0O8b800`0K81`201LL600G01/P700I7QX0724M05eRGP3Kh=`0
>Slk020Q8`0N7b40?Sm1020Q8`0J6ad061TK018C5@0?41805aPJ01dN800T9BL02@X>01PI7P0J6R80
6a/S01TJ7`0G61d00P0F5a`04@0D5AX05aPM01LG7`0E5Ad06ATQ00X=4P0K7R@06AhT00lF7P0O9bl0
JgEn0>Scn@3?e]T0<CTk01XP8@0?4a806Q`K00805QDJ02L05aHK01TH7@0J6Ah06QTN01HE6P0B4AH0
5A@I01<B5`0S8RL0>3Pj06YZJ`0;2`/02PX:00h>3P0@41006QXJ018B4P0G5aL051@D00`<30092@T0
6QXJ018B4P0D51@092@T01@D500>30d030X;018@4@0E4A804`l@01HB4`0G4A<040/=01LC500B3Pl0
3@T:00l;300<20T01`0A3@h0400B3Pl040`=018>3`0H51D04`l@00d92P0<20T00`00014=3P0C3a00
40`=00d82`0I51P04`hB01D@50060@D2010;3`0B00L21P0?2Ph03PX=018=4@0/9b/0RhF804U3A@0:
1@H05a4C00h82P0A2`d040X<00d72@0>20X03@L900T31@0:10H05@/<0P0;0@800`0S6AX040H70106
1`0601061`0300l51P0@1PL04@L800804@L800<040H700l51P0?1@H0100?1@H00`0?10P040D90146
2P0601052@804PL;00<03@8601hC5`0B1`/00P0<0@D0200C20`02P0300L0000K41@050T=00L0000B
1`/03`@85?ooool001_ooooo0`0>3P`0100?3`d04A4?018B400>3P`400l?3@0:00h>300C4a403`l=
03Xj>00[:bT02@T701DE4`0?3`d04A4?01/K6@803Ph<00h03@d;00l?3@0>3P`03`l=014A3`0?3`d0
3@d;00l?3@0G5aD020P600h>300;2`T04Q8@00d?30<03Q0=01T03@l<00`>2`0A4a003@l<00`>2`0?
4@h03Q0=00h>300A3Pl03`d>00h<3@0?3@h03Ph>00l?3`0>3Ph030h=00h@3`0@4Q403a<B00d?3@0?
4@h0418?014C400?4@h03@l<008030h;00@061XG02/]:P0I6aP03@l<0P0>40d01P0B51405aTF018D
4@0?4@h030h;01@F4`802`d:00@03a4>00L81P0>40d030h;0P0=3``02@0<3P/03@l<00/=2P0;3@X0
3a4>03do?0082PL04A<@00h?3@0200l?3`0700`<300;2`/03@d=01<C4`092@T02`/;00X:2P0200l?
3`8040lD00h03`l@00h>3P0?3`d0414<00`=2@0C50l02@T701@D5P0m?Cl08b8V00L71`0J6QP04A4?
00/;2@80410>01L02PX800l?3@0=3@/02`/900l?3@0L71X030d800d>2@0?40/030d800d>2@0?40/0
30d800d>2@041@4051D@00T:1@0H6A@061LC02TW8`081P80518>00l<2@0201@B3P0500`91`0=2`L0
518>00/91P0;2PH00P0?40X300h?2@0@00`=1`0?40X03Pl900X;1@0B4`d07AhH01<D3P0;2PD030/8
014@2`081`@04A0;00P7100=30P06aXE01lN6@8071/F00T03@`700`;1P0>3@P030/600l>2@0;2PH0
4a8=00d<1`0?3PT00P0>3@P0300@3`X04A0;00h=200B4@`04A0;00h=200A40/040l:00T80`0<2`H0
3@`700l>2@<03Pd800H02@P300/:1@0@3`X03`h900/:1@0?3PT200d<1`0700h=200@3`X040l;01@C
3`0H5a<04Q4=00h=2@0201LF4P803`h:00@030/700l>2P0?3PX03Pd90`0@3`/05`0?3PX03Pd900`;
1`0>3@T030/700/:1`0;2PH07QdI02<Q7@0@30P03Pd801<B3P0?3PX04Q<=03dn>@2:RhH0H69L01`N
600;3@L041<=014A3`0@3`d03`h<00803Pd;00@04A0>010?3@0@3`d040l=100?3P`00`0@3`d04A0>
014@3P02010?3@0500h=2`0H5aD0<S4_01<B400B4@l00P0?3P`0600>3@/03@`:00`;2@0>3@/04A0>
00d<2P0F5A<03@`:018A3`0F5A<03Pd;00h?2P0@40d04A4?010@4P0>3Q403PdB00T83@0?3Q80410@
00h>3P0<3@T03`h:01082`804PP<00/04`T<018:3@0A30d04`h@01<@4@0@3Pl03@/<00d<300?3`l0
3`h<00l>2`0200`;200H00l>2`0D4a0040l<00l>2`0E51404a8?00l>2`0I61H03P`=00`:2`0=2``0
40h?00l=3P0=2``04a4B01HD5@0B41404@l@01@B4`0B4140410=00l@300@40d03a0<0P0?3``01P0?
40`02`/800l?300@4@d03`l<014A3P803@d;01003Ph<00l@3P0A4a004Q@A00hC3`0:3`/03A8>00hD
40093`/061dI018D3`0A4Pd0414<01@E3`0G61<05aPB1P0C50l5018D3`804A<>0P0B50l0600C5A00
5QPC01<E4@0A4a00:2XW01@F4`0<3P/07AlL00lA3P0I6aP05ALD014C400@4Pl05aTF034f<`0C71T0
1Pl<014J5`0:4a003QLD01/T8@1NIf@0>44n03Ho?0804AXG00D02a@A00`E4P0D7AX0624N018K6003
00hG501E010I5P0A6QL04Q/H018K6@0D7R0041XM010J6`0B7AT04A`D01HQ600G8aL06BDH01HR5`0A
71@041/D01HQ700I91d06RDN01LR6`0B7AL072LQ03M2?P0G8Al05b8O01HP800C7Ad05R0P01TS8`0I
9B806RHS01/W900L:2H072TX01/Y:@0J:2T08S0b02Pg>P0^?d808S8f028b=@0P<S@07c8a024d<P0S
=S8093Lc028e<@0O<S008SDe02<e=`0Q<ST08C8j020c>P0U>Sh09C/m02<h>P0U>CX0:Shn02Tk>`0]
?cl09CHe02Ph=`0P;Rh0:3He02@a;P0U<RP09C4V028^8`0O:b007RPN01dW7@0R:R808RTQ01lV7P0N
91d07bDN020W800M:2407b/S020/9@0R;RL09c<[02Xf;P0V<RX0;3Pa02di<@0202Pd;@1?02/g;P0_
?380;3T`02dj<@0d@CP0;CXc028_:00`?CH0<clk03A0?00`?3P0;c/g02ll=@0X<R/0<cde03<n=@0e
@CL0=T<j02`j<`0X>3D08c<b02m1A00hBE00<DA;03iAFP0Z?4H0=4I@03E7D00eAdh0<T=;03A4C00_
?dH0<T5703M5B`0c@4H0:SLm02/g?00f@DH0>4E<034nA`0`?DH0;ce8034oB@0b@4T0<D990353A`0b
A4H0<TA40310@`0a@4D0<d9702ln@P0X=cX0:SPk02Pc=@0Z=CL0:CDe024[;00P:R/09S0a02@Z:P0Y
;bl0:S0]03<j<P1?ETd0K7AY03Dl<`0_=bd0:S8Y02D[9`0P9R@092XZ01hR8`0O8b@07B4R01`P8@0P
92D0720Q01TM7P0301dQ8P03020T9@0O8b<08BHR00<07B8M0P0I7QT03@0M8Qd082DP01/P6`0Q9R40
@DI101@I5@0L7Qd06Q/M01`M7`0K71h06Q/M020Q8`0O82800P0P8B<0100G61X07AhP01LH700G61d2
01LG7`0301PI7P0H6Ad05aPL00804a@I01405aPM01HF7P0G5al07alW04a?E00O8bT03A8H01@K8`0J
92`0@deF09RSZ@2;UIT04QXL01HK7@0?4a804ADD01<B5`0201@C60<05A@I00d04a8G01DD6@0G5Q/0
4a8G01@C600K6ad05aLH01HF5P0E5AD04A4A01<C4`092@T04Q8B00803Ph>01D04Q8B01lO7`0h>3P0
CDe=00410@0J6QX051@D00h<3@0A3a003P`=010<3@0>2P/04Ph?018<3P0=20T05Q8C01<?400?2``0
4Ph?010<3@0B3Pl01@0?2``0:P0@30d04`l@01<?400?2``04Ph?01<?400?2``05a<D04]7B00P71d0
3PX;00d92P0F4Q@030L<00d93@0@2a002PD:00h93P0A3A403PT>00T42@0P6b0061<H00`8300T7b80
2P@601@>40060@802`H7018<3P0;1@L03PP:01TC5@0K5AL04`d?00l92`0=0`@040H701<92P0;0P<0
4PP900l51PP040H700@03`D600h41@0?1@H040H71P0?1@H00`0>0`L03@8600d21P0300d21P0B0105
2@0?10P0304501052@0C20`02P4300h51`0A1`X03P<700d41P0<0`D040H901<8300B20/03P@700`2
1@0@1PT050T=5?ooool001_ooooo00<04a8@014A3`0?3`d00P0?3P`01P0>3P`040l=014@3P0A4@l0
4Q4?014@3P803`l=00T04A4?02HV900820H04A4?00`<2P0E5A<02`/9010@3P0=3@/00P0E5A<03P0?
3`d03@d;00l?3@0B4Q003`l=00/;2@0<30X03`l=00T91`0?3`d02PX800`<2P0<3P/03Q0=0P0?4@h0
3@0<3P/02`d:01@F4`0=3``030h;010B3`0A4a004A4?010>3`0?3@h03@d=00h=3P0>3Ph00P0?3`l0
1@0E5aH02`d<00H71P0D61L03a8@00<0418?02003a4>00h@3@0@4Pl01`T600P:1`0D5Q<01`T600H8
1@0C5A80418?00h@3@0<3P/02@/800lA3P0@4Pl04Q@A00@60`0D5Q<02`d:01PJ5`0j?3T03a4<00h@
3@0<3PX03@l:00h@3@0B5100004001PJ5`0;3@T05QPC00H81@803`l=01X04Q4A00h<3@0;2`T03Pd<
00T7200<30X05QDD00L51P061P@03`h?00h>400=31403@d?00`<300=3@d03Ph<01DE4`0820H04a<C
010@4P0820X04A0D01`L700n?S`0;Bd[00T91`8030`:00T020P6014A3`0C4a402PX800H6100@40h0
2``700d>2@0?40/00P0<3@P05@0?40/01@H100`=20092PD06Q/F01<D3`1lOGP071/G014>30030P00
30P5014>2`0510001`<001LD4@071P803`/8014?2`0>3@T02`X600d>200200`=1`0B00d>200;30H0
1PL100l@2P0;30H03@h801DF400:2`D04Q4<00`;1P0920<05QD@00d<1`0H5a803Pd800`;1P0F5A00
2`X50P081`800`0=30L03Pd8014@2`0200h=200F00L60@0@3`X07A`G00T80`0?3PT04a8=00H5000<
2`H03Pd800P70P0?3PT02`X5018A300?3PT030/600X9100;2PD030/600d<1`0;2PD03`h9010?2P80
3`h900/040l:00d<1`0?3PT040l:00l>2@0=30L03@`800l>2P0<2`L020L300X91@02014@30803Pd9
00T02`X600h=2@0>3@T030/7010?2`0C4Ph040l;00`;1`0=30P00P0>3@T01P0F5A403`h;01TH5001
00009B@P00h=20804Q4<01H03`h902<T7P20PG/0oooj0<G8`@0Z;BH05aXC00hA2P0E51804a8@010?
3@0>3@/03`h<018A3`0>3@/03`h<010>300A3@`04Pd:01<=3@0A3@`040l=0P0A40h2010?3@0600l>
300L6aT02`/900L610061P@04A4?0P0>3@/0600=30X02`X800d<2P0B4@l03@`:014@3P0C4Q006QTG
010?3@0D4a404a@?00l?300=3@/03Ph>00l?400>3Q00410B00d=3P0:2PX03Ph<014B3P0>3@T04`X=
01@:3@8050/>00<050d?01@>400?2@/00P0A3@h01P0>30d04A0@01HF5P0?3P`03Pd9014@30<04Q4=
00L03Pd901<B3P0>3@T04A0<01HE4@0:2@L040l=00803@/<02P04Q0A010>3`0>30d03`d>01<A4P0>
30d03@/<014?400?3P`03@h:00d=2`0?40/03`l<00h>300@4@`030`901@D4P0C50l051DA014A3`0:
2PP030`:00h>300B4Q005QPE01TK600J71T030l<01PJ5`0?51003A8>01HK5`0:3`T04A8=01<D3`0A
4P`03Pl9014B3@0D5@l04a@>0P0C50l00`0C50h04a@?01<E400201<E4P04018D4@0A4a004A<@014C
40<04Q@A020051HC01PJ5`0K7AX04A<>01@F4`0D5Q803a4<01LI5P0D5Q806Q`G01XL6@0H6QH04aD@
01PJ5`0V;2P06R0L01@J5P0<4Ph051XF01TO6`0=4`l0B4i:02L]:`0J81h06AlM01@J5`0C71L031D@
01DN6@0H8A`03AHC010I5P804a`K01`04a/L018J700A6A/04ATL01LN9P0B6b804a`P01@M700?6QH0
4A/E020Z8@0Y=BT06B@I01PR6@0H8a/06R@L00/G3@0/>2h05B0H024/9P0E81X06bHR01<M700K9B@0
92h_02<];`0K9BL04adN0P0H928201TU8`0b01PU9@0G9BD072X[01XX:@0U=3L08S4d02@c=P0S<SD0
7Bl_01h`;`0P<c408cHb028e<@0O<Rh08cHd02Hh=`0U=cT08cDi024b>P0P<cX09ca101he>@0/@D@0
9CPl02Xn@01UNGX0D69R02ho?`0/?3/0:CTh03E4@@0R;bP0:3@Y02Xf:P0Y=BT0930T020Z8@0O:B00
7B@L024X800N9Ad06b0J020U7`0T:b@06RHP01dZ8`0P;BH08c0Y02Tf;`0/>C8202dj<`0802Tf;`0V
<b`0;CXc03A1>P0[>2l0>TLn03E2>@0]>S4202hk=004034n=`0d@3`0=40l034m>@80;c/g05L0=D0i
03@m>00Z=Bd0?DQ004=@B@0_?CL0>TU603Q8A`0^?Sl0<3m403A5C00b@d/0@55I0311B`0a@TX0=DI>
02Pi@@0jBU40;ci502hmA00iB4l0=4=:030mA@0c@4P0:SLo0350A`0iAe00<3i702Le@00hAU00?4YC
03M8D00b@dT0;T1402do@@0Z>cl09CLk02dl@@0`?d@082lb028`<`0[=SP0:3@d02D`;`0S;B`09Bh]
02H_;P0W;Bd0>Clo03Hk>017CTH0TIV>0>[`iP17Cd80=Cdb02L^9@0X;RX092XX01hT900Q9BH07b<R
01/O7`0O8b@08bLV01`P800G6a`0720O01dQ8@0L82407b<R01lS8`0O9200724K01`Q700L8Ad061dG
01PM600C61@06QlJ02<X8P0Y;RX04aPC01XO6`0H6QT07b0R00`=3`0U9RP00P0H6A/0200Y:R`071dO
01lP8P0O82807QlQ00h?4`0H6Ah06AXO0P0K7240600H6Ah04a@H01<D600G61`07AhS01dM9@0L72@0
8b<[05QKH00H72803Q<I01dT:P0@62005QlV01XS:P0T;C407RHY010E5`0G6a`03a0B01<C5`0C4QP0
4a8G01<B60804Q4F0P0F5AX08P0C4QL051<H01@C600B4Q@05aLG0000000<30`05ADE01TI6@0A4A40
51@D010@400B4Q803Ph>00X:2P0M7Ad0410@00`<300H61P03Ph>01hL7@0@3Pl04Q0A01@@4@0C3a00
6ADF01PD5@0B3Pl06ADF01DA4P0@30d04@d>00l;300B3Pl6014=3P0M01DA4P0F4Q<03PX;00l;300D
41404@d>01HB4`1jMWL0;b//01TE5P0>2P/0<2`^01PC5`0@2`l03@P<01@?4`0<1`/01`8601XE6@0H
4aL0KVU]05mJGP0=20`04@/>00P2100I4aD09R0R00`6200>2@X00P0;1@L02P0?2@/03@L900P2100<
1PP03@<401H<3@0=0`@04PP900l51P0C2@X601061`803@<40P0?1@H00`0>10D03@<400l51P0500l5
1P0501462P0?10P03P<700l4200@1@T00P0?10P04@0A1PX040D901T>4P0T6Ad07Q<G00`11@0:0@<0
3@8601T>4P0A1PX040D901462P1lLGD05``@00L0000H3A403P<701Cooooo000Kooooo`0V010<2@0A
3P/040l;010<2@0@3@X040l;018>2`0=2PL040l;01DA3P0C4@d051<?010A300;30L03@h901DF4@0>
3`/0HV=N06Y[IP0C50l020T401<D3`031000;Rh/01lO7P071`L02PX:00h>3P0=3@d04A4A01@D500I
6AT0000001DE5@0D51@030`<00d=2`0C4a42018B400300h>30071`D03Ph<00L03Ph<04803@l<00h?
300=3``03@l<010B3`0=3``01@L401<E4P0A4a003a4?00d?3P0A4a804aDD00D71P0620L03a4@00T;
2P0:30/0418A00`>3@0=3`h03Q0<00T;1P0<3PT04Q@?01DG4P0L7Q/061XG01/M6P0=3`h06Q`K0001
000L7Qd05aPD00T:100>3`X02P/601DF400;30L030d701/L5P0R8ah04A8<00d>200C50l04A4=00d<
200<2PL03`/:00l>2P0A3P`04@d<00L60P0H5Q<040`;01lN6P0F4a803@d?00X93P0F5AX03Ph@00L7
2@0>3Q004Q8D01<C5@0:2P`2018A5P0T00d<400>3Ph0/k>a05QHEP0C4a405QHD00X:200A4@l0410>
00h>300=3@/03Ph<014A3`0=3PT03a0;00d>2@0<3@P04a@?018C3P0A4Pd03@h901HG4P0?40/03Pl:
01<D3`0D51803@d;00`<2P0>3@/03@d;010@3P0:2@L02`X800h>300B4@l04A0>0P0=30P02@0>3@T0
3`h:00l>2P0>3@T03@`8018A3@0>3@T03@`800h=2@02010?2`0600/:1@0?3PT03@`700h=200B4@`0
40l:0`0=30L01@0:2@@04Q4<01dL5`0B4@`030/600803@`700<03`h901@C3P0=30L00P0=30L01@0?
3PT040l:010?2P0?3PX03@`8008030/70P0=30P01`0@3`/03`h:00L60P0=30P040l;00d<200?3PT0
0P0@3`X02P0?3PT030/600/:1@0920<04Q4<01LF4@0>3@P02`X5010?2`0?3PX200`;1`0?00l>2P0>
3@T02`X600d<200@3`/03`h:00d<200>3@T03`h:010?2`0B4@d03`h:00`;1`0>3@T040l;00D03`h:
01d03Pd900l@2P0A4P`0414;01@E3`0N7aT0ADI00=KGd@27R8805aPB01@E3`0C50h040`;014=300B
3`h04a4B00D51@0:2PX06aXH014@3P0>2@H06@l>01/@3P0G2PX06A<C014=300C4Q00:2LU02TX9P02
010@3P0?00T91`0:2`P05aLE014C400<3P/0000001XJ600:2PP05ADC01lO7@0<30/04Q8@010@3P0>
3P`03`l=00804A4?00H051<?010?2`0>3@T03`h<010?3@0?3P`200h=2`0D00l>300>3@T03Pd900d<
200@30d030P901TE5P0<20T04@d>01/G600>2P/04Q0A010>3`0I5aP03P`=018@4@0F5A<051<A014@
3P0@3`d2014@3P1B00l>300;2PP020L501@C4@0@3`d03`h<00L6100;2PP040l=018A3`0?3P`03Pd;
018A3`0A40h040l=00l>300=30X030/9010@3P0;2`/030`:00l?3P0?3`l03@d;00`<2`0?3`l03Ph<
00d=300?3`l04A4?00l@300=3PT03a0;01TJ5@0H6A@0414<018C3P0D5A0030h901DG4P0K7AP051HA
00lA300B51403Q0;00h@300?4@h03a4=014C3P0A4a00418>00lA300B51404aDC01/O7P093@`03Q8A
00lC4P0D61L0310?010D4`0D61L03A4@00`@3`0@51<04QHC01<H4@0D6A<04QLA00lD3@0?50h041D?
00lD3@0A5Q004QL@00dB2`0@5@l04QL@014F3`0C61404AH?00lD3@804AH@01h05AXD01TN6P0L8Ad0
4QLC00lD3`0G7QH05QhC01@K4`0C6Q<04QPD01<I600?51L04aPL01@I800G6bH06alZ01LK9`0@5200
41LQ01DK900G72005alQ01`S8P1:D4`0_lW104A<A00P9al07bTP01XR6P0P:R4201/U700<01LQ6@0R
;2@04AXE01<L6@0B6aP07BHU01dU9`0H82806bDW01LS8`0J9RH06bLW0P0J9RH0100K9bL07b/[020/
;00P;Rh2028`<00P020^;P0S<c<08C4`028b<@0U=C808c@_01h_:@0S<c007bl^02@d=00U=3L08S4g
02Df?P0T>4<0:d5<02HmA@0W>d80Bf1V055TJ016FU/09CTg01T/:P0Z?CT093D_01LX800Y>2h09C8X
02Hc:@0R;bD082/S02D`:00i@c/201hU7P0;02L/9P0V:2<08RLQ02La;@2>VID0;3Lc02dh=00/=c<0
;cXf02/f<P0]>3@00P0Y=300100[=S80:CH_02/j<00Y>34202Lf;`1K02`k=P0`?cX0<D0k02hm>P0]
?3T0;Sdj02`k>00]>CL0=D4l03@o>`0b?cP0>4Dn03<o>`0Y=C80;3Pf02lm?@0c@D40<T11034o@P0_
?4<0;ca40390B@0c@TT0=4=:03E3C00hATl0=49;02Hg?`0hBE80=DI@0390B`0W>440;d9902Lh@00i
BU@0;Sm903E6D01WN880>daF03U7DP0b@4T0;C]403Y8D@0]?DD0;3m502/l@`0Y>Ch0:3Ll02hl?`0R
;Bl09c4b02/d<P0V;2X08RPV02@Y9`0R9RL0:2`]03Hj=`0]<R`0LWM`0:fcZ@0g?C<0;38X028Y8@0Q
9b<07bDS028X:00S9bH07R<O01`P7P0H71/08bPT01`Q7P0M8B007R<O01dR7`0E6AP03Q<?01/O7@0Q
8b807R0M01/M6`0K7A`06adJ01HH5P0K7A`071hL01`N6`0L7Qd071hL01dO7P0201`M7`<06a`N00P0
6Q/M01`M7`0H6A/07b0R01<D5P0A4Q@051DG01@C608061LL00/05aHK01TH7@0N7B806aXP01TH7`0H
5al06APP01LF7P0B4QX05APM01DJ7P02010E6@0N01HK8@0E6R0051LN01LJ7`0C5Q/03PlD010A5@0E
5Q/05QLL00X:4P0D5AX05QHM01<B600>3A<04A0E01@B5`0>31406aTL00h<3`0E4aH0518C00@20`0D
4Q<07Q`M04e;C01?CDh03`d>010>3`0A3a004Q0A0P0C4A801P0K6A`0BDM:00/9300<2Pd071XM00/9
30D040hA00@050lB01LC500G4a@04Ph?0`0A3@h2018>3`04010<3@0>2P/03@T:01@@4@803@T:00X0
4@d>00d92P0K5aP01P8301@@4@0C3a004Ph?00`82@0D41403PT;0P0?2@/01P0@2P`03`T;00l92`0?
2@/03PP:010:30806A<E03d040X<00d72@0@2P`03PP:010:300A2`d03PP:014;3@0:10H03PP:00@0
000K5AL030L800l4200C20`040D900d21P0B1`/04@H:00X00`0=0PH04@H:00X00`0G31003P<70105
2@0B1`/04`P<00l4200=0PH03P<700l4200<0@D040D904Hk?`1<@DD09Q/O01@8300900405@T=0145
2@0=0PD04PH:00h21P0@10P04@D901<72`0E2@d05PX>01X?4`0<0`D04`P<03<X;01EBTh030450146
2P0U6Qh06@hB00`11@0@1@T05@X>01Cooooo000Kooooo`0J00l<2@0B40`04a4=014?2`0@3PX04@l;
01LD4@0A3`/040h:00h<200=2PL040l;00P9100@4@`02@X501@E400<3@P08R<N01DF4@0B4`h03a0;
00/<1`0@4@`0=CHa01dM7@0<30`300h>3P0901@D500J6QX04a<C010@400G5aL0<c<c010@400=3@/0
2`/900803Ph<00<03@d;010@3P0>3P`01@0>3P`600d?301600/=2P082PL051HC01@E4`072@H061XH
00d?3P082PT04A<B00`>3@0:30/03@l>00X<2`0;3@`03a4@00/=300:30/03a4=00lB2`0?4@`0418=
00d?2P0@4Pl051HC00P:200U9bH0KFm^010B4@0<3Pd0418>00/<1P0E5Q003@h8014B300:2`H04a@>
01XK5P0J6aD03Pl:00l@2P0A4P`07AdI02HS8@0E4a003@/800l<2P0D4@l061DC00`91`0H5Q<03`d:
01LD4P0@3P`02PX<00l?4P0:2Pd0410C018A5@0J6Ad061PK00`;3`0B4QD03PhA00/:3P0B4QD09bLW
01`L6`0U9B<01`L6018B40L03`l=01002``700l@2`0@4@`03a0;018C3P0=3PT04a@?00T:1P082@@0
4Q<>00/<1`0C50l0410>00`<2P0?3`d0410>0`0=3@/01`0>3P`0410>018B400A4@l03@d;00/:1P0<
2`L00P0=30P05P0<2`L02`X6014@2`0>3@P030/600d<1`0>3@P030/700X9100>3@P030/600h=200D
4`h04A0;00l>2@0>3@P040l:00l>2@0F5A0081lJ018A300>3@P200l>2@0D010?2P0D4`h030/600l>
2@0A40/040l:00d<1`0<2`H03`h:014@300B4@d04A0<00h=2@0<2`L03`h:00d<2P0C4Ph030/800l>
2P0920@700h=208051<>01H0QhJ1030_:P0>3@P03`h:00d<200>3@T03`h:00h=2@0<2`L03Pd9010?
2`0?3PX03@`800h=2@0?3PX040l;014@300?3PX03Pd900l>2P0@3`/03`h:0`0>3@T0100?3PX03`l:
00l@2P0>3`T200d>200b014B300F5a40;RlY01dN600E5Q801@H101DE4@0D4@d04a0<00l=2P0D5A40
3Ph;018D400:2PL03`h:01<?2P0G3@T07A0<01hA3`0F3`d04Ph=014@3P0E518051<A00d=2`0:2PP0
4a<A00d?300:2`T0;Bl/03]0?00F5Q@02`/901TI5`0:2PP05ADC01HF500@40h04Q8@01HF500D5180
4Q8@014A3`0C4Ph040l;00h=2@0?3PX040l;00l>2P0>3@T200l>2P<040l;01<03`d>010>3`0=2``0
2`T:00d;300A3a003@/<01@B4`0_;Bh0clg>040n?`0@3Pl040l=018A3`0C4Q004Q4?00l>300<2`T0
3@`:00804a8@00L04A0>01@C4@0B4@l071/I014@3P0;2PP03`h<00804A0>00T03`h<00h=2`0>3@/0
3Pd;00d<2P0<2`T0410@00d=3@0>3Ph00P0@41003@0?3`l03@d=00l?3`0?3`l03Ph>00l?3`0A4@l0
4Q8?014B3@0B4`h04A8=00d>2@0<3@P00P0A4Pd02@0<3@P04Q<>01LH4`0@4@`04A<@018D4@0>40d0
3a4>01@F4`02018D4@0D01@F4`0C5A804Q@A01@F4`0D5aD05ATI01<G5`0G6a/05ATI00dA4@0A5AD0
4aLG01@H600?4a<04ADE01DI6@0A5Q8041D>01<H4P0D6A82018G4008014F3`0?50d04AH@01@I4P0?
50d041D>01<G3`0C5Pd201DH3`0]01@G3`0F6A805aTC01PJ5@0E5a806Q`I01<E4P0@50l051TA02Xb
9`1FGE@06B0I00lE4@0B61L04aPK01DJ7P0D624051PR01HJ9P0B5B804aLS01@H8P0E6B805AXP01LL
800L8R<0LgUi0;Fk^@17CDP07B@M01LO5@0M91d08R`S01<M500F81T04adF01TS700C71P07RLT020Y
9P0F7ah072@U01/S900N:2X06B@V00806RHX04006BDW01/X:@0N:b/07b`/01h[:`0M:RX07R/Z024^
;@0R<3008c<c02Ph>00_?ch0<40m02Ti=@0N;bT0830]020`;P0W=cH0:STl02/j?`0]?TH0AEUU0316
D`0S>D@08SHo0396C@0^@dH0<TE902Tm?00V>SH08SDa02Pl=00M<BP093@[02@a:@0X=Bd09c@/02Td
;@0/=c00;SPa02L]:00U;2H09BXU02HZ9@0Y;b/09S0]059MF@0X<bl0;3Lc02/f<P0c?SX0<C`h02lj
=P0]>3@0<C`h038m>@0]>S<0<d8i0350>@0_?SL0;C`e02hm>00a@3/0;Sdh0`0_?S/01`0X=SH093<`
02lk>00a?CT0=40l03M3?`0a?C/00P0[=cD0AP0Y=CD0;SXj030l?00/=cT0;STn03E0A`0e@TX0<d18
030mA@0^?4D0<3i702Tg@00lCEL0;d1;0311C00^?dX0:Sa80396D00[?DX0<dE@02doBP0^?dT0BU]U
02`mA`0`?TP0<T1:0350B00kB580;Si602Dh?`0U=ch0<T9802`k@00W=CL09S0a02Tc<P0Z<c409R`X
02DZ9P0Z;bX0;c4c02/];`0_<S0092TU02`a:P0m@cX0:2hT02@Z800a>340>3hl02T_;@0T:RX09RXY
01PM6@0Q9R808RLS020U8@0Q9R805a`H028W8`0O92007R<O02`a;@0h?CT07b4P01dO7P0L7Qd07AlN
01hP7`0K7A`201dO7P<071hM00@06adL01`M7`0K71h06a`N0P0J6ad02P0I6Q`07QlQ01`M7`0B4aD0
6Q/M01`M7`0J6ad06ATK01/K7@0J6Q`201PG700O01XI7P0M728071/Q01/J8@0M72@071/S01PH800E
61d05a/O01@I700G6Qh07b8V020R9P0I6Ah071`Q01TI7P0F51X061HL01/J800D5Qd05aLO01TI8@0?
3aH07ahT010?5@0G5Q/071XO018@5@0D4QD06A@H01LB5P0201PF5`0402PV9`0K6AX07adN014?4080
4Q0A0P0A3a02010>3`0601<A500h=ST0518E00`;3@0E4aH04a4D1@0A3a800`0@3@l040`=014=3P03
018>3`0<014=3P0@30d04Ph?01<?400B3Pl040`=00`82@0A3@h06ADF00d92P0D41402`L80P0>2P/0
1@0?30`04@d>02HS8`1VHV<04Pd=00803`T900X040X:00l92@0?2@T040X:014;2`0?2@T03@L700h8
200A2`/04P`=0P0>20X2010:300W00h82P0E3a401000010:300=1`T040X<00d72@0@1@T04PL;0146
2P0?10P04PL;01462P0F2`l02`0400l4200P5AT0<RL[01H;3`0A1PX04`P<01@93@0A1PX03`@80105
2@0C20`03`@801472P0F2`l07Q<G028H6`14>3`07Q<F00/20`0A1PT050P<00X00P0?0`L040@80080
4@D90P0C1`/0300:00<05@X>00`31@0800405@`>01872`0:00<04PL;00d31P0=0PH050T=01052ACo
oooo000Kooooo`0600T8100=30P03`h:00d<200<2`L02`X60P0>3@T02@0B4@d04A0<014@300G5Q80
3a0;01<D3`0720<04a@?01@E400200l@2`0G00X;1P0720<05QLB00X;1P061`802`/;00T92@0=3@d0
4A4A01TI6@0R8R80BDU900h>3P0820P02@T902DU9@010@403@d;00l?3@0M7A/05aLE00/;2@0@40h0
1P0>3P`600d?300:01HH5@0C5A805QPE00/=2P0Q8b00ADM502DW9P0B51<03@l>00h@3`803a4@01`0
3@l>00lA400A4a803a4@00d?3P0?4@d03A0900`>2@0>40/02`d800d?300@4Pl020X700T;2P0B51<0
2@/:01hP7`0=3Pd02``7018B400A4Ph06AXE00`<2P092PH02@X500X:20092PH03a0;0P0A4@l0200A
40h03Pd;00h=2`0>3@/03@`:00l>30030P003Pd;0P0<2`T03`0@3`d03Ph@014A4`092@/03@d?01<C
5@2XZ:X0DE5C01XJ700?3a4030`>00l?4@0A4A8092@T00l?3@0201<C4@0403Ph=P0>3P`03@d;00h>
3080410>00<03`l=00h>300<3@P00P0@4@`02`0>3`X0414<00/<1`0<3@P051D@010A30092PD06Q/H
09nPV`0J6QP03`l=00<02`/900T03`l=00d=2`0<30X03@d;00h>300<30X020T400d<1`0>3@P00P0?
3PT0100>3@P03@`7014@2`0>3@P300d<1`0<00/:1@0?3PT04Q4<00d<1`0<2`H03Pd800/:1@0@3`X0
3@`700`;1P071P801`H10P0=30L01P0:2@@02`X500/:1@0;2PD03`h900h=20803`h900d03Pd800/:
1@0:2@@03@`800h=2@0?3PX03Pd900/:1P0:2@D010<101DD40081`<030/800803`h:01003Pd800`;
1P0<2`H03Pd8010?2P0A40/02PT60040000_;RT0j>OR06]ZI@0D4`l03@`800h=2@0@3`/03`h:0P0=
30P300h=2@0400d<200>3@T03`h:00h=2@<03`h:0P0@3`/0200>3@T03@`800`;1`0=30P03Pd9010@
2`0@4@/03Pl90P0?40X05P0>3`T02P/500l@2P0E5Q002``60493?@1BDdd04Q8:01DE3@0>3`L04Q<;
010C2P0G6Q405aP@01@F2`0=2`<06a@<02PO600H3PP03PT6010<2`0@3`d200h=2`0M01<C4@0E5A<0
2PX800h@3@041P<06A/H02`a;@0I6AL0:RXX014A3`0G5aD05ADC014A3`0?3`d051@B01PH5P0B4Q00
3Ph<010@3P0B4@d03`h:00h=2@0?3PX040l;00d<200A40`040l;00h=2@0=30P00P0<2`L03P0=2``0
5aDF00h<3@0I5aP04Q0A00/92P0<2P/0518C01dK7011?d0071XK018@4@0?3P`04A0>0P0B4@l03P0?
3P`030/901HE4`0E51806APF00D40P0?3P`02@P6010?3@0=30X02`X800d<2P0<2`T02PT70`0@3`d3
014@3P04014A4@0?3`l03`l?010@40804A4A00`03Ph>010@400@41003Ph>00l?3`0@40h03`l<018C
3P0E5Q404A8=010A300C50l2010A300400`=200@4@`04Q<>00`=20804aDB00L03Q0=014C400H6QL0
51HC014C400D5Q<05ALD00804aDB03005QTF00lD400G6aX07R<P01PM6@062PT04QHD01@I5@0I7A`0
4QHD010E4@0C5aH04AHA010E3`0D6A<05AXD018G4@0A5Q0041D?00hC3@0@5@l05AXD014F400?50h0
4QH?01@G3P0E60l05QTA01LJ4`0H6a@061XD01HH4`0B50l071hK01LI5P0C5Q803a@=04eEBP22RH40
7RDN01/R6`0B61D04ALG01<H6`0B5a/04aPN01LL8P0D624201HK8@0H01HK7`0E6Qh061dP020U9`0<
4Q80:S0^01LM6P0L8Qh05A/G01TQ700F7aX07bPS020Y9@0>5a@06R<P01LP7@1NIf@0FV=P02D^;@0M
9RD06R<Q01hX9`0J9RH06BLX0P0H9RL00`0L:R/08S0`01d[:`0301h/;00N020^;P0R<3008S8b02Ti
>@0`@3l0<D4n02Ph=00O<2X07Rh[024a;`0V=SD0:CPk02Xi?P0Y>T80JGf803Q>F@0S>T807c<l02Xo
A@0aATT0>Ti?02Xm?00mD4`0<4<o03Q<A00_@3P08c8[02Db:`0V<b`0934Z0P0S;RP04`0T;BP0:S0/
02X`;00X;BT0:Rl[02dc;`0Y<c008bhZ02/f<P0^>CD0<chj03@o>`0e@3`0;cXf02dh=00c?SX0<Sdi
02Xg<00/?3<00`0_?SL02P0a@3/0<T4l02`k=P0]?3T0;chk030o?00[>CT0:3Ld02Xf<`0`?3P203Q4
@00X034m>`0_>cT0;SXh02Pd=00Y=CD0<3`l03E0@P0b?D40<Se303A1B@0e@TX0<3e502`j@`0b@4T0
;Sa502m0BP17F680PY>M03e>F00]?d`0<dID03=5D`0bA580>4YF03I7D@0mCUP0=TM?03Q6C`0fAD`0
<T5603E2B00[>d408S<j02Df?@0gB4`0;Se002Xf>00X<S<0:38a02L`;@809B/W01D0;34]02HZ:`0Z
;Rl09b`Y02ld<00P9Al0:RlW02/a9`0S:240<3L`03@j>00U:bT0;38a02@X9`0J7a/07b@P01`Q7@0M
8Qh082DQ01XO6`0Q9R800P0H7AT00`0U:RH09R/W01hP7`0501hP7`0301lQ800N81l07AlN00806adL
00<06A/J01XK7@0J6ad00P0I6Q`201PI6`0:01dN800H6A/07AhP01LH6P0=3Q007QlQ01@D5P0F5QP0
61PJ01PG70806QTN02@05aHL01DD6P0D4aT05QDM01LF7P0E51X04Q<G01<G6P0?4aH041@G01LH700E
5QX051<H01LF6`0F5AX05A<H01LE6P0H5a`03a4G01XJ8P0G5al06a`Q00/:400T8bT06QTN018@5@0K
6Ah03P`?01hI7@0G4QH02`T:00h<3@0I5aP04@l@018@4@081PL2018@4@804@l@0P0@3Pl201<A5004
00D31P0A3a80518E00800`D04@lB00T04PlA00l;300?2``04`l@010<3@0?2``04@d>010<3@0>2P/0
0`0?2``03@0A3@h04Ph?01<?400?2``0:RHW00<0000S7b0030P900<0000B3`l07ATJ04Q4A@0<1`P0
0P0?2@T02P0@2PX03`T900l92@0C3@d05a4A01H@400A2`/02`D500T30`0;1@H200d72@0:00h82P0?
2@/03PP:014;3@0>20X04@/=00T31@0=1`T04P`>01462P804PL;00P04@H:01872`0B1`/03P<700d2
1P0E2Ph04`P<01`A5@804@H:00<04PL;01@93@0A1PX00P0@1@T0300?10P01`0001D:3P0E2Ph05``@
00P00@0:00802`0301/?4`0>0PH02`4301<72`H03`<700H04@H:00h51`0700007a@H01<8300=0PH2
00l4200400/0100>0`L04PL;00X00aCooooo000Kooooo`0400d<200A40`04Q4=010?2`803`h:0P0@
3`/01@0D4`l04Q4=00`;1`0=30P03Pl:00802P/600D04A8=00d>2@0C50l030d800h?2P0201<D3`03
00l@2`0H6A@03`l?00803Ph>00l03@d=010@400E5AD06ATI01<C4`0A4A402PX:00d=3@0B4Q804A4?
018B400O7ad05QHD00X:200?3`d01P0>3P`600d?300:00/=2P031@8010H300/=2P072@H07b4O02<U
900F61L03a4@00h@3`80418A00<03@l>00h@3`0?4A000P0?4A006`0>40`02`h700/=200@4Pd03Q0;
00h@3@0:30T05aTF00P:2@0G6AP02P`;0001000>3`l051@B02XZ:P0F5QD030`:00h>3P0F5QD03`l=
018B4P0?3`h03Ph<00h>3P0;2PP02PT700l>300201@C4@0K00l>300C4Q0030/900h=2`0920H01`H4
00`;2@0D51H05ADG00/;3@092@/020P:09FEU`1?Ce4061PJ00d=3`0;2`d03@d?00l?40030`<04Q8@
00l?3@0b<S00K6aZ018B400<30X03@d;00803`l=00L03Ph<00d=2`0>3`X0414<00d>2@0;30L03a0;
00803@h900L01@H300/<1`0S91l020T601@E400F5Q@03`l=0080410>00X03Ph<010@3P0>3P`03@d;
00`<2P0=3@/02`/900P9100=30L03Ph60P0?3`L05`0>3PH03@d5014A2@0?3`L03Ph6010@200?3`L0
30`400l>2@0B4@`03@`700`;1P0>3@P02PT400d<1`0<2`H03`h900h=200?3PT051<>00d<1`0920<0
30/600802`X500<03Pd8010?2P0=30L00P0;2PD0100<2`H03@`700l>2P0=30P400`;1`0700`;200[
:RH05QDA03/j=P0H5a<00@0000h=200200`;1P0>00h=200@3`X04A0;014@2`0O7QT01`H203Lf<@0C
4Pd02@P400d<200?3PX040l;00h=2@0=30P200l>2P803@`81@0>3@T02P0?3PX040l;010?2`0@3`/0
3`h:00d<200<2`L03@`800l>2P0?3`X200d>200J010A2`0B4`d04A8<014B300?40X0414;00/<1P0H
6A<05AHA00/<100N81D02`d600T;000L7a@02`l50085000@4PD06Q/A01XG3P0J5Pd04P/400l:1`0?
2`X040l=014@3P0B4@l2018B400B00X:200E5a@061XG01dO700Q9R804a<A024Q7`0D51806ATG00L7
1@0K6aT0410>01<C4@0D51803@d;00X:200?3`d04A0<0P0?3PX00`0@3`/03`h:00`;1`02010?2`80
3`h:00L04A0<018A3@0=2``04a4B00X82@0E4a@040h?00803`d>00L02@L801@B4`0100006ALH00P6
1`0B4@l04A0>00@040l=00T05A@B00/:200D4a402`X8038a;`0G5Q@03@`:010?3@0?3P`00P0=30X0
100>3@/03@`:00d<2P0=30X300h=2`0E014A4@0@4100410@00l?3`0@41004A4A00l?3`0A4A40410@
00h>3P0?3`l0410>014A3P0B4`h0414<00h?2P0:2`H020T4018C3P0A4Pd03a0;00804A8=00P03@h9
01<E4P0D5Q<03a4>014C400H6QL04aDB010B3`804aDB0P0A4a004@0C5Q<051TC00hC3`093PT051TC
00hC3`0D6A@08RLQ02X_:`0K81/03A8<00hC3`0@5@l04aPB01DJ500D6A<04AH@008041D?01d03A8<
00lD3P0F6aD04QLA00lD3P0C5a0051L>01DH4@0G6Q<061/D01PJ5@0F61<05ALB01@F4`0P8Ql071hK
01DI5P0M8Q`04QTA02H]9P0L8a`05ahG01`R7`0B61H04aTI014G5`0A5QT05AXM018G6P0301@L7P03
01DM7`0I8R408BXY00808b`[01806b@R01dV8`0E7Q/06R<P01PQ7P0S;RX0:S@b01/U900F8Ad06B@P
04aGD`1;EU807RTU01`W8`0L9b808B`X01/W9`0J:2P201TW9`0601h/;00S<C406bTY024_;`0T<S80
8c4a0P0R<3008@0L;2`0830`02@d<`0S<c00830/01d^:00Y>CH0;3`j02hn?@0_?T40;ci302Xk@`0j
C5H093Q302/oB00X?4D0:Si402i1A@2>XZ<0>De;03Y=B@0mD4`0=dU301DV800Y=c00:cPa02Xg<00X
=Bh09C0Z028]9`0R:bH09RlZ02Pa;00202dc;`0?02Xc;P0^>CD09S8^034m>@0b?SX0>DE1038n>P0l
B4@0=D4m034m>@0f@Sh0<clk02/h<@0^?SD0<D0i0080<T4j00@0=4<n03I5@00c@Sd0<3ll0P0_?S/0
B@0/>SX0:STf02<_;00Z=S80<Shj034m>@0/>3H0:SHd02Pd<P0U<C409S8b03A0@016DE<0@4]?038m
@`0gA4X0>DI=034nAP0[>T407bde01h/=@0]?TH0;d1905IWL@0R<cd0;3e;0395E00gB5P0<dEC03e?
F`0nCeT0<45:02hoA`0^?D@0;Se20350@`0d@TD0:cTm020_=00S<SL0;ce202Dc=P0[=SP0:38c02H`
;`0T;BX08bTU02D[9`0[<2`08RHW038f=`0U:RL09R/W01/P6P0T:B80:c0Y020U7P0U:R@09BTX01XN
7@0W:b/09BTX02<X900L8Ad041DA01`Q7@0J7a/07b@P01`Q7@0H7AT06QlK01PM6@0E6QH00`0P8R40
1P0N81l07AlN01dO7P0O8B007R0O01dO7P806adL00<06A/J01XK7@0J6ad00P0I6Q`201PI6`0D01HG
6@0E5QP0824S01<D5P0T9BL05aPJ018B4P0D51D05QHH01PH6P0I61`061LL01XI7P0G5Q`05QDK01PG
7@0I61l06APN01@E6@0G61X201<D5P0501PH6P0F5QP04a4D01DC5P0F51L00P0G4QH04`0F51T09BL]
00d>4`0@4AH051DJ00P7300E51T092<X010>4@0U8bH040hA01LC500B3Pl06ALH01@B4`0F51D04Q0A
01HD5@0C4A800P0@3Pl02P0A3a004Q0A018@4@0B4140518E01dK7P0=2`h03P`?02<Q900F51L500d;
3P0400l<3P0:1PL02@D6014=3P8040`=01<05a<D01DA4P0?2``03@T:00l;300@30d03`/<00/7200A
3@h02PH7020L7@0N6Q/0MW9c00X61`0C3a006aLH00<0000G4a@04@`<00803`T900X040X:00l92@0?
2@T08Q`L02XT900I4a<030H600/51@0<1PH03@L8100>20X02`0?2@/0100001D?4@0:10H01P0200d7
2@0>20X03P<700d21P0?10P040D900803P<701<03@8600h31`0E2Ph02@0200h31`0?10P040D90146
2P0C20`04@H:00l4200A1PX0714E00P00@0?10P03P<701D:3P0>0`L06PlC008040D900<01`0000h4
1`0B1`/00`0>0`L300d21P0<00l4200B1`/0304501hC5`0800403`@801052@0B1`/03`@800d21P0>
0`L030455?ooool001_ooooo01403Ph900l?2P0>3PT030`800d=2@0@40`04A4=00/;1P0?3`/04a<>
010@300>3PT03a0;00/<1`0H6A@04a@?00X;1P02010A300700/<200A4Pd03a0;00`=200A4Pd03`l=
00l?3P0200h>3@0900d=300>3Pd03Ph=00/;2P0:2PT05QHE00H61@0C4a8051@B00803Ph<00<030`:
00/;2@0@40h01P0>3P`600d?300900h@3P0B51402P`900h@3@0<3P/02`d;00`>300?4@l0418@00<0
3a4?00<04Q@B010B400<3P`00P0>40h05@0?4@d03A0900`>2@0A4`h03Q0;00d?300>40d020X7014C
4P092`X030h=01LI600>3`l030`=01LH6@0>3Pl0410A00X;300A4Q<03@h?00h>3`0200h?400S00l@
4@0B4Q404A0?00l?3P0@3`h03`l>00`<2`0:2@P04A0?00d=300<30/04Q8A01hM7@0;2`/04Q8C00h>
3`0C4a@04A4B01@D5@0E5AH02@T:00l?400;2``01`L800h>3`0A4@l03Ph<01@D4P0;2`X0:2PV018B
400>3P`03@d;00h>300=3@/00P0>3P`05@0<3@P03a0;00`=200:2`H0414<00l@2`061`<05QLB00D6
0`082@@03a0;010A3P0:2PP02`/901DE4`0G5aD0410>00`<2P0@40h03Ph<00d=2`0200h>300300`=
200;2`@030`300803@d400D030`300/;0P0>3PD03@d400l?1P02014A200300h>1P0:2@@03Pd80080
30/601H04A0;00h=200B4@`03`h9014@2`0>3@P02PT400`;1P0?3PT03@`7010?2P0?3PT03@`7014@
2`0>3@P02`X500X9100;2PD03@`700l>2@0A40`040l;100?3PX01P0>3@T0>3Lc01`K5`0G5Q805QDA
01LF4PH03Pd80P0=30L03@0E50l03`h:018A300;2PD03Pd900l>2P0>3@T03@`800l>2P0B4@d040l;
00`;1`0=30P00`0>3@T200d<200;010?2`0B4@d04A0<018A3@0A40`03`h:00d<200?3PX04A0<00l?
2P0<3@L00`0=3PP2010A2`0C01@E3`0B4`d030d701<D3P0A4P`04Q@<00/>1P0@4PX03Q4700D8001@
ETT0=cX^028U6`0>40L04A8;01<A2`0@3@P04@d;018>3@02010?3@0E00l>300=3@/03Ph<01hN700D
5Q<06A/H01DG500;40`0410>01@D4P0B4Q005aLE04I6A015AD<03Ph<010@3P0?3`d03@d;00`<2P0>
3P`040l;00803`h:00<040l;00l>2P0;2PH00P0@3`/0400A40`04a8>01PG4`0K6QH03`h<00`:2P0C
4A404A0?00X9200B41004a8A00h=300=30/071XJ00d;2`0A3`l2014@3P<040l=00h04A0>00d<2P0G
5Q@01PD303Th=P3<blT0>3Le01<B400?3P`03@`:014@3P0@3`d03Pd;018A3`<04A0>0P0@3`d2010@
3`0300l?3P0>3Pd03`l>00804A4@00X04Q8A014A400?3`h03`l>010@3P0@4@`04A8=00/<1`0Q8Qd0
9BHQ0P0A4Pd0300@4@`04Q<>01<D3`0A4Pd03a0;01@F4`0F61D04A<@018D4@0F61D04aDB014C4080
4Q@A00L04A<@018D4@0D61<0314;01lT7@29SXP0<cPa00803Q<<00`05Q/D01hS700G71D04AH@01<H
4P0D6A<051TD01DJ5@0C61<04AHA018G4P0C61<200hC3P0E01@I500B5a804AHA01@I4P0E6A404aL@
01DI4P0G6a@05ATC01<F4P0F6AD05QTF01hQ7`0H6aT05aXI01@J5@0H7QT04aTD018H4`0D6QD05A/F
00807bHP00H06R0L01LM6@0I81/05A`G01@M6@0E7QX201HO7@0E01PQ7`0N9bH06B8R01DN7P0K92@0
8b/^020X:P0J8RD06R@U01HP8@0O:BX08R`/028/:`0J92<072LS020[9`0J9B008B`V01hY8P0O;2D0
6bXW00807B`Z00T072/Z01h];00Q<2l072/Z02@c<`0Y>3P09SDe02<b<P0U=3@00P0Q<C40KP0P<2l0
830]02@e<00Z>cD09cLd02hn?00]?C`0;Se002hm@P0V=cl0<dI>02TmA@0^@TT0:Ce402e1AP0^@T<0
;3lo02Pk>@0iBTT0;d4m02Hg<P0Y>S@08c0Z02Te<00X=2l0:3D_02Ha;00P:bH09S0/02La;00V<2/0
;CLc038i=P0/=S80<3`i03Q4@@0c?c`0=D4n03U5@P0d@3d0=d=003A0?@0`?3T0<Cdj030l>@0/>3@0
<40g030o>00^?CH0;C`e030o>P0b@C`0>dY503I5@P0c@Sl0<D0m02/i>@0X=c@0:CDb02/g<`0b?SX0
;c/g02lk>@0d@3h0<clm02`h>00T<300:SHf03U4AP0oBTd0>TE:03]8CP0iATd0<Sm602dl@`0`?dH0
<Cm7049CF`0]?TH0:S]402m0B@0dAE<0;d9C03]<GP0eAUH0?e5O04QHI@0`@DX0=4E<030oA00Z>S`0
;Cdm02`j>`0/>S`0;3Xn02/i?@0X=SP0:3Df02`g>00Z<c80:34`02@]:P0T:RL09R`Y02T^:P0T:BL0
:c0^01hS800S:2@082HP0P0W;2H01@0T:B<09BXV02DY9@0Q928082<Q00807R<O00@0724M01lT800e
>SH0;c@`0P0M8Qh02P0N8al082DQ01dR7P0M8Qh07R0O01lQ800P8R407AlN01/M700N81l201dO7P<0
71hM00@06adL01`M7`0K71h06a`N0P0J6ad05@0I6Q`06a`N020Q8`0P8B<07QlQ04i?D@0H6A/061PH
01LG600H61T06QXL01PH6`0C4aH06aXO01LF6`0E51T05QDK01LF7@0G5Q`04a@G01LG600201DE5P0H
01TH6P0F5AH05Q@F01PE5`0I5QP06QHH01TC5P0G4aL0:R`a01dN8`0K72405QLL01DD6@0A41D04a8F
01PF6@0I5aX04Q0B01DA4P0F4Q<04Q0A01<A4P0B41404a4B0P0A3a000`0@3Pl04@l@014?4003018@
4@06018@4`091`X03`d@01DC5P0Y9bX05Q@G1@0B41<02`0M6Q`06aLH01<?400E4A803`/<00d92P0H
51D06ADF018>3`0A3@h04`l@00804Ph?00`02`L8014=3P0E4A804@d>00/7200T8B40510A01LC500@
3@d0510A00T51P0@2`/200l92@0:010:2P0?2@T03`T9014;2`0?2PX03@L7014;2`0E3`l04P`<010:
2`804P`>00d03`T;00d72@0?2@/02PD601D?4@0@2P`0DD]=01/E5`0=1`T050T=01462P0E2Ph05``@
00804`P<01P05@X>00`11@0A1PX040D901P=4@0A1PX03@8600l4200A1PX040D900l4200@1@T03PD7
01052@0E2Ph040D900h31`0C20`04@P:00h51`0A1PX02`8400h41`0;0P@300h31`<03`@800T04@H:
00h51`0800406@hB00h41`0D2@d03@8601052@0?10P00P0=0PH00`0?10Soooooooooo`0Booooo`00
6oooool0400B4`h04A8=00h?2P0<3@P0414<01DF4@0W:2<051D@00h?2P0B4`h0414<00`=200C50l0
3@h900h?2P082@@2010A300300d>2@0F5a805AHA00804a@?01<020T4010@3P0@40h03`l=014A3`0>
3P`02PX800l?3@0A4@l03Ph<00`<2P0>3P`04A4?00d=2`0@40h03@d;00h>300=3@/02@T700H03Ph<
1`0=3``020072@H020X701DG500;3@X0418?018D4@0>40d02`d:0P0=3``02`0C5A807AlL01PJ5`0>
40d0418?014C400=3`X02@`500P:1@0?4@`0418=00803Q0=02H04A<@018D4`0>40l0418A00P:2@0C
5AD030d?01HG6@0<3@l03a0B00/<3P0P8B<07AhP00l@4P0>3a403a0B00`=3`0;2``03@d=014A4@0D
51@04Q8B00`<30061PH05aLG00`<30092@T05ADE020P800A4A402`/;01<C4`092@T01@D5014A4@0B
4Q804a<C00X:2P804Q8B00l03@d=00T91`0?3`d02`/901/K6@0?3`d03@d;00l?3@0>3P`030`:00/;
2@0<30X03`l=00L80`0;30L00P0>3`X02P0A4Pd030d800h?2P092PD06AXE00l@2`082@@05QLB01LG
5@0=3@/200X:200:00P81P0;2`T03@d;00X:20092@L02`/900`<2P0;30L03@d500h>10803`l500D0
3Ph400d=0`0:2P002PX100d=0`02010@1P0F00d=1@0<2`H03`h900`;1P0;2PD03Pd800/:1@0>3@P0
3@`7014@2`0B4@`03Pd800l>2@0=30L02`X500h=200=30L02`X500l>2@0:2@@02`X500`;1P<03@`7
00d030/700l>2P0@3`/03`h:00/:1P0920@03Pd90040000H5a<02`X701dL600;2PH03`h9008040l:
00H03`h900`;1P0;2PD03Pd8010?2P0<2`H200l>2@0300l>2P0>3@T03`h:008030/700H03`h:01@C
3`0@3`/02`X600`;1`0?3PX200h=2@0400`;1`0;2PH03`h:01<B3P804Q4=02004a8>010?2`0>3@T0
40l;01<B3P0B4Pd04Q<=01<D3P0<3@L020T300`=1`0C50h01PL1014B300G61803Pl900l@2P0;3@P0
51HA01<E3`0F6A804aH=01PK4`0K7QD03A0900d@2P0C5A8020X700d=3@0=30X04Ph=018A3`803Pd;
02d05QHD01PH5P0K6aT02`d;01/M6P010`0041DA00h>300I6AL0410>01PH5P0000007AdK00/;2@0<
30X03`l=018B400A4@l030`:00l>2P0>3@T03`h:010?2`0>3@T02PT501@C3`0A40`03Pd900d<200?
3PX04A0<00`;2@0C4Q00>STg02XY9`0?3P`02PT7010?3@0=30X04Q4?00L6100B4@l040l=00/:200>
3@/00P0A40h06@0>3@/02`X801/J600?3Pd0;2/Y01DD4P19B4H05QDC014@3P0=30X06QTG02XY9`0L
6aT030/9018A3`0@3`d03`h<00h=2`0=30X030/900h>300@40h03Ph<00`<2P0>3P`00P0A4@l02`0B
4Q004A4?00l?3@0?3`d0410>01@E400A4Pd01`P302`]:00a<Rd03@h900803Pl:00H04A8=01<D3`0@
4@`03a0;01<E4P0F61D2018D4@0401@F4`0C5A804aDB01<E4P804Q@A01H051HC018F400H7AH02a09
075fK`0Z;bP07b@M010E3P0H7AH051TB010E3P0D6A804QL@014F400C61@04QLC014F4P0B5a<05AXF
01LL600?5100314=0P0B5a<07`0A5Q805AXE01@I4P0B5a004aPB01@I4`0B5a404QLB01TN6P0D6AD0
51PG00hB4@0D61L051XH01HL600M8al03aDA00X@300E71D061lH01TP6@0D6a<04QTA01HM5@0D6a<0
51hF01HO6P0G81/051dJ01<L6@0E7Qd00P0K8bD04`0I8B@07RHY028Z;@0H82D06R<X02L`=@0I8bD0
628T05QRH`0[=CD05R0O01@O6`0L9b8072LQ01hY8@0V<b`072/V01h^:`0O;b`00P0M;B`201h^;@1?
02@d=00U=CD08S8b02<c<`0X>3P07Rh^01l_;`0N;Rd07Rh[02@e<00]?SP06b/X02De<`0W=cH0:CPk
02hm@P0V=ch093Ln02Pl@`0dBDh0=4M=0396B00P=3D08C<c03A5A@0P<2l07Rh[02Hg<P0Y>3<09C4]
02`h=00Z=S80:cLc02Lb;P0P:bL0:C@`02/f<P0V<Bd0:SDa038m>@0`?3P0;CTg03]7A@0_>cT0=40n
030l>P0iAD<0<Shl03E1?`0`?3X0<Cdk03<o?@0b?SX0<40g030o>00_?SL0<D0i03M6@@0kBTD0<T4l
03=2?`0fAD80=DA102lm?@0[>SL0;3Pe02Xf<P0_>cL0;3Pd02lk>@0hA480=40n02`h>00W<c<0:cLg
034l?P0iA4L0?4M;03Q5B`0203A1A`80=TE<01X0=dI=02m0B00dADd0:S]303I7C`0iBeT0:Sa@03]<
GP0jBe`0AeUW05UYMP0fAdl0=dU=0391A00[>c/0;3`i02He<P0/>cX0=49302hi>`0U<380;SXj02@^
;`0]=SD0:c@c02L`;@809bd[00<09bdY05mUH@12B4@00P0T:RH05`0O9B409b`V024V800R9b40724M
01dO700R924071hK02@Y9@0G71P0724M02DZ9P0Z;b/07B8N01DJ5P0R9b<06QlK018G4`0L8Ad06b0L
01TK6P0K7A`07R0O008071hM00<0828Q01/M700L7Qd00`0L7Qd00`0M7ah071dO01`M7`0301/L7P07
01XK7@0M7R006AXL01lP8P0E5QP06a`N01XK7@0201LG5`0N01/K6`0O7b407QhP01TI6`0L6b005aHK
01<B5`0D4aT05A@J01DD6@0K6ad07QhN01PH600F5QH05aHF018@4@0F51D05a@E01TE5P0J5QL05a4C
01@?4`0D5Q/030dB010A5P2@TID081lT01<B5`0K6ad0@d540P0C4A802P0B3Pl04`l@014?400C4A80
40h?01<A4P0?3@h04@l@01<A4P0B4142014?40803`d>00H030X=00T72P0P7R402@P:01<A500F51L5
00h<3`0301LD5P0?2``01`<400803PX;01@040`=01HB4`0@30d03PX;018>3`0C3a003`/<00`82@0@
30d06ADF014=3P0;1`P07ATJ00`82@0E4A801`<4014=3P0=2@X0510A00h92@803`T900X040X:00l9
2@0?2@T04@/;01<=3@0A2`/03@L700`61P0@2PX050h?0P0E3a406P0?2@/030H800h82P0G4A<01000
01H@4P2ZY:H081XL00P2100@1@T03@8601462P0D2@d03P<700l4200=0PH02P0301D:3P0=0PH03`@8
00`31@0;00@03@8600l4200>0`L03@860P0?10P00`0D2@d01`0001462P0201052@0600/010070000
3`@801052@0D2@d01`000P0>0`L200l4208040D900L01`0001872`0@1@T050T=00X00`0900805@X>
00<04@H:00<03`@800d21_ooool04oooool001_ooooo01T03a0;010A300>3`X061TD014B3@0T9B00
DeA?00d>2P0:2`P04A8=02`]:00A4Pd04a@?010A300=3PT02``702//9`0D5A0030d8010A300D5A00
2``701HG4P0<3@P03@d;00803Ph<0`0?3`d301DE4`0900`<2P0A4@l03@d;018B40071`D0<C4_018B
400?3`d03@d;00H03Ph<00`03a4>01TK600=3``0418?014C400:30T030h;010B3`0>40d04Q@A014C
400;3@X200lA3P0;00`>2`0?4@h03a4>00/=2P0@4Pl04A<@00h@3@0B51404A<@00h@2`0>4@X00P0<
3PT01P0=3`X03Q0=00h@3@0?4@h03a4@00d?3P803Q0?01<04A<C00`=3`0J6ad03a0B014B500;30h0
GUmQ02X[;@0E5QP04A8D00d>400I6Q`09BHW01HF5P0:2PX010@4014A4@0@41003`l?008030`<0180
3Ph>00d=3@0>3Ph030`<018B4P0@410030`<00l?3`0>3Ph020P801TI6@0B4Q80BDU903lo?`0@4100
2PX800/;2@0@40h201@D4P803`l=00D02`/900`<2P0;2`T03@d;01<C4@0200d>2@803Pl:00@03@h9
00`=200?40/03Pl:0P0:2`H200h?2P08014A400B4Q0030`;00l?3@0:2PT04A4?010@3P0>3P`200`<
2P0F00h>300?40/03Pd801LG400B4PX05AD>00`<1P0D50`02`X5014A2P0820004a<<00l?200F5Pl0
5aHA00l>2@0:2@H05A@?00`;1P0C4Pd040l:00l>2@803Pd81@0=30L05`0?3PT040l:014@2`0>3@P0
4a8=038a;00C4Pd02@P300h=200>3@T03`h:00`;1`0>3@T04A0<00d<200?3PX03Pd900d<200C4Ph0
3Pd901@C3`0A40/03Pd800803@`700@03Pd800l>2@0=30L03Pd80P0=30L01@0A40/03Pd900`;1`0?
3PX040l;00<03Pd900`02`X600`;1`0A40`03@`800`;1`0=30P04Q4=014@300;2PH03Pd900`;1`0>
3@T200d<200N014@300:2@D02`X6010@2`0?40X02``8010A2`0720@0:2TS01@E3`0>3`T020T301DF
4@0=3PP04Q<>00d?300>40d06A/G00H70`0I6Q<061TB01HF4@0A4Pd04Q<A01<F600>4QH03a0E018@
4@0M6AP071/I0P0G5Q@2014A3`0600h>300C5A802P`9014C400>4`l05QHD0P0?3`d02`0>3P`03@d;
00d=2`0>3P`030`:010@3P0?3`d02PX800l?3@0@3`/03`h:00803@`800P03Pd9010?2`0:2@D03Pd9
00T8100G5Q804A0<01hM6@804A0>100@3`d0200<2`T03`h<01DD4P0D4a405A@B00h=2`0C4Q003`h<
0P0@3`d05P0=30X04A0>00d<2P0S8R00?Sdk010?3@0A40h030/900d<2P0>3@/04A0>01<B400A40h0
3Pd;00l>300A40h03@`:00l>300A40h03@`:00h>300?3`d2014A3`803`l=00L04A4@00h>300=3@/0
7AdK00H6100@40h03a0;0080414<0`0A4Pd0300C50l05AHA018C3P0B4`h04a@?014B3@0B51405ALD
01<E4P0A4a005ALD01<E4P804A<@01404Q@A01<E4P0C5A804aLB014F3`0=4P/05a`E018G400;40T0
4QL@00`A2P0G71D04aPA010E3P0=4P/05AXE014F4P03010E4@05014F4P0C61@051TE01@I5@0C61@0
0P0B5a<00`0A5a8041L@010G4002014H4@1K018H500A5a<05A/G018H5P0M8b<04aTI01HL6`0A5aD0
51XH01LM6`0E6aL051XF01DL5P0F7AH05A`E01TP600M91`06R8G01<K4P0C7AD072LO020[8`0G8Q`0
62<M01TT8@0Y<c@0NXB5024[;@0H8BH05AhS01dV;00L9R/07bX^01`W:P0H8bD072PY01`X9`0M:BL0
72PU01`X900L:2<07R/S01h/9@0M;BL07BhX01h_:@0N;R/0830^020`;`0U=CD09SHf01d];@0S<SD0
8C0c02Lf>@0M;Bd0>DU804IFE@0_?c`09CHa02@e;`0U=C80:CTg02`l>`0/>ch0;Se202dnA@0]?dH0
;3m402e0A00^@DD0;T5302`n?`0^?Sh0;clo02dm?00T<c009cHb020_:P0S;RX0:C@`02/f<P0W<bl0
9C4]02@`;00U<Bd0<clk03A0?00b?SX0<Cdi02ll>0020350?@0<02dl>@0`?c`0<D0m02`k>00c@Sl0
9SDb03Q7A00_?S/0?Da9030o>P0kBT80=D@m0P0c@S/20391?00702dl=`0a@3d0<d8o03E4@@0b@400
<D0m02lk>002030l>01202lk=`0_>cT0;c/i03I2@00iADD0;CTi02Te=@0[=SP0:SDh03Y5B@0d@TD0
>4I903i<C`0`?d@0<d9803Y9D00iBU40;Sm70393B`0cA4`0;d5>03I9F`0jBed0>daL03a>F`0jBeH0
<D9:0312A@0]?3l09CDd02hn>`0a@3d0:SHe02Pc<P0Z=3D0:cDe02D_;P0W<2l0;cPg02Tb<@0S;2T0
8BLU02P^;00R:BH0;3H_02Tc:`0T;BP0:2hZ02X`;00X;RX08RHT028W8`0R92407AdK01`M6@0O8A`0
7B0M024V8P0S:2@07b@P01PM6@10AD4082DQ01hS7`0L8Ad06b0L0P0L8Ad401lQ800501hP7`0M7ah0
7AlN01XL6`0K7A`00P0N81l0200K7A`07QlQ01lP8P0L7Al06Q/M01TJ700J6ad05aPJ0P0K71h201XK
7@0S01XL700F5QH05aLE01XJ600b<S809RHW01HF600G5aT04a<F01@C600G5Q/06QTN01PG700H6A/0
6A/M02<T9P0Q8B<07AdO01TI6`0D4aH05Q@G01/I700^:bh03`X>01PF6@0E5a/04a@H01LH700N7b<0
61PJ010@4P0C4a@07A/L01PF5`0A40l00P0B3Pd04@0D4Q<04Q0A014?400C4A805A<D01HD5@0I5aP0
4Q0A010>3`0B41406ALH01`J6`0C4A@05A<F018@4`0A3a80518E008040hA00l03P`?014?4P0>30l0
4Q0C00d:300A3@h04Ph?014=3P0?2``040`=014=3P0>2P/05a<D00h:2`0D41400P0=2@X01P0C3a00
3@T:00d92P0E4A8030P900d92P8040`=0`0?2``00`0?2P/03`T900l92@0200h8200=00l92@0@2PX0
40X:014;2`0B30`040X:00h8200=1`P03PP:018<3P0G4A<05Q0B014;3@0300h82P804@/=00<03`T;
01052@0@1@T00P0A1PX201872`0301H;3`0D2@d040D900803P<700<04@H:01052@0@1@T0100@1@T0
300?10P040D901052@0@1@T03`@800h31`0@1`X04PT<00d51`0B2@`030<600l72@803PD800@05`hA
00X3100N5QP03PL81P0?10P01P0A1PX03`@800h31`0A1PX08QLK01<931Cooooo000Kooooo`0J01HH
4`0<3PT05QPC00h@2`0f>3<02`d800d?2P0B50l01@L204M9A03=clX0;2hY01HG4P051P805aPC01HG
4P0;30L00040014B3@0<3@P03Pl:00d>2@0<3@P051D@010A300?40/200h?2P8030d800`0414<00h?
2P0>3`X020T400l@2`0:2`H03`l=010@3P2XZ:H0BDU70000000B4Q0600h>300<00T;2@0T9R<09bTV
00<50`082PL04Q@A00d?300@4Pl03@l<00h@3@0@4Pl03Q0<0P0?4@`01`0;3@P03a4<00lA300>40/0
418=00lA300;3@P00P0<3PT00`0<3`T03Q4:00d?2P0200d?2P0P00h@3@0;3@X010H300@61@0@4Q40
5ALF00d?3P072PT000@300L;2P0;3`h04aLF00T=300830/061`K0045100^<S406alN01<G5P0V:BT0
414C01<D5P0?41804A8D00@41P0A4Q@03@h@018C5@0E5QP0414C00`>3P0<30`200`<2P0C014A3`0E
5A<03`l=01HF500A4@l010@201hN700S8b404A4?00/;2@0=3@/04a<A01LG5@0D518030`:00d=2`0C
4a406ATG00T91`0200h>300800`=200>3`X04a@?01DF4@0B4`h03a0;00T:1@0<3@P300h?2P0500l@
2`020P003@d;00l?3@0@40h00P0<30X300d=2`0F00`<2P0;2`T02@T7010?2`0?3PX02PT40081000C
4Ph03`h900T8100:2@D03@`7014@30071P4061LB00P70P0:2@@06aXE00P70P0<2`H01@@000d<1`<0
3Pd80P0?3PT06@0>3@P03@`700l>2@0F5A0081lJ02@S7P0E50l05aHA02<R7@0?3PT02PT400T80`0?
3PX0:bXV0040000A40`03Pd90040000@3`/03@`800T8100=30P02@P400l>2P0=30L00`0>3@P200l>
2@0700h=200?3PT03`h9014@2`0D4`h04A0;00d<2002010?2`0<00`;1`0;2PH03`h:00h=2@0;2PH0
3Pd900d<200;2PH03`h:00d<200?3PX040l;0P0C4Ph0900920@04Q4=01@C3`0?3PX05QDA01PG4`0B
4Pd030d701<D3P0?40X0<34[0:^/YP0l?CL01`P202<T7P1<CDL051D?01<D3P0A4Pd030d801LH4@0N
7Q@051@:01LF2P0F4`X04a<;014C3`0D61T06A`Q018F6`0N71d06QHE01DD4P0C4Q003Pd;00/;2@80
5QHD01@030h;01DG500I6aP061dI014A3`0F5Q@04Q8@01hN700D5180410>00d=2`0<30X03Ph<00d=
2`0:2PP03@d;014@300@3`/03Pd900d<20803Pd900H07QdI014@300L6aL03Pd900l>2P0<2`L2014@
300<010?2`0>3@T030/700X91@0=30P030/7018A3@0F5A402@P4014@300D4a4040l=0P0A40h05P0?
3P`04Q4?01HE4`061@<02@P600P71@0B4@l020L501<B400B4@l04A0>018A3`0@3`d03`h<010?3@0A
40h03Pd;010?3@0A40h03Pd;00d>2@0>3`X400l@2`0601dN6@092PD0824L05EFD@0W:2<020T40P0=
3PT200h?2P803a0;01<04Q<>01XK5P0E5Q40414<01@E400F5a803a4>02`^:`0I6aP05QPE00X<2@0@
4Pl04Q@A01@F4`0E5a@04aDB014C400<3`/04QLA00803a@>00l051TC00lD3P0F6aD03A8<00lD3P0K
81X0314;01PM5`0C61<04QHE01@H5`0E6AP04QHE00lC4P0@51<00`0B5QD2014E5004018H4P0B6A80
4QTB01<J508051XF01D06R0M00lE4`0B61P05Q`L01@J6P0@5QH03aDC01`R800X;R`06b4O018H500D
6QH0318>02L]:@0h?ST06b8K00lF3P0J8Q/04Q`D01XU7@0P:bD00P0K9R802P0L9RD05AlP03I0@@0Q
:bd0:S@f02H`<P0I8RL07RT]020[;@0M:2X201XU9`0D01HR8P0N:RX07BTW01/W9@0L:2H082`X024`
:`0S=2h07C4Y01T/9P0J;BT083<`02Dh=P0A8b<09SPi02<e=`0S=CT062X^018T9P0Z>SX202Lg=P0B
01h^:`0]?CT0>4U302Ph=@0Z>SP0;Cdl02ln@@0`?d@0;Sm60394B00`@dD0<D=503=5A`0cA4@0<D51
02Ti>@0`?ch0=4920P0[>SL0200Q<2d0:38a02`f=@0]=cH0:cLe02`h=P0^>SP0:3Ld0P0c@Sl04`0a
@Ch0<D0m02hn>`0^?Sd0<T910351@00`@3l0:c/j02Hf=@0`@3l0=dM602Hf=@0`@3l09SHe03=3@00_
?cH0;3/d02dl=@0a@3T00P0c@Sd0200^?CP0;Sdj0350?@0hAd@0>4I603E4@@0^>SL0;CTe0P0a?CT0
1P0^>SP0;CTg038n?00a?Cd0;3Ph02Te=@809S4c03D0>4=502Le=P0Y=cT0>DM:02ln@@0c@TH0>TU>
03i?EP0a@TT0;Ci50311B00`@Td0=TUH03U:FP0cAE80<TA>03=4CP0a@TX0;Cm102Xi?00W=cL0:3Pg
02Tg=`0/=cH0:c@a02Xc<P0/=C809Rl/028[:00T;BX09Bh[02@]:P0S;2T0;CHc02df<P0]=bl0:SH/
028]9P0K91l072DR02L]:`0T:2T08BDT01dO7@0M7A/07QlJ020P700L7Q/061dI02@Y9@0S:2@0BDi:
0;Bi]@0201lT800401hS7`0L8Ad07B8N01hS7`<0828Q00@07R0O01dO7P0K7A`071hM0P0J71/201/M
700401TK6P0O82806AXL01LH6P806a`N02`05QLI01XK7@0H6A/06AXL01/L7P0J6ad05ALF014A4@0H
61H0410>01<C4@0B4Q40820P01DE5`0D51H05QHH01TH7@0K6Ql06AXN01`P8`0J7b803Q8E00lC5P0=
3Q804Q<G01<D600J6Ah04a8G01lN8`0?3A8051<H01LI7@0C51P04Q<G018C5@0A4A<03`lA014A4@0D
4Q<04A0>01<B400F4Q404`l>018@4@804a4B0P0D4Q<0=00C4A804Q0A010>3`0?3@h04Q0A01HD5@0H
5QL04Q0C01PF6@0<2Pd04@lB028P8`0=2`h05aDH01DC5P0F51L04Q0C01HD5`0@3@l04Ph?01<?400B
3Pl040`=014=3P0B3Pl06ADF00P41@0F4Q<00`0003hj>`0G4a@0510A00@00@0c<300:bLX00H20`0<
20T07a/L03di>P0f<S<04Ph?00H20`070P803PP8018<300>20P02P@4018<300D3Ph03PP800l92@0@
2PX200l92@0<00l92P0?2@/040X<01<=3`0D3Q004P`>00h82P0=1`T03PP:010:300A2`d03`T;0P0@
1@T301462P0701872`0F2`l05P/?01@93@0A1PX040D900l4200601462P@040D900h03`@800h31`0:
0@@01P0000l62@0H3a8030@601<:3@0>1@P03@@701H=400A20/0:1lR020G6PH03P<700H02`0400l4
200A1PX0304501H;3`0<0@DDooooo`006oooool060000@004Q@?0001000C5A00WZ2K010B3@031@00
4Q@?0002000N81/0MgUd018D3`0@4@`03a0;01DF4@0=3PT030d801`M600;30L0414<00d>2@0@4@`0
2P/601@E40803a0;0P0>3`X300d>2@0;00T:1@0A4Pd061TD01HG4P0720<05ADC0000000];B/01`L5
00d=2`0D51801P0?3`d07@0H6QL01PP501TK600D5Q<04aDB0002000<3P/03@l<00lA3P0B51404aDB
010B3P0B50l04A<>00d?2P0A4`h04Q@?010B3@0?4@`03@l:00/=200<3PT03@l:00d@2P0>4@X03a4<
00h@2`0=3`X03Q0=00805aTF02803a4@00`>3@0;3@`030h=01@G5P0?5100310?00`A3P0B5a<03A4@
00P<2P0@5A407R8Q034e<`0:3`/01`/:00h@4@0?4180414C01DF600L7Al05aPJ014B500=3Q0051DG
01`M7`0G61X04Q@D00h>3P0>3P`03`l=014A3`0B4Q003@d;0P0B4Q00100A4@l00@400000000<30X2
00d=2`0=010@3P0B4Q00410>00X:200C4a40410>01TI5`030`401PH400l?3@0:2`H030d800l@2`02
014B3@04010A300F5a803Pl:00d>2@803Pl:01l03a0;00l?3@0N7Q`01PH400/;2@0A4@l05QHD00P8
1P0;2`T03Ph<00l?3@0>3P`030`:00T81P0?3P/061LC00`;2@0E51401PD1010?3@0:2@H03@`801@C
4@0>3@X02PT501DD3`0=30T0QHAo06=RG@0>3@P04a8=00803@`700D03Pd800l>2@0?3PT040l:00l>
2@0200d<1`0G014@2`0G5Q406QTD01DD3`0=30L01`H100D40P0B4@`05A@?01DD4@1bLFd0:BPT00P7
1@0<2`L08B0L014@300>3@T02PT500d<20061@402`X600`;1P0=30L0100?3PT2010?2P0;00h=200=
30L040l:00l>2@0<2`L03Pd900`;1`0;2PH030/701LF4P0E51000P0;2PH0=`0>3@T040l;010?2`0:
2@D04a8>018A3@0?3PX051<?00`;1`0?3PX04Q4=00/:1P020@000`8000l?2P041@004a@>00`=2000
0@00?d0j00d>200<3@L0;c0Z05UJE00@4@/061TC01LH400@40H06aX?03@b9@0O70d08Ql>01XG200L
6Pd05aL?01DG500H71d04aLJ02d[;00R7Qd06aXH01`K6@0F5A<05ADC00T91`0C4a4061XG01/M6P09
2`P08RLS00D50`0m?C/09bLU00/;2@0@40h00`0?3`d01`0@40h03`l=00h>300@40h04A0<010?2`0?
3PX00P0>3@T0200=30P01PD100T8100;2PH020L3010?2`0920@030/7100>3@T02@0<2`L03`h:00h=
2@0<2`L05QDA00T810071P8051<A010?3@02018A3`0=010?3@0C4Q002@P600l>300A40h051<A014@
3P0B4@l04a8@010?3@0?3P`04Q4?014@3P03010?3@0400l>300@3`d040l=00l>30804Q<>0P0A4Pd0
200@4@`03a0;00T:1@0<3@P04Q<>01lP6`0=3PT02``70P0?40/2010A30804A8=00@04a@?01PI500D
5A004a@?0P0F5a80100I6aP0@dE202h`;@0`<Rl401@F4`0B01DG500B51404A<@014E4@0U:R@092TU
01@I500D6A<04aPD014F4@0B5a4020d900lD3`0>4`d061dI00dB3`0A5A@04QHE0P0E6AP00`0D61L0
4aLF01<G5P0401<G5P0401<H5@0B6A804aXC01<J508051XF02@061hK010F500I7al04aTI01/Q8@0B
61P04QPF01hT8P0Y;bd07R@R01@J600F71T06b4O01LM6@0J81d0728N01XP700T:bL05R4K01PS7@0E
81X03aXF018M6@0K9B@07BLX01<M7P0E7b4072HX020Z;00I8bD06bHX01`X:00M:2X06bHX01TT9P0F
8R8201/W9`0Y01/W9P0K9bL07BTY01/Z9`0Q<R`07C4Y01`_:@0O<Rh09cXg02`o?@0U=cL08S@e01DW
:@0U=c/0;d5502do@`0Y>3/0830_02Xj>@0Z>SL0:CTe01d^:00[>cP0;3`j02hn?@0a@4<0<d970350
A@0^@480;D1102do@@0_@D40;d1002`l?00U=C@0:cXi030n?P0X=c@0:cXg02Da;`0[=C@00P0^>3L0
1@0_>cT0<Shl03A0?P0]?3T0=4=000<0<T8o00h0<40m0310?`0dA4<0<d=20310?`0[>cX0:3Pg0392
@@0iBDP09CDd0392@@14E5<0<D4n03=2>P80;chg03@0<D0i030o>P0_?ST0<D0k02dl>@0_?S/0=DA1
03A2@P0a@3d0;SXg02Te<@0^>SH0=40l034m>`0/>3H0:3@b02@`<00U<C40:CDe02Pc=@0U<38082/]
01PV9`0^?3h0<d5402He>00Y>3`0<d9703E6C@0^?dH0;Ci50352B@0cATh0>TiI03e?F`0eAe80<dI=
03M8D00fAdd0;3i202Xi?00/?3`09cLf02Le=P0_>SP0;SLd02`e<P0^=c@0:34^02</:@0Q:RL0:C8_
0P0Q:RL0500g@3d09c0/028]9@0T<2H09c8Z02Pa;P0W<2d0:2h^02L[;00Q9BH07AlM01lO7@0Q8Qd0
8R8L024S7P0/<Bd061dI01lT800A5Q80A4U50P0L8Ad0100M8Qh06b0L01XO6`0L8Ad2024S8P05020R
8@0N81l071hM01XL6`0K7A`0100J71/0<`0I6aX07QlQ01XK7@0I6Q`06Q/M01/L7P0H6A/05aPJ01PI
6`0G61X05AHH01LH6P0Q8b8071`J01PH5P0G5aD07AdK01/K6P0E5AD04Q8D01<C5@0E5AL05aHK01TH
7@0H6Ad061dP02D/;`0J7b807b@X01hR9P0M8B@04aHK01PI7P0:2`l051@I018A5`0F5a/05ATL01DF
6P0C51P04a@F01PH6P0K6ad051@D01<B400A40h061LE01dI600H51<04@l@01<A4P0201DC500401<A
4P0B41404Q0A010>3`803`d>0P0>30d04P0>30l061HI01HD5`0@3Q4071XM00L5200D4QD04@lB018@
4`0>30l04Q0C00h;3@0B3Pl0510A018>3`0A3@h04Ph?00l;308040`=01T0;RX[02TU9P1iMGH0:bLX
01XF5`0M6AX0HUiO05IBD`0?2``03@T:018>3`0D41401`<400P41@0U8B80:B@U00d71`0;1@D040X:
014;2`0@2PX03`T900`61P0=1`L03PP800803`T900@03`T:00h82P0=1`T03`T;0P0A2`d01P0>20X0
3@L900h82P0@2P`04@/=00h82PH04@H:00<040D901462P0C20`00P0C20`00`0B1`/04@H:01462P04
01462P8040D901004@H:01052@0@1@T03`@800/21@0700403PH800l62@0=1@L01`0100l62@0=10L0
40L:00/21@0H3a8040L:1P0=0PH01P0;00@0:AhR02hS9`0B1`/02@0200X00aCooooo000Kooooo`0<
01<E400A4`l0=CLb00lA300N81/02`d:01@F4@0?4@d02`d8010B3@0C5A004Q@?0P0?40/02P0>3`X0
4A8=00`=2@0L7AT03a0;00d>2@0<3@P04A8=01<D3`0A4Pd200d>2@0500h?2P0?40/0414<010A300=
3PT00P0F5a802@0:2`H04Q<>018C3P0=3@`051@B00h>300C4a403Ph<00`<2P0600l?3@0B00d?300C
5A801PP500/=2P0F61D03@l<00h@3@0:30T03a4>018D4@0=3``03@l;018D3`0@4Pd02`d8010B3@0B
50l03a4<0P0<3PT0700>40/03@l:00lA300?4P`03a8;014C3P0@4Pd030h900h@3@0@4Pl02`d:00h@
3`0D5QD03Q0?00/=300:3PX0314;00P=200;40/02@h800hC3P0@5@l00`P200X>2P0>4Pd05Q/E00/@
2`0=40h200h?4@0G014B500C51H061TK01PI6`0<3@l03@h@01@E5`0=3Q002``=00`<2`0>3P`04Q8@
010@3P0=3@/04Q8@01DE4`0:2PP030`:00/;2@0A4@l0410>01<C4@0A4@l00P0>3P`200l?3@08014A
3`020P406ATG01HF500H61H03Ph<00h?2P0=3PT200`=2006010A300C50l0:R/V018C3P0;30L03a0;
0P0=3PT0200=3@/0410?020P7P0;2`T03Ph<00/;2@0<30X03Ph<0P0A4@l05@0>3P`030`:00l=3@08
1PH04a4A01lM7P091`P03Pd<01<A4P0A3a0040l>00/92P0@3Ph02`X800/:1P0:2@D0:RTT010?2P0?
3PT02PT400d<1`0200h=20803`h900<040l:00d<1`0=30L0100=30L0500@3`X051<>00/:1@0B4@`0
40l:00l>2@0<2`P09RDQ00D40P0C4Ph02PT5010?3@0=30P03Pd900d<200B4@d02`X600l>2P0=30L0
3Pd8100?3PT400`;1P0;00l>2@0A40/03`h:00h=2@0<2`L03Pd901<B3P0G5Q804A0<00h=2@0A40`0
0P0>3@T00`0@3`/04A0<00l>2P0200l>2P0c01HE4@0d<bl08B0L00X91P0E51003`h:00/:200A4@d0
2@X601<D3P0<3@T04a@>00X;200?40X05aPB014B300D5@l03Pl901<D300F5PD04a<001hL1@0l>B00
?cXP040k7`0Z9@/09b@;01hN2P0E60/04QL<01@J4`0S8Ql071PG01HE4`0G5Q@04a8@01@D4P0C4a40
4A4?01<E4P0A4a00418?07IkM`0[:bT0GEeK03dm>`0C4a405QHD00l?3@0>3P`03`l=00803Ph<00<0
410>00h>300@3`/0100@3`/01`0?3PX05aHB030_:`0;2PH06APD01DD400<2`L00P0>3@T400d<2008
00/:1P0B4@d04A0<00/:1P0B4@d05aHB01<B400@3`d2018A3`05010?3@0D4a403Pd;01<B400:2@L0
0P0=30X01P0I61H03Pd;00d<2P0=30X04A0>018A3`804A0>00D040l=018A3`0A40h040l=018A3`02
00l@2`03010A300A4Pd04a@?00804a@?00@03@h:00`=200B4`h0414<0`0?40/01`0@4@`04A8=014B
3@0A4Pd051D@014B3@0@4@`00P0H6A@02@0A4Pd04A<@02<U8P0E5a@0828O00d?300C5A805ALD01@F
4`02018D4@0:01<E4P0G6QL0<3Db030d<`0G6aX04QLD01DI600H71X04AHC018F5@8051PF00L04ADD
01TM700D61L04aLF018F5@0C5aH051PG00H05QXI010051XG010I500@6A@04AXE018K5P0B6aP051dJ
010I5P0D7A`03aLI01DM7`0I8R805Q`K01LM6`0H7Q`05adM0P0F71`01`0P9RH05Q`K01TN7`0I7al0
7B8S05MNG@0O:BL00P0L:2@0;P0H92805R8P01/W9@0O:bT05b<Q03E1@@0Q;Bd072PX01l[:P0E8b40
52<P01PV9@0K:BT06RPX01/Y:@0I9bP06bTZ020^;`0S<C808c4c024`<00M;RP07C4W020d:`0R=Bl0
8cHa02<f<`0N<300:S`m02m1@`0bA4P09SLm02Pj?P0[>Sd093@d02Xj>@0S<c009cLc02ho>@0Y>CH0
:3Pf02/k>P0_?T40<D1502dl@@0[?Cl202Tk>`0B02Xl?00Y>SX09cLf02Pf=P0Z>3P0:cTi02Pd<P0c
?cd0<Cdk02/e=00]=cH0;SPg02hj>00b?S`0=44o0391?P0dA440<d=00P0bAD40900_@Sh0<D5003=3
@P0c@d80;Cdl02Xj>@0]?C`0<40o02lo?P0`@3l0=dM607V9R00eAD80<T8i02ln=`0^?CH0;chg02dl
=`0[>SD0<T4l0391?P0d@d00=dI303I4A00eA440;c/h02Te<@0]>CD0=D4m03M3@@0iAD<0<3`j02Da
<@0T<3009S8b02@_<@809S4c0180BUQI06AbL`0c@D80:CPk02ln@P0_?T<0;3i202Xl@@0]?TD0;d17
0313BP0hCE@0>diF03A7C`0eB4h0>DYB03M8CP0_@DD202ln@@0802/k?00Y=cX0;3He02db;P0]<bl0
;S@`02H/:00U:bT202@Z:00E02lh=@0Y<Rl08R/X030j=`0T<2H082hR024/900Y<Rl0:c@a02H/;00V
:BX092DW024Q800S8R0092<O02DS7P0H6QD082DQ01lT800Q9R8082DQ00806b0L00D07B8N020U8@0M
8Qh0724M01lT8002024S8P05020R8@0N81l07AlN01/M700I6aX00P0K7A`01P0J71/06adL01`N7@0M
7R00824S01dN80806AXL0P0M7R003@0D5AL07b0R02X[;@0T9BL071hM01`L6P0F5a8061TD01@D4P0F
5QD0410@01<C4`0G5aP00`0I6A/03`0I6Qh061hS028Z;`0>5QX0620V03Y0AP0I7b@05Q/R01TL8`0E
61h05aTP01DF7`0C5Q`04ADG018C5@02010A4`0:01HF5P0J6QX05ADE018A3`0A40h061LC01dI5P0I
5A<04@l@01@B4`805Q@E00<04a4B018@4@0B41400`0B4140;00A3a0040h?014?4P0A3a805aDH00d;
3P0@3Q404Q0C01<A500B41<05A<F01HD5`0O7B005Q<E018>3`0D41404Ph?014=3P0B3Pl0510A00P5
1@0H51D040`=00/8200Y9BH0510A00P41@0C3a004Ph?00d92P0F4Q<02PH700l;300@30d03`/<00h:
2`0?2``03`X;00d71`0?2@T04P`<00d71`0A2`/05@l?0`0>20P200l92@0400l92P0<1PP02`D700`6
20803PP:00<03@L900`6200=1`T00P0@2P`00`0>20X04PL;01872`0401462P0500l4200@1@T04PL;
01872`0A1PX01`0?10P201462P0;01872`0A1PX040D900l4200>1@P02`D700l:2`0:10H091hP00d7
2@0:10H0100;1@L00`080P<03P<700h31`0400h31`0600T00P0J41<08AHJ01062@0>0`L04@H:5?oo
ool001_ooooo00H05Q/E00X?2@0A5Q0041D?00P=1`0L8A/200lD3P0401<H4P0=4P`010T400h@2`80
3@h900X07AhI00T:1@0A4Pl0/;6/059CCP0=3PT04Q<>00h?2P0D5A00414<1P0>3`T0300D5@l0<S<]
03<d;P0F5a404a@>01@E400<30X071`J00/;2@0C4a4061PF00@40PH03Ph<0180418?07=eLP0`<Rl0
4Q@A014C400K7AX03a4>00d?300?4@h030h;00lA3P0C5A403a8;00d@2@082`@03A0900lB2`0>4@X2
00X=1P0a00lB2`0;3PL02`h700d@2@0?4P/04aD@010B3@0<3PT03Q0=03`n>`0g>CH02@/:00H81`0C
5A@03@l>020S7`0h?cL072<K00`C2`022@404AP@00@9100N9Ad061lG01LN5P00100000<0018G500D
61/020`?01LK7P16BTd0[k>f02X^<@0F6Qd02`lB00lC5P093A003Q4C018B400>3`X03a0;010A300=
3PT04a@?00X;1P0A4Pd05aPC014B3@0200/<1`0401<C4@0A4@l03Ph<00l?3@804A4?00<02@T701hN
7015AD<00P0A4@l00`0=3@/0414<00l@2`0200d>2@0?00l@2`0A4Pd03@h900L80`0?40/04Q<>00d>
2@0C50l0@40n05]KF@00000010@200h>300G5aD03Ph<00803`l=01403Ph<00`<2P0:2PP02@L801@B
5@1@CU40Shf@01dK7P0:20/0;bd`00/9300I5aX0518E00`:3@0<2P/030/701XI50020040000301/J
5@0=30L03`h900<03Pd80`0=30L200`;1P0<00h=200@3`X04A0;018A300>3@P00@0000d<1`0920<0
4A0;010?2`0510000@000P0:2@D02@081`<04a8>00h=2@0920@030/700P70`0>3@T040l:00h=2002
00d<1`0300h=200?3PT04A0;00804Q4<00D051<>01LF4@0C4Pd030/700d<200200`;1`0`00h=2@0=
30P02`X600l>2P0A40`030/700h=2@0B4@d05QDA00D4000T8al0<c8^01HE4@0S8Qh02`X60040000:
2@H04Q4=01<B3P0?3`X02P/501PI4`0E5Q0061TC00d>200>3`T0414;014B300R8ad010D001TJ4@0G
5`007Qd002l/2P17@ah0OWUC07iiD@1=B280=c<>02LW2@0V:180724;01`R4P0K6QD081`K01`K6@0F
5A<05aHD0P0E5A<03@0;2`T05ALD01TK600B51402Pl;014A3`0D51804Q8@014A3`0?3`d02`/900d=
2`0>3P`00P0<30X02`0A4@l030`:00d<200?3PX04A0<018A3@0A40`040l;00d<200G5Q801`H20080
40l;00<04A0<010?2P0>3@P00P0;2PD02P0>3@P040l:03ln>@0@3`X081lJ00l>2@0@3`X02`X6014@
3P0=30X2010?3@0800l>300C4Q003Pd;00h=2`0A40h051<A014@3P081`D200h=2`0A010?3@0C4Q00
4A0>00l>300A40h03`h<01<B400A40h03`h<01<B400A4P`03a0:00h?2@0?40X04A8<018C3@0<3@L0
0P0H6A<0100=3PP04a@>01DF400?40/2010A30<04A8=00<04Q<>010A300?40/00P0F5a80100A4Pd0
61XG014C400A4a0201@F4`0301LI5P0D5Q<04aDB008051HC01405ALD00hA3`0B5QL041@E00`@4@0D
61T05a/L01TM7P0A5AH0A4Q900dA4P0F6Q/0310A00lC4`0D61L04aLF018F5@02014E500401<G5P0E
6AP05ATH01HJ6@805a/J00@05A/H018K5P0B6aH04a`H0P0C71T03@0E7Q`01Pl>018K6P0a>C/03QHH
01DM7P0L8R806AlM01DK6@0F71`061hN01XO8P0E6Qd00P0H7B005`0>4aL04AHJ02Xa=00J92<062@R
01dY9`0N:RP062@R01TU8`0jAT@0:3@b01l[:@0B7Q`07b/Y01TU8`0P;b`072/V01d/9`0N;BX06RTV
01`Z:P0O;Bh07R`]00807R`_020082dc020_<P0O<2X07c<Y024e;00Q=2h083<^01ha;@0W>CT093Hg
02Dg>`0U=Sd0<45806anPP1MK6l0;Shn024a<00Q<Bh0:SXf02`m=`0/?3T0:CTg02`l>`0a@4<0<d97
02hm@P0Z?3`0:C`j02Pk>@0[>cX0:CTh02De=080:cTi01d0;C/k02/g=@0jAT@0?4Q6038l?@0e?d00
=T1103I2@P0fA4@0>4I603E4@`0dA4<0;d900395@`0aAD<0;d9003A4A00iBDT0?De=03E5A@0a@D40
=TI603];B`0dA4@0=TI60392@P13De<0;3`k0350>00202ln=`0@030o>00^?CP0;3/f0391?00iB4D0
>TU603I5@P0fA4@0>4M4030l>@0`?3P0<clk03A0?00e@Cl0>dM503E1?`80;3Ph00X09c<c02<^<00Z
=CL0:SDg03A2@`0/>S/03adN02<b=@0d@dH0<3m20P0bA4P0<P0^@4@0;Sm60313B@0cB4/0=4M=0313
B00bADT0<TA802i0A00a@dL0<T5602`k@00_?T<0;3To02D];@0W;2H0;34]02/`;00R9b<09bdY02H/
:P0P9R@0:c@a02H_;00Y<Rl0FfER02Te:`0R<2<06RLN01/V8P0N9b@08RPY01lP900Q8R@08b<R024P
7P0P7aX08R0K028T7`0G71P08BHR01DJ5P0I7QX08BHR01XO6`0N8al08RLS01lT800M8Qh08BHR100O
8B00;@0N81l071hM01LI600K7A`071hM01/M700M7ah0828Q020Q8`0O828071dO01TJ700G61X061TK
01lP8P0D5AL08b@V02d^<00R8bD061XI01/K6@0H6A@071dH00/;2@0D51805ADC01DE5@0J6QX071`L
01XJ700H61X061TM00dD6P0?6R406B@Z04eGH033c=@0PhbC02he?`0D6b@03A4J00T=5`0C5b806AhT
01@H6P0201@E5`0=01@F5@0D51@04a<C01<C4@0C4Q0040l=01<B3P0G4a004`l<014?400C4A80518C
01DC500201<A4P803P`=100?3@h0200<2Pd040hA00H41`0O7B0030X=01LE600>30l030X=0P0>30l0
1P0G5AP04@h@014=3P0B3Pl04@d>00l;308040`=01/03@T:018>3`0<20T03PX;018>3`0?2``05Q8C
00D10P0=2@X05Q8C00/7200C3a004Ph?00h:2`0;1`P02@D600H20`0;1PL03PP800d71`090`<02P@4
028L700X8R804@/;00l92@0>20P00P0?2@T01P0@2P/03@L900d72@0>20X03`T;00d72@<030H80P0?
2@/01@0=1`T04PL;01872`0B1`/04@H:008040D90`0B1`/00`0A1PX040D900l4200601052@804@H:
00X04PL;01462P0A1PX03`D9018930070@<03PT:00@0000E3a4010000P0<1PP0100:10H040X<00h8
2P0@2P`600h31`0601P=4@0<0@D03P<700/0100A1PX030455?ooool001_ooooo01X000@0010E3`00
1@005Q/E00T>200:3`T010T300T>200E6Q@01``6010E3`0K7AP030d801<D3`092PD0414<014B3@10
@C`0R8V401@E400J6aH030d8010A300?40/0414;00l@2P803Pl90P0<3@L0300@4@/04a@>01@E3`0:
2`D03Pl900X;1P0D518010@201TI5`061P@04Q8@01<C4@H03@d;00L03Q0=05IHE@010`004Q@A00lA
3P072@H03Q0=00804A<@04X030h;01XL6@0N81/04A@=00h@2`0930H03Q4:014C3P0?4@/02Pd600X<
1`0?4P`020/400H80`0:3@L03a4<01<E400A4`h030h900h@3@0C5A802`d:00X<2`0F61L04Q@C00lA
400?4Ph04QTB00870@083PP01Pd601@I4`0<4P/08bXS00@90`0M8ad00`X301XO6@062`P051PI00`@
4@0J7Ql0E5QI0=kRh`0^<S<05a/L00T=3P0?4a@02`l@01DH6@0L71X04Q<>00d=2P0@40h03@h900h?
2`092@L03a0;00/;200=3@/02``700l?3@0>3P`03@d;00h>300?3`d0410>00d=2`092@L092@R03lo
?@061P@06QXH00d=2`D03@h9010030d800h?2P0D5A008B8M01/L5`0:2`H03a0;0082000R8R004a<A
00d=2`0@40h02`/900T91`0;2`T030`:0`0=3@/0500G5AH00P41030^;`2:R8T04a4B01PF5`2;RHX0
6APH00d;300?3@h02`T:01@C4@0C4Ph02PT700T80`0M71L020L401DD3`0@3`X03`h90P0>3@P0200=
30L030/6010?2P0<2`H02`X500d<1`0B4@`051<>0P0>3@P04P030P004Q4<00L60@0@3`X030d800X;
1P0@4@`03a0;01<D3`0;30L09RLR01XI5@0?3PX03Pd900T8100@3`/04A0;00h=208030/600T03Pd8
00l>2@0A40/04A0;00l>2@0>3@P040l:014@2`0@3`/00P0C4Ph00`0?3PX03Pd900l>2P0200h=2@1n
00/:1P0920@051<?01HE4@0D4`l00`8003dl>01@Cd/04a8>00X91@0@3`/05A@@018A3@0920@03Pd9
01PH4`051P002``6010A2`000@006Q/F01DF4@0@4@`010D000h?2@0E5Q005QL=01@C000V8`00A3lI
06MP=P31^8d0b/:D08MnD`1PFc<0@T0O03Xm8P0V:A@06Qh>018A300N6QT06QTG010?3@0B4@l03Ph<
00P81P0>3P`05aPF00<30@0?4@h051HC00d=3@0>3P`06Q/G01PG4P0I6A406APC018>2`0B4@d03`h<
00h>3P0D51@03`l>00X:200=3PT0414<014B3@0B4Pd04A0<01/J5P0;2PH05A@@00/:1P0=30P040l;
00l;200<2PH02@P300d91P0C40`05aHA09nKV00F51004Q4<00/7100E4`l03`h:010?2`0<2`P03`h:
010?3@0?3P/04a8>00h=2`0<2`P03Pd900L6100=30T03Pd;010?3@0A40h04a8@01@C4@0@3`d03@`:
014@3P0?3P`04a8@014@3P0?3P`04a8@01/K5@0F5A004Q<=00l?2P0>3@P03@h800d=200<2`L0414<
014A300C4Ph020T4018C3P0C4a404a@?0`0D5A003P0?40/04a@?010A2`0B4`h05AH@01<D3P0B50l0
3@l:01PJ5@0?4@`03Q0;018D3`0@5@l051HA0P0D6A<00`0C61805QXH01PN7P0200hD500;01@J6P0@
5QH061hN05EKF`2na<@0728R00dC4`0K8B403a@C00lC4P0B5QD00P0D61L201<G5P8051PG00L05ATH
01HJ6@0F6QT05Q/H01<L5`0D7AP051dI00805AhK02h06B8O00H?300S;2/0GFIU01XS8P0D7A`061hL
01LM6`0D6QP04ALG018H600F6ah051TL01/P8`0E6al061dQ02@[<@0H7b@072PX01HR800G8b<062@T
01HR8P0M:BT072PX02Hb<P0W<c<06BDU02@`<00P;2`062LT01@S7P0J:BH08S4^02<a<@0[>CX0;3Xk
02Pf>@0P;C806RL]01/X<00M;340830_020c;@0R=Bl08cH`0P0U>3@0<P0[?S`09CLh03E7B`0eATd0
7Rlf03]<D`0]?4<09SDi0392@P0X>3P093@b02Xj=`0X>3D09CDc02Ph=`0]?Cd0;ci202Xi?00[>cX0
:CXg02Ti=P0Z>SL0:3Pe02@d<@0Y=cL0:SPh02hl?00/>3H0>dM503a8AP0`?3`0=41003E1@@0c@D40
=49203A4A00eADD0<TA402i0@00a@d<0<DE402i2@@0^@400=dU903e?C`0eADD0;Shn03=3@`11DE40
?dm?0P0lC4`00`0L;2`0>d]:03I5?`0203=2>`0I03=2?@0_?ST0;C`g03=2?@0lBdP0>dY70391?P0_
?Cd0<T4n030m=`0g@S`0>4@n03A0?00b?CT0<chk02/g=@0Y<c80<3/k02di>@0Z=3D0:38c02Da<@0Y
=CD0:SPi02Le=P0202Dd=`0<02ln@`0hBTh0>daC03A3BP0e@d`0=TQ=03A7B`0cATX0<4960394B00_
@DD0:cXo0P0c@TL0:@0[>C`0<T1302hl?`0R:b/09R`X02hc;`0/<Bd08BLS02/a;@0N9280:c4_02L`
;@0M9R<0:c@a02@]:P0R;BD08BhU01l/900K9R8072DT024X:00H71l07QlQ028S8P0O7ad071dH01lO
6@0P8Ql07R8Q01/O7P0_<c800`P401/O7@0G71P0724M024V8P0M8Qh06b0L01lT800N81d07R0O0080
7b4P00h07R0O01dO7P0F61L06adL01dO7P0L7Qd07R0O028T8`0T9BL07AhP01TJ700J6ad061TK018C
5@806Q/M02T0824S01PI6`0C51H09RPW01/K6@0C4a407AdK01<C4@0H61L02@T901<C4`0I6AT06a/K
01PH6P0E5AL05AHJ01TP9P0E82H0;3Lm075jP@3eoOl0Y:^e038i@`0I82T07R8[018F7`0@51d04aHM
010C5@0A4Q@04a@F01DG5P0C4a<0410@01@D4P0F5A<04Q4?018A3P0C4Q0040l=018@4@0201<A4P80
518C00D04a4B01HD5@0D4Q<04a4B014?400200l=3P0M00`:3@0O7B002`T<03/i?00F51L061HI01/I
700E4aH0518E00l=400D4QD03``>010<3@0A3@h040`=00h:2`0@30d03`/<01/G600<20T040`=00h:
2`0B3Pl03`/<00@00@0H51D05a<D00P41@0D41400P0;1`P300h:2`0:014=3P0D3`l030H600d71`0D
3Ph02P@400T30`0A2`/04P`<010:2P<03`T900<040X;00l92`0?2@/00P0A2`d0100>20X030H800/5
1`0<1PP200l92`0500d72@0B1`/04PL;01872`0A1PX0100@1@T0100A1PX04PL;01<8300D2@d70146
2P<04PL;00h04@H:01052@0600005a4C00/51P0[8RD0VI:D01hH6P0D2`h03`L:00H00P0>1@P02P@5
01072PH03`@800H0304500/2100A1PX02@0200`21@0<0@DDooooo`006oooool01@0=3`X0418=00d?
2P0=3`X03a4<008030h900L02`d800h@2`0A4`h04A<>00d?2P0@4@`03a0;00803@h900X03a0;010A
300K71L051D@014B3@0>3`X05QLB00l@2`0<3@T0414<0P0B4`h0200M7QT0>CXe00l@2`0E5Q404Q<>
00`=200=3PT03a0;0P0?3`d2010@3P03014A3`0@40h03Ph<00<0410>00T03Ph<00d=2`0>3`X04A8=
00l@2`0>3`X03a4<010B3@0=3`X00P0>4`d01`093PP03Q@>00`?2P0=3PX03Ph<00h?300?3``00P0?
3`d01P0>3`/03Ph<00h?300>3`/03Ph<00h?30<03`l=00<03Ph<00d=2`0=3@/00P0@40h09`0>3P`0
4A4?018B400@4@l0310=00L91`0>4@l0310=00/=2`0<3`d01@P600lA3`082`T02Pd;01<E4`082PP0
4aDC010B400L7Q`03@l=04=5@`0I6aT0418@00lA3`0>40h02`d;01XL6P0W9bL05QHE00/;2`0>3Ph0
3@d<01HF5@0C4a<04A4@00l?3`0A4A404A4@010@4005010@3P0E014A3`0>3P`03`l=00l?3@0<30X0
2`/9010@3P0B4Q004a<A034a;`010@003`l=00h>300=3@/06QXH00P81P0G5aD02PX800h>300>3`X0
3@h900@02``70P0<3@P200d>2@803Pl:01004A8>01<C400>3P/03@h:010@3@0=3@X051@A010@3@0>
3`/0414=00l@300<3@P03a0:00l@200=3PH030d50P0=3PH00`0?40P03@h600`=1@0300d>1P0501@E
3`0?40X03Pl900l@2P0>3`T00`0=3PP0;@0>3`T030d700/<1P0=3`P04aPA02D[900D6Q805ATB00P<
1`0>4P/03Q4:00d?2@0;3@H0414;00X;1@0?40X03@h900X;200A4Pd04A8>00T:1`0H6A@02P/600l@
2`0>3`X02P/600d>2@0@4@`030d801HG4P0?40/04Q<>00P9100;30L051D@00T:1@0B4`h01PL301<D
3`0<3@P061TD018C3P0@4@`051D@00/<200200d>2@0N00l@2`0=3PT02P/600/<1`0@4@X030h401TJ
500<3@P03@d;02/[:`0G5aP04A4A00d=2`0C50h05aPA01lP4`0a;0h0<2X606=J<02`XWL0m^o10?ok
c@3gkL80_[::05iF=`0_;AP0;2dN01dP5P0H6A@05aHB0`0E5100>@0C4Ph04A0<018A3@0B4Ph040l;
00l?2P0A4@h07AdN05]KFP1WIUh0UYB303Te8P0T7@`06a8801`C3P0E3`l04PhB01LE600D5AD03Q4>
010E4@0;3`/030h;014B3`0=3@/03Ph<00d<2P0>3@/04`l>014=300>2@P050h>01<=300E40l03`T9
01@?3P0?2PP05@l?01@?3P0B3@`04P`<014;2P0?2`T03@`800l@2P0G6180414<014B300?40`02P/5
00h?2P0?40X051D?00`=200A4Pd04A4?00T92@0200d=3@0R00h>3P0B4Q804Q8B00l?3`0;2`/0@d=3
04e=C@0>3@/04a4;01LD3`0;2@@04a0;01@@3@0A3`/0514?018>3P0@3@d04PhA01HA5P0E4aD04A8A
014C4P0<3P`04Q@A00`>2@0C5A004QD>01DH400E60l04QD<01PK4@0@4`T04QD=01@G3`805AP@00D0
4AH>00lE300A60l04AL>010H3P02014I4007018L5@0?6AH07BLS00hH500D7Q/05R0M07J0O00203Do
>`0601@N6`0A6aP041XG01LN6`0F6aL04aPD0`0B5a<02P0D6AD06AhJ01dR7P0I7QX04aPD01DJ5P0I
7QX05A/G018H500C6AD201DK5`8051XF09D06R0M01lU8P0M8b005Q`I01PN700F71X05adK01TO7@0K
8Al0624P01`U900F7ah05QlP01TR8`0G8B<06RDW02Da<`0=6a/06BLX01PV:00E8bD07B/]02Ha=P0_
>Sl0?4M<03Y3B`0[=3`09Ble024_<00K:RP08Bl_02Dc<`0N;2d0938d01h/<00T<CL072Ta020]=@0T
<CX0938j02@d>P0O<C@08cHf02Dg=P0T=c@0:Sdi02Lj=P0V>3P0:C/n02m0AP0X>D00:3U402De@`0W
>4D0:ca502Dg?@0Q=3D0;D0m02`o>`0T=c<09cXg02/n?00[?Sd0;Cln03E6@00b@S/0=4<m0350>P0Y
>3<0:3Lb02/j=P0]?3T0;3/h02hm>P0a@3d0:CPf02/m>`0/?S`0<dA303A5A@0b@d@0=TQ:0353AP0c
ADX0=DM<03I7CP0cA4`0<DA902a1?`0cAdD0<TI403=7A@0dAdD0<DA20395@`0b@T40=TI503A4@`0g
ADD0=D=303M7@`0b@ch0=dQ303I6@`0b@Sl0=DE203I6@`12DTl0@E5>03I6@`0a@Ch0=4<n038m=@0d
?SH0BeE>041;A00^=c80;cTd02H`;00X<Bh0;SPe02/d<P0Z<c40;3Dc02@]:`0W<2l0<Cdm02Pf=`0U
=3L0:c`o03]=D@16E5`0>4E?03e9E015Ced0>dQA03];D00`@DD0;Ce202hm@P0[>C`0=D95041<D00f
@TD0=3m002/f=`0R;Bh0;cPh02@]:`0202Ta;`03028[:00U;R/092dX00809c0[01T09BhX02L`:P0T
;BP07RPV02D`;P0Y<c409Bh]01/T8`0O9bD0728Q01hS8@0Q928082<P01lS7P0R9B40EEUK01dP900M
8B<07B4R028V9P0O8b<0:2`Z02<X900L8Ad0724K00807R<M00<07b4N020R7`0O8Ah00P0M7a`201XL
6@807AlL00L06adJ01TK600H6QL08B<R01hP7`0J71/061XI00805aTH03407R0O02@V9@0O8B008bDT
01HH5`0I6aX071`M01DE5P0G5aP061PI01@D5P0B4Q@0410B01XJ700@418061PJ018B500M7R0051/L
01@N7`0H8B<09bhc07j5R`1>DU/07B4Z018F7@0C5Q`051PL014E5`0C5AP04A4B010@400E5AD04A4A
01XJ6P0C4a<04Q8B01<C4`0K6a/0=CDd01LG5`0D4a@04Q0A01<A4P0D4Q<06ALH020N7`0C4A804@l@
00803`d>00h040h?00l=3P0=2``04@lB01TG6P0M6ah04a4D01/I700_;C00>SPk00X82`0L6Qd02`T<
01LE60803P`?00D0518E00d;3P0E4aH01`D800l=400200h<3`<03`d@00L04PlA00X61`0B3Pl071PI
014=3P0>2P/03@T:00@03PX;00D03@T:00d82@0>20X03PP:00l92`02010:300300l92`0>20X03PP:
00<03PP:00<03`T;010:300?2@/00P0=1`T01`0?2@/03PP:00h82P0>20X03@L900h82P0B30h00P0C
20`08P0?10P04PL;01462P0B1`/03`@801T>4P0K41@050T=00`21@0B1`/0304501@93@0>10L04@H:
028G6`0J3a<040H900l4200>0`L03@8600`31@0?1@P03@@600/3100>1@P07Q<G05Q>DP0?1`P03PD7
00d31P0?1@P040L900d31P0?1PP200h31`<03@8600<0304500l4200?10P0100?10PDooooo`006ooo
ool02P0<3PT03a4<00d?2P0=3`X0418=00d?2P0>40/04A<>01<E400B50l2010B3@0O00d>2@0>3`X0
3a0;00l@2`0>3`X03@h904e>B@0K71L03@h9018C3P0A4Pd01`P3018C3P0=3PT02P/600L80`0<3@P0
8R<N010A300=3PT02``700d>2@051P4030d800h>300=3@/030`:00d=2`0?3`d0410>014A3`03018B
400?014A3`0@40h03a0;00X;1P0;30L03Pl:00d?2P0<3PT04Q@?00dB300:3`T082DO01XQ6P072@L0
3`l=00<03Ph<00<03@d;00h>300>3P`01@0>3P`300l?3@0300h>300=3@/03@d;00804A4?01T03Ph<
010@3P0@40h03@h<00D71P0:30/02@/:01<E50010`80418A01`N7@0>40l071hM01DG5P000@006A/I
01<E4P051`@061XG01@F4`0@4Pl03a4>00`>2`0A4a00418?00801PP500H04A4A00d=3@0@41003`l?
00X:2P0B4Q83010@4003014A4@0D51@071`L00H03Ph<00@03@d;00`<2P0;2`T03@d;0P0?3`d200X:
200?01HF500820H0410>00X:200B4Q006a/I00`<2P0F5Q@02`/900`<2P0A4Pd03@h900`=200>3`X0
3a0;00<030d80P0=3PT200h?2P06018C3P0C50l03@h900/<1`0>3`X02P/60P0<3@P01P0>3`X0414<
00l@2`0<3@L03@h800d>1P8030d50P0>3`L02P0;30@03@h600h?1`0>3`L030d500/<100P8A/05AH@
010A2`0=3PP200`=1`1@00d>200>3`T020T300`=1`0>3`T01PT200T?200[<RX0SiJ>06icK00C6140
0@H0018E3P0?40X02P/500h?2@092P@03a0:018C3P0D5A000040020Q700U9R40:b`W010A300?40/0
3Pl:00`=200;30L03@h902<T7`0f=c8051D@014B3@0<3@P03@h901@E400B4`h04A8=00<4000?40/0
51D@04a=B00k?3L0:BXU02`]:00@4@`05AHA00d>2@0<3@P03a0;01<D3`0D5A005AH?00X<0@0?40X0
4A4=02@T8P2b/[80A4A4010@400?3`d05AHA01TJ4P0R8aL0;RX=03Tc3`1hKdP0a[V?0?ojc`3oom@0
imVb08IlF011>Qd05aH405mQE00>4`/051D@01@C3`0C4Ph201DD400401<B3P0B4@d04Q4=018A3@80
40l;01d051<?04=4?`2VYil0EeM40;JeV@2IUGP0Ad4W02HO3@0V7Q<07ALB01<?3P0B4@l04Q@?00hC
3`0@5A403A8>00h@3@0A4Pl03`l=01PH5P0E51803Pd;00l;2P0D40l06QHE010<2`0A3@`05a<B00h:
2@02018>3@0>00l;2P0A3@`04`l>018>3@0?2`X02`L600h=2@0;30L03a0;01@E400A4Pd00P<000T:
1@0<3@P200H70P0401<D3`0Q8Qd0IFES01/K6`80410@00`01PH601<C4`0=3@d00`<3018B4P0n?Sh0
@41001PH5P0B4@d040l:01HE400=30P2014@300B01@C4@0B41404Q0A01<A500E4aH05Q@G055BD@0L
7Qd04Q@C01TK600=3`X05QPC00P:1P0B5@`061/B00/>1@0J7A803A050`0B5@`08@0D5`h04aT?01HM
4`0=5@X06B4F01PQ5P0C7A806bDJ018M5@0540`051lK01PS7`0951005R4M08RCS`0`>cL031LC00/F
4P0G8Qh03QTE01@L600C61@041DA01<H500I7QX06QlK01TN6P0G71P05AXF01<H500B5a<04aPD01<I
5@02018H500401HL600H7QX05Q`H01DK5`805adI00H051XF01<I5@0E6aL06R0N01TO7@0G7A/201TO
7@0;01DN7@0E7ah05b4P01/U9P0G8b<062@T02Xe=`1HIVL0<Cm001/Y:P0M:bh00P0O;C00:`0d?dD0
@diD07Z5R`1UKgP0ADmH02`f?P0Z>3T09CDd02Ti>@0Z>SX08C4a01h]<00T<cP0<D1502@c>P0O;SD0
9C<k01XX<@0T=Cd08S<j02Dg>`0V>3P09STg02Xm>`0N<Bl0:chm028d=P0gBDd0=TM>02Lh@P0Z>TT0
9CE502Hg@@0W>4009SPk02Tl>P0aA4009STe02Pk=`0^@Cl0;T5002/n?00cA3h00P0_@3X02`0/?CL0
9SLb02Lg=00Y>CH0<D500392@@0a@D00<40o02Xj>@0`@d40;T100080<D=301L0<D=503A6B00`@TH0
<dA;03E6C@0fAdh0=TM?03A7C@0dBDL0;T9002a0?P0cAdD0=TU70354@P0bAD<0=4A303e=C00c@d80
<Clo030n?P0b@Sl0<d=003I6@`0203E5@P0703Y:A`0hB4D0Be]H04MGE00a@Ch0;Cdj03I5@00202Xd
;00T04I@B00oBD40:34/02L`:`0_>3<0;CHc028[:00]=S<0<3Tf03Dl>`0[=3<07bPW02Lc<P0[>CT0
9cHi02Hg>P0W>Cd0@U1I03e:E00c?d/0@D]G03=0B@0jBDh0<d9702Xi?@0T<cH09C<f02hj?@0mB4X0
9c8d02Pb=00a>c`0HVa]08bEU@0c?3/0:34`0P0W<2l05P0R:bP09Bh[02Tb;`0X<B`09S0X02Pb:P0U
;bP092h]028/;@0kAD@0;SLf024Z:@0U;R/07B<Q01hT8P0O9200724M01/P700N8ah092PY01/O8P0U
:B`2028V9`05028V9@0N8R40720O01/P700L8A/00P0M8Q`01P0M7a`07b4N024S800L7Q/06Q`I01hP
7@807AlL00L06Q`I01PJ5`0J71T07R0M01dO7P0K7A`05aTH00805ALF00P05QPG00T;2P1lOWd05QPG
01XL6`18BTT06adL01lO8@<061PJ02L05ADG01HF60071`T04Q8D014A4`0N7R006QXL00d>400L8R00
5A/L01`Q900=4QH04ADJ020S:P0F6B004aDK01DF6`0C51P0414C01<C4`0H61P03Ph>01<C4`0A4A40
20P8014A4@0D51@0410@00h>3P0O7al09bLW024Q8@0A3a00518C01DC500A3a005A<D00/92P0B4140
0P0@3Pl05@0B414040h?00l=3P0E4aH06QPK01hL7`0C4A@03P`?01HD5`040PD05Q@G01LE600:20/0
518E00l=400@3Q403P`?018@4`0?3A006aTL010>4@0200/9300600`:3@0@3Q404a4D02<P8P0G4a@0
30P90`0@30d0100<20T03PX;00h:2`0=2@X200`82@0300d82P0>20X03`T;00803`T;00<040X<00l9
2`0>20X01@0>20X01P0=1`T03`T;00l92`0?2@/03PP:00l92`802P@600D050h@01PB500C3@l05``@
01<8300201052@0P01462P0=0PH03@8601<8300F2`l04`P<00h31`0F2`l03@8601052@0?10P03@86
00l4200=0PH0;24U01T>4P0E2Ph05``@00/0100?1@P06@hB00P00@0C20`050T=00P00@0?10P05``@
01462P0N4aL01`0001<8300D2@d300h31`803@8600<0304500l4200?10P0100?10PDooooo`006ooo
ool03P0>40/04A<>00h@2`0>40/04Q@?00lA300=3`X04aD@01@F4@0A4`h03a4<014C3P0<3@P03Pl:
0P0@4@`06P0>3`X030d8024R7@0<3@P04Q<>00X;1P0=3PT04a@?018C3P041@0030d801XK5P031000
004001/L5`0:2`H02@X501PI500@4@`04A8=00l?3@0=3@/030`:00d=2`0@40h04Q8@1P0A4@l200l@
2`0:014B3@0<3@P01@L200D70P0B50l03A8<018G4@0k@3X0>T4j014D40803`l=00@03Ph<00d=2`0=
3@/03@d;1P0>3P`300l?3@0K00h>300=3@/03Ph<018B400A4@l03Ph<010@3P0?3`d03Pl>00lA400I
6aX03@h=024S8P000@005QPG00<510000@004Q@C01/M700F61L03Q0>00/=2P0@4Pl07R0M018D4@0<
3P/04A<@00<030h;00/02@/800h@3@0A4A403`l?018B4P0@41002@T900X:2P0=3@d03`l?010@4002
00d=3@0301@D500>3P`03Ph<00<03@d;00L030`:00l?3@0<30X030`:014A3`0C4a404A4?008030`:
00P03`l=018B400@40h01@D300P81P0A4@l020P6010@3P803@d;00H04A8=00`=200;30L03Pl:00l@
2`0;30L200`=20803@h90P0>3`X0200;30L03Pl:00X;1P0:2`H03a0;00`=200;30L03@h90P0@4@`0
0`0>3`X02``700`=1`0200`=1@0<00d>1P0?40P03a0800d>1P092P802P/300d>1P0:2`<01PL001@E
3`0>3`T030d70`0=3PP06@0B4`d061TC00`=1`0<3@L0414;00L:0`093`P04AP@07Z1N@1JGeP03A8;
00X?200J7AH051D?00h?2@0@4@/02``6014B300;30T02@X502h_:P0J6aH0`<6l01lP6`0?40/00`0<
3@P0<P0;30L01`P300l@2`0Q8Qd02P/600T:1@061`803Pl:010A300E5Q403a0;00P9100@4@`01PL3
020Q700G61<0414<01@E40010P003@h900l@2`0<3@P03a0;01DF4@0F5a805AH?00h?1`0?40X030d7
0000001FEUH04a<C010@3P0C4a407b0K01lP6P0H6@d0:bX>03Lb4P1CC2T0N6m80;JZPP3`h[/0_;2:
061H=010?B<0<S0Q071bI`0P9Ah04A8=0P0@3`/0100B4@d04a8>014@300?3PX2010?2`0P00h=2@0?
3PX051<>00H8001@DT@0QhU`0?kng03ooml0WIUj02lY4`0Z91@07AXA01HC3P0D4`h04Q@>00lA300>
4`l03A8>00lA3P0?40h03Ph<00T91`061P@01@@2010<2`0a;B`0CTY901/G5P0D40l05a<B010<2`0A
3@`2010<2`804@d<01l040`;00l;2P0;2PP030/7010A300:2`H030d801@E400S91l05aPC01HG4P0?
40/020T401@E400L7AP0GEeM00l?3`092@T05QHF00/;2`0?3`l04Q8B01PH600:2PX02`/;00`<300=
3@/03Pd900`;1P0N7AP03`h:00804A0<02004a8@014?400A3a004Q0C01<A500B4Q80;Rl^018D4`06
20L01`T600<5000?4@`05QTB01<F3@0G6Q402@`302<V6`082`005AP?018E300A50/04QD<018H3P0?
5P`03aL<018J3`0H8AH04adB00`F2`0?6A802QDA018M6@8041/G00P00Pd901`W8`0?6QH07BPT00PC
3`0G8Qh051lK014H5@8051TE00X06QlK01`Q7@0G71P051TE01<H500A5Q804QLC01<H500@5A404ALC
0P0C6AD01P0E6aL05adI01HL600D6QH05Q`H01LM6@804QPD00@05adI01TO7@0H7Q`05adK0P0I7ad0
7`0F7ah041XI01@N7@0H8R<04alO01DQ8@0S;S00;S`m020^;`0M:b`07R`_01l]<00`?T40>DA:05=N
I02jaL/0[kW208>=UP18E5/0?De=03=3@P0X>3P08c<c01h^;P0R<C@0<T56041?E00Z>D007Rdd02He
?@0G9Bh00P0R<c/08`0S=3/093Hh02Dg=`0W>SP08cHd02Tk>P0J;2`0;d5302i0A00]?TH0;Ce:02Xj
B00Y>T@0:CY202Xl?`0]?cl0<TE302Dh=00X>cL0;d9002m1@00[?S`0<40m02dm>@0^?cT0;Shk02`l
>@0`@3l0:SXi03A4A00c@d<0;clo02lo@00]?Cd0<TA30080<49200@0<TA403A6B00gBD/0=DM;0`0f
Adh0400cA4`0<TE;03]@CP0fBTP0<4A20396A00cAT@0;T4o03E8AP0a@D00=DE403A4@`0`?Sh0=492
0310?@0b@Sl203=3@00m03A4@@0gAd@0>DU603=3@00b@Sl0=4A103=3@00c@Sd0;SP`02`f;P0`>S80
92hV020Y900Z<bh0;SLb02lh=@0S;2T09c0]02`e<P0l@d80=3dl024Z:@0R;Rd0:cTj02dl?`0]?D40
8S@h03Q7CP1ULW`0AU9N03<mB@0gA4d0=TE:0350A@0_?T80;C`o02Tg>P0b?T40@Te?03U4AP0^>3X0
7RPY045;C01[M7@0;3Dd028[:P0T;B`09Rl^02@]:P0W<2d0:S<`02Tb;@0V<2P0:38Z02D_:00M9bH0
;SPi0:bf]@2IXZ40>T=2024Z9`0201hT8P0:01hS7`0J7a/06QlK01dR7@0A5AH0GV9U028V:@0A5AH0
4QHG01`P7`807R8Q00/07R<O01lT7P0O91h07R<M01`N6`0K7AX07b4N024S800O8Ah0828O01PJ5`02
01TK600601PJ5`0L7Q/0828O01`N7@0J71/05aTH0P0F61L07P0G6AP06A/J02LY:00^<2l07AlN00d?
3P0Q8b807alQ01PH6P0G5aT05QHH01@D5P0H61X09RHX01`L7P0?3a406ATK01hN800>3a403a<B014G
5P0=4QD04aPL01TL8P0J7B@04aHM01LG7P0G61d05ADH01@D50805ADE0180410@00T92@0I6AT05aLG
01hN7P0;2`/051@D00l?3`0>3Ph0820P01LG5`0>30d0518C01LE5P0A3a005aDF014?400D4Q<2014?
400801<A4P0A3a0040h?00h<3`0B41<06ALJ01HD5`0A3a8201DC5P0H01<A50091`X03`d@018@4`0@
3Q402`T<01<A500H5QT0NWQk0:2NX@0B41<03P`?00d;3P0>30l04Q0C01DC5P0U8R@06aLH00l;300@
30d04`l@01DA4P0>2P/03@T:0`0>2P/00`0@30d04@`=00l92`0400l92`0300h82P0=1`T03@L900D0
3@L900L03PP:010:300@2P`03PP:010:300=1`T050h@008091hP00<04P`>00l4200:00<00P0?10P0
2P0C20`0304500d21P0>0`L04@L:01872`0<0@D050T=00/0100<0@D201462P0A00d21P0@1@T07Q<G
01462P0<0PD040D900X00`0800404@H:00h31`0;0P@05``@01@93@0A1PX05@X>00L0000d:Bd00P07
00000`0@1@T03`@800l4200200h31`803@861P0?10PDooooo`006oooool03P0:30L03Q0;00`>2@0<
3PT0418=00d?2P0<3PT04A<>018D3`0?4@`03Q0;00lA300=3PT03a0;0P0@4@`06`0?40/03@h901@E
400@4@`06a`G00X;1`0<3@P04a@?00`=200?40/03@h900h?2P0=3PT06Q/F00`=200N7aX06a`G018C
3P0@4@`020T4014A3`0?3`d03Ph<00l?3@0B4Q004a<A010@3P0300h>300>00l?3@0@40h03@h9010A
300A4Pd02``701DG4P0U9b804A<>00L<1P0O91h051TC01XQ6P0=4@`200l?3@803Ph<00<03@d;00h>
300>3P`01@0>3P`300l?3@0600h>300=3@/03Ph<018B400A4@l03Ph<0P0@40h05@0<3@`020X900P:
2@0A4a80Bde<01PJ6@0;3@`02@X902<U900c=C@071hM01TK6P0=3`d03@l<00h@3@0=3``061TG06AV
H`0?4@h030h;00/=2P0200d?300500h@3@0=3@d02PX:00/;2`0@41000P0B4Q80100820P02`/;010@
400>3Ph200`<30803`l=00D03Ph<00d=2`0<30X030`:00d=2`0200`<2P804A4?00<03`l=018B400?
3`d00P0<30X03P0>3P`04Q8@00X:200?3`d03Ph<010@3P0B4Q003`l=00h?2P0<3@P02``700d>2@0>
3`X03@h90P0<3@P200d>2@<03Pl:00/04A8=00d>2@0<3@P0414<00h?2P0?40/04A8=018C3P0@4@`0
30d800/<1`0200d>200700`=1`0=3PP03a0:00l@2P0>3`T02P/500d>200201<D3P0>010A2`092P@0
2@X400`=1`0?40X03@h800/<1P0G6180824K01<D3P0;30H03a0:00`?200>4P/200X?200Z00lD3@0?
4P/03A0900lB2`0<3@L020T300h?2@0<2`H04a8=00l@30092PD020T600h?2P0D5A003@h900`=2009
2PD02``700d>2@0>3`X05aPC00`=200?40/0414<00l@2`061`804A8=00d>2@0R8ah03a0<00/<200B
4`h04a@?00<40@0720<0414<00d>2@0@4@`02P/700d>2@0:2`H02``70P0>3`X06`0A4P/03a0800T:
100?40X04A8=010@3`0H61H051@B014B3P0O81/09BHP01`M4`0T8Pd0;BX@03Db5011?1`0FE8`075Y
A`1SFc/0>cDH034_6@0M7Q404QH>018H4P0B4`h04Q4=014@300201<B3P03018A3@0@3`/04A0<0080
4a8>010051<?01PG4@0W:QT0=CTQ08B7IP3gn=<0ko3807UhD`0`;1<09B4>01PE2P0G5@`05aL=01HH
3P0=3`X030l<0P0?4@h02`0<3@X030`:00l?3@0B4Q004a8@014@3P0B40h05a<B01dI600?2`X05A4@
00804@d<00<040`;01PD4`0E4A000P0A3@`0500D40l05A@B01DE4@0=3PT030d801PI500:2`L061TD
01hO6P0:2`L0414<00/<1`0F5a805QHC01TI600?3`l04A4A00h>3P0;2`/030`<0P0>3Ph02`0M7Ad0
51@D01TI6@1;BdT06APD00T8100C4Ph04A0<00`;2@0F5A<051<A00@04a4B01X04Q8A01@F500`<Rl0
7R0M01<E4P0?4@`051HA03e0>@0I71D00`H001TL4`0@4`X04A@;01PK500D5a004A@=010C300@5@h0
3Q@=020W7`0B6A40O8Al09fWWP0h@ST05R0I014J5`8041TF00@0624N014J5`0E7Q/04a`I0P0@6AH0
1P0B6aP03AHC01<K5`0C61@04QLC01<H50@05a`H00P061dI01hS7`0N8al061dI01LM6@0H7QX051XF
01<I5@805A/G00<051XF01DK5`0I7a/00P0H7QX01`0I7a/05adK01HL6P0F71X05b0M01TR7`0H8R40
0P0I8b801@0G8b<06BDU01`X:00G8R@072X[00807bd^02X09C<f02Le>00oCE00Gfab09RUZ`3^nO`0
joSl0>;^lP28UY`0A5=F03U9B@0Y>CT08S4d020_<P0Q<3<07bhc02dl@@0P;c@08C0g03A3BP0`@4P0
8c@n02Hg@P0V=d009SLo02Pj?P0V>3T0:S`m02Dh=`0Z?C`0;T1002Dg>00^?dD0:CY302loB`0/?DH0
:3U102/m@00^@400;d5002Dh=P0X>cT202i0@00C02do?`0a@D00;Cdl02lo?@0_?ch0;3`k02lo@00_
?T00<d=502hm@@0]?400<T5503=2AP0bA4D0<dE50394A00fB4X0>Ta>03U;C@0203E7B`0E03I8C00g
B4l0=dQ?03I9C@0iCT`0?U9@03Y>C00eBDL0=DQ603A7A@0gBTP0=dM603U9B019FEP0<T1003E3@`0d
A440=DE203A4@@0fAT<0=dM40080=DE20P0a@Ch00`0dA440;cll02dl=`0202`f;P0R034k<`0W<BT0
7bPS02D^:@0Y<Rd0;CHc02L`;@0J8b006b@Q02H^;00S;2/082PZ02D`<@0/>S/0;Se003A4B00Z?400
?4]B04mMI@0gA4d0=Cm;03=0B00Z>Ch09SDh04]JG@1NKG00?de>02hj?00Z=CL0<clo02/f=P0S;Bh0
<cdn030j>`808R`]02X09Bl_02<];00T;Rd09S4]02Td<00X<bd09C0Z02Lb;00S;RT0:S@c03Q2@`2S
[:`0S9FD02lh=`0T;BX07bDS01hT8P0M8Qh06QlK01/P700O91l0:2`]05QLGP0a=CH08BDV01dQ8P0Q
9B@07R8Q01lS8P0P9B407R<O01`Q7@0K81/092HS01dO700O8Ah09BLT020R7`0N81d06A/H01`N6`0K
7AX301TK600=01dO7P0L7Qd06A/J01TK6P0J71/071hM01DG5P0I6aX092HU01TK6P0O8B0051HE01XJ
700201LG6@0301HF600D51H06QXL00805QHH02<07AdO01HF600E5AL04a@F018E500C5aL03a8D01XL
8@0J6R405aLO01<C6`0G5A`05Q@J01LE600G5AH05Q@E034a<@0V9RH03`l?01LG5`0H61P051@D02`/
;00G5aL03`l?010@400I6AT03`l?014?400B41405Q@E00l=3P0C4A8040h?01@B4`02018@4@0>01<A
4P0B414040h?014?4P0?3A004@lB018@4`0?3A0040hA018@4`0:20/030X=01DC5P0:20/2010>4@0A
014?4P0H5QT0BTQ;069PH`0D4QD03`d@00h<3`0=2`h03P`?00l=400C418030P900h:2`0?2``03@T:
018>3`0=2@X00P0?2``01@0<20T02PH700`82@0@2`d040X<00@03`T;00<03PP:00d72@0=1`T00`0=
1`T0<@0?2@/03PP:00d72@0?2@/040X<00d72@0C3@l03`T;014;3@0L5QP06aDG00`6200=10H02`84
01P=4@0@1@T05``@01062@0D2@d040D901462P0F2`l03@8601462P0;0@@0304501872`0@1@T03045
01052@0;0@@04PL;01052@0B1`/07A8F01@:3@09008060dA01D:3P0;0@@03`@801<8300?1PP04@L:
040e>@0J41<04`T<00d41P0@1@T00P0?10P300h31`H03`@85?ooool001_ooooo00h02@/600d?2P0;
3@P030h9010B3@0=3`X030h900d?2P0?4@`04A<>010B3@0=3`X03a0;00h?2P803@h900T03Pl:00l@
2`0;30L00`@000T:1@0=3PT05AHA00l@2`0>3`X00P0@4@`02P0G61<03a0;014B3@0O81/0XJ:M092A
S00O81/05aPC01<D3`0>3P`200l?3@<0410>01<03`l=00d=2`0<30X03@d;00h>300?3`d03Pl:00/<
1`0=3PT02``701LI500[;BP04A<>00/@2P0D6A<0<CH`071gL00H6aL03@d;00<03Ph<0P0?3`d600h>
30<03`l=00<03Ph<00d=2`0=3@/00P0@40h04P0>3P`04A4?014A3`0Q8R00;Bl^01XL6`051PD02`d<
00P:2@072@P06A/J00P:2@0=3`h04A<B0001000B518030h;01<E4P801`T600@0=SPe00`>2`0<3P/0
3@l<0P0@4Pl01P092`P03`l?014A4@0@41002`/;00X:2P<02`/;00@03Ph>014A4@0A4A403Ph>0P0@
40h0200?3`d03@d;00`<2P0<30X02PX800`<2P0?3`d03Ph<0P0=3@/200/;2@0501lO7@092@L020P6
018B400>3P`00P0?3`d02@0:2PP03Ph<00L71@0;30L03a0;00h?2P0;30L03@h9018C3P0200`=2080
3@h90P0>3`X02@0@4@`04Q<>00`=200<3@P03a0;00`=200=3PT0414<00l@2`0200`=200300d>2@0>
3`T03Pl9008030d70P0=3PP09P0:2`D06AXD01TJ500@4@/03a0:01@E3`0>3`T030d700d>200?40X0
30d700X;1@061`402@X400X;1@0<3@L0414;010C300:3PL03A8;00/@2@0>4@X01@P101<F3`0<3@L0
30/600/:1@0B4@`03Pd801@C3P0;30L06Q/F00D60@0A4Pd00040014B3@0?40/04A8=0P0@4@`0100E
5Q4071dH00h?2P0@4@`200`=200>00<4000>3`X07AhI04Y;AP0D5A00004000T:1@0J6aH03Pl:00l@
2`0C50l04A8=01<D3`0<3@P3010A300M00h?2P0?40/030d700/<1P0H6A@05aPC024R7@0:2`H061TD
014B3@0=3PT04A8=01DF400I6Q804A8201DG0P0J6@D0;R`C03`h6`13?R40@ShS03@b6`0D50L04aH;
010E3P0A5a<04Q<>014@300@3`/00P0A40`0100>3@T040l;01<B3P0H5a<201TH500?01/J500M7P`0
:B/C034e501PHS/0Q8IN03Xk6@0S8@X071X;01@B200;2`<020P001@D2`0>40/030d;00804Q8@0100
2`/900d=2`0J6QP04Q8@00T91`071`D02@T700X91`0@3`d04A0>020O7@0E51803@`:010?3@0?3P`0
3@`:0P0:2@L06`0=30X040l=00X:200G5aD03Ph<0082000J6QT0YZJT08N7Q@0_;bd061PF00T91`0>
3P`04Q8@01LG5@092@L010@200`<2P0B4Q004A4?01LG5@0410804Q8@01PH5P030`4061PF01DF4@02
00T:1@05028R800410804Q8@018B400C4a400P0B4Q02010@3P0;01HH500:30L00@<001XL5`0H6QD0
418=01@F4@0A50d041<<00/>1`0N8AX00P0D5a008@0B5@h04A@=01<F3`0B5a003A<<01hU7@0I81P0
TYZB0:jh[`0kAC`04Q`E00`E400?61<0624L00XC3P0<5A00214<01XS7P0?61<03QLB01XS7P0E7QT0
5QdI01XP700M8al06b4M01LM6@0J81`05Q`H010F4P0C6AD061hJ01TO6`0201HL600301LM6@0D6QH0
5A/G00@05Q`H01h05adI01XP700J81`061hJ01HO700D7AX05AhK01LP7@0H8Ah05R0O01/U900J9R@0
5b<S01PV9P0N;2`05bDV01<Q8P0K:BX0528S02@b=@0`?T40D5iQ07Z9SP2Z^Kh0jOOi0>kmo`3?g^D0
Lh>90394AP0]?d4202@f>00:02Dg>@0P<S@07S0d02Li?@0P<SH09CLk02i0A00^?dH093A102PjAP80
9SQ203T0:Se302@g>`0Z?Sl08SHe03A8A`0Z?S`0=4Q602Xn?@0X>D00;Sm702dnAP0/?D@0;T1302Tk
?@0Z?3h0:3Xj02`n?P0]?cl0;d5103E7A`0_@D40;Clo0312@P0_@D<0:C/m02Tk?`0_@DD0<D=702ho
AP0`@DP0=TM>03=4B`0dATP0=dU;03E7B@0hBT`0>Ta>03I8BP0dATX0=DM;03I8C00hBTh0>D]?03U=
CP0cB4H0>De;03M;B@0hC4X0>Da:03E8AP0fBDL0=TI503Y:B@1=GE`0<Clo03U7A`0b@Sl00P0_?c`2
03Y:A`1D0392?`0dA440?Ti;03];B00]?CX09cLd02Xi=015CdL0<S`d02/e;@0X<RX08b`W02D^:@0W
<2/09Rl/02L`;@0]=S<09c0]02L^;@0Y<C<08RX]01lZ;00W=CH0;C`o02lo@`0[?D40>TU@02`j@P0_
?4@0@D]E030mA00a@4<0:cXm02dl?P0`@400;S`m02ll?@0T<300:CDe02Xe=@0^>3L0<C/j02La<@0Q
:b`09Bl`02Tc=00T;Rl092h]02H`;`0X<bl09c8^02<^:00U<2X08B`W00hH5`0J92D0=d5003M0?`0S
;2/082TV01lU8`0N92807B8N01/P700L8Ad08RLR04E9B00T:2T07B4Q01/O7P0M8B008bLV01`P7`0N
8R407b<R01`P7`0K81`07R<O01hP7@0I6aP071hK01dO700L7Q/0<38_0P0N81d01P0K7AX06A/H01/M
6P0N81d07AlN01`N7@806Q`K01T071hM01hP7`0J71/061XI01`N7@0N81l061XI01HH5`0E5AL05QHH
01XJ700H61X05aLI01dM7`22PX@0;Bd_01<C5@0B4Q@071`N01hN800B51<051DF01TI6`0D4aP040lD
00805a@K01H05a<J01<>500J5AT07ATJ01DD4P0D51@00P8201`L700?3`l03@d=028R8P0W9bL06QXJ
01/K6`0H61P04Q8B020P800B41403@/<01<A4P0B41405Q@E0P0C4A82014?400=018@4@0A3a003`d>
00/9300=2`h03`d@018@4`0C4A@04Q0C01PF6@0A3a8030X=00X82`02014?4P0701LE600:20/02`X<
02LU:00@3Q402`T<00d;3P0200`:3@802`T<00d030T;00X61`0@30d03`/<00h:2`0C3a003@T:00h:
2`0?2``030P900/7200@30d04`h?008040X<00<03`T;00h82P0>20X01P0?2@/02@0C3@l04@/=00/5
1`0=1`T03`T;00`6200?2@/03PP:00`6200300X41P0;01X?4`0D2@d08AHJ00T00P0C20`05@`>0187
2`0;00@03P@701P=4@0=0PH00P0>0`L04@0A1PX03`@800`11@0=0PH03P<700L0000<0@D0308500`1
1@0B1`/03`@800h31`0700003`H800l4200C20`0200100804`P<00@02`0400L0000C20`04`P<0P0@
1@T200l420803P<71P0?10PDooooo`006oooool02@0<3PT0418=00h@2`0?4@`051HA014C3P0=3`X0
2`d800h@2`0201<E400300h@2`0@4@`03Pl:008030d800<03Pl:010A300B4`h00P0B4`h04@0=3PT0
4Q<>00P9100F5a8051D@00`=200?40/03Pl:01LH4`0[;2L0kNkY0=;CcP0N7aX03@h900l@2`0=3@/0
3Ph<00803`l=0P0>3P`0100?3`d03@d;00`<2P0=3@/200l?3@0<00l@2`0<3@P04Q<>00X;1P0620<0
3a4<010B3@083@L041D?00lC3`1CFU<03A4<0P0=3@/0100>3P`03`l=00l?3@0?3`d600h>30<03`l=
03403Ph<00d=2`0<30X03`l=010@3P0>3P`04A4?018B400D5A@03a4@00<5100D5QD0418A01DG5P0B
51<02`d<00lA400;3@`0418A01LI600A4a403@l<014C40092`P03a4>01<E4P0?4@h03Q0=00/=2P0>
40d04Q@A010B3`0820P03`l?018B4P092@T01PH600/;2`0A4A403Ph>00`<300?3`l0410@00d=3@0A
4@l0410>00l?3@0>3P`03@d;008030`:00T03`l=01<C4@0?3`d03@d;00h>300<30X05ADC03lo?@0M
7A/00P0=3@/01`0?3`d0410>018B400;2`T04Q8@00X:200:2`H00P0A4Pd00`0<3@P03@h901HG4P02
00`=20803@h90P0>3`X030082@@02``700P910092PD03Pl:00`=200:2`H03@h900`=200:2`H02``7
010A30803a0:00/03@h800`=1`0<3@L030d7018C3@0];RP0:R/U014B300=3PP05QLA00l@2P0200/<
1P803@h802P030d701<D3P0:2`D03Pl9014B300:2`D02@X400T=1P0@5@h000D000hA300B5@h030l8
00h?2@0=30L02`X500l>2@071P4030/601HG4P000@007b0K00L81@0H6A@02@X500`=200?40/02``7
00T:1@0?40/04Q<>00l@2`0J6aH030d8018C3P0=3PT051D@00X;1P0[;2L03Pl:0P0?40/01P061`80
5AHA010A300=3PT05AHA00d>2@8030d803403a0;00h?2P0;30L03@h901<D3P0E5Q00824L00@50007
20<051D@014B3@0E5Q405aPC01HG4P0>3`X04a@=018D1`0L7`h06QX801/J1@0L6P<0:RPA02TW4P0f
=B405QL900@7000G71H0318>01PH5P0G5Q805A@@01HE4@0E51004Q4=00d<200A40`061LC01XI5@0I
61@06ATC01<D100a<ad06A`602//2P0T9@<08R@8018A000C4@D05a<>008040l;00H0:bXU010A300>
3P`051@B01<C4@0<30X200h>30802@T700T03@d;010@3P0?3P`03`h<01/J600^;B/06aXH00/:200A
40h01@0>3@/07`0?3P`071`J00D50`092@L06ATG00/;2@1EEE<0H61N00`<2P0A4@l03Ph<018B400A
4@l0410>01lO7@0Y:BL04Q8@00T91`0A4@l02@T701XJ600=3@/04a<A0041000A4@l03a0;01DF4@0G
61<0?Shl00`<2P0D51800`0@40h0100?3`d03@d;00d>2@0:30L201HH4`0Z01DG4P0:30L04Q@?00d?
2P0I71D04A@=01`O600=40T0:bhW010C300A50d04QD>01@G400D6A805A/C01hU7@0;4PX0;CD]03Do
=P0D7QD08b`V01PQ700=5Q403aPC018K5P0K91l03aPC01dV8@0>5a807RLR01PQ700>5a8051/G01XP
700V;2P092XV01HL600?5A403A<?00lE4@0A5a<051XF0`0F71P201@J5P0_01LM6@0I7a/05adI01PN
6P0G7AT05A/G01PN6P0I7a/05Q`H01PQ7P0F7a`05AhK01LP7@0F8Ad051hM01@P7P0E8Al04AdM014O
7`0I9bL062HW01<Q8P0V=3D082h_024_<P0U<cH0BUUL05ASJ01YN7d0a]GJ0>[io`2GZ:l0AEIM02i0
A00X>S`07S0b020b=00V>3X09cTk01`^<P0R=3P07c4e02@f>P0S=CT08C8i020b?P0W>DH00P0T=T80
400X>T<08SDk02i1A@0O<c@0:cln020d<P13Ee@0;D4o02do@`0_@4P0;Sm603=5B@0dATT09SPj02Tk
?@0Z?3h202i0@0040312@P0iBd/0;T1002i0@@80<dE700/0;T1302i0A00_@DD0<4970352B@0eATd0
>DYB0393BP0fB4/0>Ta>03M9B`0203U;C@0303=5A`0iBdl0=dU=0080=TQ<06L0=dU=03I:B`0gC4X0
=4Q60396A00gBdT0=dY80313@@0hBdT0;cln0351@010D4l0<3hn041>CP0fAT<0<D4n0392?`11DDh0
@e=@03Q8A@0gAd@0=DE20392?`0/?3T0:CTf02Xi=00a>c<0<cde02Pb:P0L9Qh07RLR02H_:P0W<2/0
8b`Y02H_;014CDX0?DI3024X:@0M9BL082P[02Td=P0a?d00;3/n02Ph?00^@4@0;ci503Q6CP0b?dL0
9Bli02Tf?@0^?D00:3Lj02hm?`0c@d<0;S`m030m?@0d@400;CTi02/f=@0T;Rd07BLV02Tc<`0O:BX0
8B//02Pb<`0V<34092h]02D_;P0X<S409S4]028]:@0T;bT082/V01dW9P0R;2d07bTX028[:P0J8b80
7RLT01lU8`0N92807B8N01/P700M8Qh092TT01XN7@0Q9B@06alN02``;`0Y;B`05QXI01dQ800O8b80
8BDT01hR8@0O8b8092PV02@V8`0P8Ql07R0M01@F4`0A4a00<C<`008071hK00/06A/H01XL6@0Q8b00
:B/X01`N7@0K7A`06A/J01XL6`0L7Qd07R0O01/M700201TK6P0^010B4@0H6QT03Q0?01@D5P0G5aT0
71`N01/K7@0I6A/07alQ055AD`0I6A/09BDW024Q8`0F5QP04A4A01PJ6@0M7Qd05aLI018A5P0N7280
3``C01/H7`0I5A/050lE01hI700Q7A`061LE01@C500I6AT05QHF01DE5@0X:2P04Q8B01PH600F5QH0
4Q8B01@D500m?Cd0OGem028P8@0D4Q<05aDF014?400@3Pl02`T:01<A4P8040h?01404Q0A010>3`0?
3@h03`d@01<A500B41<040hA00d;3P0:20/03P`?014?4P0?3A00518E01PF6@0@3Q400@0201<A5002
010>4@0?00H41`0B41<03@/>00d;3P0>30l03@/>00`:3@0?30h030P900h:2`0<20T03@T:018>3`0:
1PL030P9008040`=00<04`l@01XF5`0I51D00P0@2P`0100?2@/03PP:00h82P0@2P`5014;3@0T01D?
4@0B30h02P@600/51`0>20X030H800T31@0>20X04`d?010:300<1PP02`D700X00`0700006@hB00L0
000I3Q80:QlS01H;3`0>0`L04`P<01lD600D2@d04`P<00l4200C20`03`@800`11@0C20`04PL;01<8
300@1@T04@H:00h31`0;00@03`@80P0<0@D02P0C20`03@8601`B5@08004040D900/1100@1@T060dA
00/1100B1`/201052@803`@80P0>0`L600l421Cooooo000Kooooo`0<010B3@0C5A004aD@04U;AP1Y
JfH05ALB01@F4@0?4@`04A<>010B3@0<3PT0418=0P0C50l0@00B4`h04A8=00h?2P0<3@P03@h901@E
40092PD04Q<>01LH4`0=3PT06Q/F00l@2`0>3`X04Q<>014B3@0=3PT03Pl:038c;P0j>cH030d801TJ
5@0720D03Ph<00P81P0H61H04A4?00/;2@0<30X06ATG01PH5P0820H04Q8@00@40P0>3P`0414<00d>
2@0<3@P03@h900lA300@4Pd02`d800lD3P0;40X02Pl900XA2P0:3@T03`l=00/;2@0I6AL04a<A00L7
1@0B4Q003`l=00h>300@40h04Q8@014A3`0<30X04A4?00T91`0@40h02`/901HF500;2`T200`<2P05
00l?3@0<30X030`:00l@3P0?4A000P0A4a80300>40l03@l>00`>3@0C5A@02@/:014C4P0=3`h0418A
00d?3@041@<0418?00P:1`803@l<00d03a4>00/=2P0?4@h03Q0=00T;200I6aP0=cLg00T92@0>3Ph0
2@T9010@400=3@d02`/;00803@d=0P0<30`04`0?3`l03`l=00h>300>3P`03@d;00h>300?3`d02`/9
00h>300@40h03Ph<00d=2`0A4@l0410>00/;2@0J6QP051@B00l?3@0=3@/00P0>3P`03@0G5aD0EEEC
01XJ600?3`d03a0;018C3P0720@00`@100d>2P0B4`h0414<00h?2P0=3PT00P0>3`X200/<1`0800`=
200=3PT03Pl:00h?2P0=3PT02``700h?2P0?40/200h?2P0900l@2`0<3@T05AHA00d>2@0<3@P04Q<>
00D60`0=3PT03Pl:00@03a0;00<02``600`=1`0=3PP00P0>3`T02@0=3PP03Pl900/<1P0>3`T03a0:
00`=1`0@4@/08bHO00lB2`0200/>1`0;00/<1P0=3PP030/6018A300=30L03P/6014>2@0=30L03a0<
00`=200A4Pd00P0=3PT200l@2`0;00h?2P0=3PT03@h900`=200:2`H0DU=>04M8@`0?40`03Pl:01DF
4@0@4@`01P0=3PT200h?2P0401<D3`0N7aX061TD00l@2`804A8=01h03a0;00d>2@0?40/04Q<>00l@
2`0>3`X04A8=014B300D5@l05QLA01<D3P0@4@`03a0;00h?2P0@4@`04QD=018E2P0D5PT05aP801XJ
200N7P`07Qh=01/L3@0F60/04A@=00lD3P0?51005aLD00d<200C4Ph6018A3@0f01<B3P0D4`l051<?
01PH400F5`X06Q/801`O1`0I70@06Qd;00h>1@0>3@X04Q0C014?4`0A3a407ahL010?3@0;2`T04Q8@
01HF500?3`d030`:010@3P0;2`T03Ph=01<C4@0=3P`02P/900l?3@0A40h0>STg00h=2`0?3P`04A0>
00d<2P0>3@/02`X8010?3@0>3@/04a8@00d=2`0?3`d03Ph<00T91`0<30/030`:024Q7`0A4@l07QhL
020P7P0A4@l05ADC00h>300N7Q`07alM0P0=3@/01@0E5A<04a<A014A3`0@40h03`l=0080410>00d0
51@B010@3P0F5Q@06QXH01<C4@0@40h05ADC01hN700E5A<04A8=01@E400D5@l04A<=00804QD>00<0
4A@=00lA300>40/00P0B50l04@0@4Pd03a4<01<E400G6A@051HA01LI500D5Q406adH018G4@0C6A80
4QTB010G400C71@051hF014K4`0A6A<04QPD00804ALC018051XF01HL600F71P05A/G01LM6@0E6aL0
4QPD01<I5@0C6QH03QLB01/T7`0]=S404a`G00/D3`0F7aX04a`G01@M600G81/201@M600401@L5`0D
6QH05adI01PN6P<05Q`H00P05adI01TO6`0I7a/061hJ01HL600D7AX05AhK01DP70805R4M01T05R4O
01<O7@0D81h05R@T01PV9P0I9bL072X[024/;P0N:B/092la020^<@0Z>3/0:3Lj03=4B00hBTh0G6mc
06AfO01DIfd0>4]A02Hi?@0Q<cL07c4e028d>00Q<cL08S@h00807Bla0P0T=SP08P0Q<cD0:ce202@f
@@0W>DH09cU502HhA00V>480:3]102Lj@@0Y?4009c/k02Di>00V>cP0:Shl02Xl?P0Y>d00;T1402m1
A@0/?T80;d550353A`0a@dH0=DM903=5AP0`@T80=dU903mAD`1:G5h0<D=503A6BP0bA4P0;3i202ho
AP0Z>d<303Q9D@0L05=TJ`22U9T0=DM;03=5B@0eAd/0?U1D03U;C`0eAdT0>4Y<03U;C@0hBT`0=DM9
03=7A`0dBDL0<dM503U=B`0fBTP0@eID03=6A00gBTP0@U9A04ADD`0jBTT0>dU903E3@`0gAd@0=DE2
03I6@`80>DU604D0>4Q503];B00iBDH0>d]803=3@00[>cP0;chi02hi<00/=Rh09BlW024[8`0T;BP0
9RlZ02Xc;P0]=S<08b`Y02Tb;`0N9b@0;C@e02<[;P0K8RP09c8f02lm@00]?3l0=DI902/m@@0`?d@0
;3Y002dj@00/=Sl0;S]002dm?@0a@D40;clo02`l?00fA4@0:cPh02@`;`0W<c40:SDc02Pb<@0Z=C40
92l^024/;P0X<cD0Ef=T02/g=`0T<3009C4_020/:P0R;R`08bl[024]:@0K9b<08B/[028/;@0U;bh0
7bPW01dV9@0`>CH0:c4_01hT8P0L8Ad06AhJ01dR7P0P9Al07R<O020T8P0R9RD00P0P92<02`0R9RD0
CU9A04U=C00S9bH07b<R01dQ800R9RH08R@R024S800M7a`06Q`I00@06A/H01007AlL01/M6P0K7AX0
9bTV01/M700H6QT05aTH01TK6P0K7A`061XI01HH5`0H6QT06A/J01PJ6@0F61L051HE0P0C4aD01P0E
5AL06QXL020P8P0H61X06ATK01PH6P805aLI028061PJ01TI6@0E5aD061XH01XJ6`0I61`05A@J018?
5P0D4AP061@J01D@5@0F4Q<061@C01@C4@0C4Q<0410@014A4@0F5QH05ADE01<C4`0E5AD05QHF010@
400C4a<09BDU08R8R00P7Ql020H700h<3@0B41403`d>01@B4`0A3a004Q0A100A3a00100A3a8040hA
010>4@0@3Q4200l=400300d;3P0A3a804@lB00803`d@01003@/>018@4`0@3Q4040hA014?4P0<2Pd0
3`d@010>4@0>30l02PP;00h<3`0?3A0030T;00l;300>2P/02`L80P0A3@h05@0>2P/04@d>010<3@0=
2@X03PX;00l;300?2P/03`T;014;3@0F418040X<00`6200A2`d05@lA01@>400@2P`03@L9010:300A
2`d03`T;00h82P0200d72@0700h82P0?2@/03PP:00h82P0=1`T03PP:00l92`0201052@0:01H;3`0>
1@L04@H:01462P0G3Q00=b``01062@0E2Ph0304501462PH040D91P0?10P01P0A1PX03`@800l4200A
1PX04`P<01462PH03P<700<03`@801462P0A1PX00P0?10P01`0A1PX02@0201`A5@0C20`02P0300l4
200;0@@05?ooool001_ooooo00P010H1014C3P0:30L05ALB02HX8`0620<04A<>00h@2`803a4<00D0
3@l:010B3@0D5A004a@?014B3@0200l@2`0700h?2P0E5Q403@h900`=200=3PT0414<00l@2`0300h?
2P<03a0;02P04Q<>00d>2@0A4Pd04A8=01TJ5@0?40/03@d;00`<2P092@L01`L6028R80092@L04a<A
014A3`061P@04a<A00T91`0=3@/02P/600/<1`0=3PT0414<014C3P0B50l02`d800P=1`0730H02a0:
00`C300>4@d05ADC00d=2`0_;bd0<c<a00h>300=3@/0410>00h>300@40h04A4?0P0@40h03P0G5aD0
5ADC00/;2@0<30X02@T701hN700>3P`02`/9010@3P0?3`d03@d;00h?3@0>40l03@l>0`0<3Pd01006
20L02@/:018D4`0<3Pd200L9200@03m1?`0K7AX03@l<01LI5P0E5a@04A<@00d?30092`P03a4>01<E
4P0=3``0418?01HF5P071`L04Q8B00T92@803Ph>00<030`<00d=3@0>3Ph00P0<30`07P0?3`l03`l=
00h>300>3P`03@d;00h>300?3`d02PX800/;2@0<30X03@d;014A3`0J6QP0410>00H6100;2`T02PX8
00h>300;2`T061PF00L71@030`40;bl]01LG5@0:2PP02``702l`:`0N7aX02``7010A30803a0;00H0
3@h900`=200=3PT03@h900/<1`0<3@P2010A300A00d>2@0<3@P03Pl:00/<1`0A4Pd051D@018C3P0<
3@P020T400@40P0Z:RP02`/901<C4@0=3@/06a/I00X:200;2`T00`0<30X05@0;30L02``600X;1@0:
2`D02``600`=1`0=3PP030d700H70@0Q8Q`01`P300P90`0?40X04aH?00T:100;30H03a0:01@C3P0G
5Q403Pd8018?2P0200h;1P09014>2@0>3@P020P500`=20020`003a0;018C3P0A4Pd030d800<03@h9
00P03Pl:010A300H6A@03a0;01HG4P0:2`H030d800X;1PD03@h90P0C50l0100?40/030d800P9100;
30L2010A30804A8=02803a0;014B3@0B4Pl0410>014B3@0B4`d02P/500T:100;30@03Pl7014B300C
50l04Q<>00l@300=3`X03A09010A2P0C5@X05AL:01PJ3@0E5`T061X=01PJ3P0C50h03a4<010B3`0F
5a8040l;01HE4@0@3`/03@`8010?2`0B4@d04A0<0P0@3`/08P0A40`04a8>01hJ6@0I5A805AD;018D
1P0@4P@04aD:01<E4P0B4aL040lF010=500B41D03`/;01LC4P0A40h0;bh/03<b<00H61H05ADC01PH
5P0K71T03Q0=024S800?4@h02@/800/;2@0D51800000014A3`0?3`d05ADC00d=2`0?3`d200h>300B
00d=2`0<30X02`/;00X:2P0D51@08b<S018B4P0F5QH0410@00l?3`0G5aL06QXJ01<C4`0<30X04A4?
00P910061`804Q<>0P0H6A@05@0@4@`03a0;00l@2`0@4@`04A8=018B400J71X08B<R01<E500=3`h0
4A<@00`>2`0C5A805aTD00/=200<3PT04aH?00lB2`0@4`/04A@;018E300301<F3`03018D3`0@4Pl0
418?00<04aDB00H06Q`I01PJ5`0:30T02@/802/`;00@5Q8201<I5@0:00lF4P0=5Q404AXE018J500A
5Q004QLA01@I4`0F6aD061dG01HK5@804aPB00@05AXD01PM5`0G71H05QhH0P0;50l01`0I8Qd07RLR
02lh<`0/=C003QLB010I500E7QT00P0C71L0100F7QT061hJ01TO6`0H7QX201HL60805adI020061hJ
01LM6@0F71P05A/G01TR7`0G8Qh05R4M01DQ7@0F8Qh06BDS01PW900D8b004R0P01DU900G9bH05bHV
01hY:`0^>C/08Rd_01DS9P0U<cH08C0c02@f>P0V>3`0>4]?03U<DP0dBDh07S<h020c>@0L;cD07C0f
024d>0807S4e0P0S=cP0A00V>S/093Pg02@h=`0]@4@08C@k02Di@`0V>TD09CU402@h@`0U>D80:Ce6
02Hj@00T>C`09S`j02Y0?@0/@3h0:C/k02Li>`0]?d40<TA802m0AP0/?D@0<T=:0353A`0cADL0<D=5
02i0@@0bA4@0Jgn007fATP0]@D80C61Q02i1A00/?d<0<4=702m2A`0_@TP0;T5703M:D@1:GF@0E6E/
02Pi@00cA4/0?4iB0394B00T=SX0>4Y<03U;C@0jC4h0>4Y:03E7A`0cAdH0=DY7049FE00W>cT0>4a:
02m2@00bAD<0=TU704]KFP1>GUd0>d]:03M5A@0b@400>4Q503I6@`0gAd@0>TY70`0kBdP0=00fAT<0
=DE20351?P0]?CX0<3lj02Td:`0S;BD07RPP024[8`0X<B`0<S/f02/d;`0/=C809Rl/02Pa;P0h@Ch0
E5]L024X;P0O9R`0<Ca002Le>00^?D00<T=603E7B`1IJ6d0;3Y003=0AP0d?dD09S@h02hn?P0c@d<0
;Cdl02@d<`0H9RH0934`02@`;P0Q;B/072PT02lj=P0d?c/07bXZ02`g>`0b?Cl0>4=502Pc=@0[=cL0
8bl_02Te=@0P;2X0:SHd024]:`0K9b<202D_<00<02<];00L9B@06R<R02Xc<00U:bT07B<Q024V8P0P
9B4092TU01lT7P0I7QP0724K0P0Q9R80100P9B408RHU02X^;@0[;bh301/O800501lS9@0Q8b80828O
01dO700J71T00P0I6aP01P0J71T06adJ01dO700I6aP05QPE01`N6`8061XI00D06Q`K01`N7@0J71/0
5ALF01PJ6@0301TK6P0:01PJ6@0F61L04A4C02PX:P0P82801`L904M7B@0b<S@04a<E01HF608061PJ
01X05QHH01<C4`0D5Q<04QLB01<E500B4aD04A8E014@5@0F5AX061HK018@4`0B4A004a8@010?3@0B
4Q80410@014A4@0D51@04a<C018B4P0>3Ph02`/;00`<300F5QH071`L000000804Q0A00<040h?00h<
3@0A3a000P0D4Q<00`0C4A804Q0A010>3`0200h<3@0401@B5@0C4A@04Q0C014?4P803`d@00X040hA
00l=400?3A0040hA00h<3`0A3a804Q0C00X82`0=2`h04a4D0P0Q7b8200d;3P0400L5200=2`h03`d@
00`92`803`/<01<03PX;010<3@0@30d040`=00/7200:1PL040`=00/7200:1PL03PT:01<=3`0L5QP0
7ALI014;3@0@2P`0618D01XD5P0H4Q@04P`>00<03PP:00D03@L900h82P0?2@/04@/=01@>4002010:
300@00l92`0>20X03`T;010:300E2Ph03`@800X10`090080200101462P0V6al0?C8f01<8300@1@T0
3@8601<830H040D91P0?10P01P0<0@D02`0400d21P0@1@T03`@800`11@H03P<700<03@8600l4200?
10P00P0=0PH01`0?10P04PL;00l4200<0@D03@8600l4200@1@T05?ooool001_ooooo00L02P`701<E
400<3PT01`T4018D3`082PD03a4<00<03Q0;00l03a4<010B3@0E5Q404Q<>00l@2`0>3`X03a0;010A
300F5a802P/700l@2`0;30L02P/600d>2@0;30L00P0@4@`200h?2P0G010A300>3`X04A8=010A300?
40/03Pl:01@E400<30X0410>018B400=3@/0;Rh/00l?3@0@40h030`:00H6100C4a4030`:00d=2`09
2PD030d800l@2`0A4Pd00P0@4Pd02`0?4@`02Pl900/@2P0@5@l03QD>00P<1`030`406a/I01XJ6007
1`D04Q8@0080410>02P03Ph<010@3P0@40h03`l=00`<2P0410803`l=014A3`0=3@/08R8P05IFE00J
6QP03@d;00/;2@0=3@/03`l=018C4@0?4A0030h=00/=300=3`h03Q0?01@F5@082PT05aTH00X<2`0Q
8b801PP704Q:B00N81d010H300h@3@0A4a002P`9014C400<3P/03a4>01DG500A4a003Q0=0P0<30`0
1`0B4Q8030`<014A4@0@410030`<00d=3@0>3Ph00P0;2`/01`0>3Ph03`l=00h>300>3P`03@d;00h>
300?3`d0100=3@/05@0?3`d051@B00h>30061P@03Ph<018B400C4a4020P6010@3P0A4@l030`:00L7
1@0820L02@T700T:1@0O81/04Q<>00@5000<3@P04Q<>00l@2`0200d>2@0400h?2P0?40/030d800d>
2@804a@?00<03Pl:00`=200A4Pd00P0B4`h02P0>3`X02``700/<1`0>3`X03@d;01TI5`0C4a403@d;
00L71@0J6QP200/;2@8030`:01P02`/900/<1`0>3`T02``600X;1@0;30H03@h800h?2@092P@03Pl9
03`m=`0A4P`020T300X;1@062@802``601<D3P0B4`d020L200D4000?3PT040d800h;1P0?30L2014>
2@0604I6@@0_<2/0004000h?2P0D5A00414<0P0<3@P02P0=3PT03Pl:00h?2P0<3@P01PL200P9100@
4@`051D@0493?P0a<Rd500h?2P0801XK5P0C50l01`P3014B3@0B4`h03Pl:00l@2`0@4@`2018C3P05
014B3@0B4`h0410=00P81P092@L00P0C50h05P0@4@T03Pl700h?1`0A4P`04a@?018C3P0?3`d030h;
00d?2P0@4@/04Q<;01@F2`0F60`0418501HH2`0I6a004a@<00l@2P0A4Pd05aHB00l>2P0B4@d200P7
0`804Q4=01d04A0<00l>2P0>3@T03`h:018A3P0I5AH05A4@018A2`0@4PL030l400dA2P0B51<04Q<G
00/;4`0>2a805Q@G01LC4@0C3`h02`T701TH5P0M71X03`h<00h>30061P@00`@200X<2@0?4@h02`h;
00D:1P0200X:200L00h>300M7A/02@T7010@3P0:2PP030`:00h>300;2`T03`l=00T91`0G5aL030`<
00d=3@0A4A403@d=00T92@0C4a<03@d=00@410071`L04Q8B01@D4P0:2PP04A8=01<D3`0@4@`04a@?
01PI50803Pl:00h03a0;014B3@0B4`h04a<A014C4P0M7ah05ALF00d?3P0>40d03@l<01/M6P0B50l0
3a4<018D3`803a8;0P0B5@`05`0C5Pd051L@01@G400D5a005ALB014C400C5A8061XG01LI5P0D5Q<0
4A<@01HH5@0@4Pl0;Bl/08F:QP0l@Cd04QPD01<I5@0A6A@04AXE01@M600F7AL05AXD00805Q/E0180
5AXD01@I4`0E6Q@04aPB014F400E6Q@06AhH01LL5P0G7aT04AXE00lH4`0D7AP04AXE01XS7P0M9R40
3QLB010I500D7AP2014J5@0401HM6@0H7QX06AlK01LM6@<05A/G02<051XF01HL600G7AT061hJ01PP
6`0L9B806B@P01HQ7@0C7a/0520L01LS8@0L:bP05RDR018P800F9RD06RXY01PW:00J9BL08Rd_01HQ
8`0K:B`0:CLj01LV:@0S=CT08cHj02a0@`0X?D80;DE902Q0A00N<cP06bhd01lb>00S=SX083<g01ha
=@0202Di>P0802@h>@0R=SD093Pg02/o@00O=3T093Po02LkA00V>T<202DiA00;02TmAP0U>D409S]0
02]0@@0^A480:d4n02i0@00Y>c/0<D=503M9C@0dAD/00P0_@4L03P0`@DP0<TA80394AP0cADH0=4I6
049FE@0fBT/0;41102Xn?`0[?d40<4=702Xm@@0dAd`0<dI<0`0_@TP01P0eATd0@E9I04mPI`15Ee/0
>deA03i@E0<0>Ta>01@0>4Y:03E7A`0cAdH0=DY7041DDP0Z?S`0=4Q604MJF00eB4H0<4=103Y:B@0l
C4/0<T9103U7A`0fA4@0>4Q503I6@`0gAd@0>d]803a<B@80>d]800T0=TI303E5@P0a@Ch0:c/h02Xi
=00U;bL082XR01hX800S;BD00P0Y<Rd0>P0J8ah0:34^03@m>P0c?3T0:C8_03U0@@0V;C<0;3<i02dh
?00a?d80>dY=03=4A`0cADT0<T5602hl@P0L:Bl092le02<a<`0Z>SX0;Cdm02Lg=`0V=SD0C5YJ02dj
>@0P;2X08RhZ02<_:`0/=c<0<C`h02D_<00R;C405b8T01`W:@0_>S`0;c/k01`X:019EED0=40n028^
;00S;bd082`Y01dW:00Q:b`092h]01hW9P0I8R406R<P020V900V;2X0;c@`01/P700I7QX08RLQ01/P
6P0N8ad082DQ01lT800L8Ad201`P7`0C01hR8@0L8240720Q01`P8@0N8R@0828Q01lQ7P0M7a`06adJ
01XL6@0I6aP05ALD01TK600K7AX06A/H01PJ5`0J71T06Q`K01/M700201`N7@0401XL6`0H6QT061XI
01PJ6@805aTH0P0F61L0200;2`d0410B018B500E5AL09BDW00h>400C4aD05ADG0P0F5QP03`0E5AL0
4Q@C01DJ5P0D6A@04QLC014E5P0D5AP05AHJ01HG6`0H61/04a<C01@C4P0E51004Q4=018B4P02014A
4@<04Q8B00T071`L01DE5@0820P05ADE03Hf=P0F5QH06ALH01hL7@0F51D00P0A3a000`0=2``04a4B
018@4@02014?40803`d>00@0518E018@4`0A3a8040hA0P0>30l02@0A3a803P`?00l=400A3a803P`?
00/9300>30l03`d@01@B5@0200H41`0701@B5@091`X02PP;01@B5@0@3Q402PP;00/82P0200l;300=
00`82@0=2@X03`/<00l;30091@H04@d>01dI6P0<20T01`<400d82P0@2P`05@lA01LA4`0200h82P80
4P`>00<04@/=00l92`0>20X00P0?2@/01`0>20X040X<014;3@0C3@l05Q0B010:300?2@/00`0>20X0
3@0@2P`040D900l4200A1PX0714E00l4200=0PH02@0201lD600<0`D040D901<8300A1PX0300@1@T2
00d21P0401052@0C20`04PL;00d21PH03`@800<03@8601052@0?10P00P0>0`L01`0?10P08aPL0105
2@0>0`L04PL;00h31`0?10P05?ooool001_ooooo00P02P`700X<200>40/03Q0;01XL5`0F61<03Q0;
00lA308030h900@03a4<00h@2`0B4`h04A8=0P0>3`X200l@2`0P00X;1P0=3PT0414<00l@2`0>3`X0
414<00h?2P0C50l04Q<>00d>2@0<3@P03Pl:01HG4P0C50l03@h9010A300;30L04a@?010@3P0B4Q00
8R8P018B400O7ad030`:00h>300<30X02`/9014A3`0@40h03@d;00d>2@0?40/2010A300900`>2@0;
3@P03a4<00X?2@0>4`d041D?00`C300B5A404A4?00802`/900D03@d;00h>300@40h0410>00h>3002
00l?3@0:00h>300?3`d04A4?01HF500@40h020P600`<2`0c<c4051@B00`<2P<03Ph<00@04a@B014C
4P0<3Pd03@l>0P0@4Q403`092`X04aDD00P:2@0=3`h051HE00H81`0B518020X701@F4`0:30T0418?
018D4@0C5A803Q0=00/=2P0200h@3@0800`>2`0?3`l05aLG00X:2P0@41003`l?00h>3P0=3@d200h>
3P802`/;00L03Ph>00l?3@0>3P`03Ph<00d=2`0>3P`03`l=008030`:00T03@d;00l?3@0?3`d03@d;
00h>30071`D03Ph<00d=2`0?3`d00P0;2`T0400@40h00P8101HF500=3@/05ADC01<D3`092PD03Pl:
018C3P0=3PT0414<00`=200;30L02P/600`=200=3PT200/<1`804A8=010030d800/<1`0?40/03Pl:
00l@2`0>3`X03@h900h?2P0A4Pd051@B00X:200@40h010@201@D4P092@L03@d;0`0>3P`01@0=3@/0
30d8010A300>3`T03@h800803Pl900T03a0:00`=1`0@4@/0=cPb01@E3`0;30H03@h8018C3@0<3@L0
0P0=3PP02`0?3PT051<>014>2@0?30L04@h901<>2P0A30P04@h903@d;`0W:2<01PL200803a0;0P0<
3@P200d>2@803Pl:00L04Q<>00D60`0?40/0;2dX00/<1`0E5Q40414<00D03a0;00D04A8=00`=200:
2`H04Q<>014B3@03010A300?018C3P0C50l04A8=014B3@0[;2T0;Bd/01HF500?40X03a0900`=1@0>
40D04Q<:014B300?40/03`l=0080410@01404A4@01<C400D5@l051D>01@E300>40D04aD:01TI3`0D
50`04A0:01<A300?3PX030/701LF4P0C4Ph040l;018A3@02014@300R010?2`0?3PX040l;010?300A
31003`X=014A3@0B50X0314500XA200A5QD041DG014B5P0A41404A0;014>1@0F4Ph05Q8A00l;2P0?
3P`051<A00X:200=3@/04a@A01@F4`0730P0@4E103Pm>@0B4a4030`:01TI5`092@L04Q8@00l?3@80
4Q8@014051@B00T91`0C4a401PH4018B4P0=3@d05ADE014A4@0b<S804a<C00`<300@41003Ph>00l?
3`0B4Q803@d;00h>2`02010A30803Pl:01D03a0;00h?2P0>3`X03a0;014B3@0C50l051@B00h@4009
2P`03a0B010B4@0G6AH08bDR03<e<00>40/04A<>010C300:3@H05QTA01HI3P0D5`h00P0C5Pd2018E
3P0301<E400A4a004aDB00805aTH01805QPG01LI5P0M7a`04A<@010B3`0g?3P04AHB010F4P0A5a<0
4a/F01<L5`0@6A@041LA01@I4`0F6aD061dG01HK5@0E6Q@201HK5@0501<H4P0D6A<05Q/E01HK5@0C
6aD00P0?6Q@0100B7AL041/E014L5P0F8A/201DP6P0401PS7@0C7QP04A`F01DM6@805adI00<05A/G
01<I5@0D6QH00P0F71P0D`0I7a/06R0L01XP700H7a/05R0L01@O6`0C7a/05B4M01PT800J:BH07bh[
01/Z9`0H:2L07Bd/020`;`0P;bl072LY01XT9P0K9RP06BLZ01l]<00Q<C<07C0d01P[;`0P=SP08SPm
02@l@00T?D4083@k01ha>00S=S`0:3]102@g?@0R=CT08SHg02<g>00Q=C@083@c02Hj>00V>cT08SLi
02Dj?P0W?4809SY202PlAP0Y?DP09c]602PlAP0/@4P0<4A:0315B00/@D40;d=102/m>`0`@T<0=DM:
0394BP0`@DT0:S]302/l@`0Y>cl0:C/n02/m?P0W>CT0:3`j02e1@00fBTT08cLf03E9B@0aADH0:Sho
03E8B`0gBTh0=TU=03Q;C`0dAd`0>4UA0393BP0cA4/0>T]B03Q:CP0oDED0>Ta>0080>D];05/0>4Y:
03I9A`0eBDL0=DY803M;B@0oDe40>Ti<07f@SP1;GU`0=DQ603E5A00hB4L0=dM603e;B`0fA4@0=dM4
03A4@@0eAD80>4Q503U9AP0hB4D0>DU603Q8A@0fAT<0<T8o02Lg=00O;RT082/R020Z8P0T;RH0:38Z
02Tb;@0[=2l08R/V02hg=00/=C80<CXg02Pa;P0Y<38082L_02Xa>@0_>T00;ca20391AP0`@4@0;T12
03Y9C00[>Sd0JgUl02hi?@0/>S/0:SXi02hn?@0`@3l0A5AC0:Vh]@16E5407b/Y02di=@0jAD409c8^
02Td;P0]>CP082ha02<a=00/>S`0;S`m028`<@0X=SH0?de=02`j>P0T<c0082l/01/Y9P0N:2T08B//
028/:`0Q:RT08R/Z028[:00Q9bD092XX02L/:00H7AT0724M028W8@0M8Q`07b@N024V800P9B407b@P
00808BDT00H0720O024U9P0O8bH082@W01dQ8`0N81l201hP7@0501`N6`0K7AX06Q`I01HH5@0I6aP0
0P0G6AH0200H6QL05aTF01lQ800O8B006adL01XL6`0K7A`07R0O0P0F61L401@F5@0801TI6`0F5QP0
51@F01HF600K6ad05aLI01HF600D51H2018B500A01@D5P0E5aH051XF018I4`0@5Q8041HE018G6@0D
61/041@G01<E600@4Q404Q<A01<E400A4Pd04a<C01@D500C4a<00P0B4Q802P0C4a<0:2PX020P800?
3`l0410@00d=3@0>3Ph04Q0A01DC500@3Pl201@B4`0400/92P0A3a004@l@014?40<04Q0A00@04@lB
010>4@0@3Q403`d@0P0>30l0100@3Q403`d@00l=400A3a8300h<3`0;00T72P0=2`h04@lB01hL7`0l
>Sd071XM00D31P0?3A002@L:00`:3@0E4Q@00P0?2``0300=2@X02PH700h:2`0A3@h040`=01LC500K
5aP02PH700`82@0E41403@L900/51`<03PP:00L040X<00h82P0=1`T03`T;010:300?2@/03PP:00<0
3@L901@03PP:00l92`0>20X03PP:00d72@0<1PP03@L900h82P0I3Q8040D900/2100P5AT03@8601@9
3@0<0`D05P/?00l5200=0`H05``@00h31``040D90P0>0`L0100@1@T04`P<01872`0>0`L700l42080
4@H:00T03`@801052@0A1PX08aPL01052@0>0`L04PL;00h31`0@1@T05?ooool001_ooooo00d02P`7
00lA300@4Pd03@l:014C3P0:30L03Q0;014C3P0;3@P02P`700h@2`0:30L03@h900803Pl:0P0=3PT0
2`0;30L02@X501hO6`092PD030d800h?2P0;30L03Pl:010A300?40/03Pl:00803@h900@04A8=00X;
1P082@@02``70P0=3PT0300B4Q0030`:01PH5P0?3`d03@d;00P81P0?3`d0410>018B400<30X0410>
00h>30<03a0;00D03Pl:00`>2@0;3@P03@l:00P=1`0200/@2P0900lF3`0A510020P601XJ600<30X0
0P8001HF500D5180410>00<03Ph<01X030`:00H61@0:2PP01PH400d=2`0D51805QHD00T91`0:2PP0
2`/9014A3`0=3@/030`:014B400?4A002`d<00d?3P0@4Q403a4@01/M70031@@02@/:01XL6`1lOWd0
6A/J01<E4`801@L400<00P@1018D4@0:30T00P0@4Pl200h@3@0;00lA3P0>40d07alO02TY:@0@4100
61PH00P8200:2PX03Ph>00l?3`0>3Ph00P0;2`/0200=3@d03`l=00h>300>3P`03@d;00h>300?3`d0
3@d;0P0;2`T05P0>3P`0410>00h>300=3@/02PX801HF500;2`T02PX8010@3P0C4a4030`;02PX9P08
20H0410>00H6100?40/02P/600l@2`0C50l03@h900H70P0<3@P200/<1`0500d>2@0>3`X030d800l@
2`0A4Pd00P0B4`h2014B3@0=00l@2`0@4@`03Pl:00/<1`0<3@P03Pl:00D50`0@40h08B4O04a<BP0;
2`T04a<A00h>300200l?3@0400h>300<30X030d800l@2`<03a0:00D03@h800`=1`0;30H01@H000d>
200200P90`0A00d>200?40X0414;018C3@0>3@P01`H100P70P0@3@P03P/601@A300F4@d03`X600h;
1P0=3@/03@h9018C3P0?40/00P0:2`H0300>3`X03@h900d>2@0=3PT030d800L8100E5Q405QLB00/<
1`092PD061TD00X;1PD03a0;00P030d8014B3@0G61<051D@018C3P0E5Q404Q<>00l@2`804Q<>00h0
3a0;00h?2P0G5aH04Q8B00H610092PD04Q<;01PI4@0G6@h0418700l@2P0?40`0410>018B4`80518C
02D05A@B01<D3`0A4P`03a0800lA1P0@4PL051@:01HC2P0E4PT0510;01@C3`0=30P06QTE01TH500E
51004A0<010?2`0A40`04a8>018A3@0A40`03Pd:014=3P0?2``03`l9010C200;4@D031@8038h=00J
81h02`h<00l@200<300061H7010;1`0?2PX03@T800803Pd;02D010@201<C4@092`P05QPE01XO6`08
3@T02@h:00T;20092@L00P8001PH5P0?3`d02PX8014A3`0?3`d04a<A00@40P0H61H02@T700D51@0E
5AD06a/K0000000F5QH04A4A01@D500>3Ph02@T900L71`092@T04A4?01LH4`0>3`T030d701<D3P0D
5@l04Q<=00<03a0:01<04A8<018C3@0B4`h05aXL00lC500<41402Ph=010E4@0G71P06QlI00hC300;
40T03Q<<01@J400M8aT051L<018E300A50/04QD<00804aH?01@04A<>014C400@4Pl04A<B01HH5`0I
6aX04Q@A014C400;3@X051HC01lT800D6QH04ALC01<I5@0C6QH04Q/F01<L5`0D6aD051TB01DJ4`<0
5a`E00d05Q/D01DJ4`0D6A804aPA01@I4P0G71D0620J01PS7@0I91h05R4K018M5`0<5a403APB0080
4A`F00@051lI00lJ500>6A<04a/F0P0F71P0FP0E6aL051XF01LM6@0G7AT061hJ01hT800O9B40728N
01LN6P0C7QX04alK01DQ7@0I9B406bLS01/Z9`0G9R<05RDR01DU900C9R@052LU01@U9@0G8R@051hP
02@_<@0C8B@0938e01d^<01fRHd0AEQL01/b=00F;S806c@h02Q1A@0N<ST06blf01hb>@0S>3d08CHk
020e>00O=3D08cPi028h=P0S>CH0:T0m02Hl>@0V?3X09Cdn02@l@00T>d40:3m802e3D00Y?d`0:d5<
02]2BP0Z@DL0;DE90397B00]@Cl0:Sdj02/m?@0/?T00:Sa202hoA`0_@4X0;d1702Tk?`0Z?400;Cm0
02Dg=`0M<Bl0=4]602Y0?@0^A440=de;03Q>C00gCD/0=4Y903=8B@0aATL0<4E703A7B`0iBU80>daD
0352BP0b@dX0;T1403a>DP0gBD/0=dU903I8B080=TU700H0=TY803I;B@0eBDL0;D4o0355@`1:GE/2
03E8AP0603Q8A`0kBdX0=DE403E3@`0]>c/0=4A10P0a@Ch0;P0c@d00<T8o0351?P0eAD80=4A10351
?P0b@Sl0:CTf01l^:@0S;RD092hV02Tc:`0[=Bd0:S<^02Tb;@0D7AP0:c@a03a5@P0i@Sl09c0]02<Z
;@0a>480<SU1030k@@0^>d409cHk02Lh>`0oDE<0EfIY03E3AP0oCE0082/]030n?P0/?3/0=dM603A4
@`0fATD0@E1=02@b;P0L:2@09c<_034m>00S;RP09S4[02Lb<@0M:bh202hl?`0302Hd=`0Y=cP08c4a
00805R@T00<08c8_01h]:P0K:RL00P0W<C804@0O:BP06b@S01hW9P0L9B808RPV020V900P9B406AhJ
02@Y9@0P9Al06QlH01/P6@0K81X06QlK01/P700Q9B<0<cLf00808RHW01T0720S01lS9P0G6al07AlN
01dO700N81d07AlL01/M6P0J71T05QPE01TK600D5Q<05ALD01/M6P0H6QL071hM01hP7`0L7Qd06A/J
01PJ6@0K7A`05aTH01HH5`0D5QD04aDD00805ALF00H0410B01XJ700K6ad0LW9d04Q8BP0<30h201@D
5P804a<E014051@F01<E500@5Q803AL@00dF4@0=5Q<03aHG010E600B5aX051TK00lC4P0@5A4041D?
00lA300E5AD05aLG01HF5P0201<C4`0>01DE5@0=3@d02`/;00X:2P0B4Q8051@D01`L700H5QL05A<D
018@4@0A3a003`d>00`:2`0B4143014?408040h?0P0?3A03010>4@04014?4P0>30l040hA010>4@80
3`d@02403@/>014?4P0?3A003`d@00h<3`0;2@`06ALJ018@4`0:20/03P`?00X82`071@P02`P:00l;
300E4A805a<D00d92P0<20T03`/<00d92P0;1`P02@D600P41@0;1`P03`X<00d72@0<1PP03PP:00`6
200>20X04`d?010:300?2@/00P0@2P`00`0=1`T03PP:00l92`0300h82P803`T;01403PP:00d72@0=
1`T03@L900l92`0700003P<702<H701CB4`09a`P00h41`0B1`/03`@800h41`0900807A8F01@93@06
01052@H03`@800H03@8600`11@0<0@D03P<700l4200=0PH700h31`0701462P0@1@T03P<700l4200@
1@T03`@800h31`0300d21P0301052Ooooooooooo01;ooooo000Kooooo`0K0001000?4@`04A<>00/=
200?4@`02`d800h@2`0A4`h02P`700T;1P0=3`X02@/600/<1`0=3PT03Pl:00d>2@0<3@P02@X501`M
600e=S403Pl:010A300B4`h030d800d>2@0<3@P03@h900<03Pl:01402P/601LH4`0I6QD03@h901@E
400E5Q40410>00T91`0;2`T03Ph<010@3P0>3P`0410>01<C4@0E5A<02`/900l?3@0300h?2P0A00h?
2@0>3`X03@l:00d@2@0?4@/020d700X?200;40X05QdF04U=B0061P@02PX800/;2@0c<c40JFUW01TI
5`0@40h00`0>3P`02@0<30X03`l=01DE4`071`D0410>00H6100M7A/04Q8@00h>300200d=2`0W00X:
200<30X04Q<B00d?3P092`X030h=010B4@0=3`h01@L601XL6`0<3Pd02`d<03Hh=`0F61L0418@00D7
100F61D030h;00h@3@072@H020X700X<2@0;3@X02P`900/=2P092`P03@d=01/K6`092@T06QXJ00P8
200B4Q803Ph>00l?3`0>3Ph02`/;00X:2P0=3@d03`l=00803Ph<00L03@d;00h>300?3`d051@B010@
3P0;2`T030`:00803`l=01<02`/900h>300U9B<061PF00d=2`0A4@l02PX800D50`0=3@/051@B00P8
1P0>3P`030`:01<D400;30L02@T7010A300<3@P0414<00803a0;00H04A8=01<D3`0A4Pd03@h900`=
200>3`X2010A300=00h?2P0A4Pd03Pl:00`=200@4@`07b0K02h_:P0I6AL061PF069RH03Rh^009bLU
00P81P0400h>300300`<2P0;30L03Pl900803a0:01403Pl900/<1P0:2`D03a0:00/<1P0720804A8<
00h?2@0A4P`03@h800`=1`0>3`T03Pd8010?2P0E50l03@`700h;1P0201HC3P0D00h;1P0=2PD04A4=
00P70`0;30L020P500d<200@4@`03`l;00l>2P0>3PT030d800d<200A4Pd030d80042000E5Q4020T4
014B3@0B4`h500l@2`0I010A300B4`h03a0;00l@2`0J6aH05AHA00/<1`0?40/04Q<>014B3@0>3`X0
30d800X:2@0820P030`:018C3`0=3PP02``400`=1@0=3PH03Pl9014A3P0B4Q004a<C01@B4`0201DD
4P0A018C3P0@4@`03@h7014B2P0@4@T04A4901@D300F4``0514;01lN6P0A40`04Q4=010?2`0A40`0
4Q4=00l>2P0A40`00P0D4`l0=@0B4@d03Pd:01HB4`0B3Pd03`l:00d@1`0:40@03A<902H[9@0<4@d0
2Pd901`M5@0C4`L04@l201HC3P0;1`H03`h<018A3`0=30X03`l=00h>300K7AX0004002@V8`0F6aL0
3a@@00h@3@0=3@/05ADC05QHEP0A4Pd05QLB010A300?3``05aLE00T91`0T92@05aLG01<C4`0<30`0
3`l?00H61P0C4a<05QHF01DE5@0B4Q005ADC018B400;2`T03Ph<00d>2@0B4Ph04a@?00803a0;01@0
4A8=010A300?40/03a0;010A300A4Pd04A<@00L:2P0D61T03Q8A00lC4P0D6AD03a@@00T>200K81X0
4QL@00lD3@0@5@h02a47018E308041<:00T04QD>01@G400E61404aD@01<E4P0B51404A<@01PJ6@0M
7a`00P0F6aD03`0D6A<07b@N018I4P0C6AD03aPC01HL600C71L05AhI01hW8P0O9b4061dF01LL5P0F
6a@05AXC01@I4`0201<H4@0>01@I4`0C614051TB01TN600E7AL03aXD018K5P0B7AL05b8L01HQ6`0B
7AL04A`F018M5`0F8A/2018M5`0301@N6@0E7QT05AhI008051dH00T05b0K01@M600C71L072DP020Y
9P0N9b@06R<P01PT800I9B400P0J9R804@0I9B405bHS01HU8P0H9b@062PW01@T8`0@8b404R8R028]
;`10BT`0HVe_01d[;00R<3<08S8e07^=T@0oDUH06Bha00807cLk00`06C8f02Di@00Q=C`093Po02Tm
A00W?4409ca0020e>00U>S/09C/j02Lm>`0]@d4202Pn?00]02Ln?P0T?4009SY102XoB@0_AE80;d9@
02i3CP0Y@4P0:3a302e4B00gC4d0;T<n02Xn>@0Z?S`0:C/k02Lj?@0^@DL0:ca302`nA@0W>Sh0:cdo
0313@`0W>cT0<DM402Dl=`0bB4D0:Cll02a2?`0bB4D0=D]90398AP0iCdd0>4i<0397A`0fBdh0>DaB
03M:D00`@dT0>deB0353A`0iBdd0=TQ903E7A`0eB4H0=TU70080=dY804P0>De:03iBD00R=c80?4m<
02Tl>00hBdL0=TU503U9AP0hB4D0;cll03M6@`0d@d00=DA00310?@0_@3X0<D4m0310?@0^?cT0=4A0
0351?P0]?SP0<d8n02hm>P0V<Rh09S8Y02@`9P0Y<bX0;3H]02Xd:`1BG5@0=Clg020Y900/=c<0=d50
038l>`0b>d80EEeZ04eGH@0`?TH0@e9I03U8C`0_@DD0Sj6S06YiO00gATT07B/^04IDE`0Q<340<d=2
03A4A00/?3/0>d]:00`J6P0/>cT07RdZ02Da;`0X=340:CDa02hj=P0V<c80:CPk03M6B@0R<C@0<T54
02Dc=@0]>c`0;3Xj02Xg=`0M:BT082`Z01dY9`0K9B@2020Z:@0902</:`0W<2l082TV020V900X;R`0
;34]01PM6@0M8Qh08BHQ00808RLQ00H07b@O01/P700L8Ad08BHS02da<00I7Ah201`P8@0?02DY;00P
92H071hK01dO6P0N81d07AlL01`N6`0J71T04Q@A01DG500A4a005ALD020R7`0O8Ah05aTH00807AlN
01406A/J01HH5`0F61L06A/J01LI600E5a@05ADE01LG5@0H61P05aLG01<C5@0N7R006QXL01HF600H
61X04Q8D01@D5P0201HF600K01@D5P0A4a8041HB00lG4@0@5Q8041HD014F5@0A5AH06QhQ01/O800D
61L051LE01DG500A4a005QHF01PH600G5aL04a<C01@D500F5QH04a<C01hN7P0L71`02`/;00l?3`08
20P04Q4?008040h?00d03@/<00l=400C4A@0518E01<A4P0B414040h?00l>300>30d03`d@010>4@0A
3a804Q0C00804a4D00<030X>014?500A3a@00P0?3A801@0@3Q405Q@G010>4@0;2@`03@/>008020H9
00/030X=00h<3`0:20/04Q0C01@B5@0=2P`03`/<01XF5`0O6a`040`=00/7200200l;300600d92P0>
2P/0510A00l;30080`@030H80P0@2P`020090`D030H8018<3P0=1`T030H800l92`0@2P`03@L9100:
10H00`0;1@L03@L9010:300200l92`0?00h82P0?2@/040X<01072P0900<0200202lT:00>1@P04PP<
01D:3P0?1PT05@/?00h31`0P5aX040H900803`H901003`H:00l62`0@1@T040D:00h32@0>0`L03P<8
00h32@0>0`L03P<800l4200=0PH0304500h31`0@1@T03`@81`0=0PH200l4200900d21P0>0`L03`@8
00X00`0A1PX03`@800/0100=0PH03`@801Cooooo000Kooooo`803a4<0P0M7aX200lA300500X<1`0>
40/02`d800`>2@0@4Pd00P0=3`X0100@4Pd03a4<00d?2P0>40/2010B3@803@l:00@0418=00d?2P0:
30L03Pl:0P0;30L0100A4Pd03@h901HG4P0>3`X200l@2`0300d>2@0>3`X03a0;008030d800X03@h9
00h?2P0>3`X03Pl:010A300B4`h03a0;018C3P0P8A`0:R/U0P0=3PL05`0>3`L03a0800hA2@0>4@P0
4A@;00dB2P0<4PP0318900dD2`0@50d051HC00/=2P0<3P/0<S@a07]mNP0D5Q<03@l<00X<2@0=3``0
418?00d?300?4@h01PP500803@l<00D07b4N01XL6@0D5Q<0418?00h@3@0200lA3P0500h@3@0=3``0
3Q0=00h@3@0?4@h00P0>40d200lA3P<03@l<01003a4>010B3`0?4@h03a4>00H81@0E5a@02`d:018D
4@0f>3D0418?01`N6`0;3@X0418?00T;2P0=3`h0418A0P0?4A00>`0>40l01PP701@F5@0;30/03Q0?
00lA400=3`h04Q8@00h>300C4a401`L501DE4`0I6AL03@d;010@3P0?3`d03@d;010@3P0?3`d030`:
018B400H61H04A4?00`<2P0?3`d03@d;00`<2P0>3P`03`l=00h>300;2`T03@d<010@3`0<30/02`/;
00h>3@0;2`T0410>00h?2`0@4@`04Q<>00l@2`0:2`D03Pl;00d=2`0>3P`0410>00h>30092@L03`l=
00`<2P0:2PP03Ph<01/K6@0U9B<03a0;010A300=3PX0<c@_00<03@h900<0414<01DF4@0C50l00P0=
3PT01P0>3`X02@X501DF4@0<3@T02P/600h?2P803a0;00/02``700d>2@0>3`X030d800h?2@0?40X0
414;00d>200C50h030d900d>2002018B300B00h>2@0=3@P03`l9010>2P0?2`P03``9014>2`0B3P/0
4@l;010=2P0E4@h03``8010>2P0D40d03`l;00`>2@0;3@P030h90P0?4@`07`0@4Pd04A<>00lA300>
40/051HA01<E400C50l04Q<>014B3@0?40/0:2TT02`]:00A4Pd0414<00l@2`0<3@P03a0;00h?2P0=
3@X01PH501<C4@0>3P`03Pl;00/<200A4@h04Q<?00l@300>3P`04A4?00l?3@0A4Ph00`0@4@`02P0A
4Pd04a@?01HG4@0=3PT04A8=014B300C4`h03`l;01DF4@0@4@`200h?2P1300l@2`0E5Q403a0;024R
7@0D5A003a0;01<D3`0@4@`0410=010@2`0?40/03Pl:00h@2P0?4@/03a4<018D3`0A4Pd03a0:014B
3@0A4@/07QhK01<C4@0=3@/03`l=010@3P0<30X04A4?010@3P0>3P`04A4?00l@3P0@4@l04A4A010@
3`0A4Ph03a0;014B300P8AX05QL@010A300J6QP0;bl`03`l@00@3a@0510F018?4`0?3A003P`=00l>
3P0?3`d04A8>00d>2@0;3PP03Q4;010C300>4@/03@`:01<?3`0B3`l03`h=018@400E4a<04A4@010@
3`0=3@`04Q@B00`>300200lA3`0900h@3P0C5A803Q0=018D4@0?4@h051HC00d?300C5A404aDB0080
4A<?00L04QL@00/@2@0D6A8041D?01XO6@0_=2h051TC00<04aPB02004aPC018H4@0@6Pl041/?00hI
300D7a@05R4G00lJ4@0>6A4031H@014L5`0E81`0DUeI0458A00?5A005A/G01@J5P0N9Al03A<?01@K
5P0C6A@04QPD01HL5`0J81/06AlK01XP700D71L05adI01<L5`0D7AP06B8M01@N608062<M00H04AdF
01/X8@085@h06BHN01HR6@0E8A/201@P6@805b<O00H05B4M01PS800I92<06RDS01TT8`0F924201HU
8P03010O700?7Q/04b8O00@062LT04P05bLT01PW9@0G8b<072PX01l[:`0J:2P06RPY01TX:@0N;C00
830c01//;P0J;3008S@h02@f>`0Z?D@062`e02a0B@1?Hf`0;d=;02TnA00Q=S/08CHj028g>`0T>C`0
9S/m02Pm?P0W?3/0:3`n02Xn@`0Y?4<0:ci803U<E`0iBeL0:ci802`oAP0aA4X0;45202Tn?00X?SP0
9chf02Hm=P0W?CT0:3hk02To?@0W?3X0:Sln02a1@@0]@T00:T0n02Lm>`0Z@3d0;D@o0358@P0cBTD0
<TU402m6@00eBdP0@5IB03mFD@0gCDX0=Ta803Q>B`0cBTX0>4e?03]@D@0hCD`0=d];03=7AP0eBDP0
>Te:03Y=B@0fBDD203=6@P0703U;AP12E4l0<dDo03U:A@0`@CX0>T]403E6?`0203=4>`120393>P0b
@cP0<d<j03E2>`0[>S@0:c`d03M:@P0eBD40:She02m2>P0]?CH0<3hg02Xe;`0Y<2d082PS02Hd;00T
<BP0?4Tm02Xf:00^>B/0930R01l[7`0Z=Rl0:cXg03M7B015EeX0>TaI05IVO00kC5l0>4YI0354D00]
?dX0>4UA0393B@0]?d<0<45502ln@`0_?T@0;ci205ATI@0b@D@0;Sdo01h^;`0]?Ch0:cXl02Ti>P0/
>S`0:cXl02Pg>@0W=SP09cTk02Hj?@0X?3l0:Se102@f>@0W=ST0:3Dh02Td=`0X<cD09Bh`02@];P0T
;2`08R/Z020[9`0Q;2P0;CHc0P0N9b@02`0N92808bTW02<W9P0M8B007R8Q01lS8@0L8Ah07B4O01dR
800M8B007b<R008092PW0P0S9bH0100R9RD082@T01dQ800N7aX201lP6P0f01dN6@0L7AP06a`G02@T
8P0R8R005aLE01DE5@0I6AT061XI01dO7P0F6AP06adL01`N7@0H6AL06QXH01/K6@0J6QL05aLC01LF
4`0F5A405A@@01DE500G5aL05QHF00`<300H61P04Q8B01PH600B4Q805ADE01PH600E5AD04a<B01HG
500E5Q8051DC01DF4`0E5QD04a@C01HF5`0B4aD04A4C01@D5P0C4aH04Q8D01HF5`0>3Ph07alO010@
400j>SX07QhN014A4@0C4a<04Q8B0P0?3`l05@0A4@l0414<014A3`0A4A003`lA00X93P0@3aD040lD
00l?4@0?3`l03Ph=00h?2P0>3P/03@/=01HD5`091`X04a4F00L52P0B41D030X@01@A6@02010=5@03
018@5`0@3Q803`d>00@03`d>01004@l@00D4100=2``030X;00D3100B4140514C00T4200o>Sh0If9V
01D@500;1PX06QDI014<400@2`l03`X>0P0>2@d03@0?2Ph03PT=00l;3P0<20/03`X>01D@501JEET0
5a<F00H21@0B3A4030P;01<>4P0=20`00`0;1@T0700<1PX03@L;00d72`0E3a<030L:014;3`0F41@0
3@P;00`62P0@2Ph030H:00P21@0@2Ph03@L;00`42@0;1@T03@H;00h72`0=1`/03PL;00X52@0?2Pl0
71HL00/42`0=1@/05P`C00h4300>1@/200l4300300l42`0?10`03`@:00D03`@:00D02`460146300?
10X03P<901052`0700h32@030146300@1@/03P<900803P<900<03`@:ooooooooool04_ooool001_o
oooo00@03@l:00h@2`0J71L06adH0P0@4Pd0400=3`X0418=00`>2@0<3PT03Q0;00/=200<3PT03a4<
010B3@0>40/03@l:00h@2`0620<03Q0;018D3`0?4@`200h@2`0301DF4@0B4`h020T40080414<00@0
4A8=00l@2`0?40/03Pl:0P0;30L00`0<3@P03a0;00l@2`03010A300;014B3@0@4@`03a0;00h?2P0<
3@P02``700/<1P0=3PL03@h600h?1`0?40P00P0>4@P0600@4`X03Q@:00hD2P0=4`T02Q8700dB2`0E
5a@03Q0=01<E4P000@003a4>018D4@0<3P/02@/800h@3@0A4a003Q0=00T;200?4@h05QPE01PJ5`2D
UY<0Ce5>00T;20803Q0=00<04A<@010B3`0>40d00P0<3P/300d?300500`>2`0=3``03@l<00d?300<
3P/00P0=3``04@0<3P/02`d:00T;200>40d020X7014C400@4Pl0:bdZ00d?300D5Q<01PP500P:1`0<
3Pd020X900h@3`0@4Q402`d<0080418A018071hM018D4`0;3@`01`T800/=300B4Q001@D301LG5@08
20H05ADC00`<2P0:2PP03`l=010@3P0=3@/03`l=00d=2`0<30X200T91`803`l=00T02PX800h>300=
3@/03Ph<00l?3@0>3P`02`/900d=3@0@41000P0<30`02`0>3Pd02`/900h>300=3PX03a0;014B3@0C
50h04A8<00h>300=3@/03Ph<0080410>01@03@d;00T91`0=3@/0410>00l?3@0:2PP01@D300/<1`0<
3@T03a0;00d>2@0A4Pd04a@?00d>2@0>3`X04a@?014B3@0<3@P03Pl:01@E40802``700<03Pl:0001
000C50l00P0>3`X0100;30L03@h9010A300=3PT200`=1`04014B300?40X03Pl900@500803a0:00D0
3@h800`=1`0?40X04A8<00l>2P0200h=2@0B00l>2P0@3`/04A0<00X91@0<2`L03@`8018A3@0A40`0
3@d800d?2P0?4@`04aD@014C3P0<3PT02P`7018D3`0E5a804Q@?0P0@4Pd01@0<3PT04a@?014B3@0?
40/04A8=00803@h900<0414<014B3@0>3`X00P0>3`X00`0?3``030`:01LG5@0201<C4@0800L71@0;
2`T03`l=010@3P0A4@l020P600h>300A4Pd3010A300;014B3@0C50l030d800l@2`0D5A002P/6010A
300B4`h051D@00l@2`0B4`h00P0A4Pd0200b<bh071dH01@E400A4Pd030d8010A300D5A003a0;0P0>
3`X0100=3PT03Pl:00l@2`0;30L300h?2P10018C3P0A4Pd03@d;00d=2`0<30X03@d;010@3P0A4@l0
6QXH00l?3@0l?3X0;2`Z00/;2@0>3P`03`l?010@3`0C50l04A8=01<D3@0L7AD06AXD00d>200@40h0
DU9D04m>DP0I61h06A@J01HC5P0C4A@04Q0A014@3`0@40h03Pl:010A300D5Q405QTB014E3P0=3`X0
40l=01<?400A3@h04@l@01HF5P0J6QX02`/;00D71P0@4Q407b4P018D4`0E5aH04aDB018D4@0F61D0
3@l<00lA3P0<3P/04aDB00D7100E5a@04Q@A00lA3P0K7AX03a@>00hC3@803a@>00@05a`F020U7`0D
6A<051TC0P0C61806@0B5a404AP@018L400A6a003QP=010J3`0@6Q403QP@01/U7@0@6A@0624L01DN
6@0@6AH04ATE00P>2P0A5a<0>T0l01@J5P0B61@05Q`H01LM6@0H7QX04aTE018H500H7QX00P0J81`0
4P0V;2P07RDQ00lH4`0D7AP04A/E01`W8@0F8A/05b<M01<P6@0F8a`04b0H01@Q600D8AX04b0I018O
600E8Ad05b<O01DQ7@80520N00D05B4O01HR8P0E92405RDR01@S8002018Q7P0301HU8P0I:2D06BPU
00@06BPU00d07RXZ01DQ8@0L:2P09C<c01l];@0R<3405bHY028a=00O<C<0:Sa003i@E00]@4D0:Se4
0080<4A=00<0V:be020d?@0[?dH00P0T>Ch02@0U>Sl09CXm02Hk?P0V>c`0:3`m02Hi>`0Z?D40;3m6
02TkA00202TkA@0=02i1B@0cAT`0;T5702Xn?`0`A480:T4k02U0>P0X?cT09chh02Po>P0X?S/0:Cll
02Y0?P0202]1?`0H02a1@@0/@T00;D=102a2@00_AD80<dU70357A@0[@Ch0=de;05Q^J`0lDTl0;dE3
02i4@@0hCT`0=dm?03M<C@1@IFH0<TQ604IJF@0eBDP0=TY803Y=B@0iC4P0=TU50P0dAd<0C`0lCDL0
AUMA03A5?`0_@3X0:3Ta03U:@P0_@3P0;3dc02/l<P0^?cD0<dDi03I6>`0_?3D0:cXc02ho=`0iC4<0
=T]202i3>P0[?cH0<3lh02`i<P0W<B/092XV020Y900nBdT0<clk03E1>@0^>S00@4Y102La:@0b?CL0
;CTi02hl@@0kC5H0=dUG03M9G014EVh0=dUO03mAI017FVP0AUQT065dN`1ZOH<0@eEI02/l@P0]?TD0
=TE<03e<D@1WMWT0@U5D02@c=P0W=ST0<d9502Pg>P0^?D00;ci102dl?`0[>Sd0;3/n02/n@@0U>Sd0
9CPl02Xl?`0W>C/0:3Lj02/f>00X<cD09Bla02H^<00U;Bl082LX020Y:00D7a/07BPT02Pa;P0I8Ql0
7bPU01`R800N92800P0M8B000`0P92<07B4P01lS8P0201hR8@0601lS8P0P92<082@S024U900M8B00
8RHU0P0_<c80E@0O8b407AhI01dN600M7QP06a`G01TJ5@0G61<04Q8@01PH5`0H61P06ATI01dM7@0I
6aX071hM01LJ6@0J71/071hM01TJ600H61H05aLE01LG500G5Q805QDA01LE400E51006QTG01DE5@0A
4A405QHF010@400E5AD04a<C01DE5@0H61P05QHF01<C4`0G5aD051@B014A3P0D51806QXH01/K6P0F
5QH04a<C01DE5P0E5AL04a<E018A5P0B4Q@061PI00`<300J6QX07AdM055AD@15ADD04Q8B01<C4`0B
4Q804A4A010@400B4Q004a@?00h>300F5Q@04a<E014@5@0B4AH040lD01<C5@0D51@04a<B00l@2`0=
3@/0518D01PF6@0<2Pd0518G00T7300A3a@05Q<J01dJ8@0;20l061DN01@A6P0:20d01@0?3@h0400B
41402PP901XH6@10?Sl05A<D0040000>2`d02PD900D0100<1`/03PT=014<400E41@04@`@010;3`0?
2Ph2010;3`0300l:3P0L5a/020<700805A0D00X00`0203Lb=P0<1`/00`0200P31`0<1`/05A0D00l9
3@0@2Ph04`dA0P0D3Q803P0C3A405Q0D00@00P0=20/040X>00H0100>20`02P@8010:3P0I4aL07ALK
01LA5@0B310030H:0`0=1`/200`62P0300/6300@2a406aHL00802@8900@03`P?00h4300>10`03P@<
0`0?10`700l42P0401D:400A1P`03`@:01052`L03P<900@04@H<01052`0>0`T03P<90P0?10XDoooo
o`006oooool0500C5A002P`700X<1`0:30L03@l:01LI500?4@`04A<>00d?2P0<3PT03Q0;00X<1`0>
40/03a4<00h@2`0<3PT03@l:010B3@0<3PT03a4<0P0A4`h200lA3005028S7P0M7QT02P/600l@2`0>
3`X00P0;30L200d>2@0300`=200>3`X0414<00H0414<00X03a0;00d>2@0>3`X0414<00h?2P0;30L0
3@h700d>1P0>3`L03a080P0>4@P0300?4PT03Q@:00hD2P0=4`T02A4600`A2P0@4Pl03a4>010B3`0D
5Q<02`d:010B3`803a4>00h03Q0=00`>2`0;3@X03@l<00lA3P0<3P/02`d;020R7`0a<c001PP500/=
2P0<3P/03a4>00h@3@802`d:00D03Q0=00lA3P0?4@h03a4>00h@3@0600lA3P0S00h@3@0A4a003@l<
018D4@0?4@h02`d:00840@0E5a@01PP5014C400;3@X04A<@01DG5P0=3`h0418A018D4`082PT03a4@
0001000L7Qd030h=00430P0;3@`05aTH04I6A01?Cdd06ATG00l?3@0D51803`l=00d=2`0?3`d0410>
01@D4P0G5aD00P0@40h01P0<30X02@T700d=2`0=3@/02@T700l?3@803@d;0P0?3`d00`0<30X03@d=
010@400200`<300500l?3P0;2`T03`l=00h>2`0<3@P00P0=3PT01P0=3PP03Ph<00d=2`0>3P`04A4?
018B40803`l=1@0@40h00`0?40/0414<00l@2`0200h?2P0<00D60@0:2`H02P/600h?2P0<3@P02@X5
00/<1`0I6QD020T400l@2`0@4@`020T40P0=3PT02`0>3`X02``700h?2P0A4Pd03a0;00h?2@0;30H0
5QLA00T:100>3`T06Q/E00@03Pl900@03a0:010A2`0?3PX03`h:0P0>3@T0300@3`/04Q4=01<B3P0?
3PX02`X600`;1`0?3PX03a0;00d?2P0?4@`04Q@?010B3@8030h900d04A<>010B3@0=3`X05ALB01/M
600E5Q406AXE01DF4@0I6QD04Q<>00P9100B4`h04A8=00804Q<>00l05QLB018C3P0=3PX03`l=014A
3`04108051@B014A3`0H61H04A4?00`<2P0:2PP04A4?00`<2P0A4Pd00`0@4@`0500A4Pd04a@?00h?
2P0A4Pd04a@?00T:1@0C50l05AHA014B3@0:2`H03Pl:00/<1`061`808b@O02HW8P0>3`X0414<00X;
1P0=3PT051D@0P0>3`X300d>2@0800h?2P0=3PT0414<00l@2`0>3`X04Q<>014B3@0<30X2010@3P0e
00`<2P0;2`T03@d;010@3P0D5180SHf;07IfM00A4@l010@2010@400B4Q004Q<>00l@2P0>3`P04A8:
00T:100D51401PH4014A4`0D4aL04a8G01TD600G4aL0518E01<A4P0A4100410>00d>2@0@4Pd051HA
01DH4@0A5@h03Q0;010?3@0B3Pl04@d>014?400C4a<05ADE01LG5`0>40l03a4@00T;2P0620L071hM
01<E4P0@4Pl04Q@A00`>2`0C5A8051HC010B3`092`P00P0E5a@01P0@4Pl051HC01<H4P0C61803Q<=
00/@2P803Q<=00L05AXD01@I4`0C61804aPB014F400A5Pl04A/>00803aT>01004Q`A018L4`0?6A00
5AlG00hG4P084@`051dH01XS800C6QL03A<?02`b;P1iOg/08RPT018H500E6aL051XF0P0I7a/201@J
5P0I01DK5`0I7a/09bdY01lV8P0@6A@051dH01@N600K9R0072LQ02@`:P0>6a@08BhW014N5P0D8AP0
524J01<P6@0B7aP05B4M01PT800G8al05R8P01DQ7`0G8b406BDU01LV8`0201PW900301HU8P0E9240
5B@Q00H062LT00<05b<S01HR8P0J9RH00P0L:RX03@0P;Rl06bX]024`<`0P<S@0:Sa003I8C00V>3d0
93Po02e1BP0V>T<0?51I02LkA00T>3l00`0V>d0202Hk?P0?02Dj?@0W>c`09CPk02Pk?`0Y?480:C]4
02m1B`0Z?4H0<4=:02/nA00Q=3P093Lj03=7AP0Y?c`0:3li00809Sdg01P09S`h02Hl>@0/@Sl0:d4o
02Y0?P0[@Cl0;T=302m4A@0^A480;D=10357A@0gCD/0>4i<0398AP0cBDL0>e5?02Lm>`0jD4h0:d4o
04EKF@0fCTh0DfQY0;gBd`1EJfT203M;BP0403I:B00iC4P0>Da803I9A@80=DQ400L0;3dg02/l=P0S
=2h0<T<m02Tj<P0b@c/0;Chf0080:c`b02h0;Chd0312=P0a@cL0;S`e02dl=@0a@3T0=DLo02i2>@0V
>c80;d8i02/j<`0^>c@0:C<^02<Y9@0X<Bh0@Di>03Y6AP0hA440>dI205AMF00Y<c40?DQ:02lj@00/
>TH0BeY]03Y;G`0Z?5<0AeUa03a>I00lCV40>4]I0312CP17FV40CF1V03a>DP0hBDl0=TM>0350A`0a
@4D0DF1S03M6B@0P;c80:cXm03I5B00Y>3/0:STl0P0/>ch0500]?3l0<3m203=6B@0/@D@09CPl02Dh
>`0T=SP0:3Hi02Pc=@0S;S008R`^02L_<@0X<3808bX[02</:`0K9R808bhZ02D^:`0T;BX08b`Y0P0K
8Al01@0J7Qd07B4P024U900M8B008BDT008082@S0P0R9RD0200O8b808BDT01dQ800N8R40:2`[02T]
;00M8Al07b0K0P0O81X04@0L7AP06Q/F01PI500C4a406ATH01XJ6P0K6a/07AdM01PJ6@0J71/061/J
01XL6`0K7A`06AXI01LG5@0E5A<05QDB00805QDA00<05aD@01DD400J6AL00P0C4a<0100Q8B403`l?
01PH600J6QX201HF5P0E01DE5@0C4a<05aLE01XJ600B4Pl04Q8@01XJ600N7Qd061PH014A4@0E5AH0
51@F018B500D4aP061PJ01<C500<30`05QHF018B4P0[:b/07alO00<04a<C00L04Q8B014A4@0B4Q00
3`l<00L71@0@40h02PX<00803PdB01804Q4F01@D5P0E5AD051@C010A300?3`d04a4C01@B5@0<2Pd0
4a4F00d;400A3a@02PL>010=500?31<0QX><01TF7`0=2Pl500h<3@0:00`:2`0=2``04a4B02l];P0O
7Ah02`T:010<3`0C3Q805A0D00d830803PT=01@03@P<00h93@0=20`03@P<00h93@0?2Ph04PdA00L2
1P0;1PX02PH900l:3P0:1@T0100300H11@0F4AD040/?00<00P0<1`/02`H:00`62P803`T=00d03@L;
00X4200C3A405@lC010:3P0B31001P04010:3P0C3A402P@8034[;`17@DD06Q@H00@03PP<00T03@L;
00`62P0;1@T020<900<010080`T030D<01@=500<1@`00`0?1@d301053@H03`@:00H04PL=01P=4`0D
2@l04@H<01873@0?10X600h32@8040D;0P0>0`T00`0?10X040D;ooooo`0Cooooo`006oooool0700<
3PT03a4<01HH4`0F61<04A<>00d?2P0@4Pd04Q@?00h@2`0=3`X03a4<00/=200A4`h03a4<00/=2009
2`H03@l:01<E400I6aH0418=00d?2P0C5A004Q@?00lA300J6aH05aPC00T:1@0B4`h201<D3`0300h?
2P0?40/03Pl:00803@h90`0?40/300h?2P0400d>2@0@4@`02``700`=20804Q<>00D0414<00d>200=
3PP03Pl900l@2P0300hA2P<03A8;00H02Q49014F40041P<03a4>00d?300@4Pl200h@3@0<01LI5P0I
6aP04A<@00P:1`0;3@X03Q0=00d?300A4a00=SPe04A6A00B51403@l<0P0<3P/0100?4@h0418?00d?
300<3P/200d?300400h@3@0=3``03@l<00d?30803Q0=00l03a4>00h@3@0>40d0418?01DG500=3``0
10H401`N6`0<3P/03@l<018D4@0>40d03a4>00d?300>40d00P0:30/0900J71/07R0O010B4@0;3@`0
6adL065SHP0?40l03a4@01PJ6@0O8B00b/[80>WYi`0b<S005QHD00X:200C4a404Q8@00h>300=3@/0
6QXH028R800E5A<030`:00l?3@0@40h03@d;00l?3@0D51804A4?00h>300=3@/03`l=010@3P0>3P`0
3Ph>014A4@803@d=00T0410?00`<2P0<30X03Ph;00h?2P0=3PT03Pl:010A2`0@40h00P0>3P`06`0?
3`d04A4?010@3P0:2PP030`:00h>300?3`d0410>00l?3@082@@04A8=00T:1`0?40/03Pl;01HG4P0A
4Pd03Pl:014B3@0@4@`03a0;018C3P0<3@P03@h901`M600;30P04Q<>00X;1P0200l@2`0L00`=200>
3`X04A8=00l@2`0A4P`03a0:00/<1P0L7AL09BHP00/<1P0<3@L03Pl9010A2`0B4`d03Pl900`=1`0>
3@T04A0<010?2`0=30P040l;01<B3P0>3@T03`h:010?2`0>3@T04A0<014B3@8030h902804A<>01LI
500I6aH05ALB010B3@0>40/04Q@?01dO6P0L7QT04Q<>010A300<3@P05QLB01@E40092PD0414<00l@
2`0<3@P04A8=01TJ5@0C50l03Ph;00d=2`0B4Q00410>00`<2P0W9bD0ATI400d=2`0J6QP03@d;01LG
5@0@40h04A8=0`0@4@`00`0A4Pd04a@?01@E400200h?2P0@00X;1P0B4`h04a@?01DF4@0A4Pd05AHA
01@E400>3`X04a@?02HW8P0@4@`03a0;00d>2@0<3@P04A8=010A30803a0;00X03Pl:00l@2`0@4@`0
4A8=01@E400B4`h03a0;014B3@0@4@`03Ph<0P0B4Q005`0>3P`030`:00l?3@0@40h03@d;024Q7`0@
40h04a<A00d=2`0?3`d04Q8@010A300@4@/04Q<=014B300@4@`0410=01XJ6@071`P05ADH00L62P0F
4A@05A8C00804a4B02H04A0@00l?3@0>3P`0414=010B3@0?4@`03a8<014C3P0@40h04a4B01DC500D
4a<03`l?00d=3@0E5aH05QPG018D4`0>4Q40:Bd/05=GEP0?4@h05aTF01dO700A4a00418?00`>2`0S
9B806A/H00h@3@0A4a005aTF00h@3@0@5@l04aPB014F400D6A<05Q/E01<H4P8051TC0`0C61804P0C
61405ahE01<I4P0D6a<05A`D01<I4P0B61806B0I03Dj=P0I7a/04ALC01`Q800>5140<SPd02hd<00H
7QX03Q@@01TO6`<051XF01/05A/G01HL600F71P05adI01@J5P0K8Ad0620K01@M600I8Qd05R0K01dX
8P1LIf40Oh^501PU7P0G91d04QlG01@Q600F8a`05B8K01@Q6P0F8Qh05b<O01HR7P0E8Al05R8P01LS
8@0J9RH00P0D8b00100F9B805bHS01PW900F9B8601TX9@0W020^;P0`?Sh0:CLg01HT900N;2`0830`
028a=00L;Bl0838d02@f>P0N<3@08C@i01lc>P0N<S/0:3a501P/=@0Y?DH09c]202Hk@00W?440:3e2
02Pm@00V>ch093Tl024e=P0[?d40=4M;02i1A`0W>T00;D160354B`0Z?D@0:3]102m2AP0cATT0:Shm
02]1?P0Z@C/0:3li00<0:3hk0P0^A4805`0/@T00;D930356A`0cB4T0<DI70397B00dBDX0=da=03Q=
CP0fBd`0=DY;03iCE00kD540<dQ903]@D@0aATL0>51@04AIFP24VIX0@5ID03]?CP0cAdH0=d]90080
>Da80P0gBTH0=@0hBdL0=TM10352?00gB480DV=M03A5?@0/?CD0;Chf02m0=P0`@CL0;Sle02Xl<00X
>Rh0;Sdf0350>@0fACh0<dDm02/o=P0Z?SD0<44i02hm=P0]>S<0:SD_024Z9@0^>CD0<3do02dh?00^
>3X0<3Xl03m9BP0/=CT0?4I?03i9E`1IIWd0EVF203a;J`19FWL0NhnW04iSN@17Ffd0@5=Q02@h@`0j
CED0=DQ>03=4B`0dAD`0<D990393B`0c@dP0<d=302/k>`0V=SH093@d0080:c/k01h0:3Ph02Xj>P0Y
>CT0:3Ph02Xj>P0/?T00:Ca002/m?`0a@T@0;3/n02Hd=@0/=cT0:3<e02H`<@0Z<S@0:c<e02H];P0N
:2H082/W024/:00G81d0<3Tf01/T8@0L8R007B<Q01`P7`0N8R408RHU020T8`0O8b82020T8`0:01lS
8P0N8R407b<R020T8`0N8R406QhM01TM700M8B0092TV01`N6P807AhI00h071dH01XK5P0I6AL05QHD
01TI600G5aL061PH01hN7`0K71h05aXI01TL6`0J71/06adL01/L6`805ADC00h05aLD01PG4`0H5a<0
5aD@01@C3`0I61H05QHF01lO7`0Z:RX061PH01lO7`0Z:RX06a/K01DE5@8061PH01@061PF02/[:@0L
71T04a<A01@D4P0F5QD04Q8B014A4@0C4a@04Q8D01<C5@0I61d07AdO014A4P0?3`l05ADE018B4P0?
3`l02PX:01@D50<04Q8B01804A4A010@3`0C51003`l=014A400L71d06QTN01<B5`0D4aL04Q8D014A
4@0A4A004Q8?018B400D4Q<03P`?00`:3@0A3a82018@5@06010>4`0I5Qd0;b`c08N4R`0@3QH040dB
1@0>30d0500?3@h0>SPi044o@00C4A801PD500`:2`0A3Q0030L;00l:3P0>2@d03`X>01HA5@0A3100
40/?00l:3P0>2@d03`X>010;3`0B3A403PX=0P0@2`l02`070`H05Q4E00l:3P0<1`/02PH900/72P0B
3A404@`@00`72`0?2@d04`dA00805Q0D00H05@lC00d72`0e;c<04@/?018<400;1PT200d72`0500T3
1`0L5QX0:28V018<400=1`/00P0>20`02P0?2@d03PP<00h8300=1`/03PT?00P32@0?2Q002`H<010;
4@0;10/200h73P<040H>00<04@H>00l42P0?10X01@0?10X01@0D2@l04@H<00h32@0?10X03@8800H0
3P<900H040D;00l42P0>0`T03P<901052`0A1P`Dooooo`006oooool03`0B50l03a4<00X<1`092`H0
3@l:00h@2`0?4@`04Q@?00h@2`0=3`X03a4<00`>2@0=3`X03a4<00h@2`0200d?2P04010B3@0D5Q40
3a4<00d?2P80418=00d03a4<00d>2@0<3@P02P/601<D3`0B4`h06AXE014B3@0B4`h04A8=00h?2P0=
3PT03a0;00<03Pl:00@03@h900`=200<3@P0414<0P0=3PT00`0>3`X03@h900`=200200d>200500h?
2@0?40X03Q4:00hA2P0<3`P00P0:3`P0300<4@X031<;00hC3@041P<00@<0010B3`072@H030h;010B
3`0?4@h0418?00d?30802@/800L04A<@000100031@80@dE204i@C@000@005QPE00803Q0=00@0418?
018D4@0A4a003@l<0P0;3@X0C@0<3P/02`d:00/=2P0;3@X030h;00d?300>40d03@l<00`>2`0:30T0
2@/801/M6P0:30T0828O01XL6@0@4Pl02P`9018D4@0?4@h04A<@010B3`0?4@h03Q0=00X<2@072@H0
2@/8014C400?4@h03@l<01DG500620D0418?01<E4P19BDL0I6AR01LG5@0A4@l05ADC018B400?3`d0
3Ph<00`<2P0B4Q0061PF018B40092@L03@d;010@3P0=3@/03Ph<01<C4@0A4@l03Ph<00d=2`0>3P`0
410>00l?3@0>3Ph04A4A00h>3P0=3@d0410?00`<2P092@L03Pl;010A300>3`X03Pl900l@2P0A4@l0
3@d;00`<2P0=3@/03Ph<00d=2`0<30X03`l=00804Q8@00d03`l=00/;2@0F5a800`@001XK5P0H6A@0
7b0K00@5000A4Pd03@h900l@2`0>3`X03a0;00804a@?00D02``700`=200Y:RD02@X500l@2`02010A
300R00d>2@0>3`X0414<00h?2P0>3`T03@h800/<1P0Y:R@0<S<]00d>200<3@L02``600h?2@0B4`d0
414;00d>200=3PT0414<00l@2`0;30L03a0;01<D3`0L7AP02P/600d>2@0>3`X02``700h?2P0>40/0
30h900lA300E5a8061XE018D3`<03Q0;01/04A<>00d?2P0<3@P030d800h?2P0@4@`051D@01DF4@0<
3@P03a0;00h?2P0=3PT04Q<>014B3@0:2`L0418?00lA3P082PL03a4>00P:1`10@Sl02P`9018D4@0=
3``0418?00d?300A4Pd00`0@4@`0300A4Pd04a@?01<D3`0:2`H05QLB01@E400=3PT0414<00/<1`0?
40/03Pl:00/<1`803Pl:00H05QLB01DF4@0>3`X04a@?018C3P0@4@`2014B3@<0414<04d04A8=00l@
2`0B4`h04A8=00l@2`0B4`h0414<00h>300@40h03`l=00h>300?3`d0410>00d=2`071`D03`l=00h>
30092@L03`l=00d>2@0A4Pd03@h900l@2`0F5a804a@?01<C4@0A4A003Ph>00820P0=3@h03`lA018>
3`0C40l04a8@01@C4@0B4Q004A4?00d=2`0@4@h03a4>00d?2P0=4@/04A<>00h>300>30d03`d>010@
400<30`020X901PJ6@0;3`h03A4@01XN7@062PT000<2014C400M7a`09BLT01LI5P0B51403Q0=02@V
8`0F61D03Q0=00lA3P0C5A803Q0=01LL5P0E6Q@05a`F01HK5@0B5a404aPB014F400B5a404aPB01@I
4`0201DJ500B01LL5P0D5Q405Q/E01DI4`0C5A005QXE01<H500[;BX04QDB018G4`0D5Q<06R0L02<Y
9@0U:bL04ALC00lE4@0>51006b4M0P0G7AT03@0D6QH05A/G01XP700L8Qh04aTE01PN6P0E7AP051dH
01XS7P0E7aX072LQ03E0>P0Q;BH00P0K:2401P0C81P05R<J01LT7@0G91d05R<L01LS7`806BDQ00X0
6BDS01LS8@0F8R005B4Q02Dc<`0O;Bd05R@T01DS8`0I9bL07B/[1P0K:BT01P0N;2`0:SPh028`<00A
8B005bLV01`/;0807Bla01d07c8c01ha=@0M<3@09STn0396C@0gBe@093Q10396C`0E:C80;D5802<h
?@0T>Ch09ca102Pm@00V>ch093Tl02Di>P0[?d40<TE902i1A@0X>cl0;3m302m2B011E5P0?4mC0313
A`0^@T@0<dM602Lm>P0302Hl>@0W02Lm>`0X?S`0;TA202i4@`0_A4D0<DI703=8BP0dBD`0<dQ;03Q=
D00iCU40=DY=03I;CP0jCe80@eQK06AiO00Y?T40<dQ;02i3AP0lDE@0=dm?03eBD`0fBd`0=de;03iB
D@0Y?C`0=d]903U<B00hBdL0=dY603Q;A`0jCDT0=DI003a=A`0b@cd0<44k02dn=P17F500<44i0080
<D8h04P0;Sle02/m<@0Y>bl0;3de0311>@0fAcl0<d@l02m0>00b@c/09cH_055NE`0S<2T08bhX024/
9P0V<Rh0;chn02@b<`0^>c/0<3`l03M1@`0_>Cl09Bli03i:FP1DHGT0@e9c04QHO00nD6h0@EE^02e1
F@13F6`0?eES03A7E@0fBU80<TI=03Y=D`10DeT0=dYA0393B`0gAd`0<T1103E3A00[>CX07bd^02Dc
=00]>c`0;3Xk02dk?00/>S/0:3Hg02Le=P0U=CH0:3Lj0350@`0hAdT0;cdn02Td=P0U<C40930`02<]
;P0R:bX08BXY020Y:00T;b/07bXV02Td<00U;R/0BU=@02/d<@0M8b408BLU028V9@0O8b82028V9@1>
024U900U:BP09b/Z020T8`0O8b809b/Z01`P7`0M8B00720O01PL6`0J7Qd08RHT01dO700N81/07b4L
01lQ7P0N81d07AlL01PJ6@0M7Ql06a`N01dN800S92H08R<U01@H5`0J7A`06A/J01/M700L7A/04a<A
01LG5@0I6AH06QTE01TH500G5A004a8>01@C4@0A4A406a/K01HF5P0D51@05QHF01dM7@0D51@04Q8B
01<C4`0B4Q804a<A01PH5P0C51004A4?01@D4P0H61L06ATI018B4P0C4a@05ADG01PH6P0F5AX051@F
01<C500B4Q805ADE01`L700C4a<06QXJ018B4P0?3`l0410@018B4P0@41003Ph>00P81P092@T020P8
03Ti>@0S8bD020P:0P0@4180400@41003`l>00h>300>3P`09B<T01LE5P0D4Q<040hA014?4P0;2@`0
5aDJ01HD6@12@4D0Q86800P5300>310500d;300900P61`0J61T0:2HW00<10P0100003`d>00d9300:
1@T03`X>00805Q4E00D05A0D018=4@0B3A404@`@010;3`0200l:3P0<00/62P0O6Qh01@0400h93@0F
4AD04@`@00`72`0F4AD061<G01@?4`0:1@T010030P0;1@T04P0=1`/03PP<00l93@0@2Ph04`dA00/5
2@0=20/04P`@00P21P0J51P02`D901<=4@0:10P0100201<=4@0B310030H:00d72`<03`T=00L03PP<
00H11`050`P04@lD00T42P0=20h040/A00<03PL>0`0@1Ph600l42P0600h32@0D2@l04PL=01052`0B
1`d040D;1P0>0`T01P0?10X03P<900h32@0>0`T040D;014631Cooooo000Kooooo`0I010B3@0A4`h0
3Q0;00`>2@0=3`X02P`700h@2`0A4`h03Q0;00d?2P0@4Pd03@l:00X<1`0?4@`04Q@?010B3@0=3`X0
30h900X<1`0>40/03a4<00h@2`0?4@`04A<>01@E400200l@2`09014B3@0:2`H04a@?00h?2P0@4@`0
4A8=010A300B4`h04a@?00803a0;0P0>3`X0200=3PT030d800h?2P0@4@`04A8=00l@2`0=3PT030d8
0P0=3PP01@0>3`T03a0:00hA2P0>4@X030l800802@h700P02a0900dD300A5A0071hK0043000B5140
61XG010B3`803Q0=00X030h;00lA3P0B5140418?00`>2`0J71T04aDB00X<2@082PL05QPE0P0=3``0
1@0;3@X03@l<010B3`0@4Pl03Q0=00803@l<03403Q0=00d?300=3``03@l<00h@3@0@4Pl04A<@010B
3`0>40d0418?014C400f>3D06Q`I01HH5@0<3P/04A<@00L91P0B514030h;00lA3P0<3P/04A<@01HH
5@0D5Q<03Q0=010B3`0?4@h05QPE00840@0:30T04Q@A00X<2@0?4@h05ADC018B400E5A<01PH401HF
500<30X02`/900l?3@0=3@/02PX800d=2`0>3P`030`:00h>300?3`d030`:00802PX801X04Q8@00h>
300=3@/03Ph<010@3P0?3`d03`l?014A4@0>3Ph03@d=010@3`0<30X04a<A01TI5P0I6QD05AHA014B
300@4@/04A4?00h>300;2`T030`:00d=2`0<30X0410>00h>308030`:00X03Ph<010@3P0?40/04A8=
0083000D5A00TY>>02LX8`0C50l03a0;0P0@4@`0200A4Pd05AHA00`=200<3@P071dH07IgLP0D5A00
3a0;0P0A4Pd06`0=3PT03Pl:010A300=3PT04a@>00X;1@0C50h03@h8010A2`0D5@l03Pl900X;1@0;
30H0414;014B300@4@/03@h9014B3@0?40/02``700h?2P0C50l0@d@o01HG4P0?40/04Q<>010A3002
014C3P0C00h@2`0=3`X03@l:00/=200?4@`05ALB01<E400<3PT03a4<01<E400C50l02``7018C3P0<
3@P0414<01TJ5@0:2`H04Q<>01DF4@0200h?2P0>018C3P0E5a<03@l<00`>2`0E5a@01`T6010B3`1l
OW/061XG00H81@0?4@h06A/H014C400A4Pd3010A300D014B3@0C50l04Q<>00`=200R8ah071dH00`=
200A4Pd03Pl:01LH4`0B4`h020T4014B3@0F5a802``701LH4`0=3PT05aPC01DF4@0A4Pd2018C3P06
014B3@0@4@`04A8=018C3P0<3@P03a0;0P0>3`X0100B4`h04A8=018B400@40h300d=2`0e00`<2P0=
3@/03`l=00l?3@0F5Q@03Ph<00l?3@0?40/0414<00X;1P0;30L04Q<>00h?2P0:2PP05QHE00h>3P0G
5aL03@d>010@400A3@`04a0?01@C4@0E518051@B018B400<30X0414?014C400?4@`03Q4<014C400B
4Q8040h?00l?3`0C4a<04Q@C010B4@0I6aX06QhM00hB4@0<40l03A4@01HJ6@0<3P/04A<@01DG500<
3P/04aDB01DG500A4a0030h;01DG500C5A800P0;3@X02P0B5a403a@>01DJ500E6Q@04AH@01DJ500@
5@l04AH@018G4@0E6Q@201HK5@0U01@F4@0@4Pl05QPC01LI500E5a806adI01@F4`0M7a`05QPE02<U
8P0B514061dI00P>2P0K8Ad05adI01TO6`0;4@d05A/G01HL600O9B40728N01HL600J81`0728N01DK
5`0K8Ad05ahJ018K5P0I8Qd04adH01hY8`0mB48082`V01<P6@064``06BHN01HS6P0201PU7P0>01LT
7@0G8al072PT01l[9`0N:RP06bLU01LS8@0C7al0>DM702lm?@0L:RX05R@T01XX:00O;Bd601d[:`80
82h^01h07bd]01d];00O;bh0:3Ti01X/;P0Q<cD07S8c01`_<`0T=c/093Ll014U;00gBe@08SHo02Xn
A`0R=Sl09CU0024f>`0S>3d09S]002Pm@00V>ch093Tl02i2@`0U>3/08cHj02Hi?@0]@4@0>4]?02/n
@P0_@TH202Pk?`030395B00cAdP0:T0n0080:T0m0100:d4n02e3@00^A480;TA202m4A00aATL0<TM8
03A9B`0eBTd0<DI903Y?DP0lDE@0>DiA03]@D`14FE`0?55D0P10EEP0D`0hCE00>e1C03U>D@0lE5@0
>4e>03iCE00aAdD0:Cdl03U=C00gBdT0>Da803Q;A`0gBTH0>4]703Y=B@0gB480;Chh02`m=`0jBdD0
93D]02Xk<`0b@c/0<44g02m0=P0^?cD0;T0d02do<`0[?3@0;Slg03=4?00^?cL0:c`d0350>@0eA3d0
Ohb5034n=`0d?cT0=T4k03A0?00a@3h08S4^03=0?P0lB4H0A4i?045<C`0iATh0Df1`03M5G00lBfX0
Ff^=04iQO`1:GWL0@5A/03]@I00P=T@0<dID03eAF`0kCeH0=dYA03A7CP0_@TT0<45903Q7C00c@D80
>TQ902Pf=`0Q;c00:CLh02hl?@0[>CX0;S`m02lm?P0/>S/0:cTj02dk?@0^?D00<T130390@P0Y=cP0
;3Li024];@0R;Rh092h_00808b`[01<09Bh]02Td<00H8al08RdY01hW900j@d005AhK01hT8P0S:BL0
9BTX01lS8P0Q9B@08bLV01hR8@0S9bH09BTX01`P7`0K7ah09b/Z00807B4P00L07R8Q01/O7P0H71/0
5a/J01PJ5`0I6aH06adH00806adJ01P06Q`I01HH5`0K7Ad06Q/M01/L7P0N7b406a`N01@H5`0K7Qd0
6A/J01/M700L7A/04Q8@01PH5P0J6QL06aXF01XI5@0G5A004Q4=01TH5P0C4a<06QXJ00`<300E5AD2
01@D500701DE5@0H61P05QHF01<C4`0G5aD04Q8@01<C400201<C4@0/01<C4P0B4Q804a<C01@D5@0I
6A/06a/M01<B5`0<30h04A4B018B4P0D51@06QXJ00P8200@41004Q8B00h>3P0?3`l04Q8B00l?3`0=
3@d04Q8B01HF5P0E5AD0G5aL03Ti>@0B4Q803@d>010@400A4A403`l?00`<300:2PX05aDF00/92P0=
2``03P`?01DC5P0?3A00518G00D3200D4QL07AXQ00/83`0@3Q8500d;300@010>3`0200402`T:018@
4@0A3a00518C00L41P0J5AT071LK010<3`0910P030L;01<>4P0@2`l03`X>00h93@8030L;00X03`X>
018=4@0L5a/0@ci200L21P0:1@T04@`@010;3`0:1@T03@P<0P0;1PX04P0F41@04`dA014;3`0>20`0
3@L;00`62P0:10P04P`@01D?4`090`L0?SPl03li?@0>20`040X>01@>4P0@2Ph04`dA00X4208030H:
00X03PP<00l93@0?2@d03`T=01@B5`0;2@h03`dB010;4@0F4AL030L=0`0>1`h301063PH03`@:00H0
2P0501052`0>0`T0304700l42P0=0PP:00h32@0301052`0A1Pcooooo01?ooooo000Kooooo`07018D
3`0@4Pd03@l:00/=200=3`X04A<>010B3@03014C3P0900lA300=3`X03a4<018D3`0A4`h03Q0;00lA
300D5Q4030h900803@l:00D030h900h@2`0@4Pd04A8=010A300200l@2`803Pl:100@4@`01P0>3`X0
3@h901DF4@0K71L051D@00l@2`804A8=00h08b@O038c;P0I6QD030d8010A300720<0414<00`=200C
50l03a0;00d?2P0>40/02`d8010E3`803A8<01d02@h900dA300>40d03@l<010B3`0B51404A<@00`>
2`0?4@h05aTF01HH5@0?4@h030h;00lA3P0=3``03a4>01DG500@4Pl03a4>01lQ7P0F61D07AlL010B
3`0B51401`T6010B3`0>40d03@l<010B3`0200d?300T010B3`0=3``030h;010B3`0H6QL010H4018D
4@0620D0418?01<E4P0A4a0030h;00h@3@0D5Q<05ALD00lA3P0:30T03@l<00/=2P0=3``03a4>00d?
300<3P/03@l<00D7100F61D030d;00T;200?4@h03@l<00d=2`0>3P`03`l=00d=2`0;2`T03`l=0P0A
4@l0100?3`d03@d;010@3P0A4@l300l?3@0500h>300=3@/03@d;00`<2P0>3P`00`0?3`d03P0>3P`0
2`/;01`L700G5aL03@d=00/;2P0=3@/04A4?01lO701hNG@04Q<>010A2`0>3`T03Ph<0P0=3@/02@0<
30X03Ph<010@3P0=3@/03`l=00X:200;2`T0410>00h>300200`=200401@E400720<0824L014B3@80
3@h901@03Pl:00l@2`0?40/0414<00h?2P0<3@P03a0;01<D3`0>3`X02@X500h?2P0=3PT030d800h?
2P0A4Pd04Q<>00`=1`0=3PP03Pl9010A2`804A8<00h04Q<=014B300?40X030d700d>200?40X04A8=
00/<1`0D5A003@h900T:1@0=3PT03a0;010A30<04A8=00H04Q<>018D3`0B50l04A<>010B3@0?4@`2
00`>2@0300h@2`0@4Pd03a4<0080418=0P0>3`X01P0A4Pd04a@?018C3P0B4`h04A8=010A30<03Pl:
01l03a4=01/M6P092`P030h;01<E4P072@H05aTF01@F4`0<3P/04A<@00lA3P0T9R<04a@?014B3@0?
40/03@h900h?2P0@4@`04A8=01PI500];RT0414<00l@2`0D5A005QLB00d>2@0?40/04a@?00h?2P0B
4`h030d800804A8=00l0414<018C3P0>3`X03Pl:014B3@0@4@`03a0;018C3P0A4Pd0414<01@E400C
50l03@h9010A300B4`h00P0>3P`200l?3@80410>00`04A4?00X:200>3P`04Q8@010@3P0=3@X03@h9
018C3@0>3`T03@h9010@3@0=3@/2010@40804A4A0280410@00h>3@0G4a404@l;018A3@0G5Q@05QDC
00h>300C4a405aPE0001000K7AX03A4=01DI5@0>3Ph051@D00l?3`0C51<05QPG010B4@0<40l05ATH
00lC4P0A5aD02a4?00dB400@4a003a4>018D4@0A4a004Q@A01LI5P0E5a@03Q0=0P0D5Q<01@0J71T0
4aDB014F400J7aT06AhH00804aPB01<05Q/E01<H4P0F6aD04AH@018G4@0H7AL061dH01PK6@0@4Q40
61/I01@G500T9R<061XG01dP7@0K7AX061/G01PL600H6QL051TE00805adI03/05A/G01dS7`0S:BD0
8BLS010F4P0O9B406AlK01dS7`0G7AT06AlK01PN6P0I7a/0620K01HO6P0D7AP04adH01/V800E81X0
5b<M01<P6@0B7aP08BhV01XW7P0G91d062DN01XW800H92005b<O01HR7P0I9B<0CUYH020/:P0K9bL0
9S@e01`Z:`0F92D06RPY01TW:00H9RL06BLX01PV9`0G9BH06BLX01`Z:`0P;Rl06BTX01h^;@0M;B`0
7Rh]02<d<`0O<C408C@e02@h>@0N<S<07c@g01/`<`0N<cL09c]2028f?`0202@h@@0>01da>P0W>d80
734f02@i?P0X?D80:d1302Hk?P0S>3/09cXn02Pl?P0Y?Ch0:cm002i2@`0Z?Sh302Tm?P0602m3A00d
B4X0;D5202Y0?P0X?S/0;48o0P0aAdD0=00Z@3h0;45203I;C@0iCU40=T]>03Q=D00kD5<0=T]>03U>
D@0mDUD0=DY=03]@D`1KL7<0DVMZ03Y?DP0hCE00?E9E03U>D@0lDE@0>U9B03Y?D010EEH0=de;0355
A00fBTT0>4a:03a?B`10Ddl0=dY603Q;A`0aA400=TM103Q9@`0dACl0;Chh02m0>00b@c/0=4Dm03E6
?00fAcd0=dPn03M9?@0fB3`0;d<j02dn=P0cA3`0<D0i02Pf;`0X=Bh0<3df02/h<@0/>C8202/h<@0N
02dl=@0_@SX0<D8i03U8?`0hACd0=d@m03Y7A00c@D<0>4I?03m?H@1AHWX0GW2<05Q/R01<HG/0@eUa
03mDJ00kDEl0=TaI03M<EP0lD5P0?51G03E9D00cATd0=DMA03U8C@0kAdL0=T9202`h>00Z=SH0:cLg
0P0/>3P01P0]>CT0;c/k02hj>P0[=cL0:cHg02Xf>080;3Li00/092la028^;P0T;Rl09Bl_02<];00P
:BP08BXY02Tb;`0U<2`092l[01lZ9P0201XS800301dV8`0U:bT08BLU00<07b<R00@0:Bd/02@X9`0P
92<07R8Q0P0T:2L03P0N8R406QhM01`P7`0L81l06QhM01TM700L81l07b4N01hP7@0I6aP0828O01HH
5@0J71/07b0R0P0P8B<0400O82@07QlS01hO8@0J7Qh061/J01LI600H6QT06AXI01TI5`0H61H05aLD
02PW8`0N7AT05A<?01@C3`0H5aD201HF5P<05ADE00h092@T02TY:@0E5AD05QHF01DE5@0@40h04a<A
01HG4`0F5Q@051@B018B4@0D51@04a<C01<C50804Q8D00D04A0E014A4`0C4a@05QHF01DE5@02018B
4P0301<C4`0H61P020P800804Q8B00X061PH01DE5@0C4a@03`l@00`<300E5AD06ATH00`<2P0A4A00
410@0P0?3`l200h>3`0700l=3@0?3P`040l=010>3`0?3A003P`?00l=400400l=4P0300l=400>30d0
3P`=00<03P`=00L03`d>00d;300>30d03P`=00T7200<2P/04@h@008040/?00@03`X>00h93@0>2@d0
3`X>0P0A3105010;3`0501PC5`0Q72004@`@00X52@0?2Ph01@0>2@d0300<1`/03`T=01@>4P0?2@d0
30H:00l93@0A2`l01`85018<400C3A40618F01/F6@803PP<0P0=1`/03P0@2Ph04@/?00/62@0;1@T0
5Q4D04m9C@0?2Pd03PT=01HD6@0920d061HK030^<`0X9R/050lE0P0?2Q002`0?20l03@H=00d63@0>
1Ph03P<901873@0?10X04PL=00d4200M4QP040D;00803P<900<040D;0146300?10X01P0?10X01P0F
2a403P@900d4200D2@l02P0500h52ACooooo000Kooooo`0800d?2P0>40/03Q0;00`>2@0>40/04A<>
00`>2@0>40/2014C3P03010B3@0>40/02@/600804aD@00X03@l:010B3@0J71L030h900h@2`0=3`X0
30h900h@2`0@4Pd03Pl:0`0?40/2010A300@014B3@0;30L03@h901<D3`0?40/02@X5018C3P0I6QD0
4a@?00`=200>3`X04A8=00d>2@0F5a803a0;00h?2P8051D@01804A4?00T91`0@40h03`l=00T;200A
4a00418?00lD400320@02a0<00L=2@0B5Q<03Q0=00X<2@0<3P/04A<@00lA3P0>40d201<E4P0700lA
3P0;3@X030h;010B3`0>40d03a4>01<E4P02010B3`0b01/M6P0A4a005aTF01PJ5`0C5A802P`9014C
400=3``03Q0=014C400<3P/02P`900d?30051`@02@/801TK600U9b@03a4>01HH5@0H6QL05QPE034c
<00H6QL0418?01LI5P041P<01`T600T;200A4a002`d:00/=200=3`X03a4<00d?2P0<3PT03@l:00X<
1`0D5Q404Q@?00d?2P092`H02`d8014A3`0=3@/02`/9010@3P0C4a40410>00h>300?3`d2014A3`03
010@3P0?3`d03`l=00803`l=00D03Ph<00d=2`0=3@/030`:00h>300300l?3@0B00h>300@4100410@
00T92@0:2PX061PG024Q7`0A4@l02@T602d^:@061`803Pl900X;1@0A4@l02PX800T91`0>3P`04A4?
0P0=3@/04P0>3P`0410>00h>300=3@/051@B01DF4@0=3PT0:2TT01LH4`0;30L02P/600l@2`0=3PT0
30d800h?2P0?40/0414<00X;1P803a0;00L030d800/<1`0<3@P03a0;00h?2P0=3PT03Pl:00803a0;
00L030d700X;1@0:2`D03Pl901@E3`0F5a403@h80080414;00T03Pl900d>200=3PP04aD@010B3@0:
30L0418=00lA300:30L00P0@4Pd4014C3P0900lA300>40/03Q0;010B3@0A4`h0418=00lA300A4`h0
418=00803Q0;00H03a0;00`=200=3PT05AHA01TJ5@0D5A0200l@2`0:00h?2P0=3PT03Pl:00l@2`0D
5A4051TE00T>2P0?51004aPD00X?2`803A8>00@020d900`?300@5A405aXG0`0A4Pd3010A300N018C
3P0A4Pd051D@00@5000C50l04A8=01@E400=3PT051D@018C3P0H6A@06Q/F01LH4`0@4@`03@h9014B
3@0@4@`03Pl:00d>2@0A4Pd0414<014B3@0E5Q4051D@00d>2@0J6aH07b0K00l@2`0;30L04A8=0`0@
40h01@0A4@l04Q8@018B400W9bD05aLE00803Ph<02L03`l=01@E400>3`T05QL@00l@2P092PD03Ph=
01@D500;2`d04A4B014A4@0?3`l03`l>014A3`0A3@X040h:010?2`0B4@d051<@01@D4P0@40h0414?
01<E500?4A005QTH00/?3P0C4a<03a0@01<E500>40l041@C01/O7P0@51<04aTG00P>300220H0;cPe
02P^;00J7AX00P0E5a@04@0B51404A<@01DG500O8Ah03Q0=01LI5P0H6QL04A<@00h@3@0D6A<04AH@
01<H4P0H7AL051TC00lD3P0E6Q@061dG00805AXD00h05a`F01HK5`0<4A000PH700hD500O92<06QhM
018H5@0L8Qh01@X601XO6P0C6Q<05Q/E01<J508061hJ00<051XF01TO6`0N92000P0E6aL05P083PX0
:Bl[00dC3`0K8Ad07R@P01`R7P0H7QX061lK01XS7P0I8Qd05R0J01dX8P0I91h05R8K01HS700?71D0
5B8J01HS6P0F8a`062DN01LT7@0F8Qh201DQ7@0[05=OG@3@g=X0DEeK01DQ8@0T<S<07R`]01`Z:`0K
:BX062HW01/Y:P0X=SL08Bl`01PV9`0I9bP07B//028`<@0N;Rd06b/Z01d`;P0R=C<083<a01ha<@0I
;Bh06bl`01`a<P0W?3l083Dh02Ll@00cAdh07c<l01hb>`0aADh0:cm802Pl@`0dBDh0:Sm402Dj?`0g
C4l0;dA702Ll?`0Z?D40:3`n02Tm?P0202a0?`0I02/o?@0U>CP0:3`k02Xn?@0_@d@0<dI902/o@00[
@Cl0:Clm02e3@@0aAdD0<DM602a1@P0T>C`0<4E803eBE@0nDeP0=T]@0315B00jCe80=DY;03Y?D00h
CDh0<4E603E:B`0203I;C00;03eBD`0lDE80=T]<03eBD`0iDE40>e1A045FE`15FeT0CV9Q0396A@0/
@3h00P0cAT801@0Y?3P0=dY603]>BP0fAd40<T<m0080;d0j00h0<D8j03=4?00fAcl0<d@j0352>00b
@cT0=4Hj03E7>`0jCTD0?U9903m@B00`?cP09c@]02Xe;`80<3/e02<0<C`f02dj<`0]?3D0<d8k02`o
=00a@SP0>DXo03I6>`0e@SP0<T0i02Le=@0/>ch0?e5L05Y]OP1QMXT0DFIo05E]Q`1GKHD0@EM]03I=
G@0hCU`0>E1I03aCF`11EEh0@5AM03]?F00jCUL0Df=W04EAC`0[=cD0=40n02Da;`0O:bT0;c/i038n
?003030l>P0:02hj>00`>c`0;SPj02/e=`0Y<c@08bd^02D_<00Z=3<0:38a02D_;@<09C0/0P0T;b/0
2P0S;RX07bPU01hW900P:BH07bDS01hT8P0S9bH08RHU01hR8@0Q9B@4028V9@0C024U900P92<07R8Q
01hR8@0L81l05a/J01PL6`0O8b806b0L028W8`0H71/04QHE01/O7P0H71d08RHW01dQ8`0K7b807B4T
01lS9P0201`P8@0=01PK6P0E5aH05QPG01XK6@0K6aT061PF010?300I61@04A0<01<A300G5Q8051<A
01@D500201DE5@805aLG01<04a<C01dM7@0C4a<06QXJ01`L700K6aT04a<A01HG4`0F5Q@051@B01<C
4P0D51@04a<C01<C500C4aD04Q8D018A5P0B4Q@04Q8C0080410@01L04Q8B01<C4`0B4Q8051@D00h>
3P0E5AD0410@018B4P00000020P:01XJ700B4Q8030`;00`<2P0B4`h03Pl:00l?3@0?3`l03`l@010?
500@41803`d=00l>3002010?3@0300l=3P0>30d03`d@00803`d@0P0?3A800`0?3A003P`=00h<3@03
00h<3@<04@l@00D05A<D010>3`0<2P/03P/=010;3`0300l:3P0>00h93@0A31003@P<00X52@0?2Ph0
3@P<00/62P0?2Ph08ahR01D@50060PD04PdA00h93@0=20`500`72`0[00`62P0?2@d04P`@00l93@0=
1`/03`T=01H@500@2Ph02PD800T31`0;1@T040X>00d72`0?2@d04@/?00d72`0;1@T03`T=010:3P09
0`L0100200d72`0A2`l0510C01`J7`0000@0<S4f0<[9cP3Lfn00BTQ=018=4`0=20h02@@:00h73P0@
2A003@H=01052`0>0`T04@H<01X?5@0F2a40=BX`0146300200l42P8040D;00<03P<900l42P0?10X0
100?10X01P15>T0060lC00`11`0E2Q005``B01<83QCooooo000Kooooo`08010B3@0A4`h0418=00d?
2P0<3PT03Q0;00lA300>40/200`>2@803@l:00`02@/600lA300?4@`030h900h@2`0D5Q403@l:00lA
300>40/030h900h@2`0@4Pd200h?2P0>00l@2`0@4@`0414<014B3@0@4@`030d800h?2P0C50l03a0;
00/<1`0A4Pd04Q<>010A300>3`X200d>2@0L00h?2P0=3PT03Pl:00h?2P0A4Pd05AHA00`<2P0D5180
3`l=00`<2P072@H04A<@010B3`083@T02a0<014F4P0@5Q8041@@018D4@0<3P/03Q0=018D4@0@4Pl0
3Q0=014C400@4Pl03@l<00/=2P803@l<0P0:30T03`0<3P/02`d:00/=2P0>40d020X7000100041P@0
3a4>00`>2`0@4Pl02`d:00d?300A4a002`d:00P:1`0200`>2`0F01DG500?4@h0418?00D7100>40d0
3@l<00/=2P0L7Q/03a4>00d?302Z[:T0BTa900lA3P041P<01`T6010B3`0;3@P03@l:00lA300=3`X0
30h900d?2P<03Q0;00/03@l:00P:1@0;3@P03Ph<00d=2`0<30X04A4?01LG5@0E5A<04A4?00h>3002
00d=2`0300`<2P0@40h03`l=00803`l=00D03Ph<00d=2`0=3@/030`:00h>300300l?3@0300h>3008
20P030`<00803`l?00T02`/:00<30@0B4Q002@X600h?2P0;30L04A8<00d>200=3@/00P0<30X01@0=
3@/030`:00T91`0?3`d02`/90080410>00l03@d;018B400F5a8051D@02//9`0L7AP02P/600`=200@
4@`03@h900`=200=3PT03a0;010A300?40/00P0B4`h0100@4@`03a0;010A300@4@`200l@2`<03Pl:
00L03@h800/<1P0;30H03Pl9018C3@0D5@l030d700803a0:0P0>3`T00`0@4@/04A<>01`N6@0200X<
1`05014C3P0>40/051HA018D3`0A4`h00`0@4Pd0100>40/030h900/=200<3PT300lA300C014C3P0@
4Pd03Q0;00lA300A4`h03Pl:00/<1`0D5A006Q/F01DF4@0@4@`03Pl:00d>2@0<3@P03Pl:010A300E
5a<04aPD00lD400200hC3`0700dB3P0B5a<0KW=_01HK5`0I7QX04QLC00D91P02014B3@804Q<>0P0A
4Pd04@0;30L04A8=01<D3`0:2`H06AXE00`=2P0@4@`05QLB00/<1`0=3PT00@8000P9100>3`X03a0;
01HG4P0A4Pd02@X500803Pl:0P0A4Pd02P0?40/04a@?018C3P092PD05AHA01XK5P0<3@P02P/6014B
3@0?3`d2010@3P804A4?02@04Q8@03Hf=00S8b4051@B010@3P0?3`d051D@00`=1`0B4``03a0:00`<
2P0A4A004a<C00l?4@0E5AL051@D00h>3P0<30X0414<010=200B40/040l;00h=2@0A40d05QHD010@
3P0@4@l05ALF00L9200A51<00@D400d?3P0A4Q805QPG01@F5@0>4Q42010D4`0601TO7@0?5A<07B<Q
09ZSX02[/Jl0720L0P0F61D0400D5Q<04Q@A01DG500V:2D07b4N03i0?@0g>CH04aDB01@F4`0D6A<0
41D?018G4@0G71H04aPB00lD3P0D6A<401HK5@0V01DJ5P0H7Qd08RPX01`R8P0@5QH0318@01<I5`0R
:2@01P`801TO6P0H7aP072<L01@J5@0M8al06b4M018H500A5a<04QPD01<I5@0M8al05A/G01/Q7@0@
5Q809R`X01LM6@0I7a/05A/G01LO6P0L9B006b@O01HP6P0J9Al062<M01<O6@0I9Ql05B8K01DR6P0G
91/201@Q6P1801DR6`0G8al07b/W01dY9@0D81h0BeME018N700G8b<06bTZ01XX:@0L:R/06bTZ01TW
:00Q;c00;C/l02Hd=@0J:2T062HW01XX:@0I9bP07bl^01PX9`0L;bd08cHd01d`;P0L<2l062`]024e
=P0N<c@09CXm02Pm@00]@TH0SZ:Y03A8D@0[?dP07c<l028f?`0V>T40:Ci3014V:`0U>Sl08cPk07>8
R`16Feh0;T5502Xm@00[?d00;D5002a0?P0]@Cl09CTg02Xn?@0[?ch0;T9302m3A@0W>Sh0;45202]1
?`0^A480<DM50397A`0_A4D0Bf1S03U>D@0aATT0=DY?03I;D00eBTd0>Di?03I;C00lDE80?E9C0P0f
Bd`0BP0jCe00?55B049GF00mDU<0=DY;03U>C`0iDE40<dQ903Y?D024VYP0X[Je04YNG@0jCT`0;T4m
03I9A@0aA400<4<o02m2?P0gB480<44k02ho>@0`@C/0<d@l03A5?@0gB400=4Dk03=4>P0b@cT0<T@h
0355>@0fBd80C61G04AHC`0Z>C80:C@^03@o>@0^>C<0;3La030k=@0_?3D0;Sdf0352>P0Y?C@0;Chf
03A5>P0b@SL0<Sle0392>P0U=C809cTk03]=EP17FVT0Aea]04ELM01AJH<0Bf1k03iDJP17GVh0A5YX
03Y@G00kDUX0?U9K03mCG00iCEH0=d]D04aLH00mBDL0:CDc03A0?P0V<S008bl]038n?00c?cd0;c/i
0`0]>CL02@0_>ST0:C<e02@^<00S;Bl08R`]02H`<@0f@3l0;cTh02Ha;@0202D`;00<024/:00T;b/0
9C0/02@_:`0P:BH07RLT01lX9@0S:BL08BLU02DY:00S9bH07B4P0P0N8R401P0Q9B@092PW024U900P
92<08RHU01/O7P806AdL00`07b<R02<W9P0U:BP082DQ028W8`0E6AP04aLF01XN7@0P92D0:Bd^01lS
9@0I7B0201`P8`0301HJ7@0Q9BH07B0O00806Q`K00X06AXH01LG5@0I6AL04A0=01LF4P0A40`05aD@
01XI5@0D4a404a<C0P0D51@201DE5@0300h>3P0G5aL0410@00805aLG0P0E5A<0100F5Q<05QHD01DE
4`0D51<201<C4`0O01<C500C4aD04a<E01<B5`0B4Q@04Q8C010@400C4a<061PH01DE5@0B4Q8051@D
00h>3P0@41004A4A020P800F5QH071/P00/;3@030`<051@C00d>2@0;30L03Pl:00h>300?3`d0410B
010?500A4A<03`d=00l>3002010?3@0300l=3P0>30d03`d@00803`d@0P0?3A800`0?3@l03P`=00h<
3@0300h<3@<04@l@00@06ALH01@B4`0>30d03@X<1@0?2Ph200h93@0;00`72`0?2Ph06QDI01PC5`0=
20`07aXN01<>4P0810L05A0D00X52@0;1PX01P0<1`/02P0?2@d04@/?00l93@0>20`03`T=00`62P0A
2`l030H:01<=4@0A2`l200l93@0300d72`0>20`03PP<00802`D900T0618F00/52@0K5AT04`dA014;
3`0b;C40;R`a01PG701XIf`00P3oo_l0401LFUl04`hD010;4@0:1@/02P<:00`5300=1Pd06A0E0146
300>0`T04@H<00/21P0`9B/04`P>01052`0?10X201052`0300d2200?10X03`@:00@03`@:00<03@88
01052`0C20h00P0700800`0<0@Ooooooooooo`0Booooo`006oooool06@0;3@P03@l:00`>2@0;3@P0
30h900lA300I6aH051HA00`>2@0;3@P03@l:010B3@0C5A003Q0;00d?2P0?4@`0418=00d?2P0?4@`0
418=00lA300=3`X03Q0;010B3@0>3`X00P0?40/2010A300T014B3@0>3`X04A8=014B3@0@4@`03a0;
010A300B4`h02P/600d>2@0B4`h03@h900X;1P0>3`X02@X500h?2P0=3PT02``7010A300C4a40410>
00`<2P0?3`d04A<@00/=2P0=3``02@d:04A9A@0`=3404QPD00lC3`0B51403Q0=00d?300?4@h03Q0=
0P0<3P/01@0=3``03Q0=00h@3@0?4@h03Q0=00803@l<02T030h;00h@3@0?4@h03a4>00L91P0R9240
?T0m00`>2`0=3``03a4>00d?300?4@h04aDB00lA3P0<3P/07AlL018D4@0@4Pl02P`901@F4`0=3``0
4Q@A00/=2P0A4a001@L401DG500N81d08R@Q00D7100?4@h02P`900P:1`0A4a002`d800d?2P0?4@`0
3@l:00`>2@0=3`X0418=00T;1P0200/=200600`>2@0>40/030`:014A3`0>3P`02`/90P0A4@l01P0>
3P`03@d;01HF500J6QP04Q8@00h>30<03`l=00D03Ph<00d=2`0=3@/030`:00h>300300l?3@0D00h>
300>3Ph04a<C00d=3@051@D06QXI03lo?@0>3P`04Q8?00X;1P0D5A00414<00l@2P0;2`T05QHD01PH
5P0@40h02PX800/;2@0A4@l200h>300;010@3P0?3`d02PX800P9100B4`h051D@00l@2`0>3`X030d8
010A300?40/0100>3`X01P0?40/030d800d>2@0@4@`03Pl:00`=20<04A8=00/0414<00h?2P0=3PT0
3Pl900l@2P0@4@/03a0:00h?2@0=3PP03a0:00h?2@0200`=1`0;014B300D5@l04aD@02<U800B50l0
4A<?01LI500F61<061XE01@F4@0@4Pd00P0=3`X01P0A4`h04aD@014C3P0>40/03@l:00h@2`803@l:
00T03a4<010B3@0?4@`0418=01PI500G61<03a0;010A300B4`h00P0?40/04P0@4@`03Pl:00d>2@0@
4@`04a@?010C3P0@5A403a@@010E4@0?5100314=01DJ5P19CTX0724M01<G500?51004QLC010A3080
4A8=0P0B4`h03`0A4Pd061TD01PI500>3`X071dH02l`:`0H6A@05AHC051AC00I6QH05QLB018C3P0@
4@d03Pl:00d>2@0200`=200?00l@2`0C50l04A8=01@E400A4Pd03@h900h?2P0<3@P061TD01XK5P0F
5a80414<01<D3`0D5A003Ph<00803`l=0P0@40h0>00A4@l06ATG014A3`0?3`d03Ph<00d=2`0B4`h0
3Pl7014B2P0C50h061TE01/K6`0@41803`hC01DE5`0E5AD04A4A00l@3@0C50l04a0;01DC3P0B4@`0
3Pd900l?2`0C50l03Ph<014B400?4A006a`N03m2@`17Bd`03Q0?01<E500=3`h06QhM01lS8P0A5A@0
2Q0>01DK6@0>518041TF05eVH`1LHV004aLC00d?300A4a004aDB018D4@0C5A804Q@A01DG500L7Q/0
9RPU020R7`0B51404QLA0P0E6Q@2018G4@0801DJ500C61804QLA01DJ500G71H05AXD01HK5`0?5aL2
018J701P01DN7P0C71/05AhL01HO700=5Q40628K018L500K9Ad072@N01HL600H7QX05A/G01LM6@0H
7QX06AlK00lE4@0J81`05Q`H01LM6@0Q9b<05Q`H01PN6P0G7AT061lK01LP6`0E7QT05AlJ01LR700K
9R0062@N01h[900R;bP062DM01DR6@0J9b008BhW01TV7`0F8Qh05b<O01`X900G8b404AdK01dY9`0M
:BT06BLY01TW:P0K:B`06BLZ01HT9`0M:bh06BLZ01PV:@0I9bX072X]01d[;P0L:bd08c<b01/^;00N
<Bl08cHd01lb<00O<c809CXk03E:B`0W?3d07cLi02U1@`0W?d80@EEL051TK@0_@d`08cM00355CP0Z
?TD0:d1502Ll@@0Y?T<0;T=606MlO`13F5/0<dI<02/n@@0]@D40;T9102Xn?00^@ch0:Chi02i3?`0]
@Cl0;D5202a0@`0U>3`0;T=402i4@P0`AT@0<DI70P0cB4T02@11EUT0?U=G04=HG@10EEX0=daA03Q=
D00dBDT0=Ta:03Q>B`0203I<BP0503Y@C@0gCD/0=4Y703I<B@0iCdd00P0jD4h04@0kDe<0=DY;03M<
C@1JL6h0Jgmn0355A00fBTP0?e9>03M:AP0bAD40?E1<03E8A00jBdD0=4Do0352?00b@cd0=4Dm0080
=TLo0P0gB3h09`0eAS`0<D<g02i2=P0]@ST0=TY103A7?P0^?CH0;CPb02`g<@0[=2l09c8/02dh<P0b
?cP0<40h0312?00^@T00;3hl0392?P0c@Sd0=D@n03I5@00a@D40<495041CG01/PHl0JGnA04YQN@1=
IGl0AUih03aDJ@16GFd0Aei/049II00mDeh0>U5I03aBFP0fBU<0<dMB03M6B`0203I0?`0703<m?00[
=C@0;SPg03@n?@0_>CP0:cDd02Tc<P0202Xd<`0802/d=@0U;Bl082PZ02@/;P0X<380;CHe03Q1@00`
>CP202<^:P0:02D`;00R;BL08bhZ02@_:`0R;BT07RLT01`U8P0M9R<08bTW020V90808RHU00<082@S
02L[:P0S9bH00P0V:RT05`0O8b806alN01`P7`0L81l05a/J01XN7@0Y;B`0;C4`02@X9`0K7ah05a/J
01TM700/<2l07R8Q024U9P0V:Rd07b<V01/O8P0M82D07R4V01XN8@0H71d06ahM00807R0O00X06AXI
018B400G5aD04a8?01XI5@0F5A406QPD01HE4@0J6AL06ATI0P0H61P03@0G5aL05QHF01@D500J6QX0
5ADE01/K6`0H61P06ATG01LG5@0F5a<05QHD01LG5@0F5QD00P0C4a<0600C4a@04a<E01@D5P0D4aP0
51@F01@D5@0G5aL06QXJ01dM7@0G5aL04a<C00d=3@0I6AT061PH010@40092@T06ATJ018A5P0?3a40
5QHF00h>3@0>3`X05aPC00h?2P803`l=00X0410B010?500A4A<03`h;00l>2P0@3`/040l=00l=3P0>
30d03`d>100?3A000`0?3@l03P`=00h<3@0400h<3@0600X82@0<2P/04a4B010>3`0<2P/03@X<100?
2Ph03P0@2`l03`X>01TD600H4aL03`X>02@O8`0R7B403`X>010;3`0>2@d04`hB00l:3P0;1PX03`X>
1@0>2@d200l93@0[010:3P0?2@d03`T=00l93@0;1PT03PP<00l93@0>20`03@L;00h8300B31002P@8
00/52@0A2`l03PP<00l93@0=1`/04P`@02DO8`0910L020<604E0A00W9R/03PlC02`[<02:RHh0V9NL
02TW;0081P/04@lD01dH7P0E41H03@P>00X42P0=10T04@H<01@93`0A1``09a`R07EZL00C20h04@H<
01052`020146300300h32@0?10X03`@:00@03`@:00H040H;01D:400=10P040H;01D:400;0PHDoooo
o`006oooool200lA30803Q0;00D04Q@?01LI500F61<04aD@00lA300200h@2`0>00lA300A4`h03Q0;
00h@2`0?4@`04A<>00lA300@4Pd04A<>00lA300=3`X03Q0;010B3@0@4@`300l@2`@03Pl:01@03a0;
014B3@0@4@`03a0;010A300=3PT04A8=00l@2`0<3@P0414<01@E400B4`h051D@014B3@0=3PT03Pl:
014A3`0F5Q@0?clm00h>30802`d:00l04aDB01LL600P9B405AXF00@:1P0>4Ph0418?014C400>40d0
2`d:00`>2`0=3``02`d:00X<2@0<3P/00P0>40d03@0<3P/03@l<00`>2`082PL03@l<00lA3P0H6QL0
0`D20001000X:RL04A<@01LI5P0:30T00P092`P08`0>40d030h;00`>2`12A4409bTV00d?300B5140
1@L40001000<3P/02P`900/=2P072@H03@l<018D4@0;3@X03a4>01<E4P0B514051HC00H71@0;3@P0
3A0900lB2`0=40T030l800d@2@0;3PL03a8;01XM5P0<3`P03a8;014C3@0=3@/04A4?008030`:00P0
5ADC010@3P0>3P`030`:01PH5P0M7A/04Q8@00d=2`<03`l=00D03Ph<00d=2`0=3@/030`:00h>3003
00l?3@0M00h>300B4Q801`L700`<300C4a<03`l>00T91`0;2`T03a0<014B3@0>3`X030d8010A2`0=
3@/051@B01DE4`0?3`d03@d;010@3P0<30X06a/I014A3`0;2`T04A4?00X:200:2`H0414<00P9100<
3@P00P0@4@`01P0>3`X0414<010A300?40/030d800/<1`80414<00D03a0;00h?2P0?40/04A8=010A
3003014B3@0300l@2`0>3`X03Pl900<03Pl90P0?40X2014B300A010A2`0?40X04A8<01<D3P0>4@`0
00<000X?2@0W;2H08BHP00/@2P0C61803a@>00`A2`0:3`T02a0:00hB300A4`h00P0@4Pd0100?4@`0
3Q0;00`>2@0<3PT200h@2`8030h900<04a@?01DF4@0A4Pd00P0?40/200h?2P0C00l@2`0>3`X04Q<>
01XK5P0P8A`051PC010F4P073@T0:Bl[03Hl>00@5Q801`d900lE4@032@D04QPD020V8P093@X03a4<
00l@2`0200h?2P05010A300B4`h05QLB02PY900K71L00P0=3PT02`0F5a80004002`]:00>3`/02``7
01@E400E5Q404A8=024R7@0M7QT02@X5008030d800`05QLB01PI500E5Q404A8=01<D3`0@4@`04a@?
01@E400@4@`03Pl:014B3@0=3PT3010@3P0A014A3`0B4Q004Q8@01DE4`0C4a405ADC01<C4@0<30X0
3@h9010B1`0B50X04a@>01LH4`0H61T03`hC00h=4P0@3a<00P0A4A40@@0@4@d0414;018?2P0D4P`0
51<>01<B3@0B4Pd04Q<>00`<2P0B4a4030h=010A4`0H6ad00`L8014C4P0>40l02P`;01@H5`0J7Qd0
51PG01@J600Y<Rl09Bh[01LP7@0?61D02a4?014E4@0>40d05ALD01TK600F61D05ALD01dO700K7AX0
3@l<010B3`0Q8b004Q@A018G4@0E6Q@04aPB010E3`0B5a405AXD01XO6@0C61805AXD01HK5@0C6180
51XF01XS9@1aNgd0IW1a00hH6@094a805R4N010K5`0b?CL051lH01`W7`0F8AT04a/E01HL600H7QX0
51XF00804aTE01X03Q@@03@j=P0<4Ph05adI01PN6P0F71P0728N01TO6`0K8Ad05ahJ01DN6@0I8Qd0
6R@O00hI4`0J9Al06bLQ01<P6@0I9Ql05R<K01PU700P;BH0:SL`01dZ8`0I9B407BTU02@`;0806RHT
02/072PV01/W9`0L:Rd06BLZ01XX:`0I9bX05B<V01LU:00M:bh08S0c02Dc=P0P;S4072X]01d/;@0P
<3007c8`01/^;00J;R`07c<a01lc<P0Q=SL0:3dn02Ll?@0[@dD0:D5302]3AP2;WjH0i_[o05IZL`0R
=Sl07S8k028f?@0[@4D0<dQ=02Ll@@0gC4l09CXm02i3AP0bAD/09STm02Tm?00Z?Sd093Te0080:Slh
00L0;d=002a0?P0/@440;T5502Xm@@0_A4D0<4E50080<DI702L0=4U;03I;CP2hcM00HgQl02]0A@0]
@TL0>DiC045FF@0fC4X0=Te803A;A@0bB4D0=4Y603A;A@0nE540>U1<03E<AP0fC4T0=di903I<B@0c
BdX0>Di?04=HF@0eBdT0>De<04IJF@1cQhD083<_03A7@`17FUH0=dY602i1?@0lCDL0>da603Q9@`0c
A3h0=4Dm03M8@00eASh00`0dAC/09P0bA3P0;d<g0398?P0^@ST0;Slg03I4?@0d?cT0:S<^02/b;P0`
>cD0=D0j0390>@0dACd0>Te90354B@0`@TH0=TI903I6AP0iAdL0>dY:02`k?P0gB4l0AeYV03eBH`1;
HGH0DFR104YRO01>IX00A5eb03]EIP10EfL0AEeX03aDGP0kDUX0@UQQ03U=F00dB5<0=TE:0P0e?ch0
1@0_>CP0:38a02Xd<`0_>CP0;3He0080:C<b0P0Z=3<02@0Y<S<092T/024V:@0Z;c80;C8e02`e=00[
=340:34^02<^:P0202@_:@0=024/9P0P:bL082/W01hY9@0L9B807BHS024Z9`0Y;bd09B/Y02DY:00P
92<0720O01lS8P0202DY:00702<W9P0M8B006QhM01LK6P0I7A`05a/J01TM700201hR8@0701TM700I
7ad05Q`J01LM6`0]<c<09R`/01LM7@0301HK7P0801HK7`0G72005a`O01HJ6`0I71/07R0O020R8@0M
7Q`201LG5@0601@D4@0K6QH05aHB01`J5@0A40`05QDC100E5AD09P0D51@06a/K01/K6`0C4a<05aLG
010@400D518061PF01HF4`0F5Q@061PF01LG5P0B4Q804a<C01<C500D51H05ADG01DD6@0E5AL05ADF
01LG5`0F5QH05ADE01@D500E5AD061PH00l?3`0000003`l?02h^;P25QHL0MGAi00D51`0@41005ADD
01TJ5@072080414<0P0?3`d02@0?3a403PdB00h=4P0?3P/03`h:010?2`0@3`d03`h<00h=2`0300l=
3P803`d@00<03`d?00h<3@0>30d00`0>30d01`0?3@h030X;00d;300>30d02PP900/92P0?2`h00P0>
2@d0400?2Ph040/?010;3`0@2`l04@`@010;3`0=20`03`X>00h93@0@2`l01P45014<400?2Ph01P45
01<>4P0?2Ph500d830803`T=00`03PP<00l93@0?2@d03`T=00P21P0:10P0:bDY01lI7@0H4QH02@<7
00l93@0;1@T2010:3P0K00`62P0K5AT03PP<00h8300910L03@L;01LA5@0D3Q8051<H00P93@010PH0
3`hC01LF6`0920d01@<800d;400I51X05A0F00h93`0;1@/05PdB01873@0<0PL05P/A00X11@0=0PP0
4@H<008040D;00<04PL=01<83P0@1@/01P0?10X01P070080EDY@02dR:00E2Q00200301H;4ACooooo
000Kooooo`0J014C3P0?4@`030h900X<1`0=3`X04Q@?00d?2P0>40/03a4<00h@2`0<3PP02P`700T;
1P0<3PT03@l:00/=200>40/04Q@?010B3@0A4`h03a4<00d?2P0>40/0418=014B3@0@4@`200l@2`0;
00h?2P0=3PT03a0;00X;1P0=3PT051D@014B3@0<3@P03Pl:018C3P0D5@l00P0;30L01@0E5Q002@X4
00d>2@0?40X04Q<=00804Q<>01<03Ph;03@d<P1lO7X04Q8@00L91P0J71T0;S0]09^PW01DFED06QlK
00<8100>4@h04A<@01DG500A4a0030h;00h@3@0A4a003@l<00802P`903h030h;00d?300=3``0418?
00lA3P0;3@X0418?018D4@0:30T08R@Q010B3`0>40h01`T601<E4P0>40d02`d:00`>2`0@4Pl03a4>
014C400B51402@/801DG50072@H0;S0]02T[:00620D04A<@00/=2P0J71T02`d:00T;2@0@4Pl030h;
00P:1`0?4@h01`T600h@300;3@P03A0900lB2`0=40T030l800d@2@072P<05QTB02LZ8`0?4P/041<<
018D3P0>3P`03`l=00X:200C4a408B4O01PH5P0E5A<030`:00h>300A4@l02PX8014A3`<03`l=00D0
3Ph<00d=2`0=3@/030`:00h>300300l?3@0300h>300A4A403@d=00804A4A02P03@d<018B400=3@/0
2``801<D3`092PD030d801<D3`0=3PT03@d;00`<2P0;2`T03@d;010@3P0820H092@R01@D4P071`D0
4A4?00d=2`0>3`X03@h900H70P0>3`X02P/600l@2`0=3PT0414<018C3P0@4@`02``700T:1@0<3@P0
4Q<>00l@2`082@@030d8018C3P0?40/04A8=0P0B4`h200l@2`0700h?2@0;30H02``600d>200A4P`0
4a@>010A2`0201<D3P0;014B300@4@/041<<00hA300A5Q005a`F018G4@0?50h0314;010E3`0=4P`0
0P0;40X0100=4P`0310:00/=200<3PT200d?2P8030h900<03Q0;00lA300=3`X00P092`H0100;30L0
30d800h?2P0@4@`201<D3`0f01DF4@0C50l0414<00`=200=3PT0414<00dA300D6AD01P/703m4@01E
FUH061dI00X?2`0B5a<03Q<?00`A3@042@D04QLC00lA3P0?40/03@d:00d=2`0?40/04Q<>00d>2@0J
6aH03@h:00l@2`0>3`X03@h901<D3`0:2`H04A4>010A30041@00414<01DF4@10@C`0BDY401DF4@08
2@<030d700h?2P0A4Pd03a0;00`=200>3`X030d800X;1P0?40/04Q<>010A300B4`h0414<0P0A4@l2
018B40804a<A054051@B01DE4`0I6AL061PF01<C4@0D5A003Pl901<D3@0?40/03Ph<010@4@0>3Q00
4A4C00l?400>3Ph03`l=00d>20092P@03`h9014@300C50l05QDA01DF4@0C50l0410>010A3P0?4@h0
4Q@C02X];00H71/03@l>00X<2`0B51<03A4@00H:2@0830/041HD02dc<@0K924020l=00@:200N9280
3Q4>00`>2`0C5A8061XG018D4@0@4Pl03@l<00h@3@0M7a`03Q0=00lA3P0D5Q<04QLA01<H4P0B5a40
4AH@018G4@0D6A<082DO01DJ500G71H05AXD014F400C6AD04ATJ059JG01>EUP03aPG01HO7P0?6QH0
AU5=09ZUW`0R;BH051lG018M5@0=5@l05adI01/Q7@0I7a/00P0K8Ad05`0N9200Q8f8024W8`0D7AP0
5QlJ014J5@0E71P05adI01XP700F7aX0624L02</9`0S;RP04A`F020[9@0R;bP041dF01DR6`0E8QX0
524H01HS700K:2404QlH00805B4M02/0:3@`01DQ7`0M:BL04AdK020/:`0L9bT05bDV01TW:00K:BX0
62HW01XX:P0G9BP07B/^024_<P0J:2/05R@W01`Z;@0S=CD09STg01la<@0L<2l09CTh02@h>00V>c`0
8CHi02U0@P0dC4h08CTk02@l@011EU/0RinV03Q<D`0Z?TD08cLn02a0A`0Z?d@083Dj02Tn@`0N<cP0
8cPm02Tn@`0`@dL08cLi00809c/j00@08CHb02Pm>00X?CP0;D<o0P0[@Cl00`0_A4H0;T=602m4A`03
0356B@0k03A9C00gC4l0H7Ej04=HG@0lDEH0?U=H0397C00]@TD0>U1>03Q?BP0gCTP0>Dm<03YAC00e
C4H0=4Y703M>B@0dBdD0<dU603M=B@0iCd`0@5UG03E:B`0gC4d0>4i<0355A00bATD0@5AB03Q<BP0j
CdX0<4A003E8AP0hBdL0>Te803e@BP0iC4H0<d@n03A5?`0hBD40=DHn0393>`0`@CL0<D8h0393>@0c
A3X0<4Dl03Q<@`0a@SX0:SP`02hi<`0_>S80:S@_03U4?P0kB440<3li03M8@P15EE@0;d560311B00h
Ad/00P0fATH0:P0gB4T0=4M;03U=EP0oEF@0DVQm05eeS@1>IX80AEak04MON`1;Hg`0@U]_045HJ012
FFD0>E9I03YAF@16Ff<0?51I03E9DP0kBTh0<Cdk02Tc<P0Z=C<08bl]02D_;P0/=cH0:cLe02Xd<`0[
=S@0;3Pf02`f=@0Y<S<082PZ01hV:00W;c40:C4c02H_;P0W<2l09c0]02Ha;P0U<2`08RdY01/V8P80
7RTU00l07BPT01`U8P0O:2D09Rl/01lU8`0N92808BLU028V9@0N92808RLU020T8`0N92807b<R01hR
8@0M8B000P0K7ah0C`0M8B007b<R01dQ800M8B008BDT02<W9P0M8b4041DD01hR8@0Y;bd05a`L01TM
7P0K82406R0P01PL7`0F6Qd05a/L01DI6P0F6AP05aTH01PJ6@0E5QD04A4?01XJ600G5aD06a`G01PG
5@0M71P04a8>01HG4P0G5aD061PF01TI6@0J6QX06QXL01PH6P0G5aT04a<C01TI6@0E5AD071`J01PH
5P0F5Q<05QHD01PH5P0G5aH04Q8B01<C4`0C4a@051@F01DE5`0E51T05ADG01DE5P0D51@04A4A00d=
3@0A4A405QHF00h>3P0J6QX03`l?010@40092@T0IfMW03`l?P0820X0:BTY00l?3@0D5A002``7014B
3@0@40h03`l?00l?4@0>3A803@`A00l=300?3P`00P0@3`d00`0?3P`03Pd;00l=3P0200l=3P803`d@
00<03`d?00h<3@0>30d00`0>30d01`0B4140518C01<A4P0@3Pl02PP900h<3@0B3Q400P0>2@d01`0?
2Ph040/?010;3`0C3Q8030L;00d8300F4AD00P080`L01`0C3Q80100301LB5P0=20`01@0401HA5@0:
1@T01@0<1`/200l93@0^00h8300?2@d040X>010:3P0B3100100201/E6@0400802P@8010:3P0=1`/0
3PP<01H@500?2@d02P@802<M8@0>20`04@/?00`62P0=1`/02@<700d72`040PD01`L900l?4P0A3a@0
40hA014?4`0;2@h02`H:00P320060@L02@@8010:3`0<0`P040L<00h42P0E2Q003P@901893P0A1P`0
3`D:00l62`0B1`d04`T>014630L03`@:00D0@cPn00L00P0?10X05@X@01052`0Dooooo`006oooool0
1P0C5A803a4>00h@3@0A4a004Q@@010B3@<03A0900D03Q4900lB2P0@4`/03A0900hA2P02010C3005
00hA2P0=40T030l800d@2@0>4@X00`0?4P/0300?4@`02`d800`>2@0?4@`02`d801DG4P0@4Pd02P`8
010B3@0?4@`030h900h@2P803a8:01`03a8900lB2P0>4@T03A0700d@200A50`03a8900hA2@0A50`0
4QD=010B3@0B50l04A<>00lA300@4Pd04Q@?04a>B@3=c/X0K6iY01<E400A4`h0418=014C3P072@@0
51HA00l@3@0E5a8030h:0P0=3`X0100?4@`0418=00d?2P0<3PX500d?300500lA3P0@4Pl03a4>00lA
3P0>40d00P0?4@h00`0>40d03@l<00d?300200`>2`0<00h@3@0:30T02P`901<E4P0B51403@l<00X<
20082PD0418=00d?2P0;3@P03Q0;0P0@4Pd02`0?4@`03Q0;00lA300@4Pd03@h901DF4@0?40/02@X5
02<T7`0C50l03Pl:00<03a0;00h03Pl:00d>2@0;2`T03`l=00`<2P0:2PP03`l=00h>300;2`T051@B
010@3P0D51803Ph<00d=2`H03@l<02P0418?00d?300;3@X02`d:00d?300@4Pl03`l=00d=2`0>3P`0
410>00l?3@0<30X03Ph<00`<2`0A4@l02@T7014A3`0F5a<06A/F010B3@0:30L03Pl:010A300=3PT0
3`h:010?2`0G5Q801`@1034^:`0C4Ph03Ph900l@2`0=3PT02``700`=200@4@`04A8=010A300?40/0
3Pl:0P0<3@P02@0J71L03a4<014C3P0<3PT03Q0;00/=200>40/0418=00lA300200/=200300d?2P0>
40/03a4<00803a4<01403Q0;00d?2P0<3PT03Q0;00lA300A4`h04Q@?01<E400D5Q404Q@?010B3@0>
40/030h900/=200>40/03@l:00`>2@0200d?2P0600lA3@0;3@X051HC00`>300<3P/03Q0=0P0<3P/0
400?4@h0418?00d?300<3P/02`d:01DG500A4a003Q0=00`>2`0:30T03Q0=014C400C5A803@l<00h@
3@0?4@h200h?300@00l@3@0?40h0414>010A3P0@4@l03a0>010A3P0A4Q00414?018C400D5Q@0418@
00h@3`0E5aH06A/I01LI5P803a4>00D03a4<00`>2P0A4`h03Q4;00`>2`02010B400;00lA3P0A4a00
2`d8018E3P0G6Q<04aH=00X=1@0=40L03Q4800lB2`0>40/00P0=3`X02`0>40/0418=00T;1P0I6aH0
3@l:00P:1@0Q8ah0<cD`01@F4`0B5140418?00@03a4>00P03@l<01<E4P0;3@X030h;014C4@0@4Q80
418C010B4P80418A02H0418@00lA3@0=40/03A0:010B300A50d0418<00h?3@0D51D051HF018C4P0@
4Q004A<@00/=200>4@/051H@00lA2`0Q8ad03Q4;01<H500R9RD05ATH00`@3`0C5aH051PG010D4`0J
7Qd05a`J00hC4P0E6AP03Q8A018G4`0?51003Q<?01@I5@0>4`l04AHB01<H50803A8>00P05a`H01DJ
5P0=4Ph051TE018G4`0A5Q804aPD01DJ5P805Q/G03/05AXF01@I5@0D6AD05Q/G01PM6@0D6AH061hK
01TN6`0H7AX051XG01LO6P0Q:RD0JG9]028[9P0D7aT0<chh010I500I7a/05A/G018J5@0@6A@05AhI
024Z9@0W<R`0628M01DQ6P0?6aD082`V01HQ6`0C71L05AhI01LP6`0A71H07bXT02Xe;`0H9Ah072XS
01PW800=71D062LP01PV7@0F8QP06RDM01PS6`0I91`07RTS01/V800I91h06RDQ01TT800J9B407BPU
01dY9`0J9RD07b/Z01XV9@0S;bh07BTY01lZ;002020[;@8082/_01X07b`_01d_<@0I;Bd09SXk03]>
D@0Z?T0083Dh02Y0A010F5`09ci302M0A00Z@dP093e102<h>P0V?3/0;45302]0A00Y?T80:Sm402a0
A`0Z?TD0:3a402Lk@`0Y?DH0;41702@g>`80:3`k02@0:Cdl02Ll>P0^A4808cXg02]3@00`BDH0;dU6
02i7A@0]ATL0<dY@03A:E00dBe@0=TeD03YAE`0lE5T0>e9H03M>D`0eCE40>51D03YBEP0iDE<0?EED
03M@C@0dCDX0=e1=03YCD00iDTl0=Tm<03UBC`0fCd`0=e1=03eFD`0lEE80?UAB03]AC`0jD4h303U?
C@1305M]J`0hCT`0;48o03Y@CP0_A4<0=4U703Q=BP0dBD@0=T]603=7@P0`@cd0=4M103A7@00dACd0
<D8j02`m=00`@3H0<d@j03i@B014ED/0<D8h02/l<@0a@SL0:c`a03M8?@0hB440<T8j03I6@P0b@T00
;Shm02lk?P0c@D80=4=20354@@0dB4@0=di;03YBEP0lEUl0@5a]04AQNP1:IX<0EW2D06N0Y`1BJY00
DV^:04=KL`0nE6T0Aei[04iUK00nDeP0A5QL03Y=D00_@d@0=4E302`k=P0^?3L0;C/f02He<00^>cT0
=D=002dl>@0/>CT0:cPh02Tg=`0d@D40=D9202Hc<`0202@a<@0<02Ld=00W<S<0:38c02li>@0V<300
92d]02H^;`0S;2`08BXW01hW8P0L9B007BHQ0P0N9b802@0/=C007bPS01`U800P9b<07RLR01lX8`0S
:RP07RLT028Z9`02024W9@0G01TO7@0G6aX07B4P024S8P0O8B00828Q01lQ800L7Q/06QhJ01dP7@0I
6aP06A`I01lR800M7ad071lM01hQ7`0M7ad061/I01dO7@0M7ah071hM01PJ6@0C5A@00P0E5aH0>00H
6QT06adL01DG5@0E5QD06AXI01DG4`0G6Q4061/B01@F400D5Q<05aTJ018C5`0L7B805aPL01@E600G
61X071hN01dO700P8Ad07AdJ00h>300E5A<05ADD030`<00N7Qh06ATJ01HF600G5aT05A@I01<C5@0B
4Q<04A4A01<C4`0E5AD04a<C010@400A4A40410@01<C4`0E5AD04a<C01<C4P0F5A804Q4?014@3P0B
4@l04@l?010>3P0O7Qh03@/=01HD5`0=2`h030X?018@500A41004@l@0P0@3Pl200l=3P03014?400?
3@h03P`=00803@/<00T030X<01@B5@0<2Pd04a4D00l=400;2@`0JVQ[06=QI00K6A`00P0;2@`0600:
20/03P/>014<400@2`l05Q4E00/62P0910P05a8F00d8300;1PX03`X>00d8300?2Ph04PdA00d8300<
1`/03@P<00h93@0=20`030L;00d8300?2Ph04@`@00l:3PL03@P<1P0<1`/02@0@2P`03PP:00d72@0?
2@/040X<00l92`0>20X030H800d72@0200l92`0900`6200?2P`01`<300d72@0@2Pd03`X<00l:2`0;
1PT030H8008030H900D030H800`62@0=1`/03@L;00d62P0200`52@0>00X4200?1``02`@8014;3`0G
41@02`D801XC5`0D2@d040L901052@0=0`H05P/?00`31@0@1@T400l4200301052Ooooooooooo01;o
oooo000Kooooo`0700lA3P0@4Pl03a4>00d?300>40`04A<>00d@2@0200hA2P0500hA200?4PT03a89
00d@2@0>4@X00P0?4P/00`0>4@X03A09010C3002010C30<04A@=00d03a4<00H80`072@@03a4<00T;
1P0@4Pd051HA02DW8P0=3`X030h9018D3`0;3PL03Q4900803a8900X03Q4800/>1@0:3@@051L>00`?
1P0@4`X020/300X=100G6Q403Q0;0P0?4@`05@0=3`X03Q0;00lA300@4Pd0=3Ha01PJ5@0D5Q40418=
00h@2`0H6QD05ALB00L9100:30L020X501`N6@0@4Pd030h9010B3@0D5Q40418=00`>2P0500d?30@0
3Q0=0P0=3``05@0;3@X03a4>01<E4P0>40d020X700/=2P0>40d02P`900`>2`0A4a003Q0=00d?300@
4Ph051HA00lA30072@@03@l:01@F4@0<3PT03@l:00lA3003010B3@0700l@2`0;30L06Q/F01hO6P0P
8A`0>CXe00h?2P0300l@2`0>00h?2P0=3PT04Q8@018B400<30X02@T700h>300A4@l0=SHd04U9A`0D
51802`/90000000G5aD<00d?300800`<2P0?3`d03`l=00h>300=3@/03Ph<018B400J6QP200d=2`0D
010@3`0A4@l05QPC010B3@0>40/0418=010A300<3@P03@h900l?2P0B4@d03PX701LC40071P8040l;
00d>2@0<3@P03@h900h?2P0=3PT600h?2P0501lQ700<3PT03Q0;014C3P0D5Q400P0<3PT01@0?4@`0
3Q0;00`>2@0;3@P030h900<03@l:01803a4<010B3@0A4`h03@l:00h@2`0?4@`04A<>018D3`0C5A00
418=00d?2P0;3@P02P`700/=200<3PT03Q0;00d?2P0<3PT200d?2P0I00T;1`0210403Q0=01`N6`08
2PL00`D200`>2`0L7Q/01`T600P91`0<3P/01@L401<E4P0B51404A<@01@F4`0C5A803@l<010B3`0B
51404aDB00h@3@0?4@h0418?00d>300200`<2P803@d;00X03Ph<014A3`0B4Q003`l=010@3P0A4@l0
3@d;014C4P092`X0418A0P0F61L05P0k?CX03Q0=01<E4P082PD02@/600`>2@0@4`d02P`900`>3@08
2PT020X700`>2`0Q8ah02Pd600hA2P0>4@P030l6010C2P0B5@/04A@=014C3P0?4@`300d?2P0300/=
200@4Pd0418=00802@/600H06Q`G014C400A4a004A<@010B3`0?4@h200d?300500D710092`P03@l<
00`>2`0<3Pd00`0A4Q@01P0A4a804A<A014C400C5A004A<>010B3@804A@=02H03Q0;018D4`0D5AL0
4a@F014C4P0@4Q004A<@014C3P0>40/04aD@00`?200@4``02`d800hC3`0F6QT03Q8A00`@3`0B5QD0
41@C00lC4P0F6QT051PG00dA400C5aH03A4@01<H500>4`l0314=01<H500>4`l04aPD014F4P0E6QH0
5Q/G01XO6`0H7AT04QLC01<H50804QLC00@04aPD01@I5@0E6QH06AhJ0P0F6aL301PM6@8051TE0P0E
6QH02`0B61@02Q8=010I500K91l06B<M018M5`023@L0620K01TO6`0G7AT0620K008051dH02@05R0K
01<N600?6Q@0520I00TF3`0D8AX06B@N01LP6`0H8A`06R@O01DP6P0L9b40?DU3014N5`0O;RL03ahG
01/Z8`0]?3D09cD/01hZ800N:B406RDM02@_9`0S;RP062<M01`W8@0L9b<06B@P01PS7`0K9R806RHT
01LV8`0N;BX06BPU024`;@0J:2P2028`<@0D024_<00P;S407bd`01h/;`0Q<cD06Bd^01/_<00/?d<0
83<g01ld=`0Q>Cd03RHZ02Y1A`0V?d@093e202a5BP0W?3l0:Cho02a1@P0[@4<202Xo@P809ca100D0
:3a302a0B@0aADh0=DU@03A7B`0202<g>00:02@h>@0S>3T07c@e03UAD@0cBd/0:D5102Do?P0^B4L0
>eEF03=:D0<0=DaD01D0=DaC03A;D@0gCU@0=TiC03Q@E00kDeL0?5AG03YBE00kDe<0=Di;039;B00d
CDX0>U=@03aEDP0fCd`0>eAA03UBC`0jDe00?EIC03UBC`0jD4h00P0kDDl0100lDU00>e5?03Y@CP0g
CD/203E;B@0e03eCD@0eBdT0>Dm=03Q>B`0fBdH0=da70397@P0^@C/0;d8l03U<AP0eASh0;Slg02/l
=00dA3X0>d]103e>AP0oD4H0;d0f02Pj;P0/?S80:3X^03Q:?P0lCDD0<D8j03Q8A@0dA4<0:CTh030k
?@0b@400<d900354@00cB4<0=4a903QAE@0mF640AF5b04YVOP1;JHD0GWVM05efWP1FKY@0AEam03]C
J`10EV/0B5i[03Q?E@0W?440?eAF04iRH`0`@T80;3dk02Th<`0X=c800P0[>SD0:00^?CX0;chk02ln
>`0^?3`0:CLg02Pf=P0W=CH082h^01l^:`0T<c009cHc02He<P0W<c409c4`01XT8`0T;Rd08b`[05iW
IP0[=3<07bPU01dV8@0L9B007BHQ01lX8`0N9b80624L02H_:P0N9b809BhY02</9`0O:2<06R<P02H_
;00K92405adK014G5@0K8Al05a/J01dQ800O8B0201/M700E01TK6P0F61D08B<P01TK600U9b@08bDR
01DG500:30T06Q`I01@F4`0U9b@04aDB020R7`0J71/0:bd/01@F5@0G6AP061XI01hP7`0E5aH061XI
00805QPG01<061XI01<E4P0H6a@05aXC01HH4`0J71/071dP018C600F5a`061TM01LH700G61X06A/J
01`N6`0<3@P051DA01DE4`0J6QP04Q8A00806a/K01805ADF014A4`0>3Q002`X?00T92`0A4A804Q8B
014A4@0?3`l04A4A018B4P0C4a<030`<00l?3`0I6AT051@D00d=2`0C4Pl2010?3@0:018A3`0B4140
4@l@01DC50050`H04Q0C01HD5`0D4QL05Q@G014?4@8040h?0`0?3@h500h<3@0C00l=3`0B41<081hQ
038`<`0O7B002PP;01HD5`0D4QD01085010>4@0H5QT04a4D01@@500I51P05A0D00H21@0F4AD07QTM
010;3`0200X52@803@P<00L03`X>014<400=20`030L;00d8300>2@d03@P<008030L;00D03@P<00h9
3@0=20`030L;00d8300500h93@H030L;00<03PP:00d72@0>20X00P0@2P`01@0=1`T03PP:00`6200:
10H030H800803@L900H040X<01D?4@0F4180100001TC5@0:1@H600d72@<03@L;0`0<1PX03P0;1@T0
1P04014;3`0B31005Q0D05UCE`1ZGf<050/=01hC5`0>0`L030<501L<400>0`L040D90P0A1PX00`0@
1@T03P<7ooooo`0Cooooo`006oooool01`0@4Pl04aDB018D4@0?4@h0418>01@F4@0?4P/00P0@4``3
010C2PH03Q4:0P0=40T400hA2P0?010B3@082PD030h901@F4@0:30L03Q0;01DG4P0U9b803a4<00`>
2@0B50l02P`700d@200=40L03Q4800803a8900<041<:01@G3P0:3@@00`0930<00`0<3`P03@l:00h@
2`0400d?2P0B00/=2@0B50l03@l:014C3P0>40/02@/600<5000B50l03a4<014C3P0T9R40Ce5<01TK
5P0@4Pd030h900d?2P0>40/03Q0<1P0=3``300h@3@8030h;00X02P`900h@3@0C5A804A<@00d?300@
4Pl04A<@00/=2P0<3P/03Q0=0P082PL00`0620H02P`700d?2P0200X<1`0400<50@0:30L02`d800h@
2`<0418=00L02``700H70P0;30L01PL200P9100B4a003Pl:00<03a0;00h03Pl:00d>2@0B4Q004A4?
00d=2`0;2`T03@d;010@3P0N7Q`0;Bd[00P81P0@40h02`/900h>30H03@l<00L030h;00d?300>40d0
3Q0=00d?300<3P/02`/90080410>0P0=3@/0500?3`d00P8004e=B`0l?3X051@B00@40`0W9bD03Q0;
00`>2@0>40/04A<>018D3`0@4@`02``700l?2`0C4Ph06ADB014=2P0>3@T0414<0P0<3@P200l@2`04
00`=200=3PT03@h900h?2P<03a0;00/020X500h@2`0C5A003a4<01LI500E5a803a4<00d?2P0;3@P0
30h900lA3002014C3P0D00h@2`0=3`X030h900d?2P0>40/04Q@?014C3P0@4Pd03a4<00h@2`0=3`X0
3a4<00`>2@0:30L02`d800`>2@0=3`X03Q0;00d?2P0<3PT200d?2P0C010B3P0V:2D01PP500d>3008
2PL00040014C400M7a`07R0M01@F4`0E5a@02P`900T;200B51404A<@01LI5P0D5Q<03@l<014C4002
00lA3P0400h@3@0=3``03@l<00d>2`8030`:00H03@d;00h>300>3P`0410>01<C4@0B4Q0200l?3@0L
00d=2`0B51<03@l>00d?3P082PT02@/:02d_;0041P<05ALD01PJ5@0G6A@03a4<00lA2`0F61D04aDD
00T;2P0:30T05QPE04E7@P0@4``04A@=014D2`0?4PT041<:010C2@0@4``0418=00lA30<03Q0;00L0
4aD@00lA300=3`X04Q@?01DG4P0?4@`03a4>00<04A<@00T03Q0=00`>2`0>40d030h;00h@3@0F61D0
4A<@01<E4P0?4A000P0?4180100?4A003a4?00lA3P0A4`h2010B3@04018E3P0A50d03a4<00lA4080
3a0B01/03a4@014C4@0C5A805QPC014C3P0R91l02Pd600lB2`0D5Q403A8>00lC4P0:3Pd03Q8A018F
5@0?4a803A4@01/O7P0O8b805QXI01<G5P0:3Pd06AhJ01HK5`0C61@05a`H00dB3P0@5A400P0B5a<0
100>4`l04QLC01TN6P0I7QX3018G4`0501<H500D6AD051TE01HK5`0G71P00P0I7QX03P0C61@03Q<?
018G4`0F6aL0724M01/P700A5a<04aXF01<L5`0A6QD04Q`F01LR700D7aT05QhI0P0H7QX04P0L8al0
51dH00dF4@0E7aT04A`F00lJ500G8a`03AXC010M5P0J9Al06B8M01PQ700K9Al05b8L01TT7P0Q;BH0
6BHO01LV7`8052<L00<03A`E01LU700G8aT00P0B7AD01@0E81P06RDO01`W8@0L9b407BPT00806RDQ
00L072PT01XY9P0E92406bXW01d/:@0V=C806BLW00<08Bl`0`0P;S40<P0B92H08cLh01lc=00T=c/0
:ci201`a=00X@4@07CDi02PoA@0B:c007cPm03YCE`0Z?d80:d1102e2@`0/@D@0:d1302Xo@P0V>d00
9ca102Pl@`0[?dP0;d=<0355C00Y?400;T9302@h>@0iCDh0<dQ902Tn?`0O=cL09Cdm0318B00eCdh0
=U1?035;C00`Add0<dYB03I=E@0hCeL0>4mF03M>E00hCeD0>U9G03eEF@0nEUX0?EEH03YBDP0kDe<0
=Tm<0P0bBdP0200gD4d0>eAA03M@C@0lEE80>U=@03]DD@0mEU<0>55>0`0nE5800`0lDU00>4i<03M=
B`0203I<BP0<03Q>C00mDe40>4i<03Q>C00iCd`0>4e803I;AP0aAT40;D0j02`o>@0cAT00<T<k0P0]
?SH0?P0hB3h0?dm503]<A00lCD<0<D8h02Li;@0U=b/08C<W02m1=@0iBT80<44i03];B00fATD09SHe
02dh>@0/>SX0;Sdj02e0?00_@Sh0<4Q503E?D00lEeh0B6=c055]P`1HLi00HGfO04iXS@1BJXh0@eai
03UBJ00hCf40?UAQ04UPIP17G640=DY<03Y>C`0Y>c/0<D8o02dl=`0Z>C@0;C`g030o>P0`?c`0;C`i
02ln>`0^?3`09cDe02Xh>00U<c@072XZ028a;P0Y>3D0:cXg02Dd<@0U<Bl0=d5001HP7`0`>ST0KWMf
0:Zc/P0U;R`07RLT0P0L9B009P0M9R407RLR01hW8P0X<B`0>D8m01`U800Q:RD08b`W01lX8`0O:2D0
;cPe01@M6P0b>3H09bd[01LM6`0J7Qd07b<R024S8P0M7ah07R0O01dO7P0H6QL08B<P01LI5P0];b`0
8B<P01lQ7P0Q8b006adJ01TK600Q8b0071hK01hP7@0J71/0;S0_00d?3P0H6QT06A/J0`0J71/04P0G
6AP05QPG01HH5`0E5a@05QPE01HH500H6QT08B8T02DV:P0I6Ql05AHK01XK7`0J6ad05QLI01DG5@0H
6QL03a0;01DF4P805QHD00@04A4@018B4P0E5AD04a<D0P0A4A<04`0A41D0410B018B4`0D51@04A4A
00h>3P0A4A405ADE014A4@0G5aL04a<C00h>3P0@41004A4?018A3P0?3P`040l=018A3`0B41400P0A
3a001`01008030X=014?4P0;2@h01`D8010>400@3Pl00P0?3@h200h<3@0I00d;300>30d03P`=00l=
3P0>30d030X<03<a=01QGf80BDM:00X82`0>30l06QPK014?4P0@3Q403P`?00`:3@0610L01`@700H1
1@0C3Q8040/?00@00`0A31003`X>00/62P0200X52@0700T4200:1@T03@P<00d8300<1`/03@P<00h9
3@0200d8300400h93@0?2Ph03`X>00l:3PD03PT=0P0=20`600`72`803`T;01004@/=01@>400C3@l0
3`T;00h82P0<1PP02P@600/51`0=1`T030H800T31@0B30h03@L900@000090`D02@@51P0>20X600d7
2`0900T31`0<1PX04P`@00l93@0<1`X0>38f02TN8P0<0`D01`00008040D900<03`@801052@0B1`/0
0P0E2Ph00`0B1`/040D9ooooo`0Cooooo`006oooool03@0@4Pl04Q@A014C400>40d03a4=01<E400=
40T03Q4:00lB2`0?4PT03A0700/>1@0?4P/0100>4@X00`0?4P/03Q4:00hA2P0400d@2@09018D3`0?
4@`051HA01XL5`0<3PT03Q0;01<E400@4Pd04Q@?00803Q0;00h02`d800lB2`0=40T03A09014D3@0F
6A8061/D010C300?4P/020/401/N5`0O8Q/030l800h@2`8030h900T03Q0;00d?2P0<3PT04A<>00lA
300D5Q40418=00h@2`0=3`X00P0<3PT01`0@4Ph04A<>00<40@0J71L051HA01PJ5@0C5A000P0<3PT0
0`0>40`03@l<00d?300400d?300600h@3@0?4@h03a4>00h@3@0<3P/03@l<0P0?4@h0100>40d030h;
00d?300>40d200/=2P0F00h@3@0=3``03a4>014C3`0B50l02P`801LI500=3`X0418=00X<1`0<3PT0
3Q0;00lA300@4Pd03a4<00d>2@0A4Pd03Pl:00T:1@0N7aX03Pl;00h?2P<03a0;00X03Pl:00d>2@0>
3P`030`:00h>300?3`d03@d;00h>300?3`d04a<A0P0?3`d00`0B4Q002`/900d?300500d?300E00/=
2P0=3``03a4>00lA3P0=3``02`d:00`<2P0?3`d0410>00h>300=3@/03`l=00h>300D51801PH500h>
300A4@l02``;00`>2@0:3`T02a0:00803Q0;00P030h900l@2`0A4@`04a8>01PG4`0<2`L051<?010A
30803Pl:0P0@4@`300d>2@0500h?2P0?40/0414<010A300D5Q400P0@4Pd0400?4@`05ALB00/=200<
3PT04A<>01HH4`0G6A@04A<>00d?2P0@4Pd03Q0;00d?2P0>40/03a4<010B3@0?4@`500h@2`0300lA
300>40/03Q0;00803Q0;00@03a4<00h@2`0=3`X030h90P0=3`X04`0O8Ad0<38_00/=2P0I6aT0418?
01DG500l?S/07b4N00X<2@0<3P/020X701PJ5`0<3P/03a4>00d?300A4a0030h;00T;200D5Q<00P0?
4@h0100A4a003a4>00h@3@0?40h200l?3@80410>01004A4?00d=2`0@40h04Q8@00`<2P0>3P`03`l=
00H81`0?4A004Q@C00h@3`0A4a80418?01LI5P0@4Pl03a4<0P0=3`X0400@4``02`d900lA3P0@4Pl0
3@l<00T;200J71P04A@=00hA2P0?4P/041<:00lB2@0=40P03Q0:00h@2`0@4Pd3014C3P07010B3@0L
7QT05aTD00d?2P0B50l02P`700h@3@03010B3`0800lA3P0=3``030h;00h@3@0A4a008bDR01DG500A
4a04010B4@09010B400@4Pl03@l<00d?2`0@4Pd04aD@01<E3`0@4Pd04Q@A00804A<B00h04Q@C018D
4P0A4a003@l<01@F4P0m?cX051HA01LJ500C5A004AHB00hB4@0;3`h04ADD01<G5P804ADD00D05a/J
01dQ800E6AP051PG00hB4@0301DJ5P0;01XO6`0>4`l03a@@00lD400C61@041DA018G4`0F6aL05AXF
018G4`0C61@0100D6AD07P0C61@04AHB014F4P0C61@061dI01XO6`0H7AT04QLC01HK5`0G71P04QPD
01DM600A6QD07bPS03Q2?@0E81X041/E01@L5`0H7QX04QPD01PO6`0I8Qd05AhI01hX8P0A71H04ahH
01HR700J9b004b0I01XU7`806B8M02h06R@N01LR700G8Q`05B4J020]9P0B8AX062LP03E4?@23TX/0
BEM>01XW7@0I9Qd0;c`c01LT6`0A7QL07BXS01XW800L:2@06bLS01`X900P;2P093<`01TX9@0L:bP0
9C@a0350?@0N;2`07B//01h/;@0O;Bh08Blb028`<`0S<C@07Bla02Di>P0Q=CH09STm02Pk?`0S>3/0
7cLk02a4B00R>Cl0:dA905M`M@1[Q8T0:3e00P0W?3d202Pm@00802Ll?`0Y?T<0:Ci302Pm@P0V>d40
9SY002Dj@00Y?44202e0A00<05]^LP12EUT0;T=6059ZK00mEEL0;TI8035;C00dCTl0;TM;0358CP0c
BU80=DaD0P0fCE<03`0eC580=dmC03YBEP0kDeL0>U9D03I>D00cBd/0>E9@03M@C@0cC4T0<T]803E>
B`0hDDh0=Tm<03]DD@0203UBC`0N03aEDP0hDDh0?E=A03iDDP0oEE<0?UAB03aBD00kDDl0?eEC03M=
B`0iCdd0?59@049HEP0lDU00>U1=03Q=B00dBD@0<4E002i1>`0[?SP0;d8l0393>`0`@CT0;Slg0392
>00gAcd0>T]303Y;@@0gB3h0<48f0P0[?C407`0]?c<0=TLo03E6?P12DTl0?4a;02lo?P0^>cX0:cTh
02dm>@0^@C/0;d8n03A:A`0kE5H0?eUP04QRL01BKH40FWF>05igUP1@JHX0@U]k045JM00nF6X0@EQW
03mGH00_ATX0=TY=02i1@P0mCe40;d5103E5@`0`?cX00P0^?CP01@0c@Sd0<D0m030o?00d@d00;cdm
00809C<c00L08c4b01d/:`0S<Rl0:STf02hm>P0Z>CH0:cLe00809c4`00L08B/Z01/T8`0]=SD07bPV
020Y9@0O:2<082TT00808b`W03l08R/V03<l=`0j@ch07BHQ02H_:P0W<2/07BHQ024Z9`0N9b@072DR
02/a;`0U:bT07B<Q01PL6`0M8B00828Q01dO7P0P8R408B<R01`N6`0Q8b007AlL01hP7@0?4@h0BD]8
06]]JP0N81d061XG018D4@0`<Rl04Q@A01@F5@0O8B0020X901XL6`0M7ah05aTH028T8`0L7Qd06A/J
01LI600E5aH061XI01<E5P0C51H04a@H01XK7`0M7R@04Q8I01TJ7`0K72006AXL01DG5`0B51804Q@A
01HG4P0D514051@B010@3P0G5aH05ADE018B4P0C4a@00P0B4Q@03`0D4aP05ADG01DE5P0E5AD051@D
014A4@0B4Q8051@D014A4@0D51@04A4A01PH600K6a/05ADC018A3P0200l>300:018A3`0B41404@l@
01lM7P0B41<05aDH01hL7`0E4aP03P`?010>40<03`d>0`0>30d02`0?3@h040h?010>3`0>30d04@lA
018@4`0=2`h03P`?00d;3P0;2@`03@/>00804Q0C00L02`T<00l=400B41<0AT=6034/<00:1PT04`hB
008030L;0`0@2`l02P0?2Ph04PdA018=4@0?2Ph03@P<00`72`0=20`03PT=00d8300<1`/800d83080
30L;00<02`H:00`72`0<1`/0100<1`/200h82P0500l92`0A2`d04@/=00d72@0>20X00P0<1PP200h8
2P8030H800D04P`>00`7200V828020<400l92`0600h82PH03@L;00h02086014;3`090`L03`T=00l:
3@0=1`/04`X<01P>4@0:0@<06A0B01D:3P0>1@L03`@801462P804`P<00<04@H:00l42?ooool04ooo
ool001_ooooo00h04A<@00h@3@0=3``03a4>010B3P0?4@`030l800hA2P0?4P/03a8900`?1P0930<0
3a8;00hA2P803A0900@03Q4:00lB2`0@4``041<<0P0?4P/200hA2P0@00d?2P0;3@P03@l:010B3@06
20<03@l:00lA300:30L02`d800`>2@0>40/0418=00hA2P0?4P/041<<014D3@804QD>00L03A09018E
3P0?4P/06ahG01lR6`0D5a003Q0;008030h901D0418=00h@2`0<3PT030h90084000C5A0030h900lA
300>40/08B<N01PJ5@0>40/020X5010B3@082PD02`d801<E400E5a803a4<00`>2@0<3PX01P0=3``0
5`0>40d0418?014C400?4@h03@l<00/=2P0>40d03a4>00/=2P092`P03a4>01DG500<3P/020X700`>
2`0=3``03Q0=00`>2P0A4`h0:R`W05YLE`0Z;2L03Q0;00D03@l:00P03Q0;01XK5P0D5A0051D@00/<
1`0=3PT02P/600h?2P<03a0;00`03Pl:00d>2@0>40d02P`900`>2`0?4@h03@l<018D4@0?4@h0418?
00`>2`0J71T800d?300900`>2`0=3``03Q0=00h@3@0=3``030h;00h>300=3@/03Ph<00803`l=0100
30`:00d=2`092@L03Ph<00l?3@0@40h010H300lA300=4P`0314;00X?2@0:3PP02`d8014C3P0?4@`0
3a0;0P0=30P01@0C4Ph03@h9010A300A4Pd0414<00L03Pl:01003a0;018D3`072@@01PP300lA300F
61<020X500d?2P0E5a8071hI01lQ700E5a803Q0;00`>2@0=3`X03Q0;0`0?4@`200X<1`0=00/=200=
3`X03Q0;00h@2`0?4@`0418=014C3P0@4Pd03@l:00/=200>40/03@l:00`>2@0200d?2P0I018D4007
2@H061XG07j0O@0];b`03a4>02LY9P051`@0004001<E4P0:30T04A<@00d?300A4a003a4>014C400;
3@X04Q@A01lQ7P0@4Pl03Q0=01<E4P0A4a003a4>010A3`02010@3P<04A4?02004a<A01LG5@0C4a40
3`l=01TI5`0@40h06Q`K018D4`072@P01@L600L9200=3``02P`9018D4@19BdH0:B/V01HH4`0D5a00
4Q@?01DG4P0A4`h03a4<018D3`0E5a803Q0;00T;1P0<3`P04QD>00hA2P0=40T03Q0;00lA30<04A<>
00T0418=014C3P0P8Qd07R0K00d?2P0:30L04A<>00lA3P0>40d00P0=3``200lA3P0600h@3@0:30T0
7AlL04a>B`0`<Rl02@/81P0A4a001`0>40d03a4>018D4@0D5Q404aD@00lA300A4a000P0?4@h0300A
4a003a4>00X<2@0B51403Q0=01HH5@072@@04A<>018D3`0D6AD03a<B00hB4@<04ADD00L04QHE00lC
4P0E6AP03a<B018F5@0@51<041DA00803A8>00@051TE00hC3`0B5a<03Q<?0P0C61@01`0E6QH04aPD
00hC3`0B5a<04aPD01@I5@0E6QH00P0C61@01`0H7AT06QlK01PM6@0F6aL07b@P02L/:00/<Bd00P0F
6aL0<P0C61@03aDA01DL600F7aX05AhI03Y4?P0E81X03QTC010H4`0D6QH05Q`H02D]:00Q:RD04Q/F
01@N6@0D7aT08RdW01HR6`0M:R<04QlH01PS7@0J8ah06b@O01TS7@0H8ad06RDO01LS7@0=6Q<052<L
01h]9P1@GeP0_Lc506akL@0U<RP09S<Z05MTF`12CdH082dV01PU7P0L:B807BTU01/W8`0L:2@07b/W
020_;00H:2D072`Y01l_;00[>cP0830_0P0N;Rh04@0P<3008C0c028a=00S<SD05RPZ01X^;`0/@440
?4mC02Pk?`0O=3L08SXn01P`=00Y@4H07cPm01Tb=`0Z@dP0:3e000809S/l00<0:Ci102]0@`0Y?T40
0`0Y?T402P0X?D009ca002Dj?`0Y?480:Se302e0AP1OLWP0YKVo03Q=DP0dC5020359C@0303=<D00a
BTh0:dA800<0=DaB01D0=TeC03Q?E00iDED0=4a@03Q@D`0hD580=De?03=;C00dC4`0<4U603A=BP0e
CT/0<da903E>B`0iDTl0=4e:03M@C@0eCT/0=Tm<03]DD@0jDe000P0lDU006@0mDe40?UAB041FE011
EeD0>e5?03aBD00nE580=de;04AJF00nE580>U1=03M<A`0_A3l0;T<n0313?@0]@3X0;d8l03=4?00a
@SX0;3de02hn=00a@CL0@55903M8?P0fAcd00P0`@SH07`0gBCd0B5Y>03e>AP0kC4@0?dm<03E5A00c
@d80<T4n02dl>@0`@3X0<TDo03=6@P0gC4X0?EEG041IGP12GFP0Af5b04]TN01LMXl0PI^f04aTOP14
Fg40>4mO04UOK00cBDl0Fg1c09nc]012EED0=DM703a<C00]?C/00P0`?cX05@0_?ST0=TE003I5@P0c
@Sl0<D0m02hl?00W=CD07R`/020^;`0T<c408c8]02Dd;`0[>SD0;C`g02`h=00U<2`0:SDa020[9`0C
71T07bPU02</:@0201`U800701hW8P0Q:RD08R/V01lX8`0G81/051dH01PQ700202@]:00N024Z9@0I
8Ql0:C8_024Z9`2AUiD0NX1n01TO7@0I7A`07B4P01hP7`0J71/07AlN01lQ800R924061XG01/M6P0U
9b@07AlL01lQ7P0Q8b004Q@A024S800=3``061XG018D4@0E5aH05aTH01HH5`0L7Qd0828Q0P0K7A`0
7P0I6aX07AlN01`N7@0F61L061TK01TJ7`0I6B405ADM01HF7P0H6Al04Q<H01XK800G61`05AHH01DG
5P0D5Q@04A<@01hO6P0F5a<05ADC00d=2`0P81l071`L01LG5`0I6AX05aLI01DE5`0F5AX061PJ01DE
5P<04a<C00T0410@00h>3P0B4Q80410@00h>3P0M7Ad07QhN014A3`0C4Pl00P0?3P`02`0@3`d03`d>
00h<3@0E4a@03@/>00l=400G5AP04Q0E00h<3`0?3@l03`d>00803P`=0P0=2``01P0?3@h040h?014?
400?3@h030X;00h<3P802PP;01<03`d@014?4P0=2`h02@L:00h<3`091`X020H9018@4`0F51L04@hA
01hI7@0F4AD0100301D@500D3a<020<700`72`0>2@d030L;00804@`@00L03PT=00d8300<1`/03@P<
00h93@0=20`030L;00802`H:00L02PD900/62P0;1PX03PT=00l:3P0>2@d030L;00802`H:1P0<1`/0
1P0=1`T02`D700/51`0<1PP03@L900/51`803@L900@03`T;018<3P0A2`d030H80P090`D0100<1`P0
6A<E02/U9`0;1PL600d72@0400X4200;1@T02`D900`62P803@L;00@02`D900l93@0400802@<70P0:
10P01P0800403`@8024F6P0=0PH0MV]_04@i?@803P<70P0?10P200h31aCooooo000Kooooo`0>01@F
4`0@4Pl03a4>018D4@0C5A40418=00lB2`0A50d04aH?018E300?4PT030l6010C300>4@X200`?2004
00hA2P0@4``03a8;00lB2`803Q4:01D03A0900`?200C5A00418=00h@2`0@4Pd02P`701DG4P0>40/0
418=00D70P092`L0418=01<E400=40T04A@=01<F3`0B5@h03A0900X=1P0<3`P00P0?4P/03@0=40T0
3Q4:010C300?4@`030h900d?2P0@4Pd03a4<00`>2@0=3`X010H101TK5P051`<00P0=3`X01`082PD0
0`D001LI500210005QPC010B3@0>40/00`0<3PT00`0=3`X03@l;00d?300400d?300U00h@3@0?4@h0
4A<@018D4@0@4Pl03@l<00T;200=3``04Q@A00d?300<3P/06A/H02@V8`0G6AH03a4>014C400@4Pl0
3@l<00lA3@082PD02P/803Pj=@0>40/04A<>00lA300>40/030h900/=200<3PT03Q0;014B3@010P00
3a0;00/<1`000@005AHA00h?2P0300l@2`0300h?2P0=3PT04A<@00802`d:0P0>40d01`0F61D0OGml
05iPG@0?4@h061XG00840@0>40d0300=3``00`0?3`d03@d;00d=2`02010@3P0900/;2@0?3`d03Ph<
01@D4P030`402PX801HH5@0;40X0314;00802a0:00<03A4;014C3P0@4Pd00P0>3`X02@081`<04Q4=
01LF4P0;30L04A8=018C3P0?40/03Pl:010A300600h?2P0500`>2@0E5a804aD@00h@2`0D5Q400P0;
3@P010092`H030h9018D3`0A4`h200lA3080418=00@03a4<00`>2@0:30L030h90`0;3@P200X<1`09
00h@2`0A4`h04Q@?010B3@0;3@P02@/600h@2`0=3`X030h900803@l:00`02P`8018D4@031@80;2h[
00d?300E5a@03Q0=010B3`0C5A80418?00lA3P0B514200d?300<00`>2`0>40d020X701<E4P0R9240
3@l<00/=2P0A4a003Q0=00`>2`0?40d03`l=0P0@40h3014A3`0[010@3P0<30X05QHD02l_;@0S8b40
61XI00/=300?4A005ALF00`>3@0B51408bDR00P:1`0S9B000P@000@60@0E614020X500d?2P0?4@`0
4A<>01DG4P0<3PT04aD@00d?2P0?4P/051L@00lB2`0<3`P0418=014C3P0B50l04A<>010B3@0>40/0
4aD@014C3P0>40/0418=00/=200?4@`03a4>00h@3@0200`>2`0800h@3@0@4Pl02@/801<E4P092`P0
6Q`I00T;200F61D600lA3P804Q@A00@051HC01DG4P0C5A003Q0;0P0A4a00300D5Q<05aTF01HH5@0A
4a003a4>014C400>40d05aTD018D3`072@H05ATH010D4`<03a<B00`04ADD00hB4@0A5A@06QhM01<G
5P0@51<02`l>01@I5@0=4Ph02@h:010E4@0=4Ph2018G4`0m00hC3`0:3`/03a@@01<H500@5A404AHB
01<H500D6AD05AXF01<H500B5a<04aPD020U8@0O92005AXF01<H500G71P06QlK00dB3P0D6AD05Q/G
01<I5@0B6QD0624L018K5P0F81/02QD?01`W8@0D7AP06b4M01<I5@0J8Qd06B8M00lH4`0D7QP072LQ
034l=P0I9Ah06bPQ00hK500F8A/06b@O01dV8@0I8ah062<M01`W8@0L:28072TR01d/9@0@7aP07RdV
041?B00W=R`05b@J01dZ8@0V<bX03a`C018O600S<2T07R/T01hZ9P0201/W8`0801`Z9@0G9b@05BDR
01XZ9`0F9R<08C4^01d];00Q<C42028b<P808S4d00L08S<e024c=@0X?3d083@e02<f>P0X>cl0;D95
008083Pl00X09ci4018[<00iDUL073Di02@i?00Q=SL083Df02Dj?@0W?3l09S/n0P0X?D00400Z?d80
:d1302]0@`0[@4<0;d9802Pk@@10DeT0<TE;082DVP0]@TL0:d=702i6BP0_Ad/0;TM;039;C`0hDED2
03M>E00<03Q?E@0kDUP0@EQM04ALH00eCE40>E5C03YBE00gCe40=dm@03YBDP0[A440<DY70P0eCT/0
1P0gD4d0>eAA03=<B@0fCd`0<da903A=BP80>eAA00@0@EME03iDDP0mDe40?E=A0P0nE580200gCD/0
@EME04AJF00cBDL0?eEC03U?C@0jD4d0=T]60P0]@Sd0@`0bACl0;d8l02i1>`0a@SX0;d0h02dn=P0b
@SP0=THl04MHD00eAS`0<44g02Tk;`0Z?300=4Hj041BAP0]?SH0;Slg03I6@`0b@T40>4Q70391?P0]
?3L0<40j03A5?`0cAT80=DU703]@D`0nEE/0@UYU045KJP15G6h0B65g07bF[@10F700@5QZ03E=F@1A
J700?59G03A9BP1/P840<DA403E7A`0oCdl0;C`j0350>`0c@Sd0<T4l03Y9A00lBdP0<d8o02Th=@0Z
>3P0:CLg01h/;00R<340;3Xi02He<00U=2l0:3Lb02Xi=00X=300;CPd02Pc;`0P:bL07RLT03Q1?P0N
9b@00P0O:2<02`0R:bH09BhY02H_:P0S;2L09BhY01XS7P0Q:RD07bPS01XS7P0O:2<06B8O00807RLT
0140=C/i02P^;00Q9bD0720O020T8`0P8R406adL01dO7P0N81l07AlL01/M6P0N81d061XG01dO700K
7AX05aTF01@F4`0201LI5P0@01@F4`0H6QL051HE01<E500I6aX04aDD01DG5P0B51<051HE01DG5P0O
8B00828Q01LI600F5aT05QHN01TI8`8051@L02L06AXO01HG6`0I6Qh051DG01<E500E5aH05QPF01<E
4P0E5Q404Q<?01LG5@0<30X061PG00T92@0@410051@E01<C5@0@41804a8G01HF600C4a@0410@018B
4P0D51@03`l?00X:2P0A4A406QXJ014A4@0@410051@D010@3P0D4a0040l=00l>300@3`d03P`=00d;
300C4A800P0=2`h01@0E4aH040hC00l=400?3@l03`d>00803P`=0P0=2``0200?3@h040h?014?400?
3@h02`T:00d;3@071@P03`d@0P0;2@`03P0G5AP03P`?00`:3@0;2@`04@lB010>4@071@P02PL:01<>
4P0;1PX05A0D00h93@0300803`X>0P0@2`l0200<1`/03`X>00h93@0<1`/03@P<00`72`0=20`03PT=
100=20`00`0<1`/03@P<00d83002010;3`0300l:3P0>2@d03@P<00L030L;00@03`T;00d72@0;1@L0
3@L90P0>20X0300<1PP03@L9018<3P0D3Q004P`>00`6200@2P`0100001D?4@1FD580Y9jP01/E5`H0
3@L900@02@<700X4200;1@T02`D90P0<1PX03P0:10P040X>00l93@0@2Ph02@<701XD600?10P04`X<
00L0000O51P0:R4S020E6@0A1PX040D90P0?10P00`0@1@T04@H:ooooo`0Cooooo`006oooool01P0A
4a003a4>00X<2@0<3P`04A<?00h@2`803a8;01403Q4:00d@1`0<3`H02`h500T<1@0@4``03A0900/>
1`0=40T030l8010C300:3@H041<<018E3P0<3`P03A0900h@2`02014C3P0700lA300>40/03a4<014C
3P0@4Pd03a4<010B3@02014C3P0D00/=200=3`X04Q@?00lA300;3@P0418=014C3P0:30L04Q@?018D
400E5a803@l:01<E400K7AP051HA00h@2`0?4@`03Q0;00d?2P0;3@P200lA3008010B3@0G6A@03Q0;
00T:1`0=3`X03Q0;00`>2@0>40/2014C3P0A00`>2@0>40/02P`700lA3P0C5A8030h;00lA3P0:30T0
3a4>010B3`0/;R/0?T0m014B400E5a@0418?00`>2`0A4a000P0<3P/01@0H6QL03@l<024S800I6aP0
4Q@A008030h;00l03@l<014C3`092`H0418=00d?2P0A4`h03@l:00lA300@4Pd05ALB01@F4@0>40/0
30h9010A300>3`X00P0@4@`0100;30L03@h900`=200<3@P200d>2@803Pl:00/02P`901HH5@092`P0
5ALD00@61012A440h^CQ055CD00?4@h01`P601DG500200lA3P0;00/=2P0>40d03a4>00lA3P0=3``0
3a4>00X<2@0?4@h02`d:00lA3P092`P00P0@40h200l?3@80410>018030`:00l?3@0>3P`03@d;00h>
300A4a003A8<06M^I`0F7AH02Pl901@I500=4P`0418=00lA300>40/03a0;00h?2P0=3PT2014B3@05
010A300?40/03Pl:00`=200=3PT00P0:2`H00`0=3PT03a0;014B3@0200d?2P0600h@2`0?4@`0418=
010B3@0>40/03a4<100@4Pd200`>2@0<014C3P0@4Pd06A/F02X/9`0A4`h030h9014C3P0?4@`05ALB
00X<1`0@4Pd03a4<100=3`X00`0C5A005ALB00h@2`0200lA300<00/=2@0<3P/03Q0=014C400?4@h0
3Q0=00d?300A4a00;c4^014C400@4Pl03Q0=0`0?4@h0100:30T020X700h@3@0A4a0500h@3@0700h?
300>3P`0410>014A3`0@40h03Ph<00l?3@02010@3P03014A3`0B4Q004Q8@0080418A01T03Q0?018D
4`0O8B00418@01@F4`0=3``03Q0;01XL5`0I6aH041<<00hA2P0=40T04QD>01<F3`0B5@h04A<>01HH
4`0C5A004A<>00X<1`0I6aH0:bdX010B3@0B50l04A<>00803@l:00T0418=014C3P0:30L04A<>01@F
4@0F61<03Q0;00`>2`0>40d0100?4@h4010B3`0300h@3@0=3``03a4<00804aD@0P0A4a00400C5A80
3a4>01@F4`0E5a@04aDB010B3`0?4@h05ALB010B3@0E5a804Q@A01<E4P0;3@X04aDB01@F4`0C5A82
01@F4`09014C400@51<04aLF00hB4@0@51<04aLF010D4`0A5A@0310?00804ADD00D030l>014E500B
5a<03A8>00`A3@02018G4`0<01`Q7@0=4Ph05Q/G01@I5@0F6aL03a@@02H[9`0F6aL051TE00dB3P0J
7a/01``80P0G71P201DJ5P0901PM6@0E6QH04AHB01<H500D6AD061dI01LL600D6QH05AdH00804Q/F
00L04Q`F018M5`0C7QP0624L01`R7P0K8Ad06B0L00805QlJ00L0628L02lj=00nBD<0:CD^01<P6@0G
91d07RTS00809BhY01405b4L01XU7`0U<2X08RhW01XW800K:R<06BPQ01LV7`0M;2D08C4W01XZ7`0H
:1h072`R01/[8@0I:2406bXS01d/9@0201d/9`8072/V01H05bLT024a;P0J:RL07BdZ01h^:`0U=C@0
72`/02<c<`0M;Bd09C@g02Th>`0R<cD093Li01X^;`0Y?Ch083<g04MJGP10EEP09Si203E=D@0dBe40
9Ci30P0[A4T01`0V>cl09CXm02Hk?P0X?Ch09c`m02Dj>`0Z?d000P0W?3d202Xo@00702Ll?P0[?T<0
;T5702/nA00^@DL0<dM<02]0A@020318C00A0359C@0aBTh0=4eA03I?D`0bBDl0>U5G02m6C00oEe/0
=dmC03aDE`0gCe40>E5B03UAD@0hD500=dm?03E=C@0dCDX00P0_B4D01@0eCT/0>U=@03QACP0lEE80
>E9?0080=e1=04`0?5EB03mHE@0mDe40?UAB03mED`10EU@0@EME04=IE`0kDDl0?59@03Q>C00oEE<0
@5ID03M=B`0iCd`0=4U40356@@0`AD00=4M103I9@`0/?cT09cP`02Xk<`0/?CD0;Shd0351=`0fAcl0
=DHl03=4>P0`@SH0;d4e0312=P0bA3P0<T<k02dn=P0hB4D0=dM60351?`0nCDT0>da603A5?`0^?cT0
9STe03iAD01;H680=DY?049GH012FF@0@UQU04]RL`11FVd0@U]]04IOK013G6@0>e9G0397BP0hC4d0
;Cm00352@P1?Gel0>4M:0391@00d@ch0<d8m03E4?`0fAD00=4=00350?@0[>SL09cDe02Tg=`0P;Rh0
=TA502Hd<`0a@3/0:3Lb0P0V=C00100Z=S809S4]02@_:`0P:bL201`U8P0401lX9@0J8ah072DP020Y
90808R/V00L08BXU01dV8@0O:2<08BXU01dV8@0K91l07RLR00<07BHS0P0O9B<03@0P9R@06QhM01/O
7P0N81l071hM01XL6`0L7Qd08bDR01XL6@0T9R<07AlL01LI5P0M7a`00P0L7Q/02@0I6aP07R0M028T
8@0G6AH05ALF01XL6`0D5QD04aDD01PJ6@0201LI600F01PJ6@0I6aX05QPG01<E500H6A/0KVie05=C
G00D51/09BH/01PI7@0K71l05aTI01HH5`0D5QD05ALE01@F4`0A4a004A8=01@E4@0E5A<051@B01<C
4P804a<C01805ADF01<C5@0E5AL05A@I010@4P0@41405aLG00d=3@0C4a<04A4A01HF5P0B4Q803Ph>
00l?3`0>3Ph03@d=00l?3@0?3P/300l>300A010>3`0?3@h04@l@014?4P0F51L0518E00l=4P0B41<0
40h@01<A4P0?3@h03P`=00l=3P0<2P/03P`=028P8@1HEUL00P0=2``01`0=2`d03P`?00l=400=2`h0
30X=00h<3`0?3A001@0=2`h01`0>2`h03PT=00d8300>2@d04@`@01@?4`0A31000P0@2`l03@0=20`0
3`X>01<>4P0<1`/040/?00d9300>2@d02PD900`72`0>2@d040/?01<>4P0@2`l0100=20`01`0A3100
50lC018=4@0<1`/03`X>00d8300<20/00P0>2@d00`0<20/03PP:00`6200200l92`0D018<3P11>cd0
40X<00L10`0A2`d07ALI01<=3`0=1`T030H800/61`0?2@/0?CLi05eGF@0C3@l0<B/]010:300=1`T0
3PP:00/51`0:1@H200l93@803PP<0P0=1`/0200<1PX04`dA00H1100?2Pd03PP<00T41`0@1@T03`@8
0P0>0`L0100?10P040D901052@0?10P200h31`0300l4200@1@Wooooo01?ooooo000Kooooo`0700lA
3P0B514020X701DG500@4Ph030h900`?200200d@2@0800hA200?4PT03a8900T<1@0@4``03a8;00hA
2P0B5@h3010C3005018E3P0?4P/041<<01HI4P0=3`X00P0@4Pd01P0>40/03@l:00h@2`0>40/03@l:
00`>2@803@l:00<03Q0;00/=2P0:30T00P0=3``02@0<3P/03Q0=018D4@072@H03a4>014C400B5140
1`T600lA300200/=200R014C3P0@4Pd02P`700h@2`0B50l04aD@00lA300E5a80>S`g02T[9P0;3@P0
4aD@00h@2`072@@03@l:018D3`092`H0418=00X<1`0T9R4030h:0001000>40d04A<@00P:1`0@4Pl0
3Q0=00840@0>40d0418?00/=2P041P<03Q0=01PJ5`8020X701001`T600T;200A4a00418?01HH5@0D
5Q<030h;00/=2P0;3@T05ALB00/=20092`H03Q0;00T;1P0>40/02`d80P0<3PT0100:30L0418=01HG
4P0B4`h2014B3@0400d>2@0>3`X030d800`=20<03@h900@03Pl:00L91P0A5Q802Pl;0P0;40`02`0G
71P05Q/G01DJ5P0?51003Q<?00H;1`0:3`/05aTF030b;`0D5Q<01PP500804aDB00H01`T600X<2@0?
4@h02`d:018D4@0:30T600`<2P0D00l?3@0=3@/03@d;00h>300@40h03Q0=01HM5P0nAcl02A0901HM
5P1LHU`0<SLa01LL5P0D5a803Q0;00`>2@0=3`X03a0;010A300?40/200d>2@0800l@2`0@4@`03a0;
00/<1`0<3@P0414<00l@2`0<3@P300d?2P<03Q0;0P0?4@`0600@4Pd03a4<00h@2`0=3`X02P`700P:
1@0:30L01`T4018D3`0R91l061XE00h@2`0:30L03a4<00P:1@0:30L030h9014C3P0<3PT03a4<00/=
200Q8ah03a4<014C3P803@l:00<03Q0;00lA3@0@4Pl00P0@4Pl200lA3P0=00h@3@051`@04Q@A00/=
2P0@4Pl03Q0=00lA3P0>40d0418?00lA3P0@4Pl05QPE01DG500500h@3@0600l@3P0A4@l04Q8@01<C
4@0B4Q004A4?100@40h200l?3@<030h=00l071hM01PJ6@0@4Pl04A<@00/=2P0@4Pd07AlJ01`N6@0C
5Pl071lF00d@1`0B5@`01`X300lB2`0B5@h00P0E5a801`092`P00P@101<E4P0E5a@04A<>010B3@0>
40/00`0?4@`01P0B50l03a4<00h@2`0@4Pd04A<>00h@2`803@l<0P0>40d200lA3P1;010B3`0?4@h0
3@l<00h@3@0@4Pl04A<@00h@2`0A4`d0418=00lA300?4@d0418?00h@3@0@4Q004A<B00lA400@4Q40
4A<@018D3`0?4@/03Q0;00lA300A4`l0418?01HH5@0Q8b403Q0?00P:2@0F61L04Q@C00hB4@0B5QD0
3a<B010D4`0A5A@03A4@01hR8@0l@3l0004001`P7`0;3`h03a<B01PM6@0@5A405Q/G00lD40062`L0
6b0L01@I5@0H7AT03Q<?00`A3@19CTX0e]_G024V8P0D6AD07b@P018G4`0E6QH06QlK01@I5@0A5Q80
5Q/G01`Q7@0I7QX05AXF018G4`0P9B40:BhZ024V8P0E6aL05QhI01PQ700F7aX051hI00804QdG01/0
72@O024W8`0K8Ad051`G01<L5`0E7QT09c4/02Pc;@0F8A/04alH01l/9@0M:R<05b8L024Z9@0S;2L0
6bDO01HQ6`0H8ad06RHO01`Y8P0L:b@06BPQ01HU7P0I:2407BdS01LY7@0E9Q`00P0K;280400L;BD0
834Y020a:@0O<2X07BhX01`]9`0K;2H08c<`014T800P<bl0H7=_02<f<P0U>3H05RPX028d=00P<S82
028d=P0@024c=@0S=cP093Pi02Xn?`0U>3`0;d9602@i?00T?400:d=702U0AP0/ADX0>55F039;C`0U
>Sl09S/n02Dj?@808SLh010093Tj02]1?`0Z@3h0:Clm02Y0?P0[@Ch0:3hl02Xm@@0/?d<09cXn02Dh
?00X?3l09c`o02]3A@0_AdT0<TY<0P0bC4d05`0`BT/0>U9F0359C@0U?D40<4Q<0359C00eCDl0=Ti@
03M?C`0hD500=e1=03I?C00eCT/0?5EB03M@C@0eCT/0>55>03YCD00hDDh0=Di;03M@C@0hDDh0>E9?
0080>U=@01<0>U1>03]AC`0nE580@5ID03eCD@0jD4h0AE]I03Y@CP0mDe40@EME03aBD00iCdd0>e5>
03=8@`0aAT40<dQ303=6@00aA3h0=4M10080=DHn00L0<D8j03=3>@0jBT00<44i02ho=@0]?S@0;Clc
0080;T0d01h0=DLk0311>@0eASh0A5AA03Y:B@0/?3T0=4Dm0352>P0cA3d0>DY403E8A00kCTd0;D52
03mBEP0jCeD0Cf=/05=WL012FFD0A5]Y04INJP15GFH0?eMK03Y?DP0nDU<0>4a;03=5A@0iBTX0=4A4
03=1A00/>ST20391?00@03A3?P0c@Sd0;chk02`k>00T<c00<3hn02Pf=P0O;Bd08Bl`02Tg=@0[>S<0
8S4Z02Lf;`0P;bP09S</02@_:@8082/U00D09c0[02Pa;00O:2<07RLR01lX8`02024Z9@0X020Y900N
9b8082TT024Z9@0P:B@072DP01XS7P0L9B006B8O01XS800M9R<082HT01lU8`0N92806alN01`P7`0N
81l06adL01XL6`0M7ah04Q@A01`N6`0C5A804Q@A030b;`0K7AX07AlL01TK600C5A805QPE01/M6P0G
6AH05ALF01PJ6@0C5A@04Q@C01PJ6@0K7A`06Q`K01HH5`804Q@C010061XI028S9@0C51T04a@I01TJ
7P0C51H0;Bl^03<e<P0K7AX05aTF01DG500E5aH05QPG01DG500F5a804a@@0P0A4@l08P0C4a805ADE
014A4@0E5AH04a<E01@D5P0E51T04A4C010@4@0D51@030`<01<C4`0?3`l0410@02h^;P0D51@04A4A
01HF5P0E5AD051@B018A3P0A40h040l=00l>300>30d03@/<00l=3P0@3Q404a4D018@4`0>314040hA
010>400A3a0200l=3P08010>3`0<2P/040h?0040000<2P/04@l@00<10P0?3@l200d;3P0300/9300:
20/030X=00H03P`?00<040d@014<400?2Ph00P0=20`04@0>2@d030L;00P31`0C3Q803@P<01<>4P03
00805A0D00<00P0G4QH02`H:018=4@0:1@T03PT=00l:3P0>2@d03@P<00802`H:0P0<1`/00`0>2@d0
40/?010;3`0200`72`803PT=01`02PD900d8300J5AT0?SPj00/51`0>2@X04`d?00D00@0E3a404@/=
00d72@090`D02`D700d72@0;1@L030H8018<3P0?2@/01P0200X41P0:1@H03@L901hH6P0;1PL03@L9
00h82P0D3Q003@L;0`0<1PX400/52@06010:3P0A2`l02086014;3`0@1@T03`@80P0>0`L0100?10P0
40D901052@0?10P200h31`0300l4200@1@Wooooo01?ooooo000Kooooo`06018D4@0;3@X04A<@00lA
3P0M7a/04A<>0`0>4@X300hA200800`?200?4P/030l800`?200>4@X02Pd600T<1@0>4@X2014D3@03
00lB2`0>4@X03@l:0080418=00@03Q0;00d?2P0>40/03Q0;0`0=3`X200h@2`0800h@3@0<3P/030h;
00lA3P0@4Pl03a4>010B3`092`P2010B3`0301DG500=3``03Q0;008030h900/03Q0;00d?2P0;3@P0
30h900d?2P0A4`h03a4<00h@2`0A4`l02`d800X<1`0200d?2P0:00lA300A4`h04Q@?00H80`0E5a80
3Q0;03Pj=@0N81`0ADM400/=2P803Q0=00l04A<@00h@3@0=3``04aDB00T;200J71T04A<@00h@3@0N
81d02P`9014C400D5Q<02`d:00`>2`0>40d00P0=3``0500>40d03a4>00h@300D5Q403Q0;01PJ5@0>
40/03@l:00lA300=3`X03Q0;00`>2@0:30L03a4<00d>2@0:2`H03@h9018C3P0@4@`03a0;1P0=3PT0
6P0?4@h02@h:00hC3`093PX02a0<00`A3@0@5A400@D1010E4@0:3P/03Q4>069WH`0I6aP08B<P00lA
3P0A4a006adJ06U[J00_<Bh03@l<018D4@0@4Pl02`d:00h@3@0<30X03@d;0P0>3P`00`0=3@/030`:
01<C4@0200l?3@0A018B400D5180418?02H]9P0B71@04AXB02/b:`3Af=40AD]4018G4@0A5@l03Q8<
00h@2`0=3`X03@h9018C3P0@4@`00P0>3`X0300B4`h051D@00h?2P0;30L03@h9014B3@0?40/030d8
00d?2P0>40/0418=018D3`8051HA100?4@`0700=3`X030h900`>2@0?4@`05QPC01DG4P0=3`X02`d8
01dO6P0C5A002P`7018D3`051`<03Q0;04I8@`0j?3L05QPC018C3`0b=2l02P`700`>2@0>40/03@l:
00`>2@0=3`X04A<?014C400>40d200d?300800h@3@0@4Pl03@l<00d?300@4Pl030h;00/=2P0?4@h2
010B3`0400d?300<3P/03Q0=00lA3PD03Q0=00<0414>014A3`0B4Q000P0B4Q02014A3`03010@3P0?
3`d03`l=00803`l=01l04A<B01@F5@0:30/03a4@010B4@0Q8b0051HC00lA3P0>40/0418=00d?2P0=
40T0:2/R0495>`0M81L06A`D00d@200A50d02`d:03<e<00/;R/03@l=02HX9P0A4a404aD@010B3@0>
40/04A<>01<E400@4Pd02`d800804aD@00<06Q`G01DG4P0A4`h00P0>40d08`0=3``03Q0=00lA3P0@
4Pl03a4>00h@3@0<3P/03@l<018D4@0D5Q404A<>014D3@0?4P`0418=014C3P0A4`l0418?014C4@0@
4Q403a0A018C500F61H03@l:01@G400;3PP0418=01<E4@0J71P04A<@00lA3`0@4Q404Q@D01<E5@0B
4a@02`l>008041@C0P0C5aH0600?4a804QHE010D4`0=4A003a<B01TM700E6AP04QLC014F4P0>4`l0
5AXF010E4@0B5a<051TE018G4`0C61@06AhJ01PM6@0X;BT061dI01@I5@0A5Q805Q/G01LL60804aPD
00<03a@@01DJ5P0H7AT00`0D6AD01@0L8Ad08BHR01XO6`0C6AD05QdI00805AhI01T051hI01@O6@0E
81X0620K01TO6`0G7AT05QdI01LP6`0J8ah07BLQ01`W8@0I91h05b<M01PU7P0I9Ql05b8L01LP6`0K
91l07BLR01lZ900Q;2H08BdW024^9`0N;BH072/T008062LP00d06b/Q01LY7@0F9ad06BXP01LX7P0I
:R807RlW01d^9P0M;RP07RlY01d^:00N;bT07C0/00807c8^00X0DfIR02@g<`0J;B/07c4a02Hh>00M
;bl08S@f02Dg>@0R=3H08CDf0P0X?3d05P0/?d<09cXn02Dj?@0W?d<0:T9602LnA00V?d@0;DI;02Ho
@`0Y?T<0;45402Tn@@0T>CX09c`m02Tn?`0T>SP09C/i02Lm>P0X?S/0:T0l02Y0?@0V>S/202Tm?`0?
02Pk?P0]@D<0=4U;03A<C@0cBd`0<TY;031:BP0_BDT0;TQ903I>DP0aBDd0>E5E03A<C`0hD5<0>E5C
0080>E5A00`0>55?03UBC`0iDTl0>55>03aEDP0hDDh0=Di;03I?C00eCT/0<da903E>B`0hDDh203YC
D00:03M@C@0dCDX0>U1>03mED`0nE580>Dm=03eCD@12F5H0C69P03I<BP80?59@00X0<DM503=9A`0f
C4T0=T]603Q=B00kD4/0=TU30354?P0bACl0;Chf0P0`@CT202`l<P040393>`0`@CL0<D8h03E7>`80
=TPl0280=DLk02Xk<`0]?SH0<40m02dm?00dA440;Chd02`m=00a@S/0=4Do02e0?00hBdX0>di>045D
EP0lCe<0AeYQ049EG015Ff<0B61Y04URJ@15GV80?EEF03]AD00hCD`0;40n04=DE01XN7L0QIBD03e;
CP0c@T40;C`g02hm>00a@3/0<T4l0P0^?CX04@0Y>3D09cDe02Hd=00/>SX07R`]02dl>@0^?CH08c8[
02Xi<P0M;2D09C8[020[9@0K9R007BPR02`e<00_>3<08BXU00807bPS100Q:RD00`0N9b807BHQ01hW
8P0301dV8@0J01/T8@0M9R<082TV02<Y9`0R:2H082HT01`P7`0M8B007b4P01`N7@0K7A`07AlN01lQ
7P0H6QL07R0M01dO700P8Ql07R0M01/M6P0G6AH04Q@A010B3`0C5A805QPE018D4`0F61L201PJ6@0L
01TK6P0J71/08R@S01LI600Q8b808R@S01PJ6@0S9B@07QlQ01XK700Q8b00@dE20;>e/014ASl07AlH
01PJ500D5Q<05ALF01PJ6@0H6QX05QHD01<D400B4Q004a<A01@D4`0B4Q803`l?01DE5P804a<E00l0
5A@I01<C5@0A4A804Q8B014A4@0S8b<05QHF00`<300G5aL02PX:00/;2`0?3`l03Ph>00l?3@0@3``0
0P0@3`d01@0A40h04@l@014?400@3Pl040hA00804@lB00D040hC010>4@0=2`d03P`=00/92P0200l=
3P0=00T7200A3a005A<D00/92P0>30d030X;00d;3@0=2`h03`d@010>4@0A3a805A<F018@4`0500d;
3P0300l<3`0@2`l03`X>00<03@P<01D03PT=00@00`0C3Q803`X>00d8300N6Ad0NGAh00h:3@0;1PX0
2PD901LB5P080`L040/?00/62P0=20`04PdA00h93@0<1`/03PT=00d8300<1`/00P0>2@d0100=20`0
20@700l:3P0E41@200X52@0I01hI7@1YHfD09R0R00h92P0<1PP03PP:018<3P0>20X04P`>00/51`09
0`D04`d?014;3@0B30h030H800h82P0A2`d03@P9010:300=1`T01000018=3P1SGEl07ALI00d72@08
00d72`0600l93@0@2Ph0DTe@02XU:00@1@T03`@80P0>0`L0100?10P040D901052@0?10P200h31`03
00l4200@1@Wooooo01?ooooo000Kooooo`0601LI5P0D5Q<04A<@02X/:@0M7a/00P@00P0@4``02`0?
4P/03Q4800hA200=40L02Pd600hA2P0=40T041<<01DH4@0@4``030l80080:B`U00@04QD>01<F3`0L
7aP03Q0;0P0A4`h400lA300800h@2`0=3`X03Q0;00h@2`0?4@`0418?00h@3@0=3``2018D4@0800d?
300D5Q<02@/800X<2@0=3``0;S0]03Tk>00?4@`201@F4@0I00/=20082PD03@l:00h@2`0;3@P0418=
014C3P0;3@P03a4<01TK5P0E5a8030h901<E400@4Pd02`d801@F4@092`H030h900@60@0K7AP06A/G
06IXI@0;3@X020X700`>2`0200d?300700P:1`0?4@h030h;01<E4P0:30T03a4>010B3`0200/=2P03
02HX9@0@4Pl04aDB00802`d:01804A<@01<E4P0>40d02`d900/=200<3PT04aD@00X<1`092`H03a4<
00h@2`0A4`h0418=00/=200=3`X0:R/V01hO6P0?40/200`=2003014B3@0>3`X03Pl:00<03@h901/0
30d8018G4`062`L03A8>00/@30083@T04aPD00870`0a=S802Pd:00dB3P0F6aL0>d0l00T;200;3@X0
4aDB00L91P0];b`0fM_H04A6@`0=3``04aDB018D4@0620D03a4>00d=2`0?3`d00P0@40h00`0?3`d0
3@d;00l?3@0200d=2`0A00h>300@40h03Q0=01DL5@0H8QX04A/C00P?200V;BH061lH00T>200;40X0
314;00h@2`0=3`X02`d8014B3@0@4@`00P0?40/01P0B4`h051D@018C3P0A4Pd0414<00h?2P803@h9
00H03Q0;00lA300A4`h051HA01HH4`0G6A@400h@2`0D00d?2P0<3PT020X500D70P0:30L04Q@?00h@
2`0:30L03Q0;00`>2@0;3@P0418=00`>2@0A4`h04A8?01lQ70000@003Pl<02<U800U9b8200d?2P0>
00lA300;3@P030h9010B3P0>40d030h;00/=2P0<3P/03@l<00/=2P0E5a@02`d:010B3`0:30T200lA
3P@03Q0=0P0?4@h500h@3@0300l@3@0?3`d03`l=00H03`l=0P0@40h02@0A4@l02@/:01@F5@0?4A00
4Q@C02`^;@1<CT/04A<@00lA3P02010B3@0B014C3P0Q91`0Z:^R0?KikP1JGE@07B0G01HI400=40T0
8B<N01@F4@0M7a`09BLV014C4P0<3P`04A<@010B3@0>40/0418=0P0A4`h0200F61<08B<N014C3P0G
6A@05ALB01hP6`0?4@h03Q0=0P0<3P/00`0?4@h04A<@00h@3@0200d?301100h@3@0A4a004aD@01<F
3`0@4``03Q4:010B3@0B50l04A<>018D4@0C5A<04A<B010A4`0B4aD05QPG01<E400<3`P04aH?018D
3`0C5A40MWQc02d_;00A4a404Q@C01LH6P0?41805AHH00X>3@0?4a80310?00hB4@0?4a80310?01DI
600J7Qd04ADD020T8`1YKF`03A4@01DJ5P0F6aL0724M00`A3@0H7AT0AT]701dR7P0N8al08bPT00D:
1P0>4`l01``8010E4@0J7a/0:BhZ01DJ5P0B5a<04aPD01HK5`0D6AD061dI01DJ5P0F6aL07b@P01PM
6@0B5a<00P0C61@01@0C6AD061lK01LP6`0F7aX051hI00804QdG01D051`G01LM6@0I7a/06R4M01TR
7@0H8A`06B<M01HQ6`0E81X06RHP01/X8@0L:B808bhX020Y900M9R407bTS01hY8`0O:R@07BTR01TV
7`0H9b000`0K:R<01@0J:b4062XN01X[8@0O<2H07BhT00807c0X02/06BXR01//9P0L;BL07BhX01l`
:P0J;BT0:chj014T800H:bL07C0/028e<`0W>CT0:3Xj01/];@0S=CL0:3Xl028d=P0R=SL09c/l02@h
>@0V>Cd08SDi02Hk?P0Y@DD0;TI:02e4BP0X@DH0:T=802U2A`0W?440:Sm202Hk?P0U>S/0;45202Pm
?@0R>3H093Xg02Lm>P0W?SP0:D0j02a3?@0Y?C`0:3`m0080:cm00100;4520397B00cBd/0<DU902m7
A`0^B4L0<Ta;03E?CP0kDeD0=4a@04ALH00Y@D<0<TY<03UAD`0dC4`0=4a;0P0cC4T0200eCT/0=Tm<
03YCD00iDTl0>55>03I?C00eCT/0=4e:0`0hDDh02`0gD4d0=Tm<03E>B`0nE580@UQF03mED`0jD4h0
@eUG04eSH@15FeT0=4Y80080>U1>00`0<TQ603I<BP0`AT<0=T]603U>B@0jCdX0=dY403I9@`1LKfT0
?Tm703M8@00jBd<203Y:@00503=4?00_@3H0<T<i03Q:?P0iBcl00P0gBCd0A00fAcl0?Tm703Q8A@25
UI@0<d=002Li;P0]?S@0=TLo03]<AP0iC4X0<D=203]=C@0_@D<0AUQK04=FFP14Ee/0BEmS04MPI@16
Gf<0@eaM03iGE00mDe00?E1>02@g=@18F5L0AEAD06IdM@0_?D00=4=203Q7@P0fAD00=4<n0350>`0]
?3T09SDb02hm>P0[>CT0;C/k03m=C@0G9BH08S0^02/j<`0Q<2T09SD^01h]9P0U<R/07bXT01XU7`0I
91h08BXU02</9`0M9R407RLR01lX8`0P:B@08BXU028[9P0S;2L08R/V020Y900N9b8072DP01/T7`0H
8A`0624N01XS800N9b@092XX0P0U:bT03`0J7Qd0720O020R8@0N81l071hM01dO7P0P8Ql0;Bl/018D
4@0e=c@0Q8J304E7A00B51404aDB01HH5@0201@F4`0901/M6P0H6QT06Q`K020R8@0O8B006adL01dO
7P0H6QT06Q`K00804A<B02X05aTH00lA400K7AX0:2XU020S7017BT40cM3504I9?P0H6a005AP@01<E
400E5a@05QPI01DF600F5Q@04a@@01<C4@0E5A<051@C00h>3P0H61P07alP01TI6`0D51H04a8G014A
4`0A4A804Q8B01<C4`0X:2P061PH00`<300A4A405ADE01PH600B4Q803`l?01<C4@0D4a004a8@014@
3P0?3P`200d;3009010>3`0A3a803P`?010>4@0A3a@03`d@010>400?3@h03P`=00804a4B00<030X;
010>3`0;2@X00P0<2P/01P0I5aP02`T;00l=400@3Q403P`?00d;3P803P`?1@0<2Pd00`0=2Pd03PT=
00h93@0300l:3P0;01LB5P0I51P07QTM00P31`070PH020<703Td>00C3Q8061<G00X52@0J5AT00P0>
2@d01P0?2Ph03@P<00h93@0910P04@`@01HA5@803@P<01003PT=00l:3P0=20`04`hB00`72`080`L0
3`X>010;3`080`L02@<500D00@0?2@/0100000L10`0<1PP01P020P0=1`T0100<1PP04P`>010:300A
2`d200d72@0:00X41P0600803PP:00d72@0;1@L0100001lI6`0E3a402`D700d72`<03PP<0P0?2@d0
200C3A404@/?00H010040080G5IJ01XD600@1@T03`@80P0>0`L0100?10P040D901052@0?10P200h3
1`0300l4200@1@Wooooo01?ooooo000Kooooo`0600T;200K7AX05ALD01/M6P0?4@d03Q0;0P0>4@X0
4@0?4P/03a89010C2P0@4`X03A09010C300?4P/04aH?01PK500B5@h00@@001PK500F6A801PT200P;
100=40T03a4<00804Q@?0P0@4Pd0100A4`h03a4<00h@2`0=3`X200h@2`0F00lA300?4@h03Q0=00d?
300D5Q<04Q@A00X<2@0<3P/03a4>010B3`0H6QL0DeEB071bK`0A4`h05QPC01TK5P0@4Pd02`d800lA
300@4Pd03Q0;010B3@803a4<018030h900H80`051`801PP300lA300A4`h03Q0;010B3@0>40/03@l:
00h@2`0B50l02P`801TK600D5Q<03a4>00/=2P0?4@h200h@3@0H01/M6P0A4a0020X700@60`0H6QL0
008000/=2P0h>SL0MgUf01hP7@0620H03@l<010B3`0C5A804A<@00`>2`0=3`/04A<>00h@2`092`H0
51HA010B3@0>40/030h90P0?4@`01P0;3@P03a4<034b;@0T9B0051D@00l@2`803@h90`0>3`X0100=
3PT030d800`=200;40`200L=2@0A00T?2`083PX03Q@@00lE4@2CVID07R@P00H<200D6QH041HB018D
4@0?4@h030h;01<E4P0H6QL05aTF02@V8`092`P00`0?4@h00`0A4a003@d;00l?3@02014A3`0?00l?
3@0=3@/030`:00h>300=3@/030`:00h>300?4@h0<CPa030j<P074@T031H>00dF3P0?5Pl02a0:0080
2Pl900<030h900d?2P0=3`X00P0>3`X400l@2`07010A300C50l04Q<>00l@2`0D5A0061TD00`>2@02
00d?2P<03a4<00@030h900d?2P0>40/03Q0;0P0=3`X0100D5Q40418=00h@2`0?4@`2014C3P0B00h@
2`0@4Pd04A<>00/=200<3PT020X500X<200A4`h04Q@?010B3@0;3@P0;BlZ00h@2`0=3`X0418=00X<
1`0;3@P03a4=0`0=3``02@0>40d03a4>00`>2`0L7Q/02@/800d?300?4@h05QPE00lA3P0200`>2`04
00h@3@0@4Pl04A<@010B3`D03Q0=00<03a0>010@3P0?3`d00P0?3`d08P0@40h03`l=00h>300?3`d0
4A4?018B400C4a404Q@C01/M700=3`h00040014C4P0F61D02@/8010B3`0G6A@03@l:00`>2@0W:R80
/;>Z0??fj`1DEdh04aH=00lB2@0@4``03a4<00D70P092`P061XI014C4P0>40h03@l<00d?2P0>40/2
00d?2P09010B3@0J71L09bTT00lA300C5A00418=01`N6@0?4@h03Q0=008030h;00@03a4>014C400>
40d03Q0=0P0?4@h07@0@4Pl04A<>01<F3`0>4@T030l800hA2P0A4`d0418=014C400C5A<04Q@C010A
4`0@4A@04Q@C00h@2`0;3PH04QD>01/N5`0G6Q@0JF]V02PZ9`0E5aD04Q@C01@E5`0@4A@04a@F01<G
5P0D61L03Q8A00803A4@03l02Ph=00hB4@093@`06AdL020T8`0m@D0051PG00D:1P0:3`/06AhJ01HK
5`0Y;RX0FUmK02T^:P0>4`l04QLC01@I5@0H7AT04aPD018G4`0b=c<0PhR401hS7`0B5a<05AXF014F
4P0D6AD06QlK01PM6@0Q9R80<SLc01hS7`0E6QH061dI01/P700H7QX06R4M01PQ700G81/05AlJ01@O
6@0E81X05alJ01XP700K8Ad072@O01XS7P0I8Qd072HP01TT7P0H8ad07BTS01dZ8`0N:b@09S4[024Z
9@0L9B007RPR01/V800J9Al072PQ01`Y8P0K:R<00P0N;BH02P0M;2D06b/Q01T[7`0N;bD08S<Y01h_
9@0O<2P07RlW01PY8@0I:R@201X[9@0/01//9P0O<Rh06bhZ01d`;00U>3@05bXV028e<`0R=3@0:3Xj
020b<P0U=cT09SPj020b=00T>3T09SXk02Lk?00T=c/09CPl02Ll?`0U?D40:41402PoA@0V?d@0:456
02M0A@0S>3d09S]0028g>P0V>c`0;dA502Dk>@0S>CL09S`i02Ln>@0U?3H09C`e02Po>@0/@3l0:3`k
02e1@00_@d80;D9002m5@`0^Ad@202m8A@0C02m9AP0aBdP0<Ta;02m7B@1=IFP0O9BF04aTIP0hD540
;DE503=;B`0bBTT0<DY7039;B00dCDX0=Di;03M@C@0iDTl0>55>03M@C@0203I?C00603UBC`0gD4d0
=Di;03I?C00iDTl0>eAA0`0kDDl0100mDe40@eUG04ILFP13FEL203I<BP0g03=9A`0/@T00;D=102m5
@P0dBD@0<dQ30356@@0dAd40>4]505=VH00gB400;d0h0311>@0c@cT0=THl0352>P0]?S@0<44g03M9
?@0hBSh0=DLk0394>00Z>c<0=TLo0351?P1]OG`09CDb0311=P0b@cT0<T<k0393?@0eAD@0<D9104AF
EP0fB4X0CEmQ045CE@1LKW00@EIJ04AMH@11FEd0@UQJ045GE@0nDU00@EEA03E8A01<G5/0>DQ802Le
=P10CU40BUQG03m>B@0jBD@0=D@o0391?00202ln>`0A01<R7`0N;2`0>dU909j/[00`?Sl09S@a0392
>00W=bd093@Z01l_9@0Q;RD07RTQ01`W7`0I91`072HN024[8`0W<BT00`0Q:RD02@0P:B@08BXU028[
9P0S;2L082TT01dV8@0L9B006b@O01LP6`0201PQ7P0;01XS800M8b407R@R01lU8`0I7A`0720O028T
8`0P8R407AlN01`N7@0K7AX00P0H6QL0<P0E5a@07b4N01HH5@0A4a005QPE01`N6`0H6QL04A<@01PJ
5`0L7Qd06Q`K01dO7P0K7A`06A/J020R8@0R92<05ALF01/M700L7Qd04Q@C01PJ5`0>40/082<J01dP
5@0C5P/0CU9401XN400D60X04aH=018D3`0D5Q<05AHH018C5@0J6QP04a<@010@3P0C4a404a<B010@
400F5QH07AdN01PH6P0C4aD04a8G018B500?3a004Q8B00d=3@0I6AT0410@0P0=3@d02@0?3`l0410@
00X:2P0820P03@d;01DD4@0C4Q004Q4?010?3@0200d;300700h<3@0?3A002`T<00d;3P0?3A8030X=
014?4@0200l=3P0501DC500D4Q<03@/<00h<3@091`P00P0F51D01`0@3Pl02`T;00l=400?3A0030X=
00X82`0;2@`01P0=2`h00`0>2`h03`X>010;3`02010;3`0D00l:3P0;1PX00`0200<00P0>2@d071LK
00h93@0300801`86018=4@0C3Q805Q4E00l:3P0<1`/03`X>018=4@0A3100100300X52@0D3a<200h9
3@8040/?01403@P<00T4200=20`03`X>00/62P0:1@T040/?01H@4P0=1`T01`4301<=3`0L5QP03PP:
00T31@0<1PP03PP:00d72@0200h82P803@L900X04`d?01PB500K5AL03@L900`6200C3@l040X<00@0
000A2`d020<40P0<1PX200d72`803PP<00P02`D900d82`0?2@d07ALK01H@500>20`040D900l42080
3P<700@03`@801052@0@1@T03`@80P0>0`L00`0?10P040D9ooooo`0Cooooo`006oooool04@0=3`/0
3Q0<00h@30072@D0418=01<E400;3PP03@l900hA2`0@4P`041<<010B300=3`T03Q4;00/>200>4@/0
4QD?00802`d700D03Q4;00lA2`0@4`d051H@014D3P03010B3@<03a4<01003@l:00lA300A4`h02`d8
00T;1P0A4`h02`d9018D400<3PX04A<?00d?2`0?4@d04A<?00`>2P0=3`/02`d90P0@4Ph200h@2`0X
014C3P0?4@`02P`700/=200>40/04A<>010B3@0<3PT04aD@01PJ5@0D5Q404aD@010B3P092`H030h9
010B3@0>40/0418=00h@2`0B50l030h9014C3`0B4a00O7ij024S7`0620@05ALC014C3`0?4@d0418>
014C3`0O8Ad05QPD00lA3@082PH051HB00`>2P0S9B401`T500lA3@D03Q0<01H02P`8020R7@0A4`h0
30h902X/9`19BdH071hI014C3P0<3PT03Q0;00`>2@0?4@`03@h900T;1P0;3@P0418=00h?2P0?40/0
3Pl:00h@2`0?4@`03@h90P0<3@P01P0>4Pd02Pd9018F4@0N8Qd03a8>00hA3@803Q8=01<041@?00X>
2@0A51002Ph900l@3P0=3P`0414>00P91`0;30X03Pl=014B3`0<3@/051DB00P91P0@4@h030d;00d>
2P0>3`/03`l<0080410=01003Ph<014A3`0@40l03Ph=00L71P0C4a805AHC00H8100>40`04AHA00/?
3@0>4a403A8A00`B400<4@l03A4?0P0=3`/04`0@4@`03Pl;00`>2P0<3PX03a0<010B3P0@4@d03Pl;
018C3`0C51003a4=01<D400I6aL03a4<014C3P0<3PT05aTD00`>2@0@4Pd00P0;3@P0700=3`X03a4<
00/=200>40/02@/700h@300<3PX02`d9010B3P0A4`l03Q0<010B3P0C5A403Q0<010B3P0:30P03@h;
00h?2`0?40`02P/8018C400:2`P03a0<014B3`0B4`l03@h:00`=2P0>40`200d?300A00lA3P0A4a00
418?014C400K7AX02P`900d?300D5Q<05aTF00h@3@0=3``02`d:018D4@0A4a004Q@A00`>2`0=3``0
0`0>40d05P0A4a004A8B00d=3P0>3@l0518A01<@3`0A3P`040l<00`<2@0@51002@l;00hI5`0F8Ql0
314?01HH5P0@4Q002@/901@F500>40d04Q@A00lA3P0?4@d2018D400J01@F4@0R91d0?T0h01TK500A
4`d02P`600`>200F5a80>S`g034c;`0:2`L04A8>014B3`0<3PT03@l:00h@300@4Ph02@/9010B400>
40h05QPD00`?2@0?4PX02Pd400/>1@0A4`d300h@300300lA3@0A4`l03Q0<00@03a4=01D03a4<010C
3@0=40X03@l900lB300@4`d03Q0;014C3`0B51004Q@B010B400?4A003a4?00d?2P0D5Q003a4;01PJ
5P0?4@d051HB014C400B51400P0B51805P0C51D051DE01lR7`0L7a/04aHB014D400B5A404AD@010D
3`0B5Q404A@@01TL600D5a<03Q4=01DJ5P0B5a<041DA014F4P0@5A405AXF01<H500I7QX201@I5@07
014F4P0F6aL05QTF03@h=01nPGh09BPU01@H500201<F4`0T01@H500H6aP04QHB01PK600S:2@06QlJ
01<I500H7QP082LQ01@L5P0H8Q/05R0J01PR700G8Q/04AdF01LS700K9Ah06R@M01dU7`0K9Ah07BLQ
01hX8@0K9b007B/S024]9P0M;2<05bLO01/Z8@0R<2L082`T01dY8P0O:b<07B`S020/900S<RT093<Z
0P0R<RT0100P;bL072`S01`/900M;bL201d_:00;01X/9@0L;RL0838/01T[9P0O<B`07BlZ01T[9P0M
<2/07S4^01``;@0M<2d00P0O<Rl01@0T=cD07c8a02Lj>@0V>CP093Lf00808SDd04808cLg01hc<`0W
?3d0:Ce002<g?00W?4809ce302PmA00X?T@0:T1402U2A00X?T00:3`m02a0@@0U>CX0<DA503U>C00Z
?S`093Pe02Lm=`0X?CH0730Z02@j<@0W?CL0:d9102Y2@`0[@d@0<4I802e3A@0`B4L0<4Q902m8AP0a
BDP0<da:0359B00^A4D0>U5C02e4A`11F5X0=Ta?03M=D00dBT`0=Te>03U?D@0dBdX0;DA504=JFP0k
De@0=Ti?03I?C`0jDe40>55>03UBCP0fCdX0>e=>03A<B00bBDL0>Tm>03iCE@14FET0=de:03=8AP0g
C4P0?55=03Y@C00iCd/203I;AP0A03E:A@0bAd40;T@n02i3?P0cAd80<TI002m3?@0]@C`0<dI003Q;
A@0^@C/0<48k02i0>@0dASl0>de603Q:@`0iBd@00P0dASl0A`0iBd<0>DY103i?AP0kC4<0;clh03A4
?@0b@S`0;clj02hn>00_?cD0;clf04=CC00c@ch0?Ti=03]<B`12De@0>D]>045CEP18FUl0LhB:059U
J`16G640@UIL03eBE010De40>dm;03M;AP1FJF@0?e1<03]<B`0lCTd0>dY<03Q7AP0jBD@0<3lj0391
?00Y>3<0<D0l02Dd<00b@Cd0:3Lc024`;@0iB4H09S@c02Db;@0c?cP0;SXc02<_:00Q;BH08bhW020Z
8`0O:B<07RPR01hX8@0R;2D0:cD^028/9`0S;bX082/V024[9P0R;2P07RPS01dW8P0H8Qd07RLS01XS
7`0L9B407BDQ01PQ7P0P:BH07RLT00807R@R0280728P01TM700K7ah08B<R020R8@0N81l06adK01TJ
5P0K71L07b4M01HH500E5a<06AXH01PI600`<C00@dA501/L7@0B4a@071dM01PJ6@0G6AP071hM01DG
5P0G6AP06adL01lQ800G6AP0@49103m1@00E5aH07R0N01`M6P0D5Pl07R0I0P0E5`l0:00K7AD051H>
01<E3P0B4a004a@A01@E500C51<06ATF01DF4P0B4Pl04A8>01<C4@0C4a804A4@01DE5@0C4a@04Q8C
01@D5@0E5AH0410@01XJ6P0@41003`l?00/;2`0B4Q805ADE010@400B4Q803`l?018B4P0A4A404Q0@
00l>3@0@3Ph04Q4@014?400?3@h04Q0A00l=3`0>30h2010>400C00l=400>31004@lC014?4@0?3A00
4@lA00`:300B418030X;014?400>30d02`T:00l=3P0>30h03@/=00h<3P0?3@l04@lA01<A4`0200`:
300T00l=3`0=2`d030X<00d;3@0A4180510C00d:3@0920X040d?03Xg>P0c<S@030P;00h<3P0;2P/0
3PX=01<@4`0@3A0020D800d8300910P03@P<014<400@2`l05Q0D01PB5P0<1`/030H:00d9300:2@X0
40h@038^<@0]:B/040`>00l:3@0B2Ph04@T=0P0=10P01P0?1PX030D700l92`0>20X02`D700T41@<0
3PP:0P0?2@/04P0=1`T03PP:00X41`0=2P`04`hB00L21`0@3@l0@Si201LB5`0;2@X0<bhb00l93P05
0`@050hC00/52@0;1@P03`T<010:3@<030H900D03@L:01LA500;1@P02`D800h82`0201052@0:00l4
200>0`L040D901<8300?10P040D900l4200>0`L03`@801462QCooooo000Kooooo`8030h90P0=3`X0
100<3PT02`d800`>2@0=3`X300h@2`0>00d?2P0>40/03a4<00`>2@0>40/04aD@00d?2P0G6A@01`T4
00d?2P0E5a80418=0043000?4@`200h@2`803@l:0P0<3PT03`0;3@P00040018D3`0K7AP0004000h@
2`0I6aH04A<>018D3`0620<03@l:010B3@0?4@`03@l:00`>2@0200/=200600h@2`0<3PT03@l:010B
3@0A4`h0418=0P0>40/01P0=3`X02`d800h@2`0;3@P00P@000L9108071hI00<03a4<00X<1`0<3PT0
0`0=3`X03`0>40/03@l:0084001@DTd061XE0002000A4`h03Q0;00d?2P0;3@P03@l:01DG4P0A4`h0
30h900h@2`0400lA300B00h@2`0;3@P02P`700h@2`0A4`h0418=018D3`0620<03@l:01<E40000P00
<cD`028T7`0C5A002`d800lA300:30L02`d80P0=3`X00`0<3PT02`d800/=200200X<1`0<00`>2@0?
4@`03Q0;00d?2P0?4@`02P/600L80`0B4`h05QLB00D60@0?40/030d80P0?40/0AP0>3`X04A8=014B
3@0>3P`01`L503@d<P12@T003`l=00h>300820H04A4?00h>300<30X051@B00L80`0<3@P03a0;014B
3@0B4`h0410=00/;2@061P@06QXI01dM7@0G5aL010@400@30@0<20L05a<A01`L6P0E5AL020X=00T=
400=4QD0310B01@H5`0@4Q40418>00X;1P0I6aP04aDB00lA3P0@4Pl04A<@00lA3P0@4Pl03Q0=018D
4@0A4a002`d:00`>2`0@4Pd04A<>00P:1@0C5A000`D000L9100<3PT02`d800d?2P0>40/02P`7010B
3@0<3P/03@l<00/=2P0?4@h04aDB014C400?4@h200d?300300h@3@0=3``02`d:00803Ph<0P0A4@l0
2@0@40h04A4?010@3P0B4Q00410>00h>300?3`d04A8@010B3`0200h@3@<0418?00@03a4>00d?300>
40d03a4>0P0@4Pl060082PL04A<@00L81P041P<051HC014C400=3``03a4>010B3`0C5A8061XG02LY
:@0P7b@03P`?00T41P0>1@H04`/902<O7011@Sd041HB00`I5@0kDT`0WkJb02@]:P804A<@00`03@l<
00L91P0>40d03@l<00lA3P0@4Pl03a4>00h@3@0?4@h04a@?018C3P0A4Pd3010A300D00X;1P0I6QD0
61TD00d>2@0F5a8061TD01@G400I6aH01PP500L9200<3Pd03PlA010B4@0?4@h03a4:010C200@50H0
3A4300hA2P0<3PT2010B3@0400h@2`0A4`h030h900d?2P803Q0;0P0@4Pd00`0?4@`03Q0;00lA3002
014C3P0300lA300@4Pd04A<>00804A<>00/0418=00lA300:30T05aTF02LY9P0U9b@05ALD00d?300@
4Pl03Q0=01<E4P0201@F4`0=01dO700D5Q404aH?018E3P0C5Pl05APA01HI4P0C5Pl04A@=01<F3`0A
50d03a8;018D3`06014F4P804QLC02P04aPD01@I5@0D6AD051TE01HH5@0I6aP06adJ01TK600E5a@0
4aDB01@F4`0F61D06Q`I01TK600J71T07B8N01LM5`0B6A809bhW02hh<00F81P04Q`D00lJ4P0J9Ad0
5B4I010M500D8AP04alF01XU7@0K9Qh06RDM01hY8@0L:B006BPN01TY7`0N;R@093D[01d^900J:b40
72`R0P0M;B<201/[8@0301d]8`0Q<BL08C4W0080830V05X07RhT01/[8@0K;BH072l[01X]:@0H:bL0
6RdY01`_:`0G:RH07C0/01LZ9P0P<bl0:chj01ha;@0K;bd07S8`02Lk>@0U>CL0730^01T]:`0P=380
7C4_01/_;@0Q=C<09SXh02@h=P0S>CH08SPe02Dj>`0V>d00;T=80314C00Y?DH0:Si502]0A00[@4<0
:d4o02Y0?P0Y?3X0:3/i02Hi=`0^@Cl09cXh02`o>`0U>3807c8/02Pk=@0X?3<0:clf02@i=00Y@D40
:DA602U3A00cC500;dU:02i8B@0bBT`0<DU:03=;B`0eCDd0=Da<03=8B@0bAdX0=DY=0397BP0`ADP0
<TM:03U>D@0cB4/083Dh049GFP0lDE@0BUmR02Lo@@0nEUX0=e5C03==C00Z@d00>55<04=ME010Edl0
>Di:03I:B@0oDe@0?4mD03]>DP0gBdP0>Di903eBC@0hCDH20356?`0403=8?`0gC4<0=da30398?080
<4Hj03@0<dI003I9@`0eB480<D@n0395?`0dAd40=DQ203a?B@0^@C/0;3li03M:A00mD4X0=4M303=6
@P0Y?3P0>Te803U:A00eASh0=4Dm03=2>`0c@cT0=DDk03A1>00a?SD0;c`c03a;A02a`;X0?Da7024a
<00nCTh0?Te@041BEP15EU`0BEYQ04YKH`19FV<0A5EM03i?EP0iBdh0>Da:03=6@P0dB400@UI=049E
C`0lCd/0?4m=03e?C`0iBTL09cHa02/j=@0b@C`0<3lj0P0X=c802`0]?3L0:cXe02/j=@0]?3L09cHa
02Pc;P0V;bX0:34/02D^:@0O:2<06b@O00808R/V0P0Q:RD0;00R:bH08R`W01lZ9P0Q;BT08bl[01hZ
9P0Q;BT072LS02D`;00G8Qh07BHS01HO700J8b005Q`J01PQ7P0S;2T06b@Q01`R800M8b406R0N020T
8`0O8b807b4P01`N7@0J71/061XH01HG4P0L7AL06a`F01LH4`0L7AP071`J02PX:00H61T0:2PZ018A
5P0K6Ql04A4C01XK7@0Q8b807b4P01HH5`0K7A`06Q`K0P0E5aH0300N81l071hM018D4`0E5aH05ADC
018B400G5aD06ATG01`L6P0U9B<05ADC01<C4@804A4?00<04a<A01DF4@0A4Pd00P0D5A001P0B4`h0
4a<@01HF500B4Q004A4@010@40804A4A01d04Q8B01PH600<30`02@T901HF5P0B4Q80410@014A4@0>
3Ph05ADE018B4P0I6AT04a<C010>3`0>30d03`d>014?400@3Pl03`d>00d;300F51D06QPI01<A4P0<
2P/03P`?01TG7@0<2Pl03@/@00X83@0201DC5P0J00T72P0610D02`T:00h<3@0J61T040h?01lM7P0^
;2d040h?0040000>30d0518C00/92P091`P040h?00l=3P0>30d0BdY;0410@00:2PX04Q8B014A4@0C
4a<0N7Qh07AdM00Q8B4200H61P0;00P8200=30d030X=00`:3@0<20`030L;00d8300>2@d03@P<00h8
300?2@d00P0@2Ph02@0B41802`d<020P803oo_l0bLO801hH6P0B2@`04@P;01<72`0201<42@0901<3
200A20/03PP:00h82P0=1`T03PP:00l92`0<1PP03@L900803PP:0P0=1`T07`0>2@d05Q@I01dI7`0?
2Q005A<H04A0AP0:1@/00@0403Hc>00300@00@0400T52@0<1PP0208400P3100;1@L03PP:01@>400J
51H03PP:00X41P0;1@L03@L9018<3P0>0`L040D900l4200=0PH03`@801@93@0>0`L00P0@1@T00`0>
0`L03`@801052@0Dooooo`006oooool0200;3@P03Q0;010B3@0A4`h03a4<00d?2P0?4@`03Q0;100=
3`X03@0>40/03a4<00d?2P0?4@`04Q@?00d?2P0:30L05QPC00<5000;3@P0008001lQ700@4Pd00P0?
4@`200h@2`0=00d?2P0C5A000P@001PJ5@0B50l03@l:018D3`0<3PT04Q@?00h@2`0B50l02P`700d?
2P0400h@2`0600d?2P0<3PT03Q0;00`>2@0>40/051HA0P0E5a803@0@4Pd02`d800/=200>40/030h9
00d?2P0?4@`061XE01`N6@0;3@P03a4<01DG4P0>40/00`0=3`X0500<3PT051HA00h@2`051`8051HA
00X<1`0H6QD04Q@?010B3@0?4@`03Q0;010B3@0=3`X020X500X<1`0=3`X0418=00lA300>40/03@l:
0P0<3PT0=@0>40/04A<>010B3@0C5A00004000h@2`072@@01@L200`>2@0G6A@03Q0;00/=200=3`X0
2@/600`>2@0=3`X0418=00`>2@0=3`X051HA00h@2`0=3`X03Q0;010B3@0>40/03@l:010B3@082@@0
51D@01DF4@0=3PT020T4014B3@0=3PT0414<00l@2`0=3PT0414<00l@2`0E5A<01PH4030`;P10@3h0
30`:01@D4P0=3@/03Ph<0000000D5180410>010A300;30L03@h800803a0;02@03Pl;00h>300>3P`0
20P70000000N7Qh08B4Q00/:200B3Pd02`L600/;2@0D51H030hA01@I700>4aH02@l@01PL6`0D5QD0
7R0L018D3`0?4@h030h;00/=2P0>40d04A<@010B3`0>40d02`d:018D4@0E5a@03@l<00X<2@0=3`X0
418=00`>2@0@4Pd300d?2P0<00`>2@0>40/030h900d?2P0A4`h03Q0=00lA3P0<3P/0418?01<E4P0A
4a003Q0=0P0<3P/02@0>40d03@l<00/=2P0;2`T020P600d=2`0:2PP010@200H61002010@3P0800l?
3@0>3P`04A4?01DF4`0D5Q<04A<@00d?300<3P/2010B3`0[00lA3P0@4Pl03@l<00/=2P0>40d0418?
01TK600B51404A<@024S80000@003a4>00`>2`0=3``03Q0=010B3`0D5Q<04a@E00X;3`0<30h061DF
01`F5P0G4Pl04`l<02`]:00320@04AhJ04UNF@2ldLd02a@A00@60`0E5a@01@L400/=2P0C5A803a4>
00h@3@0<3P/03Q0=00lA3P0>40d04A8=010A300200h?2P0N014B3@0D5A003a0;01@E400C50l03a0;
014B3@0B4`h0004000L9100?4@h061XI010B4@0K71h04Q@C010B3`0?4P`04A@;018F200B5PL02`h7
00/=200A4`h04Q@?00lA300A4`h02`d800d?2P0>40/03a4<0P0A4`h00`0@4Pd03a4<010B3@02018D
3`03010B3@0?4@`0418=00<04A<>00L0418=018D4@0D5Q<06A/H01PJ5`0B514051HC00803a4>0P0C
5A801P0D5Q<06adJ010B3@0D5Q405aTD01TK5P805aTD0P0D5Q40100A4`h04Q@?018D3`0?4@`601@I
5@804QLC00D04aPD01@I5@0D6AD051TE01HH5@0201DG500H01HH5@0G6AH05aTF01DG500F61D06Q`I
01TK600J71T07B8N03Xo>`0B61@07bDQ01TR7@0@6A@051hH01HQ6`0L9b404QhG01/X8@0S<2T05b<L
01XU7`0K9R006RHP0P0M:R<0200M:b@062LP01HU7P0O;bL06b`T01`]9@0O<2P06b`T0P0M;RH01@0L
;BD07BhV01l`:00M;RH072dU00807BhV00<06R/S01X/9@0K;RX00`0J;BT01`0K;RX09CPd010S7`0R
=C405BPT01ha;@0L;b/00P0Q=C<01`0T>3H083@b01hb<00/@3h09SXh02<g=@0P=3800P0S=cD01`0Q
=C<07S@a02]1?P0R=cP05R/`03=8C@0I;C@00P0Z?TD0>@0Y?T80:Ci102To?@0Z@3d093Le020c<@0X
>cT0;d90024d<P10Ddl0J7]g04MJEP0hBdD0=4M102Pk=00R=c0093dj02Q1@P0W?cl0;dM902e5A`0a
BD/0<4Q:03=<C@0cCDh0<Ta=03=<C@0dC4h0=4U<03aAE00hCE00<DI903Y?DP0lDE@0;dA705aaM00K
<3<0;T=6041EF00mEEL0=DeA03YCEP15Geh0?eQE03mHD`0hDD/0:D0j03aAC@0jCTd0=TY;0395BP0n
DED0=d]803Y?BP0mDTd0=DY502m4?@0203=8@@0Q03E:@@0dBD00<DLk02m5>@0`ASX0<TDo03Y=A`0i
C4H0<D@n0313?@0dAd407S4[02Pk=@0[?SP0>Te703A7@@0fBD<0=4M103M:A00W>S@0A5M@04EFCP0_
@3P0<D8i0351=`0b@SP0=4@i03=0=P0b?cH0=D8j03Q7@01FIEl0>DQ30080>4Q701P0>dY=03]=D@17
FEh0CUmV04UJH@15EUd0?TmG03U:D@0jC4l0=DQ602i1?@0cASl0?e=:041CC@0jCDT0>Da:03U;B`11
DU00<d8m045@B`0jBD@0>dY501/Z9@0S<Rd202dl=`0902hm>00H9b803ahI02hi=00S;2L082TT02D^
:@0O:2<072DP00<082TT02l08BXU028[9P0S;BP0:3<_01l[9`0Q;BT03a/G01PT800R;BT05b0M02`e
<P17D4d08bTW018H5P0T:RP05QlL01`U8P0F7a`07R@R020V900N928082@S01lS8P0N81l06Q`K01TK
6P0H6QP051D@01XK5P0G61<05ADC01`L6P0G5aD071`L014A4P0K6ad05aHK01XI7P0C4aD06AXL01TK
6P0;3@`05aTH020R8@0B51<08B<R01/M700201DG5P0:01LI600I6aX061PF01@D4P0F5Q@061PF01LG
5@0I6AL04a<A018B4080410>00@04Q8@01<D3`0?40/04Q<=0P0B4`h0100C51005ADC010@3P0A4A02
018B4P804A4A00d03`l?010@400C4a<03Ph>00`<300@41003Ph>00P8200>3Ph02`/;00l?3`092@T0
3`d>008040h?01d03P`=00l=3P0@3Pl03`d>01`J6`0O7Ah04@l@00h<3@0F51L04Q0F00P62`0E4aP0
4Q0E00h<3`0:20/040hA00/92P0=2``02@L800d;30071@H0>3Hg051>C`0?3@h03P`=028P8@0=2``0
2PP900P61`0200`:2`0>00d;3013@T80<30`00410@0>3Ph00@410000000P820030`<010@400[:b/0
7alO018B4P081`P200l:3P0500h93@0<1`/03PT=00l:3P0=20`00`0?2@d01`0@2Ph02PL900d=3@0N
7Qh0f=KG08:0P@0E3a400P0?1PT01@0A1@T04`@901<42@0B1@T04@P;00803PP:00D03@L900h82P0?
2@/030H800d72@0200h82P803@L901h030H:01/F6P0L5a/040X>01HA5@0B3A0071HJ00X52@0e;c<0
50hB01D@500E3a<081XL00@0001@BT`0H5YL014;3@25Oh408Q`N00l92`090`D030H800l92`0@2P`0
3@8600l4200>0`L03@8600l4200B1`/200h31`0401052@0A1PX040D900d21QCooooo000Kooooo`04
00d?2P0>40/03Q0;00h@2`803a4<00@04Q@?00lA300=3`X030h90P0>40/600lA300601`N6@0=3`/0
3a4<010B3@0?4@`02`d80P0@4Pd200lA30803Q0;00T06A/F05YLE`0C5A007AlJ01DG4P0;3@P03a4<
014C3P0@4Pd00P0>40/0100?4@`030h900h@2`0?4@`2010B3@0500lA300>40/030h900h@2`0C5A00
0P0D5Q4200h@2`0:00lA300@4Pd0418=014C3P0=3`X05aTD024S7P0>40/02P`7010B3@803Q0;00d0
3@l:00`>2@0<3PT020X601HH4`0<3PX02`d800h@2`0@4Pd030h9014C3P0B50l0418=00803@l:0P0?
4@`01@0>40/03a4<00lA300>40/03@l:008030h900/03@l:00h@2`0>40/030h9014C3P0?4@`02P`7
01TK5P0:30L030h900/=200200h@2`0K00/=200?4@`020X500lA300<3PT04Q@?024S7P0J71L04Q@?
01<E400A4`h03@l:00/=200>40/03Pl:01HG4P0I6QD05QLB00d>2@0>3`X03a0;014B3@0?40/030d8
00l@2`0=3PT03Ph<00803`l=02<02PX800`<2P0:2PP04A4?00d=2`0H61H0?Cdk00d=2`0F5a803a0;
00d>2@0@4@`03a0;00l?300E5A<04Q8@018B4@0h>3P05QHF00h>3P0H5aD040`<01dK600L71X071`N
00hB500?51L04aTL00X@4@0A5aD03Q8A024S7`0F61<03a4>00h@3@0200d?300K00h@3@0?4@h0418?
01@F4`0H6QL04aDB00`>2`0>40d03Q0;00d?2P0?4@`02`d8010B3@0<3PT03@l:00/=200A4`h03@l:
01<E400>40/03Q0=00lA3P0<3P/03Q0=014C400?4@h03Q0=008030h;01D03a4>00h@3@0<3P/02`/9
00d=2`0C4a404Q8@010@3P0C4a403Ph<014A3`0B4Q00410>014A3`0@4@l0418?018D4@0?4@h030h;
00lA3P0A4a001@0?4@h02P0B51401`T7014C400c=C80GEmL01@F4`0?4@h04A<@010B3`0?4@h200h@
3@0H00`@400>4aH04aHG01@D4`0?30/03`/801<A3@092PD05QTF00dF4`0@7a`0830]014G5@0B5140
3Q0=01HH5@1WJFH0Gf5N01<E4P0?4@h030h;00lA3P0A4a00418?0P0?40/2010A3003014B3@0B4`h0
5AHA0080414<01D04a@?010A300@4@`05QPC00H8100Z;2T0=SPf00P91`0l?Cd04Q@C010B3`0>40X0
41<:018E2P0C5P/03Q4:00h@2`0D5Q405ALB010B3@0A4`h01P0?4@`2010B3@03014C3P0C5A004aD@
0080418=00L04Q@?01<E400D5Q4051HA01<E400E5a@04A<@00804Q@A00<04A<@01DG500A4a000P0C
5A82018D4@0=01@F4`0D5Q405QPC01HH4`0E5a804Q@?010B3@0C5A005aTD018D3`0G6A@06adH01DG
4P06014F4P804QLC00@04aPD01@I5@0D6AD051TE0P0F61D08@0G6AH061XG01TK600I6aP05aTF01HH
5@0H6QL05ALD01@F4`0F6aL0<3Hb018H500D6QH03aPC01hW8P0G8A/03APB01/V800U<BX07BXS01XW
800D81X06B@N01XV800M:B807BXS01d[900K:B806bXS01`/900L;2D08c@/024d:`0201`]9@0<01l`
:00P<BT07c0X020a:@0Q<RX07RlW01d^9P0N;bL07c0X01h_9`0L;RP07C0/0`0N<Bd0G`0M<2`0;d8n
07^>RP0`@cl07C0/020c;`0O<Rh083@b01hb<00P=3808cLf02Di=`0_@d408CDc028f=@0V>ST08SHd
01``;`0Q=C<09C/i02To?@0P=CH0AU]N08BIW@0bAT`0:Si402Tn@`0W?4009CXk02Hk?00W?C/0:3Xi
02@g=P0S=SD0;3lm02Hi=`0gBTL0@UEA02Xm>@0X>cD0:Sdg02`o>00bAT00:3di02a2?`0/@d80=Te<
039:BP0aBDX0;DI803==C`0cCU00;dY<031<C`0gDU@0=Ti@03=8BP0mDU@0=4U;03E:C00cB4X0DfQZ
06UnP00_A4H0;D9403]@DP0eCDh0>U9E03]EE@0oFEP0=Tm<03YCC`0kE4l0?5=>03iCD@0cAdH0?U9C
03e@D`0_@dD0=d]903U>BP0jCT/0<TM203=8@P0jCdT0<TM00356?@0`AC`0<4Dk02m4>P0^@cX0<4<m
0354?P0bACl0<dI00080<TDo00@0LHAn0313?@0W>S@0?E1:0P0hBdD01@0dB3l0=TU202Xn=00mDDL0
?4e40080<T<h02@0;cle0392=P0a@CD0;S``02ll<@0_?3@0;3/d03e<AP0b@C`0<D4n03E5A@0gAdL0
=TQ:03i@E014EE/0@UAI049CF@0oD5H0?e5E03i@D@0_@T00;d8n03M:A00kCdL0?U5;03U<A`0fBDH0
=4I502`m>P0hAd80=dI102ln>@0gAT40<3lj02@c;P0^?CP202dl=`08028a;00oCTT0JWIa02lh<`0P
:B@08b`W01dV8@0O:2<201dV8@0F01lX8`0P:B@08R/V02@^:@0X<bl07BTU03Q4@00O:RH09C4]01dX
900P:BH072DR01hV8`0O9B<06b4O01`R800G81d06B8O01XS800X;R`08RPV01XP7P806AdL0P0M7ah0
6P0K7A`06A/J01hN700G61@07alL02HV900M7A/05aLF01TI6P0O7b006a/M01/J7`0E51T092@V01HG
6@0c=C@06Q`K01DG5P0F61L06A/J02@V9@0P8R405aTH01TK6P0M7ah05aTH0P0I6AL0100F5Q@04a<A
01@D4P0G5aD201@D4P804Q8@00<051@B01@E400A4Pd00`0A4Pd0100A4Ph04A4?014A3`0D51<201HF
5P0A01DE5@0D51@06QXJ00h>3P0J6QX03@d=00l?3`0B4Q80410@00T92@0A4A404a<C01XJ6P0D51@0
40h?01<A4P0A3a000P0=2``06P0@3Pl05aDF01@B4`0B414030X;01<A4P0M6ah0K6Y`014?500:20d0
4Q0E01@B5@0=2`h040hA00X82@0=2``030X;01<A4P0>30d03@/<01/I6P0c<C805A<D00T8200>30d0
3@/<0`0?3@h03P0>30d040l?018B4P0?3`l03@d=00l?3`0=3@d02`/;00T92@0=3@d04a<C00P8200@
41005aDG0P0>2@d01@0=20`030L;00d8300?2Ph03PT=00@03`T=00H03`/>00<30`0;2PX071TJ01PD
5@0A2`d200l62@0501462P0D1P/050L;01@8300A20/00P0>20X01@0=1`T03PP:00l92`0<1PP03@L9
00803PP:0P0=1`T0500=1@X040P=00h72`0>1P/05@dB00d62P0;0`P02`@801L?500A2Ph02`D801PA
5@080P@03`X;02PR900Z92H040X<01HA4P0B30h03`T;0P0C3@l00`0=1`T02`D700d21P0300h31`<0
3`@800D03@8601052@0C20`04@H:00X00`0Dooooo`006oooool0200K7AP05aTD014C3P0>40/03@l:
00h@2`0@4Pd03a4<0`0>40/01`0?4@`0418=010B3@0A4`h03a4<00d?2P0A4`h00P0B50l01@0J71L0
LgE`01XL5`0J71L0418=00803a4<0P0>40/01`0=3`X0<C<^0;Rj]@0U9b802@/600L9100>40/00P08
2PD0200@4Pd03@l:010B3@0:30L04aD@010B3@0>40/03@l:0P0<3PT00`0?4@`030h900d?2P0200lA
30803Q0;00T04A<>010B3@0<3PT030h900T;1P031@0020X501DG4P0A4`h00P0:30L0200>40/03@l:
00d?2P0=3`X030h900lA300:30L07R0K0P0B50l01`092`H0418=00/=200=3`X0418=00/=200<3PT0
0P0A4`h0100>40/030h900`>2@0=3`X200`>2@0<00d?2P0<3PT02`d800`>2@0=3`X05aTD00/=2P0?
4@`02@/600X<1`0;3@P030h90P0?4@`0100>40/0418=00lA300B50l200d?2P0301<E400=3`X03@l:
00803Q0;00/030h900h@2`0B50l04A8=00H70P082@@04A8=00L80`0B4`h030d8010A3002014B3@80
5QLB02/0410>00h>300@40h0410>00d=2`0:2PP01`L5018B400<30X08B4O01<C4@0:2`H04Q<=01LH
4`0R8ah07AhI00d>2P0=3@/03`l=01TI600h>3P03@d=01PH60020P00;b/Z00/91P0:2PP05aPJ02DY
:`0=4QD0:S8d02<Z:`0=4a40310?00dA300620<03a4>014C400@4Pl03Q0=00d?300>40d05ALD0080
7R0M00l04A<@00d?300E5a@03Q0;00T;1P0?4@`04Q@?00h@2`0<3PT061XE00X<1`0A4`h03Q0;01PJ
5@092`H00P0>40d06@0;3@X030h;00h@3@0;3@X03Q0=00`>2`0=3``0418?00lA3P0>40d03`l=01HF
500=3@/020P600`<2P0;2`T03@d;018B400D5180410>00l?3@0<3@/02`d:00h@3@0@4Pl00P0?4@h0
3@0@4Pl03a4>00h@3@0A4a004aDB010B3`0G6AH00`D2010B3`0L7Q/0=cTf01lQ7P0@4Pl00P0=3``0
4@0?4@h04A<@010B3`0730/03ADG01dS8`0M81l05aLE01DD400>3@T05aPC00`>2`0;4@l01a4@010L
6`0;3`h02@/8008020X700H0=cTf038d<@0B5140418?00lA3P0@4Pl2014C400500h?2P0?40/04Q<>
018C3P0@4@`00P0=3PT01@0:2`H030d8010A300@4@`04A8=00802`d801T0=3Ha04U;B00E5a@02P`9
00lA3P0>40d03@l:00hA2P0@4`X03a89018E3P0@4Pd051HA01<E400?4@`0418=01<E400B50l0418=
00lA300>40/03@l:010B3@0?4@`0418=00804Q@?00D0418=014C3P0C5A004aD@01@F4@0201<E4008
010B3`0B51406adJ01dO700D5Q<03Q0=00/=2P0B5142014C408051HC00`04aD@018D3`0A4`h04Q@?
01<E400D5Q404aD@01HH4`0E5a806A/F01`N6@0J71L601<H50804QLC00H04aPD01@I5@0D6AD051TE
01<E4P0E5a@201LI5P0501@F4`0C5A805QPE01LI5P0J71T00P0H6QL06P0K81`03Q@@01PN6P0G7AT0
5b0K020Y900J91l04ahH02Ha:`0kAd0082dV01PU7P0I9Al062<M01TV7`0O;2D07BXS01`[900N;BH0
8C0Y01l`:00F9al07RlW020d:`0N<2P07c0X0P0P<BT02P0O<2P08C8Z02@e;@0R<b/07c0X020a:@0R
<b/08C8Z020b;@0O<Rh3020c;`0L01lb;P0S=S80Sj:N024d<00S=S806bhZ02<f<P0U>CP083@c028f
=@0W>cX09CTh02<g=P0eBDP09SXi020d<`0X?3/09CTh024e=00T>SP0;D=102Hk?00U>Sd0A5UL024f
>@0Y?T<0:Ci102Pm?`809S/l04T09S`j02Xn?@0_@D408C<c02Xm>`0`@d409CPf03=6@P0^@Cd0<TE0
02Hi<`0^@C/0<dI003mBC00gC4L0B5aJ06UmN`1JL6h0<TY:031:B`0eD580<e5C031=D@0bCe<0>UII
04=KG@12EeP0AU]L02]0@@0eBT/0AEYK0:g2``1:Gf00@EIG03I;C00eBT/0?5AD02U1@`1LMWH0MHn>
05A]JP0iDTh0=e1<02]1?P0oE580<DE403Q<C@12EEP0@5AE03=7AP0kCdd0@5AB03U>B@0bAd80<dQ3
0315?P0^@c`0;d@k0315?00/@CP0:Slf02m2?00X>cD0:Sdg03=6@00bACl0;T4k03E8@P0/?cT0@EA>
03Q;A@0fBD<0=d]20080<DDj0140;d<h02i2=`0W>Bd0<T@h03A6>@0_?c80<d<f02m0<@0Y=bP0;3X]
03I3>`0fACh0<d8l03Q7@P0`@3d0<D4o03Q8B00203M9B`0303U;C`0oDED0@UAH0080@59D0140>4Y9
02e0?P0bAD40>Da703a?B@0oDT`0>di903M:AP0cAT@0<d@o06AcKP17EU40<T4l02Lf<@0`?cX09SD`
02dl=`0202Dd;`0801h]:00S<Rd0?DU402H_:P0R:bH09c0[028[9P0O:2<2024Z9@0D028[9P0T;BP0
9RlZ02Pa;00Y=3007BTU03<o>`0R;BT09S4]01`W8`0@6AH05AhK01TO7@0N92804aTG01HL6P0G81d0
5QlL01`U8P0]<c4202<Y9`806alN01H07R0O01/M700H6QT051HE01/K6@0B4Q007alM02TY9`0L71`0
6a/K01LG6@0I6A/06QXL020O900H5a`07AdO01HH5`0Y:bX07AlN01XL6`0H6QT04A<B0P0F61L02P0H
6QT06A/J01DG5P0A4a8051@B01HF500B4Q004A4?01@D4P0B4Q0501@D4P8051D@00P04Q<>014B3@0A
4Pd0414=00h>300@40h04Q8A01<C4`<051@D0P0C4a<01P0a<C404A4A00T92@051@D05aLG00/;2`80
410@01l05ADE00`<300B41404Q0A014?400?3@h03P`=00l=3P0B41403@/<010>3`0B41403P`=00l=
400;20h06QPM01lM8P071@X05aDH02`Z;@18ATT0:bTZ01`J6`0=2``05Q@E00h<3@0200400@0001hL
7@040P<00@0000802`T:00d03P`=00d;300?3@h040h?00h=3@0:2PX020P800T92@0:2PX020P800h>
3P0C4a<00`<3008020P800L0000000/82P0<1`/03@P<00/62P0:1@T030L;00803`X>0`0>2@d01`0=
20`040h@00T92@0B41401`<4018>3`0=1`T00P0@1`X01@0B1`/050P<01@8300D2@d04@P;00803PP:
00D03@L900h82P0?2@/030H800d72@0200h82P803@L901804PT>00X11P0?1P/04@P=00`3200A20d0
3`H;00d42@0?1P/030<800/21`0F3A802@<500@0000=1`T04@/=00`7200S7Al200`6200700l92`0=
1`T02`D7018<3P0>0`L03@8600h31`0201052@<03P<700@040D901462P0@1@T03@865?ooool001_o
oooo00L06adH01PJ5@0E5a804aD@010B3@0?4@`03Q0;00803a4<0P0@4Pd03P0?4@`0418=010B3@0B
50l0418=00/=200A4`h03@l:01/M600f>3<0gn7L01`N6@0620<03a4<0P0>40/200d?2P0D00`>2@0:
30L08B<N00/=200H6QD01PP3010B3@0U9b8020X500X<1`0;3@P051HA00T;1P0B50l03Q0;00`>2@0=
3`X03a4<014C3P0>40/200`>2@0300lA300@4Pd03a4<00803a4<00/0418=014C3P0?4@`03Q0;01HH
4`0D5Q400`D10084000>40/04Q@?00`>2@0300d?2P0700h@2`0B50l01PP300lA300<3PT01PP300<5
000300d?2P05018D3`0>40/03@l:00d?2P0;3@P0100:30L03@0;3@P03@l:00lA300=3`X02`d800`>
2@0=3`X06Q`G00d?2P072@@051HA00`>2@0=3`X00`0>40/02@0?4@`03Q0;010B3@0?4@`03@l:00/=
20092`H020X500/=200200`>2@0;00/=200=3`X04aD@00h?2P0;30L03@h9010A300720<051D@00d>
2@0A4Pd00P0@4@`201@E400l01HG4P0=3PT03@h900h?2P0;30L03a0;00d>2@0>3`X00@800001000@
4@`03@h9014B300E5Q00824L01/L5`0<30T0410>01@D4P13@d804a<C00@4100D51@07AdK09VEU00O
71X03Ph<01PI6`0V:R`00`/=020X:P0W<3002a4?01@H5`0;40/02Pl900P:1`0=3``03Q0=00d?300>
40d04Q@A014C400F61D061XG00lA3P0<3P/04Q@A00d?2P0620<0418=020R7@0B50l05ALB02T[9P0<
3PT0418=00`>2@0L7QT020X50P0@4Pl01`0<3P/03@l<00h@3@0<3P/03a4>00d?300>40d00P0A4a00
2P0?4@h0:2PV034a;`0J6QP03@d;01<C4@0=3@/03`l=018B400A4@l200l?3@08010A3P0>40d03@l<
00lA3P0@4Pl03a4>00h@3@0?4@h2014C400400lA3P0>40d04aDB01XL6@803@l<00d04Q@A00<50P0<
3P/02P`900T;200=3``0418?00h@3@0H7ah08R`]01LP7`062`X02@/80080414<01407AhI00lA3P0<
4Q0000D400T@40072`X03a4>01hP7@0=3``020X700/=2P0>40d03a4>014C400?4@h03Q0=010B3`02
00l@2`80414<0P0?40/00`0B4`h051D@014B3@0200d>2@0800/<1`0E5a804Q@?00d?2P0F61<03@l:
00h@2`0?4@`200h@2`8041<<00T03A09010B3@0=3`X0418=014C3P0>40/04A<>018D3`0A4`h00P0@
4Pd01@0?4@`03Q0;00lA300>40/03a4<00804A<>00@03a4<014C3P0A4`h04Q@?0P0A4`h0300?4@`0
61XG00lA3P0>40d0418?014C400E5a@02P`9018D4@0A4a00418?01DG50804Q@A00<04aDB01@F4`0F
61D00P0G6AH00`0D5Q<04aDB01HH5@0201HH5@0301TK600E6QH05AXF00@05AXF0P0B5a<01P0C61@0
51TE01@I5@0D6AD04aPD01@I5@805AXF00D04QLC014F4P0D6AD05AXF01PM6@0201HK5`0@01/P700L
8R0061hL018H5P0@6AH03aPE01LQ7@0>6AD05R4M01/V8P0<61@04QhJ01XV8P0G8al06BDQ01l/:080
72/V00L08c<]024b;00S=2h08cD_01HY8`0J;BL093La00807c8/0P0M<2X0100O<R`08cH`024d;P0N
<B/301lb;00301lb;@0O<Rh07c8^00<07c8^00T09STe0313?`0P<bl08cHb00hQ7@0R=C40:3`k02@h
=`0S=cH00P0T>3L00`0/@3l0?U9A02m3@P0302Di>00803=7AP0J<2h09C/i02a2@00O=3D08cPi03I;
C00[@4<202]0@@0802Xo@00Y?cd0:3hl02Hj>@0^@T409CTh02a0?`0aAD@202/o?@8093Td01h07c@_
0315?`0hBdD0:chh02Tl=P0bAd80BUmJ03eCD00Q>CT0<4Y;039=C`0`CU00;da@035@E@0gE5P0<TY<
03U>C`0hCDh09S/l049GF00eBT/0>e1A03=8B@0]@T<0@UMH03Y?D00kDe<0=4a<04EOGP18HV420319
AP0b03iGE01<HV00=4U702/o?P1PM7D0LXJ703eADP0kCdh0>dm=03eAC`0hC4X0<TM203=8@`0_A3h0
;D8k02m4?@0`AC`0:d0g02Ll<`0_@S`0;D0j02m2?00bACl0;d8l02/n>00aA3h0?4m905=VH00W>S@0
=dY403mCBP0eBCd0=d/o03I:?P0cAc/09cT]0312=00cACH0;Sl_03A5=@0`@C00:SPW02hl;@0f@c/0
=4<n049AC00fAD009SHc03A4@P0gAdH203I8B00M03U;C@0nD580@UAF045CD`0mCdl0<TE303=6@P0g
BTH0=DQ403U<B00lCd/0>4]703A7@`0_@Sh09SLc03e<A`0a@3/0:3Lb02He<00R<B`0:3Lb02Lf<@0Z
>C@0<3lj03=2?@0/>cH0930[01dV8@0S;2L00P0U;RT07@0V;bX092dX02</9`0T;BP09BhY02L`:`0Y
<Rd0:SD_020[9@0M:28062<M01XU7`0Q:RD09B/W01lU8@0P9R80AT]703a1?@0K8Ad08BXW01XS800I
8Ql09bd[024W9@0`=S@07R8Q01`P7`0J71/05aTH00805QPG00@05aTH01XL6`0K7A`061XI0P0H6A/0
3P0;30h06a`N02X[;@0S92H05aPJ01PI6`0E5aH03@l>018D4`0K7A`07b4P00P:2@0F61L04aDD0P0J
71/00`0E5aH06adL01HF500201DE4`0301XJ600I6AL020P600804a<A0P0D51800`0C4a404a@?01@E
4002014B3@0B01<D3`0C4a003`l=014A3`0A4A004Q8B01@D500E5AD05QHF01<C4`0];Bd0DU9B01`L
700B4Q805ADE02/[:`0J6QX07AdM0P0I6AT01P0?3`l0518C014?400A3a004Q0A010>3`<03P`=0P0D
4Q<03P0;2@X020H9018?5@0100@02`T>01LE6P0L6Qd04a4D01/I700;2@X01`D600@20`0B41402PP9
0P0H5QL06`02004040h?01@B4`0;2@X04Q0A014?40091`P02PP900d;300<2P/03P`=01DC500F51D0
2@L800X82@0?3@h02`T:00T7200B41404a4B00`:2`0;20X03PP<00l93@0=1`/030H:00d8300300l:
3P0900d:3@0;2@`02`T<02<Q8`0C4A8020@501@@4@0H51D02@<5008040L:0P0A1PX201872`080148
2`0>20X03PP:00d72@0>20X03`T;00`6200=1`T200h82P803@L901D040L:00`11@0@1@T03P<700T0
0P0=0PH05``@00h31`0@1@T02`0400l4200;0`D06A<E00d72@06008050h@010:300400003`T;00X4
1P0;1@L00P0<1PP0100A2`d03`@800h31`0?10P201872`0700d21P0>0`L040D901052@0>0`L03`@8
01052@0Dooooo`006oooool500lA300300h@2`0B50l03@l:008051HA00<03Q0;01<E400@4Pd00P0?
4@`200h@2`09010B3@0A4`h04A<?01<E400k?CP04aD@018D3`0?4@`04Q@?00802`d800l0418=00T;
1P0A4`h0418=00h@30092`L05QPC01<E400j?3L061XE00h@2`0;3@P04Q@?00/=200>40/00P0<3PT0
100?4@`04Q@?01@F4@0=3`X400h@2`0C00lA300>40/04A<>00d?2P0o@C`051HA00/=200>40/03@l:
00d>2P0A4`h03Q0;00/=200@4Pd04A<>010B3@0B50l04aD@00h@2`02010B3@0400h@2`0?4@`051HA
00lA308030h900T04A<>00h@2`0<3PT03Q0;010B3@092`H03@l:00T;1P0B50l00`0=3`X200`>2@07
01<E400=3`X04A<>00T;1`0<3PT05QPC010B3@0200lA300=00d?2P0D5Q406Q`G010B3@0>40/030h9
014C3P0B50l03@l:00h@2`0;3@P03@l:00h@2`0200/=200=00lA300720<05AHA03Df<@0C50l030d8
00d>2@0@4@`02P/8014B3@0<3@P03Pl:00d>2@0200l@2P0400h?2P0=3PP0414<00l@2P803Pl:0280
5QLA00d>200@4@/03@h9014B300=3PT0414<00d>2@0:2`L05QHD010@3P0L71/05ADE04=3@`0[:b/0
=SHd04]:B00@40d051HC00h?4@0C6AX02a<E00TB500F7al01Pl<01<I5`0<4@`051TC01@F4`0];b`0
51HC01DG500?4@h051HC0P0;3@X300h@3@08010B3`0@4Pd02@/600d?2P0H6QD030h900lA300Q8ah2
00lA300600`>2@0E5a802P`700h@3@0@4Pl03a4>0P0>40d0400=3``0418?00lA3P0?4@h03Q0=010B
3`0B51405aLE01`L6P0G5aD020P701TI5`0>3P`0410>014A3`0@40h200h>300D018C4@0B51403Q0=
00d?300A4a00418?00h@3@0@4Pl04Q@A00h@3@0;3@X03@l<00h@3@0<3P/03@l<00lA3P0;3@X04aDB
00h@3@0?4@h4010B3`0>00`C4P0:5QH02a@C00XB3`0?5100418=00lA300=3PT03@l<01TK6P083@h0
5a`M01<F5@0A4a0300h@3@08018D4@0:30T04aDB018D4@0<3P/0418?00lA3P0>3`X200`=200O00h?
2P0@4@`04a@?018C3P0D5A004A8=00h?2P0@4@`04A8=010B3@0C5A004A<>018E3`0>40X041<=014C
3@0@4P`03a4<00lA2`0>4@/03@l:00h@2`0=3`X03Q0;00lA300>40/0418=014C3P0@4Pd03a4<00h@
2`0200d?2P08010B3@0?4@`0418=018D3`0A4`h030h900lA300A4`h200h@2`0?014C3P0?4@`04aDB
014C400C5A805ALD01<E4P0B51402`d:01TK600;3@X04aDB01@F4`0E5a@04aDB00804Q@A00<051HC
018D4@0?4@h00P0D5Q<0100F61D04Q@A018D4@0H6QL6018G4`08014F4P0B5a<051TE01@I5@0C61@0
4QLC01HK5`0D6AD201DK5`1B01@I5@0F6aL051XF01XP700C61@04QPD00hD400@5A405adK01DK6@0H
7Q`06b@Q01DN6`0H8Qh05b8N01`W8`0J9R805R8N01TU8@0K:2@07R/W01TW8P0P;RX072/V02@d;P0P
<2/07c0Z03=5?`1=H5X093Pa01@X8P0P=2h08C@^02<f<00Q=2h072lY01ha:`0P<bd08SD_01lb;00N
<B/09CPb01d`:P0R=C008SDa01lb;P0M<2`0:chj04=FDP0S=S8062/W02Dh=00[?SX07S4]02@g=00T
>3L09SXj02/o?`0X?3`08cLg028f=P0/@4009SXj02Pl?00O<c<07C4a03eAD@0hCDd08SLg028h=P0^
A4<0:T0o02]1?`0_AD@0;49102a1@@0aAdD0IWaj02i3@`0V>SX0:Shn02Lk>`809c/j02`0:Shm0396
A00Y?C/0=4Q503Y?BP0aAT40;D8k03I7?`0fB400<4<m02m4?`0]@Sh0<da902e5A@0`C4h0;Ta>02Y9
C00ZBTh0<E1C039:B`0jCdl0>Di>03mDE01HKFd0<dU803U?CP0hCTd0>4e=0397A`0iCdh0=4a;03aD
D`0iDe40=e5?03Q@C`0oEeH0>51?03M=C00kD500<DE503mCD`19GEd0>Ti=041DD`80=d]90380=DU7
03M;B00lDDd0<4E002m4?P0^@c`0;T<k02m4?00`ACd0<4<m03=6@00dAd40<D@n02e0>P0Z?CL0<dI0
04QKE@1FJF<0=4M103E8@P0_@cX0<dLl041DB00jCT80=DTm02Xl;P0^@380=4Hf02`m;@0b@c<0<44_
02dk:P0b@340=D8k03I5@00hAd80>DQ302hn>`0a@Cl0=DE30395@P0fB4L0?4i=03e@C`0oDDl0>di;
03I9AP0gBTH0>Te903U<B080>4]700d0>Da803Q;A`0eB4@0?4m;03M8A00X=c80;3/f02/j=@0W=S40
7bhY04YIE01;FUD0>TU400809C@_00H0:cXe02Pc;P0T;BP09RlZ020Y900O:2<402D^:@8092dX03L0
9RlZ01dX8P0P:bD08B/U02H`:`0P:RD072<O01dS7`0Q9b<07b@P02<X900O9200:2hZ03a2@00Z<c00
6b@Q01lU8`0K8Al08bTW01`P7`0I7A`06A/J01LI600F61L071hM020Q8P0V9bP07AhQ01<D5`0I6Qd0
6Q/N01lP8P0J6ad07AhP01PI6`0J6ad061TK01PJ6@0L7Qd0828Q01HH5`0G6AP061XI01HH5`0D5QD0
6Q`K01TK6P0F61L07b4P01PH5P0D51806a/I02/[:@0];B/04Q8@00804a<A00h04Q8@014A3`0B4Q00
4Q<>01@E400C50h04Q<>01<D3`0C4a00410>01<C4@0C4a804Q8B01@D50805ADE00l03`l?00`<300N
7Qh030`<00h>3P0?3`l07AdM018B4P0>3Ph04a<C018B4P0=3@d04Q0A01<A4P0G5AH00P0@3Pl02@0<
2P/040h?01<A4P0B41404@l@00d;300:20/040hD01<A5P0200h<4@0G01<A500A3a80518E01hL7@0G
5AH03P`=018@4@0>30d01P@500l=3P0A3a002PP901PF5`0I5aP0NGMh02<Q8P0=2``05A<D00T7200@
3Pl03`d>00`:2`0:20T00`0<2P/01P0>30d02`X:00d;300:2@T020H7014<3`804@X>014040T>00l9
3@0?2Ph04@`@01<>4P091@T03@/>00P72P0@3a403@/=00P51P0D41402PD700T51P0@2P`04@P;00l6
2@0300h4200500h41`0>20X03PP:00h82P0=1`T00P0>20X0600?2@/03PP:00`6200@2P`03`T;00`6
200A1PX04PL;01462P0@1@T03P<701472P0>0`L03@@601062@0@1@T050T=00l52@0=10L040X<014;
3@0;1@L03PP:018<3P803@L900L03`T;010:300;1PL02`D701052@0?10P040D900804@H:00L03`@8
01052@0A1PX040D900h31`0?10P04PL;01Cooooo000Kooooo`08010B3@0>40/030h900`>2@0>40/0
418=00/=200A4`h2010B3@0L014C3P0;3@P01PP300h@2`0B50l04aD@00h@2`051`8010H101@F4@0A
4`h0418=00`>2@0>40/06Q`G010B3@0>40/05ALB0043000S9B003Q0;01hP6`1OHE`0<cD`00X<1`0;
3@P030h900h@2`802P`700D03Q0;00d?2P0=3`X03@l:00h@2`0400lA3005018D3`0A4`h03a4<00lA
300A4`h00P0?4@`040010`008B<N00`>2@0A4`h030h900/=200<3PT03Q0;00`>2@0;3@P0418=014C
3P0;3@P03@l:00h@2`0;3@P200d?2P0700/=200>40/03Q0;00d?2P0;3@P030h9014C3P0200h@2`0G
00X<1`0?4@`03@l:01LI500?4@`06Q`G00D70`0G6A@061XE00H810082PD03@l:00D70P0E5a8061XE
010B3@000@002P`700`>2@0@4Pd030h900lA300G6A@00P0?4@`01@0=3`X04Q@?01@F4@0>40/030h9
00804aD@00H04Q@?00d?2P0:30L02P`701/L5`051P4201TJ5@08018C3P0:2`H04A8=0042000720@0
414<034b;@0=3PT300l@2P0500`=1`0=3PP0414;010A2`0>3`T00P0<3@L02`0>3`T0414;00T:100>
3`X04a@?018C3P0@4@d051@B00l?3@0@40l03`l?00805aLG01<05aLE00l>300?3``04A<@00lC500H
7b005QhP00hH6@0C7Ad02a@A01@J600D6A@041D?00T;200M7a`02@/800h@3@0@4Pl09RPU00803@l<
00@03Q0=00lA3P0?4@h03a4>0`0=3`X00`0>40/03a4<00lA300200d?2P0500`>2@0=3`X0418=018D
3`0C5A800P0=3``03`0?4@h03Q0=00`>2`0@4Pl03Q0=018D4@0A4a003Q0=00lA3P092@L05QHD02h^
;00C4a406QXH00X:200200h>300700l?3@0>3P`03Ph<00l@3@0A4a003Q0=00`>2`02010B3`0400lA
3P0@4Pl03a4>00h@3@<030h;01P03@l<00lA3P0@4Pl0418?00lA3P0=3``03Q0=010B3`0?4@h03@l<
00lA3P0?5A@031HG00`E500:4Pl02Q0<00hC3@0A4`h03a4<00@60`0@4A404Q<E02/_<@0?4A02018D
4@0>00d?300<3P/04A<@01@F4`0E5a@02`d:00`>2`031@804A<@01HG4P0D5A00414<00l@2`0@4@`2
014B3@0A010A300>3`X03@h900h?2P0A4Pd0418=00lA300>40X03A0900hA2P0?4P/03Q4:00lB2`0@
4Pd03a4<00lA3P0>40d00P0A4`h2010B3@<03a4<0P0@4Pd2014C3P09018D3`0G6A@02P`7010B3@0B
50l03Q0;01TK5P0A4`h051HA0080418=00D05aTD01@F4@0@4Pl04Q@A01<E4P0201@F4`0:01<E4P0K
7AX0:2XW00h@3@0H6QL04A<@01@F4`0C5A804Q@A014C40<0418?00H05QPE01PJ5`0F61D04Q@A01DG
500J71T601<H500@01@I5@0G71P06AhJ01TN6P0F6aL05AXF01HL600D6QH02Q0<01DK5`0?5A406b4M
01hT80001@408BLS01PN6P807B<O00H05Q`J014G5@0D6QP0624N01LP7@0E7a/201DP700601HR7P0H
92006RHR01/Y900Q<2/06BPS0P0M;2L04@0dACl0:CXd01`_:@0Q=2h0;D4k01/`:@0L<BX0>De60354
?P0N<B/08C@^02Hi<`0N<B/06RdW01`_:@0S=S009STc00809CPb00T06bhY02<f<P0H:bL07C0/028e
<@16FED083<_02@g<`0J;BT00P0R=C40100aA440:Cdl02Tm?P0X?3d302Hj>`0F018V9`0T>3T0;d=4
02Hj>`0X?3d0>4a=05AYJP0fBd`0:d4o02Lm>`0S>CH0:T0m02a2?`0V?3T0:3hl02a2@01cRHL0;D93
0355AP0_@d@0;41102Xn?@80:Cdl01T0:Shl02Tm>`0W>cT0<dQ303U>B@0W?3L0=4M10396?@0dBD80
<dQ302i4@00]AT80<D]8035<C00^C4h0;D]=02a;CP0]Bdd0=Ti>03A:B00^A480=de;03iDDP0/@T00
=Ta:0080>4i<00@0=de;03Q>C00hDDh0>U=@0P0iDe004`0oEeL0@5QH03A<C00fBd`0=DU:02m3A00c
AdH0?51?03Q<B`0dB4L0<dM603Q<B`0fBTP0<TI403I:B00`AD00;D8m02a1?00]@S/00P0^@c`0:`19
G5H0FVeW04=FD00]@3X0;T4k02/n>00fBD<0=DQ20395?`0eB480>4]503I:@@0]@CH0>Ti20355>@0`
A3P0<48f03M9>`0iBc`0=TLg02m0<00/?B`0;cd/02lm<00c@3X0<d8m03I5@00^?CP0:c/h0392?`0c
@d00<4<o03Q;A`0nDDd0?4m=03E8@`0/@3L0;D4h03U<AP0gBTH0=TU503e@C00gBTH00P0eB4@0700b
AD40?E1<03m@C00Z>C@093<^020_:P0L:bH0:3Lb03A3?P0T<bh07B`W02<b;@0X=c80:STd02Pc;P0Q
:RD08R/V01lX8`0N9b808b`W02lh<`0/=C00:C8]02Xc;P0/=C00;SLb01lZ900Q;2H2020Y900@02</
9`0O9B4082HR020V8P0O92007B8N01hS7`0S:2@09bd[01`U8P0G81d06b4O01PN700G7A/04aLF018F
5@805QPG00/05ALF01hO800Q8RH071dQ01PI7@0J6al071dQ01XK7`0I6Q`0824S01HG6@0201/L7P04
02//;P0F61L061XI01LI60805ALF00P05QPG01LI600H6QT05aTH01DG5P0F61L06A/J01PH5P805QHD
00D07AdK01`L6P0:2PP05QHD01@D4P02018B400:01<C4@0C50l03@h900h?2P0A4Pd051D@01LG500H
61H04A4?014A40@04A4A1P0?3`l05`2GUiL0?3`l01`L700820P04a<C00T92@0K6AX0F5IG04a:B`0>
30d03`d>01HD5@0B4140518C00h<3@0;2@X03@/<00d;3P050PP03`dB01HD6@0=2a002PP;008040hA
00<07A/L018@4@0=2``00P0@3Pl0200C4A801`D600d;300H5QL020H700/92P12@4402`T:0P0=2``0
1@0:20T03@/<00d;300>30d040h?00802PP900L02`T:014?400?3@h02@L8018@4@0>30d030H900<0
4PT>0P0@2Ph01`0:1@P04PdA00X82`0:2@`00`<500410`091`P00P0>2P/300l92`0601072P0A20/0
40L:00h5200A20/06A0C1P0=1`T03@080P@09R0R01/E5`0F41801@0101<>3`0E30l05``@01@93@0A
1PX03`@801D:3P0;00@00P0@1@T00`0<0@D03P<700`21@0600h82P06010:3005004050h@00@0000H
4Q@02@<51P0?10P201052@803`@80P0@1@TDooooo`006oooool0200>40/03@l:00/=200;3@P03@l:
00h@2`0=3`X06A/F0P1ADdh0100I6aH03@l:01<E400?4@`200d?2P0300lA300C5A0020X500805ALB
0P0B50l04`0C5A00EEMB07MiM00=3`X05ALB00h@2`0:30L03Q0;01TK5P1IFeH0;BlZ00<5000<3PT0
2`d800h@2`0;3@P030h9014C3P0@4Pd00P0=3`X01`0>40/03a4<00lA300?4@`0418=018D3`0A4`h0
0P0@4Pd03@0A4`h03@l:010B3@0D5Q40008000`>2@0>40/030h900/=200=3`X03Q0;00d?2P0>40/0
0P0B50l02P0<3PT02`d800/=200=3`X04Q@?014C3P0>40/04A<>010B3@0=3`X200/=200I010B3@0<
3PT030h900h@2`0F61<03@l:00P:1@0210002`d800X<200>40/00@<001DG4P0?4@`03@l:02@V8@0>
40/02`d800h@2`0<3PT05aTD00/=200B50l03Q0;00L9100200`>2@0400h@2`0<3PT03Q0;00lA3080
2`d801H07AlJ01/M600F61<04aD@014C3P0>40/05AHA00X;1P082@H04a@?00L80`0C50l061TD010A
300>3`X06Q/F04Y;AP0D5A003@h800l@2P0@4@/03@h80P0;30H0800@4@/03@h801DF400E5Q003@h8
010A2`0;30H04A8=010A300>3`X03`l<00d=2`0?3`d03Ph=010@40092@T03Ph>018B400>3P`04A8>
01DG500D61T06b8S02D_<00O:BX09c4a00hI5@094Pl01`l900X?2@0D5Q<03@l<0P0B5140100=3``0
7b4N010B3`0?4@h200h@3@8030h;01l02`d800d?2P0?4@`03a4<00d?2P0;3@P03Q0;00/=200:30L0
30h901@F4@0I6aH071hK00d?300:30T03a4>00h@3@0;3@X0418?00h@3@0E5a@05aTF00lA3P0<3P/0
4A4?02DU8`0l?3X0820N024Q7`0C4a403`l=00<03Ph<00D03`l=00l@3@0?4@h03Q0=00`>2`02014C
400900h@3@0?4@h03a4>00lA3P0=3``030h;00d?300?4@h0418?00804Q@A00`04A<@00lA3P0=3``0
3a4>00h@3@0=3``03Q0=00hD4`0=5AL031DD00/A3`0:40`200hC3@0600`>2@0I6aP09BLV03Hg>@15
ATT03Q0?100=3``08@0?4@h04A<@01<E4P0O8Ah0<C<`00P:1`0=3``0414<014B3@0@4@`03Pl:00l@
2`0D5A004A8=010A300>3`X03@h900h?2P0A4Pd04A<>00lA300=40T02`h700`?1P0>4@P030l600hA
2P0A4`h04Q@A014C4P0?4A00418?010B3@0300lA30803Q0;00L0418=01<E400D5Q4051HA01<E400A
4`h03Q0;00809BLR00@03a4<01LI500C5A005ALB0P0B50l06P0F61<051HA01<E4P0A4a00418?014C
400E5a@061XG01@F4`0P8Ql030h;01DG500@4Pl04aDB01<E500E5aH051HE014C4P0C5A@05ALF01LI
600H6QT05QPG01<E500F61L06Q`K1P0C61@09P0D6AD05AXF01LL600G71P05AXF01@I5@0J81`05adI
00D;1`0E6aL03Q@@01`R7P0C6AD03aDA01HL600>51004QPD01LM6@0F71/041HF01PN7P0I8R404a`K
01DN7@0E7ah05R0O01PS8P0K9bD07BTW020]:`0L:bP04R4N01`/:@0W=c@0=4A102Hg=00P<bl07C0/
0P0M<Rd06`0Y?ST0>e1;02m4?`0Q=S407c@_024f<@0S>3<0:3dh01ld;`0F:bH0;T<n018W8P0U>SD0
8cLb02<f<P0D9b<08C@`01<V8P0Y?3P06bhZ01ha;@0hBdL0:3/g02Dh=00D9b@09SXi02Lk?00202Pl
?@0D02Lk?00V>S/0<4A502a0@@0L<340:cm002Pl?@0/@440>e1A01hc=00W?C/0=D]802a2?`0U?3L0
:D0j02Hm=`0Y?c`09C/i03eCD@0W?3d202e2A@0b02a1@P0[@440;45202e3@@0kDDl0>Dm=02Y0?@0V
?3T0<DM402i3?P0dBD80<TM003E:@`0dBD@0;D@o02a5@@0hDTl0;dY902Y8B00_CDd0<DmA02a8B@0e
CDd0<4I402i4@P0kDDl0AE]I03E;B@0jD4h0=de;03Q>C00kDDl0?59@03I?C00kE500=4m;03iHE@17
Gel0@5QI03A<CP0gC4l0<dQ:0314A@0fBTT0?E5@03Q<B`0aADD0=4Q703U=C00fBTT20314@P0f0355
@`0/@C`0;D8m0315@00Z?cP09CXc04IID`1NLF/0@EA>02i1>`0eB480;d8l03Q;A@0/?cT0;d8l03I9
@`0gBT@0=d]203Q<@@0gBd00:Shc02m3>00fB3`0>D/o03U;?P0nCT40;clb02`m;P0d@S<0;cd`03A1
>`0fAD00>4M20391?00b@cd0=4Do0311>`0_@S`0?4m904=FD00mD4`0<4@k02Lk<00/@3D0>De503Q;
A`0iC4P0?e9@03]>C00gBTP0=4M403=6@P0bACl0;3dg0P0V=C005@0U=2l09cHa02`k=P0`?cX0:STd
02Pg<P0/>cH0:STd02Lf<@0T;bX08R/V024Z9@0O:2<07RLR028[9P0a>SD0;3D`02L`:`0X<B`0:S<^
02/d;`0202<]9@0d020Z8P0R:B809RdV02D/9@0R9b4082DO01hS7@0Q8ah08R@O024T800J81h0624N
01/T8@0L8R005adK01TO7@0L81l06AdL01XL6`0H6QT05QPG01hO800P8bP06QdR01HI7P0K7R<07R4V
01XN8@0F6Qd09BT[01PL7@0O8b@07B4Q03Hj>@0G6AP061XI01DG5P0C5A@051HE01PJ6@0L7Qd06Q`K
01@F5@0B51<05ALF01XL6`0?3`d04a<A018B400D51805aLE018B40@05ADC00@051@B01<D3`0D5A00
51D?0P0C50l0100C51004Q8@014A3`0A4A04014A4@80410@100?3`l02`1`L70061PH01lO7`0<30`0
5QHF01@D500B4140D4i?04A2@`0F51D04@l@00803P`=00h03`d>010>3`0@3Pl06ALH02@R9@0[:Bl0
108701@B5`0@3Q<04@lB01<A500;2@`03@/<00`:2`803`d>01403P`=00`:2`0P7Ql03@/<00l=3P07
1@H04Q0A0040000<2P/04@l@00X82@0<2P/03P/<00h:2`0B3Pl05Q8C00h:2`0200`82@0602/W:018
A4D05A4B00@00@0I5AH03`P;0P0C20h201893P08010:3P0E3a<04PdA00@21@0<2`h092@V010A4`0?
3@l500l92`0600d72@0@2P`04@/=00`6200?2@/07QPJ1P0=1`T04P0F4180SHN904<m?`040000:28T
00d82@0@1`P04`X;01D<3@0=10D030<40107200:0@8040L801482@0=10D03PD600`310H03PP:00H0
50h@00P2100E3a40100000/51`05004800l420803P<70P0?10PDooooo`006oooool200lA30803@l:
0`0?4@`02P0P8Qd0aLO20<G7`P0P8Qd03a4<00h@2`0<3PT051HA018D3`0;3@P2010B3@0G00`>2@0@
4Pd03@l:01<E400=3`X092HQ03<e<00>40/04Q@?00P:1@0E5a804A<>00X<1`0C5A002@/700h@2`0A
4`h03Q0;014C3P0>40/03@l:00lA300>40/00P0=3`X0200>40/03a4<00lA300?4@`03Q0;00d?2P0<
3PT03@l:0`0>40/02`0=3`X03a4<010B3@0B50l02P`700d?2P0<3PT03@l:00lA300=3`X03Q0;0080
4A<>00@03@l:00/=200<3PT03a4<0P0B50l0300>40/0418=00lA300=3`X02P`700/=200>40/02`d8
00X<1`0<3PT04A<>00d?2P803Q0;00h02P`800d?2P0D5Q404A<>00`>2P0;3@X05QPC03Tk=P0F61<0
2P`7024S7`1EEe803@l:00`>2@804A<>00H03@l:00h@2`0=3`X03a4<00h@2`0=3`X200`>2@0:00d?
2P0D5Q40418=00h@2`0A4`h04aD@010B3@0720@05aPC01@E40803@h900<051D@00`=20082@@00P0>
3`X0100G61<02``700d>200>3`P200l@2@0401<D3@0G6140414:00l@2@808B8K02403a09010A2P0D
5@l03a0;00T:1@0>3`X05ADB00h>300@40h03`l>01PH60092@T03Ph>01<C4@0B4Q004aDA018G4`0E
6AX06b@T04MADP1ZMGH0@de=02<^:P0X<Bh06R8L01<J4`0H6QL051HC01PJ5`0S9B803Q0=00/=2P0@
4Pl00P0?4@h00`0>40d03@l<00`>2`0200d?2P803Q0;00<03@l:00`>2@0=3`X00P0<3PT01P0>40/0
5ALB01TK5P0G6AH03a4>00`>2`803@l<01<030h;00lA3P0@4Pl051HC018D4@0>40d0418?00h>300=
3@/061PF00d=2`0D518030`:014A3`0?3`d03Ph<00l?3@0@40h0414?0080418?00X03a4>01@F4`0D
5Q<03a4>00h@3@0?4@h0418?00h@3@0=3``03Q0=0`0@4Pl3014C40D03a4>01`03A4A00dB5@0=4Q<0
2a0>00T?2`0;4@X03aD>00P>1`0=4`l061/J014D5@0;3@l04A<B00lA3P0>40d04Q@A01@F4`0A4a00
51HC01TK600X:RL0>C/h01LI5P0D5Q<03a0;018C3P0E5Q404a@?0P0B4`h00`0@4@`03a0;00l@2`02
00l@2`0>010A300?4@`0418=014D3@0A50/03a8800d@1P0@4`X03a8900lA3@0@4Q404A8C01<D5P0?
4@h500lA300:00d?2P0@4Pd04Q@?018D3`0?4@`03@l:00h@2`0E5a807AlJ01TK5P803a4<0P0A4`h4
010B3@803a4>00L0418?014C400C5A805ALD00d?300F61D03@l<00804Q@A00L05ALD01DG5P0A4a80
4A<B01HH5`0D5QD04Q@C00805QPG00@051HE01<E500F61L061XI1P0C61@601DJ5P0<01HM6@0@5a<0
4QXE018J5@0J8Qd04a/F01XQ7@1UK6P04a/F01/R7P0?5Q80620K0P0D6QX0100N92@05b0O01HO7P0O
:2L201XT8`0o01/V9@0M:BL07RXX01h/:@0N;BX09cHc02@d<@0S<c009SLd01la;@0T=c<09CXe020f
<00S>C<09S`g02Hk=P0O=2l07S<^028g<P0Q=S4083D`01db;@0Z?cX0:Chi06YoNP0W?3L07c@_02<g
<P0W>SH07C0/02Lj=P0M<2`093Lc02Dh=00V>CD0PiJB02@g<`0P<bl09cXg028f=P0U>3/0:Cdo02/n
@@0Z?D009SXl02<g>@0Z?T00:Se002e1@`0I;Bl0H7=f06b1P`0mDU<09S`j02Hl>@0Q>380:3li02Hm
=P0]A3d0:T0l02a2@00X?S`0:Sm10080:Ci103P0:Sm102]0@@0[@440:d5002i4@P0Z@3h0<4I402a2
?`0eBdP0HWQe03Y@C00bBD<0;dM202i6@@0]AD40<T]703UBC`0bC4P0;DU6031<B@0bCT/0<Da:03A=
BP0eBdP0<TQ503I<B@0kDDl0=D]903M=B`0hCT/0>4i<03U?C00iCdd0>55=03aED@0fDD`0?eUF049J
FP0hD540>E5D03iCE`0hC4h0=d]<03eAD00oDe40>dm=03M;B`0iCDd0>dm?03]?CP0jCT`0>De<03=7
A@0bAT<0<DE20315@080;T<m00X0=DQ203I9@`0aA3h0=TU303M:A00^@C/0BUeG03=6@00hBdD0?U5;
0P0hBdD0201<H5L0?4m802Xn=00bAS`0>T]203Q9?P0fAc`0=4@j0P0b@SH0:`0d@CH0=D8h03<o>`0`
?cX0=4<n03Q7@P0gB480=TM103=4?P0dAd00@UE>04MKD`0oDd/0;D4f02Hk;@0aACT0@5A:03]>B00j
CD/0?e9@03a>C@0hBdT0<dI30395@@0Z?CL08C8/02Th<`0/>cH0:CPc02ln>@0d@ch0;chi02He<00T
<bh09SD`02Th<`0[>SD0:3<^028[9P0Q:RD07bPS020Y900R:bH00`0X<B`0300S;2L08BXU028[9P0T
;RH08bdU02@/9@0S:R<08RTR028X8P0R9b4082DO020S7P808bDP01l07R4L01dS8@0K924072DR01hT
8P0M8b40728P01`P7`0H71/071hM01dO7P0K7A`07QlP024T:P0O8RT07B0W01/N900J7B806QhR01<G
6P0L82809BTZ00lC500C5aL05a/J01/M700J71/05aTH01DG5P0G6AP06adL008061XI00`05aTH01DG
5P0G6AP06Q`K01`L6P0G5aD04a<A01@D4P0F5Q@05ADC018B400D518201HF500:01<C4@0?40/061TD
01LH4P0D5A004a@?010A3@0?3`d04Q8@018B4@804A4A0P0@4100100B4Q804A4A010@400@410200l?
3`1201<C4`0F5QH030`<014A4@092@T03`l?010>3`0F51D04a4B00h<3@0A3a006ALH00l=3P0>30d0
4a4B00h<3@0B414081hQ02d[<@0;2@h05A<H00T7300H5QT04a4D010>4@0=2``03`d>00d;300<2P/0
4Q0A00l=3P1[JFX0?3Xk00l=3P0A3a003@`<01DC500>30d02PP9018@4@01000040d>00h:2`0A3@h0
5A4B00l;300>2P/040`=02<O800e<C805A4B00/7200G4a@040P<01<73@0B1`d04PP=01483@0?2@d0
3@L;01LE601gMGP0JVY/01PI6`051PP03P`=1@0?20X01P0>20X03`T;00h82P0<1PP03@L9014;3@H0
3@L9018030L801<=3`0?2@/040X<00d72@0?2P/0204101082@0L51D04PX;00l7200;10D04@T:01@<
3@0A2PX030D500l8200B2P/600d72@0600/51`0C3@l02@@500l92`0J5AH03`T;1`0?10P01@0>0`L0
3@8600d21P0>0`L03`@801Cooooo000Kooooo`H03a4<02404A<>00`>2@0[;BP0:bdX00`>2@0A4`h0
5aTD00h@2`0G6A@051HA00/=200L7QT02@/601@F4@0T9R401`T400h@2`0=3`X05QPC018D3`0A4`h0
4Q@?01@F4@000@0030h900d?2P0I6aH0418=00/=200B50l0418=01<E400?4@`00P0>40/0100;3@P0
3@l:00d?2P0>40/300lA300E010B3@0<3PT02`d800h@2`0?4@`03Q0;00lA300C5A000080014C3P08
2PD03Q0;00d?2P0<3PT03Q0;00lA300>40/030h900/=200=3`X03a4<00802`d800L03Q0;010B3@0?
4@`030h900lA300>40/030h900802`d800D03Q0;00X<1`092`H03Q0;00d?2P0200`>2@0>00T;1P03
1@009RPS00H80`0>40/04aD@01@F4@000@00418=00X<1`092PL0F5YE0;2b[@0N81/200X<1`0;00d?
2P0B50l04A<>00X<1`0?4@`04A<>00h@2`0<3PT03a4<00h@2`0?4@`00P0>40/200lA300>00`>2@0H
6A@010D000h?2P0A4Pd03@h9018C3P0J6aH02P/6014B3@0N7aX02P/601PI500=3PP200d>1P0500l@
200G61007b0H01DF3P0=3PH00P0@4@T02`0=3PH05AH>01<D3P0=3PT0414<01<D3`0?40`030`:01<C
4@0:2PT04A4A00803Ph>01@051@B01XJ600I6QH05a`H024W9`0g@D40SiVJ0>kjnP39e=<0R9>?05aU
HP0O9b405QdF00h@3@0B51401@L401PJ5`0C5A803a4>00d?30<03Q0=0P0?4@h0100@4Pd03Q0;00h@
2`0=3`X200h@2`0<00`>2@0>40/03a4<00lA300@4Pd04Q@?00`>2`0?4@h03Q0=00/=2P0<3P/03Q0=
0P0?4@h02`0>40d02@/800d?300E5a@05aLE00/;2@0B4Q0051@B01LG5@0>3P`0410>00<03`l=00L0
410>010A3P0A4a004A<@010B3`0D5Q<04aDB00<03Q0=00<03a4>00h@3@0>40d00P0>40d0100=3``0
3Q0=00h@3@0@4Pl2014C400A00lA3P0A4a004A<@010B3`0?4A404A8F018C5@0>4Q40314=00`C300@
5a003aH?00dC3`0Z;bd07B4R01XN800?4A000P0=3``2014C400700h@3@0B51405ALD00`>2`0@4Pl0
3a4>01<E4P0200d>2@0400l@2`0C50l051D@018C3PH03a0;00h02P`700`>2@0@4`/04A@;00lB1`0;
3P<04aH=014D2`0<3`X02`d<00h?4@0C51L04Q@A018D3`804aD@0P0D5Q400`0<3PT03a4<018D3`02
01<E400?018D3`092`H051HA00/=200:30L05ALB00lA300@4Pd03a4<018D3`0C5A00418=014C3P0=
3``0418?00804aDB01@04A<@00lA3P0C5A805ALD01HH5@0C5A8051HC01DG500H6QT04A<B01DG5P0Q
8b806Q`K010B4@0E5aH04aDD018D4`0C5A@051HE01DG5PH04aPD00l05a`H01DJ5P0C61@051TE01DJ
5P0E6aL05QhI00hG4P0F7aX03aPC024Z9@0?61<0624L01@M600K91l00P0@6A@01`0C71T061hN01DK
6`0F71`05AhM02Xc<P0]=cH00P0J92<05@0I92<06RHT01/W9@0L:bP04b<P01h^:`0K:bP0:SXg02Hi
=@0R=C40:3/g02Tn>@0P=S007cH`020g<@0R>3808SLb020e<00O=2l07C8]028g<P0202Dj=@0I01`a
;00R=c806c0[0315@00J;RT09CPd02<f<P0P<bl093Lc024d<00[?SX072l[01ha;@0Z?CT0>Da801ha
;P0R=SL093Lk02Tl@00[?T80:Ca002Hi?@0`@dL0>TeA02Tl@0020313A`0A024d>00X?D005R//028h
=`0^A440:D0j02Dl=00P=bl0:d8j02Po>@0cBDL0>e5?03A9C00Y?T40:Sm202a1A00]@T<00P0^@d@0
200`AT@0=de;03A:B00_AD80;TA1028k=`0Z@cl0:T@o0P0`BDD202U2?P0?03=<B00dCTX0<Te802i9
A00`BTH0=Di:03=9AP0iCd`0>4i;03=9AP0aAd@0=4Y703=9AP0fC4T0=de:0080=D]808h0=e1<03QA
B`0hDdd0>59?03A<C00aBD`0>E5E0356B`0_@dL0=4Q903Q<B`0jCd/0?E5?03]?C`0jCTl0=TY;03Y>
C@0oDe80?U9A0314@P0bAT@0;T9002]0>`0aAT40=da703=6@00bACl0=dY40395?`0`@cd0=dY403mB
C00cAT00=DQ203U<AP0dAd40<TDo03Y=A`0cAT009cXd0395?P0jBd<0>da403U:@@0^?S@0=THl03A4
>@0]>S00<Slf02hj=`0[>SD0;Sdh03M6@@0hBD<0>da603i?B@0kCdH0?E5803]?AP0eBD00:clb02Xo
;P0fBc`0@5A903A7@@0dAd<0>de<03E7A`0aA480;3ll02Lj=P0S=S00834/02@c;P0[>SD0<D0k02hm
>00[>SD0:STd030o>P0a@3/0;C`g02Xi=00V=C008bhY028[9P0P:B@08BXU02@]:00U;RT08BXU02@]
:00X<B`09RlZ02@]:00V;bX08R`T024[8`0U;2D08bXS01dT7@0N8ad07b@N01hS7@0Q8ah08R@O024S
7P0N8Q`08BLS01`U8P0G81d082HT02L]:`0S:BL092PW01lS8P0O8B007R0O01XL6`0H6AX07R4X02<V
;`0S9Rd06A`S01@G7P0I72408bLZ028V:00g>c`06AdN024U9@0D61L05aTH01PJ6@0E5aH04aDD01@F
5@0H6QT04A<B01HH5`0J71/06A/J0P0H6QT0200W9bD05aLE018B400F5Q@05ADC018B400@40h04a<A
0P0D5180100A4@l03Pl:014B3@0A4Pd2018C3P0401<C400C4a404a<A01<C4P804A4A0P0?3`l2018B
4P0@014A4@0@41003`l?00l?3`0C4a<02@T900`<300D51@0410@05iNGP0R82404a4B01@B4`0A3a00
3@/<02TW:08040h?00/04@l@00d;300:20T03P`?00T73@0A3a@05Q@I00/93P0C4A@02PP;00`:3@02
00l=3P0L00X82@0<2P/03P`=00H41@0O7Ah05aDF01DC500100001`H600l=3P0100004@l@00L51P0=
2``03@X;00d92P0>2P/040`=00`82@0>2P/04@d>00`82@0400403PX;014=3P091@H040L;01853080
4@H<00T040L<00h8300>2@d05Q@G08B4QP1nOX001PL900<720091`T01@0?1PT00`0<1PP02`D700`6
2002010:300300`6200=1`T03@L900@03@L9018040X<00@0000A2`d0100000/51`0B30h03PP8010<
2`0B3@d02P@400T5100=20L03PP8010<2`0<1`H01`4100X61@0?2@T600`6200600P2100:10H02@<5
01hH6P2HTY@0D4Y<200?10P200h31`803`@85?ooool001_ooooo0P0>40/200lA30803Q0;014010H1
01HH4`0B50l04Q@?01HH4`041P400P@0018D3`0g>C@0=3Ha00h@2`082PD06adH01LI500U9b802P`7
01@F4@0200`>2@0A00h@2`0I6aH020X500h@2`0K7AP02`d900/=200H6QD03a4<00@60@0B50l0418=
01@F4@0A4`h0418=014C3P0>40/00P0=3`X01@0>40/03a4<00lA300?4@`04A<>008030h900D03a4<
010B3@0?4@`02P`701HH4`02010B3@0600P:1@0=3`X03Q0;00`>2@0>40/03a4<0`0>40/01@0B50l0
5QPC00lA300>40/03a4<0080418=00@03@l:014C3P0A4`h03Q0;0P0<3PT03`0?4@`02`d800X<1`0>
40/020X500/=200@4Pd06A/F02`^:@2WZJ@0?3hi00T;1P0=3`X03Q0;0043000200d?2P0Z01PJ5@0A
4`h0:R`W00`>2@0;3@P02P`700d?2P0?4@`03@l:00X<1`0=3`X04A<>00h@2`0<3PT03a4<00d?2P0>
40/04A<>01@F4@0B50l03a4<00d?2P0D5A0020T4018C3P0@4@`01PL201LH4`0>3`X02@X500P9100@
4@`030d8014B300<3@L03@h600h?1`0=3PH04A8:01HG3`0A4PX03Pl70P0;30@03@0>3`L04A8:01DF
400>3`X051D@00l@2`0=3@X08b<Q020P7P0<30/02PX:01HF5P0C4a<00P0J6QP03`0J6aL07B8N038h
>01JI6@0cmWJ0?;noP3`n_T0WZVU05=LF@0S:bD0<CPa01PJ5`0D5Q<03@l<00lA3P02014C40H03Q0=
00d0418=014C3P0A4`h0418=00h@2`0<3PT03Q0;00lA300>40/030h900d?2P0?4@`03@l<00802`d:
0`0=3``02@0?4@h030h;00d?300;3@X03@l<018D4@0?3`d01`L500/;2@0200d=2`0400P81P0@40h0
410>014A3`80410>00L03a0=010B3`0@4Pl03a4>018D4@0?4@h03@l<00803Q0=00D03@l<00h@3@0>
40d03a4>00h@3@0200d?300X00h@3@0@4Pl04Q@A010B3`0>40d03a4>014C400?4@h03Pl@018A5P0C
4aD041<B00`A3@0<4``02Q<;00PB2P043@P05AdJ00<92@072P`030h=00`>2`0=3``03Q0=00d?300:
30T02`d:00lA3P0<3P/04aDB00h@3@0=3``061TD014B3@0;30L0414<01DF4@0D5A003Pl:00l@2`80
414<0P0?40/200d?2P0;00hA2@0?4PT03a87010D1P0B5@X041<:00d@2`0<3Pd03@h@010A5@0A4a00
0`0B50l201<E4004010B3@0A4`h04Q@?018D3`804aD@00h02`d801<E400F61<061XE01LI500=3`X0
418=00h@2`0D5Q405ALB014C3P0C5A004A<@01<E4P8051HC00l04Q@A00lA3P0>40d03a4>01HH5@0B
51405QPE01LI5P0E5aH051HE01XL6`0S9B@06adL01<E500F61L00P0C5A@00`0D5QD05QPG01HH5`06
01<H500H01LL600C61@04AHB018G4`0D6AD051XF034i=00W<2/031D@018K5P0H8A`04Q/F01PQ7000
1P4082TT01HO6P0G81/05QlL01PM7`0E6Qd051TL01PP8P0W;c409Bh_0P0J92D02P0K9RL072PX01hZ
:P0R<3006RXY02Ti>00R<c80<DA202Xm>`0X>cT202Xn?00M02<h=P0S>CH0:3hk02Dk>00T>SL0:3hk
028h=@0L<Rl0:T0m0316@`0V?3T0:T0m02Lm>P0Z@3d0;48o01ha;P0O<Rh08SDa020c;`0R=C407c8^
01ha;@0W>SH0:Sdi02Hi=@0J;BT09CPe02@h>@0V>Cd00P0Y?4008P0X>cl09STm01lb=P12EET0@eIJ
02Tl@00_@TH0:Se103E:C@0W?3d09CXi024g=00V?CL0<DPo02Hm<`0Z@CT0:T4k02]1?`0iCdd0;T=6
02Dm?`0V?T00:d=502i6B00`B4X0<4Q802Hn?P0[@d<0;DI3039;A`0dCDT09Slk02Q2?`0X@d02031:
A`0?02Y4@00YA3l0<DY603A=B00cC4H0<4U30359@`0dBdD0;dE203E;B00jD4d0>Dm<03M=BP0iCd`0
=D]80080=4Y701`0=Ta903M=BP0cC4P0<DY403A?B@0`BTL0<4Q803=;CP0cBdl0;D9702i2A`0fBT/0
=d]:03M<B010EE00?51@03]?D00eBDX0=d]<03]?CP0hC4/0<dM50355@`0_@d40;d@o0397@P0eBTD0
<D@n0P0eB480;@0cAT00=dY403Y=A`0cAT00=4M10354?P0bACl0<D@n02`o>@0`@cl0=TU502e0?00d
Ad80=TM103Y;@`0iBT80=TDn03I6?00c@cT0<Slf038o>00b?S/0=TE00391?00gAT40?Di8041ABP0n
CdL0>4a303=7?P0_@cX0;T8g0314=P0cB3L0>Tm003a@A@0^@C/0<TE103e?CP0dATH0<4=102Tl>@0N
<Bd08SD_02m1>P0202Lf<@0N03M6@@0eA3l0:STd01l^:@0P;bX09C@_02He<00Y>3<09cHa02@`:`0R
:bH082TT02</9`0W<2/0:34/02/d;`0V;bX08BXU02D^:@0X<B`09BhY02D/9@0R:B408bXR024X800L
8a/08BHO01dR6`0N8a`08B@M0P0P8A/03P0R91h07bDQ01`U8P0H8Ah07bDS02H/:P0P9R@0<3@c02L[
:P0P8R407AlN01XL6`0J6a`07R4X0P0P92d0300I7R@05Q/Q01LL800K82<06R0Q01LM7@0F71X04aTG
018F5@0F61L061XI01LI60805ALF00h05QPG01<E500H6QT06Q`K01TK6P0G6AP05QPG028R800D5180
4a<A01HF500E5A<05QHD018B40<051@B00X04Q8@010A300C50l04a@>014B3@0@4@`03`l<00h>300C
4a404a<B0P0A4A4200l?3`0401<C4`0B4Q804A4A010@40<03`l?03D00@4101<C4`0<30`000000451
@@0G5AH02`T:00d;300G5AH02PP901TG600?3@h03P`=00d;300C4A805A<D014?4P0F4aT02PP=00`:
3`0A3a@04@lB00d;3P0<2Pd04@l@00h<3@0<2P/03P`=014?400@3Pl00P0100P61`0E4a@04@l@01TG
600:20T02`T:01HD5@081PL04a4B00X7200=1`T03PP:010:300<1PP03PP:014;3@0G4A<05Q0B01<=
3`0;1@L02P@601D;3`020185300:0146300@1``03PP<01@?4`0200<03@d?024R90041@L03a<D00/8
2PD03`H900<030H800d72@0>20X00P0<20T00`0=2@X03@L900d72@0400d72@0B018<3P0;1@L050h@
00/51`0:10H040X<00`81`0;2PH02@H400L300030P002PP400T50P0<2`L030X600T50P0920@02`L5
1P0<1PP01P0J51H03PP:00H00P070@<0E4i@01LA4`H03`@80P0@1@T200l4208040D95?ooool001_o
oooo02H020`700/>2P0>4@d03a8>00dA300;3PX03Q8=00lC3P0@50l04A@@00lB3P0<40/05QPD00d?
2`0E5a<04Q@@00lA3@0E5a<092HR00h@300B510030h:01<E4@0620<02`l800d@2P0=4@T03Q4;018E
3`0K7QP03Q8<014D3`0D5a803Q8=00/?2P0:3PT03@l;00lA3@<03@l;00@030h:00/=2@0=3`/03a4=
0P0@4Ph03@0@4Pd04A@>00`?2@0<3PP03a4;010B300?4P`030h800T<1P0>4@/02`d7010C3@0?4@`0
0`0?4@d00`0=3`/030h:00/=2@0201<E4@04018D400C5A403Q0<00`>2@<02`d800<03Q0;00d?2P0=
3`X00`0=3`X0600;3@P02P`700/>2@0W:bH041<A00`?30072`L04aDA05YLF00J71P01`T4010A3@0=
3`X0414<018D3P061`@03@l:00`>2@051`@03a4<00h@2`0=3`X03Q0;00d?2P8030h900P03@l:010B
3@0=3`X030h9010B3@0<3PT02`d800`>2@803Q0;07H03@l:00X<1`0>3`X0414<00h?2P0?40/0414<
00l@2`0;30L04a@?00l@2`0:2`H04A8=010A300;3@L03a4:014C300<3PP030h700d?1`082@@0418;
00d?1`0B4`h03Pl900`=1`0F5Q403@d900l@2`0A4Pd08R<O09nSWP1OH5`051DA00/<200E5A@03Ph<
018A3P0I6aH03Q<=01/Q700b>cL0HVaX0<?=bP3SkNX0f>?N05aXH`0/>34051lG01<K500D5Q803a0<
01DF4P0?40`04A8>014C3`0?4@d04A<?00lA3@0>3`/03a0<00h?2`0?4@`030h900d?2P0B50l02`d8
00lA300F61<03@l:00X<1`0;3@P030h900d?2P0?4@`030h:00P:100@4Pd0418>00hA2`0@4`h03a4=
010B300?4@`03Q0<010B3P0A4Q002``900`=2P0B4a404A8@018C4@0>3``03a0>014B400A4Pl03a0>
00lA3`0;3@/04aDC00T;2@0I6aT030h<00d?3@0?4@l03@l=00`>300F61H0:B/Y01<E4`0B51805ALE
01<E4`082@L05QPF010B400?4@l03@l=0P0?4@l01`0>40h03Q0@010A4@0@4A803a4>00d@3@0=40`0
0P0>50l05P0:40`03a@A018G5`0R9BD0418@014C400C5A804Q@A014C400?4@h04A<@010B3`0>40d0
51HC00h@3@0A4a008B<O01`M6@0D5Q804A8>00l@300>3`/200/<2004010A3@0D5Q803@l;018C3`80
3a4=00`03a4<00h@2@0?4P/04aH>014D3@0?4P`03Q0=00lA3`0?4A403Pl@00h@2`0@4P`3014C3@0L
00lA300E5a<04aDA010B400>40h04A8A014C4@0C5A404Q@@014C3`0B51003Q0<01LI5@0C5A40418>
04Y<B00L7QX04aDA01PK5`0I7Q/05Q`I00lD4@0=4Pl05QXH010C4@0E61H04Q@B01HH5P804aDC00H0
51HD00`?3`0A51@04aHF014D500G6QX301@G5`0701PK6`0@4a<06ahN018E500C5aD05AXG01DI5`02
01@H5P0<01DJ5`0H71X05a`I01DJ5`0L81h05Q/H01DI5`0e>c/09B`/01<J6P0B6AT041LG0P0C6QX0
O00J8B4051/K01XQ8@0F7Ad04Q/J01HO7P0?5QL0624Q01LQ8P0L9BL06B<U01`Y:`0Q;S008Bda01l^
<@0V<SL07Rh_02i2?P16FUL0;40m02@i=@0[?c/0;48n020f<P0W?CT0:3hi02Ln>@0^AD00?5=>02]0
?00S>3@0:Clk02a2?P0Y?SX0:Clk028h=00M<bl093Te01ld<00I;RX0:Chh024g;P0V>S<093Ta02Hl
=@0V>SD09CXf01hc<@0Z?S`08cLf01da<@0W>c`09SXl02Tm@@0_@dL0;41302Tm@00W>cl0:3a002Hj
?P0[?d807C4e02e1A00T>3`0:Cln02Hl>00Y?c/09Sdg028i<`0V?CH0;48m02Y0>`0]@d409C/j02Tn
@00Y?T40:d5302e4@`0`AdL0;TE60317AP0X?ch0=Te<02i5A00_Ad@0;DE202Hm>P0aBDD0<D]602a6
@P0]Ad80;dU5035:AP0cBdL0=4]802m7A00bBDH0=4Y803=9AP0dBTH0<4Q2039:A00cC4@0=4Y60399
@`0bBD80?55=03E;A@0bB440>e1<03E:AP0mDT/0<DLl0399?@0^A3`0<DE103I;BP0cAdP0<dM90354
A`0iCDh0=TY903A9AP16FeL203]@CP1P03mDE00kCe00=d]=03Y@DP0jCe40:D1003I=C@0lDe40=De:
03=;B00bAT@0>Ti;03I9A`1:GE/0=d]803Y>B`0gBTH0>4]803M;A@0bAT40=4Q302i2?00fBT80?558
03U>A@0fBT<0<DDm03E9@00gBD40>D]303A7?P0eAch0=TM00393?@0a@T80>T];03=4@P0hBDL0?U1=
049DCP0jC4D0<TDl02Xm<`0/?S@0<dHk03]?@`0lD4H0>dm603E8@@0bA3h0>DY704ADD@0nCDX0=T@o
02Le;`0P;RL0:CL_049BBP0iBD<09SHa02Xi<`0^?3H0;c/f030k=P0_>c<0;STd02/g;`0Y=bl09S@/
02@^:00Q:B@082HR02<Z9P0Y<B`0:34/034k=@0[=Bl082/U02@`:P0Z=S0082/U02<[9@0R:B808RPR
01lV800N9Ah09B/U01XP6`0L8Q/07b<N01lR7P0N8Q`082@O01`Q7`0K8b006b0O0P0J7ad09`0F6aT0
7b<R01/O7P0D5aH06QdL01hQ800O8b<07b@X01/R9P0I7bD07B@X01XP9@0S:Bd0;C<f01dS9P094140
72<T01DL7@0H7Qd061XH01XK600J71P061TG01HF500H61D061PG01/J600K6QL06aTH01XH5P0H61H0
<c8`01PH5`0D51<06QXI00l?3P0B4Q005ADC01HF500201DF4P0>01@E4@0C50l030`901@D4P0A4A00
3`l>018B4@0?3`h04Q8C01@D5@0F5QL03Ph?014A4P0B4Q<2018B4P0O01<C4`0A4A403Ph>00d=3@0A
4A407QhN00D51@0D51@03`l?00P8200@3a404a8D00h=3`0?3Pl02@P:010?4@0@3a003Pd?00/:2`0>
3@l03`h?00T82`0=31003`hA010?4P0<2`l02PT<01@C5@0B4A@051<D00/:2`0200h=3P0I00`;300;
2@X040h?00h<3@081PL0518C00d;300>30d04a4B00`:2`0?3@h030X;00/92P0;20T03@P:00l;300<
2@X03PT;00l;30091PL03PT:00l;300?30d030L800l92`020148300<0108300?20/03PT;00/72@0F
4aD030T;014@4@061@H061LI01LC500@20X040T:0P0>1PP02@0@2@X03`T:010:2`0?2@X02`H600X5
1@0?2PX030H700d7200300h82@0O00d7200;1@H05@l@00P3100;1PL040X;00`61`0:1@@02`T600/7
1`0C3Ph02`P600/8200;1PL02PL500h:2@0<1`L03@X800`71`0?20X03PH900h5200?1@T03PD900/4
1P0>10L040T:0149300C2@d03@@701D;3`0600l4200601872`0n<cL04`P<00h31`0C20`091TM5?oo
ool001_ooooo00@051TE00hC3`093PX02Pl;0P0=4Ph00`0>4`l03A8>00`A3@0200`A3@0800/@300:
30T02`d:0043000J71T04Q<A01HH5@0D5Q<200h@3@0B00lA3P0S9B809bTT00dC2P0>50X02a4700X@
1P0?50d04aPA018G4@062`D0<cPb00D:1P0730P04QLC00lA3P0>40d03@l<0P0>40d00`0?4@h030h;
00lA3P02014C4080418?00L03Q0:00`?200=40T03a8;00hA2P0<3`P03A09008030l800@03A0900hA
2P0<3PX030h;0P0?4@h200d?300800h@3@0@4Pl051HC00lA3P041P<01`T600h@300>40/400d?2P03
00h@2`0=3`X030h900<030h901006QlK05AJF00Q9B@05ATH00L;2P082PL02P`9014C400>3`X020T4
01TJ5@0?40X020X400`>2@0>40/03@l:0P0<3PT04P0A4`h03@l:00T;1P0<3PT03@l:00T;1P0B50l0
4aD@00h@2`0<3PT03a4<00`>2@092`H02P`700h@2`0A4`h0418=00d?2PH03@h91P0>3`X09@0B50l0
20X500<50@0:30L030h900lA300=3`X02`d8010B3@0;3@P05ALB00P9100D4`l04@h;00/<1`0B4`h0
5QXD08V>R01OI5h04QD@01@F4@040`004@h;01dL6015BT@08RTR01DL5@0G7QL07RPP03Do=`1KIEd0
KGQ`02<`9`0I9Qd03a`C014K4`0@4Pd00P0G61<04P0B4`h051D@01`M600>3`X04a@?00l@2`0>3`X0
414<00h?2P0a<bh0@48m00`>2@0=3`X05QPC00H80`0K7AP03Q0;00`>2@80418=01<03a4<00X=1P0;
3PL02`h7010C300;3PL030l800lB2`0C5Pl04A@=00`?200>4@X04A<>01@F4`031@807R0M06a^J`0E
5a@0004000803@l<01403a4>010B3`0?4@h051HD00840`0A4a809bTX05=EE00P8R402P`;010B4@0>
40l02`d<014C4P0];bh0418A00lA400200/=300301LI6016B4L0:2XY00D03Q0?00@03a4?00lA3P0?
4@h03Q0=0P0?4@h2010B3`@03a4>0P0A4a00100@4Pl03a4>00lA3P0?4@h200d?30803Q0=0P0?4@h0
100620D03@l<010B3`0@4Pl201@F4`0901HH5@0B514051HC01DG50072@H02@/800`>2`0>40d03a4>
00803@l<00@03a4>018D4@0?4@h03Q0=0P0@4Pl00`0>40`03a8;010C2`02014D3@0A010C3@0?4@`0
30h;00lA3`0A4a804A8D00l@4`0;30h092HU00L91P0A4a00?Cll03@f<`031@805ALD00`>2`16B4D0
0P0C5A806P0E6QH06R0N00D;200E7Q/06b4O00dC4@0>51803Q8A00lB4@0C5A@051HE01`N7@0/;Rd0
2@d>01<G600E6AX08RHW00`@4@0C5aP06QhO00`@4@0>4Q<05QXK010D5@0F6Q/04QHE100D61L0400E
6AP04aLF01<G5P0B5QD082@S01LK6P0E6AX041DI01dR9P0J7b<07B8V01LL800B5a/05a`P01DJ7P0G
720201/P900N01LO8@0H8B8041XI01HP8@0J9RH04ahP01XV:@0J:2/08c8g01h]<`0H9bh082lf01P[
;00S>S@09C`f01dd;P0R>C<09chh02U0>P0R>C<0:d8l02Ln>00U?3H093/e03A:A@0X?CP08cPc02]0
>`0/@C`0:3dh0P0S>3<03@0V>cH09c`g02a1?00]@Sd09S`c02Q0<`0Z@SD08SX^02Ln=P0X?cT093/g
02Dk>@0U>S/00P0U>Sd09P0S>3d07c@g02i3AP0nDeH0=4U<02Hk?P0O=3L0:3e002]0@`0`ADP0<DI9
06AiO00]@T@0;4<m02]2>P0Y@3P07cH`01`c;@0R>3D0:3hl02Hl>P0[@440<dQ903eBD`1FJfd0<4I4
02Pn?00P=S@08CLe02e3@@0eBdT0<dU702m5@`0`AT@0<DM502i4@P0bB4D0<DM40P0_AT002P0aB480
<TU40398A@0cBDL0;TA20398AP0dBDX0<TM803I<BP0_B482031:@@1/0399@@0cBT80=Te503I;A010
EDh0<DHo0354?P0iC4H0:Shc03I6>@0gB3P0=dTm03Q9?`0hBTD0=dY803E7A`0cATH0>De>03M;BP0h
CD`0BV1M03Q?B@0iCd`0AE]H045FE`10EEP0BV9V04UPI@0[@dL0=U1A03E?C`0`BTT0;TQ703Y?D00/
@440<4A50396A`1KKfh0;T910396A00fBTP0<DE303=8@`0fBdH0=4U203A:?@0fC3l0>Dm203I<@00e
Bcl0>4i203U>A@0gC4<0>4e403U>A`0eBT<0<TM2049GF@16FEd0?51A041DD`10De40@5=?03Y=A`0c
A3`0:S/b03E6?00oCd@0?dm903a?C@0hBdT0<dE203Y:A`0oCTT0?D]503M4?@0/=bl08R`T02Xd:`0^
>2l0;3Xb02Pk=@0[?3H0<T4k02dj<`0Y<Rd0:C4[02/b:`0/=Rh0:C@[02@`9P0Q;R@0:34Z02T^:P0T
:BD09BXV02P^:P0T;BP08RdW02D`:P0Q;RL093</02dl=@0U<b`09RlZ02L]:@0R:2@06R0L0P0G7AT0
;`0L8Qh07B<O01dS7`0M8al06b4M01TO6`0N8al06QlK01TM700L81l06alN01HJ6@0D61L061`K014E
500L81l08RHU01hS8P0]<SD09blb01XR9@0@61/00`/>01XR9@0>5QT07RHY02@/;`0G7b803ADH01XO
8P0H6QL05QLB01PI500H5a<051<?01HE4@0I5A806QHC01/G500L5a@06aHC01XF5@0E4a@05ADE028R
8P0V9RH05aLF00805ADC00<05ADB01@E400C50l00P0C50l0200E5AD03@d?01LG6@0O7b405ADG01LG
6@0?3a402PX<0P0B4Q@01P0C4aD02@T;01<C4`0A4A40410@00l?3`803Ph>00L03@d=00X:2P0G5aL0
10@400l?3`0;2`/03Ph@00<03`lA0P0=3@l01P0>3Q003`lA010@4P0?3a403@d?00`<3PH03`lA00<0
6ATK01PH6P0:2P`00P0<30h01@0>3@l03@/<00d;300<2P/03@/<00803`d>0`0>30d00`0=2``030X;
00`:2`0200/92P0:00`:2`0=2``03@/<00`:2`0@3Pl01P@500X82@0<2P/0518C00h;30803`/<00X0
3PX;00d92P0=2@X02`L8018>3`0;1`P03PX;00<0000<20T02`H60P0=1`L0100:10@02`D500h8200?
2@T200h820803@L700@03PP800X4100;1@D03@L70P0?2@T05P0@2PX0<B/[03H`<00I4a<02@<3014;
2`0C3@d071HH00X41P0?2P/03`T;00@0000=20T03PP:00`6200C3@l030H800h82P0@2P`050T=0146
2P0@1@T201872`0700l4200;00@03P@700X00`0>0`L04@H:00L0000600l4200600h31`0T6Ad02001
01052@0C20`0;R<W5?ooool001_ooooo01<04QLC00/@30093PX0314=00dB3P0730P041DA00`A3@0B
5a<04AHB00P=2@0;40`04aDB01PJ5`000@0051HC04i@C@0E5a@04Q@A00<03a4>00h0:B/X034c;P0?
50`03A<900H<0P0>4``06AhG01PM5P0=4P`05a`F069WH@0J7a/02a0<00`A3@8030h;00D03@l<00lA
3P0A4a004Q@A00h@3@0300lA3P803@l<00P02`d800`>2@0?4@`0418=00`>2@0:30L03Q0;00d?2P80
30h900<03@l:00`>2P0<3P/00P0?4@h03`0=3``03Q0=010B3`092`P03a4>00/=2P0>40d05aTF00d?
2`0?4@`03Q0;00`>2@0:30L030h900h@2`0300d?2P0N00h@2`0?4@`0310=024W9@0420L02`l>00H:
2@0A4a0071hK01LI5P0F5a803@h901hO6P0720803a4;00h@2`0?4@`03Q0;00d?2P0>40/05QPC010B
3@0:30L030h900d?2P092`H04aD@01HH4`0B50l03@l:0P0>40/01P0;3@P03@l:00h@2`0;3@P02@/6
00P:1@H03a0;1P0>3`X0;00F61<03@l:014C3P0H6QD03Q0;00`>2@0=3`X020X501XL5`0<3PT0:R`W
014B3@0?3PX04a0=00`=200A4Pd03Q4<02DZ900I7QP02`d900d?2P0?3PX04a0=00`;1`0];bX04aPB
00`A2`0E6Q@07RDN01lY8@0P:R80=T0h01`W7`0D7aL02aH>00D?1`0:30L02``700T:1@0:2`H03Pl:
010A300>3`X04Q<>0P0?40/02`0@4@`03Pl:02X/9`0a<bh04Q@?00H80`0=3`X0418=018D3`0;3@P0
2P`700803Q0;0P0<3PT04`082PD030h900d?2P0:30L03Q0;00lA300A4`h0418=00`>2@0=3`X03a4<
00lA3P0A4a0051HC020R7`0B51404aDB00d?300>40d00P0?4@h0500>40d020X800T;2P0W:BP05ALF
01/M700<3Pd051HE00d?3P0>40l03@l>00P:2@0H6QT01@L600T;2P0?4A002`d<00lA400X:RT04A<B
1@0>40l0100?4@l03a4>00lA3P0>40d200lA3P80418?00X03a4>00h@3@0=3``030h;018D4@0@4Pl0
3@l<00`>2`0=3``0418?0P0=3``300h@3@0F00lA3P0:30T0418?00d?300<3P/051HC00lA3P0B5140
3Q0=00lA3P0D5Q<03@l<00lA3P0>40d03a4>010B3`0>40d03@l<00lA3P0A4a00418?00h@3@80418?
01803Q0<014D3@0@4``03a8;00lA300@4Pd04A<>00d?300?4@l04Q@C018C5@0@4A<03PlA00lA400B
51403a4>01LI5P0C5A8201DG500P00h@3@0E5a@0418?01DG500A5Q8000H402hg=00C71T03A<A014G
5@0>51804aLF01<F5@0C5A@0418A01PJ6@0Z;2/07B4R01DI6P0T:2T041@E00dA4P0G6a`0ATY;03Lk
?0052@X08RHW00dA4P0420T04QHE014E500B5QD201@H5`0@01<G5P0B5QD06alN010D4`0=4A002Ph=
01LK700C61/0DeQK02@Y;00K82<04QLJ01XO8P0F6ah05AXM01HK7P806AhQ01T05QhP01XS9@0`>S/0
7BLY01LR90084aD08c0b01XX:`0S<SD082lc01/Z;`0Q<3D07S4a01lf<00N=Bl083La028i<`0T>cD0
9chh02<j=00]A3h09chh02e4?P0T>cD0:d4l0080:3dh00@0;T<n02a1?00Z?cX0:Chi0P0bAd8202Dj
=@0M024f<@0L<RT09clb02U0=P0S>S409Sde02Hm=`0V?CT09S`j02@i>P0X?D00:Ci102@i?P0W?3l0
<DI903M<C`0W?3l07S<f02@i?00W?3l0:d1302m4A`0bAdX0J7f002m4AP0W?CX0:d8l02Po>@0P=S<0
0P0]@d00600eBdP0;dE202Hl>P0R>3H093Xh03I<B`0^A480;49003Q>C00/@T008CLe02Pn?00]@d40
:d4o02i4@P0bB4H0<DM50398A@0_AD80<4M102m6@00^ACl0<4I20398A@80<4I403L0=4Y803A9BP0b
AdP0=Ta:02m8@P0_BD00<D]203E<A00fCDD0=4]303M<A@0_@cd0=TU302e0>P0aA3h09CT^03=3=P0e
AcL0>4Xn03U:@00gBD@0=4M502do?`0cATH0=4Q70396A@0gC4X0@5IC02i3?P0_@d40<dM503A8B@0h
CE00?U=F049IG@0bBTh0=Ti@0359BP0_AdL0:dA10355AP0_@d@0>De>04MKFP2calH0KH6003U=B`14
F5H0=TY803aAC00cB4<0<dQ10398>`0dBSd0>4i10080=de102`0>e5503E:@@0eBT<0=T]403M<A@0c
B440<4E0049GF@16FU/0?e=D049FE@0nDDl0?4m;03iAB`0kC4@0;d0g03]<@P12DTL0>da503Y=B`0l
C4/0>DU703a<B@0mC4L0=T@n02`i<P0U<2X09C0X02hi<@0^>300:SP`02Tl=P0_@3X0=T@o02hj=P0Z
<bh0:30Z02dd;@0_>C40:cH]02@`9P0S<2H0:S</02X_:`809B/W00h09bdY028[9P0T;bT09S4[024^
9`0V<b`0<3df02Tg<00O:2<08BLS01lU8@0J81`06AlK01/Q7@<0728N02406b4M01XP700I7a/07B8N
01XO6@0H7AT07B8N01hS7`0H7AT04QLC01TN6P0E6AP08BDT02L[:P0S:2P05AXM01HN800D71h04QXL
00lG6@0e?Cl0GfMY03@l?P0D71h04QXL01DM7`0H7Qh05QPG01@D4P0I6AL06a/I01TI5`0K6QP00`0H
51<201TC4`0K01PD4`0<2P/05ADE01TI6@0L71`051@C01LG5@0C4a404a@@01<D3`0B4`h04Q<=014B
3@0H61H04A4A00h>3P0@410020P801TI6@0N7Qh04Q8B010@400A4A405aLG00d=3@0D51@0410@0080
3Ph>00P03`l?014A4@0>3Ph03Ph>01`L700I6AT04A4A00/;2`803Ph@0`0?3a4200h>400300l?4@0@
4180410B00803`lA1P0=3@l00`0M7Al071`N00h>400200`<3P0300l>400=2``03@/<00<030X;0P0>
30d00`0=2``030X;00`:2`0200`:2`0<00/92P0<2P/030X;00`:2`0=2``02`T:014?40040P<03`d>
00T7200E4a@030T:0P0?2``03`0>2P/03@T:00d92P0A3@h05a<D00X61`0<20T020@501DA4P0A30`0
30H600X4100<1PH03@L700`61P0200d71`8030H600<03@L700h8200>20P00`0>20P04@0?2@T040X:
01dG5`0U7al03PP800@0000600002`D500@000080P@040/<00T31@0R71h050h@00P210070@<040X<
0080208400d03PP:01462P0@1@T040D901872`0C20`04@H:01<8300D2@d03@8601/@500/8BD05P/?
00H03`@800H04`P<00P00@0=0PH04`P<01052@0F2`lDooooo`006oooool090093PX04AHB02<X900[
<2`082DQ00X?2`0=4Ph03Q<?01lT800N8al0314=00lD400;3@X02P`9024S80092`P05QPE00X<2@0@
4Pl03a4>01@F4`0>40d051HC014C3P0=4`X03aD<00L=100D6A807b@N01LL5P0>4`d03A8=01@H500;
3``04QHD00dB3`<03@l<00@03a4>010B3`0A4a003a4>0P0<3P/200lA3P0300h@3@0A4`h03Q0;0080
3Q0;00D03@l:00/=200?4@`03Q0;00d?2P0200`>2@0400h@300@4Pl04A<@00h@3@8030h;00L0418?
00`>2`0?4@h02`d:03/m>P13AD80418>00803a4<00@03@l:00/=200;3@P03@l:0P0<3PT04P0=3`X0
3Q0;00lA300?51002Q0>00@81`0?4a801`/:01HH5@0?4@h06Q/I04]<A`0E5Q403a0;00`=1`0G61<0
3Q0;00lA308030h901<03Q0;00lA300@4Pd04A<>00h@2`0<3PT03@l:00h@2`0C5A004Q@?00/=200=
3`X0418=00lA300=3`X030h900d?2P0>40/03@l:00H04A8=1P0>3`X0;@072@@03Q0;00lA30082PD0
3@l:00lA30051`804Q@?01<E400@4Pd07AlJ00l@2`0>3@T03``900h?2P0<3@P041@>00870P093PP0
@D@o02T[9P0l>cT08AlK01lN6P0@4Pd03a8<00hB300G6A@07b8M01HL5P0V;2D08BLQ01dU7P0?6100
3AH?00dD3@0];bX06Q/F00`=200?40/0414<00/<1`0?40/04A8=00l@2`02010A300F00d>2@0<3PT0
0P@100T;1P0>40`03Q0;010B3@0;3@P03@l:00X<1`0<3PT03Q0;00/=200<3PT03a4<00`>2@0:30L0
5aTD014C3P0>40/03a4<00h@2`8030h901P03@l:01@F4`0<3P/020X7010B3`0:30T03Q0=00d?300@
4Pl03a4>00d?300>40d04Q@B00lA400D5QD02P`;01DG5P0=3`h04A<B00X<2`0>40l04A<B00d?3P0A
4a8200`>3@0501XL6`0:30/0418A02DW9P0D5QD01@0>40l0100?4@l03a4>00lA3P0>40d200lA3P03
010B3`0?4@h03a4>00<03a4>300>40d03`0?4@h03@l<00lA3P0?4@h03@l<018D4@0C5A804A<@010B
3`0C5A8051HC01DG500>40d0418?014C400200h@3@@0418?0P0?4@h0=00>40`04Q@?010C3@0>4@/0
3Q0;010B3P0B51004aDB00d?3@0=3`h03Pl@00l@4@0E5aH03a4>01DG500B51405aTF01<E4P0G6AH0
3a4>01<E4P0?4@h061XG018D4@0>4`l06AlM04I?C00G81d03Q8@01TN700;4@l04QHE014D4`0F61L0
5ALF018D4`0C5A@051HG03Pl?@2=TI8051PI01dQ8P0=4A80<3@e0414A@0F6Q/04aLH010D5@0F6Q/0
4aLF00hB4@0@51<201@H5`0>018F5@0C5aH07B4P00hB4@0G6aX04QHE01<G5P0F6ah0>Sm201hS9P0F
6ah06QlR018G6P0E6Qd201HK7P805a`O01`05AdO01lW:`0V;c<06bDX02lj?@0G8R@072PZ01PV:00M
;2h07Rh_01d];P0R<S<09SXh01he;`0O=S00;4<m02U0>P0W?SP0:d8l0317@@0jDD/0:T4k0399@`0Z
@C/0;dE003=8@`0bAd80;d@o0P0Z?cX09P0cB4<0;T<n02@i=00W?3L0:Chi02Pm>00U>c<09clc02U0
=`0T>c<09C`e02Dl=`0U>cT09S`j02Hk?00U>Sd09S/n02Ll@@0S>3/09c`o02Xo@P0W?3l09CXm02Pm
@00^@dH08SLj02Tn@@0W?3l0:Ci102]0@P0U>cT0>Dm;0398AP0S>CH0;D=102Hl>@0Z@3d0:3hk0P0[
@Cl03@0Y?c/0;490055WI@0]@d40:d4o02e3@@0/@T00<4I402]1?`0/@T00;dE30316A00_AD<00P0^
A440200aB480<4M102e4?P0^A400<TQ502a2@00cBDL0=D]90P0cB4T0100eBdT0<DU30318@00cC4<2
03Q?A`0c03=9@P0gC4D0A5QA02Xm=`0_@S`0C5iH03I7?`0[>bh0;3h_02do<`0^?cD0;T0j02`o>`0Y
?3X0=TY80355@`0]@D00=DY703I;AP0hBdD0>T]803E8AP0gBDX0>4Y>03=7B`0V>Sl0=TY>03iDE`0j
D500>E1>0357A@0iCDh0@eMG0355A@0jCTd0B5aK03]?CP1<H5h0?U=?03Q<B@0nDdh0;D8l03M<A@0e
Bch0=D/o03Q>@P0fC400=T]103Y@A@0dBD00=DY30080=T]40240=T]503I:A`0hCDh0?E5B04EIF@1?
Hf80@eID03]>B`14Ee40A5E=03Q9@010DDL0@E5703I6@00iC4X0?dm>03m?C@0nCT/0>DQ402lm>00/
>S@0;SXd02lk=@0^>S<0;SPa03I4?P0eB4<0;d0j0390>`0`?3P0;SLb02dd;`0[<B`00P0Y<b/03`0U
<2L07b`S020Y8`0R:2@08BLS02@[9`0W;bX09c0[02Xe;`0X<bd08RhW024^9`0U<R/08BhW01dV8@02
01lU8@80728N00<082HR01XP700J81`00P0K8Ad07P0L8Qh072<N01`Q6P0O91`07B8L01XO6@0K81/0
61dH014F4P0I7QX051PG01XN7P0M8B4061`M01HK7P0G7R0051/M01DL7P0C6A`0:c8d0<;9b`1MI6H0
5A/N01LM800J8B<0318B01`N7@0G5aD061PF01LG5@804a8@00/06ALE01TF500G4a8061<B01PC4`0H
51<04Q0A014A4@0?3`l0820P00d=300201DE4`0A01@E4@0D5A004a@?01<D3`0B4`d03@h:01HF500:
2PL05aLF01HF500L71T07QhM014A3`0C4a003`l=01@D4`0@40l00`0A4A402`0@41003`l?00l?3`0>
3Ph05QHF00X:2P17AdL03@d=00`<300>3Q003`lA00@0410B0P0=3@l0100>3Q003`lA010@4P0@4186
00h>400601DE5`0I6A/0410B00d=3`0820X03Pd?0P0=2``00`0<2P/02`T:00/92P0200d;300500`:
2`0:20T02`T:00`:2`0=2``01@0<2P/01`0>30d02`T:01<A4P0>30d03`d>00H41@0=2P/00P0?2``0
3P0>2P/03@T:00d92P0G4a@081`M014=3P0B3Pl02`L801@@4@0?2P/03PP800d71`0@2PX04@/;1P0>
20P0200@2PX05Q0@01@>3P0@2PX03@L700`61P0=1`L01`820P0H4Q803`0B30`04@/;00l92@0;1PL0
5A0A018<3P090`D0G5IH014<3@0G4A<02`D700d72@090`D02P@600h82P0200d21P0300l4200@1@T0
4@H:00804PL;00D0308501`A5@0>0`L07A8F01<8300600l4200600X10`0G31004`P<00l4200C20`0
2@025?ooool001_ooooo00D02Pl;010E4@0L8Ad08RLS01XO6`0200/@300=00X?2`0A5Q804AHB014F
4P0O920061XG02/]:P082PL03Q0=0494@@0H6QL0418?00X<2@0200h@3@0@01<E4P0;3@P03149010E
3P0:3`P03A8;00hC3@083@L03a@>01DJ5P093PX07b@P00D9200830/0418?00lA3P@03@l<00h051HC
00h@3@0>40d04aDB01@F4`0C5A80418=00/=200:30L030h900h@2`0=3`X03Q0;00d?2P8030h900<0
3@l:00d?2`0=3``00`0>40d02P0A4a004aDB00P:1`0=3``03a4>01XL6@0T9R<051HB010B3@0A4`h2
01@F4@03014C3P0>40/030h900<030h900h03@l:00X?2`000P001PX900T=30072`X051HC00L91`04
1P<0<C8]00`=200;30L03a0:00h@2P803@l:0P0;3@P0200=3`X01`T400/=200?4@`02`d800T;1P0<
3PT02@/60P0=3`X02@0:30L03Q0;010B3@0;3@P030h900lA300>40/02`d800@60P0600d>2@H03Pl:
01X03a4<01<E400@4Pd03a4<01<E40082PD01PP3018D3`0620<04A<>00`>2@0A4Pd03@`8010>2P0G
61<03Pl:00X=20083@L03A8<02X^:00G6A@05QDA01hK600F4Pl01PD100l?2`80414<00h04a@?01@F
4@0F61<030h9018G4@0?50h041H?014F400A4`h06AXE014B3@0720<04Q<>02//9`803a0;00H03Pl:
014B3@0@4@`030d800d?2P0B50l200d?2P0>01LI50041P4030h901<E400=3`X030h900lA300<3PT0
2`d800h@2`0B50l03a4<01`N6@0:30L200h@2`803@l:0P0<3PT07P0>40d03@l<00L91P0620D030h;
01LI5P0>40d04Q@A00lA3P0;3@X030h;00P91`092`X05ALF00`>3@031@@02@/:01<E500:30/0418A
00d?3P0A4a802`d<01DG5P0F61L0=3He01hP7`0?4A00418A00d?3PD03Q0?00@03a4?00lA3P0?4@h0
3Q0=0P0?4@h0300>40d02`d:00`>2`0=3``03Q0=00lA3P0;3@X03@l<010B3`0A4a00418?00h@3@80
3a4>0`0>40d0400=3``04Q@A00`>2`0?4@h0418?00T;200<3P/0828O02<U8P0N81d04A<@01<E4P0>
40d03@l<00lA3P0@4Pl200lA3P09014C400?4@h0418?014C400>40d03@l<00lA3P0A4`h041<=0080
3a4<00H0418>014C400?4@h0418@01`N7@0M7ah2018D4`060043000D5Q<04Q@A00lA3P082PL051HC
0P0B51407@0I6aP0418?00d?300D6AD04aTG014J5`0M9R<06b4O00lE4`0G7A/04QHE010C4P0L7Qd0
8bDT01/M700@4Q402`l@01<G600X;2d0310A00/?400J7Ql02Ph?01DI6P0H71d0310A01DI6P0C5aP0
4aLF008041@C00L04aLF01@H5`0D61L051PG03/o?P0F6QT041@C00804QHE00L04aTJ00D:3@0E6Qd0
4aPK020U:00C61/05Q/N00805a`O01d05AXM01HK7P0E7Al07BD[01lX;@0_>3d0D5]O03Q3A@0O:bd0
8c4a01d];00L;2/07Rh[01`/:`0S=c<07SD_020g<@0]A3h0:d8l02Po>@0^ACl0=Da603mFD00[@S`0
;dI002U0>P0aAd40=4U403=8@`0202e2?@0<02i3?P17G5L0@5E@02Tn>@0^@ch08CHa01`a;00U>cD0
:3lg02Y1>@0W?SL09C`f0P0U>cP01P0W?C/09c`m028g>P0R=cX0:Sm402Ll?`808cPk00@0:3e002Xo
@P0V>ch0;D950P0W?3l05P0bAdX09CXm02]0@`0aATL0Fg5_05Y_K`0]@d409C/i0357A00[@Ch09cdj
02Hm>00V?CL09C`f02Po>@0bB4D0738`03E;B@0W?C/0:d4o0357A@0`AT@203M=B`80;D=104@0;dE2
0316@`0aB480<4M102i5?`0_AD40<4I302e3@@0cBDL0<TQ60356A`0eBT/0<dU703=:A00bBD40<dY2
03E<A00eBd@0=4U20315?P1@I5d09CPb02i1>`0nD4X09CH^02Ti;00Y>R/0:3X^02Tj<00Z?3H0:Sdi
02e0?P0iC4X0<dM50314@P0fC4L0>4e60394?00dACl0=4A103M7A`0fADP0<49603M9C@0lCe<0@5AE
03Q=C00iCdd0<dU703mCD`0[?ch0>De<03eAD00R=S@0=d]909jb/01NLfh0D6EP03eBC@0]@S/0=da3
03U>A00gCD40>4i203=9?@0cB3l0=da303=8?`<0=4U202h0>Di903a@CP1<HF40CF5R04mSHP1CIfH0
@eID03I9AP0iC4P0?Di803Y;@`0lCDD0>d]103E5@00iC4X0@51?03i>C00jBTL0=4=002Lf<P0X=c80
<Cdi03=0>@0^>c@0<Slh03a:A`0cAT80<44k03=2?@0_>cL0:34^02T`;00W;BT08B/S02D`:00W<RX0
7BXQ01`V800U:bL09R`X02L^:P0X<B`0:C8]02Pc;@0W<R`092lY0P0R;bP06@0Q;BH07RLR020V8P0N
92006AlK01LM6@0J81`08RPT024W8`0N92006R0L01TO6`0H7aT05a`E01dS6@0K8AL05Q/D01XO600F
6aD05Q/G01hS7`0F6QT061`M01LK700D61T00P0C61/0300>4aH061dP01HK7P0J7b805Q/N01LL7`0E
6Qd041DH014F6@0N92@05ALF01@E4`8061PF00X071/I02HU8`0K6QP06QLF01PD4`0G4a8061@C01LF
500V92D05QHF0P0>3Ph01@0>3Pd061PF01DE4`0E5A8051D@00804a@?00X04a@>01/L5`0C50l03Pl:
010A300?40/0Ngag0;>d[`13A3l04A8=0P0B4`h03P0>3`X03`l>014A4@0C4a<04Q8B00l?3`0=3@d0
410@00h>3P0H61P04a<C014A4@0B4Q803`lA0P0@4180100A4A<0410B00l?4@0=3@l200`<3P0300d=
3`0>3Q003Ph@00H03`lA00H02`/=00l?4@0=3@l03`lA00H6200;2P`200d;300600h<3@0=2``030X;
00d;300>30d03@/<0`0<2P/200d;30<030X;00P02`T:00`:2`0:20T05Q@E00l=3P0C4A802PP900l<
3@803`/<00l03PX;00d92P0=2@X071PI020L7@0300001P8301hJ6`19ADH0=2l_00`61P0=1`L03`T9
00h8200<1PH00`0>20P0100?2@T040X:018<300@2PX200l92@803PP801D03`T900/51@0E3`l040X:
00/51@090`<01`4102@N800500403@L901<=3`0I4aD030L802hX:P0G4A<040X<00l92`0>20X030H8
00d21P0?10P00P0A1PX0200B1`/05@X>00l4200D2@d0?S<g01hC5`0C20`04@H:1P0?10P01P0B1`/0
3`H800L0000A1PX03P<701D:3QCooooo000Kooooo`8020d901T02Pl;00`A3@0;40`020d900hC3`0?
51002Pl;00P=2@0?51006QlK00/=2P0G6AH02P`901DG500<3P`06Q`I00h@3@0=3``04aDB00lA3P0E
5a@04A<>00/@2@0?50d03A8;00802@h800T02Pl9010E4@042@D000@000P<2`0420L04ADD010B3`0>
40d00`0=3``03P0>40d05aTF00h@3@0<3P/04A<@018D4@0@4Pl03Q0=00`>2`0>40d04aDB01DG500D
5Q<03@l<0P0<3P/0100=3``03Q0=00d?300=3``200h@3@0300lA3P0B51404Q@A00802`d:00`030h;
00X<2@0>40d0418>00d?2P0>40/05QPC01TK5P0B50l03@l:00lA300>40/300d?2P0=010E4@0>5180
61`K00`@3`0:3Pd04A<@01TK600<3P/00@8000h?2P0@4@`02@X400lA2`0200h@2`8030h900D03a4<
018D3`0?4@`02P`700/=200300`>2@0600h@2`0;3@P02`d800lA300=3`X030h90P0?4@`00`082PD0
2`d801/M600600l@2`H03Pl:00<01`T400H80`0>40/00P0;3@P09@0R91l07R0K00/=20092`H03@l:
01<E400F5a8030/7014>2`0A4Pd03a0;00/>2@0<4@/03a@>00P<1P0;3@P04a8>02XX900@30T061@A
01LE4@0D4`l040l;00d<200A4Pd06a`G01@E400D5Q405QPC00hA30092`H01`P301HG4P0H6A@04a@?
01lP6`0f=c800P0?40/0200=3PT04A8=014B3@0;30L02`d800L9100F61<020X60P0=3`X0800@4Pd0
61XE00lA300;3@P0418=00`>2@0W:BH01`T601@F4`0>40d05ALD00X<2@0?4@h03Q0=00d?300>40d0
3@l<00`>2`0<3P`0418?01lQ7P0?4@h06A/H0001000=3``04Q@A00lA3P0:30T030h;01DG5@0E5aH0
30h=0P0@4Q402P0C5A@03a4@00/=300D5QD02P`;01DG5P072@P051HE00430P0G6AP200@61@03010B
4@0E5aH03Q0?00@03Q0?00@03a4?00lA3P0?4@h03Q0=0`0?4@h200d?30D03Q0=100@4Pl300lA3P0:
00h@3@0=3``03@l<010B3`0B51403@l<014C400J71T03@l<01@F4`807AlL00D03Q0=01@F4`0A4a00
30h;00h@3@03010B3`0i01<E4P0>40d0418?014C400>40d030h;00lA3P0?4@`0418=014C3P0A4a00
418?00lA3P0@4Pl04Q@A028T8@0S9B805ALD01@F4`0P8Ql05ALD00X<2@0E5a@04Q@A00h@3@0D5Q<0
4aDB01HH5@0?4@h05ALD014F4P000P004a`I00lH5@0D6QP03aDC01TO7@0G6aX051LF01TK6P0L7Qd0
5aTH01@F5@0;3a00310A00X>3`0N8R<02`l@014E5P0L82406alP00hB4`0D61T05QXK00861`0D61L0
4aLF00804QHE02005ATH01PL6`0T:2L0GV9Q02HZ:@0C5aH07B4P01lS8P0G7Ad06R0P01lU9@0=4a<0
4ALG01hT900F71`06AlO01PN7P0E6a/05Q`L01HN80073aH07BH]01lX;`0S;S807BPZ028^;`0^?3`0
830_01l_;00S=2h07BdZ02@h=0808SPe00X0:3hk02Y0?@0[@Ch0;D=002]1?P0gCDX0<4I303Q>B`0a
Ad@0=D]80P0fC4T03`0bB4D0=D]803=9AP0fC4T0;D=002<i=P0[@Ch0:Cll02Y0?@0]A3h0:T4k02]2
?00Z@3`09S`i02Dk>@0202Pn?00S02Ll?@0U>Sd09c`o02]0@`0`ADP0:Sm2024f>@0R=cX0:3e002i3
AP0/@D@0:3e002Hk?P0cB4/0:Sm202e2A@0P=CP0?E9C03aAD`0M<S<083Hd02To?@0X?S/093Xg02Ln
>00_AT00<TU103YAB@0W?CX0<TQ60767Q@15FeT0>e5?03=9A`0_AD<00P0iCdd0@00X?S`0:Clm0316
@`0cBDH0<DQ202m6@00`Ad40<DM302m5@P0`AT@0<TQ602i4@P0`ADH0=T]<0398AP0cBT80=4]103=:
@00bAch0<dPo03A9@00dB3l0<TDl02`m=@0Y>S807BhV02Lh;P0W=bX0:CX[02/m<@0/?C<0:cdg02Pk
=`0Z?C/0<DE20397@P0`AD00=Ta403iCBP0hB400=D@o03U8A@0mC4`0?De=03i=D010D5<0=dU;03a>
CP0gBTT0>Ti<03Q<BP0kCdh0;d=203iBD@0oDe40>De;049FE01QMW40?E9=03aAC00fBd@0?U=<045F
C@0iCT@203M=@@80<dPo02d0>4e40356?`0aAT40;d@o0315@00hCDP0?U9@051VI01BIVD0AUYI049F
E00jCD/0>4]803I9A@0jBdD0?Tm803Q9@@0fACh0=dM203a<B@0oCd`0?4a903M7A00_?c`0:3Pe02Pg
=00/>cP0<T4l0350>`0gAT40>dY60354@00dA440=D=102/g<`0X<Bh0:C4]02H/:00R:bH09c4Z02Pc
:`0Q;RD082XS02@]:00V;bX00P0W<2/00`0X<B`09S4[02@_:@0202D`:P0302<^:00Q;2H06B8M0080
728N01`06R0L01/Q7@0P9R809R`X02@Z9P0O9B406b4M01TO6`0H7aT06R0F01`R5P0G7A<0724J02DZ
8`0J7aT06QlK028W8`0J7Qd0720Q01dQ8P0M8B@082HV01lU9@0E6a/061hN01<I6@0@5QH07R@T0P0J
82001@0H7Qh04aTI01@J6P0B51<051HE00806A/J01@08b@S03De=@0K6AX06ALH01DC500F4Q<061@E
01LE5P19AdP06QXJ010@40030`<0?Cdl024Q7`0C4a404a@@01<D3`0B4`h04Q<=014B30804Q<=00/0
5aPB01TJ500];RP0e=G?0?oonP1NGeT0414;014B300C50h05QLB010@3`02010@400:014A4@0@4100
410@014A4@0B4Q807AdM00<30`0C4a<051@D010@4P<04A4C00@03`lA00h>400@41803Ph@0P0=3@l2
00h>40H03@d?00/03Ph@00X:30092@/0410B00P82P0<2``030X;00h<3@0?3@h03P`=00d;300400h<
3@0300d;300<2P/03@/<00803@/<00X030X;00/92P0;2@X030X;00T7200E4a@0IVAU014?40081PL0
3``=0P0?2``03@0>2P/03@T:00d92P0<20T0510A00l;300C3a002@D6014=3P0=20P03PP8010:2P0?
2@T00P0>20P300d71`0300h8200?2@T04@/;00803@L7100>20P07P0?2@T050h>00d8200=1`L03PP8
010:2P0>20X0100000h92P0A2`d0100001<=3`0R71h03PP:00l92`0>20X02P@600/51`0>0`L040D9
01872`0@1@T04@H:01@93@070000304502<H700M4QH040D900d21PH03`@800H06PlC00`21@090080
50T=00d21P0@1@TDooooo`006oooool0100=4Ph041DA00`A3@0>4`l200lD400@00hC3`0B5a<03a@@
00`A3@0=4Ph03Q<?010B3`0>40d03a4>00d?300@4Pl03a4>00L91P0U9b@0@48o018D4@803Q0=0100
314;00lD3@0?50h02a0:00dB3@0C61<02Pl;00X>300E6AL03a<C014E5@0I7A`04A<@00h@3@0=3``0
3Q0=0P0?4@h04`0D5Q<03@l<00`>2`0=3``030h;00/=2P0=3``04Q@A01<E4P0E5a@09RPU00lA3P0C
5A801PP601DG500;3@X05QPE00lA3P0G6AH00P0?4@h04@0:30T061XG04=5@P0U9b@04aDB00`>2`0U
9b@0GV1M01LI5@0?4@`02@/601lQ700R91l030h9018D3`0A4`h0418=00<03Q0;01H0314=00@:200=
4A002Pd<00X>3@0I6aP02`d:01DG500;30L03Pl;01<D3`0?40X03Q0:00`>2@0C5A003@l:00`>2@0>
40/061XE01@F4@0<3PT03Q0;0P0C5A0200lA300G00d?2P0>40/0418=00lA300:30L0418=00h@2`0<
3PT04Q@?030b;@0A4Pd05AHA01<D3`0H6A@04Q<>00l@2`0=3PT02``700d>2@0?40/03Pl:00l@2`0>
40/00P0?4@`06`0:30L06A/F04e?BP0Y:bH02`d900h@2`0:30T02`d800T:1@0>3@T04@h;00/<1`0@
4@`041@>010E3`0:3`T03A4;00`>2@0D4`l06aTE01LC400A3@X05Q4>01DA3P0@3PX04@l<01LF4P02
018B3P04018C3P0F61<04Q@?00l@2`803@h900<03Pl:010A300@4@`00P0>3`X04`0@4@`04A8=03@e
<00A4Pd0414<014C3P0:30L04A<>00d?2P0A4`h03Q0;01dO6P1TIV405aTD00h@2`0E5a803a4<02la
;P072@H00P0<3P/200d?300O010B3`0G6AH02P`900d?300<3P/03Q0=00lA3P0=3``02`d:00d?300>
40d05QPE00h@3@0@4Pl03Q0=00d?300>40d03Q0>00lA400<3Pd04A<B018D4`0A4a802P`;00lA400E
5aH03Q0?01HH5`092`X0418A00L81`0201@F5@0A01<E500<3Pd03@l>00lA400>40l03@l>00h@3`0?
4A003a4?010B3`0=3``04Q@A014C400?4@h05QPE00d?300A4a000P0>40d01`0@4Pl04aDB00/=2P0F
61D0828O01DG500B51400P0@4Pl07@0A4a00418?00h@3@0=3``02`d:014C400>40d0:R`Y08^=RP0i
>cP03@l<018D4@0D5Q<02P`901<E4P0?4@h03@l<01XL6@0L7Q/0418?01<E4P0B51404A<@010B3`0?
4@h0418?018D4@0C5A80418>00804Q@@00L04Q@A014C400?4@h04Q@A00lA3P0E5a@05QPD00804A<?
02002`d:010B3`0C5A805QPE018D4@0?4@h0418?01<E4P0B514051HC01PJ5`0<4@d06b4O00hG500;
51405adK00lE4`0<4Q004aLF010C4P0B51<051HE01LI600J71/04ADF01LK700A5AH03a<D01dQ8P0B
5QL051PI014E5P804aLH03L03a<D01XN7`0@51<04QHE01@H5`0B5QD08RHU01XN7@0B5QD092PW00`@
3`0G6aX06AdL00`@3`0F71`06AlO01<I6@0D6QX041HF01XP800F71`06AlO01PN7P0F71`06AlO01/S
9@0I8BP082T`01HO9@0I92P06B@V01hZ:`0O;R/05RHS01`]9`0S=2d0834Z02<g<`0W?C/0:3hk02Dk
>@0[@Cl0;dE30357A@0`AT@0=Ta903M=B`0mDe40>4i;03U?C00kDTl0?5=@03UACP0hCd`0=Da900<0
<DQ502d0;DE202Y1?P0Y@3d0:T4n02a2?P0_AD80<4I302]1?`0Y?cd0:Cln02e3@P0W?3d0:Sm2049G
FP17G5l0:Sm202a1A00Z?d80:d1302Xo@P0bAdX0<dQ;02Pm@00]@TD0:d13028g>P0`ADP0;45402i3
AP0V>ch083Df0315AP0V?3X0:Cll02Dk>00Y@3X0;TDm02]2>P0Z@CP0;dE202m5@`0nE580;TA203Q>
C00`AT@00P0_AD<01@0aAdD093Xh02Pn?00_AD80<dU60080=di800X0=4]50357@`0`AT<0=de;03A:
B00^A480;dA503E:B`0eBdT0<TQ00P0bB3h07`0bAch0<dLn03=7?P0dASh0<dDm02Hg;`0Q<BT09cL`
02hn=00T=2P09CHZ02/m<@0b@c/0:cdf02Pk=P0/?c`0;40k0397@00dBD80>4i4045GB`0b@cT0:3P_
02dl=P0^?CX0;cln03M7AP0eADH0<49203Q;B@0kCT/00P0nDdh03@13EeD0@UIE03]?C@0lD4h0>Di:
03U=BP0lDD`0>4e703U>A`0hCDH0@EI>03Y?AP0hCT@00P0iCd@0>`0eBT40=DY203Q=A@0eBT@0=DY5
0356@@0iCTX0@UIC03mCD@17GEX0C61N03a@CP0hC4X0>Te:03iACP0lCd/0?Ti:03i?B@0iBT<0=dI0
03Y:AP0jBTL0?Ti;03U9AP0_?c`0;Shk02hm>`0[>SP0;chl0392@00iBdH0>TU703U;B@0eB4D0AUID
03a:B00Y=C<0;3Dc02L_;00O9B807bPS024[9@0O:R<07b`T028^9`0N:28082XT02La;00Q:bD09S0Z
02La:`0Q:bH09c4/05QRG00g@C`08BXU024W8`0P9R807B<O00806b4M00@07bDQ02<Y9@0Q9b<07B<O
0P0N92002P0K8Q`07R<K01`Q6@0F71@0724K02<X8@0I7QT04QLD01LL6@0G6a/201TM7`0401hR9@0F
6a`05a`L01@I6@806AhN02806QlO01hS8`0D6AT05a`M01TN7P0F6a/06AdN01XN7@0H6aX04A@C01<E
500C51@08b@T01PG600F5AD0518C01DB4`0F4a@0518C030`<00I6AT06QXJ020P801XJ6L06a/I018B
400A4Ph0414<014B3@0A4P`03a0:010A2`0E5Q004a@>0P0H6A<0101<CDL0OWmi02`]9`0@4@/2014B
300301LH4`0B4Q403`l?00804A4A00D0410@018B4P0C4a<04Q8B00h>3P02018B4P0300X:2P0@4180
410B0080410B0P0?3a40100@41804Q8D018B500@418200h>400F00d=3`0>3Q003`lA00h>400<30h0
2`/=03Hf>00<30h020P:010@4P0?3a403`h@00d;30091`P04Q0A00T7200B414030X;00h<3@0?3@h0
40h?00h<3@<03@/<01`030X;00/92P0<2P/030X;00d;300A3a005Q@E085oP00B414040h?00l<3@0?
2``03PX;00d92P0<20T03@T:00X61`0C3a002PH700d92P0<20T04`l@00l:2`0?2@T04P`<014;2`0>
20P040X:0P0;1@D00`0=1`L03`T900l92@0200h8200700l92@0>20P03@L700`61P0;1@D03`T9010:
2P0200d71`0400h8200=1`L040X<00`720803`T;00@06Q@F00/61`0@2P`02PD60P0=1`T04@0>20X0
40X<00l4200?10P04PL;00/2100B1`/050T=00l4200A1PX03@@601072@0B1`/03@8601052@0E2Ph0
4PL;00803`@800<03P<700X10`0?10P00P0A1PX00`0B1`/030<5ooooo`0Cooooo`006oooool0200B
5a<03A8>00P=2@0010003Q<?010E4@0;40`03A8>0`0>4`l00`0<4@d0418?00lA3P0300d?300G00h@
3@0C5A805QPE02HX9@0;3@X04aDB00`>2`0=4P`03Q<=00dB300:3`T0314=00lD400@5A403Q8A00H:
2@0@51D09RX[05mSHP0A4a4030h;00/=2P0=3``00P0>40d09P0@4Pl03a4>00h@3@0>40d03@l<00`>
2`0@4Pl00`D201/M6P0A4a000`D202@V8`0`<Rl02P`90002000C5A80FeeJ03Xl>@0@4Pl00@<0010B
3`082PL02@/8038d<@0@4Pl0004001HH5P031@80=cTf01HH500A4`h010H104mAC01SIF007AlJ00P:
1`0?4@`03Q0;0`0=3`X01P0;40`02a4?01<G5P072`X03A4@01@F4`8030h;01003@h900h?2P0?40/0
3a0:014B3@0=3`X05aTD014C3P0@4Pd03Q0;00`>2@0>40/03@l:00`>2@0@4Pd04A<>0`0;3@P300`>
2@0;00lA300F61<0418=01DG4P0G6A@030h;00/<1`0@4@`030d800l@2`0>3`X00P0=3PT300h?2P80
3a0;00h020X5010B3@092`H03Q0;00lA300>40/020X5014C3P0I6aH01`T4024S7P1=CTT03`h:014>
2`803a0;01003A0;00/@2P0=4P`041<>00`>2@0>3@T03``900P40@0E40d07APE01HB3`0@30T04Q0<
01@C3`0=30P05ADA0P0L7AP0100E5Q4030d800d>2@0>3`X300l@2`0:00h?2P0H6A@01`P301/L5`2;
S8L03a0;0042000A4`h03a4<018D3`803Q0;01l051HA01<E400];bX00040018D3`0<3PT051HA00T;
200:30T03Q0=018D4@092`P04A<@00X<2@0@4Pl00@<001/M6P0A4a002@/800P:1`0?4@h06Q`I01/M
6P0;3@X00`D200d?300>40d03a4>00d?300:30T02P`:00804A<B00/03Q0?018D4`0C5A@03Q0?01LI
600C5A@01`T800lA400@4Q403a4@00`>3@0200X<2`0?010B4@0>40l030h=00lA400=3`h030h=00d?
3P0?4A0051HD01LI5P0B51403a4>00T;20082PL061XG00803@l<00T03Q0=01PJ5`092`P05ALD00T;
200I6aP09bTV01DG500<3P/00P0@4Pl06`0A4a00418?00h@3@0<3P/04aDB00h@3@0A4a0010H304M9
AP0I6aP030h;00/=2P0@4Pl04aDB024S800N81d06Q`I02HX9@0L7Q/01`T600`>2`0@4Pl0?T0m02h`
;@0@4Pl01@L400T;2002018D4@0601@F4`0F61D05ALD018D4@0?4@h04aDB0P0A4a002@0C5A004Q@?
00d?2P0B5140418?014C400C5A8051HC01<E4P0201@F4`0>01<E4P0D5Q<05ALD01@I5@000P007BHS
00TB3`001@<05A/I018H5P0B5QD04A@C014C4P0C5A@201@F5@0301<G600@51D03A4B00806alP00@0
6QhO018F5`0B5QL04QHG0`0A5AH03P0G6aX05QXI01TM700B5QD0720O00hB4@0H71/051PG01<G5P0E
6AP05QXI01DI600D6QX06AlO0P0L8R80100G7Ad05A/K01@J6P0F71`201DK6`0;01TO7`0J8R@05AdS
01LP9@0E7b405R4T01PS9@0M:RT07RdZ020a:`0V=c400P0Y>S803@0S=S809cdk02To?@0X?S`0;dE3
03=9A`0eBdT0?59@03iDDP0oEE<0AE]I04ILFP14FeT00P13G5T01011FUL0?5EB03]DD@0fCd`2035:
A`050319AP0]AT<0;DI302e5@P0^A4800P0_AD<0700^A480;49002Pn?@0Z?d009S/l02Hk?P0dBD`0
@eQK04IKGP10EEP0;T=602Pm@00U>Sd0<TM:02<h>`0[@4<0;D9502Tn@@0aATT0:d1302e2A@0_A4D0
:Sm102Dj>`0`AT@0:Clm02Y0?@0W?CX202Po>@0902Hm=@0]A3`0<4I302a2@00_AD<0;TA202m5@`0b
B4H0>U1>0080<DM501P09cdk02e3@@0]@d00;48o03E<AP0fCDL0<4M102a3?P0`AT<0=4Y803]AC`0l
DU00>Tm@03A9BP0/@T00<4Dn0397?P0aASd0;d@k02a1>00[?cH0:CXb02dn=P0P<BT2028a:P0K02Xj
<00W=b`08c@X024c9`0[?3@0:C/d03A7@@0fBDD0>De703M<@`0_A3/0=D`o051VF@0iBSl0;Shd0310
=P0/?3H0:c/h03A4@`0gBDP0>4]903U<B00kCdX0?55:03eBB`0kCd`0>4a:0080?E5?00h0=T]603A9
A00lDD/0=T]40356?`0eBT40>Di503M<@`0hCD@0>e1703Y?AP0gC4<0=da503Q=AP80?E9=01X0>Tm:
04AHEP16FUP0?E5?03aBC`10E580>4a:03E9A`0dAd<0=DQ403a?B`0oCd`0?4e803i?B@0mC4L0>TY6
03E5@P0hB4D0<T8o02`l>@0^?S/0:c/i02Ph=`0a@D00;T4o03U<BP80;d9000`08cHd0351@00[>CL0
8Bd[02Tb<@0X;bh092XX028[:00R;2H072LQ01`Y8P0P;2D201dX8P0N02D`:P0^>C<0:C@^02`e<00R
:bH07bPS05aUH00b>cH082TT024W8`0O9B40728N01XP700L8Qh07bDQ020V8P0L8Qh06AlK01`R7P0M
8al06AlK01PM5`0G71H05a`H01TN6P0K81`05QXI00hB4@0=4A804QHG0P0F6Qd05P0M8B@09RX[028V
9`0J7Ql05QXK01@H6@0@51D0Ngn002da<P0830d061`M01@H6@0Q9BH03Q8A00lC4P0@51<04Q@C01dO
7P0?4A005ADE01@C4`0D4Q<201DC5006018@4@0G5aL04A4A010@400A4A4071`K0P0G5aD07@0D5140
4A8=014B3@0A4P`03Pl901DF400P8A/06Q/E018C3@0@4@/03a0:024R700D5@l03Pl9014B300H6A<0
4Q<>01@D4`0?3`l04a<C018B4P0>3Ph0410@00T92@030`<02`/;01@D500A4A404a<C00L03`lA00<0
4a<E01@D5P0A4A<00`0=3@l03P0?3a40410B00l?4@0<30h02`/=05eMG`0d=3H04Q8D00d=3`0A4A<0
0`8300l=3P0U8b@0<2h_0P0N71d0100<2P/03@/<00h<3@0>30d200`:2`802`T:0P0=2``0800<2P/0
2`T:00P61`0?3@h00@0001`J6`091`P07A/L014>3`0:1PL02`L801<?400F4Q<040`=00/7200A3@h0
2PH7014=3P0810D0=C4b010;300=1`L03`T9010:2P0=1`L03`T900/51@0:10@02`D500d71`0?2@T0
3PP80`0=1`L500`61P<02`D501P030H605==C`0W8B<03`T;00L10`0:10H04P`>00/51`0?2@/03PP:
00`6200>20X03@L901052@0800404@H:020E6@0Y7R804PL;00h31`0E2Ph02`0401H;3`0>0`L200l4
200601<8300?10P03`@801<8300?10P03P<70`0?10P201052ACooooo000Kooooo`0800T>2P0:3`/0
5a`H00L<200F6aL0314=00/@300=4Ph300hC3`0300dB3P0@4Pl03a4>00<03@l<01H03Q0=01XL6@04
1P@00`D201<E4P0a<c009bTV00`A2`0=4P`02a0:00X?2`0<4@d03A8>00X>3@0F6Q/020`=014E5P05
2@X0720O00lA3`0;3@X02P`90P0=3``00`0<3P/03Q0=00h@3@0400h@3@0700lA400@4Q400040010B
4@0[;B`0004000T:2@0201<E500G010B4@0E5aH0418@00d?300620D04aDB00`>2`010`004aDB01LI
5P0D5Q<0=CLd00lA3P0<3P/0418>00`>2@092`H061XE01TK5P0B50l05QPC00lA300>40/00`0=3`X0
3`0A5Q800@L500`@3`0B5QD04ADD0001000@4Pl030h;00d>2@0>3`X03a0;00l@2P0@4P`02`d8014C
3P0200lA300300/=200:30L03@l:008030h900<0418=00lA300;3@P00`0;3@P200X<1`0600<5000@
4Pd020X50001000G6A@04Q@?0P0?40/0600=3PT01`P301<D3`0I6QD03Pl:01@E400A4Pd03@h9018C
3P0?40/02@/600h@2`082PD04A<>00h@2`0620<02P`700/=200=3`X0004003Tk=P1fMg803Pd900l=
2@803@h901H02`l900X?2@0:3`T04A@?00h@2`0>3@T04@h;00l;200F4Pl05a<@010<2@0:2@D03Pd9
00l>2P0=3PT04a@?01TJ5@0H6QD04Q@?00`>2@0@4@`03a0;100>3`X2018C3P0700h?2P0S91l02``7
01HG4P0@4Pd03a4<014C3P0200h@2`0=01<E400g>C@0004000/=200I6aH00@<0010B3@0<3P`03@l>
018D4`0?4A001@L601<E5002018D4`0;00X<2`0>40l00P@301`N7@0G6AH030h;010B3`0D5Q<03Q0=
00/=2P0=3``00P0>40d00`0<3P/02`d:00`>3002010B4@0:00h@3`0A4a804Q@C014C4P0210<00081
01XL6`0C5A@01@L600P:2@803Q0?00@02`d<00h@3`0>40l03@l>1@0>40l00`0;3@/030h;01DG5002
01LI5P0=01TK600@4Pl03a4>01/M6P0?4@h04Q@A010B3`0A4a0030h;01<E4P0J71T04Q@A00/=2P03
00lA3P0M00h@3@0=3``030h;01`N6`0=3``05ALD00H81@082PL04Q@A00lA3P0=3``0418?00lA3P0J
71T05aTF01<E4P0F61D0418?00T;200>40d05aTF01hP7@0G6AH03Q0=00lA3P0E5a@06A/H00lA400D
5QD00P0G6AP02@0B51803Q0=018D4@0A4`l04A<>018D3`0A50h03Q0;01<E4P02018D4@0L01<E4P0D
5Q<04Q@A01@F4`0C5A804A<@018D4@0D5Q<051TE01`R8014CDX07BHS00@:200C6AL02Q0>018F5@0D
5aH05ALF01@F5@0E5aH061XI00`@4@0R9RL01`/<01@H6@093@h05ATJ01@H6@804aLH00H04QHG014E
5P0A5AH04ADD00/?3P0D61L201HJ6@0401PL6`0F6QT05a/J01LK6P805ATH00P05QXI01PN700@5Q@0
5Q`J01PN700F71X06R0N01DK6@805adK02805Q`J01LM6`0G81l051dP01<M7`0E7b005B0Q01`X:00O
;B/072/X020`;@0Q<R`08S<]02<d;P0P<c009S`j02To?@0[@Cl0<TQ603I<BP0hCT`0?E=A045GE@14
FUP0Bf5O04eSH@1:HUl0BV=P04URG`16Ge`0@U]H03mHE@0iDTl0=4e:0P0cC4T01`0aBTL0<4U60317
AP0_A4D0;45202Xo@00[@4400P0/@D80G@0Z?d00:Cho02a1@P0L<C80;T=403aAE00dBD`0:Sm202Tn
@@0X?D00;T=602]0@`0_A4L0:Ci102i3AP0U>Sd0:3e002Pm?P0/@T00:T0o02@j>00Z@3h0:3hl02To
?00X?S/0:d4m02U0>P0V?CL0;D@n03mEDP0[@Cl0>U1>02i4@P0`AT@0>U1>0316A00]@d40;TA202Lm
>`0cBDL0=D]80316@`0bBD<0<4M102m6@00`Ad80=4Y703I<BP0iCdd0<TQ60356A`0eBT/0<4I402i3
?00dBCh0<dLl02e1=P0Z?C80;Chd02<d:P0W=bd08C4W028b:00N;R@0;3`b02Lg;00Y>Rd09CL[02Xk
<`0Z?3D0=dY403E8@P0]@CX0:3dd02Dk;`0W?S40<DPh0396=`0[?C40;Chd02Tj<`0X>3D0;D0l03]>
C00jCT`0>e1;03]AB`0kDTX0?5=;03M<B00kCdd0@5AB03]@B`0203A9A00703aABP0fBd@0<4Dl03=8
?`0eBT40<TLn03Q=A00203]@B@0=03Q=AP0hCDP0>Di903aAC00iCD/0>dm=03mCD@0lD4h0>4a:03U@
BP0mDTd0=da703A9A00203=6@P0n03Y=B@0oCd`0?dm<045ACP10Cd`0?4]703Q7@P0hAd@0<d=003U9
AP0jBTT0;d0o02Xm>`0cADD0=DU803iBD@0aAD@0?U9@03U<BP0dA4<0;C/k02Te=@0c?3/0<3Lg02L]
:`0R:bP092hZ024/:00P;BH07R/T03A1>P0mBT<08BdV01lZ900Q;2H0:C8]02D^:@0O:2<0<3Hb01lU
8@0Q9b<08RPT020V8P0M8al06b4M01`R7P0O9B408BLS01dS7`0J81`0728N01dS7`0I7a/07B4P01XN
7`0I7Ah06QhO01LK700@51D04ADF00dA500@51L201HJ7@0401XN8@0U9RP08B<R01XL6`<05aTH01X0
D59A02T[:P0H6QT0:2XY01PJ6@0F61L08BDV01DI6P0I7Ah041@E01lQ8`0<3@l05AHH01<D5P0C4aD0
51@F01@C5P0B41<071`L010@400A4A40410@00H61@0K6aT071`J01LH50804Q<>00D04A8<00l@2P0?
40/05AHA01<D3`02010A300C00d>2@0C50l04A8=00d>2@0A4Pd07AhI018C3P0H61L04A4A018B4P0A
4A403Ph>00l?3`0H61P04a<C01@D500K6a/00`<3010@400700l?4@804A4C00D03`lA00h>400?3a40
30`>00h>400200l?4@803@d?00h05aLI00000P010@<03`lA00/;3@0G5QL020H700d;300A3a005aDF
00`:2`081PL03@/<00`:2`<02`T:02H02@L800`:2`0B41404a4B00d;300;2@X030X;014?40010000
3`d>0040000C4A803``=00`82@0>2P/07a/L02DQ8P0H51D04@d>00/7200300004Ph?020L7@27Ph@0
>C@d00d71`0?2@T040X:00d71`0?2@T040X:00d71`0;1@D030H600h8200@2PX02P@400/51@803PP8
00@03@L700`61P0<1PH030H60`0=1`L07`0<1PH04`d?00D00@0<1PP03`T;010:30090`D02P@600l9
2`0A2`d040X<014;3@0=1`T02P0300d21P0I3Q8060dA01X?4`0>0`L02@0201<830070000714E00P0
0@0@1@T04@H:00d21P0:00<03`@801D:3P0>0`L00P0@1@T300l4200300h31ooooooooooo01;ooooo
000Kooooo`07014F4P0<4@d02a0<01HK5`0U:RH08RLS00`A3@0200dB3P<03Q<?00<0418?00lA3P0=
3``00P0=3``05P0>40d02`d:010B3`0F61D051HC02DW900Y:bP0314<00/@2`0:3`X02a0<00/@3@0<
40h0310?00X>3`0;3a002@d?014E5`0:3Pl03a4?00d?300<3P/200lA3PH03Q0=01h03a4>01<E5006
20L06adL00lA400@4Q404aDD00/=300=3`h04aDD00h@3`0=3`h0418@00h@3@0C5A803a4>00/=2P0A
4a003Q0=00X<2@0B51403@l<01<E4P0<3P/03a4=00X<1`0>40/0418=00/=2@0?4@`200h@2`0D00d?
2P0<3PT03@l:00d?2P0>4Pl0BDm=08F9R00H71/03A4@00/=2P0?4@h030h;00d>2@0>3`X03a0;00l@
2P0<3@P02`d800lA300>40/200d?2P0600/=200>40/03Q0;00h@2`0A4`h03a4<0P0@4Pd0900?4@`0
3Q0;00h@2`0=3`X08B<N06QZI@0D5Q802`d:00`>2@0@4Pd04A8=00l@2`0B4`h01@H101HG4P0K71L0
3@h901HG4P0B4`h03@h901LH4`0B4`h02`d8018D3`0=3`X03a4<00X<1`0?4@`03Q0;010B3@0620@0
418=00/<200J6aH040l;014>2`803@h901003A0;00`A2`083@L041@>00d?2P0<2`L040d:018>2`0D
4@h04a0=014@300B4@d04A4=00d>2@0B4`h03a0;0P0:3PP01P0=4@/04A<>01<D3`0@4@`03Pl:00d>
2@803a0;00@04A8=00h?2P0?40/0414>0P0=3PT200h@2`0I00d?2P0<3PT03@l:00lA300D5Q802P`7
00lA30092`H0418=014C3P0@4Q403Q0?00L9200?4A003Q0?014C4P0B51<01`T8014C4P0@4Q402`d<
03m1@00O8Ah02P`900P:1`0200d?300300h@3@0?4@h03Q0=008030h;00<0418?014C4@0?4A00100?
4A002@0B51<051HE01LI600;3@`02@/:01<E500@4A004aDD01DG5P0200lA400I014C4P0?4A003@l>
00lA400@4Q403a4@00d?3P0?4@l02`d:00lA3P0:2`T071hK038d<@0N81d04Q@A01dO700?4@h04Q@A
00h@3@0=3``03a4>00d?300>40d04aDB014C4003010B3`803a4>02003Q0=00`>2`0?4@h09RPU00lA
3P0H6QL04aDB00lA3P0;3@X03a4>00X<2@0@4Pl03Q0=00lA3P0<3P/04A<@01HH5@0A4a003a4>01<E
4P0B51404A<@018D4@0@4Pl030h;00lA400@4Q804A<C014C4P0@4Q003a4>010B3P804Q@?00@04QD?
018D3P0@4``05ALD0P0C5A8201@F4`03014C400C5A804Q@A0080418?00H04aDB01<H500F71X041LD
010I5P0D6QP201<I5`0800lC4P0D5aH05ALF018D4`0D5QD061XI01HJ6`1IGEh201LK700300`@4@0J
7Ql05a/L00805QXK01405ATJ01@H6@0D61T06AdL00dA400O8b809b/Z018F5@0G6aX05ATH01`P7`0M
8B0061`K01@H5`0E6AP05Q`J01<I5`02028X9P1901@J600F71X061hL01TO7@0J81h06b4O01TO7@0G
81h06B8R01TS8`0O:BL06RHU020/:`0X=S@082l/020`;P0S<c40:3Td02/k>@0W>SP0:3dm02]0@00^
A4<0<TQ703M=C00lDE40A5UI04]PH01CJ6P0G79a05idL`1KLg40F75_05E^K01@JVP0BfAR04IPGP10
FUP0>UAB03M@CP0dCT`0<Ta:031:B00_ATH0;dA602e2A00[@480:Sm102]0@P0]@T@0<DI802]0@@0a
ATL08CHg02Xo@00X?D008SLj02a1A00_A4L0<DI902Pm@00]@TD0=4U<055VJ@0eBTd0D6EX0397B@0V
?3T0:Clk02]1?P0W?CX09C/i02To?00202Lm>P0N02]1?`0`AT<0<DQ302m5@P0aAdD0:Clm04YPGP0d
BTP0>e5?0398AP0_AD<0<dU70357A@0_AD<0>U1>03Y@C@0gCDX0<DQ202]2?00]A3h0<TQ403E;B00e
BdT0>4i<03A:B00eBT/0>4e>0398A@0]@S/0;d@i0P0aACX0=00a@cT0<44g02Lh;P0V=R`093@Z02/i
<00U<bX0;C`a02Hf:`0_@3<0<T@h03a=A@0bA3d0;D0j0396?P11ETd0@UQ<03E;?P0Y@C40;4<b02Pl
;00Y?Bl0:d0c02a0=P0_@cd0=4Y403U?BP0jD4X0>E5903YCB@0kE4T0?5=904UNFP0nDTl0?55=03U>
B@0fBdD0>Di803]@B@0hCD@0=4U003Q=@`0jD4D0=da303eBBP0mDT/0?55:03Y?B00gC4L0=T]603M<
B00dB4H203U=B`0d03E9A`0fBTP0=Te703A9A00bAd80<4E00395@@0fBDD0?E1<03m?C@0mCD/0?dm=
03m>C00kBTH0=dI103A3@00`@3d0@U9?049DDP0`@d40:3/j0355A@0hC4`0@5AD03=7B@0fBDX0=DM6
02Ti>@0Z>3P07BTY02Pa<@0X;bl08RPX01dV8`0S;BX09S4]02Lc;P0Z=c40?de604EBB`0Y=Bl08blY
024/9P0O:2<092dX02`d;`0P9R8092XV02H/:00Q9b<082HR01dS7`806b4M00@07B<O02<Y9@0P9R80
7B<O0P0L8Qh03P0L8Ql061`R01TK900J7BH05APP018E700K7R@061/Q01@G6`0H6al07R8U01XN8@0D
61X06Q`K0P0H6QT0400J71/06adL01XL6`0H6QT051HE02<U900A4a806Q`K01dO7P0Q9BH0;34a00lD
5@0K7b004aHG01TK7@0E5QP201@D5P0M01DE5`0E51L04a8D010@400F5QH02PX:01`L700K6aX02`/9
01TI5`0E5A804A8=018C3P0C50h04A8=010A3@0@40h04A4>01<C4P0C4a40410=00l?3P0D5180410=
00/;2@0C4a807AdL01XJ6P0D51@00P0@410200h>3P0601<C4`0<30`030`<010@400A4A403Ph>200?
3a40200>3Q003@d?00h>400@41802`/=00d=3`0>3Q003`lA0P0>3Q003P0D51H0;Bd_01HF600>3Q00
2PX<01dL7@081`L03P`=00X82@0>30d01@@4018@4@0?3@h03@/<0P0<2P/01@0=2``030X;00l=3P0E
4a@04a4B00803@/<00L03P`=00l=3P081PL04a4B00P61`0>30d03P/<00803@T:01405a<D01/G600D
414030P9010<3@0<20T03PX;010<3@0L61T04@`<00d71`0?2@T040X:00d71`0?2@T04`d=014;2`02
00l92@0:010:2P0?2@T02@<300/51@0>20P040X:00l92@0=1`L03PP800l92@804@/;00<040X:00l9
2@0<1PP00P0@2P`0100;1@L030L800X51P0>20X200d72@03018<3P0F41803`T;00804`P<00L03PD7
00/2100@1@T0304501462P0B1`/0;24U00804@H:00T03`@801872`0?10P03`@801052@0?10P03045
01462P0@1@T00P0?10P00`0>0`L03@86ooooo`0Cooooo`006oooool02@093PX03A8>00P=2@0b=c<0
ADY605=HE00B5a<041DA00dB3P0200/@300300X?2`0@4Pl03a4>00<03@l<00P03Q0=00P:1`0?4@h0
5ALD00/=2P072@H02`d:00dB3P802Pl;00l0314=00`@3`0;3`h03Q8A00451P0D61T02`lB00`@4`02
1PL03a4?00d?300>40d04A<@010B3`0?4@h01P0>40d07P0?4A004Q@C01TK6P1mOgh0004000lA400=
3`h030h=00@61@092`X03a4@00X<2P082PL02P`900d?300C5A804Q@A00T;200?4@h03Q0=00`>2`0>
40d00P@1010B3P0<3PT03a4<00D7100210004A<>018D3`<030h90P0=3`X03`0I7AX0PhV70<G9b00R
9RD01PX901/M6P072@H030h;00d>2@0>3`X03a0;00l@2P0C50l06A/F00h@2`0200`>2@0500lA300:
30L03@l:00`>2@0:30L00P0=3`X200h@2`@03@l:02000P@001lQ70051`<06Q`G01DG4P0A4a003@h9
00h?2P0@4@`02@X5014B3@0?40/030d8018C3P0@4@`03@h901@E400A4Pd03@l:01@F4@0@4Pd03@l:
00/=200N81/00@<000/=20000P004A<>01@F4@1KG5L04A0<014>2`803@h901003A0;00dB300730H0
3A0;00/=200=30P04a4=01@@3@0>3@T03`h:01HG4P0H6A@04Q<>00h@2`0=3`X03a8=0P0@5@l0100>
4`d02a0:010B3@0@4@`300l@2`09010A300B4`h03@h900T:1@0720<04A8=01@E400?4@`04A<>0080
3@l:01d0418=00lA300D5Q405QPC00/=200A4`h05ALB00P:1@0>40l04A<B00T;2P0>40l02@/:00P:
2@0<3Pd05QPG014C4P0@4Q4020X900D71P0<3P/02P`9010B3`0B514030h;00/=2P0<3P/04Q@A014C
400200/=2P0?00lA3`0>40l03Q0?010B4@0=3`h030h=02LY:00E5aH0418A01/M700<3Pd0418A00`>
3@0@4Q404Q@C00803@l>01T03a4@00h@3`0=3`h03a4@010B4@0?4A003@l>018D4P0B51404A<@00X<
2@0@4Pl071hK01PJ5`0;3@X04Q@A00h@3@0C5A8051HC018D4@0E5a@0418?00/=2P0@4Pl03Q0=0080
4A<@01D0418?00lA3P0@4Pl04A<@01@F4`0A4a00;Bl/00h@3@0L7Q/03a4>00h@3@092`P0418?00d?
300A4a004aDB01HH5@0@4Pl03a4>018D4@0A4a000P0?4@h03P0=3``02`d:00h@3@0B51406Q`J01<D
5P0A4Q@03a0B00lA400B51805ALD00h@2`0A4`h04Q@?0P0A50d01`0B5@h051HA01<E4P0C5A8051HC
01DG500C5A800P0A4a02018D4@0C01<E4P0A5Q805Q`J01@M6P0?61D041HD01<I5`0>518041@C018E
500C5A@04Q@C01<E500F61L0310A024U9P062P/04QHG00H:2`06018F5`0F01<G600;3`h04ADD02da
<00a=C@06alN01@H5`0R9RD06alN01DI600A5A@051PG01LK6P0C6AL061hL02@Z:00S:BL051XH018H
5P0G7A/05A/I01HL6P806AlM02005QlL01HP6`0G8Qh06RDQ01LS7`0J9R@07bdZ01DT8@0L;2/0:SXi
02<c<P0V=SD0:Sdm02Xo@00]@T<0<dQ903A9BP0iCTl0@UMH04mTI@1IKVl0IW]l07:7R01dRHX0LHV9
06^5Q01UOgh0GWQg05I`K`1?JFP0AEmN03aFE@<0=U1?02X0=4i=0318B@0_A4L0;dA702i3AP0[@4<0
:Sm202]0@`0cB4/09c`m02Dj>`0[@44093Tj02m4A`0S>3/0;D9502Pm@00`ADP0;45402<h>`0B9bX0
?E9E02Pm@00_A4L0:3do02To?00V?CL09chh02Y0?@0T>SL0;48o02Y0?@0Y?c`093Xh02Lm>`0`AT@0
=4U902Lm>`0/@T00?E=A02Y0?P0gCD/202]1?`0Z02m5@`0/@T00=4Y803A:B00aAd@0>Dm<03=:A00]
A3h0;TDo03=9A@0fC4T0>U1>03E;B@0nE580@5EF03=8B@0]@d00<4@k02a0=@0[?c@0;T8g02`n=00U
=R`08c<Y02Ti;`0S<bT0;CXa02`i<00/>Bl0;Cd`02m0=00[?C40>4U103A6?`0[?SP08CD/0397?@0a
AcX09S`_02Dm;00/AC80:T4_0P0]A3@02`0]A3L0<TU103M>AP0fCTP0=Dm603I@A`0hDTL0>E=603UC
B00oEDh0=T]60080>4e801H0<TM00315?P0fBd@0=DY103=8?`0iCd<0?UA803]AA@10EDh0?E9;03aA
BP0kD4T0=da703A9A00iCD/0>4a:03M;B@0iCD`0>Ti=03]?C@0dBd@0;T<n0P0`AD00:`0cAT80>Te9
041CC`0oCdh0>DU803Y:B@0kBDT0>TU603A3?P0a@3d0:cXg03A4@@0gBTP0<4A202Tm?00aADH0<DI7
03=8B@0Z?d80=T]<03e?C`0L;2`08c4a01DQ8@0T;2h09B`]028X:00M9R<082XV020[9`0Q;BT082hX
01`[900N:b@07b`U02@a:P0R;BL08b`W028[9P0W;BT07R@P028X900S:2@00P0O9B401`0M8al06R0L
01XP700J81`082HR01hT800I7a/00P0F71P08P0H7Q`06Q`Y01/L;P0P8C806A/Z01<E8P0T9c405APQ
01@G7P0M82D08bLZ01hR9@0I7Ah05QPG01LI600J71/071hM01/M700F61L061XI01`N7@1dMWD0>cdl
01XL6`0R9RD0WJ6R0;:h^00D6QX06AdN018F5`0E6AX05QLI01@E5`0D51H201DE5`0>018B500D51@0
5QHF00l?3`0B4Q80410?018B400@40h03a0<010A300C50l051D?018C3P0H61H301<C4`803`l?00T0
30`<00h>3P0<30`071`L00410@0I6AT05aLG01<C4`0>3Ph00P0?3`l01`0<30`0>CTi02LW9`0L71`0
30`<01`L700410@01P0?3a4300d=3`0300`<3P0>3Q00410B00<030`>0`0=3@l0300410H0<S8d014A
4`061PP03Ph@00d<3@0;2@X061HG00`:2`0D4Q<05A<D018@4@803`d>00<03P`=00d;300>30d00P0<
2P/01P0>30d02`T:00T7200;2@X03P`=00d;30<02`T:01/030X;00h;300?2``03@T:00X61`091@H0
30P9010<3@0H51D02`L800<0000F4Q<00`0001HA4P0=1`L03`T9010:2P0=1`L03`T900/51@0:10@0
2`D500h8200?2@T03@L700/51@0<1PH00`0?2@T00`0>20P030H600`61P0300d71`0500`61P080P@0
1@0102PR900m=cT00P0E3a402@0;1@L03@L900/51`0<1PP040X<00d72@0=0PH04@H:00d31P020187
2`0=00d21P0@1@T04@H:04]0A00:00<04@L:00T00P0C20`04@H:01872`0A1PX03P<701462P020105
2@<03`@800<03P<7ooooooooool04_ooool001_ooooo00P02Pl;01DJ5P0;40`06AhJ010C400:3`/0
3a@@00hC3`80314=00@03A8>00hC3`0@4Pl03a4>0`0=3``0200>40d030h;00lA3P0:30T04Q@A014C
400B51403Q<?0P0:3`/04@0>4Q403A4@00`@3`093@h0<SHg00020`062Pd05QXM01@H6@0>40h030h;
00h@3@0A4a003a4>00h@3@0@4Pl03a4>00803Q0=02003@l<00`>2`0>40l020X900T;2P0Q8b803@l>
01DG5P0>40l03a4@03Pj>@0a<c808R@S01<E4`0<3P/02@/8010B3`0C5A803@l<00X<2@0F61D04A<@
01LI5P0<3P/02@/8018D400=3`X02@/6010B3@0F61<03Q0;00T;1P802`d80P0<3PT04@0=3`X01PX7
01<I5`0^<S4041@C00P<2`0G6AH03Q0=00`>2`0=3PT03Pl:00l@2`0?40X08R@N02d_:P0<3PT02@/6
008030h900@03@l:00lA300;3@P02@/60P0=3`X00`0;3@P030h900`>2@0200`>2@0=00d?2P0D5Q40
10H101HH4`0;3@P04aD@00X<1`0=3PT04a@?00l@2`0C50l0414<00h?2P0300l@2`<03Pl:00h030h9
014C3P0>40/0418=00h@2`0Q8ah092HQ00X<1`0E5a80418=00<50P0N7aX04A0<00l=2@802``700X0
2`l900dB30083@L02`l900`>2@0B4@d06aTE01/G500=30P030d80P0B4`h02@0;3@P03@l:00d?2P0>
4`d04AH@010G400=50d02a0:00h@2`02010A30804A8=01@0414<01<D400@4@`06AXE00h?2P0J6aH0
004000lA300A4`h030h900d?2P0@4Pd03Q0;00/=20082PD01PP301<E400A4`h0418=01<E50804Q@C
0P0:30/03`0Q8b803a0?010B4@0>40l030h=01TK6P0C5A@03@l<00/=2P0>40d03@l<00h@3@0B5140
3@l<014C4002010B3`0D01DG500F61H03@l>00d?3P0@4Q4030h=00/=300:30/01`T804i@C`1_LG00
30h=0001000>40l03a4@010B4@0<3Pd03Q0?00lA400=3`h200h@3`0C00lA400>40l03Q0?00T;2@0=
3``04aDB01`N6`0E5a@03@l<018D4@092`P051HC00lA3P0;3@X07R0M018D4@0D5Q<04A<@00d?3002
00h@3@80418?00d03a4>00h@3@0?4@h04A<@00/=2P010`003@l<00lA3P0J71T030h;01<E4P0=3``0
4Q@A00802`d:03L03@l<00lA3P0?4@h030h;00lA3P0D5Q<05QPE010B3`0B514051HC018D4@0>40d0
2P`:014B500A4QD0414C010B4@0C5A<04aDB00d?2P0B50h04aH?014D3@0A50`04aH?01<E400B5140
4aDB01DG500F61D051HC010B3`0B514051HC01DG500D5Q<041DA00@:200A6QL02A8?00P>300C6AL0
4QPF01@H5`0C5QD051HE01DG5P0G6AP05QPG01@H6@0?4a@0310A01PL7@0G6a`05QXK008041@E00L0
4ADF018F5`0C5aP04aLH01/O7P0N8R40:Rh]00805a/J00<041@C01lS8P0I7A`00P0F6QT201LK6P05
01DK6@0B61H04QPF01@J600F71X00P0G7A/09@0D6QP05A/I01XP7P0K8Al0624N01LQ6P0G8Q`051lI
01PU7P0L:2@082dZ01h]:P0eAD@0Be]J02dm?@0[>c/0<4=502]0@@0_A4D0>4e>03U>C`0nDe@0BUmP
05M/K@1SN7T0LXN8082EUP22UiP0P9RH07ZDT`1bS8/0JXB3061jN@1FL6l0BfET041JF@0jE5<00P0h
DU40:@0eCdh0<TU:0315BP0_A4T0;T=802a1AP0[@4<0;4540315B00^@d@08CHg02i3A00U>S/0:3e0
01`a=00[@4<08SLj02m4A`0^@dH0?E9E02Pm@00^@dH0=T]>01X_<P0bAdT0;D@n02Dl=00T>c<0:d8l
02<j=00]@d009S`j02i4@P0`ADH0:Sm002e2@`0cB4X0=4Y803=9A`0bB4H0;TA20080<dU700P0=de;
03Q>C00hCT`0C69P04=IE`10EU<0=D]803A;A@80<TU302H0=Te803Y@C@0oEE<0<TQ604AJF018GEh0
=T]<03Q>B`0aAC`0<4@h02e1=@0]?c<09cT]028d:00Z>Rl0?Ti302hn<`0^>c40;c`b02hk<@0^?S40
<T<g02Xl<00cA3`0<dDm02m3>P0cAch0:Chd02Dk;P0_ACP0=Ddk02Ho:P0[A300;THf02a4=00Z@SD0
<DQ003A>A@80=e5800X0=U5803IBAP0fDT@0=U9603I<AP0fBdH0>Di903E:@`0`ACh0<DHo0P0eBT40
2P0cB3l0>U1403iDB00kDDD0?U=<03]@B@0lDDX0?E9=03Y?BP0gC4L203]?C@0<03A8AP0gBdX0?E5@
03U=B`0cBT<0<4Dn03I;A@0dBD@0=4M303Q;A`0nDDd0?dm>0P0jBTT09@0iAdL0>4M403=2?@0c@Sd0
;chj0310?@0hBdT0>Ti<0355A00fBd`0<dQ:0318BP0]ADL0KX>408FGU`0fATH0;3Xj02Da<@0b>S`0
:C0a02@Z:P0O:2L07RPV01/V8P0N:RH0938/02hm=P0a@3T09cD^02Tf;`0a?3H092dX024Z9@0S:BD0
9R/W01lT800Q9R800P0P9R801`0N9200728N01/Q7@0J81`07R@P01dS7`0H7QX00P0C6AD07@0F71/0
8bDd01lP=@0R8cL07Qla01@F9@0I6bL051LP01@G7P0K7R<07R8U01XN7`0K7b005ALF01HH5`0I6aX0
7R0O01lQ800L7Qd061XI01HH5`1IFeX092HU01dO7P0f>ST0]KVj0;Zo`P0K82<05QXM00804aLJ00<0
5QLK01@E6@0C51P00P0E51T03`0C4aD05QHF01@D500E5AD03Ph>014A400I6AL03Ph<00l?300B4`h0
5AHA01@E400A4Pd0410@00`<3P02010@4P0300h>400C4aD03Ph@00803Ph@00H0ATI800L72@0C4aD0
4Q8B014A4@0=3@d2010@400300/;2`0I6AT04a<C00803@d=00<05aLG00l?3`0?3a401@0?3a401`0;
2`d03@d?00d=3`0<30h03@d?00h>400=3@l01@0<30h0300=3@l02PX<00h>400?3a4010@600l>4008
1PL00P0101LE5P0=2``03P`=00/92P<03P`=00@03@/<00`:2`0;2@X02`T:0P0<2P/200/92P<03`d>
00@020H700T7200610D030T:0P0A3@h01P0?2``03@T:00h:2`0:1PL030P901<?40805A4B00T00`00
00l:2P0=1`L03`T9010:2P0=1`L03`T9018<300?2@T00P0<1PH200d71`D03PP800<03@L700`61P0<
1PH00`0;1@D0800<1PH04P`>00d72@0B30h06Q@F00@000090`D02P@601D?4@0I4aD030H800T31@0<
1PP01`0001H;3`0E2Ph03@8600/2100=0PH02`0400h41`0/8BD0304500d41P0W72008AHJ01<8300@
1@T04@H:00l4200B1`/03P<70`0?10P201052ACooooo000Kooooo`0;00P>2`0[<Rl06AhK00H<2@0;
4@h03A8?00X?300;3`d03A0>00hB3`0A5A800P0C5Q@01`0930X06QdK00L81P0=40h04A@B00hA3`0F
6AL00P0>4@l0400?4Q002Pd;00hA3`0>4Pl03A0>010C4P0F6AP03a8A01`O7`2;SXh0=CPh014D500?
4Q@04aHG00d?3`0?414200d>3`0800lA4@0<3Ph071hN00lA4@0A4Q<03@l?00d>3`0;3@d200d?3P0;
014C4P0;3@`05ALF00H71P0D5QD02P`;03/m?00X:RT02P`;00d?3@0?4@h00P0=3``04@0<3P/02`d:
00h@3@0;3@X04aDB00/=2P0?4@h051HC00lA3@0E5a804Q@?00`>2@0:30L02``700h?2P0<3PT03@l:
00<03Pl:01D04A@?00lC3P0930X03a4>00/<200>40`03a4=00h?2`0?40/05AHA01LH4`0B4`d0824L
02T[9`0>40`02`d900h@300?4@d0418>01dO6`0Q8al00P0>40`09`0?4@d03Pl:00h?2P0=3PT030h9
00d>2@0>40/01`P501PI500;30P030h900P91P0B50l03a0;014B3@0;30L04A8=00h?2P0A4Pd04a@?
010A300?40/03Pl:00/<1`0<3@T0:R/Y01HG5@0<3@/051DD00d>2`0N7a`0KFi[01DF4P0<3@P020T5
010A300?40/03`l:00l?2@0200`=200d00`?2@0<40T02Ph800hB3@062@D04Q@@00d?2`0?4Ph02Pd9
00/?2P0C5a804A@@00X=200?4@`03A4;00hB300<40T02@d7014E3P0830L03Q0;010C3`16BTD0ATM3
00lB3@0B5A40?3lk014C3`052@@02`h900P:1P0F61@03Pl:00l@2`0<3PT02P/6010A300=3PT04A8=
01@F4@0?40/03Q0;00P9100@4Pd03a4?00`>300B518030h<01/M6`0o@Cl0@49000X<2P80418@00h0
61XH05mQG`0B5Q<0:Rd[05ILF@0B5Q<020/900P>2`0?4a403A0>00/?3@0@5A806ahL01XM6`803a4?
01P0418@00h@3P0>40h0418@00d?3@0E5aD04A<A01<E4`0G6AL03Q0?014B4@0>3`l03a0?010A4@0A
4Q804Q<C00`=3@0A4Q40414A014B4@0;30`03a0?018C4P0A4Q02018C4P0:00h?3P0H6AP04Q<B00l@
3`0?40h03@h=01<D4P0=3`l03Pl@010B4@804A<A01/04A<@014C3`0@4Ph03Q0;00d?2`0>4@/0418<
00lA3P0C5A<04Q@B01<E4`0A4a403@l=018D4P0>40h04A<A00lA3`0@4Q004aDC01DG5`0<3Ph04A<@
01<E4P0@4Ph04A<=00lB300@4`d00P0B51401P0C5A<04aDE00d>3P0@4Q004Q@B014C4@804A<@00H0
4aDA018D400@4Ph03a4=014C3`0C5A42018D4P0_01<E4P0D5Q<05ALC01<F400D5Q805ALD01@F500C
5AD04aDF00lB500@5A@041HD014F5@0@5A@04QLF01TN700@51<04A@C01DH5`0=40l05APG014D4`0?
4a<05a/K014E5@0D61P04aLG014E5@0@51@05ATI01LK6`0B5QH051PH01PL700G6aX07B4P01lS8P0F
6QT0<cLf03e1@00E6AP05a/J014E500Q9B@051PG01XN7@0A5aD00P0H7Q`04P0G7A/05Q`K01@J6@0H
7Qd051XI01HL6`0L8R<07R<U01`R8@0K9Ah06bDM01PS6`0M:28082dW01d[9P0N;BT0<D4m03i?C@80
9SLf01h0;T9102]2@@0^AD@0>Dm?03eCE013FUX0E6U[06UmO`1iS8l0S9bP09bZ[P2P[[@0XJbd09fW
/02CWjH0QY>J07R9SP1ZOh<0FW9c04YTI010G5X0>eQF03IDD@0aCd/0<D];0398BP0_ADT0;D=602]2
@`0[@D<202]2@`0802m6AP0S>SX0:D1002To@00[@D@08SXm02e4A`0S>C`202]2A01?02a1@`0fBdd0
:d1202m4AP0cAdL09cdm03I<B00V?SP0:40k02e5@00V?CX0<4M402@l>@0iDDh0E6]Z02m6A@0]A4<0
<4I702m5@`0`AD@0<dQ603M<BP0`AD<0<DI303=8AP0`AD40;D8n03Y?B`0cBDD0<DM30399@P0`B480
;dM202m7A00dBdX0>E1@03M>D00hCU40EF]/06^1PP0oEU@0>4i90398?00dB3`0<DDl02i0>`0Z>cT0
:CXj03A5AP1QLG00AUEA03I6?P0a@CH0:c`_02dm<00gASX0<d@h03=4>@0b@cX0<dHl0396?@1>HeX0
:d0g0316?00dBSl0<4Ll03A:@P0eBd40<dTn0399?@0gCD<0>55803U@C00jDDh0>E1>03Q@B00fD4@0
=e1503Y?B00203U>B080>4e602P0>e1903E:@P0fBd<0=da403aAB00oE4`0?E9:03eBB`0lDD/0?U==
03iCCP0kD4/0?55<041DD@0mDDh0=da803]?C015FEP0?U=?02i2>@0W>c40=DQ103E7@00bA3d0=dU3
03Y<A`0kC4L0?4e903I6@P0c@T00<D0k02hl=00a?cT0;chh02lo>`0hBD@0>Te:03A9A@0iCD`0=D]9
0P0aB4L03@1aQ8<0TZ6Q02ln?P0Q;B`09S0^02Pc<00Z<c009RdZ024Z9@0S;2H08RdV02D`:00Y=Bd0
0P0U<BT08P0P;2D0:38[02Pb;@0R:bH07bPS024X9@0]=34082PT02@Z9`0Q9b<082HQ01hS7P0O9B00
7R<N02L]:00P9R406b4L01PN6@0J7aX06R0K01`Q7@0M82L061/T01/N9`0M82P05APO01@G7P0E61d0
4QDH01DI6@0L8Al07B8N01dQ7@0I7A/201XM700>01TL6`0L7ah08bDS01PJ600A4a407b4M01<D4`0P
8Qh03@h;02LZ:@0e>3P05APH01LJ6P0D5AH201DF5`0601TI6P0C51D04Q8C01XJ6`0>3Pl0410?0P0A
4A00:00@3`h06aXI01<C4@0E5180410=01@D4@0E5A805aLC00l?300C4Q804A0B014@4@0E51D051<D
018A4`0D4a@04A0B01XI6`1<Bdd040l@01<B4P0@40l05QHE00X:2@0A4A003Ph>00l?3`0A4A404A4B
00T92P0>3Pl04A4B00d=3`0@3a403Pd?01<B4`0?3Q002`X;018A4`0<2`d200h=3P803@`>01403Pd?
00h=3P0;2P`03@`=010?4@0?3Pl030/<00h=3`0L6a`03@`=00`;3@0?3Pl02`X;00T82@0P7b00W9^K
01hM7P0200l>3P0600`;300=30`03@`<00/:2`0:2@X030X;100>2``03`0=2P/030T:00/82@0?30d0
3P/<00l<3@0<2@X03@X:00l;2@0?2`/040`<00l;2`0=2@T03`/;00`82@0200l;300@00T61P0E4A80
3PX:010;2`0?2PT03@P800/61@0>2@P06QDE01HA4@0>2@T02`H600`71P0>2@T03PP800l92@803PP8
02<030H600l92@0>20P03`T900d71`0<1PH03PP800l92@080P<04P`=00d7200;1@H02P@500h82@0<
1PL0618C01/E5P0B30d02PD500d7200A1PX04`P<00h41`0B1`/04@H:00l4200>0`L04`T<00`21@0F
2`l050T=030V:00P5QH04`T900d30`02010620803@<700D03@D900/31`0>1P`04@T?00`42P0Doooo
o`006oooool0200010404a`I00/D4@093`d0728P01lU8`0<40l03A0?0P0?4A02010B4@0U00T=300F
6QT0D5AC02@X9`0G6aX010P70001001:CTd0Gf=R01@H5`052@P04QHE010B4@0B51<02`d<00P:2@0?
4A000`D4010B4@0I6aX02P`;014C4P0;3@`00`D4018C5P061`/051DI010A5@0=3Q804Q<G030a=@02
0`L01`P<01TJ7P0S92P071dO00h@3`0201@F5@804A<B0P0B51<04P0<3Pd0418A01HH5`082PT0418@
014C400:30T01`T600d?300@4Pl04A<@00L91P0E5a@04A<@01TK600>40d04Q<?00h?2P80414<00@0
3Pl:00l@2`0?40/03Pl:0`0?40/0200>3`X03@h900d>2@0@4@`04Q<>00d>2@0<3@P03a0;0P0<3@P0
3`0D5A005aPC010A300=3PX03a4>00h@3@0;3@X02P`900h@3@0=3``07R0M01XL6@0;3@X030h;014C
400200l@2`0500h?2P0=3PT03Pl:010A300B4`h00P0?40/0100L7AP04A8=014B3@0;30L200l@2`06
00L80`092PD061TD01<D3`0B4`h0414<0P0>3`X0300>3`/0:b/[01LG6@0;2`d0410@00l?3`0E5AD0
8B4O00X:1`0>3`X03@h9010A30803a0:02l03a0800h?1`0>3`T03@l900`?200H6QD03A4<01DJ5P0V
:bL01P`801<I5@0H7QX051TE00D:1P042@D03a8>00lA300C5Pl02P`6014B30082@402P/401/L5P0A
4`h03a@@055FDP1?E5004aPD020U8@1JGe/05a`H00@91@062`L0314=01@F4`0>3`X03@h900h?2P0=
3PT04A8=00d>2@0O81/06Q/F01@E400B4`h020T400`=200200/=2P0A010B3`0<3P/02`d:01@F4`0?
4@h0418?0043000C5A807b4N06MYIP0B5A@02@l=03e3@@062PP04QPF00X@3P0<4Q000P0;4@l00`0<
4Q003A<A010C4@02010B3`0F00lA3P0@4Pl0418?01DG500J71T05aTF014C400B51404A<@01HG5@0F
5QH04A4A010@400<30`02`/;00X:2P0B4Q805QHF00d=3@0P8200410@01DE5@803`l?00`02`/;01<C
4`0L71`04Q8B014A4@0C4a<03`l?00`<300B4Q803@h@00d>4P0>3a42014C4P0<010B3`0B50l04A<>
00lB2`0=40T03Q4:00lB2P0D5Q<04A<B01<E500E5aH0418A0P0A4a803P0@4Q403a4@010B4@0A4a80
4aDD00/<3P0E5QP051HD00<50P0?4P/02Pd800lB2@0@4`X04Q@?0P0B51<03`0A4Q@0418=014D3P0@
4Pd03a4<014C3`0E5a@0418?00h@3P0>40l04A<B01@F5@0C5A@04A8D018D500201<E4P0P018E3`0A
50d04aH?01DG4`0@4A<03a0D018C6@0?3aL041@E00lC4P0C5aH04QHE01<G5P0K7ah05QXI01<G5P0A
5A@05ATH014E500=4A007R8Q00lC4P062PT041@C00030P0J7Qd061`K018F5@0F6QT07B4P04Y>C@0@
51<201XN7@1E01PL6`0G6aX07R8Q02<W9P0F6QT07B4P01LK6P0L81l06QhM01PL6`0C6AL05adK01PN
700G7A/05adM01PN7P0I7al061dP01TN8@0L8B@0724U01/P8`0I8Q`06R@L01`V7P0M:2807BXS01l]
9`0O<2X08C8/02@g<P0Y?3P0:Chi02]1?@0Z@d00;4E203M@CP10F5P0BV9R05eaM01hRXh0SibR0:Ra
^@2m`L`0aLOC0<_6eP37`=80^[K50:>T/@2=UJ00O8VA06^0Q01ILg@0AV=Q03aJE`0fEU40=EE@03IC
D00cBd/0<DU90318B00_AdL0;DE502a4A00^ATH0;dM702]3@`0Y@D40:d=301lh?00H<CD0;DI:03E=
C`0/A4H0;TI803A9BP0]@T<0:Cdn02/o?P0]@D00=TY90357A@0W@3d0;DI302U2?`0202Y3@00903E>
B`0]AT<0?5EB01lh=@0cC4T0<4Q502m3@P0aAD@0<dM50080<4A20440<dQ303A9A00bAd80<DHo03A9
@P0fBd@0=DY303E<A00cC4L0<T]803=;B`0eCE00=dmC049JGP0fCU40;DE5051YIP0bBdH0>4m503=9
?00cAcX0<DA00353A@0^?dP0;3a903E5DP1TMGd0BeeO03Y=B@0`A3L0;3h^02dm<00e@cL0=DDj0351
=P0a@CL0=4Dk04YNE@23Uhl0>4e603I=A`13FUD09cdk03U=CP0hC4X0=da503Q>@@0nDdX0@UM@04YN
GP0fBDd0>Da@03M;B00fBd80?eE903aABP0hCDH0=da503Y?B00iCTL0=da503=8@@0fBd@0>4e603]@
B@0203eBB`0303eBC@0lDD`0?U=>0080>Tm:03<0?eA?03]@B`0bAd80>4e803iCCP12Ee80=4U203]=
@P0oD4H0@eA:03A5>`0b@c/0>da403M8@00hBD<0?Di802m0>P0Y>S@0:CLa02Tf;@0[>2l0:SPa0391
>P0gB480<T@n02i1>`0aA400;T<n02Pn>`0Y?C/0:SXi06A`L019EE<08Rh[02Xe<@0N:B<082XS020Z
8P0N:1l09blW02Xa:@0Z<RL0:C8X02H`9`0`>S80<C/c02<]9@0Q:RD05b0K024Z9@0U;R/00P0N9b@0
6`0H8Ah0724M020U7`0L8A/08BHP028W8@0b=c40724K01PM5`0I7QP0724K01/P6P0M8Q`061dG01@I
5@0G6aT06QhM01PL7@0K7b008bLX01`P7`0G6aT0724K01dR6`0D6A4061hJ01TO7@0201/O7P0;01hR
8@0V:2D05aTF00h@300B4`h04a@?014B300I6Q@04Q8@01HF500H61H00P0G5aD02@0J6QP092@R018B
400?3`d0410>01/K6@0B4Q005A@B01@C4@0201<B400V01@C4@0E51806QTG00l>300;2PP00`8000l>
300E51803`d>01XH6@0c<C806QPI014?400@3Pl0518C01/I6P010000GUaM04=1@P0;2PP02``803Ph
=P0o?cd05aLE010@400;2`/02PX:01@D5P0=3@l04A4C00/:3`061PP0518D00L51P0F51D05aDF00P6
1`0D4Q<600h<3@0400l=3P0=2``03@/<00l=3P8040h?00d04@l@02d[;00J61T04Q0A010>3`0:2@T0
20P800H61P18B4P02@T900`<300>3Ph030`<00@02`/;00<03P`<00l;300=2@X00P0<20T01@0=2@X0
3PX;00l;300?2``03PX;00803@T:00@03`/:00l;200>2PL03@T70P0=2@P00`0=2@T03@T:00h:2`03
00l;300C00`8200I5A@04@d<00d9200>2PT04Ph=010<2`0?2`X02`L600T5100:1PD03@T801D?3`04
00003`T901dG5`070@405@l?00`61P0400/51@0=00`61P0=1`L03PP800/51@090`<03@L700h8200?
2@T03PP800D000070@401P00010:2P0601052@0600d21P0>0`L050T=01H;3`0@1@T03P@50P0=0`80
2P0;0@0030@200l71P0@1`X05Q0B00X52P0E41H03PT?00X62`0910XDooooo`006oooool00`0B6aP0
214>00PA3P0200`B400300hD4P0<40l03Q4@00803a4@0P0@4Q402@0B5QD02Ph=02<W9P000P4020`;
014E500I7A`07R8Q01/O7P0200X>3@0900T=300?4A004aDD010B4@0?4A006A/J00h@3`0620L061XI
0080418A01`04Q@C01dO7P0?4180414C018C5@0:2`d02@X<00/<3P14ADL04A8D00d>400A4Q@04a@F
00T:300H6QT08R@S01DG5P072@P01PP700D71P0C5A@03a4@01HH5`0O8B0030h=00h@3P0@4Pl03Q0=
0P0@4Pl02@0>40d0418?00d?300A4a004Q@A014C40041P<03a4=00h?2P02014B3@<03a0;00@03Pl:
00l@2`0?40/03a0;0P0>3`X02@0@4@`04A8=014B3@0B4`h03Pl:00`=200=3PT02``700d>2@0200l@
2`0300d?2`0>40d03a4>008030h;00L03@l<00`>2`0:30T03a4>028T8@051`@02`d:00<03Pl:0180
3a0;010A300C50l0414<00/<1`0H6A@07AhI018C3P0>3`X02P/600d>2@0>3`X02@X500X;1P0D5A00
4a@?018C3P0A4Pd200l@2`0>00l@300?3`l04Q8D00/;2`0<30`051@C00X:200820H02@X6018C3P0?
40/05QLB01DF400?40X200l@200T00h?2@0>40T030l800D70P0F6QD020d90;Fj]P0M8al08BLS05UO
F`0T:BD03A8>01@I5@0A51001`T401HI4P0:30H04Q<=01HG3`0=3PH04Q<=00X<1`0=3``08B<P020R
7`0C5A8071hK010B3`0?4@h030h;018D4@0?4@h010H300h?2P0=3PT03Pl:0P0@4@`06P0=3PT05AHA
018C3P0>3`X04Q<>00/<1`0@4@`03@l<00/=2P0A4a003Q0=00L91P0;3@X03a4>01dO700<3P/071hK
00d?300;3@X03A4@01XN7@0T:2L00`D4014E500>4Q403A4@0P0<40l0100=4A003Q8A010C4@0@4Pl3
00lA3P0<010B3`0A4a003a4>00d?300:30T01@L400X<2@0D5A<0410@00h>3P0B4Q80410@0P0?3`l0
1`0I6AT02PX:00l?3`16ATH08R8R01<C4`0;2`/00P0=3@d04@0<30`05QHF01<C4`0@41004a<C014A
4@0>3Ph0410@00l@4P0>3a4030d?00h@3`0?4A003Q0=014C3P0@4Pd03a4<00803Q4:00P03a8<01<E
4P0A4a8051HE01DG5P0B51<04aDD014C4P<0418A00/04A<B01<E500;30h01@H8028T8P0O8Ah030l8
01LJ4P0C5Pd04QD<014C3P02010B4@0?014C4`0B50l04Q@>00h@2`0=3`X04A<?01HH5@0>40d03Q0>
010B4@0C5A@05ALF018D4`0A4Q@04Q@D00804aDB00X04QD?014D3@0?4@`04aDA010A4`0@4AD04a@J
00l@5@0C5aP04QHE0P0E6AP08@0C5aH061`K010D4`0A5A@05a/J02L[:P0G6aX0:bl^010D4`0B5QD0
4aLF01XN7@0Z;Rd0IVYY01<G5P072`X06alN02T];01iOG`09RXY01LK6P0B5QD04aLF01LK6P0E6AP0
4ADD018F5@0H71/06alN014E500N8R4041@C01DK6@0201PN700^01LM6`0I7al06b4Q01LM7@0H7B00
5a`O01HK7P0F6al061dP01PR6`0J91`072HN01dX8P0N:RH08BlZ020a:`0Q<Bh0:3/g02i1?@0[@3/0
:T0l02Y3@00^Ad@0>U=A04EMG@1CJ6T0IgYm08>BU`2NZJl0_<;;0=OGh`3Qgn`0i]o`0>;Ik03DcMd0
]kO509^S[P26Ti/0MHR=06=kO@1<JFL0?eeK03QFE00gEU40>5=A03A<C0<0<TY:00@0<4Q802]3@`0X
@400;4A40P0[@d<03P0]ADD0?EIJ02]4B00S?4009cm102<k?@0[@dD0@eQI03]@D@0`A4D093Pg01lc
<P0X?3/0;dE20P0^A440300V?3T0;dE202e3@00eBdP093Xg02i4@@0Z@3d0@5IC02]1?P0cAdH0=4Q7
03=7A@80<4A203`0<dQ30397@P0aAT40<TM003A9@P0cB440;d@m0399@`0eC4L0>Dm=03U>C`0iCU00
=da?03]@D`0kD540<TQ6051WH@0hCdL0<TTo02m5>00`A3X0<4<o0312A00`@DX0<41=03U9EP1GJ700
BE]M03e@C00bAS/0<D<e02/k<00c@cP0=THk03A4>P0b@cT0=4Dk02i2>@12Edl0<dQ103U@BP0lDdd0
<dU603Y>C`0kD4/0>4e403M=@010ED`0B5eF055UI@0`@dL0>4a=03U=BP0dBD00?eE903eBB`0jCdP0
>Di703Y?B00iCTL203M<A@0303U>A`0jCdP0?55:0080?55:00T0?E9=03Y?BP0kD4/0>Di903aAC012
Ee80>e1;03=8@`0lDD`00P14FE@04`0bAd00=DHk03m@AP15ET`0>4To03A5?@0gB400<T<k03M8@P0n
CdT0<D8l02Tj=00Z>S<0:cXc02Th<@0W=S40;chi0311>`0^?cT00P0/?cT0100Z?CL09c`g02Tl>00a
@Sl206ijN00;02hi=P0b?CT08bhX020Z8`0N:2008B/S02Pa:@0W;RH09RdU02<[8`0U;bH00P0W<BT0
1P0M9al07RLR02/d;`0L9B008R/X01hW90809Bh[00H07b@P02L/:00M8Qh06QlK01/P700Q9R8201PM
6@0C01`Q7@0J7a/05Q/G01XO6`0K81`05a/J01LK6`0M8B807B4T01`P8`0R9RT07B4R01PM6P0I7QP0
6QlH01LL5@0I7a/061hL01TM700201/O7P0:01dO700P8Ql06AXF00T:1@0M7QT05AH@02//9P0P81h0
51@B01DE4`805aLE00T08R8P04=3@@0G5aD05ADC01HF500D51805ADC01<B400D4a400P0E51809P0D
4a404a8@00l>300D4a4081lM01/J600G5Q@02`X801XH6@0Q7b00BDM801lM7P0D4Q<05Q@E010>3`0?
3@h07A/L01XH6@0=2``04a8@01TI5P1`L6h0LW9`00/;2@0O7al06QXJ01PH600B4Q@02@T;00l?4@05
10T04a<E014?4@0G5AH02PP900d;300:20T01P@51P0>30d200l=3P0700d;300;2@X03`d>01<A4P08
1PL07Q`M01@B4`0201DC5007010?400?3`l04a<C00L71`0E5AD04Q8B014A4@0300/;2`8030`<00P0
3P`<00l;300>2P/03@T:00`82@0=2@X03PX;00l;30<03PX;00L03@T:00l;2P0?2`P03PX700d91`0=
2@P03PX900803@T800d03PX900l;2`0?2``03PX;00`8200E4A004`l>00`81`0>2PT03`/:00d9200<
20L02`L600802PH501T02`L600/51@0>20P0618B00D0000400002`D500l92@090`<02`D500d71`08
0P8030H600h8200?2@T02P@400`61P0C3@d040X:00P20P0@2PX05Q0@01dG5`0B30`030H600H040D9
00H050T=00X10`0E2Ph040D900h31`0C20`200l51P0:00d3100;0P<03PD70189300600803`X=00D0
10030080:RDY018=4ACooooo000Kooooo`0800D>2`094Pl041TF00lE4`0;4@l04QPF00dA400>4A04
00lA400900dA40072`X06alN00/?3P0>4Q403a<B00X>3@0=40l04ADD00803Q8A01l041@C014C4P0D
5QD05ALF01@F5@0N81l05aTH01<E500?4A003@l>00lA40082PT05ALF010A4`0:2`d05QLI01LH6P0>
3a404Q<E014B500D5AL05aPJ00/<3P0A4Q@04a@F01dO7P0T9RD051HE00lA400F61L04aDD00803Q0?
01<04Q@C01LI600:30/04A<A00d?300;3@X030h;00X<2@0;3@X03a4>00h@3@0;3@X051HC00d?3009
2`P04A<?014B3@0D5A004Q<>00803Pl:1P0?40/01`0>3`X04Q<>018C3P0=3PT03a0;014B3@0?40/0
0P0@4@`03@0?40/03@h900l@2`0?40`03Q0=010B3`0>40d03@l<00lA3P082PL06Q`I01/M6P0b=340
0P0>40d600l@2`08014B3@0B4`h09bPS01HG4P0720<04A8=00l@2`0A4Pd201@E4003014B3@0;30L0
4A8=00804A8=0P0@4@`03@0?40`030`<014A4P0@41003Ph>00l?3P092@L0414=014B3P0<3@P020T3
01LH4P0@4@/00P0@4@T05`0?40P03a0:00h@2P0=40T02`d:00T<200H7AT06b0L01DK5`1OIF40gN?O
04M=B@0=4Ph05AXF00`?2`0Q8ah01`X301PJ50092P@051D=00d>1`0@4@/02P`700803a4>00H03Q0=
00d?300<3P/04aDB00h@3@0;3@X200d?300=00`>2`0A4Pd0414<00`=200?40/02``7018C3P0=3PT0
30d800X;1P0A4Pd030d801<D3`0200d?300B014C400;3@X03@l<01HH5@0c=C<0418?014C400>3`d0
2`d:00h@3@0?4a80:Bd/02DY:00@51<02Ph=00hB4@0<40l03A4@0`0>4Q407P0?4Q00418?00lA3P0>
40d03a4>010B3`0A4a003@l<00lA3P0A4a0030h;01LI5P0N7ah0410@00l?3`0D51@04A4A00l?3`0@
41004A4A00h>3P0@4100<c<c01`L700B4Q802`/;01HF5P0N7Qh030`<00h>3P<04A4A00T03`l?00h>
3P0B4Q8051DF014C4`0>41003Q0?00lA400?4@h00P0?4@d01P0?4@`03a8<00lB300?4P`03@l<00h@
3`80418A00<04A<B010B4@0>40l00P0@4Q4200h@3`0:010B4@0C51H01`P:02/]:`0a<c005aTD01lR
6`0F6A4051L@014C3P803a4@00X0418B014C3P0B5@l04A<>010B3@0A4`l04aDB01/M6P0F61H04Q@C
0P0C5A@0<P0A4a804A<C018D4`0C5A804aD@018E3`0A50h04A<?01HH5P0D5QD04a@H01@E6P0?41D0
4QHG010D4`0E6AP05QXI01<G5P0F6QT05ATH01<G5P0G6aX08BDT04=7AP0O8b8051PG01DI600C5aH0
3Q8A01PL6`0f>ST051PG00lC4P0J7Qd0310?01hR8@0B5QD05QXI01@H5`0G6aX06QhM01DI600A5A@0
61`K01DI600A5A@07b<R01HJ6@0I7A`05Q`J0`0G7A/00`0I7al0728R01LM7@0201/P8`0Y01PM800K
82@07R<V01TR7@0I8a`06bDN01hY8`0Q;BT08BhZ020a;00T=340:3/h02/n>`0Y?SX0:d8o02e6@`0a
BTL0?5AC04MOG`1HKFh0LH:5096MX`2^][h0dmCO0>o[n@3jloh0oOCo0?_`o`3]iOH0d<kL0;2e`@2G
XJX0Nh^B06AiO01BJf`0AV5Q03YHEP0fDU00=Dm>03A<C@0cBd`00P0dC4d05P0bBT/0;TI702]3A00/
A4D0;dM8039:B`0fCU00=DiB03=<D00/ADT0;dM902U1@`0iDE<0=da=0315AP0]@D80;D5002/o?P0/
@3l0<TQ502To?00^A44202Pn>`0=0316@`0bB4D0:d4n03E;B00X?S/0<TQ50316@`0hC4/0=TY90396
A00aAD<0<TI403A9A00202i3?P@0;T<l03@0<dY403E<A`0hCT/0>Dm<03Q>C@0gC4/0=4Y903U?B`0_
ASh0A5]A03Q?@`0/A3L0;40d02a0=P0[?SX0;3i00393B`0iBUD0>daG04IGG`1;GEl0@eIB03I:?`0a
ASP0;3hb03=4>@0hB3h0=dPn03E7?@0dB3h0=d]202e2>P0fBd@0>4m803aCC00aAd<0>4a<03aAC00i
CTD0=4Xm03Q=A00oE4d0?51?03=6BP0hC4d0?51=03U?A00hCT80>e1803Y?B00kD4T0?55:0P0mDT/4
03aABP0O03]@B@0jCdP0>e1;03eBC@10EE00?U=>03eBC@11EU40>Di903M<A`0nDdh0@EIA04MLE`0k
D4T0=4Dj02m0=P0kC480?Tm503Y;@`0dACd0;d0h03=4?P0hBD<0<D8l02`m=`0Z>cD0:S`g02`k=`0_
?c/0=TI203A5?`020351>`0H02`l=P0W>3409SH_02Lg<@0X=c<08Rh[03<o?00^>SH0<C`h01XU7`0U
;bT08b`V02D_9`0Y<BX09B`U02H]9@0/=2`0=3he02Pb:P0Q:b<08R`T03Dn>@1lQH00=Chi0P0Q:RL0
1`0K924072DR01hS7`0Z;b/07b@P01`Q7@0O92000P0M8Qh03`0I7QX06b0L01hS7`0J7a/05a`I01PL
700G6ad06alR02@X;00V:Bd07b8W01`O9@0K7b<0720Q01`P7P0201/P6`0C028X9@0L8R005QXI01PL
6`0J7Qd061XG01DG500G61@07QlJ01DF4@0D5A007AhH03/k>@0M7A/05QHD01LG5@0E5A<08R8P034a
;`0201HF500501@D4P0E5A<051@B018A3`0D4a400P0F5A<05@0D4a404Q4?01LF500?3P`04a8@018A
3`0G5Q@03Pd;01HD5@0G5AH05A<D018@4@0A3a0040h?00h<3@0@3Pl061HG018@4@0?3@h03`h<00d=
2P0201<C4@0>02d]:`1=CDd04a<C04U9B@0@41804A4C00h>400=31403Ph@014?4@0?3@h03P`=01LE
5P0;2@X900h<3@0@010>3`0C4A804Q0A014?400@3Pl03@/<00T7200>30d04@l@00`;30051@D03@d=
00l?3`0>3Ph01PH600d=3@D030`<00H03P`=00l;300?2``03`/<00h:2`0=2@X600h:2`0600l;2`0?
2`T03PX800d9200>2PT03`/:0P0>2PT0300?2`X03`/;00l;2`0>2PX040`<00@1000B3Pd02`L600l;
2P0=2@P02`L600`81`803@T801X030P700/71P0A2`/01`8200`61P090`<05Q0@00d8200B30`02P@4
01<=3@0I4a<03@L700h8200<1PH03@L700h8200C3@d0618B00l92@0D3Ph03`T900H10@0B30`040X:
00/51@H040D901805``@00l5200?10P02`0401872`0>10L04PL;01462P0C20/040L;00d41`0A20/0
3PP:00T51P0<20T0920R03Hb<`0K5aLDooooo`006oooool0200C71T03QLD00@=2P093`d03Q@B00H<
2P0>4Q403a8A0`0?4A000`0>40l04aLF00P<2`0200H:2@0800P<2`0>4Q406alN00P<2`0420L0310?
00hB4@0C5aH200h@3`0@00lA400:30/03a4@00T;2P0620L07R0O01LI600<3Pd0;2h]05eOGP0H6A/0
=CHh014B500720X04Q<E00D620804Q<E00/051DG00/<3P0<3@l01@L6014C4P0C5A@03Q0?01TK6P0W
:BP09RPW00lA4002010B4@0A00lA400:30/04Q@B00lA3P0H6QL08B<P01@F4`0<3P/03a4>00`>2`0:
30T03Q0=00L91P0D5Q<02P`800h?2P0?40/00P0@4@`2018C3P0;010A300?40/03a0;00l@2`0@4@`0
30d800P9100;30L04A8=00d>2@0<3@P00P0>3`X01`0?40/03Pl:00`=200<3@P03@l;00h@3@0?4@h0
0P0>40d2010B3`0500L91P0j?3T0LgEb01<E4P0<3P/00`0@4@`04@0?40/03Pl:00`=200D5A002``7
014B3@0D5A0030d8010A30092PD06a`G02TZ9@0D5A001`P3010A300>3`X03a0;0080414<00l03a0;
00h?2P0D51@030`<00l?3`0B4Q803@d;01@D4P0A4Pd03Pl:00d>2@0;30H04a@>0083000A4PX00P0@
4@T05`0?40X03a4:00hA2P0A4`h04QDA0002000]<Rh03Q@@01LM6@0Q9b<03A<?00dB3P0B5a<03Q8=
00d?2P0A50d02`d601LH4P15ASh06AXB010A2`0@4Pd03@l<00803a4>00d03Q0=018D4@0<3P/010H3
01HH5@0G6AH02@/800d?300B4`h03Pl:00`=200J6aH02``700804a@?01T04A8=00h?2P0B4`h030d8
014B3@0<3P/05aTF01dO700?4@h02@/8018D4@0O8Ah01@L400d?30072@H05QPE01TK600A5A@00@D4
00T=300?4a801PX900/?3P0<40l03A4@00<03Q8A00<03Q4?00lA3P0>40d00P0>40d08P0?4@h0418?
010B3`0@4Pl02P`900<50P092`P051DD010@400?3`l051@D014A4@0?3`l04A4A00T92@0E5AD04A4A
010@40092@T04Q8B00P8200?3`l05aLG00`<300@410051@D018B4P0>3Ph030`<00h>3P0C4a<051HE
014C4P0?4A02010B4@0300lA3P0=3``03Q0=00<0418=01L03a8<00d?300@4Q40418A00lA400A4a80
418A00`>3@0?4A004Q@C00h@3`0;3@`03Q0?010B4@0H6QT04Q@B00@60`0F61<04aH@01@G400C5Pl0
4Q@@010B3`0200lA400c00lA300C5@l051HA018D3`0@4Ph0418?01`N6`0F61H04A<B018D4`0F61L0
61XI014C4P0B51804aDB01<E400B50l04A<>01DG500H6QP051DG01@E6@0E5QX0414E01<G600>4Q40
4QHE01DI600D61L05ATH01LK6P0@51<03Q8A04E9B03=dM00>Cdl01@H5`0M8B00?T9101`P7`0N8R40
4ADD00hB4@0H71/03a<B02@X9`0C5aH08RHU01<G5P0G6aX061`K00<05a/J00L061`K01`P7`0G6aX0
=CTh00`@3`0L81l051XH00805adK02005Q`J01PN7P0J82005adM01XO8P0K82<0724T01lT:00P9BP0
6R<O01XS7P0K91l07RTS020/:00N;2P07bl/02De<P0U>3D093Le02Lk>@0]AD80;dU6039<B@0kE580
B5eN05Y^K`1iR8`0WjR_0;g1bP3Sgn/0o_?o0?oio`80ooSo00/0ooCo0>KRl@36b=D0ZK2j08NFWP1[
OX@0EV]^04MOH@0oFEX0?UQI03eFE`0203Q@DP0503UAD`0hD580=4a>03=;C@0aBD/00P0]ADL0G00^
ATP0;dM902i7B`0X@DD0;DI:03YBE00dC4h0X[Zl04mTI@10EEH0;d=402/o?P0Y?C`09c/j02e3@00Y
?c`0A5YG03eCD00Y?c`0;D=003=9AP0[@Ch0<4I302i4@@0cBDH0<TQ503I:B@0cAdH0<DE30396A00c
AdD0<dQ302m4?`0`AD00<4Dn02e2>`0_A3d0<dQ10399@`0bBD@0<TQ503=9AP0eBdP0=Te703U@BP0`
Ach07CDX02Hn<00U?Bd09C`/02Hl;`0[?cD0;D0l02do@@0fAdd0?e1J03e>F00oD5P0BUaN045DD00j
CT@0<THj0394>00fAc`0>DY003Y;@@0hC480=TY102Xo=P0X?CD0;D8k02e4?00jDDT0=Te703=7AP0k
D4/0>e1703M=@@0iCd<0?55:03M;B@0lD540<TI703E:A`0nE4P0>Dm303U>AP0iCTL0>4e603I;A00g
C4D0>Di70`0hCDH02P0gC4D0=4U203A9@P0jCdX0?U=>04=HD`0oE4l0>Tm:03aAC011EU4203mDC`0H
03M<A`0oE4l0>Tm80393>00iBT00=dPn03U:@014EDd0@5590311>@0_@3X0;3dg02Pi<`0U=S009SPc
02`o>`0_@Sh0=4E203Q8A@0eAT00<T8l02ln>@0X=c00938[0P0T<BX0<P0W<bh0:SHb03M3?`0g@cl0
;cXf01dX8P0R;2H08R/V020Z8P0U;BH09RdV02T`:00Z<RX0<3Xa03@n=P0^>30072HN01`U800X<B`0
6B8M020Y9P0L9B808b`Y028[:00J7a/08BHR01XO6`0M8Qh07R<O01`Q7@0Q9R806AhJ01PM6@0O9200
7R<O01PL6P0L82<07R4V01lR:00R9B`092L^01dP:00P8b`07b8Y01hQ9@0K7b006QhM01TM6`0V;2X0
7R@R0P0E6AP0300H71/061XG00`>2`0I6QH0Si2;03<d;`0H6A@01PL101lO7@0C4a405aLE01/K6@80
5QHD00P03@d;01HF500G5aD03`l=01PH5P0@40h04a8@01@C4@805A@B02H051<A01<B40081`D0;B`Z
04E4@P0_;R`06APF00d<2P0?3@h0;2X[00T7200L6Q/0518C01/I6P0D4Q<03`d>01TG600:20T01@<4
01@C4@0@4@`04Q8@00/;2@0=3@/03@d=00X:2P0d=3@01PH801@D5P0@41805aHK00<31@0F51H0=S@e
00l=3P071@H02`T:00P61`H03P`=01<03@/<00`:2`0A3a006ALH01<A4P0;2@X03`d>00H41@0?3@h0
40h?00X82@0<2`/05ADE00L71`0@41001`L701HF5P0?3`l03Ph>00803@d=0P0<30`01@0>2``03`/<
010<3@0@30d03PX;00<03@T:0`0>2P/00`0?2``03`/;00h:2@0200d9200>00h:2@0?2`X03`/:00h:
2@0?2`X03`/900h:1`0=2@P02@D401PD4`0?2`X02@D400/71P0?2`X200d920@03`/:01P0208200T3
0`0F4100100001hH600>20P030H600X4100D3Ph0618B00l92@0;1@D04@/;00T30`0:10@040X:00d7
1`0>20P01P0000d71`0O6AT0>cDe02lY:@0>20P601052@0B00`11@0F2`l03@8601462P0?1PP05``@
01052`0900@040D;01893P0=10T040L:00h82P0?2PT05Q8A020L6`091@D03@T65?ooool001_ooooo
00P02Q<@00D>2`053P/03Q@B018H5P0@5Q@03Q8A00lB4@803a4@0P0>40l0:`0;40`04AHB018G4`0C
61@02a0<014F4P011P803Q<?01LL600<4@d041DA02H[9`0<3P/03@l<010B3`0<3P/04Q@A00lA3P0G
6AH02P`900P:1`0B5140418?01XL6@0Y:bX0FUaK01/M700:30/08R@S00d?3P0@4Q402`d<00h@3`0?
4A005QPG00h@3`0>40h03Q0=00d?300?4@h04aDB01DG500C5A800P0A4a003`0B514030h;00lA3P0>
40d07b4N02h`;@0I6aP02`d:00h@3@0=3``03Q0=00`>2`082PL08bDR00P91@0300d>2@0400h?2P0B
4`h04a@?010A30<03a0;00X0414<01`M600B4`h020T4014B3@0=3PT02``7010A300>3`X03@h90`0<
3@P01P0=3`/03a4>00lA3P0=3``03Q0=018D4@805ALD00@03@l<038d<@0G6AH03a4>0P0?40/2014B
3@0@010A300?40/03a0;00X;1P061`804Q<>00T:1@0=3PT02@X501LH4`0P8A`03a0;00H70P0?40/0
30d800d>2@803a0;00h03Pl:00d>2@0C4a<03@d=00`<2P0@40h03`l=018C3P0A4Pd03@h9018C3@0?
40X04a@>00P90`804A8:01d04149010A2`0?4@X03Q4:00<5000930T092TU0002000=4`l00PP400hD
400F6aL0314=00@91@0:3PT03@l:01LJ4`082P<05QLA05IGC`0M7QH010D000l@2`0<3@P02@X500/<
1`0@4@`04Q<>034b;@02010A300900l@2`0>3`X061TD010A30082@@03a0;02d^:@0A4Pd03a0;0080
30d801D02``7018C3P0>3`X051D@00lA3P0F61D07AlL018D4@0:30T04A<@00lA3P0@4Pl05ALD018D
4@0@4Pl00@<001<E4P0@4Pl05QPE010B3`072@H00P0>40d00`0?4@h04A<@010B3`0200lA3P803Q0=
00X03@l<00h@3@0>40d04Q@A01XL6@0K7AX04A<@00h@3@0@4Pl0414?0P0;2`T201<C4@0=01@D4P0I
6AL03`l=00d=2`0D51807alM00X:200@40h01`L500X:200>3P`030`:010@3P02014A3`803Ph<00<0
410>018B400@4Pl00P0?4@h2014C400I00h@3@0<3P/03@l<010B3`0A4`h0418=00lA300>40d04Q@A
014C400?4@h04Q@A00lA3P0=3``04A<@01DG500?4@h03@l<010B3`0A4a0020X700d?30092`P02`d8
01@F4@02018D3`0B018D4@0A4a00418?00lA3P0A4`h04aD?018D3`0@4Pd0418>014C400F61D04Q@B
014C4P0D5QD05aTH01PJ6@0A4a004Q@A0P0C5A806P0B51404A<@01@F5@0F5aP04Q<E018C5`0F5a/0
4a@H01PL7@0A5A@04QHE01DI600D61L05ATH01TM700A5A@02@d<02/_;P22QXD05a/J014E500Z;Rd0
K71_00lC4P0D61L03A4@0P0D61L01@0=4A004ADD01HJ6@0;3`h05QXI00805ATH00d05QXI01LK6P0H
71/04aLF01PL6`0I7A`08RHU00lC4P0I7A`05A/I01PN700J81h06AlM00806AlO00L05Q`L01DJ7@0G
71l06QlR01XO8`0J7b807BHR00806b@O01D07BPT020/:P0P;R/07bl/028b<@0S=S@09cXh02Pl>P0]
AD80;T]703A>B`0kE5<0BUmP05ibL`1oS900XjZb0<;5cP3Wh^l0ooCo0?oho`3omol00P3on?l02P3`
j_T0c]3M0;2f`P2>Vj<0L8>905aaMP1=IFT0A5aP049JGP0nEUP303UAD`0M03M?D@0cBdd0<4Q:02m7
B@0^ATP0<4Q:02m7B@0Z@T@0;4E903=<D00bBdl0=4a>01/c=@17Gf40=T]<02i3A00Z?Sl0;T910355
A00iCD`0;d=103I;AP1?I5l0?55<02]0>`0^@ch0<TM202]0>`0bAd800P0jCdX0@`0`A440<dM60355
A00`A480<dM503A8AP0bAd80;d@o0397@P0cB440;d@m02e2>`0_A3d0;d@o0315@00aAT40<TM203=8
@`0cB440=4U002i4>00Y?c80;D@d02Dl:P0Q>2H08SP[02e3>00dBD@0=DU803Q;D@0nDEP0@5=J03mB
E`14F5L0>Di903aAA`0dBSh0=TXo03M;@00hC440>De403U>A@0gC4<0>e1703M<@`0lDDP0=T]202a1
>00jCdP0=TY903U>A`0hCT80=de003Q>@P0jCdH0>4a;03Y>C`0eBDP0<dQ303Q>@P0iCd<0>4e503Y?
B00iCTL0=da503U>A`0lDDX00P0hCDH0700gC4D0=T]403A9@P0cB440>Di903aAC010EE00?55<03M<
A`0jCdX0AU]F041ED00oE4l0=da703aAC00cB4409SP]03E6?00hBCl0?4e304MHD010DDT0;d0h02m0
>P0/?CL0:S/e02Pi<`0/?ST203=7A@0702i1?P0/?c/0;Chh02hn>00_>cL0:CH_02Lc:`0202Td;00E
02@`:00]>S<09C8[02Te;P0Y=2h0<chh03@n>00X<B`08b`W02L_:@0W;RL09RdV02Xb:P0a>c80@4Y2
03]5?@0S;BD08R/V01<L5`0M9R408R/X00806R<P00P051dJ01lS8P0P92<061`K01`P7`0G6aX05QXI
01hR8@8061`K01h06alN01TM700I7Ad07b@X024V;00M8RP06QhW01lS;00P92h09RXe020T;@0I7R<0
61dP01XP800K8Al082HT01/Q7`0F6QT05ATH01HJ6@0G6AH092HS018C3`15AT400P<0014B300O81X0
4Q8@014A3`0E5A<201TI5`0901DE4`0F5Q@07AdK01`L6P0A4@l05QHD010@3P0E518051<A00804a8@
00D051<A01DD4P0B4@l07ahL028Q7`0200h=2`0O01LF50061@<06QTG00X91`0B4@l02`X8010?3@09
20H03Pd<00`;2@0H5aD0:2LU00L6100F5A4040l=01TH5P0H5aD0518C010>3`0C4A803P`?00T72P0?
3A005aDJ010>4@0T8R@0GE]L01TG600;2@X07Q`M00l=3P0800h<3@0@010>3`0C4A803P`=00X82@0A
3a001083014?400?3@h02`T:00X82@0@3Pl02PP900/92P0:20T040h?00/92P8040h?00D03P`=00`:
2`0;2@X03@X;00l;3002010<3@0300l;300=2@X03@T:00803@T:00@03PX;00l;300?2``03`/;0`0=
2@P00`0>2PT03`/800l;200200l;200900l<200>2`H03@T600/71@1bKVd08alN00d920060P4030P7
00<03PX90P0?2`X02@0@30/04P`<00/51@080`<07aTI07I`L00/9RH02`D500`61P02010:2P0>00l9
2@0<1PH04P`<00L10@0D3Ph07ALG00`61P0=1`L03PP800`61P090`<05a4A01D?3`0A2`/601052@0B
00d21P0C20`02@0201@93@0?10P0DTM=01dB6P0<0PT03`@<0188400>1@X04@P;00@0000D3`l02@D2
00<000091@<03@X55?ooool001_ooooo0P0<5A801P0B6aP04QPF00X@3P093`d03a<B010C4P80418A
0P0?4A00200>4`l08RLS00X?2`0:3`/03a@@01PM6@0:3`/02a0<0P0=4Ph0100C61@082DQ01@F4`0>
40d200lA3P0<014C400@4Pl02`d:010B3`0?4@h04Q@A00/=2P0<3P/04A<B018D4`0?4A00418A0P0=
3`h01`0@4Q404Q@C014C4P0;3@`03@l>00X<2`0?4@h00P0@4Pl00`0?4@h030h;018D4@0200d?3003
00h@3@0@4Pl02P`900803a4>00d04A<@01@F4`0=3``030h;010B3`0<3P/0418?018D4@0H6QL0;2h[
01<D400?40/03@h900<03Pl:00X03a0;010A300?40/03a0;010A300A4Pd07b0K01TJ5@0=3PT03a0;
0P0<3@P08`0B4`h03Pl:00l@2`0E5Q404A8=00`=200@4@d04A<@00lA3P0D5Q<0:R`Y01<E4P0X:RL0
2`d:01PJ5`0m?c`05QPE00lA3P0@4@`03Pl:00l@2`0B4`h04A8=010A300A4Pd05AHA00h?2P0C50l0
3@h900l@300>3`X03@h900l@2`0>3`X03a0;008030d800<03@h900h?2P0>3`X00P0>3`X01`11@Cl0
9BDT00X:200?40`03a0;00d>2@0?40/00P0>3`T0700:2`@0414:014B2`0@4@T03a08010A2@0A4P`0
418<00hA2P0<3PT04QHA00@81@0?51002a0<00dC3`0B61@03Q@@01@I5@0?51002`l:00lA300=40T0
5QPA00X;1`0I6Q8030d501<D300@4@/200l@2P80414<01D03@h9018C3P0=3PP03a0;010A300=3PT0
3Pl:00d>2@0:2`H03a0;02LX8`0D5A002``700l@2`0A4Pd0414<018C3P0=3PT0414<00h@3@092`P0
0P0@4Pl200h@3@09010B3`0>40d03Q0=00`>2`0A4a00418?014C400@4Pl03Q0=00804aDB00@03a4>
00h@3@0?4@h0418?0P0?4@h400h@3@803a4>00L03@l<00`>2`0@4Pl03Q0=010B3`092`P04a@A0080
4A4?00@04a<A014A3`0?3`d03Ph<0P0D51801@0A4@l051@B00X:200D5180410>00804Q8@00H04a<A
018B400?3`d04Q8@01<C4@0B4Q0200l?3@0>00d?2`0>40`0418>014C400@4Pl03@l<01@F4`092`P0
4Q@A00lA3@0B51003a4=014C400B5142014C400801<E4P0<3P/03a4>018D4@0E5a@04Q@A010B3`0C
5A8200lA3@0401DG500>40d02P`900lA3@80418>01@04A<@018D4@0A4a00418=01<F3`0@4`d03@l:
01PJ5@0Q8al04aDB01`N6`0E5aD05ALF00h@3`0D5QD04Q@C018D4@0B51005QPD014C40804A<A01L0
30h>01<E5P0>3a404a@G01LH6`0E5QP05a/J01DI600A5A@04QHE01DI600C5aH041@C018F5@0F6QT0
4ADD01HJ6@0C5aH04ADD024U901RIVD061`K01TM700201<G5P0N01LK6P0T:2L041@C02HZ:@0O8b80
6QhM01LK6P0C5aH05QXI01LK6P0J7Qd05QXI01DI600G6aX04ADD01TM700J7Qd05A/I01dS8@0L8R00
;C<a01TO7`0N92@061hN01PM800K82<07R<V01<H700N8bH072DR0P0M9R80:@0N:BH07b/Y020];00N
;R`08C4`024c<P0[?C`09c/j02i6@`0]BTH0<D]803eFE@1@IFH0H7Ae07n<T02PYjl0`L7;0>SQkP3o
lol0ooSo0?ofo`3omol0ooSo0?C]n`3Ee>80/kW508fJX`1^PHP0H7=j05EZL015GF80?UEL03UAE@0h
D5<0>E5D03I>D@0eCE00<d]>039:C@0aBD`0=4a?0080>U9E00/0<DU<02i7B`0fCe<0:4550318BP0c
Bdd0;TI802]0@@0/@D80<DE60355A00202i2@@0903E9A`0gC4L0>e1;02m4?`0]@Sd0<DI103I;AP0a
AT40;T<n0080;D8m00H0<4E002m3@P0/@3l0=4Q60355@`0cAdD203E:A@0h0315@00`ACh0;d@m02Tn
=`0/@CX0:d0k03eBC00hCDL0<TM103A9@@0]@SP0=Ta002Y0<`0X?bl0:T4a02i5=00bBCP0:3hb02m4
?00lDDd0?51?03iAEP10DeT0A5MM041CF011EE@0>De:03U>AP0gCD80=4Xo03I;@@0gCT<0>4i503Y@
A`0lDTP0<dPo07^@Q`19GUD0<4Hk03Y@A@0hCDD0>De<03Q=AP0fC400=4/l03A:?@0eBT00=4Q603M;
C00lD4l0=TY60357>P0fC400=DY203U>A`0kD4T303aABP0?03M<A@0iCTL0>e1903Y?B00gC4D0=DY3
03U>B@0hCDP0>Di903Y?BP0mDTd0?eA?041ED00gC4L0>Tm:0080>4e800X0=DY30352=`0hBCl0?4e3
04aMD`1=GUH0<T<k02dn=P0W>380<44k0P0dACl08P0^@3/0<TE20314@@0Y>cL093Ha02Xj=@0_?3P0
:3@`02D`:`0X<bd0:C</02Ta:`0X<b`0:cP`01dZ8P0T<2T072LQ02<^:00[=C00;3D`02Xc;P0[<Rd0
:S0[02D[9P0S:b<08B/R02Pb:P0T;RH07BLO02@]:00Q:RD07RLR01PQ7P0V;b`201`U8P1302<W9P0N
8R407B4P02@X9`0N8R40720O018F5@0U:BP051PG020T8`0D61L07b<S01PM8@0H7R@05Q`T01/P:`0W
;CL0=S]602hd?P0U:c<06AhU01LM8@0H7R4051`J02<Y9`1;DDl092PW01LK6P0F6QT06A/H01DG500H
6QH04Q<>014B3@0F5a804Q<=01XJ600F5Q@051@B01LG5@0H61H05aLE01HF500D51805ADC018B400F
5Q@061PF01<B400F5A<04a8@014@3P0D4a405QDC01<B400B4@l06APF01HE4`0C4Q0040l=01/J600@
3`d06QTG02@S8@0O7Q`04A0>01TH5P0301<B400:00X9200F5A<05QDA01dL6P0F5A<030/901LE5P0<
2P/03@/<01hL7`803`d@00P03P`A018@4`0;2@/05A<D00d;300D4Q<040h?00`:2`804@l@01P03P`=
00l=3P0@3Pl03@/<018@4@0?3@h03@/<00/92P081PL040h?01`J6`0?3@h04@l@00d;300:20T03P`=
00`:2`0>30d03@/<00h<3@0;2@X03P`=010>3`0A3a0300d;300700d:2`0>2P/04Ph?014=3P0>2P/0
2@D600l;300200d92P<040`=00D03`/;00h:2P0>2PT03@T800l;2P02018>2`0Y00T6100B3`X04Pl9
010=1`0C40X04Pl<07YfM@0[9bH0510?00`81`0=2@P0510?00d9200<2@P030P7014=300=2@P030H6
00T30`0=20P040X:038/;00@2PX02P@400d71`0?2@T03PP8014;2`0D3Ph04P`<00`61P0I4a<071HF
01<=3@0;1@D03`T900h8200<1PH05@l?00`61P0;1@D01P0@1@T04P0B1`/03P<700X10`0@1@T050T=
05=8CP0P5Ad04PL@00l4300@1Ph03`H<0189300G4A<02`H5010<2@0=2@H02`L400`91ACooooo000K
ooooo`03010I5P0=5Q<02a@A00<0318@00@03a<B010C4P0@4Q40418A0P0?4A00400:3`/05Q/G00P=
2@083@T0314=00/@300A5Q803Q<?00dB3P0?51003Q<?00dB3P0O8Ah04Q@A014C400?4@h200X<2@06
018D4@0C5A804A<@01<E4P0E5a@04Q@A0P0?4A0200h@3`803@l>00d030h=00lA400?4A003a4@01<E
500G6AH04A<@00h@3@0;3@X0418?00T;200>40d0418?00804aDB00P0418?00h@3@0>40d03a4>010B
3`0A4a00418?00lA3P804A<@0`0@4Pl02@0?4@h03Q0<014B3@0C50l05aPC01DF4@0A4Pd03Pl:00l@
2`0200h?2P0D00l@2`0@4@`0414<014B3@0B4`h03a0;00`=200>3`X0:R/V018C3P041@00?3dh034b
;@0C50l030d900h@3@0@4Pl01PP502@V8`0>40d300lA3P803Q0=00D03@l<010A300<3@P03@h9010A
300200d>2@0<00T:1@0:2`H04a@?00d>2@0?40/02@X601<D3`0?40/01@H201hO6P0;30L04Q<>0P0?
40/2010A30804A8=00X0BDU702PX9P0=3@/04Q<>00h?2P0?40/02``600l@2P0;30H02P/30`0>3`L2
00d>1P0M00h?2@0<3PL020/4018D3`0;3PX0008000dB3P0A5Q809B/W00lE4@0<4Ph08bPT01/P700=
4@`03Q0;00`?200?4@X03a0:00h?1`0?40P04149018C3@0>3`T04A8<018C3@0>3`T0414;01<D3P0A
4P`0100@4@/02P0B4`h04a@?00h?2P0>3`X03@h900P9100D5A003@h900X;1P0;30L200d>2@803Q0=
00H03a4>00`>2`0<3P/04Q@A014C400@4Pl200lA3P803Q0=00<04A<@00lA3P0C5A800P0=3``00`0F
61D03Q0=00h@3@0600h@3@803a4>0P0@4Pl01P0A4a004Q@A01DG500Y:bP04Q@A010A3`804Q8@00X0
4a<A014A3`0?3`d03Ph<010@3P0B4Q00410>00`<2P0=3@/0410>0P0C4a40900?3`d0410>00l?3@0>
3P`04A4?01<C4@0D51804a<A01DE4P0C5A004A<>00`>2@0;3@X03@l<018D4@072@H04A<@024S8009
2`P02P`901TK600=3``02`d:00d?300D5Q<05QPE014C400@4Pl04A<@018D4@0A4a00418?01<E4@0@
4Pd04A<>014C4080418?00D04A<@010B4@0?4@h0418?014C4002018D3`0J00/>1`0H6aD04Q@?00h@
2`0D5Q80418?01LI5P0?40h03a4@02T[:P0f>3L0418?01`N6@0B50l01`T400T;200N81h06adL020Q
8`0H6A/04a@F00l@4P0;30h09RLY00lC4P0D61L2014E500301<G5P0>4Q405QXI00805a/J01H05QXI
01<G5P0A5A@03a<B01<G5P0W:bX04ADD01dQ800H71/05a/J020T8`0U:BP05a/J01PL6`0I7A`0:Bd/
02@X9`0H71/05a/J014E500D61L061`K0`0F6QT201LK6P0S00dC4@0B61H0728P059HEP0P9RH051XJ
01lU9@1/LG@09BX]01LL7`0J7b<07R<V01PQ7`0K92407BHS01dW9P0L:2H08c0_02@d<`0/?3/0;3hm
03E7A`0mDE00Df]X02]8A00nF5D0GgQf065fM`1VNW/0MX>709^RZP2h^l@0h=_X0?[]oP3omOl00P3o
n?l05P3onOl0lnck0=?EhP2c^LD0S9RR06n2R@1PM7/0DVU`04MNIP13FV80?eIM03]CE`0lE5P0?EEI
045IG@10F5`0>U9F0318C00]ADT0<DU=039:CP0^ATX202i7B`0402m8C00^ATP0;4A602U1@`80:Sm0
01P0;D520355A00bATD0<TI403E:A@0bAd80;T<n02a1?00^@ch0<4E00397@P0aAT40;T<n02]0>`0Z
?cX0:d0k02e1?`0]@D00=TY80355@`0cAdD0>Tm:045FD@0dBD@202m4?@0L02Tn=`0^@c`0:d0k03mD
C@0lDDP0<DHm02i4>00/@SH0<DLj0398>`0eBch0=4Xm03iDA`0bB3`0<4Dl0315?`0oDe40?U9A045E
E`10DeL0>TeC03]?D@0nDU40>De;03M<AP11F4h0?eI<03aCB@80>4m501h0?EA:049IC`0iCTD0K85h
03iCBP0bB3`0>4i202e2>@0fBTP0>Di703Q>@P0gCSl0>e5403iDB00hCDT0>4a;03U=C00cAd<0<4Hi
03A:?@0gC4@0>Di703]@B@0jCdP0=T]403=8@@0gC4D0>4e603U>A`0jCdP203U>A`0403]@B`0eBTD0
<dQ303Y?BP80?U=>01/0>e1;03U>B@0mDTd0?55<03I;AP0eBT<0>de2041AA`0iBT00@eA:04MHD00X
>C408S<[02`m=`0`@C/072dW03U:A00nCdT0=DQ203E6@00_@3X08c@^02@c;P0X=S408bl[02D`;00Y
<c000P0W<2d0>00X<R`09C8Y02@a:00P;2D07bXT024/9P0S;BL09c0[02Tb;@0X;b/0:Bl[02L]:@0S
:bD08bdT02@^9P0U;bL08bdU020Y900L9B0041TD02H_;00K92404a`I020Y9P0F6QT05a/J01XN7@0L
81l07B4P01`P7`0M8B007b<R01`P7`0S9bH0720O01TN7P0O92P072<Y01XQ:@0K8R`082La02L]>@0Q
:3807RD]01TQ9P0H82<0620R01LP7`0>5180>3hl014E500I7A`020`;01/M6P0P8Ql061XF0P0G61<0
3P0F5a4061TC01DE4`0?3`d04A4?01<C4@0G5aD08R8P01DE4`0D51804Q8@01<C4@0E5A<05QHD0P0G
5Q@04`0E51804Q4?014@3P0D4a4040l=01@C4@0K6QP05aHD00l>300C4Q005aHD00h=2`0E51807QdK
01LF500;2PP04a8@018A3`0A40h00P0B4@l0200C4Q006APD024P7P0L6aT05A@B018@4@0@3Pl04a4B
0P0F51L04@0D4QD04Q0E01<A500S8B<04@l@00l=3P0=2``02`T:010>3`0A3a0040h?00/92P0=2``0
40h?00d;300;2@X02PP9008040h?00@03`d>00H41@0>30d03P`=0P0=2``00`0<2P/03@/<00d;3004
00d;300=00/92P0?3@h04@l@00`:2`0=2``03P`=00X7200B3Pl030P900L4100?2``040`=00/72002
00d92P0500h:2`0?2``040`=010<3@0?2``00P0@30/02@0>2PT02`L400h;1P0/:B804a0900T60@0@
3@@01040010=2@0200l;2P0Q014=300?2`X02PH5085mO01NFUT06ADD00<0000D40l03@T800d71`0>
20P05@l?00T30`0400005Q4A01LA4@0D3Ph03`T900h8200?2@T04@/;00`61P0D3Ph01`8200X4100B
30`03PP800X4100D3Ph01`4100@0000:10@040X:00L040D901403`@800d21P0>0`L040D90146300?
10`03P<;00d22P0=0`/03`H;01482`080P@02`H501<?300A3@X03@T601/H4`0Dooooo`006oooool0
2@043@X0214>00TB3`093`d02a4?00lE4`0?4a803a8A010B4@0300lA400900lD40062`D041D?00dB
300;40X03Q<=01HK5@0=4P`02@h800803A8<00D02Pl901HH4`0>40/0418=014C3P0200h@2`08010B
3@0A4`h03a4<014C3P0C5A00418=010B3`0>40d200d?300D00h@3@0?4@h04aDB018D4@0>40d01`T6
00H81@082PL04Q@@00lA300<3PT03a4<00P:1@0=3`X04A<>01@F4@0C5A003a4<00d?2P0>40`200lA
3P<0418?00<04A<@00lA3P0=3``00P0>40d01P0<3P/02``800l@2`0D5A005QLB018C3P803a0;01X0
414<00l@2`0>3`X03Pl:00l@2`0A4Pd04Q<>014B3@0>3`X03@h9010A300A4Pd04Q<>01hO6P0Q8Qd0
2P/600P9100C5A405ALD01<E4P010`003a4>00h@3@0@4Pl03a4>00h@3@803@l<00<03Q0=00d>2@0<
3@P00P0>3`X0200:2`H03@h9014B3@0=3PT04Q<>000100092PD03a0;0P0>3`X0100=3PT04A8=00`=
200A4Pd200l@2`80414<0P0A4Pd08P0L7AP051D@010A300A4Pd03Pl:00l@2P0<3@L0414:00`=1@0:
2`<03Pl600d?100@4@T03a08010A2@0A4P`0418<00d@2@0;3@P02`d900X?2`0J7a/00PH300D;1`04
2PH01@/707YoN`1cN7@02`h:00T;1P0=40T030h700/<1P0=3PH2010A2@0F01@C3P0B4@`04a8=014@
2`0>3@P04Q4<01LF4@0D4`h04a8=018A300A40/04Q4<00d>2@0?40/03@h9010A300D5A004Q<>01DF
4@0<3@P02P/600d>2@803Pl:00P03Q0=00lA3P0A4a0061XG00`>2`0C5A804Q@A010B3`@03a4>00H0
3@h901XK5P0`<B`071dH00H70P0E5Q4500l@2`0300lA3@0?4@h03a4>00<0418?00T04aDB018D4@09
2`P06Q`I055CD00[;BX030h:010A300A4Pd00P0B4`h0100A4Pd03a0;00d>2@0>3`X200l@2`0500h?
2P0?40/04Q<>01<D3`0B4`h00P0F5a80100A4Pd03@h900h?2P0B4`h201@E400?01<E400A50d030h9
00/=200=3`X04Q@A00/=2P0?4@h01`T8014C4P0I6aX03Q0>014C400?4@`03Q0;00804Q@?02/03@l:
010B3@0A4`h04Q@?010B3@0?4@`04A<>010B3@0?4P/0418>01@F4`0D5QD04A<B014B500A4a804Q@B
018D4@0C5A004aH@00lB2`0B50h04A<>010B3@0A4`l051HC01HH5@0C5A<05aTH01`N7@0S9B@0828O
018D3`0>40X06Q`G01DG50082@X04Q<E010A5@0;31005AHJ01TJ700A4Q<051HE00804QHE0P0G6aX0
0`0@51<03a<B01@H5`0201@H5`0n01<G5P0A5A@03a<B01`P7`0C5aH05ATH00lC4P0M8B004aLF01PL
6`0K7ah07b<R01DI600F6QT04aLF024U900K7ah04aLF01PL6`0C5aH051PG01/O7P0H71/05a/J01HJ
6@0G6aX061`K01dS8@0W;B/06b4O02D[:@0>51@0728R01dS8`1YKW406b0S01dR9@0U:Rh05Q/N01TR
800K92<07BHU01dW9P0L:2P06RLW01`/:`0Z>SX06bd]03E7A`23UiP0X;Nf03==BP0eCd`0EVm]05Q]
KP1QMGH0M8>709>LX`2]/KX0dloK0?3Um@3ml?l20?oio`0f0?ofo`3/j?H0cLoL0:jd`027UZ00LhF?
06AhP@1AJ740Bf=]04MOJ@0mEE/0?5=I041GG@0jDEL0;dI<03A;D@0iD5H0<dY@02m6C00^AD/0;dI<
0399C`0Z@dL0;TM;039;C`0_AdT0:d=502U1@`0aATL0;T=402e1@P0`A4<0<TI50314@`0_@Sh0>Da6
03I9@`0Z?CL0;D0j0313?@0bACl0<4<m02/n>00X>cD0:C`f02`o>P0fBTP0?51?03Q<BP0gBdT0=4Q6
03Q=B011EU40=da70P0bAd001`0/@CX0<DHo02m2?00eB480>dm603E9?P0/@3@00P0bASX04`0_@cL0
;D4f02e1=P0nDTP0=DY10356?`0bBD80@eUF041FE010EEH0?E9C03Y?DP0oE5D0?eEC03Y@C@0mE4d0
C6=K03E?AP0gDDP00P0jE4/0@@0gD4H0<dY003U@AP0hCd@0<4Hj03E;?`0gC400;40g03I:B00jCdH0
>4i103I=?@0kDD@0@EM;03]@B`0dB4L0=TY803E:@`0eBch0>4i103U>AP0jCdP0>e1903U>A`0fBd@0
=DY303aABP0jCdP0>Di703Y?B00mDT/0?U=<03mDC`0dBD@0<TM203M<A`0jCdX0>e1;03U>B@0kD4/0
>Tm:03]@B`0gC4L0<DHo03m@A@12DdT0>DY003A5>`0fAcl0<D8j02Lh<00`@C/0>T]504EFD02L[JL0
PY><03I7?`0fACh0=4<l02/j<`0Y=C40:3@`02Da;@0X<S40:S@c00809Bl^01`0:CD_02Tf;00W=2/0
8RhU01hY8@0O:R@08bdW02Tb;@0Y<Rl09bh/02P^;00V;2X08BTS02<]900U;bL09S0X028/900N9b80
82TT034j=@0B6aP092dZ02Tb;`0P:BH05a/L01hR8`0M8B805QXK0P0J7Ql02@0P92D02Ph?024U9P0P
92D0:bl`01lT9P0R9b/07bH/01hU;00301`S;@0H01/R;00L8b/06b8X01HN8@0E7Al06B8P00hD4P0G
7A/02`l>01hR8@093@`06Q`I020R7`0I6QH061TD01TJ5@0G61<06AXD01/K6@0F5Q@04Q8@014A3`0L
71X0;bl]0P0E5A<401@D4P0=01LF500>3@/04Q4?01@C4@0A40h061LE010?3@0E518061LE01@C4@0?
3P`05A@B01TH500301<B3P04010?2`0B4@d04Q4=018A3@804A0<0P0B4@d0200G4a007ATH01TE500D
40l04@d>00l;300D41404PdA0P0C3Q80200A31803`X>02@R900;2@X040h?00h<3@0=2``06ALH0P0>
30d02P0;2@X030X;010>3`0?3@h04@l@018@4@0L6Q/03`d>01`J6`0:20T200h<3@803@/<00<030X;
00h;300?2``0100?2``00`0>2P/040`=018>3`0200l;300:010<3@0?2``04@d>00<0000K5aP030P9
01DA4P0<20T03@T:00l;30803@T:01X040`=01<?400>2P/02`L600`81`0A3@`05A4>01@A300l>C80
8AhG01/H3`0R81@00`40010<1P0@30/04`l>01DA400<20L03PX902dY:00[9bH03@T800/71P0Q7A`0
1P8101XD50803@L701D0100000P20P1FD5008adM01XD500>20P030H600h8200=1`L0100001@>3P0E
3`l03`T900d71`0?2@T01000014;2`0G4A4050h>01TC4`0=1`L01P0@1@T201462P0501052@0?10P0
3`@800h31`0=0PP00P0>0`T02@0=10T03PD:00h5200G4A<03@P700H20@091@@02PH503Da;P0Doooo
o`006oooool0200@6AH02Q8?00L?300;4@l03A<A00`B400>4Q403a8A0`0?4A00200>40d04AHB00X?
2@0F6aD02@h800dB300;40X03A8<0P0@5@l0600>4`d03A8<00hC3@0<3PT02P`700h@2`0?4@`03@l:
00h@2`0?4@`0418=00d?2P0@4Pd04Q@?00lA300@4Pl03@l<00`>2`0=3``03a4>014C400I6aP03Q0=
00d?30804Q@A00P0418?010B3@0>40/030h9010B3@0:30L03a4<00d?2P80418=0P0>40/0100?4@d0
3a4>00lA3P0>40d200d?300@00`>2`0;3@X02`d:00d?300@4Pl03a4>00d?2`0@4@`04a@?014B3@0?
40/0414<018C3P0A4Pd0414<00l@2`803Pl:01P03a0;010A300@4@`0414<00l@2`0>3`X04A8=00X;
1P0:2`P05AHA018C3P0=3PT06AXF01PJ5`0>40d04A<@00lA3P0=3``0418?00lA3P0=3``030h;00d?
300@4Pl200`=200700l@2`0=3PT02@X500h?2P0:2`P061TD00h?2P02010A300700d>2@0>3`X03@h9
010A300A4Pl04Q<>010A300200d>2@<03Pl:03/03a0;00H70P0<3@P03a0;00h?2@0A4P`03Pl900d>
1`0B4`/03Pl700h?1P0B50X04Q@900`=1@0=3PH0414901<D3P0D5Q004QD>014C3P0B5A406AhJ00<8
100C61@041@A00X@300A5a<0J6eY065VHP0D61<03@l:01@G400>40T02``600h?1`0@4@T03Pl700h=
1`0@40T04A0:00l?200@3`T04Q4;01HE3`0C4``04Q8;014A2P0A40X04A0;018C3P0@4@`03a0;010A
300A4Pd04Q<>00`=200B4`h051D@018C3P02010A300700d?300:30T05QPE034c<00B514030h;00d?
300200`>2`0900h@3@0A4a004Q@A018C3P0H6A@09BHQ01/L5`0=3PT04a@?00D03a0;00<0414=010B
3`0@4Pl00`0@4Pl01`0>40d04A<@018D4@0A4a00;S0]01DG500<3PX00P0@4@`2018C3P0<01<D3`0A
4Pd03Pl:00h?2P0A4Pd04a@?014B3@0@4@`04Q<>014B3@0=3PT03a0;0P0@4@`05@0A4Pd0414<01@E
400E5Q404A8=00d@2@0>4@X04A@>014C3P0@4Pd03Q0<00d?300C5A804Q@C014C4`0<3@h05QLG01<E
4P0A4`h03a4<014C3P02018D3`0;010B3@0A4`h04Q@?00lA300>40/03a4<00hA2P0@4``04A<>010B
4@0A4a800P0E5QP03P0F5aT05QPF018D4@0@4Pd04QD=018E3P0>40X04aD@018D3`0@4Ph07AlL06U[
J00E5aD05aTH0P0B51<04`0C5A803Q4;01HH4P0<3PT04aDD01LH6@0E5QT05QLL01PI7@0D5AT03@h@
01TK6P0C5A<06alN01@H5`0J7Qd06AdL014E500F6QT00P0D61L02P0E6AP05QXI01LK6P0G6aX051PG
01LK6P0A5A@05ATH01`P7`0A5A@201DI600301TM700H71/07R8Q00805a/J00<04aLF00lC4P0K7ah0
0P0F6QT0>`0N8R406QhM01LK6P0G6aX061`K01TM700F71X06AlM01DK6@0M8b405adM01XP800K8B40
5a`O020U:00M8RD04aPL020U:00N9bD07RLV01lX9`0O:BT07b/[020];@0P<300:CTi02@f=P0]?d00
;D5203eDD`0gDDh0:48o03QAD017Gel0Bf1Q06inPP22SY@0UinV0;Vja@3Gdn00j^;a0?K[nP3gk?X0
l>Wg0=_HiP2l`Ld0XJZf086AV`1aQHl0HWV204aUK`18Hfd0A5iX03iFG`0kDUP0=TeC03YAE`0nEE/0
>U5G0080<dY@01H0=4]A02m6C00^AD/0<TU?02i7B`0bBdl0<da@02i6B00[@dD0<4Q:0315AP0^@d@0
;T9303=7AP0dB4L0<4A202/n>P0hBdD0=DQ202`o>@0cAT00<4<m0P0Z?CL01P0[?SP0;D0j02m2?00a
A3l0@eME04]OGP80>Ti<00@0=4Q603A9A00iCTT0=DY50P0cB4401`0bAd00=da50396?P0hC4<0=TXo
03A8?00fBch00P0dB3`0:P0^@SL0B5]D04QKEP0oDTl0>Di;03E:AP0fCDL0AeeJ04=IE`10EUD0>e1A
03iCE010EED0?eEC03aBC`0mE4h0?UQ@03mJDP0jETh0>5=;03YDB`0lET`0?EI;03I>@P0gCT80@UQ<
0398>`0cB3`0>De203Q=B@0jCdH0=T`o0399>00hCcl0?UA803]@BP0`A4<0=4Q603aABP0mE4D0?UE6
03E:@P80>Di700L0>4e603U>A`0jCdP0@5E>03iCC00mDT/0?U=<0080?eA=05/0>e1;03Q=B00gC4L0
=4U403eBC@19GUT0?eA?03aAC00cB4<0>4e803]@B`0dBD80>D]003Y;@@0oD4H0=TLm02ho=`0Z>c<0
9CH^02Tj=00hBD<0;Sli04UJE013DTT0<cld02ll<@0`?C<0<3`e02di<`0/=c<0:3@b02Td=00b?3h0
;cXm02Lb=@0W=2l0;3T_02Xg;P0T<2P07bXR01lZ8`0T;RP0:S<^02Tb;`0T;2X09B/Z02@Z:@0R:RD0
8bdT02<]9@0R;2@082XR01lX8`0M9R406b@O02D^:`2:Ti00DeaI01`U8P0K7b008bLX01dQ8P0J7Ql0
9BTZ01lS900N8R<0<cLh01dQ8P0O8b@09BTZ02<X:@0S:bd07bP/01/T:00J8RT07RH^02@/=@0N9Rh0
72@[01TQ9@0E7R0051hM01HO6`0D6QP06b4O01HJ6@0B5QD05a/J01/M6P0L7Q/05ALC00805QLB00P0
51D@01HG4@0L71X05aLE01<C4@0B4Q0061PF01`L6P@05QHD00/051@B01<C4@0Z:BL05A@B01PG5@0J
6AL04A0>01DD4P0F5A<04a8@014@3P0201<B4003018A3`0I61@04a8>00804Q4=00H04A0<01HE4@0B
4@d04Q4=010?2`0A40`2018A3@0D010<2@0E4A004`l>01<?3P0C3a004@d>01DA4P0@2`l04@`@01@?
4`0A31803PT=014?4@0=2``04Q0A01<A4P0=2``030X;00h<3@0?3@h2010>3`803`d>0P0=2``0100;
2@X04@l@00P61`0<2P/200h<3@803@/<00<030X;00h;300@30d0100@30d300l;3004010<3@0?2``0
3`/<00l;30804@d>00L0E51A01<?400B3`l030P9018>3`0F4Q<04`l@00803@T:00@03PX;00X61`0=
2@T04`l?0P0A3@X0:00H5@l0Cda5092=Q01eLfL0;R`O02DS5P0I5Q004Ph=00h:2@0B3Pd02`L601hJ
6@0@3@`04`l>00T61@0?2`X040`;00h:2@0@2PX01`8200h8200B30`02`D501TC4`0D3Ph04P`<00l9
2@0<1PH03@L700l92@0G4A403@L702hX:00:1@D04P`<00X4100E3`l01`4100d8200=1`L200`61PH0
40D900<03`@801462P0A1PX00P0A1PX200l4200;01052@0A1`T040L;01072P0>1@P01P42018=3`0@
3@d0BTI802`X:@1FDU805?ooool001_ooooo00T0IVm/03i7A00H8Ah04QPF00/A3`032@L03A4@00hA
400?4A000P0>40l0;00=3``01``6014F400>4`d01@X4010E3`0<4@/03A8<01TN600K81X03a@>00/@
2P0?50h04Q@?00lA300A4`h03Q0;00X<1`0<3PT03@l:00lA300<3PT03Q0;010B3@0=3`X03a4>00d?
300<3P/03Q0=00lA3P0@4Pl0@dE201dO700=3``02`d:00P:1`051`803Q0;00d?2P0;3@P0418=00/=
200A4`h03@l:0`0@4Pd02P0B50l04A<?00h@3@0?4@h0418?00d?300;3@X03@l<00lA3P0=3``200h@
3@0:00`>2`0=3`/03a0;00h?2P0<3@P03Pl:018C3P0C50l0414<00l@2`803Pl:01<03a0;00h?2P0=
3PT03Pl:014B3@0@4@`030d800X;1P0@4@`05QLB00h?2P010P002P/6014C3`0=3``030h;018D4@04
1P<04aDB00803Q0=0P0=3``0100>40d0418?00l@2`0=3PT200l@2`0900/<1`0?40/0004001/L5`0<
3@P07AhI00H70P0>3`X0414<00803Pl:00<0R8V402`]:00=3PT00P0?40/2010A30@04A8=00P03@h9
00d>200A4P`03Pl900/<100@4@T03@h600`>0`804A<80200414900l@200?40P04A8<010B2`0<3`P0
1@L205mSGP1dNGD02@h:00H<200?5A4051XF00hC3`083@T000D100d@300@4Pd05QTB018D3P0?40X0
3a0800h?1`0=3PH051@<018B2P0=3@D03`l701HF3P0D50`04A49010@20<03`l700X0410801<D3`0@
4@`04A8=00h?2P0<3@P03Pl:00l@2`0A4Pd03a0;0P0=3PT0200?40/03@l<00lA3P0?4@h04Q@A00T;
200C5A803a4>0P0=3``02@0A4a005QPE01PJ5`0A4Pd03Pl:00P9100?40/04a@?00d>2@0500l@2`04
010A3@0@4Pl0418?010B3`803a4>00X04A<@00d?300;3@X03a4>01dO70092`P04aDA01DF4@0C50l0
414<0P0>3`X0100?40/04A8=018C3P0C50l2018C3P07010A300?40/03a0;00h?2P0D5A005QLB01<D
3`0200l@2`0/014B3@0B4`h0414<01<F3`0A50d030l800/=200=3`X04Q@?01DG500:30T0:B/Z01@E
5`0F5aT03Q0@01HH5@0D5Q404A<>010B3@0B50l05ALB010B3@0A4`h04Q@?010B3@0?4@`04A<=00`?
1P0A50/04aD@010B4@0B51<07b0R01DF600H6A/05aTG014C400>4@X041<;01`O600A50h051HA01LI
500D5Q8201PJ5`0B01LI5`0>40l03@l>01`N7@0K7AX041<<01HI4@0J71L05aTF00d>4@1CE5P0GUmT
014B5P0J6ad071dO01@F500@4Pl05a/J0`0B5QD0700@51<051PG014E500A5A@04QHE01<G5P0F6QT0
61`K01DI600N8R404ADD01<G5P0J7Qd0720O01DI600G6aX061`K01LK6P0M8B0051PG01TM700G6aX0
4QHE01XN7@0E6AP05QXI01dQ800I7A`201HJ6@0:01TM700K7ah0728P0416A00oAD<06b4O01TO7`0L
8R807R@T01TN8@807b@W00<06QlS01PM800M9RH00P0L9B@0;00M9bP07BTY020];P0fATH0@U9B01d_
<00L;S0083@e02e2@P0[A440<4U603I?C@18H600CfAU05]^L@1bPHH0QI2F0:2V[`2k^lL0b/SE0=SB
h03Le><0em7O0<;2c`2W[kX0TYjZ07J9T`1TNXD0EG1i04ERJ`11GFP0?5QS03QBFP18GfD0Bf9X03Q?
E@0cBU00=DaB0317C@0bBDl0=DaB0399C`0_AT`0<4M=0P0cC500100aBTh0;4A602e5A`0dC4h20315
AP0F0314A@0^@T40;D5002/o?P0dAd<0=dY40354?P0^@C/0<TDo02Xm=`0U>3809cXd02e0>P0bACl0
=4M103E8@`0iCD/0>dm>03=7A@0dB4H0<dM503E:A@80>4e804P0=DY30356?`0aASl0=4U202e1>00i
CD80;d<g02a0=00fBSd0;T8f03I:?`0]@3T0DVEQ05=UI@0mCe80?4mC03Y@C@0hCdX0AE]H03mED`0n
E5<0>Tm@03]@D@0kD500>e5?03mEDP11F5<0=Tm903QCC00nFU<0@UeF03iID00eCdD0;dTn02U1=00b
BCd0?59602m5>00hCD40=d]003M<A`0gC4<0=de003U@?`0oETH0@UQ;03U>B00bATD0=TY803Y?B00f
CCd0=D`l0356?P0iCTL0>e1903Y?B00lDDX0?eA=03iCC010EDh0@EI?041ECP0mDT/0>e1903I;AP0i
CTT0>e1;03E:A@10EE00DFIQ03]@B`0nDdh203eBC@0S03I;AP0^@c`0=4Hk03A5>`0mCT@0=dPn02Lh
<00Y>S80<T<k02Hg<@0Z>cD09SLa03I7@@0kB3l0=3la02dh:P0W<BH0:3@Z02Lb:P0V<Bd09C4a02Xe
=`0lAd/0>DI<02dj@00S<Bh08c0V02Db:00U<BP092lW02Ha:@0W<B/0:34/02D^:`0P9bH00P0R:2P0
4@0R:RD08R`S01lY8@0M9al07RPP024Z9@0E7QT05QlJ02H_;01XLFh0=Sll01`U8P0M8B807R8S01TM
7P0M8B809BTZ0080720Q01d0EUYK01PL7@0N8R<05QXK01hS8`0N9RP06B<T018L7P0A6Ql05AhS01hW
;@0J8bP05b4S01<M7`0E7ah05b8N01HQ6`0B61H03A<A018F5@0=4A003a<B01TK600K7AX05ALC01LH
4`0H6A@05QLA01LH4P02018B4004014A3`0F5Q@05aLE00h>30<05QHD0`0E5A<0400T8b405A@B01HE
4`0H5aD04a8@01@C4@0H5aD05A@B010?3@0C4Q005aHD010?3@0B4@d030/7010?2`0C4Ph4014@3080
40l;0P0A40`01`0E4@h05Q8A01<?3P0D40l0510A010<3@0D41400P0A31005@0D3a<050lE01<>4P0A
3a40518C00d;300?3@h05A<D018@4@0F51D03@/<014?400E4a@040h?00d;300<2P/06ALH01<A4P1:
B4T02`T:018@4@0200h<3@803@/<00<030X;00h;300?2``0100?2``04P0@30d03@T:00d92P0A3@h0
3`/<00h:2`0;1`P06QHG01TE5P0]:BX04@d>01@@4@0;1`P04`l@01LC500E4A803PX;00/720804@d>
01X040`=010<300@30T07ATF04Y7@@2PWI@0oO__0?Cci`1THUD0928E014?1P0?2`X03PX901LC4P0?
2`X05Q8A00d9200300002PH501@@3`0=2@P030P7010:2P0B30`03PP800d71`805a4A01801`4100`6
1P0A2`/03@L700X4100<1PH0100001@>3P1jM7@07ALG00T30`0?2@T0100001D?3`0l=SH05@l?028L
700:1@D601052@0400l4200@1@T040D901462P804PL;0P0C2@X02P0B20T04@P901072@0@1`X02`D7
00P31@13?T80h]gQ07]fNP03008Dooooo`006oooool0100G81l031DD00D>300:4Q02010F500P00dA
400>4A003Q0?00h@3`0>3`l03@l=010D3P0@5@h01P/5010E3`0=4P/03a@>00X?2@0?50h041D>00`A
2P0:3`T0314:00lB300>40X0418<00d?2@0<3PP0418<00h@2P0?4P`030l900lA2`0A4`d03Q0:00d?
2P0>40/400lA300401DG4P0A4`h03a4<00h@2`803a4<01/04A<=00lA2`0<3`P0418<00T<1P0>4@X0
3a8;010B300?4P/03Q4:010B300=3`/030h:010B3`0E5a<051HB014C400?4@d030h:00`>2`0=3`/0
3Q0<00d?300?40`03a0;00`=200?40/00P0C50l06`0A4Pd03a0;00h?2P0?40/0414<014B3@0B4`h0
414<00h?2P0?40/04A8=010A300=3PT04A8=018C3P0@4@`05QLB01@E400=3`/051HC00h@3@0E5a@0
10H301<E4P0<3P/03@l<00lA3P02010B3`0500lA3P0C50l03Pl:00l@2`0B4`h00P0@4@`01P0C50l0
3Pl:0493?P0R8ah03Pl:00l@2`803@h900@04A8=0452?@0P8A`03a0;0P0>3`X200l@2`80414<02X0
4A8=00h?2P0@4@`04A8<00d>1`0?40P04A8:01DF3@0@4PL030h400lA1P0>3`H03a0800h?1`0?40P0
4A8<00lA2`0<3`P030h901<F4@0B5a803Q4>00lE400830L041DA00dA3@0>4`h01`/700d?2`0=3`X0
3A09014C3@0A4P`03Pl700d>1P0?40P0?clg02/Y8@0?3@H03P/401@B2P0=30@2014>2004010>200B
3`T04a0:018B2`8030d800<04A8=010A300=3PT00P0A4Pd04`0>3`X05AHA01dN6@0C50l02@X5018D
4@0A4a004Q@A00X<2@0>40d04aDB018D4@0?4@h03@l<00h@3@0B514051HB00h?2P0D5@l00P0@4@/0
2@0D5@l05AH@00l@2P0?40X03a0;00l@2P0?40/0414=010B3`0200lA3P@03Q0=00H03@l<010B3`0U
9b@0418?018C3`0A4P`2010A2`0:014B300C50h04A8<018C3@0E5Q004A8<00d>200?40X0414;014B
3080414;00H061TC01`M5`0I6Q@06AXD01XK5@0E5Q0200l@2P0:010C2`0@4`X03a8;00hA2P0?4@/0
418>00/=2P0f>3H0TiFD01<D5@805AHG00<06A/F01LJ4`0A50d00P0=40T0;@0A50d041<<014D3@0C
5Pl04QD>014D3@0D5a004A@<014E3@0A4`l04A<B010B4@0A4QD0414D01@E5`0F5aH04A8>00lA2`0D
5Ph06ahG010C3@0@4Pd06A/F01/M6@0B514030h;01@F500B51<051HE02/];00F61D061/C00hA2@0B
50l06A/H01LH6`1kO800OWn401TJ7P0G61X04Q@D01@F500L7Q/03Q8A01DI6002018F5@0401DI600>
4Q405QXI01@I60804QLE04l04aPG01@I600F6QT08BDT01HJ6@0E6AP04ADD01HJ6@0D61L06QhM01PL
6`0E6AP06alN018F5@0E6AP061`K018F5@0F6QT04QHE01HJ6@0K7ah05a/J01DI600F6QT06QhM01`Q
800H7Q`06R0N02H/:P0R:BL0;38b01XQ8@0I82004APJ01XQ8`0P9bT08bT/01/Q900P:2T07RLV01dV
9@0N:2T07RXZ020^;P0O;bl08S<d01h`<@0U=cP06Rh_02Xo?P0^Ad@09Cdj03M?C@11FET0?5AD05EY
K01SMGT0LX:708JAV@2FWJL0X:J`0:n__02g]L80/k>o0::W/`2>VJ<0OXbG06QlQP1CJgD0BFA^04ER
K00mFVD0>UMR03aGG`1HL7D0GWEk03eDFP0nEE/0?EAJ00<0<DQ>03P0;dI<02m7C00aB4d0<4U=02m8
B`0^AdX0;TI802m7B00_AdT0<4E60397B00cAdP0<4A303A8A`13EeH0<TI202m3?@0^@S`0;T4l02a0
>P0]@3X0:chi02Xn>00[?cT0;T4l0314?P0eB4@0=d]:02i2@@0dB4H0;d=103E9AP0iCTP0=DY403M<
AP0gC4D0<dQ103E:@`0hCDD0<4@j0355>P0dB3`0;T8f02Lk;P0^@SL0=d]102m2?00bAT@0<dE703i?
EP0jCE80@EMD03QAB`0nEe<0>55>03YCD080>eAA02@0?UMD03UBC`0hDDd0?eQC03eFD00jEDl0BFEO
051]I@1:IE`0?eU?03eFB`0fCT40<dXm03I<?`0dB3`0=DXm03I:?`0gC4L0=4U003M=@00mE480?EA4
03]AA00hCDL0>De<03mCD@0oE4`0>4i003M>@00eBT80?eA=045FC`0nDd`0?E9;041ECP0nDd`203mD
C@0C03iCC00lDDX0>e1903]@BP0dBD@0>Tm903Q=A`0iCTT0@eQB03]@B`0hCDP0?E9<03Y>B00aAD40
<dM003U:?`0lCD@0=dPo03A5?00202Xk=00N01//9@0Y>SD0B5UD02`m=`0fAd40<Shd03<k;00_=bT0
9BlR02H`9`0T;bL08RdY02Xf=@0f@d@0@4e@034oA@0U<cX08Rl]02<`9@0T<BL09C8X02@_9P0U<2P0
9BlY02D^:@0R:bP072@R020V9P0Q9bP07bLS0P0N:200<@0O:B4082TS024Z9@0M9R405alJ03@m>P0e
?S/08BXW01TR7`0M8R80724R01dR900M8B<06AdP01LK7P0L7R807B4T01XN8P0N8bH08BHY01lT9`0G
7b005b4Q01XT9P0K92T06R<X01LP900H8BD06b@V01TS900B6aT03aTE01@O600E6aP04QLE018F5@0E
6AP05a/J01<E4P0J71T05QLC01PI500J6aH05aPB01PI4`0C4a4061PF018B400A4@l00P0H61H01P0G
5aD05QHD01@D4P0D51805aLE01TI5`8051<A01h04Q4?01DD4P0H5aD05A@B018A3`0L6aT05QDC010?
3@0E51805aHD014@300?3PX04Q4<014@2`0?3PT04a8=014@300@3`/03`h9010?2P0@3`/04A0<018=
2`0D3Ph04@`;01D@400G4A<04`h?01<=3`0E3a<201<>4P0901L@5`0I51P04@lA010>3`0B41403P`=
01XH6@0/:R/08R0Q008020H700T04@l@010>3`0?3@h03@/<014?4@0<2P/09B<T00h<3P0;2@X00P0>
30h200d;300300`:300>2``040X<00@040X<00L04P`>00d72@0<1PP04`d?010:300>20X03PT;0080
3@T:00D040`=014=3P0;1`P040`=00h:2`0200d92P0400h:2`0?2``04@d=00l;2`8040`<02`04`l<
02`X9025PW`0YJ:I0=_HcP3Acl@0?S`_01hL3P0D40T05A4@010<2`0I5A@04`l>00`81`0A3@`03`/:
03Xf=@0:1PD03@T800l;2P0>20P03@L7010:2P0D3Ph05Q0@00T4100<1PH03@L700l92@0A2`/040X:
00`61P0C3@d02P@401@?3`0=1`L030H600d71`0@2PX02PD501TC4`070P8040X:00h820H040D90180
5@X>01<8300@1@T03`@801052@0A1`P050X901881`0?1@@03@D400l71`0@1`X040T;00d7300F4AH0
=2hd01hH7`0?2@lDooooo`006oooool020053QD02A<I00D?4@0<5QL041LF00hD400<4@d03a0=0P0@
4102018@4`0800lA400>40d03@l<00d?300>40d03a4>00d?300>40d200lA3P0?00h@3@0=3``04A<@
01@F4`0C5A803Q0=00/=2P0=3``03Q0=00@60`0>40d04aDB01@F4`0T9R<02`d:00803a4>00L03@l<
010B3`0C5A804aDB01HH5@0D5Q<02@/800804A<@01P03Q0<00X<2@0>40/030h:00/=2P0@4Pd04aDA
00lA3P092`H03a4=00L91P0C5A003a8;00h@2`0C5Q004A@=010B3@0@4P`03A0900d?2P0=40X03Q4:
010B3@0?4@`200h@2`0400d?2P0<3PT030h900d?2P803a4<00l0418=014C3P0B50l051HA01TJ5@0F
5a8030d800l@2`0C50l04A8=02//9`1<CDP05aPC0042000K71L00P0>3`X200l@2`803Pl:0P0A4Pd2
00l@2`09014B3@0E5Q409bTT01TK5P0<3PT03a4<010B3@0:30L0418=00<03a4<00<03Q0;00`=200@
3`X00P0@3`X00`0>3@P03@`700/:1P0300h?2P0c00h>300?3`d0418>010A300A4P`030d900`=1`0>
3`T01`P201@E3`092PD03@h600h?2@0R8al030d7018C3@0F5a403Pl900/<1P0@4@/03Pl900`=1`0:
2`D030l8018C3P0C5@l03a8;01@F4@0;3@L03Q4:00X;1P0<3@L01`P200/<1P0H6A<071dG018C3@0:
2`D05QLA018C2`0>3`L04149010?2P0>3PT04A8<00d=200F5A4051D@00L70`0A40`04A8=00803a0;
02404A8=018C3P0>3`X02``700X;1`0M7QT05AHA04M8@`082@@03@h9010A300:2`H0414<01DF4@0;
30L03Pl:00d>2@0F5a804A8=018C3P0?40/04a@?00h?200@4@T04A8:014B300>3`T03@h800h?2P0A
4Pd04A8>010A300@40h00`0A4Pd02@0B4`h04a@?01<D3`0A4Pd03a0;01DF4@0@4@`04a@?00/<1`02
01<D3`08018C3P0A4Pd0414<00l@2`0H6A@01@H100h?2P0G61<200h?2P0H01DF4@0A4Pd04Q<>00h?
2P0=3PT05AHA02<T7`0K71L03@h9010A300I6QD04Q<=00lB2@0<3`H03@l;020R7@0K7AX0418A00/=
300H6QT07b4O01<E400D5Q403Q4:1P0?4@`06P0C5A0020X500lA300D5Q4030h9014C3P0A5A@03A<A
00lC4P0830/03a<B01@F5@0=3@/03`l=01<C3P0D4`h04Q4<00h>1`0G61<0418?014C400m?c`04aDB
01TK600F61D051HC0`0C5A80800@4Pl06AhJ014F4P0?51003Q8A014E5@0N8R<04aLH01@H6@0D61L0
4aLF010D4`0=4A004aLF010D4`0E6AP041@C01@I600@5Q@04ALE00hF4`0D7AX082TV00`E4P0G81d0
3A<A01<I5`0=4a40<3Hd01<I5`0=4a4051XH0P0J81h00`0=4a406AlM01<I5`0201<I6@0701@J6P0F
71`05adM01PN7P0G7Ad04aTI01@J6P0201LM7@0601DK6`0E7A`031DD020Y:00@6QT06b@S0P0H8R40
8`0G8b405R8P01/W9@0D81h06BDU02@`<00W<c<09S8b01h[:`0O;Bd07Rh]01TY:00K;R`08C@c02@g
=@0/?Sh09SXi02Pn?00`A4<0=DY:03Q=CP0nDe@0BEiP05I[KP1PMGP0K86507J;T01oTYP0S9jU092Q
Z@2:WJ@0P9>J0724R`1VOH<0FW9g0080CFI]00T0C6M^03aGGP0gDUT0>eIM03QCFP0iDUL0=e1E03E>
D`0dCE400P0`B4`0GP0]@TH0>4eB0356B@0`ADT0?55B039:BP0`ADH0<DI702i4@P0bAdL0=D]90316
A00cBDL0=de;03E;B@0jD4h09C/h03=:A00aAT809c/i02i5?`0[@Cd0:3`j02]2?00bAd<0<TI402e4
?P0Y?C/0<TI70314A@0dB4H0=4U40356?`0fBd40<dTm0357>`0fC440>e1903Q=A`0hCD@0>4a00312
=00^@3@08CDY02Pl<P0cAch0=T]403M<AP0bBD<0<4E003E;A@0mE4`0?5I;03UCB@0fD4L0=Tm903UB
C`0lEE80?eQE041IEP1>If@0<T]704AMF00mEU00>E9<041JD@0nF4l0>eE<03eDB`0jCdH0<DHm03aA
A@0jCT<0>De203eAA@0jCT<0=da503M<@`0gCD40>4i103M=@00gCD40?59704EJD`0nDdh0?55<03]?
C@0dBD@0>Di703Q=AP13F540>e1904QMEP15FU<203aABP80>e1901X0>Tm803U>A`0hCdH0>e1903U>
A@0lDDT0@5==03eAB00oDT/0=dY403I:@@0iBT<0<T<m02dn=P0iBT<0<40m03=3@@0Y>CP0@51@06If
MP0B8R80<40o07R8Q`13De00;d0j03A1>P80<3Xa0440:cD/024[8`0S;2L08BXV03a7@`1dOWd0BUAD
02H`<@0O:BX08bhZ01`/8P0U=B/07RhU02Ld;@0X=Bh0:3@]02<^:00M:2807BLQ01PQ7P0J8b007BHR
01hW8P0R:bH092dY024Z9`0P:BH0624N024Z9`1SK6T0DU]H01`U8P0H8Ah051lI01LR700I8Ql061hL
01LK700M7R406aXO01HG700N8RP06b8Z020W;`0R:c809B`d018I8@0a>3h0EUeS024X;P0P9BT05Q/N
01@J6P0G71T05AXF014F400C618051TE01PJ5`0G6AH061XG01/M6P0D5Q<05aTF01HH5@0301@F4`03
01DG500A4@l051@B00<05aLE00@05ADC01PH5P0D51804a<A0P0D51800`0C4Q005a<B01LC4P0201LC
4P0501HD4P0E51802@P602h^;00J6QP00P0;2`T0600@40h040l=01<B3`0C4Ph04A0>010?300@3`/0
3`h<010?300@3`/040l<010?3@0A40h04@l@018>3`0?3@h04@dA018=4@0A3a804PlB020K7`1VI6L0
5A8E00l:3P804@lB01h020H9014?4P0A3a8030X=014?4P0?3A003P`?00`:3@0:20/03@/>00l=400=
3@l02PT>00d=3`0B4QD040lD00d=3`0?3Q802`X?01LG6@081`/02`X?00h;3@0>2P/040`=014=3P0@
30d03PX;00l;300E4A8200h:2`0?01LC50070`@0510A018>3`0>2P/04@d>00l;300;1`P04`l@010<
3@0B3Pl0510A00d92P0;1`P03PX800803PX701<04@d:01@A300D4@`061D@020M5P0j=c00De1902@Q
6P0>2`@040`800d71`0@2PX04@/;00l92@0<1PH0<2XZ01XD500;1@D04@/;00803PP801<04@/;00L1
0@060@402@<301<=3@0;1@D040X:01D?3`0?2@T04@/;00d71`090`<03PX9014=300B3Pd02PH500L3
0P0<1PH040L800803`H700<03PD600l61`0A1`P01P0@1@T01P0E2Ph050T=01<8300B1`/04@H:0105
2@804@L800X040H701052@0?10P03`@801462P0=10L02@0301483@0K4QL04PT>5?ooool001_ooooo
00h05AlY014K8`0?6Qh03QPJ00T@3`0=4`l04A<>014B3`0A4@l04@l@018>4`0@3Q404Q8D010B4@80
3a4@00<0418A014C4P0=3`h01@0=3`h03@0?4A004Q@C014C4P0=3`h030h=00d?3P0A4a8030h=00h@
3`092`X0=cTh01@F5@0<3P/00P0?4@h0100=3``03a4>014C400;3@X200D7100E01LI5P0R92403Q0=
00lA3P0<3P/03a4>00h@3@0=3``04A<@00`>2`0>40d02`d:014C400?4@h051HB00d@2@0@4``051L@
00d@2@0930D030l800<03A0900<03Q4:00lB2`0?4P`00P0>40/0100=3`X030h900`>2@0>40/300lA
30803Q0;00h0418=01HG4P0E5Q403Pl:010A300B4`h03Pl:01hO6P0c=2l04Q<>00H70P0E5Q402``7
00h?2P803a0;0P0>3`X0100D5A004Q<>010A300@4@`2014B3@0600T;1P0=3`X04Q@?00h@2`0<3PT0
418=0`0?4@`01@0@4Pd03a4<00h?2P0?3PT04@h900<03Pd800T03Pd900d>2@0=3PT03@h900d=2`0>
3P`03a4=00D6000;30H00P0?40X0300@4@/02``60001000E5Q003@h801dN601;C4H0:BXT00d>200A
4P`02P/500P90`8030d703L04A8<010A2`0A4P`051D?01DF400A4P`04a@>00`=1`0A4P`03@h801<D
3P0@4@/04a@>010A2`0A4P`03a0:00d>200C50h04Q<;00l@200B4`/04Q<=00l@2P0B4`d03a0;01`L
6P0N7Q`03`l=010@3P0=3@/03a0;00d>2@0<3@P03Pl:014B3@0B4`h02P/600h?2P051P409RLR00H7
0P0>3`X04Q<>030a;00E5Q4020T400X;1P0?40/051D@00l@2`0D5A005QLB00T:1@0>3`T03Pl80080
414900H0414;00h?2@0>3`T03Pl:010@3P0A4@l2010@3P03010@3@0@4@`0414<00804A8=00D04Q<>
010A300`<B`04a@?00l@2`0200d>2@03010A300A4Pd04A8=00<04A8=01l02``700h?2P0:2`H03a0;
018C3P0?40/0414<014B3@0@4@`03a0;00h?2P0?40/04a@?010A300;30L030d800l@2`0=3PP04aH=
01@G300<3`P02P`900d?300;3@d030d?01@F5@0F61@04A<>018E300<3`H04A@=00804A<>0`0@4Pd0
300E5a80418=010B3@0D5Q402`d801@G4`0A5AH020d@00`B4P0;3`h03a<B01<E4P804Q<>00/04a8=
01HC3P0F4`h0518<01<D3`0?4@h05ALD02HX9@0B51406A/H01@F4`02018D4@0901@F4`0E5a@04Q@A
01/O7P0D61L04aLF018F5@0D61L07b<R00<04aLF01<04QHE014E500?4a806AdL02da<00d>3L0720O
014F5@0C6AL03QLD01@M6P0?61D03QTE01LR7P0;5Q8051XH01hT8P0E6aT0;C<a00805Q`J00H051XH
01DK6@0I7ad08BLU01`R800@5Q@201DK6`1801HL700G7Ad061hN01PN7P0J82005adM01TO7`0O9BD0
8BLW020V9P0H8B005QlN01XS8P0G8B0092h]01<M700N:RP062LT01<R7`0F9B8041lL01HU8P0X=3@0
;3Xj02Hd=00L:RX07Rh]028b<@0Y>CP09CPf01P[:@0[?S`0;D0n020c<P0[?ch0<DE403=7A`0eBDX0
>Tm@049IFP1<I6H0EFe_05mgNP1VOh<0KHJ:07J?U01iTYL0N96F076:S`1WP8D0H7Un05UbM`1CK740
E6eb05=/L@18HFH0@U]P03aFG00hDeX0=e=G03IAE@0eCU<0=4eA0359C@0Y@DD0>4e@02Xo@P0/@D@0
=4U;03iDDP0eBdT0;TA20P0]@d403@0gCD/0=D]90316A00aAdD0<dU70316A00cBDL0<TQ502e3@00/
@Sl0=D]803Q>B`0[@Ch00P0_AD80B00^A440;48o02i4@@0dBTL0<dM80396A`0fBTT0=da703=8?`0f
C400>U1303=9?00eBcl0?55:03M<AP0aASd0<dDi02i0<@0Z?3007c<X02e1>@0gBT@0<DI103E;A00i
D4P0>e9803YAAP0eCD00>E=603QBAP0fD4D0=e1:03UBCP0lEE80AUmL049KF01<IF80=4e904=LE`0n
Ee40>E=:03I>AP0gCTH0=4]303Q>A@1=HUT0B5eD03Y?A@0hC440>De203E9?@0gBd00>Di603aAB00k
D4L0>4i203=9?@0bB3`0>Dm303iCC00dBD80=DU703iBD`0mDE00>e1:03M<A@0hCDH0>e1904=HD@0n
Dd`0?eA=03eBB`<0?55:02h0?E9;03Q?A@0lDDP0>Tm603eBB@0oDdX0?51703eAB00gB400=TLo03M8
@00b@CX0;Sdf02m0>P0lC4T0=DE403m?C`28UiX0_<[<03e=C@0L;2`0;cln02/k>00cA3h0>dQ1030j
<P0^>3009c4Y01hX800Q:RD0:S<_079kN03foo`0UYnM02D^;@0Z<c80:CDa02<b:`0X=c009cH_020_
:00Q;RL09S8/02<^:00Q;2H082XU0P0J8ah0:00P:BD08R/X02@]:P0R:bP07BHS01`U8P0H8Ah08BXW
01`U8P0O:2D05QlL01PR7@0F8A/05b@K01TS7P0H7Q`05a/J01`L7P0G5Q`07AhS03XmA@0l@dd0=Ci7
02<]=P0Z<C/082La02H]=@0k@4H07B8V02@Y;00N8R<06alN01dO7@0J71L05QPC01TL5@0;3@X04Q@A
01/M6P0G6AH201<E4P0301LI5P0F61D051HC008051HC00X05ALD01<C4@0D51805ADC01HF500E5A<0
51@B01HF500D51804a<A0P0E5A<00`0C4Q005A4@01HA400201DA400901@B400C4Q006QTG00l>300;
2`T05aLE01@D4P0K6aT040l=00804a8@00<04A0>010?3@0A40h00P0B4@l4014@3P03014?4P0@3Q40
3`d@008040hA00`04@lB018@4`1NG5l0THnB01TG6P081PT07Q`O00d;3P0;2@`0518E018@4`0:20/2
00h<3`06010>4@0?3A003@/>00`:3@0=2`h03@`A0P0>3A802@0=314030/@00`;400I61d0Lg9g00/:
3`0K6Ql03@`A00P61`0200l;300F010<3@0?2``03`/<00d92P0C3a003PX;00l;300@30d030P900T5
1P0>2P/02@D600h:2`0=2@X020@500h:2`091@H02`L8010<3@0>2P/03@T:014=2`804Pl:00/04a0;
01@A300D4@`05A8=014>2@0I5Q40:RLR010=20040@002`H500d71`02010:2P0B00l92@0=1`L08adM
01<=3@0<1PH04P`<00l92@0=1`L02`D5010:2P0^:2P050h>01<=3@0;1@D01P0000`61P080P803PP8
0P0=1`L01`0@30/04`l>01@@3`0=2@P02`L6010:2P0@1`P00P0?1PL00`0?1@H040H7014720060105
2@804`P<00@04PL;01462P0@1@T040D90P0A1PX201052@803`@800H04@H:01052@0>0`L04PL;01P=
4@0A1PXDooooo`006oooool03P0e?dP0U9jU00D;3`0E7B003QDD00P>2P0B5Q404a@A018B400B4140
4PhB010>4@0A4A803a4@0P0>40l02@0?4A00418A014C4P0?4A003@l>00h@3`0@4Q404A<B00d?3P05
00h@3`804A<B00D02`d<00lA401`LW40>3Xi00h@3@0200lA3P803Q0=0P0?4@h01`0A4a0030h;01XL
6@0X:RL04aDB010B3`0>40d00`0?4@h0200A4a00418?018D4@0B514030h;010B3`0?4@d03Q0;0P0=
3`X0100<3PT051HA01LI500>40/200d?2P0300h@2`0?4@`03a4<00803Q0;00@03@l:00`>2@0<3PT0
3Q0;0P0?4@`01P0>40/03@l:00d?2P0=3PT04A8=018C3P80414<00T04A8=00l@2`0A4Pd03Pl:010A
300B4`h03@h900`=200>3`X00P0@4@`0400?40/03Pl:01@E400A4Pd0414<018C3P0C50l03Pl:00h@
2`0@4Pd03a4<00d?2P0>40/03a4<00T;1P0:30L400d?2P06010@2P0?3PT03Pd800d<1`0>3@P0414<
0P0>3`X200d>2@0]00h?2P0>40/02@X401@E3`0O81X06AXD018C3@0C50h061TC01<D3`051P404a@>
014B3P0=3PP03Pl9014B300=3PP030d7010A2`0B4`d03a0:00h?2@0?40X0414;00l@2P0=3PP03a0:
00d>200@4@/02P/501<D3P0B4`d09RLQ014B300<3@L04A8<018C3@0?40X03Pl700d>1P0B4`/04a@>
00h?2@0?40X04a@?00806ATG00d03Ph<018B400?3`d04a@?014B3@0=3PT030d801HG4P0N7aX04Q<>
010A300=3PT0414<00804A8=00H05aPC03`m>00E5Q403Pl:018C3P0@4@`200`=200801@E400A4Pd0
20T401DF400?40T03a08010A2@0@4@/200l@2P0600h?2P0>3P`0410>010@3P0?3`d03a0<0P0?40/3
010A300:01DF4@18BD@061TD018C3P092PD03a0;00h?2P0?40/0414<014B3@804Q<>00L051D@04]<
A`0K71L03Pl:01LH4`0E5Q4030d800803Pl:00D0414<00l@2`0=3PT02``700l@2`02018C3P0?00l@
2`0A4P`05AP?00`?1@0A50d06A/G00D7100Q8b802`d<00X<2P0?4@h06A/E00lB2P0A50/04aH?0080
4Q@?00l04A<>010B3@0@4Pd03Q0;01@F4@0A4`h061XE00h@2`0B5A40?40o020V9P0C6AT0310?00T=
300A4a000`0A4Pd02P0B4@`051<>01HE400>3`/04Q@A01/M6P092`P04aDB01LI5P0C5A82018D4@06
01@F4`0F61D051HC018F5@0A5A@04QHE0P0A5A@00`0G6aX04aLF018F5@02014E500J01<G5P0D61L0
3a<B01/O7P0S9bH051PG014F5@0A5aD06B8O01<L6@0G81d04QdI00XE4@0E81`051XH01`R800A5aD0
6AlM00hD4P0F71X06R0N01LM6`0;4@l06AlM00dC4@0J81h601LM7@0a01TO7`0F71`05A/K01PN7P0K
8B40728R01TR8@0C71/05b0O01DO7P0P:RT04Q`K01hZ:00G9R<04b8O01TX9@0E924072/X01`X:00W
=CD07bd]01XX:00L;2/08C4`02Ti>00V>CL07C0^020c<@0U>3H09cXi02Pl>`0/@3l0;T9203=7B00h
CDh0?eEG04EMG`1<I6H0Df]^05M`M01KM7P0H7Un065jO`1RNh00GgQm05M`M@1@JFh0BF9W04QQIP02
04MPI@0@04]TJ@16Gf@0>EAH03MCE`0fDUH0=U1E03E>D`0dCE40=e1D03Q@D`1>HfH0;D9303Q=CP13
F5T0<TQ60357A@80<TQ60100<4I40357A@0dBTP0<TQ603=9A`0dBTP0<dU703I<BP0`AT<0<DM403Q>
B`0fC4T0<DM403M=BP0_AD80<TQ50P0fC4T0NP0gCDX0>U1=0314A00`A4@0=T]803I;AP0aASh0<TPl
03I<@00_ACP0<4Hj03U>AP0eBT@0<4Dl0395>@0aACH0:clc02Pl<P0lD4P0=4U203=8@`0dBT@0>U59
041GCP0oET/0>51303E?@P0gDDD0>UA903]DCP0lEE40?EIC045JE`0nEe@0BF9O045JEP11FUD0?EI@
03mID00kDd/0@eYB045HD012F4l0FFiU05Q]I00lD4H0>dm4041DB@0iCD80?U9703]@B00nDdX0?558
03A:?P0_ACT0<4Hj03M=@@12Ee00>e1903I:B00kCe00?51?03eBC01RMg00C65J03aABP0dBD80>e19
03iCC00kD4T0>Di703Y?B00lDDX0?U=<03YAA`0oE4/0?E9903iCBP0lD4L0>4a303I:@@0dACd0<d@l
03A5?@0a@3T0;Sdf03I7@00b@c`0<44m02Ph=`0mCD`0D61O0392@P0Y>CP09SHc02/l=@0U=Rl0:CH^
02D_9`0T;RH08B/S01`V7P0S;2L09RlZ04]DC`2U[Z/0H6UV02Tb;`0V;bh082`W02<b:`0R<BX08C0Y
02@c;00Z=c009C4Z02@_:@0U<2X08R`V01/T7`0M9R408R/W0P0S;2T0:@0P:BH072DR01hW900N9b@0
6R<P01`U8P0/=C8072DR01TR7P0K9R006bLN01XT7P0H7Q`05a/J01TJ7@0N7b@071hS02da=`0]=3`0
;cLn02`e?P0Q:300:C0h01hU;@0N8bP05a`P01lU9`0L824061`K01PJ600F61<04aD@01TL5@0];b`0
6adJ01@F4`0M7a`06A/H01PJ5`0G6AH05QPE00<051HC00D05ALD01DE4`0E5A<051@B01<C4@03018B
400701<C4@0E5A<05aLE01HF500C4Q005A4@01HA400201DA400;01@B400C4Q003`h<01<C4@0;2`T0
410>010@3`0B4Q004A0>01<B400B4@l00P0@3`d01@0B4@l051<A01@C4@0C4Q004Q4?008040l=00@0
40hA00l=400?3A003`d@0P0@3Q403@0A3a803P`?01/I700>30l04@lB018@4`0>30l0518E01/I700D
4QD03@/>014?4P0?3A000P0A3a8300h<3`0@00`<3P0?3a403Ph@00/;3@0<30h03`lA028R901oOh40
71`N00`<3P0=3@l04@l@010<3@0?2``03PX;00l;308040`=01h04Ph?00/7200?2``04Ph?03Te=P0@
30d04@d>00d92P0?2``03PX;00d92P0G4a@03`/<00X61`0?2``040`=00h:2`0>2PT03PX700h:200=
2@L030P500`81P0D40h05A4>014=2`0E4@l05A4>010<2P0>2@P300l92@0@00h8200?2@T04@/;00/5
1@0=1`L04P`<00h8200?2@T030H600h8200^:2P05Q0@018<300:10@06Q@D01dG5`804P`<00T03PP8
00`61P0;1`H03PX900l;2P0;1`H02PH500h8200@1`P00P0?1PL00`0?1@H040H70147200<01052@80
4@H:100@1@T01P0=0PH040D900h31`0=0PH040D901462QCooooo000Kooooo`0>00/D6`0e?T<02Q@F
00072@0A61H04aTE00hC3`0?4`l0418?014A4@0B4A804Q0C010@400>40l200d?3P0<00h@3`0?4A00
4A<B00h@3`0<3Pd03@l>00lA400A4a8030h=00/=300<3Pd03Q0?0P0?4A001`0:30/05aTH018D4`0C
5A@05aTH018D4`0?4@h0100>40d02`0=3``030h;01<E4P0D5Q<01@L400`>2`0?4@h03Q0=00d?300<
3P/03@l<00<03Q0=00H03@l<01@F4`072@H05aTF00/=2@0=3`X200/=2005010B3@0N81/07R0K00lA
300>40/00P0=3`X01@0>40/03a4<00h@2`0>40/03@l:008030h90P0=3`X00`0>40/03a4<00lA3002
00lA30<03Pl:00X03@h9010A300C50l0414<00@5000C50l05AHA00T:1@0@4@`03a0;0`0@4@`02@0?
40/0414<00h?2P0>3`X04Q<>01<D3`0@4@`02@/600/=200200T;1P80418=00<02`d800h@2`0A4`h0
0P0@4Pd01`0C5A004a@?014B3@0=3PT02``700`=200>3`X00P0A4Pd04@0@4@`03a0;00l@2`0@4@`0
3a0:01HG4@0L7AL04a@>00X;1@0?40X0004001LH4P061`406Q/E01`M5`082@<02``6008030d700H0
2``600d>200A4P`03@h8010A2`0A4P`3018C3@0<01<D3P0I6Q@06AXD00l@2P0H6A<05aPB01PI4`0=
3PP02``600d>200;30H02P/50P0<3@D08`0B4`/04Q<=00h?2@0>3`T03Pl:00d=2`0>3P`02PX8018B
400?3`d04a@?01@E400A4Pd030d8018C3P0H6A@03a0;018C3P0C50l0414<01@E40092PD03@h900T:
1@0;30L03Pl:00H70P0=3PT04a@?01HG4P0?40/05AHA010A300<3@L03a0900803a080`0?40X01P0>
3`X03@d;010@3P0B4Q00410>010@3@<04A8=0P0@4@`01@0=3PT00@8000T:1@0<3@P03@h9008051D@
00<04A8=010A300@4@`00P0?40/0100H6A@0DeA?01DF4@0?40/200d>2@0700h?2P0A4Pd04a@?00l@
2`0<3@P0414<018C3P0400l@2`0>00h?2P0C5Pd020/2014D3@0U9b804A<>01hP7@0D5Q<0H69O05EG
D`0:3@H03a8;01PK4P0A50d2010B3@803a4<01003Q0;018D3`0@4Pd03Q0;01@F4@0C5A004aLB030d
<`0C6AL02Q0>00X>3@093@`04aPD00/=2P0=3``04A<>0P0D5A003P0B4`d03Q0=01PJ5`0I6aP03Q0=
01DG500B51405ALD01<E4P0B514051HC01<E4P0A4a0041@C0P0D61L02P0C5aH051PG01@H5`0B5QD0
4ADD010D4`0A5A@04aLF01HJ6@0P92<201<G5P0E018F5@0H7A/03aDC00hG5017D4d03AHC01LR7P0J
9B404A`H01XP7P0F71X03aDC01<I5`0B61H05Q`J01@J600A5aD06R0N059HEP0N92803aDC00805Q`L
100E6a/03@0K8B4061hN01HL700F71`061hN01TO7`0L9B@04a`K04I?CP0P:RT04adL024[:P0G8b40
0P0F9B809`0N;BX06RTV020_;00I9BD082h^024_;`0W=CD0830_028b<@0O;bh04B@R02@g=@0^@Cl0
9CPf02Pk>P0U>CP09c/j02/o?`0aADH0=T]<03M>C`0jDU@0@EUK04ENH@17H6@0C6EY055ZKP1CK740
E6eb059[L01;I6T0AUmT04AMHP16Gf@0@EYO03iGG019HVL0Af1U03YDF@0203EAE@0Q03E?D`0eCU80
=4eA02m8B`0kDeD0=DY<02i3A00bAdP0;T=402To?@0^A480=4Y80357A@0]@d40:Clm03A:B00eBdT0
=de;03Q>C00iCdd0>U1>03]ACP0eBdP0:d4n03eCD01@IV<0@eUF02m5@P0fC4T0@5IC045GE00lDTl0
=Ta90080<DE404d0=T]703I;AP0`ACh0;d@j02a2=P0Z@3@0;dDi0315?00_A3`0<dPo02e1=@0_@cH0
=d/o04AHC`1IKFD0@EIA0399@`0gCTP0>U5903QBB@0iDdP0?EM<03E?@P0iDdL0?EM<03mHDP10FE@0
?eQE06IoO018HEh0=e1=03aED@0jDdh0B65K03UCBP0oF4l0?5=;03iEC@10ETd0<DHm03I;@P0hC480
>4a103Y>@`0lD4D0=d]003U>AP0gC4<0<dPo02m5>@0bB3`0=D/o03U?@`16Fe@0A5UB03a@CP0jCTl0
>Ti=03]@BP1cR840EfaU03eBB`0`ACh0?E9;03aABP0hCDH0=T]403M<A@0kD4T0?E9;03]BB010ED`0
?E9903aAB00hC4<0<dLn0355?0020352>P0h0393>`0b@CX0<D0i02dn=00a@SP0=TM002dm>P0`@3d0
CemM04eMFP0T=340834Z03Y;@@0/?C<09S@Z01lY800S;B@09BlW024[8`0U;bL09BlX01lX8`0i@Sl0
;CHc02</:@0Q:RL08RhY01h]9P0A81T0;3/d010O600K:240:cL`02@_:@0R;BL072HP01`U800P:B@0
8R/W024Z9`0P:BH07BHS01`U8P0O:2D0QXn<024Z9`0F7a`07RLT01/T8@0I8Ql07BPR01/V800J8b00
6AlO01PN7P0G6ah201@G700C028V;00O9Rh07RD]01TR:@0D6b<08BP^01lW:`0N8bL05AXN01PM7`0I
7Ah05ATH01LI5P0G6A@05QPC01hP6`0o@Ch08B<P00lA3P0201hP7@0301XL6@0G6AH05QPE00<051HC
00l05ALD01HF500E5A<051@B01<C4@0A4@l0410>014A3`0B4Q005ADC01PH5P0F5Q@04a8@01HB4@0G
4Q400P0F4Q403P0E4a4051<A00h=2`0B4Q001`L501<C4@0F5Q@020P6018A3`0C4Q004A0>00l>300@
3`d04Q4?0P0C4Q001@0A40h040l=00h=2`0>3@/040hA00<03P`?00H03`d@010>4@061@L05A<F00l=
400;2@`200P62@0=010>4@0D4QD05Q@G014?4P0?3A004a4D018@4`0@3Q403@/>00`:3@0?3A004a4D
018B500200`<3P0D00h>400=3@l02`/=00h>400000805aLI00X:300I6A/0518C010<3@0>2P/03@T:
00h:2`0@30d04Ph?01<?400;1`P03`/<01HB4`1;AdP201DA4P0901HB4`0H51D06ADF02DQ8P0_:b`0
5a<D00l;300A3@h03`/<008030P901<03PX9010<3@0>2PX03@T800l;300=2@T03`/:014=3P0>2PX0
4@d<00h:2`0;1PH040X:00l92@0>20P03`T9010:2P0?2@T03@L700803PP801403@L7010:2P0?2@T0
2P@400H10@0>20P0208200`61P0@2PX050h>00/51@0?2@T03PP8010:2P0=2@P03PX900l;2P0200h:
2@07014;2`0@1`P03`H700l61`0?1@H040H70147200601052@803P<7100?10P601052@803P<700@0
2`0400T00P0>10L06@hB5?ooool001_ooooo00h051hP00LA4`0H8R<06R<R00TA3`052`T0314=00dA
3@0?4@h0410@018A4P0A4A<04A<B010B4@803a4@00L0418A014C4P0=3`h030h=00X<2`0;3@`030h=
00803@l>00<02`d<00`>3@0?4A000P0?4A003`0E5aH03Q0?00020@0;3@`0004001hP7`0>40d030h;
00d?300@4Pl03a4>00d?300@4Pl030h;01PJ5`02018D4@0E01@F4`0=3``03Q0=00/=2P0=3``03Q0=
00`>2`0A4a002`d:01DG50082PL0828O00L91@0;3@P03Q0;018D3`0@4Pd051HA01HH4`0?4@`03Q0;
00803@l:100>40/0100=3`X030h900`>2@0<3PT200d?2P0A00lA300@4Pd0418=014B3@0>3`X03@h9
00h?2P0<3@P0414<01<D3`0A4Pd01`P3010A300A4Pd020T4014B3@0?40/00`0@4@`0100?40/03@h9
00h?2P0?40/2010A300@018C3P010`005ALB01hP6`0=3`X02P`700h@2`082PD02`d800lA300=3`X0
30h9010B3@0B50l04A<>00l@2`8030d800@03@h9018C3P0B4`h04A8=0P0@4@`0400A4Pd04A8<014B
300E5Q0051D?00d>200A4P`04a@>01@E3`041@002``600P90`061`403a0:00d>200?40X200h?2@0?
01@E3`0:2`D03Pl9010A2`0?40X0414;018C3@0=3PP06Q/E01/L5P0@4@/06AXD01LH4P0:2`D02``6
0080414;02T03@h8014B300?40P03a0801@E3@0E5Q004A8<01<D3P0:2`H03Ph<01<C4@0@40h04Q8@
00X:200>3`X04A8=010A300<3@P03@h900l@2`0>3`X03a0;00T:1@0=3PT04a@?00/<1`0D5A003@h9
01PI500A4Pd020T401/L5`0F5a803Pl:00X;1P0Z:bH092DP00d>200@4@X03a0800h?1`0200l@2P07
010A2`0@4@`03@d;014A3`0D51804A4?010@3@03014B3@80414<00D06AXE0083000J6aH05aPC00l@
2`04014B3@0Q010A300>3`X03Pl:00X;1P0V9b801PL2018C3P0?40/03Pl:01<D3`0E5Q405aPC010A
300:2`H03a0;01DF4@0@4@`030d800d>2@0?40/03@h901<F3`0E60l03Q4:00`>2@0E5a802P`900`>
2`0b=340<cD`00`?200520402@`500H03a4<01@05ALB00T;1P0>40/010H100/=200B50l05AXF00D;
2@0;4@l041@C00lC4P0?51003Q0=010B3`0E5a805aPC01HG4P0C50l04Q@A01LI5P8061XG00@05QPE
00lA3P0F61D051HC0P0C5A801`0B5140418?00dA400C5aH04ADD010D4`0C5aH0100A5A@0700B5QD0
51PG01@H5`0?4a803Q8A01<G5P0<40l03Q<A00X@3P0:4a00?4E200L@3@0E81`041/G00/F4P0M8b40
4aTG018H5P0D6QP05A/I01HL6P0B61H05Q`J01XP7P17CD/0728P014G5@0D6QX501DK6`0N01HL700H
7Qh05adM01LM7@0J8200728R01PQ800F7ah0FF9Q02La<00>61L07bTX01TU8`0H9b@05bHS01d/:@0F
9B806bXW01dY:@0L:RX08S0`02Le=@0K:bX06RXY03U9B00fBDL09STg01lb<00M<2h0:chm0P0X?3/0
2@0[?cl0;d=40356A`0cBT/0>E5C03mGF@12FUd0@U]O04IOH`0204QQIP0;04YSJ01;I6T0BF9W04MP
I@14GF80@EYO03]DF@0fCe@0>E9G03M@E@0dCU<00P0dD5@07`0eCe<0=DiB03A=D@0cC4l0@UYL03A9
BP0iCTl0>4e>02m4A@0]@d40<DM502i4@P0X?S`0:T0n02m5@`0fC4X0>Dm=03Q>C00fC4X0=de;03A:
B00bB4D0=Ta902m5@P0kDDh0DVQU04eSH00hCT/0>U1=03aBC`0jD4d00P0hCT/0:@0fBTT0=DU803U=
B`0hCDP0<TM00397?`0]@ST0;T@h0398?00]@ST0:Slg0397?P0_@cL0;T8e03Q<@@11ED`0Bf1J03A9
A00`Ad40>e9<041GD@0jE4/0=e5703QBA`0fD4<0>E=703eGC00oF580@5UE03mHE@1AJVL0@5UF03mH
E@1AJVH0?5E@049KE@13GE@0AUmF03U@B00lDd/0@eUA0080:d0g02T0>e1603]?A00iCD80>Ti303=7
?00gC4@0<DHm02i3>P0aAc/0=Ta003U?@`0kDDD0?U=<03aABP0jCT`0?51A03mCDP0jCdT0CfAM041E
CP0mDT/0>Tm803aABP0mDT/0>Tm803U>A`0jCdP0?E9;03mDC@0mE4X0?eA;03]@A`0iCTD0=DU00314
>`0_@cX0<D8j0393>`0cA3`0=4<l03A4>P0203=5>@1:02m0=`0V=c40;3dg03e=B@0lCDL09CH`02`m
=00gBCd09SP/02Hd:P0T;RD0:C<Z02Xd:`0R;2@092hV028/9@0J8ah0:34^02`e<P0G81d0;SLd01PT
7P11D4T0:CPa028a:P0P;bP0;CXc02@`:P0T;bT07bXT01XT7P0O:2<08R/V02</:00S;2T08R/X01dV
8`0J8b0072DR06]dL@0N9b@07bPU01<L6@0R:bP08BXW01/V800I91h06B8O01/Q8@0J82006AdP01TL
8@0F6Ah08BH/01XQ:@0G7RH03aPN01HM8`0N9RT072@W01XO8`0D6A`061hN01DI600B5QD05ALD01HH
4`0D5Q406adH01dO700F61D05aTF01PJ5`0C5A8201LI5P0601HH5@0D5Q<051HC01@F4`0E5a@051@B
0P0F5Q@00`0E5A<04Q8@00l?3@0201<C4@0601DE4`0F5Q@05ADC01<B400C3`h050l>0P0C3`h0200B
40h04A0>010?3@0@40h05aLE01TI5`0<30X08b<Q0P0C4Q00100@3`d03Pd;010?3@0C4Q02014@3P05
010?3@0?3P`03Pd;00h=2`0?3A000`0>30l200l=400501TG6P0>30l02PP;01@B5@0F51L00`0?3A00
5P0>30l03@/>00h<3`0@3Q404a4D00h<3`0:20/02@L:00l=400D4QD05aLI00h>400<30h03@d?00X:
30061PP04a<E010@4P0=3@l01`L900<31@0;20X200l;300600h:2`0?2``03`/<010<3@0D41403PX;
0P0A3@h0300Z9RL020@500l;300?2``02@D600<0000:1PL07ATJ018>3`0=2@X03`/<00d92P8030P9
00`03@T:010<3@0>2P/030P900h:2`0@30d0510A01DA4P0>2P/040`=01<?400@2``5010:2P03018<
300@2PX03PP800803@L700d03`T900d71`0B30`03PT901<=3@0400003`T900P20P0=1`L0208200h8
200=1`L03`T9008030P70`0=2@P01`0>20P040L800l61`0?1PL03`D601061`0A1`P01P0@1@T700l4
20<040D90P0A1PX01P0B1`/040D900h31`0=0PH04@H:01dB5QCooooo000Kooooo`0:00/D50084100
41TG01<I60093`d03Q@B00dA400>4A003Q0?00h>3P803@d=00L0418A00lA400>40l03Q0?00lA400@
4Q403Q0?00@03a4@00@03Q0?014C4P0<3Pd030h=0P0@4Q402P0?4A003Q0?01DG5P082PT051HE00d?
3P0@4Q403@l<00/=2P0=3``2014C400700lA3P0:30T03@l<00lA3P0;3@X04A<@00T;2002010B3`0?
00`>2`0>40d04A<@00h@3@0@4Pl01`T601/M6P0H6QL0?T0m01<E4P0<3P/03@l<01<E4P0?4@h03@l<
0080418?00D03Q0=00d?300=3``03@l<00h@300200h@2`0300d?2P0<3PT030h900D03@l:00d030h9
00h?2P0=3PT0414<01@E400>3`X03@h9018C3P0@4@`02P/600d>2@0A4Pd03a0;0080414<0P0A4Pd2
010A300:00l@2`0B4`h04Q<>00/<1`0:2`H04A8=00L9100H6QD06Q`G00/=208030h900X02`d800lA
300C5A003Q0;00d?2P0A4`h03A0=00`A3@0>4@h03A4<0P0>40/00`0A4`h0418=010A2`0300l@2P0C
01<D3P0;30H03a0:01XK5@0B4`d03@h801PI4`0=3PX04a@>00l@2P0?40/04A8=01@E3`0@4@/04Q<=
014B300?40X05aPB00`=1`02010A2`0400d>200<3@L03Pl900/<1P807QlI02D03Pl901<D3P0=3PP0
30d700l@2P0D5@l04A8<00`=1`0@4@/04Q<;00l@200C50`051D?01<D3P0F5a404Q<>00d=2`0A4@l0
410>01@D4P0<30X03Pl:00l@2`0A4Pd04Q<>014B3@0?40/03Pl:014B3@0:2`H03a0;010A300?40/0
3@h901LH4`0720@03a0;008030d800L03a0;00`=200>3`X07AhI01HG4P0A4P`04A8;00803Pl700T0
3Pl9010A2`0A4P`04Q<>00h>300C4a405aLE01<C4@0@40d00P0@4@`02`0?40/03Pl:00h?2P0;30L0
5QLB00T:1@0A4Pd020T401LH4`0?40/03Pl:00803a0;0`0@4@`0300=3PT0414<018C3P0F5a8051D@
018C3P0@4@`04Q<>01@E400C50l04Q<>014B3@80414<00D04A8=010A300@4@`03A09014D3@0200lA
300800h@2`0_<B`030h900`>2P0@4Pd04aD@01LI4`0?4P/200h@2`08010B3@0A4`h04Q@?01<E400F
61<03Q0;03Li=00B50l2014C3P06010E4@0;40`041DA00/@300A5Q804QLC0`0@5A402P0A50l04AD?
018D3`0G6AH03a4>01XL6@0C5A8051HC014C400D5Q<2018D4@0;01@F4`0E5a@04aDB00`@3`0B5QD0
3Q8A00dA400B5QD041@C014E500B5QD00P0D61L06`0C5aH04ADD01DI600B5QD05a/J018F5@0F6aT0
4ALE01DN6`0@6AH05QlL01HQ7@0X<bl08B`X01hT8P0G7A/06b4O01<I5`0E6aT05Q`J01<I5`0P9R@0
3aDC01LM6`0@5Q@06R0N01DK6`0201HL708061hN02X06AlO01HL700J82006R0P01LM7@0F71`05adM
01TR8@0B6aX0;cPg01TS8P0L9RD06bDT01dY9`0G9R<052<P01TX9@0E924072/X020/;00I9bL08c4a
028`<00L;2/0830_06MgMP1RMG<0:C`j03A7A@0/?cd093Lf02Hj>@0X?3/0;D510355AP0aATL0<dU;
03Q@DP0lE5H0?5AG03UBEP0jDeL203aEFP0303eFF`0oF5d0@EYO0080@eaQ00H0?UML041IGP13G640
>U=H03M@E@0hDUH203A@D`0603A?DP0eCe40=4i?03M@DP0]ADH0>4e>0P0[@Cl0200/@T00:Clm0316
A00_AD<0:T0n02m5@`0gCD/0=4Y80P0hCT`02P0fC4X0>Dm=03I<BP0/@Sl0<DM403M=BP0fC4T0=de:
03eCD00hCT/203U?C080=Ta904L0>4i;03U=B`0hC4X0>De;03I;AP0aAT00<dQ103=8@00_A3/0<DHm
03=8?`0aASd0=4Xn0355>@0aAST0>e5503A9@@0gCDH0=Te704=IEP0mEE40=e1:03QABP0iDdX0>UA9
03I@@`0hDTH0>UA903]DCP0mEU40?EIC04IOG012FeP0DFYW076:QP16GeX0@U]E03mID010FE00@eYB
04IME@11Edl0=T]203U>A@0hCD<0@5A903mCB00gBd00?E5603Q=A@0`AC`0<DHm03U?@`0jD4@0>4i2
03eCA`0mDT/0?eA=03iBD00gBd`0=DU803iCC@0jCdP0?U=<03Y?B012Ee00?U=<03Y?B00iCTL0>Tm8
03]@B@0203aABP0O03iEB`0nDdX0>4e403E:@@0cAch0;T8i02m3>P0cA3`0=4Dm03E6?P0gASl0>DTo
03E7>00bA3H0;d4e02/l<`0/?CD0:3Tb02`m=@0X>C00:C/_03=5=`0`@S<0;3X^024[8P0T;RD08bdT
01dW7P0Q:b<09BlW079lM00202</9`0?01`U800P:BH08BdX05QWH00d@c`082lX01`[900Z=c0082`U
02@_:@0O:R@07bTS02Pa;00V;bX07RLS008082TV00X07RLT01`U8P0N9b@06B8O01/T8@0Q:RL07bPU
01PQ7P0K92406R<P0P0G81d06@0M8b<07R@T01`Q900H7B405AXN01lT:00J8BL072<Y01/R9`0A6A`0
8RX/01TR8`0C6AX06R0P01<I600G6aX05ATH01TK600G6AH04aDB01LI500C5A805QPE01LI5P0E5a@0
0P0F61D00`0G6AH05QPE01@F4`0201@F4`0301DG500B4Q005QHD00806ATG00D051@B00l?3@0G5aD0
51@B01<C4@0201DE4`0301<B400D40l05A0?0080510?00@04a4?018A3`0D4a405aLE0P0>3P`02@0K
6aT0ADE301<B400C4Q0040l=00h=2`0@3`d051<A014@3P05018A3`0300l=400>30l03@/>00803P`?
0P0?3A001P0>30l06QPK00d;3P0@3Q403P`?014?4P803P`?0P0A3a802@0>30l040hA00h<3`0<2Pd0
2PP;00d;3P0@3Q4040h?00h<3@0200`:2`0400h<3@0A3a0030X;01<A4P<03P`=00P03``=00l;300@
30d04@d>010<3@0?2``03PX;01<?40803PX;01`04`l@00T51P0?2``04`l@014=3P0B3Pl02`L800L3
100A3@h03`/<00h:2`0?2``02`L800`82@0?2`d04PdA01@?4`0@2`l02`H:00d8300>2@d03@P<00h9
3@0=20`030L;00d8300>2@X03`T90P0B30`05@0A2`/03`T900l92@0>20P03@L700l92@0@2PX030H6
00l92@0:1@D04P`<01D?3`090`<03PP800/51@0A2`/030H600l92@0=1`L02`D500d9200400`81`07
00`61P0@1`P03`H700l61`0?1@H040H70147200601052@804PL;00@04@H:01052@0?10P03P<70P0?
10P201052@<04@H:00D03P<701872`0B1`/03P<701872`0Dooooo`006oooool030042PP03Q@A010F
500;4@l03A8@01DI600C5aH041@C00lC4P0?4A003Q0?01DG5P<0418A00@03a4@00h@3`0<3Pd03a4@
0P0A4a802`0@4Q404aDD01DG5P0C5A@04Q@C00`>3@0:30/03@l>00/=300=3`h03Q0?00<03a4@00<0
3Q0?00h@3@0>40d01@0>40d06P0A4a003a4>00h@3@0@4Pl04A<@01XL6@0>40d030h;014C40021040
6adJ00/=2P0I6aP0S8j;02LY9P0B51403Q0=01HH5@072@H0418?018D4@010`003@l<010B3`0?4@h0
30h;0P0=3``0300=3`/00080010B3@0T9R80418=00h@2`0C5A001@L201XL5`0D5Q401`T401PJ5@<0
2``700`03a0;00`=200<3@P03a0;010A30092PD03Pl:00`=200T9B003a0;00d>2@0B4`h200L80`L0
3a0;01P04A<>010B3@0>40/030h900d?2P0>40/030h905UKEP1YJfH03@l:0043000i?CL03A<?00`B
400;4@h0318>01HK5`083@L030l800d@2@0A4P`04A8:010A2@0?3`L201<D3P0800`=1`0=3PP04Q<=
00X;1@0=3PP0414;00`=1`0:2`D200l@2P0500h?2@0@4@d00`@000X;1@0B4`d00P0>3`T300l@2P05
00h?2@0<3@L03a0:00/<1P0<3@L00P0A4P`0900;30H0414;00l@2P0=3PP03a0:014B300=3PP03Pl7
014B2P0?40P03@h8010A2`0E5Q006AXE00d=2`0;2`T04A4?00`<2P0D51804a@?014B3@0?40/03@h9
010A300B4`h0414<018C3P0=3PT0414<01@E400@4@`03Pl:00l@2`0>3`X030d800h?2P80414<0P0D
5A004`0A4Pd03a0;00l@2P0<3@T0414901HG3`0=3PP0414;00h?2@0?40/0410>01<C4@0>3P`03`l=
014B3P0@4@`04Q<>01<D3`0B4`h00P0@4@`03`0?40/061TD00h?2P0E5Q403@h901<D3`0J6aH03Pl:
00`=200E5Q404Q<>01@E400B4`h04a@?010A300201<D3`0E010A300C50l05AHA01LH4`0B4`h03Pl:
00l@2`082@@051D@00`=200@4@`03Pl<01DG4P0>40/03a4<01DG4P0A4`h041<<00lB2`062@807R0K
00803@l:00H04A<?04]=B00[;BP0418=01LI500F61<200h@2`05014C3P0E5a8051HA018D3`0A4`h0
0P0<4@/03@0>4`d03Q<?00lD400@5A403aDA01<I5@0>510041HB00dC3`0<4@d030h;01LI5P0>40d0
0P0B51408`0C5A803Q0=01<E4P0I6aP05aTF014C400C5A804QHE01`P7`0?4a804ADD00hB4@0O8b80
720O00`@3`0D61L03A4@01<G5P0E6AP051PG01<G5P0B5QD04aLF01LL6`0J81h06b@Q00hG500I8Ql0
>TE1079mN@0U<2`04QPF01TO7@0J81h05adK00806R0N00H06AlM01LM6`0@5Q@051XH01XP7P0G7A/2
01HL70805adM0P0E6a/0400L8R806R0P01`R8P0N92@06AlO01DK6`0J8b805b0O01DN7@0G8B0072HU
01lY:00J9R@06BPU01XY9P0K:RL201`[:00G01TU9@0H9RH07R`/02Dc<`0O;bh07Rh]020`;`0K;R`0
7C0^028e<`0T=cD09CPg02Lk>P0bATD0>De=02/o@00^@d@0=D]=03A<CP0gCe40<d]>03M@E00lEET0
0P0gD5D0200mEU/0?eQM045JG`11FUl0?UML03]DF@0lEEX0?eQM0P0fCe@04@0hDUH0<TiA035=D00b
CDl0=4i?03I@D@0eCTh0=4a<03=9B00Z@3h0:3hl02i4@P0Y?cd0;D=10357A@0_AD<0;TA20080<TQ6
00/0:T0n0398AP0]@d40<TQ60357A@0[@Ch0<dU603Y@C@0dBTL0=D]804AJE`0203]ACP1203Y@C@0h
CT/0=Ta903E;B00/@C`0AU]F03A9A00`AD00;44l0766P00^@c`0=da502a1>00`ASX0=D/o02a2=P0e
Bch0>Dm203iDB00hCdL0=Te604AJE`10FEH0?5EA03YCC@0jEDh0?UU@03iJCP12G4l0?UQ<03A>@`12
FeD0?EIA03aEDP17H5d0@U]H041IEP13G5P0@U]F03iGD@12G5<0@e]C049ID@0oETh0>e5903Q=A00j
CdH0@eM=04QLD@0[?c@0?E56061dJ@1=HUX0?U=:03Y?AP0hCT80>U1403mEB@0lDTH0AU]D03aABP13
EeD0=TY;03M;BP0mDT`0?U=<0P0oE4d203eBB`0W03aABP0fBd@0=DY303Q=AP0jCdP0>e1904IMD`0k
D4L0>4e403U>A@0dB3l0<4@k0396?@0]?SH0<44i041AB@0iB4409cL]03=5=P0a@cD093HY03Y;@@0d
ACd08S<[02`m=@0cA3X0>T`o03I8>P0]?bl0:CLY02dg;00Z=2T07RPN01PR6@0O:B00:38Y02@^9P0N
:2007RLQ00808BXU00h08BdW02Dd;@0R<BX06bXS01h]9P0Q;RL07RXT038m=`0R;BL07bTS05MPF`0Y
<Rd07bPT01lX9@806R<P0P0L9B800`0V;b`08b`Y020Y9P02020Y9P0>01hW900I7al04ALG024W9`0=
5AL0A4a>049:C00K8bD06B4S018J7@0K82@082DY01/P900I8B<201@M700501/Q8@0M8b404QPF01`P
7`0D6AD00P0A4a00100W:BH04aDB010B3`0E5a@201TK600@01XL6@0E5a@04aDB01DG500F61D05ALD
018D4@0?4@h061PF014A3`0E5A<04Q8@01/K6@0J6QP04A4?01<C4@805ADC00@051@B01<B400B3Pd0
5A0?0P0E4A00500C4@l040l=01DD4P0D51800P8001PH5P0B4Q00410>00`;2@0F5A<06aXH01PG5@0A
40h03Pd;01DD4P0C4Q0040l=00l>300920H051<A0P0?3A0200d;3P803P`?00D040hA00d;3P0>30l0
5A<F01<A500200d;3P0=00h<3`0A3a804@lB018@4`0F51L04@lB01<A500A3a802@L:00H41`0<2Pd0
40h?00h<3@0500d;30803P`=0P0?3@h0100@3@h040`=00l;300>2P/200l;30803PX;00<040`=018>
3`0@30d00P0>2P/200l;300@00h:2`0=2@X03@T:00P51@0J5QL06ADF00/7200D41400`0001@?4P0@
2`l04PdA01@?4`0B3A4040/?00l:3P803PT=01@03@P<00`72`0<1`/03PT;00`61P0@2PX04P`<00d7
1`0>20P04`d=00l92@0;1@D03@L700l92@0@2PX030H6010:2P070P805@l?00X410L03PP800L04Ph=
00h:2@0:1PD03`/:01<?3P0>2@T040L800803`H700T03`D601061`0A1`P09AXN01@93@0J41<01`00
01H;3`0;00@01P0?10P201462P0400l4200@1@T04@H:00h31`H040D95?ooool001_ooooo00d02a8;
00hE3P0?5A403A<?00dB4@0?4a804aLF010D4`0?4a803a4@00h@3`0E5aH03a4@00@0418A0P0>40l0
1`0?4A003Q0?00`>3@0=3`h03a4@00d?3P0@4Q400P0<3Pd00`0?4A003@l>00d?3P0200h@3`<03a4@
1P0?4@h02`0:30T03@l<010B3`0B51403a4>00/=2P0?4@h02P`902<U8P0:2`T05QPE0080418?00/0
10H304I8A@0:30T04A<@00lA3P0620D07b4N01HH5@0B51408bDR00d?3002010B3`0@00d?300@4Pl0
418?00lA3@0>40/07b4L038d;`0N81/04Q@?00`>2@000@007b4L030b;@072@@030h9014B3@8030d8
00l0414<00h?2P0?40/0414<014B3@0<3@P03a0;018C3P0/;BP051D@00P9100=3PT04Q<>010A300E
5Q401P0?40/04P0A4`h0418=00h@2`0=3`X03Q0;010B3@0<3PT0>3Xe04]=B00D5Q4020X500`?2`0<
4Q0000P5010H5@073@T04ALC00T>20803Q4:00H03a0900l@200?40P0410800h?2@0=3PP200h?2@06
00l@2P0C50h030d7014B300=3PP030d70P0A4P`03`0S91h03Pl:01<D3P0G618010D0018C3@082@<0
2P/500d>200@4@/04a@>01DF400A4P`03@h800l@2P0201<D3P803@h800`0414;00l@2P0?40X04Q<=
014B300=3PH0414900l@200=3PP03a0:018C3@0>3`X200h>300;00l?3@071`D04A4?010A300?40/0
3@h900/<1`0=3PT03a0;018C3P0A4Pd00`0=3PT07P0;30L04A8=014B3@0@4@`03a0;010A300B4`h0
3@h900h?2P0=3PT030d800l@2`0A4P`061TB000100061`004Q<=01dN600<3@L03Pl:00`<2P0A4@l0
3`l=00d=2`0>3`/03a0;010A300A4Pd0414<00l@2`803Pl:00/061TD00h?2P0E5Q403Pl:00l@2`0>
3`X03a0;01HG4P0D5A003@h900h?2P02018C3P03010A300C50l04Q<>00803Pl:02004A8=018C3P0@
4@`03@h900h?2P0=3PT05aPC01@E400`<B`0;2dX014C3P0?4@`05QPC01dO6P0F6A803a8;01DH4@0?
4P/0MGMb06maK00I6aH04Q@?07n1O01BE4l05aTD00L910092`H051HA00lA300A4`h051HA018D3`80
4A<>0P0@5@l01P0?50h03Q<?00dB3P0=4Ph010X600lE4@8041HB00X051XF01DK5`0E6QH04A<@00lA
3P0G6AH0418?01PJ5`0C5A803a4>0P0@4Pl00`0G6AH092HS01TM7002010D4`0;01@H5`0J7Qd05QXI
00D9200J7Qd02@d<01LK6P0E6AP061`K01LK6P0E6AP00P0C5aH05@0E6QP05adK00PA3P0F7a`0:c@a
086<R03]mo@0IW5]030f=00J81h08RPV01HL6P0L8R00318@01LM6`0F71X04ALE01@J600H7Q`05A/I
01HL700301LM7@805Q`L00<05adM01HL700J82000P0O9BD02`0N92@0:34`028[:P0N9bH072HU01hX
9`0O:BP062@R01LV8`0H9b@06BPU00806RTV01P082`/01d[:`0R<300:CLg02@d<`0O;bh07Rh]01lb
<00T=cD09CPf028e<`0Q=C<08SHe02Pl>`0bATH0:Sho02]0@@0`ATP0;DE702m7B@0`BD`0<DY>03A=
D@0fCe<203QAEP0F03I?E00lEEX0@EYO045JG`0jDeP0>55F03iGG00jDeP0=e1E03IAE@0cCe80<TiA
035<CP0bC4d0<de<03=<B`0bBTX0<TQ602e3@@0_AD<0>Dm=0316A080<dU700l0;D=102Y0?P0]@d40
<TQ603M=B`0jD4h0=de;02To?@0bB4H0;TA103A:A`0iCd`0=D]803A:A`0mDe000P0iCd`0=@0jD4d0
>Dm<03M=BP0dBTL0A5UD02@i=00aAT40>Di902i3?P1QMW40>Di903M<A@0aASh0;48f0398?00^A3P0
=T`o03E;?`0jCdH0>E1803Q>BP0oEE80?UMD03]DD@0jDdl0>eI?03aGC`0kEd/0AEmD045KC`0gDDH0
@eaF03iGD`0mEU<0@5UF04AMFP15GU/0@eaH045JE@10FE<0?UQ?03mHC`10Edl0?UE=03aBB@0iCTD0
?eA;04EIC`0_@cP0<THk03Q<@@10E4T0@UM?0080>4e40100>Dm303Y@A00nE4P0AE]?0397@01;H5T0
=d]902m3A00kCdh0@EI@03mDC@0nDd`0?eA=041ECP11ETl0>Tm80P0fBd@01@0jCdP0?55:03aABP0n
ED/0>Tm60080>Di500d0=DU00355?00_@cX0;Slg0352>P0oD4P0>TU202`l<P0[?Bh0:cd_02Tk;P11
DTP0?e180080:S/c0140<44g03E7>P0a@cD0:cd]02Le9`0X<RL09S0U01hX7P0H8QT06bDL028/8`0R
;2@082XR024[900U;RT09RlZ02Da:`0202Dd;@0A024`:@0U=2d09c@]028^9`0T;bT05B0J02/e<01/
MG00@4U402Xc;`0X<Bh08BXW01hW900M9R<072DR01lX9@0N9b@00P0L9B802`0K9240624N01PN7P0S
:BT051XJ0418BP3;dmD0Z[:c018J700I8B<07BDX008082DY00L08BHZ01DN7@0F7a`04Q/I01@J600R
:2H06R0N008051TE00<06Q`I01`N6`0F61D00P0E5a@201TK600601PJ5`0K7AX06A/H01HH5@0E5a@0
4aDB0`0B5140200G5aD04Q8@01PH5P0E5A<07AdK01XJ600B4Q004a<A0P0D5180100C4a404a8@01<?
3P0E410201HB4@0<01@A400A40h03`h<01hN700E5A<05QHD00d=2`0F5Q@03`h<01DD4P0F5A<04a8@
0P0A40h0800;2PP03`h<01DD4P0M71X03`h<014@3P0@3Q404Q0C010>4@0?3A004@lB018@4`0E4aH0
71XM01@B5@071@P040hA01/I700D4QD0108500d;3P0>30l02@L:010>4@0610L03@/>018@4`0C4A@0
40hA00l=400@3Pl03P`=0`0=2``0100>30d03@/<00d;300=2``200h<3@0800l<3@0>2P/03PX;00h:
2`0?2``040`=00l;300>2P/3010<3@803PX;0P0?2``00`0>2P/03@T:00d92P0201HB4`0;00L31006
0P<01P8300T51P0<20X030L;00h93@0?2Ph03PT=00`72`0=20`00P0>2@d05@0=20`030L;00`72`0>
2@X03@L7010:2P0B30`03@L700l92@0@2PX03@L700`61P0>20P03`T900d71`0400004`d=01H@4004
000081XJ00`71`0600d71`0300`81`0C3`h04@d<00800`0000`040X:0107200?1PL03`H700l51P0@
1PL04@L800T00P0N4aL0ACXn00l4200;0P@800l4200400d21P0900802`0400l420L040D95?ooool0
01_ooooo00L04QL?00lE300>4`d041D@00hB40093@`04ADF00803a<D00D03Q8A00`A3P0B5a<03a4@
014C4P03018D4`04014C4P0?4A00418A00lA40803@l>00@03Q0?014C4P0D5QD04A<B0P0?4A001@0<
3Pd03Q0?00h@3`0>40l03a4@0080418A1P0@4Pl06`0=3``030h;010B3`0B514030h;00T;200D5Q<0
10H302DW900@4Pl05QPF00lA3P0>40d03a4>018D4@0?4@h030h;01`N700?4A004aDD00`>3@0O8B00
<38a010B4@0B51<04A<B00d?3P0200lA400600d?300B50l03Q0;00lA300>40/02@/60P0<3PT02P0:
30L03Q0;018D3`0>40/04A<>00l@2`0>3`X0414<00l@2`0B4`h201<D3`0:00l@2`0:2`H03Pl:01TJ
5@0>3`X04Q<>00/<1`0A4Pd0414<01@E40H03a0;01T03a4<00h@2`0=3`X03@l:00h@2`0A4`h0418=
00`>2@0B50l02@/600h@2`0J7AX0A4e:04aFE@0[=C<01Pl;00@=200<4`d03a<<00lB2`0>3`L03`l6
00l?1@0B4PP03Pl800804A8<01803@h800l@2P0B4`d030d7010A2`0<3@L02``600l@2P0>3`T020T3
010A30020`002``6018C3@092P@05aPB01@E3`0?40X300d>2003010A2`0=3PP03Pl900804Q<=00<0
3Pl900/<1P0?40X00P0<3@L00`0B4`d03@h8010A2@0201<D300:018C3@0@4@/0414;018C3P0@40h0
3`l=00h>30071`D04Q8@00l@2`804A8=00H03a0;00h?2P0?40/03Pl:00`=200@4@`200l@2`0I01<D
3`0@4@`0414<00l@2`0>3`X03a0;014B3@0K71L05AHA010A300>3`X04Q<>01DF400@4@X03Pl7010A
2@0>3`T06a`F00h?300>3`X030`:014A3`0>3P`02`/900d>2P0200l@2`0?010A300?40/03a0;01HG
4P0L7AP09RLR01@E400C50l02``7014B3@0B4`h051D@020Q700H6A@03a0;00804A8=00D04Q<>00l@
2`0B4`h04A8=00l@2`04014B3@0H018C3P0F5a805QLB01<D3`0<3@P0:b`W024R7@0>40d03@l<010B
3@0B5@h041<<00d@1`0520406QdD04mBB`11@ch04Q@?010B3`0F61<03Q0;010B3@0J71L05QPC0P0@
4Pd01@0A4`h04Q@?010B3@0@4Pd04Q@?00803a@=0`0?50h0=00>51004aTE014H500D7AX04a`I01<M
6@0<5A805Q/G014C400L7Q/09RPU01<E4P0E5a@051HC00lA3P0@4Pl04Q@A01TK600T9R<061`K01HJ
6@0D61L04QHE01@H5`0E6AP03a<B034e=00B5QD06alN01TM701dN7L06QhM01LK6P0C5aH04QHE01<H
5P0D6QP05AhK01XS800L9B80G6MS0:>^ZP0[=S806R0N04iDDP1fO7X05Q`J01DK6@0F71X05A/I01HL
6P0E6aT201HL6P0301<I5`0G7Ad061hN00806AlO0`0H7Qh00`0G7Ad061hN01hT9002024W9`0702@]
;00O:2L06b@S01TS8P0K9B@072HU01XV900201TX9@0<01/Z9`0L:bP072/X01dY:@0I9bL072XZ024_
;`0P<2l08C4`028b<@0O<S008cHd0P0V>CL0I@0V>CP08CDd02<g=P0/@400:cm002]0@@0cBD/0;DE7
02m7B@0jDeH0=4eA035:CP0eCU80=TmD03M@E@0dCE80>E9G03eFF`0nEe`0>E9G03I?E00kE5T0?5EJ
03M@E@0dCe80=51A039>C`0aC4d0<4Y:031:B@0aBTP0<DY70316A00]@d00<4I303Y@C@0cBDL0=4Y8
03=9A`0]@d40:d4o0357A@0jD4h0<DM50398AP0hCT`0=D]903A:B00/@Sl0;TA103=9AP0gCDX0>4i;
03M=BP0dBTL0=Ta903Y@C@0kDDh0>4i;03A:AP0dBD<0Ni2905mdK`0bAT@0<DE303=7A@11EE80;44k
03Y?A`0bB3d0=4Xm02a2=@0eCCl0<TXn03M>A00kDT/0>e=>03YCD00mEU<0?5EB03aFDP0nFE<0>eQ@
03QEBP19HeP0AEmC041JC`16GeT0A5eI04=LF@12FeP0C6ER04mXI@19HUh0AEiI04QQF`0oFE00@EUA
045HD010Edl0?eE=0080?eA;03T0?E5703Y>@`0fBSl0>dm303iBA`0hCDD0=4U003Q=A00lDTH0?E=7
041FBP0oEDT0>e19041ECP13EeD0LhN805EYJ00nDdd0>e1903U>A`0jCdP0?E9;03iCC00iCTL0>4e6
03Y?B00nDd`0?E9;03]@B@0iD4H0>Tm603U>A@0dBD00<4@k02m3>P0[?cH0;d0h0393>`0hBD40=dHo
0351=`0/?S009cT[02Xl<00eAS`0<T<k02Xk<`0/?CD0;d0g02i0=00Z?2h0:S`]02Xh:@0W<R@092hS
024[800P:Ql00P0N:1l04`0Q:b808bdU028/900R;2@092hV02<_:00R<BX093</02He;P0W=Rl0:3D^
02<_:@0T;bT09C0Z020Z9@0Z<bh07BHQ01dV8P0R:bP00P0L9B8201dV8`@07bPU00P07BHS01TQ7`0R
9bT051PK030e>00W;c40OXJ806I`L@80628S01@0620R01/P8`0K82<07R<U01DM6P0D7AP06B8N01LM
6@0U:bL05adI03]0?01fNgL071hK01/M6P0B51406Q`I01TK600K7AX05aTF01<E4P805ALD00/061XG
01DG500B51404Q@A01<E4P0D5Q<05QHD014A3`0F5Q@04Q8@01TI5`0201DE4`0701@D4P0B4Q004Q8@
01<C4@0E51805A4@01HA400201HB4@0G01@B400C4Q004Q4?00h=2`0E5A<05QHD01@D4P0<30X04a8@
018A3`0@3`d03`h<010?3@0B4@l04a8@010?3@0E51806QTG00`;2@0D4a4040hA018@4`0C4A@00P0?
3A0201<A500C010>4@0B41<04Q0C00`:3@0;2@`03P`?018@4`0?3A0040hA018@4`0?3A00518E00T7
2P081`T03`d@018@4`0>30h04Ph>010<2`0200l;2P03010<2`0A3@`03PX900803PX90P0?2`X01@0@
30`03`/<00l;300>2P/03`/<008040`=0P0?2``00`0>2P/03`/<00l;300300l;300I00h:2`0=2@X0
3@T:01@@4@0:1PL04Ph?01<?400?2``03PX;00d92P0<20P03@T:00h:2`0=2@T030P900d92@0>2PX0
3PX;00d92P0<20P030P900h92@0>20P040X:014;2`0200l92@8030H600X03@L700h8200>20P030H6
010;2`070P8040/;02@O7`1jM7@04@`<1P0<1PH01`0C3`h02PH500/71P0<20L03`/:00d71`0@1`P0
0P0?1PL02@0?1@H040H70147200@1PT04PL;024G6P0;0P@04`P<01462P0701052@0501872`0F2`l0
5@X>01052@0?10P01P0@1@TDooooo`006oooool03P0<4PH03aD:010E3P0>4`d03A8?00hB4`0>4QD0
3A8C00lE5@0=4a402a4>014F4P0?4A00418A100B51<03@0?4A004A<B014C4P0@4Q404Q@C01@F5@0B
51<05QPG014C4P0>40l03@l>00X<2`0?4A000P0>40l00`0?4A004A<B014C4P06010B3`0O018D4@0>
40d03Q0=00X<2@0A4a007AlL00l@3P0I6aP05ALD02`^:`3@d/l0IVQU00lA3P0F61D00P@1014C4006
20D06A/I01LI600:30/030h=00T;2P072@P05aTH014C4P0@4Q403@l>014C4P0C5A@02`d:01<E4002
018D3`0:01DG4P0<3PT051HA010B3@0620<04Q@?0001000L7QT0@dE0014B3@803Pl:00d030d800h?
2P0@4@`03@h900h?2P0@4@`051D@00d>2@092PD04A8=00h?2P092PD03Pl:00L03a0;01D030h900/=
200;3@P02`d800`>2@0?4@`03@l:00P:1@0C5A0061XE00`>2@0O8Qh0`<[90=?Og@0P;2T041/G00/D
3`093`X02a0900d@2@0@4@T00P0A4@L06@0?3`@03Pl701XK5@0B4`d030d701TJ50072080414;01@E
3`0?40X030d700d>200:2`D03a0:00X;1@0>3`T05AH@00X;1@0G61804A8<00l@2P0=3PP03Pl9014B
300D5@l00P0=3PP0100>3`T03a0:010A2`0=3PP2010A2`0500`=1`0D5@l07QlI00l@2P0A4PX00P0B
4`/02P0B4`d0414;00d>200?40/02PX800d=2`0F5Q@02@T700`<2P0?40/2018C3P80414<01004A8=
00h?2P0;30L030d800X;1P092PD030d800h?2P0?40/03Pl:00`=200>3`X0414<01PI500D5A00414<
0P0:2`H03@0<3@L04Q<<00h?1`0C50`05AH@00P90`000@004A8=01<C4@0B4Q002PX800`<2P0A4Ph0
0P0A4Pd03`0@4@`04A8=014B3@0>3`X02``701PI500=3PT04a@?00l@2`0B4`h04a@?00P9100A4Pd0
3a0;00<40002018C3P0:01<D3`0@4@`04A8=010A300B4`h05QLB01DF4@0C50l04Q<>01<D3`808b@O
01L06AXE018C3P0?40/030d8014C400B5140418>00hA2P0@4``04QD;01DH3@031P002`h800h@2`0A
4a004aDC020R7@0J71L04Q@?00h@2`0=3`X04aD@00lA3002010B3@803Q0;00@04A<>00lB2`0@4``0
3a@=0P0@5@l09@0@5a004AXE059KEP1[MG805b4P010J6@0>6AH02@h:01PJ5`0G6AH07AlL01DG500@
4Pl04A<@010B3`0F61D05aTF01@F4`0E5a@02`l>01@H5`0P92<0GF5P03Pl>`0=4A008RHU010D4`0H
71/06QhM00P<2`0T:2L061`K01DI600C5aH04QHE01DJ600F71X00P0I8Ql02@0N9b@06bHR024/:00Q
;2P07bDS01LM6`0K8Al04QPF01lU8`0201HL6P0701LM6`0I7ad061hL01HL6P0E6aT05adM01PN7P04
01TO7`0?01`R8P0K8B406R0P01XP800L8R807B<S01dV9@0K92<06R<R01/U900N:2L082XY01`X9P0J
:BH06bXW00<07B`Y00D07b/[01/Y:@0L:RX07bd]024a<00202@d<`0F01lb<00Q=3809CPf02Pk>@0V
>SP09CTh02Pl>`0[?cl0:Cdn02e2@`0dBd`0:T9402]3A@0jDeH0<DY>02a5B@0aBTl0=TmD03UBE`0f
Ce@0>E9G03YCF080>E9G00D0>U=H03QAEP0fCe@0=TmD03=>D@02035=CP03035<C00aBdX0<D]:0080
<4U600D0<TQ50316@`0_AD80;dE20316A0020398AP1B02m5@`0aAdD0>Dm=0398AP0oEE<0MXb:03E;
B@0iCdd0;D=103=9AP0bB4D0=de:045GE013FEH0?E=@03=9AP0fC4T0>U1=03]ACP0iCd`0=4Y603eB
B`2<XIP0IW]e049FE00aAD<0I7Qg06n3P@11EU40>4e502a1>00hCT40>Dm2039:?00hD4@0?5=903]D
CP0nEe<0@5UF03iHE`0oFEL0@5YG03mLE`0lFU80=eE;03eGC00jE4P0?5I;03eFD012FeL0@eaI04AM
FP16Ge`0AEiK049KE`11FUD0@U]E04ANE@13G5<0@UUA041GC`0oEDd0?eA;049GCP17G580>4a104=G
C01bQW/0?E5603]@B00eBT40=da303U?@`0kDDD0?UA804iTF01AIUl0>Tm803a@CP1_Ph@0=TY903mD
CP<0@5E>0P0oE4d08@0lDDX0>e1903eBB`0nDd`0>Di703I;A00hCdD0=da303A9@00_A3/0<4@k0396
?@0Z?SD0;d0h0352>P0^?cL0;3/d02dm<`0Z?2l09SP/0311=`0hBD40>4U303=4?P0^?cL0;Chf02Xk
<@0V>2`09cT[02Pf:00R;Al06RDG01TT5`0201dW700E01dW7@0Q:b808bdT024[8`0O:B408B/S028^
9P0O;RL08S4Z02He;P0S<R/08RlX02Lc;@0V<B/07BPR01LQ6`0@6A@06R<N01hW8`0T;BX07BHS0080
72DR02006b@Q01hW900M9R<07RLT01lX9@0M9R<0620N01XN8@0P8bP0>Ce100hF6@0U;C00:C@e01XV
9P0N:2T07RHX01LL7`0G6ah0<S@g02D[9`053`L04Q`D01HM5P0I81T05A/G01HK5`0Y;RX06adJ0001
000Z;2T07b4N01@F4`8061XG00@05QPE01PJ5`0E5a@05ALD0P0F61D04@0E5a@04aDB014C400M7A/0
4a<A018B400<30X04a<A00l?3@0F5Q@051@B018B400A4@l04a<A01@C4@0E4A005Q4@00805A4@00T0
518@01<B400A40h05aLE01HF500820H02`/9010@3P0A40h0100@3`d200h=2`0E00/:200F5A<03`h<
018A3`0c<S00518E010>4@0B41<03P`?00d;3P0B41<020H9014?4P0D4QD02PP;00d;3P0I5aX04@lB
00h<3`0<2Pd03@/>00803P`?00<0B4I902HT9`0E4aH00P0@3Q401@091`P04@d=00l;2P0?2`X040`;
00804@d<0P0=2@P200h:2@0500l;2P0A3@d04Ph?010<3@0?2``00P0=2@X200h:2`<03@T:00D03PX;
00l;300?2``03`/<00h:2`0200d92P0T02DQ8P0K5aP05a<D01/G601IEEH03`/<00/71`0>2PL03`/:
00l;2@0?2`P03PX900h:200>2PL03PX900d91`0<20D030P700d8200?2@T040X:00l92@0@2PX03`T9
00h8200=1`L02`D500T30`0:10@03PP801PB4P0N61P040X:00@0000G4A402`H61P0>20P01`0<20L0
0`0001XF5@050@003@T800/51@0@1`P00P0?1PL01`0?1@H040H70147200A1PX050T=01D:3P070000
0P0=0PH601052@0600`11@0=0PH05@X>01<8300>0`L04`P<1P0@1@TDooooo`006oooool03P0:4080
3aD8010F300>4``03Q8@014E5P0=4A@0314B00lE5@0=4a402a4<010G400?4A00418A0`0A4a800`0@
4Q403@l>00lA400200lA4004014C4P0C5A@03@l>014C4P803@l>00<03Q0?00`>3@0@4Q400P0>40l0
0`0?4A004A<B018D4`0700lA3P0G00d?300>40d02@/801HH5@0X:RL08R@Q01/M6P0?4@h02@/906]]
JP0N81d030h;01DG500:30T0418?00@60`0C5A<01PP701@F5@0n@3l0<38a010B4@082PT00`0?4A00
1P0G6AP06adL010B3`0:30L02`d800X<1`8030h900h020X500T;1P0@4Pd08B<N0084000:30L0:R/V
00l@2`0=3PT03Pl:00/<1`0<3@P04Q<>00h?2P80414<00@03@h900D60@0P8A`0414<0P0>3`X00`0C
50l04Q<>00l@2`0500l@2`0700d?2P0<3PT02`d800/=200<3PT03a4<010B3@0200d?2P0H01/M600:
30L03a8>05iXI`2CWil031PF018M6@033PX02Q8<00X?2@0;40T04A89018B200A4@L03`l400/<100G
61803a0:00h?2@0N7aT02@X401<D3P0H6A<04a@>0P0@4@/0100<3@L02P/501DF400;30H200d>2009
01DF400=3PP030d700d>200?40X04a@>01DF400>3`T0414;00<04A8<00P0414;00`=1`0>3`T02@X4
018C3@0O81X03a0:00l@20803Pl701D03a0:00h?2@0;30H02``700`<2P0G5aD092@R014A3`0>3P`0
3@h900l@2`0>3`X03@h900h?2P0@4@`02``700h?2P0=3PT04a@?01TJ5@0G61<00P0A4Pd01`0@4@`0
3a0;010A300B4`h03Pl:00l@2`0>3`X00P0<3@P07`0=3PP03Pl801DF3P0E5Ph04Q<=00P90`0Y:R@0
5QLB01@D4P0B4Q0030`:00h>300C4a004Q<>014B3@0@4@`04A8=018C3P0?40/02P/601@E400<3@P0
5AHA00l@2`0A4Pd05AHA010A300F5a8061TD00h?2P0B4`h00P0D5A001`0A4Pd04Q<>014B3@0B4`h0
5AHA01<D3`0A4Pd00P0?40/08@0H6A@05AHA00l@2`0B4`h020T400d>2P092`X03a4@01@F4P0A4`h0
4A@;00d@1P0G6Pl00`H001HI4P0?4@h06Q`I00lA40072@H02P`700lA300@4Pd03Q0;00d?2P0>40/0
3a4<010B3@0>40/03@l:00lA300D5a004aH?014F3`0200lD3P0D00dD3@0P:B@0VZ>N0;O2_P0H8R40
3ALF00/F5@0:3Pd05aTF00/=2P0>40d04Q@A01<E4P0D5Q<03Q0=014C400D5Q<05ALD01TK600;3`h2
010D4`0J04Q<B`0[;bh04QHE014E500>4Q407b<R01TM700T:2L03Q8A01HJ6@0D61L04QHE01<G5P0F
6aT061hL020Y9P0[=3409Bh[01DP700=61@06RDQ00H<2P0K8Al07bDS01`R800F71X301LM6`0701/Q
7`0I7ad05Q`J01PN700F71`05adM01PN7P0301TO7`0701XP800K8B406b4Q01XP800L8R807R@T01`U
900201XS8P0601XT8`0L9RD07BLV01XV900H9b@06BPU0P0K:RL01P0L:bP07b/[01d[:`0N;2`082h^
020`;`808C4`01H08C@b02Lj>00X>cT09CPf028e=00U>CP0:Cdl02Tm?@0Y?Ch0;D930398BP0[@dD0
;DE703M?DP0`BDd0;DI:03A=DP0jDeP0>55F039;D00gD5D0?5EJ0P0iDUL01@0kE5T0=TmD03A=DP0e
CU<0<Te?0080<De>00D0<di>039<B`0bC4T0<4Y70319AP0203I<B@0303E;B00bB4D0=4Y80080=Ta:
0P0cBDL203Q>C00=03mED`1WOG/09C/i03U?C@0`AT@0=de:03E;B00hCT/0?eEB041FD`0hCT/0=Ta9
03Q>B`0203]ACP0O03U?C00eC4L0=da503Q=A00nDd`0=DU702Tm>`1=HF00DfMU03E9A`0dBD80=D/o
03YA@P0gCSh0<DTk03]CA`0nED/0?EI@049KEP13G5T0@5YI041JF011FeP0@5eH03eKE00hET`0?5I;
03YDB010FTl0?EI@04MPF`0204QQGP0O04MPG@13G5T0@EYF041IE010FE<0@UaC045JD@0nEDd0?EA<
03aBB@0lDDP0<TLn0355>`0^@SL0@5A9049FB`15FDh0>e1803A9@00fBd80=de103Q>@P0lDTH0=4Xn
02Pm=P14FE80=d]904iRH`13EeH0?E9<03mDC@02041ECP0403eBB`0lDDX0?E9;03]@B@80?55:05L0
>4e603E:@`0eC480<TLn0356?@0cB3l0=TY103M;@P0]@CP0;d0h0311>@0[?3@09cH_02Xj<00Y>bl0
:3T_02m0=`0iBT80>T]503=4?P0[?3H0:CXd02Xk<P0Y>S009cT]02Pf:00T;b407BPJ01XU600O:Ah0
8B/P024[8@0Q:b808R`S028/900T;RH09S0X02Hb:`0Q<2T08c8[02Lf;`0R<BX082dV01l[9@0S;RP0
7bXT02H`:`0X<B`0@da7034j=P0J8b005b0M01`U8P0Q:RL09Bh[028[:00Q:RL082TV024Z9`0O:2D0
72<R00lC5P0];S<06AdR020X:`0P:R`0Ef=S01XV9P0Q;Bd072DV00lD5`0/<3<0VYbO05AJEP0J91`0
5R0H018I4P0A61404aTE014F4P0^<bl05ALD02T[:00^<2d03a4>00d?300B51400P0D5Q<0100G6AH0
5QPE01@F4`0F61D201LI5P0;01<E4P0@4Pl08B4O01LG5@0E5A<03`l=01@D4P0@40h05QHD01DE4`0C
4a400P0B4Q000`0C4Q005A4@01D@3`0201<?3P0801<A3`0C4Q002`X800d<2P092@L06ATG02<S8@0@
40h2010?3@03014@3P0B4@l040l=008030/901h040l=01dL6P0@3`d03`h<02h]:`0L6Qd03`d@018@
4`0A3a803P`?018@4`0K6A`040hA018@4`0@3Q403P`?01@B5@0]:bh00@0200h<3`0A3a801P@7018@
4`0<2Pd00P0300400P071@P03@/>00/92P0@30/200l;2P03010<2`0A3@`04Ph=00<03PX90P0?2`X0
100B3Ph04Ph?010<3@0?2``500d92P0400h:2`0=2@X03@T:00h:2`803`/<00X03PX;00d92P0=2@X0
3PX;00d92P0M6AX0;RX[071/K@0I5AH03`/9200>2PL0100=2@H030P500`81@0=20H2010:2P0?00l9
2@0A2`/03`T900l92@0>20P030H600P20P0:10@040X:00@0000:10@040X:01/E5@0400004@/;00H0
3PP800L02@D402TU901oNgX0:BDT01HB4@0?2@T040L800803`H700T03`D601061`0A1`P03@8601H;
3`0D2@d02`0401052@0D2@d01`0A1PX01@0<0@D03P<700h31`0C20`09AXN00H040D95?ooool001_o
oooo00d04QD800hA1P0?4PX04AH@014E4`0;3a00310C00`A4P0?5AD03Q@B00/A300@5Q003a8A00<0
418A00l03a4@00d?3P0?4A00418A00lA400=3`h03a4@010B4@0C5A@051HE00lA400>40l04A<B010B
4@0A4a800P0>40l00`0?4A004Q@C01<E500600lA3P803@l<01D04aDB00h@3@0>40d06A/H010B3`0>
40d04A<@00lA3`0>40d0418?00h@3@0?4@h04Q@A010B3`0?4@h02`d;00X<2`0K7A`05aTH00/=300E
5aH00P0?4A001P0>40l02`d<014C4P0D5QD051HB00P:1P80418=01X02@/601<E400?4@`04A<>00`>
2@0:30P030h900/=200>40/02``700/=200@4@`03a0;010A300C50l01`P4010A300=3PT02P`701PJ
5@2BThh0AdQ3018C3P0A4Pd03@h901@E40H03a0;02X04Q@?014C3P0?4@`03@l:00h@2`0@4Pd03@l:
01<E40092`L0418=00/=200=4@`0318@010L70094a404AXG00H=2@0<4Pd03Q8<00hB2`0?40L03`l5
010@100B4@L0414900d>200B4`d04a@>00d>200B4`d030d701<D3P0A4P`03a0:010A2`0>3`T04a@>
02TZ900A4P`02``6010A2`0I6Q@400l@2P0500h?2@0=3PP03@h800l@2`0@4@`00`0@4@/04P0E5Q00
824K018C3@0=3PP051D?00X;100B4``03a0800h?200A4P`04a@>014B300?40/030`:010@3P0H61H0
3@d;018B40803a0;0P0=3`X0200@4Pd051D@010A300G61<030d801HG4P0N7aX051D@0P0@4@`0100?
40/03Pl:00l@2`0A4Pd2010A300400l@2`0=3PT0414<018C3@80414:01`01@H1018C3@0^;bT0UiRB
01dN6@0;2`T03`l=01<C4@0A4@l0414=014B3@0?40/03Pl:00l@2`0A4Pd051D@010A300F5a803Pl:
01TJ5@0>3`X04Q<>00L80`0F5a803a0;01TJ5@0Z:bH0414<0P0F5a801@0C50l051D@018C3P0?40/0
414<00804A8=01L0414<00l@2`0>3`X0414<00`=200>3`X04A8=00l@2`0;3@`04Q@C018D400=3`T0
41<;010C2@0;3P@041<900lB2`0:30P03a4>010B400A4a004aD@014C3P0200lA3005010B3@0;3@P0
3Q0;014C3P0@4Pd00P0>40/00`0B5@h04QD=010E3P02010E3P0I010F3`0@61<0;cLb04I@C00=6AH0
5B0M00XD4P0B5a@04Q@A01HH5@0O8Ah04Q@A01<E4P0E5a@04A<@01DG500H6QL05aTF01HH5@0F6QT0
3a<B01<G5P0<40l05ATH018F5@0201@H5`0O01LK6P0>4Q405ATH018F5@0G6aX05ATI01<G5P0C5aL0
5Q/J01LM6`0A6AL06b<Q010I5P0B71T05AlK01HP7@0M8b405adK010F500I7ad041HD01/Q7`0G7A/0
5A/I01TO7@0G7A/05A/I01PN700D6QX05Q`L01LM7@0301PN7P0301XP800N92@07R@T00806b4Q00l0
728R01LP7`0G81l05b4P01TS8P0K9B@072LU01/X9@0J:BH06bXW01`[:00M;2T07B`Z01`Y:@0M:b/0
0P0M;2`0:00M;Bd0830`024a<@0O<S408cDd02Hh=`0U>3L09CTh02Hj>@0W>cX0;4100396A`0aATL0
;D=50359B`0eCDl0=4a?03=<D00dCE40=4aA03QAE@0jDUL0=TmD03M@E@0iDEH0=e1D03UBEP0gCe@0
=DeB03UBE`0fCe<0<Ta?03IAD00fDU00=E1?039<B`0`BDP0<T]903E>B`0fC4X203M=B`0C03I<B00e
C4/0>4m>03]BD@0gCTd0=Te<03U@C`0gCTd0@EQG03A;BP0eC4/0?EAC03=:B@0hCT`0=de;03Y@C@10
EU@0@UQE03iDD@0203aBC`0Z03eCD00kDDh0>Dm<03M=B@0dBD80>Tm603I;A00iCTX0;T<o03Q<BP0`
A480;T<o02e2>`0cBCd0=Tdn03mFAP0eCD00>U5603aCBP11FU@0B65M03iHE@11FeX0?eYH03eJEP0o
FeH0?EYC03UFC00oFDh0?EM;04EOE00mETl0BF9M04YSG`16Ge`0D6UU04iWI014GET0?UMB049KE@0o
FE00?eI>0P0mE4/0E`0nE4/0@5E;049GC@0oE4T0@EE:03a@A@11EDX0DfML03M<@`0fBd80?E99045G
B`0oEDT0@5I:04=ICP0oE4d0AeaF04=GE00lD500A5QF03eBB`0kD4T0>Tm703]@B00lDDX0?E9:03Y?
B00hCDH0>Di603]@B00iCTL0=da403I<@`0cB3l0=DY103U>A@0gBd80<dLn02m3>P0^?cL0<T<k02dn
=P0X=c00:c/b02ho=00_@3H0;Slf03Y;A@0jBdH0<D4m02Xk=@0Y>S@0<d@l03U:@00dACX0;3X]02Pc
9@0U<2808bhP02@_8@0V<2D09c4V02<^8`0O:B0082XQ02<]9@0T;RH08blX020^9`0R<2T09cD^024_
:00Q;RL082/U02Td;P0H8ad08B/U01`U800S;2L072DQ024Z9`0N9b@08b`Y02Xc<00]=S<09Bh[02</
:@02020Y9P0S01lX9@0N9R@07AhR01hO900E6Ah06B4T01dV:00b?Cd06RDU01/V9P0E7Qh05Q`L04=7
A`37b<P0EUeF01`U7@0E7AH041L@01dT7@0E6a@04AHB01XO6`0E5a@06Q`I01TK600J71/08R@Q02<U
8P0L7Q/05ALD01LI5P0E5a@061XG01LI5P0E5a@00`0D5Q<01P0H61H05ADC01XJ600E5A<05QHD00d=
2`<05ADC00D051@B018B400A40h0510?01<>3P02014=300;018?3P0B4@l051<A01<C4@0A4@l0DE5?
05MGE@0C4a4051<A014@3P0@3`d00P0B4@l05`0>3@/040l=014@3P0:2@P040l=00d<2P0C4A408R0S
00X82`0=2`h04Q0C00d;3P0>30l0?C/n018@4`0;2@`03P`?00l=400C4A@09bDX01@B5@0<2Pd03P`?
008040hA01804A0B01<A500C4A@03`d@00`:3@0@3Pl040`:010;2@0@2`P04@`901<=300C3P/040/9
014;2P0@30T04@d:018<2`0@30`200h:2`0:00l;300@30d04@d>00l;300<20T03PX;010<3@0>2P/0
30P900d92P803`/<00`03PX;00d92P0=2@X03@T:01@@4@0<20T040`=00l<300D41402`L500l<1`0>
2`L200h;1P0I00l<200?30L03P/600h;1`0=2PH030T400`91@0<1`H04@/;010:2P0>20P04P`<00l9
2@0<1PH03PP8010:2P0=1`L030H600l92@0?2PX05a4A00/61P0H4Q802`D5010:2P0600d71`07014=
3018A4<0`[jm024M700:1PH04@`<0107200200l61`0:00l51P0@1PL04@L800/2100C2@`03PD70146
2P0A1`X03PD701462P804@L:00l04@H:01472P0A1PX04`P<00l5200F2`h04`P<01462P0Q5QT040D9
01062@0@1PP040D901062@0@1PP05?ooool001_ooooo03@03A8>00lD400?4a803Q8A00`@400:3Pl0
2@d>01XN7`1UJFX0310A00hB4@0<40l03A4B020T9@0=4A800PH700lC500@51D02@d>00lC500B5QL0
2Ph?00dA4P0:3Pl02`l>00D9200=4A003Q8A00/?3P0C5aH03A4@00hB4@0:3Pd02`l>00dA400;3`h0
418?00lA3P0;3@X030h;00d?300:30T03Q0=014C400@4Pl030h;00d?300@4Pl051HE018D4`0@4Q40
3a4@0P0=3``020092`P03@l:010B3@0@4Pd06adH010B3P0;3@X03Q0=0P0<3P/09`0@4Pl02P`900/=
2P0<3P/03@l<00h@3@0?4@h0418>00L9100@4Pd02@/601LI50051`80418=00L910041P404Q@?00lA
300:30L0314;00/B2`0:3`T03Pl:00l@2`0>3@T03`d901PG4`0J6aH02`d801PM5`1<Dd`0JfmY02<U
800@4Pd02`d800D70P0?4@`04Q@?010B3@0300h@2`0700`>2@0<3@P03Pl:010A300=3PT030d800l@
2`03014B3@0E00l@2`0>3`X030d800l?3@0?3`l04A4@00l?3@0<30X03Pd:00/:1@0>3@P04Q0:00l<
1@0?30<04a8:00l@2P0?4P/02`h700L:0`0E61403Q4:00@02@`500@02`h700`?200?40X030d:0P0=
3PP00`0G6180ADI000l@2P0200l@2P0=010A2`0B4`d04Q<>00lA3P0>40d03a4>00@60`0>40/05ALB
00/>1`0<3`P01PT001@G3P0200hA2009010C300G6Q@030h901<E400:30L04Q@?00d?2P0A4`h0418=
00803@l:00<03a4<00T>2P0@5A400P0>4`l00`083@L02`d800d@2@0200h?2@0800h?200>3`T03Pl9
00l@2`0B4`h06AXE01LH4`0@4@`2018C3P0D01<D3`0B4`h04A8=00l@2`0>3`X04aD@010B3@0?4@`0
418=018D4@0D5Q<05QPE014C400=3``0004002@V8`0;3@T03a4<00h@2`0=3`X200lA300:00h@2`07
2@@03Q0;018D3`0;3@P04Q@?01<E400@4Pd03a4<00h@2`803@l:00L030h901@F4@0E5a8030h901<E
400D5Q403a4<0080418=01403a4<010B3@0@4Pd03@l:00/=200>40/04A<>010B3@0=3`X01@L201dO
6P0>40X041<<00d@2@0?4PX041<<014D3@02018E3P804A<>00`03Q0;00/=200F61<06adH010B3@0?
4@`07R0K010B3@0?4@`061XE018D3`0@4Pd5014C3P0;010D3P0=4P`03a@>00dB3@062`L04QLC01DJ
5P0F61<04A<>01@F4@0F61<00P0D5Q408`0G6A@051HA01DG4P0D5Q404Q@?01HH4`0A5Q8051TE01HK
5`0A5Q803a@@01XO6`0G71P04aPD00P=2@0@5A404QLC010D4`0F6Q/04aLI018F5`0D61/05ATK01@H
6@0E6A`05AXK01@J6P0E6Qd051XK018H600A5aD05adK01@J600F71X06AlM008061hL0P0L8R002@0B
61H05A/I024W9@0J81h05A/I01HL6P0E6aT061hL01hT8P0201HL6P0F01LM6`0I7ad06R0N01XP7P0O
:BD062<O01dX900L:2@06BDQ01`X900N:bT06RPX01PX9`0K:bX08C4`02<c<P0J:B`06bX]01X/;P0P
<C<02Q`N02Dg>@808C<e02L08S@f02Tk?@0X>S`09cXj02Pn?00W?C/0:3hm02]0@@0^@d@0<DI80397
BP0cB4/0=T]?03E=D@0hCE80=de@03A<C00gC4d0>Dm@03M?C`0fBd`0=Da<03E=C@0gC4d0=de>03I>
CP0fBd`0=dm@03UAD`0gCe40<d]=02m7B@0^@dH0<DI803M<C@0iCTl0=4U:03=8B@0fC4d00P0cC500
1@0iDUH0>U=G03I?D`0gD5@0=TmC0080>eAH00T0=4eA03eFFP0mEUX0?UIH03M?D@0bBT`0?UIF03Q@
D00mEE@00P0jDe008P0kE500>E9<03M@BP0eCDH0<DHo0397@00^@c`0<DHo03M<A@0`ACh0>4e402i3
>P0aAc`0<4Hi04=IC01BJ5/0>4m503QBB@0jDdd0?5EA03iGE00oEeL0?5AD03eEE00nF5D0@5UE03mI
DP0lETd0@E]@045IC@0oET`0@EQ>04IME@19H5X304IME`0@04ELEP14FUH0@UUC04=JD012Edd0?596
03I<@00iCd80@5I903mEB00lDd<0>E1003]B@P0jDD40<DPh03eBB080<TLn02@0GW=Z0;_@a`19GUD0
AU]D0397@00gC4L0B5aI049FE010EE00>e57041EC00eBcl0>e5603M<@`0hCT80>e5603U>A@0fC400
=DY003Q=A00kD4L0?51903E8@P0aA3h0=4M1041AB`0eAT00<44k03A3?P0fAD00<3lj030l>00b@CX0
;chg0391>P0gASl203e<A@0C03E4?P0V=Bh0;Sdf03A3?00_?SL0=4<l02Xi;@0T<RD08RhR01l/800N
;1l07b/Q01l/8P0L:B006RDM01dY8@0R;bP09C0Z02@_:P02020[9`16028]:@0Q;2P07RTU01lX9@0M
9R<06B8O01`U8P0N9b@06R<P01XQ800L8R805adM01lU9@0f?3`09bd[01lU8`0N92809B/W02L]:@0T
:RH09R`X01TM7P0H71l06QhP01lT9`0Q9bL07B<R01PN7P0J81h061hL01XN7@0T:BD0;34]01lT800C
61@02Pl;00hC3`0N8al061XG05UKF00`<Rl04Q@A01XL6@0E5a@061XG01`L6P0@40h071`J010@3P0P
81h05ADC01/K6@0E5A<071`J01HF500=3@/0820N01DE4`0J6QP05ADC01<C4@0F5Q@051@B00/;2@0T
928051@B01LG5@0;2`T06a/I01<A4P803`d>0P0C4A801@0?3@h0108301/I6P0C4A80OG]l00805aDF
02003P`=00l=3P0D4Q<04a4B010>3`0D4Q<030X;00l=3P0@3Pl03P`=00d;300>30d03`d@00d;3P0D
4QD04a4D00d;3P0A3a803@/>00/9300?3A004@lB010>4@0B41<05A<F00L5200:20/04@lB06YXJ`0k
>C`02`T<00h<3`803@/>01@03`d@010>4@0@3Ph05A4B00@30@0>2`/03`/<00T81P0:1`L030P901`K
6@0;20P02@D600d92P0>2P/03`/<00h:2`0?2``03PX;010<3@803@T:00X040`=00P41@0;1`P04@d=
01HB4@0E4A003`/:00H20@0A3@`040`;1@0>2PT03@0?2`X03`/800l;2P0?2`T03`/800l;2P0?2`T0
3PX700h:2@0?2`T040`9010<2`0?2PT01@0=1`L03P090`<02`D500l92@0?2@T030H600T30`0:10@0
3@L700l92@0;1@D02P@400l92@090`<04P`<0P0=1`L0200;1@D04P`<01PB4P0=1`L05a4A010:2P08
0P8040X:1@0=1`L06@0>1`L04`X=00P2100:0`D040L:00T1100=1`T03PD8024J700K5AL040L:00d5
200B2@`060h?00d3100900004`T:01@:2P0800005`d>00/20P0@1PD05`d>0188200a9bH05?ooool0
01_ooooo00<02Ph?00`@4@0>4Q<00P0?4a@02P0>4Q<06AdN01PL7@12ATL010P900lC500B5QL0<CDf
03/o@00O8b@200dA4P0C00@82@0@51D02`l@00hB4`0?4a@0310A00X>3`0=4A004ADD01`P7`0I7A`0
3a<B01<G5P0830/051PG01<G5P0=4A002Ph=00T=3002014C400500d?300?4@h0418?00d?300>40d0
0P0?4@h00`0=3``03Q0=00lA3P0300lA400@010B4@0A4a004Q@A018D4@082PD01PP3010B3@0;3PL0
4QD@00h@3@0D5Q<04Q@A010B3`0F61D0418?00lA3P803Q0=0P0<3P/06`0:30P03Q0;01TK5P0I6aH0
3Q0;01<E4017BD@071hI00lA300@4Pd02`d800X<1`0<4P/02Q@<00lD3P0?4Pd0414<018A3@0?2`P0
2`X600l@2`0<3PT05QdF03U0>@0i?cP02P`700lA300201TK5P0>00h@2`0;3@P02P`700X<1`0=3`X0
3Q0;00d?2P0>3`X0414<014B3@0>3`X03@h9010A300B4`h201<D3`06018C3P0A4Pd0414<00l>300A
3@`04`l>0P0E4A00100F4Pl04a0;018?2P0@3@P2014>1`07010?1`0<3@L041<<00X=1P0>4@X030l8
00@7000200/>1`8030l80P0=40T0;@0<3@L051D?00l@2P0<3@L01@H2014B300@4@/03a0:00h?2@0?
40X04A8<01<D3`0@4Pl03a4@018D4`0C5A802@/700h@2`0J7AH05AP@00X=100=40L03A06014D2`0A
50d03@l:00L9100>40/03@l:00h@2`0=3`X0418=00lA300=3`X03Q0;010B3@0<4Ph02a0<01XP7005
2PH03Q<=01<H4P0?4P/0414;00l@2P0300l@200401PI500>3`X03Pl:00l@2`803Pl:00@04Q<>014B
3@0A4Pd04A8=0P0@4@`07`0@4Pl03@l<00`>2`0<3P/03Q0=00lA3P0A4a0051HC01<E4P0>40d06A/H
00H8100=3`X0418=00lA300>40/03a4<018D3`0>40/04aD@01@F4@0>40/03a4<00`>2@0?4@`0418=
014C3P0@4Pd03Q0;014C3P0?4@`00P0<3PT00`082PD03@l:018D3`0200h@2`0300lA300>40/03Q0;
008030h900`03a4<018D3`0B50l04Q@?02<V7`0d=c0051L@00`?200J7AH03A0900lB2`0@4``3018E
3P09014D3@0G6A@04Q@?00/=20010`002@/603`n>@0c=C008B<N00804aD@00<03a4<018D3`0A4`h0
1P0A4`h0600?4@`07R0K01XL5`0B50l02`d801HH4`0E5a806A/F01LI500A4`h04Q@?01<E400B50l0
5ALB01@F4@0A4`h051HA01<H500D6AD06b0L01`Q7@0E6QH04QLC01DJ5P804aPD01T051TE00hC3`0D
61L05QXK01<G6P0B5QT051PK01DI700C5aX041@G00lC5P0A5AP05QXM01LK7P0D61T06AlM01/Q7`0D
6QP04aTG01LM6`0F71X05A/I02H/:P0]<c407bDS00803Q@B00<05A/I01TO7@0L8R000P0H7Q`0100N
92806R0N01XP7P0J81h201TO7@0?01LP7@0J91l06bHP01hY8`0K9b<07BTU02@`;00G9R<05bLV01PX
9`0J:RT072`[01`/;00C9BP09cTm00805BL[01T07c4e020b=P0R=3P08cDi01la=@0R=3P093Hj02Di
>P0V?3X09C/i02Dj>P0V>c`0:Cho02e2A00`ADP0<DI903=8C00dBDh0=DY?03A9B`0cBDL0=D]903U?
C@0hCT`0=D]900<0<dU700P0=Ta:03U?C@0hCT`0=Ta<03E:C@0fBdh0>4e@03Y?DP80?55D00X0>TmB
03Q=D00bAdX0<4E80316B@0fCe@0<dmC03QDF00iEET0=51D0P0fDUH03@0jEUX0?e]O03iJGP13Gf<0
=U9F039:CP0kDeL0?UII03Q@DP0jDU@0>51@03QACP0iDTl00P0jDdl0@00hDD/0=Tm803U>A`0iCTL0
<TM00315?00dBD00<DHm0316>P0gCD40?UA802To<P0bB3/0?UI903eDBP0mETl0?eQB045JE`13FeX0
A5aL05UaL@17H5h0>U=?03aED@13G5D0A5iC041GC@11FDd0@UU?04=JD016GE@0AeiF04UPF018GeP0
AeiH04IME`13FUD0@EQB04YOEP13FDd0>4i2049HB`17GDl0@5M703iEA@0fCC`0<4Le03=:>00kDT00
?5=303Y@A015FU40C65H03Q=A01RMg00;D8k03Q=AP15FUD0EV]V03=8@`11EE<0>4e803U?A00iCd<2
03aBAP0803Y@A00oEDT0>U1403U?@`0fC400=D/o03U?@`0lDDP203U<AP0603A7@@0`@cd0=TM102m0
>P0a@S`0;Sdh0P0a@3/02@0`?3P0<Cdi03=2>`0d@c`0<d8k0391>P0`?cP0<T4j02dl=@0202/j<`0A
0350>@0eA3d0=4<i03A2=@0]>bh082hQ01d[7P0S<2H0<3dc02Xg;P0N:b807BXR02@a:P0U<R/092lZ
02@]:P0R:bP00P0S;2T3024Z9`0]020Y9P0O:2D07bPU01hW900L8b<07R<V01dS8`0N92@0:S0`028X
9P0U:bT08RPV028X900O9B406R0L01/Q700O8b@07R8U01lS900P92D08BDV01lS8P0J7Qd0720O01`Q
7@0E6QH04aPD01/P6P0B51403a4>01hP7@0F61D03Q0=01PJ5`0j?3T0828O014C400K7AX061XG01XL
6@0B4Q005QHD01XJ600G5aD0Fe]I00807QhL018051@B01PH5P0F5Q@06ATG03Hf=00O7ad061PF014A
3`0?3`d0410>01<C4@0F5Q@0820N01PH5P0L71X04a<A01LG5@0C4A82018@4@804a4B00P04@l@00l=
3P0:20T03`d>02`Z:`0C4A802@L801DC50804@l@0P0?3@h0100F51D03P`=014?400@3Pl200l=3P0>
010>3`0>30l03`d@01PF6@0B41<01`D800P62@0?3A0030X=00h<3`0=2`h030X=010>4@0;2@`200l=
400900h<3`0f=3L07Q`O01DC5P0A3a8030X=00/9300>30l03`d@00803P`=00<02`T:00l=3P0=2``0
0P0A3a001@0J61T0:RPY014?400<2P/03``=00D03`/<00d03PX;00l;300@30d040`=01<?400A3@h0
2PH600X61@070`803PX900X61@0=2@P03`/:00`03PX90P0=2@P200h:2@0300l;2P0>2@T03@L700H0
3@L70P0?2@T01P0>20P02`D500d71`0<1PH03@L700h820803`T900`030H601@>3P0>20P040X:00l9
2@0H4Q80A3hn02HP800C3@d030H600/51@0<1PH600d71`0:00`6200:10H03@L900l92`0=1`T040X<
00L10`0C3@l04@/=00`620803PP:00`03@<401@:2@0?1@@0200000l71P0L4Q4050X901L=300@1PD0
3@<200l51@0[8B0Dooooo`006oooool200dA4P803Q8C0P0=4A805@0J7Ql051PI01@H6@093@h03a<D
00hB4`0:3Pl04aLH00/?400830d03Q8C00X>3`0=4A804aLH00H:2`0>4Q<04ADF00/?400:3Pd03a<B
01<G5P0200hB4@0401HJ6@0G6aX07R8Q01LK6P<03Q8A0P0@4Pl02P0<3P/03Q0=010B3`0>40d03a4>
00`>2`0=3``0418?00lA3P0=3``200lA400:00h@3`0@4Q404A<@018D4@0?4@h03@l:01@F4@0A4`l0
71lH01TK5P803@l<0P0<3P/00`0A4a003Q0=00h@3@0400h@3@09010B3P0T9R405aTD00d?2`0<3P/0
20X602d_:P0A4`h02@/600<03@l:01<02Q0:00P@2@0<4@/030l900/<1`0>3@T040l;00h=2@0>3`X0
3Q0;00L=1P0940T02Q0:01HH4`0@4Pd06adH024S7P0A4`h03Q0;008030h90P0>40/0100=3`X03a0;
010A300A4Pd200l@2`03014B3@0=3PT03@h900<03Pl:00<03@h9014@3P0A40h00P0?3P`03@0A40h0
3`h:01DD3`0A40/03Pd8010@200A4@T03Ph600/<1P0D5a003Q4:00T<1`0>4@X00P0<3`P0200>4@X0
41<<014D3@0?4P/03A0900L81@0N7aT03Pl90P0A4P`00`082@H04Q<=00l@2P0200d>200B010A2`0C
50l04aDB00h@3`0;3@`05ALD010B3`0=3`X04A@=010C2`0A50/01PT3010C2@0G6Q403Q4:01TK5P0S
9B004A<>100?4@`200h@2`0900lA300@4Pd0ATQ502h_;@0;3@X05QLD00D60`0A4`h04A@=00804A8<
00P0414900l@200?40P0414=01DF4@0A4Pd03a0;01<D3`804Q<>00L0414<00l@2`0A4Pd04a@?01DF
4@0@4Pl03Q0=00803@l<00T03Q0=00lA3P0=3``04Q@A00lA3P0:30T04A<@014C3`0@4Pd00P0A4`h0
3@0>40/03a4<010B3@0<3PT0418=00`>2@0?4@`05ALB00d?2P0>40/0418=01<E400B50l00P0@4Pd0
300:30L06Q`G03@f<@0F61<01`T400lA300@4Pd04Q@?01<E400B50l0418=014C3P804Q@?00`04A<>
018D3`0C5A003a8;018E3P0K7QL04A@=00hA2P0C5Pl03Q4:00lB2`0A50d3018E3P0<00d>2`0=3`X0
4aD@018D3`0<3PT05QPC01`N6@0A4`h03Q0;01@F4@0C5A005ALB1`0A4`h0200@4Pd051HA010B3@0K
7AP04A<>01@F4@0@4Pd04Q@?0P0D5Q406@0H6QD04aD@01<E400H6QD05aTD01DG4P0L7QT05AXF014F
4P0K81`08RLS01PM6@093PX05AXF01HK5`0C61@0724M018G4`0H7AX05ATJ018F5`0A5AH04aLH01@H
6@0C5aP00`0G6a`01@0H71d05a/L01DI6P0J81h0728P008051XH0P0I7ad00`0L8R0061hL01PN7002
01LM6`0[01XP7P0Q9bD06AlM01LM6`0E6aT061hL01hT8P0G7A/061hL01TO7@0K8Al0728P01/T8@0J
9Al07RTU01lZ9P0I9B407BTW02@`;P0F9B806RXY01d];00N;Rd06b/Z01TY:@0J;2l0@UAH08:DV00`
@TH09SPl01la=@0U=c/0:3Xn02<e>@0T=SX09SPl02Pl?@0Y?cd0:3hl02Pn?@0Y?Sl0:Sm002i3A@02
0356B@060397B`0bAd`0<dQ=03=8BP0eBdT0>4i<0P0lDU006`0hCT`0=Ta:03A:B00bB4H0=4Y803M=
B`0hCT`0>Di?03M<C`0fBdh0=DY=03M<C`0jCe80>4e@0356B@0_A4L0=4U<03Q=D00iD580>eAI03QD
F00lF5`0>eMK03IBEP0hE5P0>eMK03MCE`0203EAE@0;03iJGP0mF5`0KhN:049JF`0gCe00=4a<03M?
C`0kDe<0=Di;03M@C@0jDe000P0lEE40;P0kE500?eA>03mDC@0gC4D0;D8k02m4?@0fBd80>U1403=9
?@0jD4@0=D/n03U?@P0hD4<0?5=903aFCP0oF580@EYG049KF@12FUX0Jh>305E]K012FeL0@5UE041J
DP0lET/0@5M=049ICP14Fe40AUeC04IME016GED0Bf9J04]RF`19H5X0B5mI04EKE`13FU@0B5eD05M]
H@15Fdl0BV1C03]AA014FTd0>U5103Q??`0jDD4203aC@@0C03eDA00mDdL0A5U@03eBB@0eBT40?E9;
03]@B@1DJF80A5UD03Q=B00mDTd0AUYH045FD@0nDd/0>e1704IKDP0lDDP0@UM>04MLD`0203U>A@80
=da300`0>Tm603eBB@0nDD/0>Te703A7@@0eB480>T]503a=A`0b@cd09SD`02Th<`0_?ST2030l>005
02hm=P0c@S/0<D0i02`k=00^?CH00P0a@3T03P0R<BX07bhW0350>@0/>c@0:cX`02hl;`0[>B`08BhS
01`Y7`0R;bD0<Chd02dj<@0O;2<07R/S0P0U<R/0100V<B`09c0]02</:@0R:bP202</:@0901hW900K
924072DR01/T8@0J8b006b@Q01dT900U:Rd09bd]00807bDU01P082HT028X9P0N928082HR028X900P
9R808BPR01`P8@0M8B@0720Q01HJ6`0E6AX061`K01dQ800H71/06QlK01PM6@0D6AD0:2dW05]MFP0W
:BH0418?01/M6P0G6AH201PJ5`805aTF01<06A/H01XL6@0I6aP05QHD01dM6`0H61H0410>04E5@`0C
4a405aLE018B400G5aD051@B01<C4@0U9B<07AdK018B400K6aT07QhL00804a<A00L061PF018B400H
61H06ATG01HF500=3@/04@l@0080518C0P0B41402`0E4a@04a4B01HD5@0H5QL01083018@4@0>30d0
4a4B01HD5@0L6Q/06QPI00804Q0A00`04@l@018@4@0A3a003`d>014?400C4A8040hA00d;3P0C4A@0
40hA00l=400F51L200l=400<010>4@0=2`h04@lB01XH6`0F51L06ALJ01<A500@3Q4030X=01<A500G
5AP03`d@0`0=2`h04@0>30l040h?00d;300A3a003@/<00/92P0=2``02`T:01HD5@0Q7b003@/<00/9
2P0?30d03`/<00h:2`0?2``03PX;00803`/<0P0@30d0200>2P/05A4B018>3`0;1`L03`/:01<?3P0?
2`X04`l>0P0<20L600h:2@D03@T80`0<20L300d9200300h9200=1`L03@L700<03@L700D04`d=010:
2P0<1PH03`T9010:2P0200h8208030H600`04@/;01@>3P0A2`/02`D5014;2`0;1@D030H600/51@0A
2`/05a4A00P30`0=1`L200h820L03@L701402`D7010:300@2P`03PP:014;3@090`D03PP:00/51`09
0`D030H800l92`0:10H040L700l51P0C2@X050X;0147200200/10P0501882@0<0P<04@L800l51P0D
2P/05?ooool001_ooooo0P0?4a@02P0=4A80310A00`@4@0;3a001@T:010D5@062P/04aLH00dA4P0:
3Pl201@H6@0F014E5P0@51D03a<D00`@4@0B5QL02Ph?00T=3P0D61T02@d>00hB4`0=4A003Q8A010D
4`0E6AP09b/Z03@h=`0E6AP03a<B00T=300:3Pd02`l>00L;2P80418?00`030h;00h@3@0?4@h03@l<
00lA3P0;3@X030h;014C400?4@h030h;010B4@0?4A0200h@3`803a4>00`0418?00T;1P0E5a8061XE
0;Nj/`1^LF`061XG00`>2`0=3``03a4>014C400;3@X200d?30803a4>0280418?00/=2@0B50l051HA
010B3@0j?3L0B4Y501lQ700?4@`03Q0;018D3`0?4@`02`d800`B300=50d02Pl900lB300B4`h03`h:
00`;1`0;2PH030d800lA30093PP020l800X@2@0B50l02`d801PJ5@0@4Pd01PP300d?2P0;3@P02P`7
0P0<3PT0100:30L03a0;00h?2P0>3`X200l@2`803Pl:00<03a0;010A300A4Pd00P0@4@`0500:2@L0
3Pd;00`;2@0?3P`05QDC01HE4@0>3@P040l:014@2`0>3PH03`l7018C2`0J6aD030l8010C300930D0
3Q4:00lB2`0;3PL03Q4:0P0@4``02P0>4@X02`h702X[9@0m?SP06Q/E01@E3`0G61803a0:014B300?
40X200d>200A00l@2P0A4Pd0004001<E4P0A4a00004001HH500D5Q403Q4:00X=1P0A50d04QD<04E8
?`1/KfH02`h701HH4`0S9B000P0<3PT03P092`H0418=00lA300>40/03a4<010B3@0@4@`05A@B0040
000N7A/010@301TH500@4@`0414;0P0?40X02P0>3`L030l600`?1P092PD0004000H70P0H6A@05AHA
00L80`0A4Pd200h?2P03014B3@0E5Q405QLB00803a4>00`0418?018D4@0C5A8051HC010B3`0<3P/0
5ALD01HH5@1`LVl0GEmK01LI500=3`X200h@2`0700d?2P0?4@`04Q@?01XL5`0B50l03@l:018D3`02
00h@2`803@l:00d03a4<010B3@0A4`h02`d800h@2`0E5a802P`700P:1@0@4Pd04A<>01<E400E5a80
4aD@00<04A<>00X03a4<00h@2`0@4Pd04aD@00lB2`0<3`P0:B`U01`O60062@8041<<0P0>4@X0400@
4``04A@=014D3@0A50d0;BlZ01/M60092`H0418=01HH4`0E5a804aD@014C3P0F61<06Q`G01HH4`0=
3`X6014C3P0902d_:P0G6A@03Q0;00h@2`0E5a801@L303i0>`0R91l04aD@00<051HA00l04aD@018D
3`0C5A004A<>01@F4@0P8Qd06AhJ018G4`0D6AD05Q/G01<H500B5a<05AXF01HK5`001@400P0J7a/0
3`0A5Q805ATJ018F5`0A5AH04aLH01@H6@0C5aP06QhO02<W:00P92D05QXK018F5`0I7Ah051XH01XP
7P0201PN700M01XP7P0H7Q`041HD014G5@0D6QP06R0N01TO7@0F71X09Rl/010I5P0>5a@05AhK01HO
700G81d0624N01TR7`0K92407RLT024Z9`0R:bP072LS01/V8P0J9B406bLS01`X9P0K9bD072XZ01`/
:`0M;B`00P0N;Rh01@0O;bl09CLj02Pj?P24UYX08cDi00807c4e00H07S0d020b=P0W>Cd0;T1402Pj
?P0P=3D202<i=`0702Hl>`0Y?Sl0:Sm002i3A@0aATT0<TM:0397B`020397C00303A9B`0fBd`0>Di?
0080?E9C00<0>Di?03Q=CP0gC4d00P0dBDX01P0gC4d0>4e>03eBE00nDeH0>4e@0356B@80;D950380
<dQ;03E:C@0`ADP0=4U<03Q=D00hCe40?EIK03]DF@0mEU/0?5EJ03QAEP0jDeP0>55F03YCF00nEe`0
=e1E03UBE`0mEUX0WkNg05E^J`0mEU<0>E9?03A=BP0gD4d0=4a<03I>CP0jDU80?EEE03iFEP0nEUD0
?U9@03iCCP0jCdP0<TM003A9@P12Edh0A5U@02e2>@0oEDT0AUa@03=9?@0iDD@0?UE;03mHD@13G5H0
A5eJ04EMG014G5`0@5QH04ENG080BF9N00X0B69J04QRE`13FU00@eY?045HCP13FU00AeiE04YQF@18
GeL0BF1I0P19H5X06`18GeX0AeiH04EJD@2EZil0CVAH03mEB@1<HUD0;48e03I<?`0nE4H0BF1@04QO
C`0nED@0?eI603I<@01=HUT0=T]203]@A`0bAd00>e1904=HD@0dBD@0?E9=049GDP0dB4H0CV=N03Y?
A`02059WGP0304IKDP0nDdX0=4U00080>Tm600/0>Di503M<@`0jCdH0?55803]>B00_@S`0;T4k03a?
B@0eAT00>DY40311>`0202Lf<@0G02Pg<P0]>CD0<Shj03I5?P0eA3d0<3lh02@c;00U=2d0;C`e0391
>P0N;BH062LP02ln=`0Y>3409SD[02@b9@0Q;R@0934W02Ld:P0V<bX08BhU01h[8P0P;BH00P0R;bP0
:@0R;RX09C0/02D^:`0P:BH07BHS01lX9@0P:BH08BXW01hW900L9B8082TV02D^:`0R:bP07bHV02<X
:`0U:b/08BLW020V9P0P9R@07bDS01`R800N920082HR01/Q7@0F71L06AdN01/O8P0J7Ql05ATJ01@H
6@0I7A`092PW01HJ6@0E6QH06AhJ01<H500L8A/0;Bl/01/M6P0H6QL05aTF008061XG01l05QPE01dO
700J71T04A<@01@F4`0I6aP05aLE018B400J6QP05QHD00d=2`0J6QP05ADC01LG5@0N7Q`06ATG00h>
300@40h05aLE00l?3@0P81h09BDS01HF500C4a403`l=018B400G5aD0410>01<C4@0?3`d03`d>0080
4a4B0P0@3Pl0300D4Q<04Q0A00`;2`0;2@X0518C01HD5@0>30d03@/<01@B4`0O7Ah07A/L018@4@80
3`d>01L04@l@010>3`0>30d03`d>014?400<2Pd04a4D01/I700@3Q400P0300@21@0>30l040hA014?
4P0>30l0518E01hL7`0Q7b803P`?00`:3@0:20/05A<F010>4@0200`:3@0R018@4`0@3Q402@L:00X8
2`0=2``040h?00d;300@3Pl07Q`M00h<3@0@3Pl02`T:00`:2`0;2@X04Q0A010=3P0<20T02`L800l;
300;1`P030P9018>3`0<20T02PH700l;30091@H05A4B038^;P0=2@P02`L600h:2@0B3Pd02`L6014=
30D03PX91P0?2`X00`0>2PT03@T800d9200300h:2@0300h92@0=1`L03@L700<03@L700T04P`<00l9
2@0;1@D03@L700l92@0=1`L02P@400`61P0@2PX00P0?2@T02P0D3Ph02P@4014;2`0=1`L04@/;00h8
200=1`L04@/;00`61P0B30`200T30`03018<300=1`L03@L700@03@L701P0208400/51`0<1PP0618D
028L7P0C3@l050h@010:300=1`T02`D700X41P0<1PP040H701<92P0900002`4200L0000J41405P`=
00d3100A1`P05P`=00/10P0O5AHDooooo`006oooool400`@4@0D00lC500@51D010P900lC50093@h0
3Q8C00`@4@0A5AH020`=00L;300:3Pl02`l@00`@4@0A5AH051PI05eQHP0N8R<0310A01DI6P0830d3
00/?3P0300X>3@0@51<05ATH00802Ph=00@02`l>014E500>4Q401@T80P0C5A801@0?4@h0418?014C
400>40d03a4>00803@l<00<03a4>00h@3@0=3``00`0=3`h02`0?4A004A<@018D4@0=3``03@l:01dO
6P0[;BP0i^WR08b?RP0I6aP030h;00803a4>00l0418?00h@3@0@4Pl0418?00lA3P0>40d03@l<01DG
4`0F61<051HA018D3`16B4<0VifH061RG@0A4`h00P0=3`X200h@2`0F018F400>5@h020d700lA300D
5A003@h900l?2`0E5Q4051D@010B3@062`D020d701`O6P0K7AP03@l:018D3`0:30L03a4<00h@2`0=
3`X03Q0;018D3`8051HA00<03a0;00h?2P0=3PT00P0?40/00`0>3`X03a0;00l@2`02010A300;00l@
2`0>3`X03`h<01DD4P0?3P`01`H400/:200;2PH030/6010?2P0B4@`00P0>3PH05@0D5@d03Q4:0044
000?4P/06A`E014D3@0D5a0030l800hA2P0?4P/03Q4:00d@2@0;3PL00P<001DF40092P@030d7010A
2`0A4P`0414;00l@2P0400h?2@0O02@V8@041@<05ALD02`^:`1GFED02@/6010C300?4P/02Pd60044
000?4PT07R4J01@F4@082PD02P`700`>2@0C5A003@l:010B3@0?4@`0418=014C3P0?4@`03Pl:024N
7@0:1PD09R8Q00h<2P0D4`l030/700l?2@0200h?2@0:00h?1`0=40L03A0701PI500L7AP061TD00X;
1P0>3`X06AXE010A30803a0;00H04A8=01@E400E5Q403@l<00h@3@0?4@h2014C4009018D4@0E5a@0
1@L4010B3`0R9240WZ2M07]mN@0G6A@02`d800803Q0;00H0418=00h@2`072@@051HA01TK5P0>40/2
010B3@0B00lA300<3PT02`d800d?2P0@4Pd04aD@014C3P0<3PT01PP300X<1`0A4`h04aD@00lA300@
4Pd04A<>010B3@0?4@`03Q0;0P0=3`X02@0>40/0418=01@F4@0>4@X04aH?018E3P0@4``05aXC01<F
3`0200lB2`<041<<00T03a8;01<E400B50l04aD@01@F4@0B50l03Q0;01LI500E5a800P0D5Q400`0C
5A004A<>014C3P05014C3P0907IhL`0k?CP061XE01@F4@0=3`X0828M03do>P0R91l04aD@00<051HA
01<05QPC01LI500G6A@051HA01LI500U9b80724M01HK5`0C61@04AHB018G4`0J7a/051TE01HK5`0>
4`l04aPD01PM6@0;40`05QXI00804aLH00@051PI01DI6P0D61T04QHG0P0M8B805@0D61T04QHG01`P
8@0D6QP06b4O01XP7P0H7Q`05Q`J01<I5`0B61H05adK01TO7@0L8R006AlM01<I5`0K92403aPE01DN
6`0M9R<05b0M018K600301PQ7P<06B8O00L06bHR01TT800H8al07RXV01l[:@0K9bD07B/[00806RXY
00P06b/[01d];@0O;bl062X^04IHG01NL7@09CLk02/m@@808C<g00/08cDi02do@`0fB4`0;T14028f
=`0S>CL09C/i02To?P0/@D80;T=402m4AP0202m4A`060315B@0aAT/0<DI;03=8B`0eBT/0=T]<0P0i
CTl03P0fBd`0=4U:03=8B@0bAdP0=T]<03]@D@0lDE80?E9D03]@D`0gC4l0<dQ;0356B@0bAdX0<dQ;
0P0bAdX04`0fBdh0>DiA03aBE@0lE5P0>E9G03]DF@0jDeP0=e1E03YCF00`BDh0?5EJ05=/L@1<IFX0
?eQM039;CP12FeP0<T]703I?B`0bBdP00P0iDTl02@0fCTh0>51@03]CD`0mEED0?UIH03eEEP10E580
?eA?03mDC@0203]@B@0K04MLE039g]D0LhQo0357>`0jD4@0?E=703]CAP0lDd/0?UQ@04=LEP14GEX0
A5aK04=KF`0oEeL0A5eK045JEP0jDdl0=Dm703I@A@15G580@UY>045HCP12FDl0AeiE04]RFP16GED0
B5mH0080BF1J00l0BEmK04QOF@0mDTT0H7IZ045GB`12F4`0@EM;0316>@0gCD00>U12049IB@10EdL0
?UE404]RDP14FTd00P0eBT403@14FE00>Di704EJD`19GUL0AU]F03mDC`15FUD0KX:00397@P0mDTX0
AEYA0356?@0lDDP00P0hCD@203]@A`0A03Y?AP0hCD@0>Di503Y?AP0kCTP0<dI003M:A017FU@0;Sli
0311>`0_@3X09cHa02He<00W=S40;CTe03<o>`0_?SL00P0]?3D03P0R<BX093</02hm=P0Z>C8062LP
010O600S<R/09cH_02Th;P0T<RD072TO01dZ800U<RP09C8Y0P0N:b80200T<BX09S</024^9`0O:bL0
8bhZ02</:@0O:2D072DR0P0M9R<0200Q:RL07bPU01`U8P0R:bP09c0]02@]:P0N9BD07R<V0`0O9BD0
@P0N928082HT01/Q7`0N92008RPT01hT800I81X05a/L01PL7`0H71d05QXK01DI6P0H71/06alN01<G
5P0H7AT07b@P01PM6@0A5Q002P`901<E4P0O8Ah04A<@01DG500I6aP05aTF01TK600E5a@03a4>01<E
4P0I6aP05ADC018B400I6AL06a/I01HF500H61H05ADC01@D4P0F5Q@05ADC01<C4@0I6AL071`J010@
3P0D51805QHD018B400E5A<02@T701dM6`0@40h020P600`<2P0>3P`040h?018@4@0A3a0040h?014?
400B41405aDF01@B4`0H5QL020H701@B4`<040h?00L04Q0A014?400>30d04a4B00d;300@3Pl04@l@
00803`d>00P040h?018@4`0>30l04Q0C00h<3`0C4A@07adP010>4@803`d@01@02`T<00`:3@0C4A@0
8AlR00`:3@0C4A@02`T<01XH6`0610L02PP;00d;3P0C4A@03P`?00T72P0>30l02PP9010>3`0=2``0
5A<D02l];P806ALH00/03@/<00P61`0<2P/0518C00l<3@0;1`P030P9018>3`0<20T02`L801<?4002
00X61`04018>3`091@H06ADF051<C0804Ph=00@05a<B00d9200;1`H0510?1@0>2PT600l;2P0300h:
2@0=2@P03@T800803PX900<03`/:00h92@0=1`L01@0=1`L05`0>20P03`T900h8200=1`L030H600T3
0`0=1`L04@/;00d71`0<1PH04P`<00X4100@2PX030H6018<300?2@T03PP800l92@070@403@L700h8
200B30`03`T900H03@L701P03PP:00/51`0:10H04`d?01LA4`0:10H03PP:00d72@0>20X02`D700X4
1P0A2`d01`0000d3100;0@80:AlP00d4100>10D040H700h41@0D2P/04PP901@:2`1:@44Dooooo`00
6oooool05@0>4Q<03A4B00`@4@0<41403Q8C00lC500<41403A4B01TM7P0<41402`l@00dA4P0@51D0
310A00lC500=4A80310A01LK700Z;Rl0EUYK01dQ8P0200lC500400`@4@0A5A@03A4@00X>3@802`l>
00X02Ph=00dA400>4Q402`l>00dA400?4a803A4@01DG500D5Q<03a4>0P0>40d02`0;3@X03Q0=010B
3`0@4Pl03@l<00h@3@0@4Pl0418A00lA400>40l03@l>00<03Q0=0P0D5Q400`0C5A00<SD_038d;`02
00`>2`03018D4@0;3@X03Q0=00H03a4>00<030h:01@F4@0620@00P0:30L06P0X:RD07b4L010B3@0>
40/030h900lA300@4Pd041@>00lD3P0>40/0418=014C3P0?4@`03@l:00`>2@0>40/04A<>00d@2`0?
50h08BDO01LI500@4Pd030h900lA300C5A00418=0P0?4@`0100B50l051HA01<E400A4Pd200l@2`03
014B3@0B4`h03a0;00<04A8=01D0414<00l@2`0>3`X061PF028R800K6aT02PX800d=2`0@4@`04a@>
014B300?40X04149014B2P0@4@T03a4=03m2>`0[;RL05APA00hA2`0:3@H00P0?4P/05@0>4@X03A09
00d@2@0=40T05AH@00h?2`0B4`d06Q/E00l@2P0A4P`03Pl9010A2`0A4P`0414;00h?2@0;30H04A<>
00`>2P0E5a801PP401@F4P02010B3@0;01TK5@0D5a005aXC00lB2`0C5Pl020X7010B3@0;3@P04Q@?
00h@2`0E5a800P0?4@`03P0C5A005ALB00lA300<3@P050l?010:2P0;1`L05a<B00T50P0H5a<03Pd8
00h?2@0?40X04A8:0P0A50/0200A4Pd030d8014B3@0A4Pd0<c@_05YKEP0@4@`04A8=100B4`h3010B
3`0G00lA3P0=3``030h;00`>2`0E5a@0418?00/=2P0V:2D0828N00lA300=3`X04A<>00h@2`0H6QD0
;S0[01HH4`0=3`X051HA00`>2@0@4Pd04aD@014C3P0@4Pd00`0?4@`01`0@4Pd03Q0;00lA300C5A00
3a4<018D3`0D5Q401@0?4@`02@0C5A0051HA018D3`0@4Pd03@l:00`>2@0O8Q/0:2/T010C3@02010C
300801<F3`0A50d04A@=014D3@0@4``03Q4:00d@2@0?4@`2010B3@803a4<00<0418=014C3P0A4`h0
0P0@4Pd2018D3`H04A<>00H0828M01HH4`0B50l04Q@?01dO6P0Y:bH201DJ500<01LL5P0D6A<03a@>
018G4@0=4P`04aPB01TN600D6A<04AH@01XO6@0H7AT04QLC0P0C61@01P0@5A404QLC01PM6@0L8Ad0
EeaH01<H50804QLC00P061`K01DI600E6AP05QXI01LK6P0F6QT04ADD01@H5`805QXI01005a/J01PL
6`0B61H05adK01DK6@0F71X06R0N01TO7@0H7Q`06b4O01LM6`0H7Q`06b4O01PN700E7Q/051dJ0P0I
8Ql01@0E7Q/05b0M01LP7@0G81d0624N00<06B8O00L08B`X02D_;P0N:2L072PV01l[:`0N:RX072XZ
00806b/[00T072`/01d];@0M;2h07Blc02Dg>`0O<CD09SPl01PZ;P0T=SX00P0V>3`01`0X>Sh0;d55
02do@`0W>c`0:3hl02Y0?P0/@T400P0^@d@0200_A4H0;dA70315B00bAd/0=4U>03E:C`0hCE00>Di?
0`0fBd`03@0eBT/0<dQ903=8B@0cB4T0=da=03Y?D00iCTl0>Di@03Y?DP0hCE00=T]>03=8B`0bAdX0
0P0`ADP01P0dBD`0=DY=03M<C`0lDU@0>51D03I?D`80>55E02P0=DiB03YCE`0fCe<0>55E04ENHP13
G600?EIJ03MAD`0lEE00?UQ@03mHDP0oF5@0>E9>03I?C00jDU80>e=C03iFF00nEUT0?EEI03aDE`12
EU@0?eA?041ED00oE4l0>Di803iCC00oE4`0=4U003U>A@0iCd<0?UA803aCB00nEDd0@5YB04ENF017
H5d0AemN04ALG017Gel0B61O0P19HUh01`17HET0AEmD049IC`14Fe00AEaB04IMD`18GeH00P18GeL0
2019H5T0B5mI04QOF@17GET0AEaF04UNE`0oE4/0?E990P13FDd06@12F4`0?E=603]AA010ETT0>e92
03YA@@1>IEH0DfUM02m4>`0iCTD0>Tm603Y?B00hCDH0>Tm8049GDP0lDD`0GG9]09FYY`1=HUd0>Di8
03iCC00gC4D0HGI_03I;A00oE4d00P0nDd`01@0lDDX0>4e603M<A@0hCDH0?U5;0080=4M10140A5MA
0311>`0oD4X0<D8l028a;00T<bh0;3/f02hj=P0]>CD0:STb02@c;00Z>C8093</02Dd;@0[>S<07bhW
020_:002024`:@0@02Dd;@0O;RD07R/Q01h[8@0P;B<082dT01l/8`0P;BD08BhW01l/9@0R;bT08bl[
024]:@0S;BX08b`Y01lX9@807BHS00<072DR01/T8@0K92400P0K9240;`0L9B806b@Q01`S8`0O92L0
8bTY024W9`0K8B4082HT02`b<00S:BL0728N01hT800L8Qh06b4L01`P8@0J7R406QhO01`P8@0K7b00
5a/J01DI600H71/06AhJ01PM6@0I7QX061dG01dO700J71T07AlL018D4@0G6AH06Q`I01TK600D5Q<0
5QPE01/M6P0H6QL05QPE01@D4P0L71X05QHD01DE4`0I6AL04Q8@01PH5P0F5Q@05ADC008051@B00<0
5aLE01<C4@0D51800P0@40h02`0E5A<05aLE01/K6@0o?cd05QHD01<C4@0D51805QHD01@B4`0B4140
4@l@0080518C00P04@l@00d;300C4A8071XK06m]KP1YIfP05A<D01@B4`804Q0A03<03`d>00`:2`0A
3a003@/<01<A4P0F51D04a4B010>3`0?3@h0518E00l=400@3Q403`d@01TG6P0X9RT040hA00d;3P0@
3Q403P`?00`:3@0>30l06QPK00`:3@0G5AP03@/>00l=400<2Pd03@/>00/9300>30l030X=01PF6@0/
:Rd06ALH010>3`0C4A802`T:01hL7@0>30d03`d>018@4@0<2P/03P`=018@4@0>2``03@T:00l;300H
51D03`/<00d92P0B3Pl00`0?2``02@0:1PL03PX;01LC4`0D4A00Ee=B010<2`0;1`H08AdL00l;2`0;
00h:2@0400d9200;1`H02`L600`81`803@T800<03@P800d71`0=1`L00`0=1`L01`080P803`T901PB
4P0C3@d03@L700`61P0=1`L00P0<1PH03`0>20P03`T900l92@0N61P07aTI010:2P0?2@T030H600/5
1@0=1`L030H6010:2P070P804@/;02TS8`0600d71`0H014;3@0>20X040X<00h82P080P@03PT:010:
300<1PP040X<014;3@0>20X04P`>01D:3P0D2@d03`H804Tn@P0I3Q803`@800`31@0?10P030850187
2`0E2Ph09a`P5?ooool001_ooooo00@020`=00`@4@0=4A80310A0P0:3Pl01`0@51D020`=00`@4@0D
61T02@d>01@H6@0=4A800P0?4a@0300=4A803Q8C00lC500N8R<0:Bd^00@82@0A5AH01`/<00dA4P08
30/04QHE01DI608020`;02005ATH01lS8P0Q9B@01PX9014E50072`X03A4@00h@3@0@4Pl03Q0=00/=
2P0A4a005aTF00`>2`072@H04A<@00`>2`0A4a005ALD01<E500H6QT02`d<00h@3`0A4a0010H300T;
200B50l04aD@00h@2`0<3`P0418=01PJ5`803a4>00<01`T601HH5@0<3P/01@0=3``0100<3PX03Q0;
00h@2`0;3@P200h@2`0K00d?2P0B50l03@l:01DG4P0h>SD0<C<^01<E400=3`X05aTD014C3P000@00
<SLa01/P6P0:3`T030h9018D3`0:30L02`d801<E400?4@`0418=00h@2`0<3PT04aD@00`>2@0=3`X0
3Q0;00<03a4<0P0B4`h02`0@4@`03Pl:00d>2@0=3PT02``701<D3`1ADTd06Q/F00L80`0D5A002`/9
00803Ph<00H04A4?00H6100B4`h03@h800l@2P0@4@/200h?1`0I00`=1@0E61403Q4:01/N5`0R9Ah0
3a8;01<F3`0>4@X02`h700X=1P0<3`P03A0900/>1`0<3@L04A8<018C3@0>3`T02``600`=1`0H6A<0
3Pl900/<1P092P@04A8<00<4000200d@2@803Q4:02003a8<00lA300;3@P05QPC00h@2`0620<03a4<
018D3`0<3PT04A<>00/=20072@@030h900lA300>40/02@/600/=200N81/04A<>00H70P0A40h06QHE
014@3P0@3`d02PT501PG4`0=3@P03@h801@E3`0C50`03a0801<D30803@h900L03a0;02<T7`0J6aH0
1PL2018C3P0=3PT03Pl:00804a@?00@0414<00d?300@4Pl03a4>0P0;3@X0400=3``051HC010B3`0B
51405ALD00L91P0F61@03@l:00L9100?4@`03@l:00lA300I6aH05aTD01<E400?4@`200d?2P0A010B
3@041P403Q0;018D3`0;3@P05QPC00d?2P0D5Q403@l:01<E400D5Q401`T4010B3@0C5A004Q@?00d?
2P0@4Pd00P0?4@`01P2BU8l07AlJ01DG4P0B50l03Q0;00hA2P804A@=00d03Q4:010C300J7AH06ahG
00d@2@0A50d05APA02@W800?4P/051HA018D3`0@4Pd04A<>00804aD@00<061XE01HH4`0B50l00P0?
4@`09`0@4Pd03a4<01DG4P0H6QD02@/6018D3`0G6A@07R0K01dO6P0?4@`04Q@?01@F4@0H6QD04QLA
020W8012BD809B`U01<J4`0P9b0061lH00lF3`0E71D051/D00lF3`0G7QL04aPD010E4@0D6AD0J6eY
01@I5@0?51005AXF01HK5`0@5A403a@@01<H500A5Q804aLF01@H5`0201DI60805a/J00d05ATH01dQ
800H71/04QHE01@H5`0F6QT06b4O01PN700P9R@04QPF01HL6P0G7A/06R0N00805adK0P0J81h00`0I
7ad05R0L01DP700401HQ7@0701TT800R;BT062<O01HQ7@0L9b<051lK02<];002020Z:@0601l[:`0V
<S807RXZ020^;`0R<S808C4a0P0N;C000`0Q<3<06R``01h`=00201la=@04020b=P0R=3P0838f020b
=P809CLk01@09cTm02/o@00U>cT0:T0n02Y0?`0Z?d00<TM802i3A@0^@dH0<dQ;03=8C00aAT/0<TM<
03E:CP0`ADP0;dA70397BP0aATT0=T]>03mDE`80>4e@00D0?eAG03U>D@0fBdh0>TmB03Q=D00203U>
D@1D0315B00eBTd0>DiA02Pm@00bAdX0?eAG0397BP0iCU40=4a>03=;C@0hD580>e=E03UAD`0kDeD0
@EUK049JG013Fed0@EUK041HFP11FEX0>55;03aFC@0nEe40>U=?03eFDP0oF5D0>E5A041HF013Fed0
BF5U03E=D@17Gf80AEUH03a@CP10E580AU]F03mDC`0mDT`0?55:03I;A00gC4<0?E9903iCBP10Edd0
@UUA045JD`12FeD0A5eJ04MPGP19HF40B61P04MOGP15GUX0@eaH049KE010FTl0@UU?04QPE011F4h0
AEaB04AKDP15G5@0NY6905ieKP18GeT0BF1J04QOFP10Ee40AEYC045FCP14FE00AeaC04AJC`14FTh0
>e55049HC00^A3L0>e5403aBA@0nE4L0=de103U>A@0kD4L0?E990P0nDd`05P0oE4d0?U=>03]@B`0h
CDP0?E5?049GDP0lDD/0?E9;03aABP12Ee00A5UB041ECP0nDd`0<TM003aABP0oE4d0<dQ103eBB`0f
BD<0?U5;0395?`0mD4X203U:A00:02/l=P0O;RT08c8]0350>`0a?CT0:SHb02He;P0U=2d0:STb02Dd
;@<093</00h08c8[01d/9@0W=Rl0:STb02Pf;P0X=B`09C8Y028_9P0P;B@07b`U02@a:P0P;BH07RXV
02<_;0807RXX00<08bd[020Y9P0L9B800P0K9240400I8Ql0624N01hW901QJVL0GVMT01PQ7P0O:2D0
61lO020U:00T:RX09R`/028X:00M8b408RPV024W9@0L8Qh201LM6@0601`R7@0K7b00:2`_04E9BP0P
92D0:bl`0P0A5A@03@0B5QD05AXF01LL600G71P05Q/E01/M6P0C5A807AlL01LI5P0B51405ALD01PJ
5`0F61D00`0D5Q<00`0A4a006a/I01<C4@0201DE4`0>00h>300F5Q@04Q8@00h>300K6aT05aLE01@D
4P0?3`d0410>01<C4@0D51804Q8@014A3`0C4a42014A3`804Q8@0P0C4a4601<A4P0601TG600@3Pl0
5aDF06m]KP1WIFH0518C1P0?3@h07P0;2@X03P`=010>3`0@3Pl03P`=00`:2`0H5QT09bDX03hl?`0Q
7b8040hA00T72P0;2@`04@lB01DC5P0>30l04Q0C00l=400C4A@030X=010>4@0?3A0020H901LE600=
2`h030X=01HD5`0C4A@02PP;00h<3`L03P`=00T02PP9010>3`0=2``040h?010=3P0:1PL03`/<014=
3P0:1PL00P0@30d500h:2`04010<300B3Pd04Ph=00l;2P8030P700L03`/:01HB4@0@30/01P81018>
3@0D40l03`/:00803@T800X030P700d9200=2@P030P700l;2P0<20L03PX900d9200810<03`X90P0?
2@T200`61P0400l92@0=1`L030H600d71`804@/;00l03PP800H0000B30`05a4A00d71`0<1PH03@L7
014;2`0I4a<02PD500/51@0A2`/03@L700h8200@2PX00P0>20P00`0S7Ad0Dde=00h8200200d71`0=
00`61P0=1`L03PP800/51`0E3a402`H700d72@0;1PL02P@600T31@0>20X02P@601LA4`0200l92`03
00h31`0H3A401`0000804PL;0P0=0PH01@0?10P05@X>01H;3`0?10P04`P<01Cooooo000Kooooo`0=
00T=3P0<41403A4B00`@4@0;3a003A4B00hB4`0S9bP020`=00T=3P0B5QL01PX;00`@4@0200hB4`80
310A00L03Q8C018F5`0J7Ql01PX;010D5@0;3a0041@E00804ADD00@00PH50496A@0f>ST000810P0N
8R4010072`X03Q8A00861@0:3Pd200X<2@0K00/=2P0G6AH0<38_03do?00M7a`030h;018D4@0?4@h0
418?00lA3P0N81l08bDT01PJ6@0L7Qd07R0M01<E4P0@4Pl02P`700P:1@0:30L04A@=01<E40010`00
3Q0=00lA3P0B5140418?00H03@l<00@03@l;00lA300?4@`030h90P0?4@`04P092`H04A<>01@F4@0<
3PT05aTD01TK5P0A4`h03@l:00T;1P0E5a80>3dg0<76`01]LV`05AXD00d?2P0A4`h02P`700H80`80
3a4<00d03@l:010B3@0?4@`03a4<00X<1`0<3PT03a4<014C3P0@4Pd03Q0;018C3P0A4Pd0414<00<0
3Pl:0P0:2`H06P0c=2l04Q<>00P9100D5A0051@B0000000F5Q@020P6014A3`0J6aH030d700h?2@0=
3PP030d5010A2@0A4PX04A@=00`?200B5@h05QTB00`?200>4@X04A@=00hA2P0<3`P03A090P0>4@X0
0`0?40X02``600/<1P02010A2`0700X;1@03100030d701DF400;30H03@h800h?2@0200`?20803A09
00`03Q4;00h@2`010`0030h900lA300H6QD01`T401PJ5@092`H03a4<00h@2`0<3PT300h@2`0700/=
200>40/04Q@?00/=200@4Pd0410>00/;2@02018B400U00/<1`0H6A@0414;00d>200?40X03a0800h?
1`0?40P03@h901LH4`092PD061TD01hO6P0O81/03a0;010A300?40/04A8=01@E400F5a803a4>018D
4@0A4a003Q0=00d?300?4@h00`D200`>2`0:30T05QPE01PJ5`0J71P071hI01@F4@0F61<03@l:00`>
2@02018D3`0:010B3@0>40/03@l:00h@2`0B50l02P`7010B3@0?4@`02@/600h@2`804A<>01404Q@?
00h@2`0?4@`061XE014C3P0C5A004Q@?00h@2`0@4Pd03a4<00H7100j?3L00`D001<E400c=C006adH
00`?200200lB2`0<00/>1`0<3`P051L@01XM5P0?4P/04aH?01TL5@0X:b@05QTB00lA300>40/03a4<
0P0A4`h0100>40/05aTD01DG4P0B50l200lA300Q014C3P0N81/02@/600P:1@0F61<061XE00T;1`01
0`002`d800lA300A4`h071hI01@G4P0F6aD0EeiG0?3gl01/Lf`06B0I018I4P0@5a0031<<01DL5@0F
7AH03QD>01<J4`0M8Qh061dI01/P701IGUX07B8N01TN6P0B5a<05AXF00804AHB00<05AXF01<H500D
61L0100D61L01@0C5aH061`K01lS8P0K7ah061`K00806QhM00L0728P018H5P083P`05A/I02P^;00=
4a406R0N008061hL00@06R0N01TO7@0F7a`05b4M0P0F8Ad301LR7P0?01TT800G8Qh051lK01TT800l
Ad<0:cHb024[:P0@6QT082XY02Da<@0I9BD06RHV01`Z:`0N;Rh07Bd]00806bX]00X07B`_01la=@0Q
<cL0838f024c=`0T=SX09CLk020b=P0R=3P09SPl0P0S=CT02P0Y?Ch08CLe02@j>00[@D00:d1102m4
A@0/@D<0;T=60356B@0bAd/203=8C@0H03A9C@0bAdX0<dQ;03Q=D00dBD`0=T]>03Y?DP0fBdh0=da?
03Q=D00dBD`0<dQ;03]@D`0eBTd0:d130397BP0gC4l0<DI902e2A@0oE5L0=4U<0315B00W?3l0>e1C
0P0dC4h01P0jDU@0?5AF03Q@DP0iDE<0>e=E03aDEP<0?UIH0240?eMH03aED@0nEe40>U==03YCC`0e
CTX0>eAA03UAD@0nEUH0?eMI04aTIP1;HfL0KXJ906MkNP1FJVP0?E5?03=8@`0dBD@0?E9=045FC`0o
E4d0?E9:041EC012Edh0?UE;045HD010FU80@EYD04=LF@16Ged0B61P049JFP13FeX00P14GET06`13
G5D0@UaA049IC`13Fdl0B5mE04ELDP16GE@0CFAL05E/I019H5T0@UUC04ELEP19H5/0B5mI04=HD`0l
DDT0?U=:041EC00oE4/0@5I:055WF`0jD4@0@EM:04ILC`0eBch0@EM:03]AA@0203]@A`0T03eBB@0m
DT/0?U=<045FC`0oE4l0?E9=03]@B`0nDU00@5AB03mDCP0mDT/0>Di703Y?B00iCTL0=4U203]@B@12
Ee00>Tm80356?`0lDDX0=4U203I9@`0eB480<TDo03I9@`0^?cT0<d@n02Tj=00L:bH07RdX02dl=`0c
?c/0;c/g02Lf;`0V=Bh0:STb0P0U=2d05P0X=c00:CPa02Pg<00V=Bh0:STb02/j<`0Y=bl09S<Z02<`
9`0P;B@07b`S01l/9@0Q;RL082dV020/:00S;b`082`Z01l[:@0O:RL07RLT01`U8P0J8b0201/T8@09
01lX9@0R:bP0CEIC051IEP0R:bP0:34^01lV9P0M8RD07bDU00808BLW01H08BLU020V900P9R@07B<O
01PN6P0G7AT06b4L01PL7@0I7B007B4R01LK700N8R<05QXI018F5@0D61L05a`H01XO6`0L8Ad07B8L
01`N6`0C5A806A/H0`0E5a@04`0D5Q<04aDB01<E4P0E5a@05QPE01DG500H61H04a<A01PH5P0I6AL0
4A4?01@D4P0H61H04a<A01@D4P0?3`d05ADC00h>300E5A<00P0B4Q000`0D51805ADC018B4002014A
3`804Q8@0P0C4a46018@4@0600/92P0D4Q<00@0001DC500I5aP04Q0A1P0@3Pl07P0>30d040h?014?
400@3Pl03@/<00`:2`0N71l05Q@G01TG6P0@3Q406QPK01@B5@0B41<02PP;00H41`0F51L040hA0040
0P0:20/04a4D00h<3`0;2@`04@lB00l=400@3Q403P`?01PF6@0E4aH03@/>010>4@L03@/<00/02`T:
00d;300;2@X03`d>014>3`0;1`P030P900h:2`0<20T040`=00d92P0500h:2`0500`8200<20L03PX9
00h:2@0=2@P00P0?2`X01P060P403@T801TE500B3Pd03`/:00`81`803@T800X030P700d9200=2@P0
3`/:01DA400A3@`040`;00`81`070`803@P80P0?2@T200`61P0400l92@0>20P03`T9010:2P803@L7
00@04@/;00l92@0G4A40618B0P0?2@T0100@2PX02P@400X410080P8201@>3P0800L20P090`<02`D5
00X4100600002`D501TC4`0>20P200d71`0<00`61P0=1`L03PP800d72@05004040/<01/E5`0<1PP0
71HH01XD5P0<1PP03PP:0P0400002@0I4aD03`@801D:3P0;00@03@8601462P0G31001`0001872`02
00L0000301872`07003ooooo01?ooooo000Kooooo`0?00`@4@0=4A803A4B00`@4@0?4a@04QHG014E
5P0S9bP03A4B00/?400?4a@02Ph?00/?400>4Q<03A4B0080310A03003A4B010D5@0;3a003Q8C00/?
400<41403A4B00dA40093@`02Ph=06Q/J`1MHF005ATH00hB4@0?4a802Ph=010D4`093@`05QXI010B
3`0>40d030h;010B3`0L7Q/092HS01dO70092`P03Q0=018D4@0F61D0418?00d?3P0A4a8030h=010B
4@0C5A8030h;00lA3P0<3PT03@l:010B3@0@4``04Q@?00d?300:30T030h;020R7`082PL600h@3@04
00h@300A4`h04A<>00h@2`804A<>01h03a4<010B3@0?4@`03Q0;00d?2P0?4@`03a0;01@D400@4@`0
51HA028W8@2NY9d0CeI?00hE3P042@<04A<>01LH4`0D510051D@00d?2P0<3PT04Q@?014C3P0<3PT0
2P`700d?2P0@4Pd04Q@?010B3@0=3`X2010A300600l@2`0>3`X03a0;010A300C50l030d80P0>3`X0
300=3PT03a0;018D4@092`P0CDm<00d?300>40d051HA010C300C5Pl03a8;00`?1P804A@;00X03A09
00lB2`0=40T02Pd600hA2P0<3`P05QTB010C300=40T03Q4:0P0@4``03@0>3`T0414;00h?2@0;30H0
3@h8018C3@0S91h03@h8018C3@0?40X03Pl900l@2P0<3`H00P0=40L300d@2@0?01@F4@0?4@d07R0M
00X;2@0@4Pl03@l<00lA300<3PT03a4<010B3@0?4@`04Q@?00h@2`0:30L03Q0;00804Q@?00d04QD@
01@J5P0D6aH03A@?00X>2P0?50h03a8=014D3@0?40X030d7018C2`0E5@d03`l700804A8=00<01PL2
01`M60061`800P0@4@`02@0A4Pd0414<00h?2P0D5A006AXE00h@3@0@4Pl03a4>00h@3@0200d?300<
00lA3P0;3@/04aDB00T;200C5A803a4=00h@2`0<3PT04Q@?00h@2`0?4@`0418=0P0=3`X300h@2`06
010B3@0>40/03a4<018D3`0H6QD05aTD0P0;3@P0100D5Q403a4<00/=200D5Q42018D3`0T014C3P0?
4@`03a4<00lA300A4`h01@L2014C3P0@4Pd092HQ010B3@0@4``04QD>01DH4@0B5@h041<<01<F3`0D
5a003a8;00hA2P0A50d06QdF00lB2`0@4Pd03a4<018D3`0E5a8051HA00lA300D5Q404aD@018D3`0A
4`h04Q@?01<E400=3`X04aD@0P0D5Q403P0E5a805QPC02<U80092PL08R@O020R7@0A4`h051LB00hD
3P12BD80VJ2I04U@B@0P9b002a8;0P0@5a00400K8Q/072<L01@K500D6a@04QLC00`A3@0@5A4082DQ
01<H500>4`l03a@@01@I5@0C61@051TE01LL600D6AD201DJ5P8051TE00h04aPD018G4`0D6AD05a`H
01DJ5P0G71P06b0L01LL600A5aD07bDS05ILFP0R:2H06b4O01dS8@806AlM00@06b4O01`R800I7ad0
51dJ0P0G8Qh01@0H8al06B@P01XU8@0J9B4072LS008062<O00X07BPT05YUH@1LIf<09c4b01dW:01:
E5D0BeMG01/V:00M:2X07R`]0P0M;2l05@0L:bh07B`a01h]<P0Q<cL0838f01la=@0P<SH09CLk02Tk
?`0X>Sh0:Sa002m1A@0/?T80:ce10355AP0S>CL09C/i03E:BP0_A4D0<4E602i3A@0202e2A@0=0397
B`0fBe00=T]@03A9C@0eBTd0>DiA03aAE00gC4l0=DY=03Q=D00jCe80>DiA03Y?DP02041EF00403Y?
DP0mDUD0?U=F03I;CP80=DY=00D0<dQ;03E:C@0dBD`0=4U<03]@D`0303Q=D080?E9E04/0>TmB03eB
E@0nDeH0?eAG045FF@13F5/0A5UL04=HFP0gD4`0@5UE03iGE017H5d0<da903aEDP0jDU80AEeM04IN
GP12FUX0?5AE045IFP11EE@0A5QF049FE013EeD0B5aJ041ED00hCDP0A5UC04=HD@0mDT/0A5UA03mF
C012FE40@EYC049KE@13G5T0AUiM04MOG`16GUh0B65O04YSG`18HEd0AEiG045KD019H5H0@e]?04YQ
E`0lDdT0BF1G041GC`17GUH0B5mH04UPFP1:HE/0B5mJ04ELE`10EE00@eQA04MLE@13F540?U=;04=H
C`0fC400?UA803]AA@0`AST0@eU<03eCAP10ETX0?U=:03eBB@0nDdX0@5E>045FC`15FU<00`12Ee80
2P0oDe40?51>03aAC00lDD`0>Tm:03iCCP10EE00?55<04MLE`13F5<203aAC080?E9=00l0?U5;03I9
@`0gBT@0<D@n02m0>P0Y>S@08S<]02<b;@0Y>3<0<T4l038n>P0]>CD09SD^02Lf;`0/>c@00P0]?3D0
2P0Z>C808C0Y024`:@0W=Rl08S4Z024`:@0V=2`09C8Y02@a:00S<2P2028_:00@020/9`0R;RX0930^
028^;00U<Bl0930^01dX9@0L9B807BHS01/T8@0J8b0072DR01hW900H8Ah06R<P02</:@806b@Q00<0
82LW020U:00N92@00P0M8b<06P0P9R@0728P01dS8@0L8Qh06AlK01LM6@0I81X06alP01XN8@0I7Ah0
61`M014E5P0S9bH07b<R01hR8@0J7a/05Q/G01@I5@0C61807AlL01XL6@0K7AX051HC01PJ5`0D5Q<0
5ALD0P0D5Q<00`0F61D05aTF01HH5@0201@D4P0301`L6P0M7A/05ADC008051@B00/04Q8@01/K6@0G
5aD06ATG014A3`0J6QP04Q8@010@3P0E5A<05aLE01<C4@03014A3`<04Q8@1P0B41401P0?3@h04Q0A
01@B4`0?3@h040h?00l=3PH04@l@01h040h?014?400@3Pl040h?00l=3P0>30d03P`?014?4P0@3Q40
4Q0C01HD5`091`X03`d@01<A500@3Q402PP;02@R9@1VI6L09R@W00T72P0C4A@030X=01<A500;2@`0
30X=00X82`0@3Q403`d@00X82`0<2Pd800`:2`0:00/92P0?3@h03`d>014>3`0?2``04@d>00d92P0A
3@h05A4B00`82@D03PX;00d03`/;014=300B3Pd040`;00h:2@0?2`X04Ph=01hJ6@0`;2/03P/:018?
3P0c;bh08QhM00803@T800H030P700d9200=2@P030P7014=300?2`X200h:2@0400/71P0?2PT03PP8
00l92@803@L701H040X:00h8200?2@T03`T900/51@0:10@03`T900/51@0>20P03`T900`61P0=1`L0
3PP800`61P0;1@D040X:00l92@0<1PH03`T900h8200=1`L03`T90P0B30`05`0<1PH03PP800d71`0=
1`L030H600d71`0>20P040X<05MAD`0H4a@03`X;01TC5@0=20T030H8014<3@0910D01`83014<3@0B
3@h060dC00h42@0J3aD04@H<00803P<900H04@H<00d4200K41H0200301D<400Q5Q`Dooooo`006ooo
ool03`0<41403Q8C00dA4P0<414041@E01@H6@0B5QL02@d>00lC500F6Q/01`/<01DI6P0=4A803a<D
00hB4`0200dA4P0D00lC500O8b@041@E01@H6@093@h02`l@00lC500B5QD01PX901DI600>4Q403a<B
00861@0B5QD03a<B010D4`0=4A001PX900hB4@0?4@h2018D4@0I00lA3P0;3@X02`d:00/=2P0:30T0
418?00lA3P0E5a@04Q@A00`>3@0>40l03a4@014C4P0C5A804A<@010B3`0C5A00418=00`>2@0F6A80
7R4L05QJE`0>40d03a4>020R7`02010B3`D03Q0=00@03Q0<014C3P0A4`h03Q0;0P0A4`h05`0@4Pd0
20X500<5000@4Pd04aD@010B3@0?40/040l;018C3P0>40/000<000`C300@6Q803QD>00`A2`0A50h0
4A8=00l>2P0=3PT02`d800lA300@4Pd03@l:00<03a4<00@03Q0;00d?2P0=3`X03a4<0P0?40/200h?
2P0R00l@2`0@4@`05AHA01@E400;30L05QLB014B3@0;30L04aDB00T;200C5A801`T6014C400=3`X0
4A@=01TL5@0G6Q<04QD<01HI400?4PT02`h701<F3`0A50d03Q4:01DH4@0<3`P04aH?00lB2`0<3`P0
3A0900lB2`0>4@X03a0:014B3080414;00X04Q<=01DF4013A3h0414;00X;1@0@4@/04Q<=00`=1`0?
4PT03a880P0?4PT0:@0?4PX03a8;00/=20092`T061XG00430P0C5A@061XG00`>2@0:30L05aTD01HH
4`092`H03@l:00T;1P0K7AP02`d800h@2`0J71L00@H0010M5`001@000a09018M5`0B71@07RDN00lC
300@4@/03a0:01DE3@0E4P/03Ph600`=200C50l0414<01LH4`0S91l0JFYU01DF4@0?40/03Pl:0080
4A8=00<0414<00lA3P0@4Pl00P0A4a00200@4Pl03a4>01`N6`0:30T03a4>00X<2@0;3@X051HB0P0?
4@`00`0@4Pd030h900/=200200h@2`0A00lA300@4Pd03a4<00h@2`0@4Pd04aD@00d?2P0<3PT04A<>
00d?2P0@4Pd0?T0k01`N6@0=3`X051HA018D3`0b=2l00`0@4Pd200d?2P08010B3@0=3`X03@l:00lA
30051`804aD@00X=1P0=40T2014D3@8041<<00`05APA01LJ4`0A50d04QD>01@G400C5Pl05QPC01@F
4@0C5A0051HA01DG4P0D5Q42018D3`0T014C3P0B50l04Q@?01<E400E5a806adH01@F4@0G6A@04Q@?
01`N6@2DUY40;S0[00X;200D5Q4030h900`@2P0X;bP000L001lY8@0C7AD0:38Z014K4`0?6A403QP@
010J4P0?6A4031H>00hE3P0F6aL051TE01XO6`0>4`l06AhJ018G4`0A5Q805Q/G0P0D6AD0100F6aL0
4AHB01DJ5P0E6QH201HK5`805a`H00H051TE01HK5`0E6QH061dI01dR7P0H7AT201`R800=071fM00h
?S`03A<A018H5P0H7Q`06AlM01/Q7`0L8R0061hL01<L6@0F8Ad05R8N01LS7`0201TU8@0>01XV8P0L
:2@09C4]024]:@0I9B4041`H028^:P0O:BX031HG02@^;`0P:bd062<U02@_<@0P;S4201l^<@<08C0e
00D072hb01la=@0P<SH0838f028d>00202Li?@0a02Dg>`0V>3`093Hj02Hh?00/@44083Hd02Lm>`0a
AdH0:3dn02a1@P0_A4H0;D9502a1A00aATX0=T]@03E:C`0dBDh0=daA03Q=DP0eBTl0=4U>03E:C`0g
C540=DY?0356B`0fBe00@UML045FF`10EET0>TmB0397BP0gC4l0@UMJ03U>D@0cB4/0KhB703I;CP0Z
?d808SLj04AIG00jCe00>Di?03]@D@0jCe00>Di?04EJF`0nDe@0?E9C03iCE002045FE`0j03aADP0d
C4`0?EEE03mGE`13Fe/0<TY:03iFEP0mEU<0@EYG049KF00jDe00?eQE04AMFP0mDE00@EED03eAD00n
DU00AUYH041DDP16FeH0FVmZ05M/I@0mDT/0?U=<03eDC015G5@0@eeE04AME`15GU/0Af1N04UQH@1;
Hf<0CFET04eVHP1;I600AEmG041JC`15G580AeiC04ELDP12FDl0JX5h04YQF@16GED0@UUB04ELEP1;
HU`0C6=N04ILF@11EU40AU]E04MLE@19GUL0K85i09baZ018GE@0:d4f03I<@080A5Y>01L0?E=7041F
BP0nDdX0?U=:045FC@15FU<0AeaE04EJD`13F5<0A5UD04EJE@0oDe40>Ti<04AIE012Ee80?U=>03mD
C`0nDdh0>Di908bQW02dbL@0B5eH03]@B`0203I;AP0?03Q;A@0eB480<D@n0395?`18FE<09CH`01l`
:P0Y>3<0;chi030o>P0]>CD0:cLc02`k=00^?CH0;chg0080<3lh00@0:STb01l^9`0P;bP0:CPa0P0S
<R/03@0T<R/07b`U01l/9@0P;BH07b`U01l[9`0M:BD082`X028^;00O:bX082`/028^;P0P:RP00P0N
9b@0:P0M9R<06R<P01XS800P:BH0:34^01`U8P0O:2D08R/X01/T8@0S:RX08RLZ028X:00P9RH07R@T
01`R800J81h0728P01`R7P0I7a/05adI01TO6P2CUiP0If]^02P/;@0R9RL07b<T01TM700E6AP051PG
01<H500D6AD05AXF01PM5`0D5Q<05ALD01dO700B51404aDB01@F4`0H6QL05QPE01DG50805QPE01<0
4aDB01DE4`0E5A<06QXH01TI5`0F5Q@05aLE024Q7`0<30X071`J01DE4`0820H03`l=01@D4P0C4a40
410>00l?3@0B4Q005ADC00D04A4?00<0410>014?400A3a00100A3a001P0D4Q<02`T:01PF5`071@H0
3P`=014?40L03`d>00D03P`=00d;300>30d040h?014?400300l=40802`T<00`05aDH00l=40010080
3`d@01LE600/:Rd0NGMj038`<`071@P06ALJ00X82`0@3Q4200l=400300`:3@0?3A0040hA00803P`?
1P0>30d02`0@3Pl02@L800T7200A3a001@<400/82@0=2@X05A4B014=3P0>2P/0510A00H03PX;00d0
4Ph>01HB4@0F4Q404@d<00d9200<20L03PX902dY:019AD@03@T800<0000L61L04@d<00803@T800H0
30P700d9200=2@P02PH5018>3@0A3@`200X61@0400P40`0<1`L03@L700h820803@L70P0@2PX01@0=
1`L03PP801<=3@0D3Ph030H600802`D500H040X:014;2`0?2@T03@L701<=3@090`<200L10@0901D?
3`0=20P03PP800d71`0:10@02@<300X4100=1`L03PP800803@L700X030H600d71`0>20P040X<048l
?P0;1@L0100000P2100?2@/050h@0P0:10H03`0I4aD0;2HX0=WCe@18?D<04`T>00l42P0;00H04`P>
01@93`0J3aD060dC0146300G3180B3e301873@0Dooooo`006oooool01P0<41403Q8C00hB4`0=4A80
3a<D018F5`803A4B00D020`=010D5@0=4A803Q8C00dA4P0200lC500C00dA4P0>4Q<03a<D01`P8@0B
5QL041@E00dA4P0<414051PI00dA400;3`h05ATH00P;2P0N8R4061`K010D4`0?4a804ADD00hB4@02
00`@3`0<00h@3@0=3``03Q0=010B3`0B51404aDB00h@3@0F61D061XG00`>2`0?4@h030h;0P0:30/2
00h@3`0>00d?300?4@h0418?00d?2P092`H051HA03/n=`0o@Sd0LG=`01PJ5`0C5A804Q@A00h@3@0;
3@X500lA3P0400h@300@4Pd0418=00d?2P80418=01h030h900h@2`0B50l04Q@?00/=200=3`X0410<
00X91@0@4@`05aTD014H4@000`003AL?00`F3P0@5@l041<>00d>2@0=30P03Ph900d?2P0@4Pd03a4<
00/=200@4Pd04A<>010B3@0=3`X02`d800`>2@0?4@`2010A300500l@2`0>3`X03Pl:00l@2`0<3@P0
0P0?40/02P0G61<04A8=00`=20082PL03Q0=00830@0<3P/04A<@00d?2P0;3PL201HI4P0M01<F3@0I
71<04A@;00X=1P0A50d04QD>010C300D5a0030l800lB2`0=40T030l800d@2@0>4@X03A0901@E3`08
2@<03@h801dN600O81X03Pl902<T7P0>3`T04A8<00h?2@0A4P`04Q<;014D2`0A50X00P0@4`X03@0?
4PX03a8;010B3@0A4`l03@l<01PJ6@041PD03a4>00d?300B50l0:R`W02LY900@4Pd00P0C5A00600f
>3<05ALB00P:1@0R91l02A09051RFP1@I5/04R<K00TG400D7aL04Q`D00hD3@0>4@X04A8<010@200@
3@H04A4900h>2P0@4@`051D@01<D3`0H6A@0DeA?01HG4P803a0;00l04Q<>00l@2`0;30L030h;00/=
2P0<3P/03Q0=00d?300;3@X0>C/h02PZ9`0A4a005QPE014C400>40`00P0A4`h0100?4@`030h900`>
2@0@4Pd2014C3P0@010B3@0?4@`03Q0;00lA300B50l030h900d?2P0>40/04A<>01/M6016B4<071hI
00h@2`0C5A001@L202h`:`803a4<00`04A<>00d?2P0<3PT03a4<01`N6@051`805aTD00h@2`0A4`h0
3A0900hA2P0A50d201<F3`04018E3P0?4P/05aXC014D3@8051L@00P06ahG01@F4@0B50l03a4<014C
3P0B50l04aD@014C3PD04Q@?00L030h901LI500P8Qd06adH0043000`<Rd0=CLb00804A<>00`071hI
01hP6`0C5Q4000L001lY8@0=5`l03QP@00PB2P002P804adE010J4P0=5`l200`F3P0900dG3`0A5Q80
4QLC01HK5`0=4Ph04aPD00lD400C61@05a`H008051TE00<05Q/G018G4`0E6QH00P0F6aL01@0G71P0
6AhJ01TN6P0D6AD061dI00805AXF01806AhJ01LL600B61H06b4O02X`;P0U:bT06b4O010F500I7ad0
61hL01XP7P0K8Al06AlM01@M6P0E81`05B4M01HR7P0H920201TU8@0?05UUH@0U<Bd04alK02lk=`0D
81`05b<O028/;@0G8B8082X[01/V:00S;S00:3<e01l]<00L:bh07Rd`00808C0e00<07bhc01d_<`0R
=3P00`0S=CT04@0^@4@0<TA802do@`0[?D40:3Xn02Xl@00/@44093Xh02a2@00_A4@0:d110356A`0a
ATP0;dA702i3AP0`ADT0<dQ=0080=4U>0P0fBe005@0aAT/0<dQ=03E:C`0iCU<0=T]@03=8C@0hCE80
>TmD03eBE`11EUX0=T]>02m4A`0hCE00A5UL04MLG`0mDUD0AEYM03M<C`0eBTd0OiBG04IKGP0203]@
D@0Q03aADP0iCTl0>4e>04EJF`11EUL0?eAE041EEP14FEX0@eQI03eBD`0lE5H0>E5C03Q@D@0iDE40
?EEE03iFEP0lEE80>U=@041IE@0dCDT0=Tm;03E>BP0iCD`0?E5@049FE@18G5X0BemM049FE013F5<0
DfQS05AYHP0oE4d0@EI?0080AUeE0100A5iF04ENF015GU/0B61O04UQH@16GUh0B65O04URGP18HEd0
AEmG049LD@15G580BV5F045HCP14Fe40JH1g0P1:HET06013FU<0@eYD04YQF`1<Heh0AUaI04EJE@19
GUP0AEYC03aABP14FE40GgA[0315?010ED/0<dTm04AJCP0lDTH0AUa@03mEB@0nDdX0?eA;049GCP15
FU<0AeaE04AIDP<0@eQC00h0?e=A03a@CP0mDTd0?55<03Y?BP0nDdh0?eA?03Y?BP27W9L0Ykbg04IK
EP14FE@0=T]603iCCP80?E1:00H0>di8045DCP1WN780=TM102@e;`0V=C0202Dd;`0802lk=`0d@3`0
=4<l03A3?00_?SL0;C`e02/j<`0V=Bh202<b:`0502He;P0T<b`09C@]02Hd;@0T<BX00P0U<R/04@0T
<BX08bl[01l[9`0M:BD082`Z028^;@0K9bL07BTY028/:`0O:2D07RLT01lX9@0N9b@072DR01XS800V
;b`07bPU008072DR00L05AhK01`S8`0O92L08BLW028X:00Q9bL07R@R0080728P00X0728N01TO6`0H
7QX06b4L04iBD`0k?d803Q8C01XN7`0F6Q/06AdL0P0F6QT02@0F6aL05a`H01PM6@0I7QP05aTF010B
3`0H6QL04Q@A010B3`0201HH5@805ALD0P0G6AH04`0F61D05ADC01HF500G5aD05QHD01DE4`0H61H0
3Ph<02HV901UIF<0HV9P02h^;00=3@/04A4?01<C4@0B4Q003`l=014A3`0E5A<00`0A4@l3010@3PH0
4Q0A00H06ALH014?400I5aP030X;01<A4P0B414600l=3P06014?400?3@h03@/<00h<3@0A3a004a4B
0P0@3Q404`0?3A0020H900@21@0H5QT02`T<00d;3P0>30l040hA00400P091`X0518E01HD5`0E4aH0
1`D801<A500>30l03`d@00/9300<2Pd00P0>30l00`0=2`h03P`=00h<3@0400h<3@0:018@4@081PL0
20H700d;30010000514B00`82@0A3@h040`=00T51PL03PX;00@03`/;010<2`0A3@`03`/:0P0<20L0
1`0:1PD020@301/G5P0D40l01`<201@@3`0@30/00P0=2@P0100<20L03@T800d9200;1`H201HB4@06
00d9200>2PT030P700h92@0=1`L03PP80P0=1`L01`0A2`/04P`<00h8200@2PX06Q@D01/E5@0>20P0
0P0=1`L04@0@2PX03`T900X4100<1PH04P`<00l92@0G4A40100000L10@0E3`l03PP8014;2`0D3Ph0
40X:00h8200?2@T03PP800803@L701/030H600d71`0>20P0100001/E5`0=20T05@lA00H10P0L5QP0
3PP:00h92P06008040X<01@?402DSY00=b`b01<83P0A1P`04`P>01052`0:00D01`0200l42P0;00H0
1`0202<H7P0900@05?ooool001_ooooo00d02`lA00hC500?51D03A8D00`A4P0=4Q802Ph@018F5`0:
3Pl03A4C00/?400A5AH0310A00803Q8C0100310A00dA4P0>4Q<02@d>014E5P062P/04ADF00@82@0@
51D02`l>018F5@0<40l02`h=00lC4P062PT0310?0P0?4a80200>4Q404QHE00T=300?4@h03Q0=00lA
3P0@4Pl03a4>0P0>40d05`0I6aP06Q`I010B3`0C5A803a4>010B4@0=3`h04Q@C00lA400;3@X0418?
00lA3P0A4Pd03a4<018D3`0Q8ad06A/F01TK60082@L03a4>00H81@0B514030h;00D03a4>00@03Q0<
00lA300?4@`030h90P0?4@`0100<3PT05QPC01`N6@0C5A0200d?2P0B00l?2P0A40`020T4018D3`0=
4`d06R4J00XB2`0;4``0314;00d?2P0A4Pd04a8>01LG4`0C5A003Q0;010B3@0>40/03@l:0`0?4@`2
00h@2`0400d?2P0B4`h04Q<>010A30<03Pl:00L03a0;00X;1P0A4Pd04A8=00h?2P0=3`X030h;0080
3a@@00T02a0<010E4@0=4P`02Pl901DJ4`0@5@l02Q0701<H400;4@P00P0?4P/01`0A50d04QD>018E
3P0B5@h02`h700`?200>4@X00P0A50d03@0=40T03@h8014B300H6A<06a`F01DF400:2`D03@h800l@
2P0A4P`02@X4010A2`0?40T00P0@4`X0:@0?4PT03a8:00hA2P0>4@X04A<>00`>2P0>40d02@/905EG
E@0O8Ah04aDA00lA300P8Qd06adH010B3@0[;BP08B<N02PZ9@0<3PT03Q0;034c;P0I8AX0SYnG08jQ
V00L;bD01QL>00PD300;4``03Q@<00T=1P0D5Pl0414:01TG4@0/;BH03`l:01DF4@0C50l03a0;00P9
1P0@4@`04A8=008051D@01T04A8=00h?2P0>3`X03@l<00/=2P0>40d04Q@A010B3`0=3``05QPE00T;
200B51401`T701@F4`0<3PX03Q0;010B3@0>40/03a4<018D3`0C5A004A<>00lA300>40/03a4<0080
4A<>01P04aD@00d?2P0@4Pd02@/601HH4`0[;BP06Q`G01<E400>40/03@l:00`>2P0C5Q003a8<00hA
2`0B50h030h900/=200B50l061XE018D3`0?4@d051LA00h@2P0C5Pl3018E3P0?018E3@0A50`02Pd5
01LJ4`0?4P/04A@=00h@2P0K7AL0418=00lA300@4Pd04aD@018D3`0?4@`04Q@?00<04aD@01X04Q@?
014C3P0H6QD0<S@_01XL5`0E5a804aD@01HH4`0G6A@05ALB018D3`0A4`h03Q0;01HJ500i@3T0@Ta4
00`F3P0D7AD04Q/C018L500C71@04Q`D010J4P0@6A404Q/D018K4`805Q/F00X041D@01TN6@0@5A40
51TE018G4`0E6QH04QLC01<H500I7QX061dI0P0G71H201HK5@805AXD00d05a`F01hS7@0J7aT05AXD
01LL5P0H7AT051XH01TO7@0@5Q@0:Bl]01TO7@0H7Q`06R0N008061hL0P0J81h06@0G81d04ahL01@P
7@0E8Ah05b<P01PT8@0I9B805b<P01dY9P0C7a`07b/X028^:`0I9B807bTZ01`V9`0Q;2`09c8d024/
<00J9bX07Rd`01/Z;`0M;3408S4f024`=@0O;c@00`0Q<cL03`0R=3P09SPl02Pj?P0U=c/093Hj02Li
?@0V>3`09cTm02]0@@0Z@3h0;D9202a2@P0hCDh0?E9C0356B0020397BP090315B@0_A4T0<TM<03=8
C@0fBe00=daA0397C00eBTl0=daA0080=T]@04P0?E9G045FF`0cB4d0@UML06f2QP1MLGD0@eMJ03Y>
DP0aATT0>TmB049HF`0`AdT0?E=F049GFP23V9/0A5UL03aADP0nDe@0@eQI03eBD`0gC4d0?U=D045F
E`0oE5D0@EIG04QMGP19GUh0@EIG03eCE`0^ATX0A5aP05M_LP1eSHl0AemP04AMFP0dCDX0?UMB03I?
BP0hDDX0?eQ@04iSG`14F5L0@EEC04AHEP13EeD0AEUH04YNF`17G5P0AUYG04EIE@14FE<0A5]D04IM
EP14GUH0A5eG04ENFP17Ged0B61O04aTH`1;I640BF9N04MPF`15GUL0@eeC04MNE018H5@0@UU?04EL
DP1;HUT0C6=K04IME@17GUL204MNF00<04UOF`1:H5d0AeaG04IKEP19GUP0B5eF045FCP10EDd0?eE:
06UnL`0nE4P0JX1d0P11Ed`01010ED/0@EI>049GC`12Edh2049GD00J041ECP12Ee80@EIA03iCCP0n
DU00@5AB03eAC`0oDe40?U9@04AHEP17FeT0@eME04AHEP10E580=TY803iBD00eBDL0=T]603U<AP0_
@S`0>4]503A7@@1IJV@0:CXd02Lh<P0Z>C@202Lf<@0403I3?`11CTX0<T4j0391>P80:cXc00D0:3L`
02Dd;@0Z>C809cH_01l^9`02028a:`0Y028`:P0V<b`09c@]02Ld;P0U<Bd08bl[02<_;00O:bT0:3@b
03A0?`0P;2/072PX02D_;@0M9R<06b<P028[9`0W<2`08BXV01`U8@0T;BX09Rl/01hX9@0Q:RP08R`[
020W:00O9BH082HU01lU900M8b806b4N01hT8P0N9240728N01PN6P0I7a/07R@O01PL7@0Y;Bl05QXK
01hR8`0G6a`00P0F6QT01`0G6aX06AhJ01TN6P0I7QX05a`G0412?`0Q8b000P0H6QL01@0B51405QPE
01/M6P0I6aP05aTF00805QPE00@04aDB014A3`0E5A<05aLE0P0F5Q@0200G5aD05ADC01PH5P0M7A/0
6a/I02<S8@0G5aD05ADC0P0B4Q0201DE4`<04A4?0P0@40h200l?3@0301<A4@0C4A804a4B00<04a4B
00H03`d>014?400@3Pl03P`=01@B4`0>30d6014?400N01/I6P0G5AH040h?00l=3P0A3a004a4B014?
4P0G5AP030X=01@B5@091`X03@/>00l=400B41<03`d@00h<3`0G5AP05Q@G00d;3P0>30l04@lB018@
4`0<2Pd03P`?010>4@0<2Pd02PP;00h<3`0?3A003P`>1P0=2``0300>30d02PP900d;300=2``05A<D
04=0@@0E4A802PH7014=3P0:1PL03@T:00l;30D03PX;00X03@T900d;2@0?2`X03P/:00h:2@0?2`X0
4Ph=010<2`0>2PT03@T80P0@30/300d9200T00`81`0=2@P03@T8018>3P0U8B008alN018>3@0>2PT0
2PH500`71P0=20L03PT800d71`0>20P04@/;00d71`0<1PH03PP801<=3@0D3`l04@`;00d7200<1PL0
3`T:00d7200<1PL07ALH03`f=`0C3@h08A`L01H@4@06004030H600X51@0;1@D03@L70P0?2@T200h8
20803@L701/030H600d71`0>20P03`T;00d82@0?2P/03PT:00l:2`0=1`T04Pd>01PB500B30h03PT:
02@N800G4A<03P@901@:4@0?1@/04`P@01063@0R61l04@H>00d42P0D2Q004@H>00`42@0G3A@05?oo
ool001_ooooo00H03QHI00TA4`0U;Bl09Bd`00`D5`053@l200hC5`0G00hC5P0?4QL03a<G00lC5P0?
4a@03A4@014E500B5QD06alN020T8`0;3`h03A4@00X>3@0?4a8041@C00`@3`0A4a803Q0?00`>3@0=
3`h0418A018D4`0?4A000`0@4Q403P0>40l03@l>00X<2@0?4@h05QPE010B3`0C5A80418?00P:1`0B
514030h;01dO7029RhP06Q`I0P0;3@X0300E5a@030`:00X:200C4a4030`:010?3@0>3@/04A0>018A
3`0>3`X02a0:00`A2`803A8<00P0314=00dB3P0?5100310?00D9200;3`h02Ph=00`@2`8030h900D0
2`d800lA300C5A004Q@?00h@2`0200d?2P0L00h@2`0?4@`0418=01<D3`0@4@`03Pl:01dO6P0N81/0
4A<>00h@2`0@4Pd04A8=010A300A4Pd06AXE018D3`082PL010H100X<1`0;3@P061XE00d?2P092`P0
1PP301HH4`0:30L03a4<00h@2`8030h900<03Q0;014C3P0B50l00P0A4`h0400?4@`03@l:00`>2@0?
4@h02@/8014C400O8Ah0;Bl/00`>2`0;3@X051HA01@F4P092`H02P`700/=200A4P`2010A2@06014B
2P0@4@T03Pl700d>1P0;30@041490P0C50`02P0G61803Q4:010B3@0@4Pd04Q@?00d?2P0>40/02@/6
00d?2P0F61<2010B3@0800/=200;3PL041<<00X=1P0@4Pd03Q0;00lA30072@@2010B3@0I00d?2P13
AD40:B/V00h@2`0=3`X03a4<00T;1P0V:2<0JF]V010B3@0L7QT04Q@?00/=200I6aH041D>01TP5`0S
:R8051/C00L<1@0<4@X03A8;00X?2@0C61802@h:00h@3@02014F4P0>00hA2`0;3PL03A09010C300?
4P/03A0901<F3`0D5a003a8;00`?200I71D01PP300h@3@0=3``200P:1`0?01PJ5`0F61D0418?00h@
3@0<3P/04Q@A00`>2`0>40`04aD@00lA300<3PX05QPC00lA300@4Pd04aD@00803a4<02T051HA01LI
500D5Q401`P300h?2P0E5Q40414<01<D3`0@4@`02@X502HW8P12@ch03@h90001000@4P/03a8700lB
2@0?4PX03a4<00lA3P0<3P`05QPE014C3P0@4`/05AP?018E2P0?4P/03A09014D2`0B5@`03A05018E
2P0>4@H07b8I02d`:@0=3`X01`T601@F4`0?4@`03a8;014D3@03018E3P1=01HI4P0C5Pl041<<014D
3@0D5a005QTB01LJ4`0b=Bh092LP0085000@4``061/D01HI4P0C5Pl04QD>01HI4P0G6Q<051L@01XO
6@0E6aD04QTB05aQF`0D6Q@03QD>014F401>E4d061lH01hS7@0D6Q<02Pl901HK500L8AX06AhG01<H
4@0?50h04aPB01@I4`0C61<051TE01HK5`0E6QH04QLC0088100K8Ad05A/G01`R7P0F71P04ALC03Pn
>P0^=30061hJ01/Q7@0E6aL03A<?01LM6`0J81h07B<Q01/Q7`0G7A/051XH020V900E6aT092XX01@J
600T:RP051dL01XU9@0K9bL062@T01LS8`0P;2`05B4Q01XV9P0K9bL06BDU01hZ:P0L:2P00P0O:b/0
500Q;Bd072XZ01PV9P0I9bP06RXZ01h]<00P;c807c4c01h`=00L;S806R``02<f=`0Q=CH093Pi01hb
<`0[?d008SHg01lc=00L<3409c/l0P0]@D803`0/@D80:3dn02Xo@P0bAdX0=4U<0315B00]@TD0;dA7
0356B@0dBD`0<dQ;0397BP0`ADT0<4E:03=8C@0203M<D@1U03I;D00hCE80A5UN04iSJ01KL7D0=DY?
05U^L`3FiNP0dn3V09:QYP0kCE40@eQK03M?D@0lEUL0>59C03=<CP18GF00@UMJ03]>DP12EET0?U5E
03a?D`0oDUH0@UEI041DE@11EEH0@UIG04]OGP1<H5l0@UID03iBDP10EEX0@5AK045EG@1OM7T0LXN:
04]PHP15FeT0@5ID03A;AP0dBdD0?5=;03eDB`0nEDd0A5]C03iED01CJFH0BV1N06j3Q02=XZD0B5eP
04IKG@1dRHX0@eQI04AJF019Ge`0@5MA04QOF@13FU@0AUaI04UOG01=Hf00CfER051WH@1?IV00C6=M
04QOE`1>IE/0BV5G04ELDP14Fe<0AeiF04YQF@16GEL0@UUC041GD@13FEH0B5iK04YPG@19GE/0AeaG
04aQFP16Fe80B5iA03aBA@0cBC`0@5I:02e3=`1ZOgH0@EI@04IKEP0oEE80B5mI04=JE012FE40AeiD
04IMD`10Edd0<dY203aCC@1<HUh00P0nE580700nE540>U1=041FD`0iCd`0?E5?07>7Q@0nDU00A5ME
03Q;B@0kCT`09CPf03M:AP0iBT80=DHn03A5?@0cA3`0834[02@e;`0S=2h0:3Pe02dm>P0_?c`0>4Q5
0391?P0fACd0;chg02Pg<00V=Bh202Th<`0D041?BP0O;RT08C0/02@c<00V=C80?4Y602Xf<P0O:bL0
82`X028^:P0Q;BT08RhZ02<_:`0T<2`08bl[01l[9`0M:BL08BTV024W8`0N8al201dT700K01/U700L
9ah062<M02@_:`0H8b<0?TU=0;>na00b>C`07R<O028W8`0L8Ad082DQ020U800M8Qh07B8L02T^:00F
6aD06QlI01`Q702UYjH0HfET01`N7@0J71/061XI01TK6P0C5A@051HE00806Q`K01`061XI01hP7P0J
71T05ALD01HH5@0H6QL04aDB014C400L7Q/0=3Hc04]=BP0O8Ah01`T601HH5@0H61H03@d;01XJ6006
1P@06ATG01LG5@0F5Q@05ADC024Q7`051@<05QHD00/;2@0@40h04A4?0P0B4Q00100A4@l03`l=01HF
500G5aD201lO7@0A01TI5`0H61H03`h<01@C4@0J6AL061LE018A400E4a@03@/<00`:300I5aX04@lB
01HD5`0D4QD05aDF01<A4P0A3a000P0B4140200?3@h04Q0A010>3`0?3@h04@l@00l=3P0>30d03`d@
0P0>30l0400?3A0040hA010>4@0?3A002PP;00h<3`0Q7b807Q`O00l=400>30d01@<401HD5@0<2P/0
0`4201@B4`0<2P/200h<3@0400d;300<2P/03@/<00`;2PD030/902004A0>00H50`0?3P`03Pd;014@
3P0?3@`04@d>01<?400=2@X03PX;00l;300E4A80100101@@4@060P<06aLH00<0000=2P/02PX:00T7
200<2``020H700H41@0>30d02PP900X61`0<20T03@T:00d72@0>2@X03`/<00h:2`803`/<00X040`=
00h:2`0=2@X03`/<00h:2`0;1`P03@T:014>3P0<2`T02`P70P0?2@T05P0D2``05Pd>01892P0<1PH0
3@T800d<2P0>30`02PD901@?4`0<1`/03PT=014<400@2`l03`X>00`72`0Y92P050lC01D@500810H0
2`D500X50P0<1`@2014<2@802`H300P050l<00l:1`070P0020<001@>3@0>20X03@L900`620803PP:
01<030H800/51`0A2`d0208400l92`0A2`d04P`>00@0000H4A@02P@600d42@0?1`/0208400`3200>
1`X02`D700X11P0?1`/05a4C01Cooooo000Kooooo`0900041P0G8B<0[kVk0;o9b`0L9BP05QhQ00/C
5P0<4aH03A8F00803Q4F00X03Q8E00861`0B5QD010P701<G5P2@U9<0J6a[00lC4P0A5A@0310?0P0=
4A002@093@`04A<B00h@3`0=3`h03Q0?010B4@0A4a803@l>010B4@02018D4`0V00lA400=3`h04aDB
014C400:30T02@/800h@3@0B51404A<@00`>2`092`P05ALD04U;B00>40d02@/800lA3P072@H04Q8@
01@D4P0000003@`:010?3@0=30X04Ph=01<?3P0>3PX0314:00`A2`0=4P`0314;00`A3@0?51000`P4
00P<2`0C5aH01`/:02da<00?4`l2010B3@803Q0;00d03a4<00d?2P0;3@P02`d800d?2P0@4Pd04A<>
00`>2@0?40/04A8=00X;1P0A4Pd04a@?00803Pl:00<03a0;00h?2P0=3PT00P0>3`X03@0=3`X051HA
00/=200:30L05aTD00P:1@0=3`X051HA00@60@0;3@P051HA00lA300>40/00P0=3`X0100>40/0418=
00d?2P0>40/3010B3@0800lA300J71T04A<@018D4@0>40d05ALD00lA3P0:30T200lA3P0W00`>2`0?
4@h03@l;00l@2P0@4@T04A8:010A2@0>3`L03@h601<D300@4@T04A8:00l@200;30@03Pl700h@2`0F
61<0418=00T;1P0F61<04A<>00`>2@092`H01PP300T;1P0>40/051HA00h@2`0B50l02P`7010B3@0<
3PT03a4<018D3`0>40/04A<>00<5000E5a80004000803a4<03D04A<>00/=200S9B00Gf5L01`N6@00
0@004aD@01@F4@0;3@P030l801<D2`0?40P020T1018C2`0H6a@04A@=01@F4@0F6aL000D101DI6006
30X01@/700lB300<3`P03A09010C300>4@X030l800`>2P0B5@h01@P1014D3@031P005APA00`>2`00
0@007R0M01@F4`0=3``01`T600`>2`0;3@X04A<@00X<2@0A4a002`d900P:1@0=3`X05ALB010B3@0B
50l04aD@014C3P0200h@2`0800lA300>40/04Q<>00/<1`0>3`X0414<00/<1`0?40/200h?2P0M01hO
6P0_<2/05aPC00l@2`0B50`03a<500lB1`0?4PX03a4<010B3`0@4Q406Q`I00P:1@0V:B402@`101HJ
3@0A50/03Q4:014D2`0A50T03A05014E1`0D5``06ahC02ha:P0S9B802@/800`>300@4Pd00P0A50d2
018E3P0@01<F3`0B5@h04A@=014D3@0C5Pl051L@01<F3`0E614061/D01TL5@0@4``030l801HI4P0E
614051L@01<F3`805APA010051L@01<H4P0?50h03Q<=03Hk=@0<4@/03a@>01<H4P1hOGL0<3D_010E
3`0E6Q@05AXC00hC300C6@l051X@0P0B5a00400F6a@04QLA014F4@0C61@05Q/G01LL600E6QH09B/W
02le<@0H7QX05adI018H500A5a<051XF01PN6P0?5A4201HL600>01LM6@0G7A/06AlM01XP7P0I7ad0
5A/I01@J600C6AL05A/I01PN700C6AL06AlM01LP7`0M:2T301TT9P0601LR900=61X062<U01PS9@0@
6ad05R4S0P0M:2X0100K9bL07B/[01l];@0N;2`201`/;00302@c=P0Q<cD08C<e00808C<g00<08S@h
024e=P0O<c@00P0O<c@0;@0Z?Sl0:cm002Pl?@0V>S/0;D5202a0@@0W>c`0:Ci002a1A00^@dH0<TM:
03=8B`0bAdX0;D9502a1A00_A4L0<dQ;03E:C@0dBD`0<TM;0397C00eBTl0>4eB03U>D`0hCE80;dA9
041EFP0lDEH0IW^006EjO`1bQh`0h_3c0=ORj022SI<0BeaP04=HF`0lE5H0G7Ig06J2P`0nEeT0>DiA
03=8B`0hBdl0@eIJ045DF00203iAE@0`03mBEP0nDU<0@UIG049FE`1:GUd0BUiL049FE010E5<0>4eB
03U=E019GFD0NXnD08^PX`1?I6H0?59@03]AC`0cBTD0<dY403]BBP0nED`0<dY004=JDP19H5/0D6IT
049GF014FE`0HgQm03iCF01GK700Q9VL05I[KP1=HV<0A5YG04ELEP1CJV@0CfIP04eTGP15G5H0C6=M
04iUG`1?IV00CVEO04]RG019H5P0B5mG04MNE015G580AEaD0P16GED0A@17GUP0A5]E04=JE016G5T0
BV1M04]QGP18G5X0BUmI04eRF@12Edh0@UQ;03aC@`0mE4@0Bf5C03iDB00oE4d0AU]E045ED`14FUP0
BV1M04ELEP12FE80A5]A04=JD011F4h0>E1803YAB@15FeP0?E=A045GE@0oF5@0AUaI041FD`0jD4d0
Ef]Y09>WY@1=HEl0>Da:03I9A`0iC4X0=4M5049ED@0fAch0:c`d03Y;@`0a@SX09SLa02Pi<`0N;bT0
9SHc02`l>@0a@Ch0>TY903=3@00`?cL0;chg02He;P0P;bP09C@_02Th<`0X=c806BPU03Y9AP0X=c@0
62HV01dZ:00K9b<05b<O01l[9`02024]:@808bl[01@0930/02<_:`0P;2P07b/W01`U8@0I7QX06AhH
01`R6`0P:1d07bTN02H`:00S;RP08BdY01XW:00[>3h0NhR@038j?00W;2H08BHP028W8@8061dG0180
5a`F01HK5@0S:28061dG01hS7@0Q9R40IfUX0453@P0O8B008R@S01hP7`0H6QT051HE01DG5P0B51<0
4aDD01TK6P0E5aH201lQ7P0F01`N6`0J71T06adJ01`N6`0F61D0828O03Dg=00H6QL04A<@01HH5@0P
81h04A4?05UIE`18B4H09BDS014A400b<S0051@B00l?3@0F5Q@04Q8@01TI5`@04a<A0P0D5182014A
3`0F01LG5@0H61H04Q8@01<C4@0H5a<04a8?014@3P0@3`d05A@C02<Q8P0e<c@06QPJ00l=400F51L0
20H:00P62@0C4A@040h?00h<3@0?3@h03P`=00`:2`804@l@0P0@3Pl200l=3P04010>4@0?3A003P`?
00h<3`<03`d@00/03P`?00d;3P0E4aH04a4D00X82`0B414071XK00T7200B41406QPI00H41@0600l=
3PH030/900T01PD3020O7@1<BdT01@@300P71@071@D04Ph?01<?400?2``00P0A3@h04`091@H01P83
010<3@091@H01P8300D10P0;2@X02`/;00`<300:2PX02@T900`:2`0>30d030X;00`82@0>2P/03`/<
00l92`0=20T00`0;1`P200`82@0C00d92P0?2``040`=00d92P0<20T03PX;00X820092@L040l=018<
300A2`/03@@501<:2`0A20T03PT9010<2`0?3P`02`/:00L21P0200/6300:01@?5@0E41H0L6]a00X5
2`080`T05a8H00D01P0?2Q002PD:00l92@803PT600`03`X700h91P0;1P<04@`901HA3P0B3@X03PT6
00X50P0;1@@03PP:00d72@0<1PP200h82P0300`6200C3@l04P`>00803PP:00h0100000l92`0S7Al0
6aDG018<3P0D3Q003@L900l92`0@2P`04@/=00l92`0@2P`07aTK02lY:aCooooo000Kooooo`06018L
7@094A80=Cm004M?D@0?5QP0CUIH0`0<4A@200dA500=00dA4`0=4A804ADD010D4`0M8B00X:BS03Hj
>@0;3`h041@C00`@3`0;3`h03A4@00/?3P0200lA4080418A0P0?4A000`0>40l0418A014C4P02018D
4`0J014C4P0B51403@l<00X<2@0E5a@020X701LI5P0B51401@L400d?300@4Pl01@H400lA3P0>40d0
418?00X<2@0@4Pl05aLE01DE4`0>3P`040l=00d<2P0A3@`04Ph=00h>2P0>4@X200lA300@00h@2`0=
3``02`d:010B3`0Q8b8071hM02HX9`1IFeX03Q0=00X<1`0;3@P03a4<00h@2`0=3`X03a4<00h@2`<0
3@l:00P03Q0;00d?2P0F5a806a`G010A300>3`X04A8=010A30804A8=00l03a0;00d>2@0>3`X04A<>
00X<1`0;3@P04Q@?010B3@0:30L03a4<00/=200@4Pd04Q@?01@F4@0F61<0100?4@`00`0>40/03@l:
00lA3003010B3@803a4<00P0418?00P:1`0?4@h03Q0=018D4@0=3``03a4>010B3`803a4>00/0418?
00`>2P0>3`T04Q<;01HG3`0@4@T030d500d>1P0<3@D03Pl701<D3002010A2@0=01LH4@0I6aL02`d8
00P:1@0b=2l02P`801<E4@0:30P04a@@00X<1`0L7QT03Q0;00d?2P02014C3P0300/=200@4Pd030h9
00804A<>00D01PP301PJ5@0A4`h061XE01hP6`0200h@2`0H014C3P0;3@P061XE0412?@0g>C@02`d8
00lA300@4Pd04Q@?018E3P0C5@/08R<K01TJ4P0=3PH03Q4:014D3@0=3`X03a@@00/@300>4Q4051PF
01HL600A4`d03a8;0P0>4@X03@0=40T02`h7018E3`0=40T061/D00/>200K7QL02Pd6010B3`0:30T0
3a4>00h@3@0B51400P0>40d0>P0B51403a4>014C400E5a@03@l;00D70`0M7aX0=SPc01@F4@0;3@P0
3@l:00h@2`0=3`X03a4<010B3@0?4@`04aD@00l@2`0A4Pd03a0;00d>2@0C50l03Pl:018C3P0?40/0
3@h901DF4@0C50l03Q0800hB1@0?4PP041<;014C3P0A4a00418?010B3P0H6QD0K6mW014D2P0?4`L0
41<:010C300B5@`041<800hA1P0A5@L041<800`?100G6Q<0;Bl/00X<2@0D5Q@051HA01<F3`0B5@h0
4A@=018E3P0E614200hA2P09014D3@0C5Pl04aH?00lB2`0B5@h03a8;018E3P0G6Q<051L@00804aH?
01@05APA01HI4P0C5Pl04QD>01DH4@0Q9R005a`F018G4@0?50h041D?01PM5`0;40X061dG014F400F
6aD05AXD00/@2@0G71D05Q`B01<I3`804QL@01<03a@=01HK5@0E6QD05AXF01HK5`0D6AD04AHB01LM
6@0Q9b<05adI01DK5`0F71P05adI00lE4@0I7a/04QPD01PN6P0G7AT06AlK00805adK100F71X00`0J
81h07R@R01PN700201PN700X01hW9@0F8B805b<S01PT900E8B405b<S020/;00I9BD082`/04=?C`0]
>CT04QhN02Da<@0O:b/07B/[020^;P0R<3007Bd]01XZ:P0S<SD07c4c01h`<P0O<CD08C<g028d>00Q
=3P0:3/o02Lj?P0Z?D408cHj03]>DP0iC500:ci202Hi?@0/?d<0=DQ<03=7BP0[@4<0;T=602e2A@80
:d1300<0;D9502i3AP0`ADP00P0aATT01@0`ADP0<4E90397C00dBDh0=daA0080=T]@01P0>TmD0315
BP0mDUL0AEYO03U>D`19GV<0LX:808JAU`1CGfD0A5AI03Q<D00lDUD0>eAE03UCE00iDE<0BUmR04EJ
G@0oDUH0?4mC03iAE@10DeL0?U9C03mCE013EeP203iBD@0P049FE@11EE<0?E5?03iBD@0eBT`0?55E
03eBEP0nDeL0A5UK03Y?D@0hCT`0?59@03aBCP0iD4/0?eI@04ELEP0nEDh0?eI?049HE@12F5L0BUmP
05EZK@1:Gf@0@eQL04YOH@1CJ6X0AU]K04ILF@0oEE40DVUS05Q_J@17GUP204QOF@0804YQF`1<Hed0
CFAN04eTGP1<Hed0BV5I049ID014Fe4204IMD`1:04IME014Fe<0B5mG04MNE`17GUP0BV1M04aRG`1;
HEh0@eQC04EJE01;H5L0?eA;041FB@11F4P0?5=303Q?@@1?IET0KhAm049GD@15FEH0BEmM04]QGP17
GUP0@EQA041GC@0oET`0@UU?049ID@0iD4P0?UAA03eCD@12F5D0>eA?045HDP0iD4X0>U5;03M<A`0m
DTd0=da704EHE00fBDD0@5=?03Q;A`0aA3h0=TLn02`m=@0`@CT0<d@l05Y[I@0eAT008S<]02Lg=00X
>3D0:c/h0392@@0V=S<0:SXa02hm=P0V=Bh07bhW028a;00U=2l0:CPc02Lf<`0c@Sl07B`Y02<a<@0T
<Rl08BdY02@`;00X=3008BdY01l[9`0R;RX302<_:`0L028^:P0Q;BT08b/W02<X900Q:2408RTQ02<Z
8P0O:B007RPP01lZ900T<2`0<3`m02<^<`0O;3<07RHX02L/:00P9280724M020U8@0I7Q/061`J01HK
5`0L8Ad06QlL01lT800N8b00828Q01hP7`8071hM00d06adL01TK6P0K7A`06Q`K01HH5`0G6AP07R0O
01/M700F61D07b4N01XL6@0?4@h05aTF00806Q`I00l0418?01TK600B51407AlL01@F4`0L71X0410>
028R800D51805ADC01@D4P0U9B<04a<A01TI5`19BDL00P0D5180100B4Q004a<A01<C4@0D518201DE
4`0A010@3P0>3P`04A4?014A3`0?3`d04Q8@014@300C4Pl061LE01LF500@3`h04@l@028P8@0F51H0
3P`?01`J7@1:B4`00P0E4aH03P0C4A804Q0A01<A4P0B41403`d>00h<3@0C4A804Q0A00d;300>30d0
4Q0A018@4`0@3Q403`d@0`0>30l03@0=2`h04@lB00l=400=2`h03`d@010>4@0:2@T05aDF038`<@0V
92D02@L800l=3P0>30d00P0<2P/200d;300300h<3@0=30X03@`:00@03@`:00L040l>01`K6P19B4H0
4a8@00P71P0B40l04Ph?00804@d>00D04Ph?010<3@0>2P/04Ph?00/8200200l;300301<?400>30d0
2@T900<030`<00T040h?00`:2`0>30d03PX;010<3@0A3@h04@/=00l:300>2P/00P0?2``03P0>2P/0
3@T:00h:2`0?2``03PX;00d92P0<20T03`/<00d;2P0:2PP03@/900`61P090`<04@P90P0@1`P01`0@
2PX04@d<00h=2`0:2PP03`X>014<400=20`00P0A31005P1ED5@050lC00d8300;1PX020@700X52@0?
2Ph030H700h8200?2@X03@L800h8200C3@d04P`=00d71`0:10D040X;018<300>20T03`T;00h82P0=
1`T200l92`0C00d72@0910D040X<00T31@0C3@l04@/=00`7200;1@L040X<01@>400A2`d03`T;00X4
1P0;1@L03@L900/51`0910D02`D7010:300Dooooo`006oooool01@29Ti@092d_00TA4`032`d02@hA
0080314D100=4A@03@0=4A802Ph?00`@3`0A5A@0004001<G5P0@51<01`/:00`@3`0:3Pd0310?00hB
4@0=4A000P0?4A02010B4@0Q00lA400>40l0418A00d?3P0<3Pd03a4@01@F5@0F61L02P`900/=2P0<
3P/03a4>02d_;01jO7T030h;00T;200E5a@03@l<00D7100D5Q<02@h:00P=2@093PX051HC018D4@0A
4a004A4?014@3P0=30X03Pd;010?3@0?3`X03a8;00803a4<01803Q0;00d?300<3P/03@l<03<e=00`
<S4030h=01lQ8015Ad@051HA014C3P0D5Q403Q0;00X<1`0>40/03a4<00h@2`0<3PT200/=200700lA
300D5A004Q<>00h?2P0@4@`04Q<>014B3@02018C3P04010A300>3`X03Pl:00/<1`803Q0;00T00@<0
00L9100C5A003a4<01@F4@0M7aX03@l:00@60@0D5Q40100?4@`00`0=3`X030h9010B3@02010B3@0D
00lA300>40/03@l:01@F4`0B51403a4>00D7100D5Q<04A<@00lA3P0B51405ALD00lA3P0;3@X03Q0<
010A2`0E5Q0061TC014B300=3PP200l@2P0i010A2`0B4`d0414;00d>200C50h051HA01<E400^<2/0
Kg5/018D3`072@@0DUA?0453?P0H6QD07b4L00T;1P0<3PT03a4<00h@2`0=3`X04aD@00d?2P0F61<0
4aD@010B3@0>40/02@/6018D3`0F61<04Q@?014C3P0E5a804A<>01@F4@0W:B@01@H301HH4`0@4Pd0
2`d801<E40041`0051D=018C2`0D5@d06Q/E018E3P082`@04Q@?00lD40042@D0CU=?0;Jl^00]<bl0
41<=010C300?4P/03A09008030l802004QD>00D80@0G6Q<05QTB00d@2@0I71D05QPE020R7`14AT<0
JVaY00T;200A4a005aTF00/=2P0=3`d030h;00d?300M7a/05ALB014C3P0E5a802@/600L9100D5Q40
418=00d?2P0?4@`04Q@?01<E400C50l03Pl:014B3@80414<00`05AHA00l@2`0C50l0414<00l@2`0@
4@`03Pl:014C300?4PL03a89010C2`0A50d2014C3P0M01DG4P0O8A`05aXB01DH3`0B5@X030l600lB
2`0@4`X03a87010C200C5`T04aH;01DH3@0<3`P05aTF00<50P0?4@l05QPC01@G400B5@h04A@=018E
3P0E61404QD>010C300?4P/041<<014D3@0@4``00P0F6A805`0D5a004aH?01DH4@0F6A804QD>01DH
4@0G6Q<04QD>014D3@0E6140?T<m02T^:00E6Q@041D?014F400;40X02@h802@Y8`0H7AL02@h801HK
5@0@5@h04QL@00804AL=00D05AXC01PM5P0H7AH06AhH01LL5`0201DJ5P07018G4`0=4Ph02a4=01HL
600M8al05adI01TO6`0201@J5P0N01DK5`0?5A406b4M01hT800M8al06AlM01PN700F71X05adK01TO
7@0J81h0728P010F500N92806R0N02`b<00P:BH072LW01PT900M:BT0:3@d01TU9@0M:BT072PX020/
;01BGUh0<3`l00TE5@0T<3008Rh^0P0K:BT04@0N;2`07Bd]01`/;00R<C@08C<e028d=P0S=CT08S@h
024c=`0Q=3X06Rdc01LZ<00W>T00<TE;03Y=D`0S=S`09CPn0080;D1600H0;3m502e1AP0`ADP0=T]>
03E:C@0_A4L502i3AP80;45400<0;dA80397C00cB4d00`0cB4d0?@0^@dP0A5UN0356B`0eBTl0?55F
02a1AP18FEh0=dE805i/K`0mCU00BUiO03Y?D00cBd/0@EUI03mGE`18GEh0@EIG03]?D00gBTh0>TeA
041DE@0oDe@0@5AE04EIF00oDe80@EED045ED`0mDDl0?U9@041DDP0lDU00?E9C041EEP15FU/0AE]I
03iDDP0iCdd0@EME049HEP0lDU00?eEB04MMFP1?IF80@EMD04MMF`17G5d0AEYM04eRI@18GF00E6U/
05Q^K@1DJVL0DVUS04ELEP1DJfD0AeiH04YQF`1>IEl0EFaV049ID`1:HE/0101;HU`07@1;HUX0AEaB
04EMD014G4l0AEaB04MNE018GeD0AeiF04IMEP16GEL0BF1J04YQF`18GeT0AEYE03iCC@17G5<0@EI=
03mEB00lDTD0;dDh03]AA@16G500<4Dn04MLEP0aAT40AE]I04EKF015G5H0@EQA0080?UE;0300@EQ>
045HD00lDd/0@UQE03mED`14FUL0=Tm:04]RG010Ee40=Te704=HD`17G5L0AU]F03e@C024Ui<0//G1
03M:AP0nDD/0=dPo03M8@00a@SX0<T<k069cK@0/?CL08c@^02De<P0V=S<0<d=0049BD@0fAT<0:SXa
02Lf;`0V=Bh093</024`:`0L:bH09C@_01@S800a@3d0:STf01XX:00M:bP07BTU024]:@0S;b/07BTU
01l[9`0T<2`5028^:P0n01hX8`0J81`06R4J01dV7P0P:R808B/S020Z8`0M:28082/W020[;00S;S80
51lU02T`=00K7ah07b<T01`P800R9RD06alO01dQ8P0L81l061`L01/O800I7A`061`L01`N7@0O8B00
61XI010B4@0E5aH061XI01LI600E5aH06adL01LI600>40l071hM02PZ9`0d=S<0:bdZ01PJ5`0J71T0
5ALD01hP7@0C5A8051HC01HH5@0G6AH051HC02h^;00G5aD04a<A01lO7@0H61H03Ph<010@3P0?3`d0
2PX802PX9P0@40h05QHD01<C4@0G5aD201`L6P0401XJ600F5Q@04a<A010@3P804Q8@00X04A4?01HF
500L6aL04A0=00d<2P0<2`T03@/;01<A4P071@H05A<E0P0G5AP01`1JF5`05Q@G010>4@0?3@h040h?
014?400@3Pl00P0<2P/02@0B41404@l@00/92P0=2``04@l@018@4`0@3Q403`d@00h<3`0300d;3P07
00`:3@0>30l04@lB018@4`0D4QD030X;00D3100200P61`0300/92P0C4A803@/<00802PP90P0=2``0
0`0;2@X03@`:00d<2P0400d<2P0901<B40040`400@0001@C4@0;2PP0518A010<3@0>2P/03@T:0080
30P900`040`=00L3100K5aP03`/<028N7`0<20T04@l@00<30`020P8030`<00/;2`0;2@X200`:2`05
00d92P0?2``040`=010:300>2@X00P0=2@X01@0<20T02PH700T51P0;1`P03@T:00802`L800L030P9
00d92P0;2@P01@@202HR8@0_:BT04@/;00<03`H701l03PP800`81`0:2@L02`X800T4200A31003@P<
00h93@0B3A402@D801@?4`080`L03PT=020K7`080`L02@@800/52@0=1`T03PP;00`62P0>20X05a4D
01H@500@2P`03`T<01<=4@0A2`d02P@700l92`0>20X03@L900803`T;00@03@L900h82P0@2P`02`D7
0P0<1PP03@0T7R00:B<U00H10P0?2@/03@L900T31@0400002@<500h82P0C3@l04P`>00l92`0=1`T0
5?ooool001_ooooo00L051hO0003100D71h01@d?01DK7P011PT03A8E00@03Q8E00d03Q8C01LK6P0;
3`h03A4@01HJ6@0B5QD04ADD00dA400>4Q402`l>00hB4@0?4a802Ph=00H03a4@01H0418A00`>3@0:
30/03@l>018D4`0E5aH0;c4^010B3`0?4@h02@/800d?300k?CX0418?00lA3P0F61D02``:010B3`09
2`P02Pl;010E4@1DFED0DeEB0P082PL01`0D51804a8@00h=2`0?3P`04A0>00l?2`0?4P/00P0?4@`0
300=3`X030h;00h@3@000@003@l>00lA400A4a804Q@C04a>B`0>40/02@/600lA30803@l:00X03Q0;
00/=200;3@P030h900d?2P0?4@`051D@018C3P0<3@P03@h90P0C50l200l@2`0?010A300>3`X030d8
00d>2@0>40/05ALB00d?2P0:30L09BLR01`N6@0K7AP051HA01LI500<3PT01`T400<03a4<0`0>40/0
1@0=3`X02`d800`>2@0?4@`0418=00804A<>02@00`D200T;200F61D02P`900lA3P0=3``02P`900h@
3@0D5Q<03a4>00/=2P0C5A404Q<>01@E3`0E5Q00414;00l@2P0@4@/03@h800/<1P0?40X0414;00h?
2@0A4P`05ALB00d?2P051`806adH014C3P0?4@`061XE01<E40041P404A<>00lA300F61<200d?2P0R
00lA300F61<03Q0;01LI500<3PT04aD@00/=200:30L03@l:0084000>40/03@l:010B3@0?4@`03Q0;
01DG4P0O8A`05aTD018D3`092`H04A<>00lA300A4P/02@X200X;0`0B4`d04A@=00hA2P0<3PT0314=
00lD401DFED0bm7=04I=AP8041<<01d03a8;00d@2@0<3`P03A09010C300?4P/0;2lX00T<1@072P<0
2@`500d?2`0E5a@07AlL04e?C0010`00418?00D7100U9b@0F5YG028T8@031@802@/701HH4`0>40/0
2`d800`>2@0;3@P061XE018D3`0200h@2`803a4<02L0418=00h?2P0B4`h03Pl:010A300D5A0030d8
00l@2`0@4@`051D@00h?2P0<3@P04aD>014D2@0A50/04A@<010C300@4Pd05aTD0001000=40T03a8:
00L:0@0A4`h030l8010C300A50/03Q46014D2@0C5`T030l401@G300A50d04aDB00h@3@0@4Q005ALB
01@G400B5@h00P0A50d0100C5Pl051L@018E3P0@4``2018E3P0:014D3@0K7QL03A09018E3P0G6Q<0
2`h701PK500C5Pl051L@01DH4@804aH?01T05APA02L/9P0H7AL041D?01DJ500C6180314;01@I4`08
3@L02a0:01PM5`0M8Q`02a09018G400B60h04AL=018G400E6Q<05a`E01DJ500D6A@051TE01DJ5P0D
6AD04AHB00805A/G01806R0L00lE4@0F71P05Q`H02D[9`0O9B404ALC01TO6`0F71P03aDA01XP7P0I
7ad061hL01TO7@0K8Al0728P01lU8`0A5aD202P^;00?0457A@0_>3D06RDT010L700L:2P0A51@02Da
<@0D8200930`024];@0W<c<07BTY01XV9P0R;Rh082`/00806BLW00`07R`/028b<P0S<c<07Rd`020b
=00R=3H08cDi020b=P0O<CD07S4g01lb>@0U>3h202Pk@P0C02e0A`0R=C/093Ln02/nA@0Z?D<0:Ca3
02e1A@0`ADP0=4U<03I;CP0bAdX0;dA702e2A@0[@4<0;45402i3AP0`ADP0<DI903=8C00303E:C`80
=4U>01@0=DY?03]@E@0W?440:d1503Y?E00/@DH0<45504aKGP2ga/T0BeiP024e=P0cB4T0AUaM03]C
D`0aBDT0>4e>03U>C`10E5D0>diB03e@E080@5AE00`0?e=D045EE00nDU40@EED03mCD@0jCT`0>dm=
03eAC`0jD4d0?eEB04ILFP0oEE<203I<BP0H049HEP18GU`0B5iL049HEP15FeT0C69P04QNG00oEE<0
@eQH04aQI017G5l0E6U/04AIG01=HV<0CVAQ04UPFP19H5P0?eI>04YQF`16GEL0D6MQ04]RG01<Hed0
BV5K0`1<Hed204]RG00P04]RFP18GeD0AemB04EMD015G580AeiD04UPEP17GUH0AEaE04AKE@16GEL0
B5mI04MNF01<HE`0@EI?04YOEP12Edh0>U140398>`0lDTD0@UQ<05=XG`1GK6<0CF9K03M<A`12F5H0
@EMD04AKE@12FE80?eI<041GC@11F4h203mFCP0L04AJE`14FUP0DFMT03iGD@17GUP0Bf9L041GD@0m
DTd0=DY503]@B`0oDTh0RYfI0;K9a@0_@Sh0<D@n03U:@@0cA3`0>T]301h_9`0R<bd02Q/E02<d;P0T
=3408c<`0310?@10D4l0<D4n02Xi<@<08S4Z00d07B`W01l^:@0S<Rd05RDR03Q7A00U=3407B/[02Hc
<@0R;RX08BdY01l[9`0H92006bLS00808RhZ00P08BdY020/:00P;2P082`X024[9P0O9B407B@M01dV
7P807bTQ018072HO01TT800J92<05b8Q020[;@0E82@082L[014E5P0E6AX07B4R01DI6P0M8B806QhO
01dQ8P0G6a`0720Q01PL7@0I7Ah201lQ800T01XL6`0E5aH05aTH01HH5`0H6QT05aTH01dO7P0K7A`0
4aDD01/M700D5Q<07AlL01`N6`0D5Q<05QPE01<E4P0G6AH04aDB01DG500I6aP0418?01HH5@0S8b40
7QhL00l?3@071`D05QHD01<C4@0B4Q005QHD00`<2P0@40h04Q8@01HF500?3`d051@B0P0G5aD0100C
4a403`l=018B400?3`d2018B400C014A3`0E5A<05aHB010?300B4@l051<A01<B4@0E4a@01@<401DC
5@0>30l01`D801<A5@0B41<040hA010>3`0B41404a4B018@4@0200d;3008014?400@3Pl030X;00d;
300?3@h04Q0C010>4@0?3A0300h<3`0400l=400:20/03@/>010>4@8030X=00`02`T:01LE5P0C4A80
5Q@E018@4@0610D040h?00d;300?3@h04Q0A00l=3P0<2P/600h=2`0700`;2@0D4a402`X800L6100G
5Q@02PP800l;300200d92P0H00/7200A3@h07a/L00<0000?2``07ATJ051<C@0H51D010<301@D500?
3`l02@T900d=3@091`P03@/<00/92P0<20T03@T:00l;300?2@/040/<014=3P0?2``03@T:0P0;1`P2
00d92P0=00`82@0=2@X03PX;00d92P0=2PX00`8001lK6P0Z92@03@L700l71`0?1PL040L800l72002
00/71P0=00/:200>2P/05A0D018=4@0?2Ph03@P<01D@500>2@d020<701<>4P0Z9BT03`X>00d83002
010:3P0;00h8300;1@T030H:014;3`070@D02`D900l93@0>20`030H:00h9300@2Ph00P0>20X05@0?
2@/040X<00d72@090`D01`8301/E5`0C3@l04Pd>06IPHP1lMWP05@lA01TC5@0L5QP040X<01D?4@0:
10H02@<500L10`080P@02`D700h82P0Dooooo`006oooool01P0740l031DD00dF5@083@d03A8B00L=
3@<0310A0`0>3a400`0;3Pd03A4@01DI600200hB4@0400`@3`0A5A@03A4@00dA40806AdL00P04ADD
014C4P0>40l03@l>00h@3`0@4Q404Q@C00d?3P<03Q0?0P0=3`h02@0G6AH03@l<00lA3P0A4a00418?
00d?300@4Pl02@/800d?3002014C400O00X<2@0>4`l04aPD030e<@0f>SL0418?00lA3P0F61D05ADC
00l?3@0@3`d04Q4?014A300A4P`04A8=010A300>3`X03@d;010@3P061P@05ADE00l?3`0<30`03`l?
024R800G6A@030h900h@2`0:30L02`d800h@2`0200/=200600`>2@0=3`X03a4<01@E400B4`h03a0;
0P0B4`h00`0?40/03@h900l@2`02010A300900l@2`0@4@`0418=01DG4P0<3PT07AlJ05=ED00Q8Qh0
7b4L00803@l:00D02P`700lA300@4Pd03a4<00h@2`0200d?2P0400h@2`0A4`h03@l:00h@2`@0418=
02l0Ce5>01hP7@0>40d061XG018D4@0=3``03Q0=00X<2@0>40d0418?00/=2P0=3``04Q<>014B300>
3`T03@h800l@2P0@4@/061TC00l@2P0B4`d05QLA01<D3P0?40X0418=00h@2`0;3@P03Q0;018D3`09
2`H030h900d?2P0@4Pd03@l:00h@2`0<3PT03a4<00h@2`0C5A006Q`G00`>2@0D5Q403a4<00d?2P08
2PD04A<>010B3@0200lA300400`>2@0?4@`04A<>00lA308030h901H0418=01DG4P0>40/04Q@?00lA
300@4@/03@h801HG4@0O81X05QPC00`>2@0@4Pd02@h8014F400?50h08bXS01/R6`0>4@X041<<00lB
2`0=40T03Q4:0P0@4``00`0]<2X0FUeF01<F3`02014D3@0601<E400@4Pd02P/801<E400F61<051HA
0P0@4Pd02P0K7AT030h900d?2P0E5a803@l:01@F4@0C5A002@/6010B3@0A4`h2010B3@0@018D3`0C
5A00418=010B300@4@/04Q<=00l@2P0H6A<08B8L01PI4`0I6Q@051D?010A2`0C50h03a0:010B2P80
4aH=01P04QD=010C300?4P/03A09018E3P0A50d041<;01@G3P0@4`X041<<01DH4@0C5Pd03A0500lB
1`0>4P@05QT>00/>0`0A50d0418?01TK600D5Q@04Q@?01<F3`0B5@h2014D3@0;010C300D5a0051L@
01LJ4`0H6a@05aXC014D3@0F6A804aH?00lB2`0B5@h00P0D5a000`0F6A8051L@01<F3`0201HI4P07
01@G400A5Q003a@>01hS7@0B5a403a@>01DJ500201HK5@0L01@I4`0I7QP04QLA01LL5@0D6A805adC
01DK4@0B5a005Q/D01dR6`0F6aD05AXE01DJ5P0F6aL051TE014F4P0I7a/051XF01dS7`0=4`l05adI
01HL600A5a<06R0L01@J5P0K8Ad061hJ01LM6@<06AlM01H06R0N01/Q7`0K8Al06R0N01TO7@0L8R00
7R@R01lU8`0K92408B`[01dY9`0@71X0;CTg01hZ:00J9R@082`Z02<_;@0D81h07BTW02Da;`0O:bT0
82`/0P0Q;bl0600P;Rh08S8b02@d=00R<C@07c4c020b=00R=3P08cDi02@e?00T=cl09SQ203A6C`0Z
?DH0:Sa602/mAP0Z?4D0:C]502/mA`0[?DH0;d5;03E9C`0aATT0;T=602m4A`80<dQ;00X0<DI90315
B00`ADP0<TM:03A9C00eBTd0=T]?03E:C`0dBDh0<dQ=0P0bAd`04P0dBDh0;dA903Q=DP0cB4d0=DY?
049GG010DeH0=4M805e_L@10DeD0>De>03aADP0fBd`0@5EF03iCE012EUL0?e=D03iBD`80?E5B02<0
?U9C049FE@13EeH0@5AC04AHEP19GE/0AEUG03mDC`11EU40?eA?045HDP14FeD0Bf9M04AJE`0lDTl0
AeeJ045GE@15FeT0@eUG041EEP15FU/0C65R04YOH01HKFh0A5UJ04]PH`1AIVT0G75d05=XJ@1AIVH0
CF=O04QOE`1@Ie`0GgI/07R?Q`0204iUG`0;051WH@1=I5h0C6=M051WH@1?IV00CFAN04aSG@1;HU`0
Bf9J04IMD`18H5<00P19HE@0C@16GU80@eY@04YQE`16GE@0@eYB04ELEP18GeT0BF1I04YOE`16Fe80
D6EL04=HC`0dBCh0<DLk03mEB@1aQg`0BEiE045FC@12Edh0A5UB04=IE`11Ee@0AEaF04AKE010Edd0
@eY@045HCP0oETh0@eYB045GE01;HEl0KXB107:;Q00kDTX0@5M?03aCB`10EDh0?eA=03eBB`0aA3h0
=dY404AGD@0jCDL0<DDm0393>P0`@CT0<D8j02@e;@0S=2h0<d@n02@e;`0Z>SL0:CTf03=3@00kBdX0
9SHc02`l<`0X=c008S4Z01d/9@0M;2L072/V01LV8@0V=C808C0]045@C@1SLG409S<a02@`;00Q;BT0
82`X01/W8`0L:2@08RhZ02<_:`0Q;BT07RXV00807BTU01T092lZ02D_9`0P:R807BHP01lX8`0P:B@0
8B/W02Pc;`0H8R409S0`02La<P0P:R`07B@W05QLG`12ATT061`O01lS9P0I7B006QhQ024U:00H71l0
7B4T01@H6`0J7R007AlN00806adJ00X061XG018D4@0F61D05ALD01TK600C5A809RPU03do?00V:2D0
6A/H0P0F61D201LI5P0:01TK600G6AH051HC01TK600M7a`03Q0=01@F4`0C4a406ATG01<C4@8061PF
00/04Q8@01HF500B4Q0051@B01<C4@0E5A<0410>01DE4`0C4a404A4?00l?3@02010@3P0L014A3`0@
40h04a<A01<C4@0A4@l04a<A01DD400A40d05A@B01LF500C4A404@l@01dK700@3Q004a4D01HD5`0B
41@03P`?010>4@0A3a004a4B01DC500C4A803`d>010>3`0?3@h03P`=00l=3P803@/<00@040hA00l=
400>30l03`d@0P0@3Q401P0?3A003P`?018@4`0>30l02@L:00/930803P`=00X02`T:00`:2`0=2``0
2PP900l=3P0>30d04@l@01DC500?3@h02PP91P0>3@/0900B4@l030/:014@3P0>3@/02PT801LE500?
2``040`=014=3P0B3Pl081`M01dI6P0@30d05A4B00h:2`0E4A8040`=00/92P1GEeL0C4a<00X:2P0C
4a<02PP900/92P0<2P/030P900h:2`0?2``03`T;01@?400F4Q<04Ph?00d92P0<20T03PX;010<3@80
3`/<01004`l@01@@4@0@30d03P/;00X91`0;1`H03`L800l61`0B20T03`D601892P0F3Pl04Pd<00l;
2P0=2`T02@D60P0?2``0600;1`P02@D600l;300810D05Q8C00h:2`0G4a@04Ph?00h92`0@2Pl03@H=
00/42`0=1Pd03`P?00h73P0=1`d05PlF0109400500D04@`A03hg?P0@2Ph03`T=00h8308040X>00l0
3PP<00h9300C3A406A<G01H@500=1`/0:bDY03<];`0=20T04@/=00L20`0A2`d02P@6010:300?2@/0
0P0>20X00`0=1`T030H8ooooo`0Cooooo`006oooool06@0:4100318B00dC4`0=4a<03A8C00dA4P0C
5aP02`h?00`=3`0>3a404Q8D01LH6P0>4Q406AdL00H:2@0@51<02Ph=01@H5`093@`05ATH00hB4@07
2`X06AdL03Di>00A4a800P0?4A002`0@4Q403Q0?00`>3@082PT06adL00T;2P0A4a805aTH00L9200?
4@h02`d:00802@/800l030h;00h@3@0>40d01@L4020R7`0@4Pl08B<P00d?30093@X0318>01TO6`03
20@041DA00`A3@0?4@h00P0>40d200l?3@0F01<D3`0C50h03a0;014B3@0E5Q405QHD018B400A4@l0
4Q8B00d=3@0:2PX03@d=010A3P0B50l08B<N018D3`0:30L01`T400lA300>40/0418=00lA30802`d8
00<03Pl:010A300>3`X0100=3PT00`0>3`X03a0;010A3002010A300300h?2P0?4@`01`T400803Q0;
00L03@l:010B3@0?4@`03Q0;00`>2@0=3`X03a4<00803Q0;0`0@4Pd0200?4@`03@l:00h@2`0;3@P0
3Q0;01@F4@0:30L0418?0P0A4a000`0>40d030h;00d?300300lA3P0700d?300<3P/02`d:00l@2`0;
30L0414<00P9100200l@2`0N010A300A4Pd04A8=014B3@0@4@`03Pl:01HH4`0?4@`030h900d?2P0?
4@`03@l:00h@2`0@4Pd030h900X<1`0<3PT03@l:01XL5`0Q8ah030h9018D3`0=3`X04A<>00X<1`0@
4Pd03@l:00lA300E5a80418=0P0=3`X0<P0?4@`04A<>010B3@0<3PT04Q@?010B3@0;3@P030h900d?
2P0;3@P04A8=00d>2@0<3@P0414<00d?2P082PD03@l:00hC300=4P/0314:00XA2@0;4PX041<<01<F
3`0B5@h02Pd6018E3P0?4P/04aH?00/>1`0=40T030l801PK500@4``03Q4:01HI4P0?4P/03Q4:010C
300;3PL04A@=00hA2P0=40T03Q4:010C300?4@/04A<>01<E400>40/03@l:0P0C5A002P0G6A@02`d8
01HH4`0@4Pd02P`7014B3@0A4PX03a0800h?1`0?40P2014B2P0<01<D300G6100414900T:0P0<3@D0
2P`500hA2P0D5a004A@<00/>1@0>4@P041<:0P0A50/0300<3`L04QD>010C300>4@X03a8;01@G3P0G
6Pl05AP=014E1`0D5``04aH;018E3P804aDB00<04A<A010B3@0@4``00P0A50d2018E3P0;00hA2P0E
61405QTB00hA2P0?4P/04aH?01HI4P0?4P/071lH01HI4P0C5Pl00`0D5a002P0E61405QTB01LJ4`0I
71D03A8<00`A2`0E6Q@07b@N01<H4P0@5@l201@I4`804aPB01@05AXD01HK500D6A8051X@018H3P0B
5a006QlH02@Y8P0E6Q@05Q/F01<H500c>3@051TE01TN6P0F71P04ALC01HL600I7a/05Q`H01DK5`80
5Q`H01T05A/G01HL600G7AT05adI0457A@1LHV006b4O01LM6`0P9R@04QPF01PN700R:2H08bTW028X
9P0Y;bd0;SLd01lZ:@0V<S005R8P01DQ7`0K9bD082`Z01l[:@0N:RP082`Z0080930^01X08bl]01hZ
:P0T<S807R`/01/Y:@0S<c<0:CTi03E4A`0Q<cD08cDg020b=P0S=CT0;d17028e?@0`@T`0;T1:02<e
?`0R=3h0:Sa603A6D00Z?4H0@E=M02Dg@@0Y>dD0;T980315B0<0<TM:00X0=4U<03I;CP0dBD`0<dQ;
0397BP0dBD`0=T]>03Y?D`0eBTl0<DI;0`0dBDh03`0gC540>e1E03mDF@0jCe@0=4U>03I;D00kD580
=de;03Q<B`0mDE00>dm>03eAD00nDU40>dm>03eAD00303mCDP80?U9A00<0?e=B03eAD00mDE000P10
E5804`0kCdd0@eQC04QMF00oE4l0@EI?03I=A`14FeD0AEaF05I]I`1>IEl0?UAA05ecL01?IF80A5YH
04QNG019Ged0AeeK05abL01NM7800P1?I6D0?@1=HV<0D6EV05=XJ@1@IV@0DVQT05=ZHP1?Ie/0DVYM
05U`J01:HE/0HGQb06V0NP1CJV@0CVEO05=ZI01;HU`0BF1J04ELEP1>IEl0AEaD04ALC`17Ge40BF5C
04QPD`14G4l0@5Q;04QOE@12FDl0@EQ>04UPF01@Iel0BV5I05AYH00oEDX0D6EL03M<@`1>HeX0Ni27
03aAB010ED`0@eQ?04AID017G580Bf1G04EKF017GEX0BF1J051WH015G580AUeC04ELDP15G5@0AeiF
04YPG@19Ged0B5iK04ENE`12FE40?UE=03M>AP11ETl00P0lDDX0@@0dAd40<TDo03A7@@0bACl0;d<j
0393>P0]?SH09SL_024b:P0U=S00:S/e02Pi<`0U=C80:c/h096QWP2Q/K00=dM402hm=@0_?SL08S4Z
02He;P0X=c807bhY01XY900L:bP09C@a02Xi=P0X=SH0:3Dc02`h=00Y=C407RXV01`X900P;2P08RhZ
01l[9`0N:RH06bLS01`X900P;2P08blY020[8`0N:B<07bXU01hY9@0Q;2P08bd[02</:`0U;Rd08b`[
01hW9P0L9B@06R4R01lS9P0V:Rd061`O01lS9P0J7R407B4T03a0@`0_<cH0:Rha01hR9@0J7R006adL
008061XG00D06A/H01HH5@0H6QL051HC01`N6`02020R7`0H03Li=P0S9B805ALD018D4@0C5A8071hK
01dO700D5Q<04A<@01PJ5`0D5Q<06A/H00d?300D5Q<0820N02<S8@0L71X05ADC01HF500B4Q005aLE
010@3P0>3P`04A4?0P0B4Q003P0=3@/05aLE01PH5P0B4Q003Ph<00l?3@0@40h05ADC010@3P0<30X0
3`l=00d=2`0>3@T040l<0P0A40h0700@3`h03P`=00h<3@0>30h04Q0C010>4@0=2`l04@lB01@B5@0G
5AH02`T:010>3`0F51D02PP900/92P0A3a004Q0A01DC500Q7b000`4201<A500>30l02PP;00`:3@0?
3A003P`?010>4@0J61/2014?4P0800X82`0C4A@030X;00/92P0E4a@03`d>00/92P071@H2014?4004
00h<3@0:20T02@L800X82@802@P601002`X8010?3@0?3P`03@`:00/:200O7Q`00@00010?3@0<2`T0
2`T801TE5P0=2@X040`=00P41@0R7Ql02@D61@0>2P/0200<2P/04Q8B01LG5`0@410020P800`:2`0?
3@h030X;0`0>2P/0=`0?2@/04Pd?014=3P0>2P/04@d>01<?400?2``03@T:00h:2`0;1`P04`l@018>
3`0;1`P0<2`/024M700F4100;B@U01H=3P0@1@H04PH801882@0J4A805a4A00`81`0;1`H02@D601@@
4@070`@0BdM802hZ:`0V8R<03@T:010<3@0n>S/06QHG00X61`091PH03`P?00/42`0=1Pd04P/B0109
400A2Q402@89014:4@090PT0204802TR:@36_lH04@/?010:3P0>20`030H:00d72`0>20`00P0@2Ph0
2`0?2@d04`dA00P31P0=1`/01@0100l92`0B30h01P0201@>40080P@03`T;008040X<00<03`T;00`6
200:10H05?ooool001_ooooo02402Q0@00/A4@0<4Q803A<C00lD5@0@51D0720Q018D5P0>3a403a0B
010A4`0E5QP03a4@00dA40072`X05QXI00hB4@062PT03Q8A01hR8@0L81l0310?00H:2@0E6AP03@l>
00h@3`0?4A00418A00`>3@0;3@`051HE0001000=3`h00P0>40l00`0;3@`03a4>00`>2`0200/=2P03
00d?300>40d061XG00801@L402H02@/801LI5P0320@02a4=01`R7P27SHT0724M00D:1P083@T0418?
00h@3@0=3``03`l=014A3`0C50l04A8<00h?2P0?40/04A8=00l?3@0;2`T020P600/;2`0=3@d030`<
010@400B4a0020X501dO6P0;3@P09bTT00L9100=3`X03a4<014C3P0@4Pd03@l:00`>2@803a0;00@0
3Pl:00d>2@0=3PT03@h90P0>3`X03@0?40/0414<010A300?40/03a4<00d?2P0<3PT04A<>00P:1@0;
3@P04A<>010B3@0>40/00P0<3PT01@0=3`X03Q0;00lA300?4@`0418=00<03a4<00/04Q@?014C3P0D
5Q4061XE018D3`0<3P/02P`900P:1`092`P03@l<01<E4P0200`>2`@03@l<00L04a@?014B3@0G61<0
30d800l@2`0<3@P04A8=00<04Q<>00L04A8=00l@2`0B50l03Q0;00`>2@0?4@`04A<>00803a4<0140
51HA01DG4P0B50l03a4<00`>2@0>40/051HA00X<1`0<3PT03Q0;010B3@0D5Q403a4<014C3P0N81/0
7b4L00X<1`0200d?2P0A00h@2`0@4Pd0418=00d?2P0C5A004Q@?00h@2`0?4@`04A<>00h@2`0?40/0
3Pl:010A300A4Pd0418=014C3P0>40/00P0>4``02@0=4P/02a8:00`C2`0<3`P02`h701@G400Q91d0
71lH00T<1@0200P;100501@G400@4``02`h700/>1`0=40T00P0;3PL2014D3@0400/>1`0@4``03a8;
00hA2P803a8;00L030l900X<1`0;3@P02`d800`>2@0>40/04A<>00803Q0;00D04Q@?00/=200B50l0
418<014B2P03010A2@804A8:00H06Q/C01DF3P0=3PH04a@<014B2P0B50`201@G4009010C2`0?4PT0
51L>01PK4P0E60l04QD<01<F3P0G6Q<04aH?008041<<00`03a89010C200?4PL03Q84014D2@0@4`P0
3Q4:00lA3P0@4Pl03Q0>010B3@0@4``2014D3@804QD>00`03A0901@G400D5a003Q4:014D3@0E6140
4A@=01<F3`0:3@H030l800X=1P0M81T201@G400C01DH4@0F6A805aXC01TL5@0F6aD061dG00X?2@0<
4@/061dG00L<1P0D6A<04QLA010E3`0A5Q0051TC01HK500G71D05Q`B01DK4@0201LL5@0=01DJ4`0=
4P`051TD014F4P0I7QX082DQ00hC3`0G7AT061hJ024W8`0S:BD061hJ00lE4@0201@J5P804aTE00T0
5A/G01LM6@0J81h0<3Hd01TO7@0J81h08BLU01lU8`0J81h00P0P9R@02@0O9B<08bTW02@]:P0H8b40
6BDS02di=`0f@T0062@R01DQ7`0201`X9P0M01dY9`0P;2X08Bd[024]:`0S;bl0938b024_;`0S<C40
:CTi02Xj>P0V=CP07S0b02Dg>@0R=3P07Blc02@e?00Z?D@08C<m028e?00^@4T0=DMA02m1BP0gBU40
<TA>055TK00oDUT0=dUC02m3B@0bAdX00P0dBD`01@0cB4/0=DY=03A9C00bAdX0<dQ;00<0=DY=01P0
=da@0397C00^@dP0=DY?03A9CP0`ADX0;dA903=8C@0fBe00=4U>0397C00cB4d0=da>03E;B@0hCT`0
?eAB03]?CP0jCTd0?E1?03a>CP0lCdh0?51?03eAD010E5<203mCDP0=03iBD@0lD4l0?51?03iBD011
EE<0?eA?045FD@12Ee80?E9=03mDC@1;HU`0CfIP045HDP0204eTGP0P04UOG013FEH0?eEB045GE017
GE/0AeeJ04QNG019Ged0CF=Q04MMG01=HV<0C65R04eRH`1CJFL0D6IS05=YI@1CJV80CVIJ04iVF@1F
KFD0Bf9L05U`JP1NMFl0D6MQ04iUG`1GKVP0DFQR04]RG018GeT0CfIP04UPF016GU4204QPDP1F04IN
D@13Fdh0@5Q;04MNE018GeD0@eY@04]RFP1GKVH0BV5G05I/H011ET`0>Di50356?@1`QG`0]<W0049G
D011ETd0@UM>04AID015Fdl0@eQ?049HEP15FeP0@eYD04MNE`15G580CFAJ049IC`13FU80A5]C04EK
F014FUP0@eUF03YCC00hCdL0>e9:03iEC@18GEH0@EI?03Y?B00fBD<0=DQ203A7@@0`@cd0;D4h0393
>@0a@SX0;Chf02Hg;`0T=Bl09CH`02Xk=@0W=c@0;cll06IfL`1_Ogh0:c/h02hm=@0^?CH09SD^02dl
=@0_?ST08c8]01d/9`0N;BX093<`02Lf<`0U<c<0:CLd030l>00/>3@08BdY01hZ9P0O:bL072PT01DQ
7@0O:bL0<Shj02Da;@0J9R807b/T028]9@0R;BL092lZ01lZ9P0M:2@201lX9`0E024Z:@0O:2L06b@Q
01XS800R9bH0310C02P/;`0^<SD0Q8R;02P/;`0K7b80Si>F07b0P`0<41<020`?01lS9@0H6QT05aTF
01/M6P0M7a`061XG00805QPE02409bTV02/]:P0B51407AlL01PJ5`0F61D051HC01HH5@0O8Ah08bDR
028T8@0I6aP02P`901DG500a<c005ALD01LI5P0K6aT07AdK01PH5P0C4a405QHD01<C4@0?3`d05aLE
00H6100J6QP0>CTg010@3P0E5A<03`l=014A3`0H61H00P0A4@l00`0h>3H05QHD010@3P0200h>3003
01<C4@0?3PX04A0=00804Q4?01D04@l?00l=3P0E4a@040h@01<A500F51L04Q0D014?4P0=2`h04Q0A
01@B4`0K6AX01P@504Q6A`0d<S<02@L8018@4@0>30d03@/<00P61`0A3a800`0D4QD03`0@3Q4030X=
00T72P0100804a4D00d;3P0I5aX03@/>00`:2`081PL03@/<00D3100@3Pl05Q@E00h<3@02014?4007
00h<3@0<2P/030X;00`;2@0;2PP030/900d<2P0200`;2@0900T81P0J6AL03@`:01DD4P040`405Q<C
00h:2`0?2``04`l@00800`0000<07ATJ00h:2`0>2P/00`0>2P/0200?3@h02PX:00H61P0=3@d03`l?
00`:2`0;2@X030X;0`0>2P/04P0?2@/03PT;00/720091@H03PX;010<3@0?2``030P900T51P050@80
30P900d92P0<20T06ADE00/71P0:1@D06a8C01H<3@8050P:01804`L901D<3@0A2`/02`D500`81`0K
5aP0920Q01LC5016@T<0;b//02HR8`0=2@X020@502LS900H51D03`/<00`82@0B310200h73P0<00l8
3`0=1Pd030D<00D01@0=1Pd04``C014:4@0;10/0@CY1010:3P0?2@d03PP<0`0=1`/03`080PH02`D9
00H0100=1`/030H:014;3`0I4aD020<400l92`0O6A/0<B/]00h82P0;1@L03@L900l92`02010:3003
00h82_oooooooooo01;ooooo000Kooooo`0800hD4P0=4a40318@00lC4P0C5aH05ATH01LI600>3`l3
00d=3@0?014B4@0F61L03A4@010D4`0?4a803Q8A00/?3P093@`05ATH01TM700A5A@01@T800`@3`0=
3`h0418A00804A<B0`0?4A001@0O8B002`d<01LI600;30/04a@C00803a4>0140418?00lA3P0=3``0
3@l<00/=2P0>40d0418?00lA3P0C5A803Q<?00T?2`0>51005QXG00`A3@083@T04AHB00dB3P0200d?
300800lA3P0B4Q004a<?018A300A40`040l;00l>2P0=30X2018A3`0>014?400E4a@03@/<00`:2`0A
4Q0020X5018D3`0=3`X0@T@o00`>2@0>40/0418=014C3P0@4Pd200h@2`03010A300?40/03Pl:0080
3@h90P0>3`X02`0=3PT03Pl:010A300@4@`03a0;018C3P0C5A002P`700/=200K7AP04Q@?0080418=
00@03a4<00h@2`0=3`X03@l:0P0@4Pd400lA300800T;1P0=3`X03a4<00lA300A4`h0418=01`N6`0G
6AH3014C400<00d?300D5Q<051HC018D4@0@4Pl03a4>00h@3@0@40h04Q8@01`L6P0@40h04a<A0P0B
4Q0201<C4@804Q8@00P0410>00h@2`0=3`X03a4<014C3P0B50l0418=00d?2P803Q0;0P0=3`X0200B
50l03@l:00d?2P0B50l02@/6010B3@0<3PT0418=0P0=3`X01P0B50l05QPC010B3@0>40/03@l:00h@
2`80418=01L03Q0;00lA300@4Pd03@l:00lA300B50l03a4<00l?3@0<30X04Q8@010@3P0;3@P04Q@?
010C300A5Pl041D>00lE2`0=5@X03QH;00lB2`0@4``02`h700hA2P0201<F3`0O014D3@0?4P/03a8;
010C300>4@X09RTR01lR6`0>4@X04A@=01@G400<3`P02@`500lB2`0@4``04A@=010C300?4P/0418<
00lA300>40/04Q@?014C3P0?4@`04Q@?00P:1@0@4Pd04A<>010B3@0?4@`03Q09014B2P0301<D3080
4A8:01@04Q<;014B2P0A4P/04a@<014B2P0?4@X03a4<010C3@0C5Ph051L>014D2@0@4`P030l400X=
100C5Ph04aH?01<E400H6a@05aXC01<F3@8041<800@04QH801DH3@0C5P/04QD>0P0C5A800`0A4a40
418=010C3002014D3@804QD>00d04aH?01PK500D5a003Q4:010C300C5Pl03A0901dP6@0B5@h05aXC
01XM5P0a=2d05APA008051L@00P05APA01HI4P0H6a@04aPB01HK5@0<4@/05a`F018G4@804aPB02<0
4QLA014F400B5a4051TC01DJ4`0G71D04QP>014G3@0D6A805AXC018G400C61805Q/F01HK5`0E6QH0
5a`H01hS7`0P9R805Q`H01@J5P0E6aL061hJ01lU8@0H7QX05adI01HL600G7AT0728N01lU8@0C6AL0
5adK02D[:@0M8b405A/I01`R800201TO7@0;01XP7P0N92807R@R01`U8P0N:RH062@P01dY9@0_>cL0
9S8^02Da;@0K9b<00P0N:RH0900O:bL08BdY02<_;00R;Rh082h^01d[:`0Q;bl08c<c028b<P0R<C@0
8C<e02Dg>@0U=c/08cDi02Hh?00R=C/0;d9902e0AP0Z?D<0<dI<0313BP0cAT`0<4=903=6C00Y?480
<DA;0314B00_A4L0<4E802m4A`0]@TD0;T=60315B00aATT0=4U<03M<C`80=T]>0180=T]?0397C00a
AT/0=DY?0397C00_A4T0<dQ=03M<D@0hCE80>e1E03eBE`0lDEH0>51A03E?C00jDe00@UQF03mCDP0m
Cdl203e>CP0>03a=C@0jCDd0?51?03iBD@0jCTd0>De<03Q<B`0jCT`0?51>03mCD@12Ee80B5eH04=H
DP0jCdP203iCC00K03M=B@14FUL0C69O04aRG`17GEX0AeiH04QOF@17GUP0C6=L04eTG`17GUL0AE]E
049HD`19H5X0BV5M05=YIP1BJ6H0D6EU055WI@1?IF80DFQS05=ZH`1?IU`0DVUO05=ZHP1BJF<0DFQR
0080D6MQ0P1?IV002@1AJ680BV5K04]RG01=I5h0Bf9J04EMC`14G4d0@UY<045IB`02041HB`0I049J
C@15G540@eY@04QOE@1>IE`0@eY@03eCA`15Fdl0?eA:03aAB@0nDdd0AEYD049GDP12Ee00A5U@04ML
D`17GE40AEY@04aRG`1;HEh0AUeG04QOF01=I5X0FW5W04QOE@0204QOE`0S04ILF@14FUP0A5YG059/
HP15G580@UU?03aCB@11ETd0>e1703Q=A00iCD@0>4a303A8?`0^@ST0;40g02dn=00]?SH0:S/c02@e
;@0O<2X07RlY02Xk=@0Y>CH0<d=002/k>00_?ch0:3Pe02Ti<00T<b`08C0Y02Lf;`0U=2l07bhY020_
:P0Q<2d00P0S<Rl0@@0Q;bl0934_02Pd<00U<Bd08RhZ02@`;00Q;BT07RXV01TU8@0T<2`0?4Q402/g
<`0M:BD07BXS01dZ8@0Q;RL0:3<_02<];00P:RX07bPZ01hV:00N9bH07BDR01dS7P0N91l08RLU024U
9@0^<S<06alP02/_;`0J7Qh051PI02/_;`0X;2d08RHW01lS8`0G6a/06Q`I01XL5`0Q8ah08bDP01dO
6P0H6QD04aD@01`N6@0O8A`0418=01`N6@0H6QD05ALD01HH5@0G6AH061XG01/M6P0R92408B<P01@F
4`0G6AH0;Bl/01PJ5`0@4Pl05ADC01HF500D51804Q8@00805ADC01@03@d;01XJ600=3@/05ADC02DU
8`0<30X04a<A00d=2`0@40h05QHD018B400@40h04A4@014A3`0F5Q@04Q8@01@D4P0<30X04Q4=018A
3P804Q4?01H04Q4@018@4@0F51D03`d?018@4`0G5AP04a4E00l=400C4A@04@l@00L51P0G5AH04Q0A
06QVI`0l>S/04a4B018@4@0D4Q<03`d>00d;300=2`h030X=0P0=2`h03`0?3A004@lB010?4@0<2Pd0
5Q@G01@B5@020@<05aDH00d;300I5aP08R0Q014?400=2``03`d>00d;3002018@4@0E010>3`0>30d0
3P`=00h=2`0?3P`03Pd;00d<2P0@3`d04Q4?014@3P0<2`T03Pd;00d<2P030P403``<020M7@1RGUl0
510A01XF5`0<2@T03`/<00D03PX;00P03P`=00T92@092@T03@d=00T92@0:20T03P`=00`:2`<03PX;
00D03`T;00l:300?2``03`/<00h:2`0200d92P0O00`82@0=2@X0510A01/G600B3Pl030P900/71`0A
3@`04`d=01482@0F30d05@T;01H:300C1`T040H700`41@0:10@03PT800`81`0B3Pd02`L601@@3`0?
2`X02PH5014=30091@@02`L6014=300>2PT030P8014;3P0200`62@0900l93@0<1PT03@L;014;3`0<
1PT02P@701<=4@0C3A0030L:00803PL>0P0@2A00400>1`h030D<01XC6P0P6B0030D<00d63@0?20l0
2P@800/5200B30h03`T;00P3100@2P`030H800d72@0>20X300l92`0300h82_oooooooooo01;ooooo
000Kooooo`0500dA400;3`h020`;00P<2`0;3Pd00P0>40l08`0=3Pd051@D01LG5`0D4a<04a<C00h@
3`0:3Pd0310?00L;2P0<40l02@d<014E500=4A0020`;00/?3P062PT03A4@00h@3`0?4A003@l>00`>
3@0@4Q4051HE01DG5P2=Shh08R@S010B4@0;3@`09bTX00lA3P0A4a004Q@A014C400>40d030h;0080
3Q0=01T0418?00h@3@0R92402@h:00hE4@0020<07BHQ00hD40073@T01P`800T>2P0<4@d03A8>010B
3`0>40d03`l;010?2P0@3`/03Pd900l>2P0A40h03Pd;00X91`0<2P/03P`=008030X;00H03@d;01DG
4P0210005aTD01/M600:30L200d?2P0600h@2`0=3`X030h900d?2P0?4@`03Pl:0P0=3PT01@0>3`X0
3a0;00h?2P0=3PT03Pl:00803a0;00L03Pl:00h@2`0?4@`06A/F00X<1`0F61<03a4<008030h900@0
3Q0;00lA300?4@`03a4<0P0A4`h00`0?4@`03Q0;00h@2`0200lA3003010B3@0C5A004A<>00803Q0;
00<0EUQE0494@@0L7Q/00P092`P01@0=3``061XG01HH5@0B51403a4>00803@l<00L03`l=00h>300F
5Q@02PX8014A3`0C4a403`l=00<0410>00<03`l=00d=2`0>40/00`0@4Pd200lA300?014C3P0>40/0
3a4<00h@2`0=3`X05ALB01@F4@0A4`h06adH00d?2P0B50l02`d800h@2`0B50l04aD@00804A<>01@0
5QPC00h@2`0=3`X03@l:00lA300@4Pd03Q0;00`>2@0>40/030h900lA300A4`h03Q0;01<C4P0;2`/0
4a<C01LG5@0@4Pd04Q@?010C30804AL=00L03aD;00hF2@0?5``03Q4:00T<1@0=40T06A`E00801@P1
00P02Pd601XM5P0A50d04A@=00P;100F6A804QD<00P;0P<03A0700d051L>00hA200@4`X04A@;010C
2P0>4@P03Q0:00`>2@0>40/03a4<00`>2@0B50l05ALB00802`d802@03Q0;01/M60051`8051H?014C
200C5@X051H;01<E2P0A4`P05AL<00D7000M7a@0:bdR00h@1@0E5``04Q@=010B3@0B50l06QdE01XM
500C5P/03A4300`?100?4PT04aH>010B3@0C5A403Q4:014D3@0D5`h04A@900lB1`0?4`D04A@9010C
200?4P/2010B3`0300h@3P0@4Pd041<<00804A@=0P0B5@h03@0930D03A09010C300B5@h06A`E01hQ
6P0M81T07R4J02X]9P0>4@X06ahG018E3P0E61400`0D5a007`0E61405QTB01<H4P082`L092TS00@9
0`0E6Q@04QLA010E3`0E6Q@061dG01TN600F6aD04aPA00dB2`0E6a4061hD01DJ4`0F6a@06b0I02DZ
900E6QD07B8N01XO6`0C61@08RLS00/A3@0@5Q806R0L01/Q7@0D6QH00`0C6AD0200B61@04aTE01PN
6P0K8Ad06AlM01HL6P0L8R005Q`J0P0G7A/09@0J81h05Q`J01TO7@0O9B<07R@R01TR7`0I9B40930/
01XV8P0O:bL07RXV01dY9@0L:2@07RXV01l[9`0P;2P08BdY02<_:`0Y=CD0;C/k02Hd=00O;Bd08C4a
02<c<`0S<SD093Hh028d=P0Q<cL08cDi02@f>P0W>Sh0;T5502`o@`0^@DD08C@h02Dh?00P<cL00P0_
@TH05@0Z?D40<TE903A8C00dBD`0=DY=03A9C00bAdX0<dQ;03A9C00cB4/0<TM:03=8B`0eBTd0=da?
03Q=D@0iCU<0>TmD03E:C`0^@dP0=DY?03iCF00203]@E@1l03eBE`0nDeP0?55F03IAD00fDdh0>EA?
03]CC`0nDU00?U5?03i=C00lC4/0?U1>03mBD00mD4h0>Ti<03U=B`0fBTP0<dM503M;B@0jCT`0?55<
03mDC`1>Heh0BUmH03eBB`12Ee00?E9:04QNF`10EU@0@eUG04iTHP1CJFH0B5mI05A[H`1:HET0AEaC
04]RFP1:HEL0B5mE049IC`19H5H0AeiF04mVH01?IF80CfES05U_K@1CJFL0CfIQ04iUG`1?IUh0EFaT
04iUG`1EK6H0DFQR04iUG`1AJ680CVEO04MNF01?IV00AUeG04mVH01;HU`0C6=K04=KC@12FTX0@5Q8
045IB`14G4h0AemA04YRE@12FTd0CFEH04mVG014Fe40AUiA04]QE00lDTH0?UA804aQFP17G5H0C65L
03Y?BP12Ee40AU]B04AID015Fdl0B5iB04YPG014FUL0@5MA04IMEP13FU00BF1F04ELDP16GED0AEaD
041FD`0nE580?UAA03YDBP10Edd0AeiD041GC@17G5<0BEiE03Y?AP0gBd80=DU003=7?P0bASd0<DDl
03=4>P0Y>S808c@/02@e;@0[?3H0;Sli02Tj=00V=S<0;cll028b;`0Y>CP0;Cdj02`l<`809C@]00@0
:3L`02@c;P0O;RT08C0[0P0R<Bh0;P0Q<2d08Bl_01l]:P0O:bL07RXV020/:00W<bl0930/01dY9@0O
:bL08RhZ01XV8P0I9B406bLS01/Y8P0J:R007R/T02@`;@0R;R`08bd^028[;@0N9RP082HV01hT8@0M
91d07b@N020U800M8Qh04QHE02P]:P0I7QX0720N01<G5P0J7a/09BTW01@H5`093PX06AhK01LI500E
5a8061XE01TK5P0E5a8051HA024S7P0G6A@201DG4P0@028T7`0B50l04Q@A01HH5@0H6QL04aDB014C
400F61D03@l<01@F4`0A4a004Q@A01DG500Z;2T05aLE01DE4`8051@B01004a<A01@D4P0>3P`04A4?
01/K6@0C4a4030`:024Q7`0?3`d061PF018B40092@L03@d;01HF500<30X06a/I0P0>3P`200l?3@0`
018A3@0B4@h04Q4?018A3`0B4A004Q0A00l=3P0>30h04Q0C014?4P0=2`l040hA00h<3`0A3a0061HG
014?400=2``00@0000D3100D4Q<01`D600d;300E4a@04@l@010>4@0D4QD06ALJ00l=40050`H01P@7
014?4P0R82<02@L:00P62@0H5QT02`T<018@4@0:20T04Q0A014?400J61T071XK010>3`0?3@h03@/<
00X82@0<2P/03P`=100>3@/03P0@3`d04A0>018A3`0?3P`05QDC01@C4@0:2@L04@h>01XF5`14@440
3@X:00L3100C3a002@D61@0>2P/01P0;2@X030`<00l?3`0820P0000000@20`8030X;0`0>2P/01`0?
2@/03@P900`82@0>2P/040`=01<?400G4a@00P0C3a003P0O6a`0920Q01DA4P0=2@X030L800h8200C
2P/050X;01D;300K3Q005PL:01@82P0A1`P040L80P0?2@T020091@@03`/:00X61@0300002PH500P4
0`0<20L04@d<0P0<20L040050@003@T801<=3@0=1`L030H700l92`0>20P04@/<00h82P0B30`03`T:
00H00P0D3Ph02P@600`62P0=1Pd20109400=00l83`0=1Pd030D<01TB6@090PT03PL>014:4@0:10P0
3`T=010:300;1@L03`T;014;3@0300l92`@03PP:5?ooool001_ooooo01d04ADD00lC4P0<40l0310?
00d@3`0?4A003Q0?00h?3P0E5AD05aLG018A4@0?3`l02`d<00lC4P0;3`h05QXI01/O7P093@`03Q8A
00/?3P093@`03A4@00H:2@0;3`h03@l>00h@3`0<3Pd02@/:00h@3`02018D4`0N02T[:P031@@03a4@
01XL6`000@003a4>010B3`0A4a00418?00h@3@0<3P/03@l<01DG500@4Pl08B<P02d_;0083@T03aLB
00070P0?61<01@T60004000@5Q802a0<00dB3P0>4`l0418?00d?300=3@P03Pd80P0?3PX01@0>3@T0
40l=00l>300D4a405aDF00<03P`=00L03Pd;01lQ70072@@07R0K00L9100>40/0418=00803@l:00D0
30h900/=200>40/03a4<00h?2P0200d>2@0500h?2P0?40/03Pl:00`=200=3PT00`0>3`X02@0?4@`0
3@l:03Li=00I6aH01PP300h@300;3@P030h900h@2`0300lA300301<E400A4`h03a4<00803@l:00<0
3a4<01<E400A4`h00P0C5A005@0>40/03@l:01DG500?4@h01`T600X<2@0?4@h051HC010B3`0?4@h0
3@l<00`>2`0=3``03a4>01DE4`0@40h04Q8@00P81P0>3P`03@d;00h>300300l?3@0300h>300<30X0
3Q0;0080418=0P0>40/2010B3@0800lA300E5a804aD@00P:1@0<3PT0418=00lA300G6A@3014C3P0I
010B3@0<3PT05aTD01hP6`0F61<020X500lA300=3`X030h900h@2`0@4Pd03a4<00h@2`0A4`h03a4<
018D3`0C5A003a4<00l?3`0;2`/03Ph>01@D4P0B50l03a4<010C3002014G3@0@00lE2`0=5@P03QH9
018E3P0=40T02Pd600/>1`0C5Pl0?d8k01hQ6P0I71D03A0900lB2`0;3PL041<<010C2P803Q4800<0
2`h500lB2@0F6A000P0?4PT04@0@4`X03a8900lB2@0A4``04A<>01@F4@0F61<051HA01lQ700L7QT0
418=02<U800H6QD06A/F00L9100K7AH04A<800<04Q@901`04A<801@F2`041P007AlD02`^8`0;3@80
4Q@901@F3`0A4a003Q0;014D300D5``051P:010D1P0B5PP051L<014D300A4`h03Q0=00`>2@0B5@h0
61/B01DH3@0A50T03a<501<F2`0A50T041<<0P0A4a000`0?4@l0418=010C3002014D3@804QD>00@0
3Q4:018E3P0C5Pl04aH?0P0G6Q<01P0A50d01PT201hQ6P072P<07b8K01LJ4`805APA0`0D5a002@0E
614051TC02`a:`0<4@/06QlI00X?2@0X;BL04AH@01DJ500201XO6@0C01LL5P0C61402a0901dS6@0V
;2807b@M01HK500G71D07B8L00`A300U:RH02a0<02X_:`0P9B404QPD01DK5`0K8Ad06R0L01<I5@03
01@J5P0401DK5`0F71P061hJ01TO6`806b4O01<05A/I01HL6P0O9B<06AlM01hT8P0J81h06b4O01hT
8P0L8R005b0M01dX900F8Qh07RXV024]:@0C7a/07BTU01/W8`0J9R8072PT008082`X00l07b/W02`h
>00b@400:SPh020^;P0R<S8093@d02Dd=`0^@480:S`n02Li?@0V>3`0838f02@g>`0eB4`00P0^@DD0
3`0X>cl0DfIZ02Hi?@0V>Cd0:ci20354B00^@DD0;T9503A9C00eBTd0=4U<03=8B`0dBD`0=T]>03A9
C0020397BP0903=8B`0fBdh0>4eA03Y?E00kD5D0=DY?02m4B@0iCU<0@EIK0080?U=H06`0?E9G03]@
E@0jCe@0=U1?03EDCP0dDD`0=Da903Y>C00oCdh0?4];03i<C012DU40@EAB03iAC`0iCD/0@5AB03]?
C@0fBTP0=d]903Y>C00jCdX0?eA?04aQG01<HEX0@5E>04=HD@0oE4`0?59@04EJF`1KLG00Bf5O049H
EP13FED0KhIn061gK`1AJ5h0CVEK04UQE010F4/0?UI904EMD014Fe00CVEM051WH@1DJVP0H7Id05U_
K@1BJ6D0CVAQ04aSG@1BJF<0C6=M059YH`1AJ680D6MQ055XHP1>IEl0F6mY05YaJ`17GUP0E6]U04iU
G`1?IUh0AemA04INCP15GDd0AUi@04UQD`1<I5H0BF5D045IC01<I5L0CVEK04=JD018H5<0Aee@03U?
@@19Ge<0CV=L03aAB`0aAT40?55<049GD@15FU40A5U@04=IC014FTh0AeeI045GE00oEU00AEaE03eD
BP0oET`0AEaB04QOE`16GED0@5IC03iDDP10EU<0?eU?04eTFP1EK680?UE;03A9@00bAch0?55803A8
?`0cAch203I:@@0B03A8?`0b@cT093D]01h_9`0R<b/0;Chh0352?00Y>S@08c<`02`l>@0Z>SL0;Cdl
02Ti=P0Y>C009SD^02Lf;`0Y>3409cHa0P0S<Rd0:@0T<c008S4^020_;00Q;bl08S0]02@`;00S;b/0
8RhZ02@`;00S;b/07RXV02Xf<P0^>SH07RXV020/:00U<Bd08BlX01h^900O:bL08BdZ01dY:@0O:B/0
7bPZ01`T9P0O9BD07B<P01/R6`0L8AX06AhG01HK5`0`=C4061dI01/P700B5a<09R/W014F4P0C61@0
6QlK01hS7`0F6aH071hI008061XE01H06A/F01HH4`0H6QD06adH01LI500K7AP051HA01XL5`0F61<0
51HC01PJ5`0K7AX061XG01LI5P0J71T06A/H01XL6@0L7Q/06A/H01LI5P0k?CX06ATG0`0E5A<05P0B
4Q0051@B01<C4@0C4a404Q8@01<C4@0F5Q@05aLE00`<2P0A4@l03`l=028R800820H05ADC014A3`0K
6aT020P601`L6P0=3@/051@B018A3@0B4@h2014@3P07018@400B414040h?014?4@0D4QD04Q0C00l=
4@0201<A500=00X82@0N71d030X;01XH6@0F51D02`T:01HD5@0A3a003P`=01@B4`0Y9bP03@/>00L5
200200X82`0Q01@B5@0R82<030X=00<1100D4QD07Q`O00l=400>30l040h?00L51P0B414040h?00T7
200100004@l@00h<3@0;2@X02@L800`:2`0?3@h03`h<00h=2`0?3P`040l=00h=2`0;2PP051<A00H5
0`0920H030/900d<2P0=2PX040`=00803PX;00<04Ph?01/G600C3a001@0>2P/0200;2@X03`l?018B
4P0>3Ph051@D01HD5@0?3@h030X;0`0>2P/02`0?2@/04@`=014=3P0?2``03PX;00l;300@30d03PX;
00l;300C3a005Q8C00803PX;01X04`h>00`61P0?1PL050X;01@82P0I2Pd05@H901L82`0C20X04PT:
01D<3@0?2@T04`l>01/G5P0C3`h020@301<?3P0>2PT01P8100h:2@0@30/03@T800L30P0A3@`0618B
018<30803PP800<030H600d71`0600000P0C3@d01@0400003@L700h92@0<1PX03@H=00<03`P?00d0
3PL>00D01@0A2Q402@8900l83`0@2A0030D<00d72`070P<01000010:300>20X01P0200802`D700@0
30H800h82P0A2`d04`d?5?ooool001_ooooo02403Q8A00lC4P0?4a8041@C014D4`0A4a8051DD00l?
3`0A4A4051<C018A4P0C4a<0418A03@i=`0<4@h03A4@01`P7P0[;bd04QHE010D4P0=4@l041@B00T=
300>4Q40418A01LI600F61L04A<B00h@3`0@4Q403a4@00h@3`0=3`h00P0?4A000`0>40l03a4>00lA
3P0200lA3P803@l<02003a4>014C40092`P03Q0>01<E4P1_M7008bXU014H500:3`/03AD@00`B3P0<
4@d051TE010E4@0=4Ph03a4>014C400@40`04a4<01/G500J5a@04a4=010<2`0>2`X09B<Q02`X:00C
41005a@D01XF5`0@3`d05ALB01HH4`804A<>00H03a4<010B3@0?4@`03a4<00h@2`0=3`X2010B3@<0
3@h900D03Pl:010A300>3`X030d800d>2@0300h?2P0600l@2`0=3`X08R@O00X;200G6A@03@l;0`0@
4Pd04@0?4@`03@l:00/=200D5Q404Q@?00h@2`0<3PT03@l:00lA300C5A0030h900h@2`0D5Q40418=
00`>2@0<3P/03@l<00804A<@00l03a4>00d?300C5A804Q@A00lA3P0=3``03Q0=014C400E5A<03Ph<
01<C4@0@40h051@B00X:200@40h00P0A4@l2010@3P0900h>300<3PT03a4<00h@2`0=3`X0418=01HH
4`0H6QD03@l:00<03Q0;01H07R0K00d?2P0@4Pd03a4<01HH4`0=3`X05aTD014C3P0=3`X04Q@?01<E
400?4@`04A<>010B3@0=3`X030h900h@2`0@4Pd03a4<00h@2`0A4`h03a4<0P0A4`h05`0=3`X06QXI
028R8P0E5A@03Ph<014C3P0=3`X03a8;010F3@0@5P`03Q@:00dD2@0>5@X04A@=018E3P0>4@X05APA
06]^I`3Si]l0CE19010C300H6a@06A`E00804A@=00D04QD<01<F3@0=40L03Q4801<F3@02014D2`0Q
00lB2@0>4@P03a89010C2P0C5Pl030h900X<1`0@4Pd02@/600/=200@4Pd06A/F07anN@1?DD`04A<>
00h@2`0D5Pl04A<8010A200?4@L04187014C2@0@4@L05QP=018C2P0D5P`05AL<00d?1@0B4`d03a4=
00lA300@4`/04A@:00804AD901<05QT>01<F300C5Ph0:2XU01HH500A50h05QTB01/N5@0D5`d03a87
00lB1P0D5``04QD;014D3@0B51004aDB014C400@4Pd041<<00804A@=0P0B5@h0300A50d05APA01HI
4P0F6A805aXB018E3P0I71D030l801TL5@0E61406QdF01<F3`805APA00X051L@01<F3`0D5a005APA
014F401HGEL041@@01HK5@0C5a805a`F100D6A<201HK5@0D01DJ4`0J81H06b0H01PM5P0E6Q<05Q/D
01XO6@0F6aH05a`H01XO6`1JGe/05adI01HL600G7AT06b4M01TO6`0H7QX07bDQ01HL600H7QX201/Q
7@0801XP700H7QX05alL01XQ7`0H7ad06R8O01dU8P0L8b4201XR7`0401/S800M92807B@R01`U8P80
6BDQ02P05b<O01`X900J9R808RhZ01l[:00I9B406bTT02Hb;P0T<2`07b/W02Ld<`0Y=cL09C<c02<a
<@0S<c<08C4a02Xj?@0_@D<09CLi02Dg>`0^@4@0:Sa002Lk?00bATL08CDf02m3A019GEh0Wk>d03]?
D00fBT/0>4a=03U=CP0dB4T0<dM90356B@0cB4/0=4U<03=8B`0eBTd0=T]>0P0eBTd0>P0fBdh0=4U<
03=8B`0eBTh0<dQ=0356B`0fBe00=daA03U>E00lDEH0?U=H045FF`0mDUL0>4eA03Y?D`0hDe40>EMA
03UED00gCd`0?U=?045BD00oCTd0@4m>049AD00oDU00?U5?03a@CP12EU@0?51>03Q<B`0nDU40A5QF
04EIEP11EE40B5eG04UNF00oE4`0?eA;04AID@18GE/0CVAT06YoP01FJfT0Bf5O04UOFP17GED0@eYA
04IMD@18Ge80@e]=03iEA`0lE4H0A5a>04IND01BJF00DfYS05I/J01IKfd305I/J@0@059XI@1DJfH0
EF]W04mWH@1BJV@0EVeW05A/IP1GKfT0PIRB06j6P014G5H0E6]U04aSGP1@Iel0BV9E04YRD`<0B61A
0300AemB03eEB01:HUD0@e]>04MNE01EK680BV9E04EKCP14FTd0Bf5E03eBBP1=HU`0@eMD04IKE`12
Ee40BEiF05=XG`1CJEd0B5iB04IMF@19Ge`0AEaF04IMEP11F4l0B5mE04AKD@19H5P0AUeE03mFD@0o
EE80@UQD03YDB00mE4T0AemB03aDA`0lDTL0?E=703Y@A@0cAcd0=TXo03mCB@0jCT@0<THk02ho=P0T
=Bd08C8Z02@e;@0V=c4202Lh<P0A02<c<00b@Sl0;Shk02Ti=`0Y>CH09cH^02He;P0V=Bl08C0Z020_
:`0U=300:STe02/h=P0U<S007bdZ020];00R;b`00P0V<Rh0C`0N:RH07BTU01hZ9P0M:BD06bLS01hZ
9P0P;2P07BTU020/:00Q;RP07B/S01dZ9P0P;BT07BPY01dW:00O9bX07bLY02<Y:@0R9b@07R<M01`Q
6P0Q9R006b0K01<H4`0P9B0061dH028W8P0Z;bX04aPC01dR7@0J7aX06b0K01DJ5@0K7AP061/D01TL
5@0I71H05QTB01PK500J71H04QD>01XL5P0G6Q@06ahG01HI4`0I6aL061XG01HH5@0D5Q<05aTF01/M
6P0>40d07R0M01DG500=3``061XG01DG500F5a<04Q8?01<D400E5Q804A8>01DE4`0B4Q004a<A01DE
4`0G5aD05ADC010@3P0D51803`l=03Xj>02UYJ<08R8P018B401NGU`0VIVG01/K6@0E5A<00P0@40h0
9P0B4@d04A0=00l>300?3P`04@l?018@4@0D4Q<03`d>01<A4`0F51L04Q0C010>4@0<2P`04a4B010?
3`0>30d04@l@00l=3P0>30d04@l@00h<3@0A3a001@<401LE5P0A3a803@/>014?4P0@3Q406QPK02XX
:`0?3A004Q0C03Pf>@15@dH06ALJ02h/;P0P7Ql02PP90P0>30d00`0B41403`d>00h<3@0200l=3P0>
00d;300?3@h04Q0@00l>300?3P/05QDB028Q7@0N7AX061LD014@3@0=30T09RDS024P7`0?3@d2018?
3`0301TE5P0A3@h04Ph?00803@T:1@0>2P/0200=2``03`l?00h=3P0D51@0>STi02l];P0>30d030X;
0`0>2P/04P0?2@/04`h@018>3`0<20T03PX;014=3P0@30d03PX;010<3@0?2``04@d>00/720091@H0
3`X;010:2P0@20P04PP901L<3@805@P:02<05PT;01061`0@1`P05@d>010:2P0<1`D05Q8?00/71@0;
1PD04Ph;00/71@0<1`H01`<100`81`0>2@L040`900h91`0F40l03`X700`6100=1`H02`H300h91P0;
1P@04@`900h81P0=20H040/8018<300>1`d03@H>00d63@0>1`h03`P@014:4@0201094@0900/4300A
2Q4030D<018;4P0@2Ph04P`?00`62@0G4A@03PT;00<03@L:00@030H900d72P0A2Pd04P`?5?ooool0
01_ooooo00D06QhO00`@4@0830d0KW9c01@H6@0200`@4@0A014D5@0?4180414C00/<3P0H6QT03@l<
00`>2P072@@04A<@03Li=@3inoH0IVQU018D400B50l04Q@@014C400<3P/00`0H6QT02P0C5A@030h=
00T;2P0=3`h030h=00d?3P0@4Q403a4@00h@3`0<3P/200lA3P0400`>2`0?4@h051HC00L91P80418?
00X02`d:01XL6@0R92405a`F02hc;@011P0041D?00hC3@0D5Q402`d80P0?4@`05@0>40/03a4<01DG
4P0=3PT030/7014A300H6A@06QTE018B3P0D5A004a8>014A3@0C50l06QTG01dN700D5Q<05QPE01DG
500210405ALD00d?300200lA3P0700h@3@0?4@h03a4>00h@300=3`X03a4<00h@2`0200`>2@0800h@
2`0<3PT02`d800d?2P092`H03@l:014C3P0@4Pd200d?2P05018D3`0?4@`03@l:00lA300A4`h00P0@
4Pd01@0B50l02``702LX8`0l?CP030d800803@h901H051D@00H70P0L7AP0=CHa01PI500?40/02@/8
018D4`0E5aH0418A014C4P0>40l04A<B00X<2`0B51<0418A00H81`0B51<04Q@A00lA3P0=3``03a4>
0P0B5140100<3P/03@l<00h@3@0>40d200lA3P0K00`>2`0>40d0418?010B3`0>40d030h;030b;`0>
40d02@/801DG500>40d061XG00D70P0c=C006Q`G0084000?4@`03@l:00lA300B50l030h901DG4P0O
8A`02`d800d?2P0>40/0418=008051HA00<03@l:01<E400@4Pd00`0?4@`01`0@4Pd07AlJ02X/:@0B
50l03@l:018D3`0210000P0=3`X0300C5Pl04QD?00P;100A50d03a8;01PK500F6A804QD>02/^9`13
ASl09BPQ01@G408030l802H02`h701LJ4`0;3PL041<<01DH4@0>4@X02Pd6010C300?4P/04A@=010C
30082`@02`h701LJ4`0E61403Q4:00d@2@0B5@h051L@01<F3`0@4``06A`E01@G400930D01PT201/N
5`0>4@P06QdF00d@200S9Qd04A@=010C2`0E60l06QdF01XM5@0=40L02Pd6010C2P804aH=00d04QD=
014C3P0A4`h0418>014C3P0C5A004aH>014D2`0C5Pd030l8010C300B5@h03Q4:00803A0700d03a89
018E3P0B5@h030l800`>2@0E5a80418=02LY900@4Pd051HA01<E400C5Pl04QD<00804aH=01D041<:
010C200C5Pd05Q/D01LL5@0;40T07B8K00lD3@0A5Pl051TB00/@2@0C6140314:01@I4P0I7QL02a0:
01@I4`0@5@l04aPB00lD3P0H7AL0100E6Q@0100D6A<04QLA014H4@0D6a@201HM5P0;01@K500A6140
3QD>01DL5@0C6Q<07B@M014H4@0M8al04ALC018K600F7a`00`0H8Ah0:`0C71T06B8O01HO700K9240
5AhK01PQ7P0C7QX05b8N01PS7`0G8Qh06bHR01hY9@10BdL05b8N00`G4`0Q;2P07RTU01lZ9P0T;bT0
41/E00lJ5P0R;R/0B5AB02Pd<P0K:RP06BPU02ho>@1AHEX0<3lh01LV7`0Z>3L0:CLg020`;`0Q<C40
:3Lj01PZ;00S=CL09cTm02Lj?P0V>Cd0:3/o02/n@P0Z?D400P0Y?4002P0[?T80;T550395B@0X>cl0
CV5U07jAU@18Fel0<DA803=7B`0cB4d203A9CP0403=8C@0eBTl0=T]@03A9CP80=DY?05`0=T]@03U>
D`0hCE<0<TI=0314B`0fBU40@5AK04=GH011EE`0?E9G03aAEP0mDU@0?E=A03Y@C@0jD4h0AE]H03iD
D@0mDdd0;T<l04QMEP0jCDL0?U5;03iAC00dBD@0<dM503Y>C00dB4H0@5AB03U=C@14Ee/0BUeQ09f`
]021U9P0F6a]04MKFP19GUT0@eQA04MLD`1=HU/0?eA=05Q/IP1SMfh0EFYQ049FC@10E4/0AUa@04=H
C@17Fe00@EM;03]@A00jDTD0>e=604QOE01CJV00E6]S05M^I`1GKVP0EVeW05M^J01IL6X0F6mZ05E[
J01AJVL0DVaX04YUH01=IV00EW1X04eXG`1FL6L0DVaU04aWH014GET0GGMc04aUH@1BJF40CfMJ04eU
F01<I5L0BF5D04AKD@1:HEL0CVEK05A[H@0jDDL0CfIL03E=@016GU00EViQ05eeJ018H5<0?UE;03aC
B`80AEaD0P14Fe<0?`16GE<0AUeE04YQG012F5D0@eYD04MNE`13FU80?UE=049ID@13FU00@UU?041G
C`0oET`0@EQ>03QBA`0fD4L0?eU>03iEC00lDd/0A5]A03I;@`0aASl0=4U003E8@@0aA3h0<THm02hn
>@0W=S407RdX01`[9P0Z>C@0=D@o02Xi=00]?3L0:3Lb02@c;P0U=2l093<^02`k=P0R<B`08c8_01XY
9P0N:RX09c<c02Xf=P0[=CH09Bl_024[:P0U;bh09S4/01hY8`0M9R407BPR01lZ900O:RH07BPT01PT
800H9b@082l/01l^:`0M;2T07bXW01/T8@0201XS800401HO7P0A6QT0:S0`01hT90807B<Q02<07B<O
01`R7P0S:2L09BTZ01/O800A5AH06AdN020T9@1DF5T09RX[01TM7P0P92D06QhO014E5@0K7AX06Q`G
01PJ5P0G6AH061XE01/M6@0I6aP07b4L01/M6@0C5A805QPC01TK5`0I6QD06Q/F01HG4P0K71L04A8=
01XK5P0K71L06AXE01HG4P0201DF4@0W01<E400D5a005APA010C300B5@h061/D014B3@0G61<04A4=
00d<200?3PX05A@@01LF4P0D4`l040l;01`K5`0[:RH06APD014@301DDdl0UIB@020O6`0:2@D08b8N
014@300>3@/05QDC00/:200E51804a8@00l>300C4Q004Q4?014@3P0B41404@l@00h<3@0?3@h04@l@
00804a4B00d04@l@00l=3P0A3a0040h?018@4@0C4A8040h?00h<3@0=2``04@l@00d;300B41400@00
00804Q0A00H03@/<00h<3@0A3a003P`=00/92P0B3Ph200d9200300l;2P0A3@`04@d<00804@d<0P0@
30/03`0?2`X03PX901PG4`0F5Ph02@T0051@@`1cM6H0BDXl02<T600K6QD08b8N00l=40091Pd03@X=
00d9200201DA400<00X61@0@30/05Q8A010<2`0?2`X030P700/71P0=2@P03`/;00`:2`0>2P/03@X;
0`0>2P/01P0H51D020@5010<3@0B3Pl03@T:01@@4@D03PX;00@03`/<00h:2`0=2@X02`L80P0:1PL0
9@0<20T02`L800h92`0?2@/02P@6010:300C3@l03PP:00/51`0F418030P900T41P0;1@L02`D500d5
1`0A20/040X:00l72@0D2`h04@/;01082P0?1PT03PP801492`0>20X03`T9010:2`0=1`T030H600h8
2@0A2`d030H600T310090`D02@<301<=3`0<1PP01@0<1PX0300:10P04`dA00@00P0E3a<02PD8018<
400>2@l050lE01<>50070PP05Q0G01<<4`8050XB00@04@L?00h4300@1@d04PP@5?ooool001_ooooo
00H04QHG00dA4P0E6AX0>Cdn014E5P0?4a@200hB4`0C010D5@0;3a004ADF04a@C`0G6AH04aDA01HH
50092`L07R0L05mQG@0_<Bd03Q0<01HH500;3@T04A<?01<E4P0F61L051HE018D4`03014C4P0700lA
400=3`h03a4@014C4P0@4Q403a4@018D4@0200h@3@03010B3`0>40d030h;00804Q@A00X01PP6018D
4@0?4@h03a4>01lQ700B50l0418=018D3`072@@04A<>0P0>40/05P0=3`X030h900d?2P0B4`h02``7
00h?2P0A4Pd04a@?01LH4`0A4Pd0414<00l@2`0<3@P02``700d>2@0>40`0:2XW01TK600:30T03a4>
01HH5@0>40d200lA3P0900h@3@0?4@h03a4>00lA3@0?4@`04A<>010B3@0>40/03a4<00804Q@?0P0C
5A001P0;3@P02P`700h@2`0B50l0418=00`>2@803a4<00<03Q0;00lA300?4@`00P0<3PT00`0?4@`0
51D@00/<1`02014B3@0;00h?2P0A4Pd04a@?00`=200@4@`05QLB00T:1@0B4`h03Q0?00d?3P0?4A00
0P0A4a802`0>40l04aDD00L9200=3`h04aDD00lA400B51<03a4>014C400C5A804A<@00803a4>00L0
418?014C400@4Pl0418?014C400@4Pl03Q0=00@03a4>01D03Q0=01DG500;3@X061XG00T:200>40d0
30h;00T;1P0Q8ah04aD@00T;1P0B50l030h9010B3@0A4`h030h900/=200@4Pd03a4<01<E400>40/0
0P0B50l0100<3PT04A<>01<E400@4Pd200lA30<0418=03805ALB01HH4`0>40/03Q0;01@F4@0B50l0
30h9018D3`0E5a802`d8014C3P0B5@h041<<014D3@0=40T04A@=01XM5P0>4@X030l801<F3`0A50d0
4QD>00d@2@0C5Pl03Q4:018E3P0C5Pl04A@=01<F3`0?4P/061/D01`O600A50d03Q4:018E3P0@4``0
3A09010C300E614051L@010C300A50d02@`501XM5P0B5@h04aH?02`_:00Y;2D04QD>01DH4@803Q4:
01X071lH01DH4@0?4P/041<<018E3P0D5a005QT?01<G2@0C5P/04QD=014C3P0A4a004aDC01<E4P0@
4Pd04A@<018E2P0A50P06QdD01HI4P0@4``04A@=01@G400C5Pl04A@=018E3P@051L@00h0:2XU030b
;@0E5a805ALB010B3@0D5a004QD<01@G3P0F6A005AP=01<F2`0D5``03a@=014F3`8051TB00`04QL@
00hC300K81T03A8;01LL5@0D6A806QlH01<H4@0C61804QLA00hC3@0F6aD201<H4P0801@I4`0E6Q@0
5AXD01@I4`0C61804QLA01XQ6P0G7QL201DL5@0801LN5`0J8AX051/D02/b:`0e?3D09bhW01PO600R
:B8201HO700_01DN6`0D7AX051dJ01<L6@0K924051dJ02@]:P14CDX0>44n01@O6`0C7QX05b<O01PT
800G8al062@P01TU8@0K9b<09S8^01PT800L:2@08RhZ01LT7@0E81T0:3<]02D`:P0iAD<0/Kfm04aH
F00S<C406b/X01`]9`0X>C80834W020a:@0O;R`08c<b02Ph=`0P<300:3Xk02`n?`0U=cT09cXm02Lk
?@0W>Sh0:3e002Xo@P0]@4@00P0[?T80400/?d<0;D1402m2AP0_@TH0<4=703U<D00aA4P0;3m303I:
C`0fBe00=daA03E:C`0cB4d0=4U>03I;D00gC54203Y?E00e03I;D00cB4d0<TM<03=7C@0dB4h0>TiE
03mCF`10E5d0?E5I03]?EP0lDEH0@5EG045GE00mDe00?55?03mCDP0oDe40?U==04=HD@10ED`0>Di5
03mDB`0kD4T0=DY503mCD@0lD4l0?51>03M;B@15FET0SJ2S08bOY01OLWL0CF1U03a?DP12EUD0BEiI
04QMEP14FU00?U9804]OE@1PM6X0C61F04QLDP14F4h0B5aB04eQE`17Fe40BEeC04EIC`11ED/0@EM;
03mGBP18GeD00P1?IU`00`1BJF40DfYR05A[H`0205E/IP0@05U`J`1LMG40EVm/059]J@1AK6L0DfiW
05A_I`1BKV<0DFeR051[H`1EL6T0D6]V069mN@1PNWH0DVUQ04mVG080CVEK0180Bf9H04QOE@1;HUP0
Bf9H04YQE`1]Q7X0BF1F04QPD`13Fdh0@UY=04IND@0mEDP0?EE903M>A015G580AEaC04IME@17GUH2
04UPF00404QNF`1:HE/0BF1J04MNF080AEaD03d0A5]C04AKD@12FDl0?eI<03iFB@0oEdX0BVAK03A>
A@0fD4L0?UE=03aCB`0oETh0>Di703M;A00jCTL0=TU302`o>@0[?SP0:STd02/j=@0Z>C@09cHa02Dd
;`0V=C009cHa02Xi=00U=2l093<^02Lf<@0V=C0093<]028a;@0Q<2d08S0`02Ha<`0Y<cD0:cDg02/e
=P0U;Rd082TV028[:00T;RL08B/S01lX8`0P:R@08B`V020[9`0O:RH06bLS01/Z9`0M;2T062LT01TW
9`0L9bD08bTW028X9P0/<S00728P02D[:@0S:BL082HT00807R@R0P0O9B<01P0P9B@06alQ01XN800O
8bD08RHX01TM7`8061`N00D06AdO01PL7P0<41806QhP01TK6P0501TK600701LI5P0J71T061XG01DG
500H6QL05aTF028S7P02034b;@0A02PY900G61<05AHA01LH4`0E5Q4051D@01HG4P0G61<05QPC018E
3P0A5Ph051L?01DH4@0D5a005aPB01hO6P0H61@00P0C4Ph05@0D4Ph0510=00l>2P0C4Ph04Q4=01/J
5P0D4`l04a8>01HE4@0e=30051<?01/J5P0?3PX05QDA01XI5`0=30/02PT701DD4P0D4a405aHD01<B
4002014@3P05018A3`0A40h03Pd;014?400C4A800P0E4a@02P0C4A804@l@00l=3P0@3Pl04Q0A01DC
500C4A804Q0A01<A4P091`P200`:2`0401XH6@0@3Pl03@/<00d;30803P`=0P0?3@h0100C3`h03`/:
00l;2P0A3@`5018>3@804@d<00h040`9020O6@0P81P0<S8V0;FfY`3oonh0k>gK08j?P@0H61005aHB
010=4P0;214030P>00d920802`L600T05A4@02`X9`0Y9B@04Ph=01<?3P0A3@`03`/:010<2`0@30`0
1@0>2P/01`0:1PL05Q8C00h:2`0>2P/00`0000l;300=2@X01@0>2P/200l;300500h:2`0=2@X030P9
00d92P0?2``00P0<20T02P0=2@X02PH700`82@0>2P/0510A00h:2`0@30d03`/<00`82@0B2@`20148
2`0301<:3@0D2`h04PT<00804PT<00l040L:00l62@0?1PT040L:00h82P0?2@/040X<00d72@0<1PP0
3PP:00P2100@2P`07aTK01/E5`0@2P`0200=1`T04@0;1@L04P`>01@>400A30d0JVAX0<W4bP0F4AL0
4PdD00h9400<1Pd04``C00l53@0>10`03P@=01863`0D21404PL@01Cooooo000Kooooo`8041@E00d0
3Q8C00010P0;3a005ATJ00hB4`072``041@E01LK70052@X04QHE01<E500G6AH07R0M008051HC00@0
1`T601<E4P0<3P/0418?0P0B51400`0:30T03a4@00`>3@0200/=300300d?3P0>40l04A<B00803a4@
00d04Q@C014C4P0?4A003a4>01PJ5`0C5A8030h;00lA3P0C5A802`d:00840@0K7AX0418?00805ALD
00h06Q`G01@F4@0C5A002`d8018D3`0?4@`05ALB01<E400@4Pd03@l:010B3@0D5A003@h900h?2P80
30d800D04A8=00l@2`0C50l051D@018C3P0200h?2P0>01HG4`19BdP09RPU00d?300C5A802@/800d?
300?4@h03Q0=00d?300>40d03a4>00h@300?4@`2010B3@803Q0;00@03a4<00d?2P0@4Pd051HA0P0@
4Pd0400A4`h03a4<00`>2@0>40/04Q@?010B3@0:30L02`d800lA300C5A006A/F028T7`0:2`H06AXE
01<D3`0?40/2018C3P04010A300F5a805AHA010A30804Q<>0180418A00/=300>40l04aDD014C4P0C
5A@02@/:00X<2`0H6QT030h=00H81`0F61L030h;014C400E5a@03a4>00d?300B514200lA3P803Q0=
00<03@l<00`>2`0>40d0100?4@h06P0>40d03a4>01DG500J71T09bTV014C400N81d03Q0;018D3`0A
4`h0418=00lA300>40/03a4<018D3`0H6QD05ALB00h@2`0A4`h03@l:018D3`0?4@`02`d800`>2@0=
3`X04A<>1P0@4Pd0900?4@`06A/F00lA300;3@P06A/F00`>2@0=3`X04aD@00lA30031@002`d800hA
2P0<3`P04QD>01HI4P0D5a005APA020S700C5Pl06A`E00hA2P0I71D01`X3018E3P0=40T03Q4:010C
300?4P/03Q4:00/>1`0=40T03a8;00T<1@0:3@H04aH?01@G40<041<<020030l8010C300=40T0:bhW
08jARP072P<00`H0028U7P0V:B8051L@014D3@0<3`P071lH014D3@0B5@h03a8;018E3P0>4@X02`h7
00lB200A50T04A@;014D300A4`h04A<@01LI5P0F61<0418=014D300E60l04QD:01@G3P804A@=0180
4aH?010C300>4@X04A@=00lB2`0@4``05APA01HI4P0@4``05aTD01dO6P0I6aH05QPC00X<1`0I71D0
4QD<01@G3P0F6A0201@G300:01HI3P0C61404aPA024V7`0?50d06b0I01DJ4`0Z;bP05a`E01hS7080
3Q<<00P041D>01LL5P0B5a4041D?01lT7P0K81X04QLA01<H4P@051TC00<04QLA01TP6@0F7AH00P0C
6Q<02@0F7AH06B0I01PO600X;bP0=chg01hU7P0I81T061lH01@M6P0201<L6@0X01@M6P0H8Ah06b@Q
01DN6`0J8b004AXG01<L6@0E7Q/08RdY01<N6P0F8Qh06BDQ01PT800E8Ad0520L01hZ9P0H92006BDQ
01XV8P0G8al06BHO01`W800E81X08bhX01hZ:00]>CT07b/[01`Z:P0L;2T06R/U024b:`0O<2H09cP`
02<b<00R<S409CDd02Hf=P0V>3P05BLW02Li>`809c/l00<0:3/o02Tn@@0Y?T400P0Z?D40BP0[?T80
;T550395B@0]@4@0<TE90313A`0cATX0>4]?02i1A@0_@dP0<dQ=03I;D00hCE80>DiC03]@E@0oE5T0
?55F03I;D00bAd`0<dQ=03E:C`0aATX0;dA703A9C00jCe@0>TiE03I:D`0gBe<0>TiE03iBF@14FEd0
A5UJ045GE@16FeX0?E5@03U=B`14FED0IGYc03eBB@0fBd80>4e403Q=A`0jCT`0?e=A03I:B@0iCTT0
@eQC03eAC`0oDe80?U9C03Y>C`1:GUl0AEUH04MKF010EDh0AEYA04AJCP0jCTD0?51704UME01;GeH0
EVYQ04YNE@15FE00BUiE04AHC`1:GUD0BEeD04YNE@17GE40A5a?04UPEP1>IE/0CFAJ0P1AJ600501E
K6@0FG1Z05U`JP1TNgH0LXR505YcL01AK6P0Eg9]05MbJ`1AK680Eg=W05=_H`1AK680FGA]05IaK01G
LFd0Hgah05=ZHP1@Ied0CVEK0P1?IU`08P1=I5X0BV5G05=ZH01DJf40TJRN04eTFP19HE@0D6QK04EM
D014G4l0?UI903iFBP0eC480@EQ>04=JD@15G5@0AeiF04QOE`19H5P0B5iK04MNF016GEL0AEaF04MN
EP18GeL0A5]C04AKD@12FDl0?EA:03aDA`0mEDP0A5iE02e7?P0_BD0303]BBP0<03E:@`0hBdD0?E1:
03Q;A@0/?cT0:c`f020_:P0M;2L07RdX02<b;@0V=C009cHa0P0X=c805`0T<bh09C@_02He<00T<bh0
93</02Lf;`0O;RX08c8_02@`<00S;Rl0:S@e02Tc<P0T;RX082TT024Z9@0R;2@082XR01hW8P0O:B@0
82/U01lZ9P0L9b<06RHR00806bXW00X05bHS01d[:`0[=S@04ALE02`b<02GWI/07B<Q01DK6@0R:2H0
7R@R0P0M8b40400O9B<08BLU024V9P0I7Ah061`M01lS900K7b005QXK01DI6P0I7Ah05ATJ01hR8`0<
414061`L01LI600H6QL201/M6P0=01XL6@0H6QL05QPE01DG500F61D06A/H01/M6P0E5a@05aPC02@U
800J6aH04A8=00h?2P0201XK5P0T01PI500E5Q405AHA01DF4@0B50l05QTB00lD3@0B5@h051L@00lB
2`0B4`d0414<00l?2`0@3`/04a8>01DC3`0E4@h02PT501DD400?3PX06APD01XI5@0A40`04Q4=01/J
5P0510005QDA01<B3P0>3@T02@P602LV900B4@l0;bh/08n>S0040`404Q4?0P0A40h01@0C4Q004Q4?
00l>300A3a004Q0A00804a4B01D04Q0A014?400A3a0040h?014?400D4Q<04a4B018@4@091`P01`D6
02LU9P0Q7b00JfUZ03<a<P0E4a@05aDF01@B4`0>30d03@/<00l=3P0C3`h00P0@30/201<?3PH04Ph=
01T04Ph;01<B3P0M7AD0>SX`0;>dY@3ooo40m_OW07AdI`0>3PH04Q4=00T72`0A3QL03PX>00h:2@0A
3@`03@T800H20@070`803@T8014=300D40l04`l>010<2`0?2`X03`/;00H03PX;00D04@d>00H20`0D
41401`<4018>3`0600h:2`803`/<0P0>2P/01@0?2``040`=014=3P0=2@X030P900803PX;00D03@T:
00P41@0:1PL02@D6014=3P0200`82@06010:300@1`X03PD801072P0A20/03`H90P0@1`X03`0?1PT0
3PD800h5200>1@P03PP:00l92`0@2P`03@L900`6200>20X030H800l92`0H4Q@050h@00`6200700h8
2P0?00P2100C3@l03`T;00l92`0:10H09AlQ02TT:P0F4AL01`8800P32@0=20h0100401<94@0@1Ph0
50XB00806a0H00<05@XBooooooooool04_ooool001_ooooo00T01@T:01TM7P0K7b00310A00lC500:
3Pl04QHG00T=3P011@H00P0>4Q<01P0<40l030h=01HH5@0E5a@06Q`I010B3`805ALD00D05aTF018D
4@0C5A803a4>00T;2003010B4@0400lA400>40l03@l>014C4P803a4@00l04A<B010B4@0?4A004A<@
01<E4P0>40d030h;00/=2P072@H03Q0=04=5@P25Qh@05QPE00h@3@0I6aP00P0A4`h02P0>40/03@l:
01DG4P0<3PT05QPC01<E400@4Pd03Q0;010B3@0F5a8200l@2`0300h?2P0A4Pd05AHA00803a0;00L0
4A8=010A300>3`X03Pl:00d?2`0_<Bh04A<@00803@l<00<01PP5018D4@0>40d00`0=3``01P0>40d0
3@l;00d?2P0?4@`03Q0;00`>2@803@l:00/02`d800`>2@0@4Pd03a4<01<E400F61<03a4<00/=200D
5Q406adH01@F4@02010B3@0700lA300>40/03a4<01DG4P092PD05AHA018C3P02010A300?01LH4`0<
3@P051D@014B3@0=3PT05QLB00`=200A4a803a4@014C4P0@4Q403@l>010B4@0C5A@020X900803Q0?
00P03a4@00`>3@0;3@X03a4>014C400=3``0418?01LI5P803a4>0P0>40d00`0=3``030h;010B3`04
00lA3P0<010B3`072@H051HC03Pj=`2JW9T0?d4n00lA3P0A4`h04Q@?01<E400@4Pd03@l:0P0@4Pd0
2`0>40/04aD@01<E400?4@`04Q@?00P:1@0J71L03a4<00`>2@0F61<03@l:00H0418=00<04Q@?01<E
400C5A000P0>40/00`0C5A0030h900lA300201<E400B01HH4`0X:RD04aH?00lB2`0A50d03a8;00`?
200?4P/09bXS01HI4P0I71D030l801LJ4`072P<03A09018E3P0A50d03Q4:0P0<3`P00`0@4``04A@=
01@G400200lB2`0301PK500G6Q<041<<00803A090P0;3PL05`0S9Ql041<<024T7@0@4``082<L00lB
2`0G6Q<010L001HI4P082`@06A`E01HI4P0E61405aXC01PK500?4P/03Q4:014D2P0A50T04A@;014D
300A50d04A<>008061XE01H04A<>01<F3P0G6Q404aH;014D2`0@4``04aH?014D3@0>4@X06QdF01PK
500C5Pl04A@=01LJ4`0J7AH05APA018D3`0>40/04A<>01`N6@0B50l02Pd60`0C5Pd05`0A50T04QD:
01LJ3`0A5Pl041D>01XO60083@H05AXC01<H4@0?50d04AH?01DJ4`0<4@X0:RlX01@I4P0K81X06AhH
00X?2@0;40X0314;01XO6@0C618051TC00<05AXD00<051TC01HM5P0F7AH0100F7AH01P0E71D04QTB
01/R6`0?5Pl05A`E00`C30804a`I02`051dJ01HO700K92407RLT01<L6@0E7Q/051dJ01hW900M9R<0
7BPT01PS7`0I9B4072PT01dY9@0I9B405b<O01dY9@0hA4007b/W020/:00T<2`06RLP01DP6@0M:280
5b8L02Hb<00H92@09C4a01l];@0J:RL072dW02Tj<`0Q<RP08S<[028a;`0S<c80=TI502`l>`0V>3P0
8S@d02Pj>P0W>c`0:3`m02Xn?`80:Ci100h0:ci202Xm@@0[?T80;T550354B00dAd/0;T5502`o@`0b
ADT0=4M;03=6BP0cAd`0=DY?03Q=DP80>TmD02h0?55F03mDF@0kD5D0=DY?03=8C@0fBe00=daA03A9
B`0dBTP0>Tm@03iCE`0lDEH0>DeD03U=E@0lD5L0@5AK04EJG`16Feh0@UMJ03iBDP0lD4l0AEUG03eB
CP1<HEX0<DHm03Y?AP0aASd0>Tm904AHEP0lD4h0?51?03M<A`0nDd`0>Di:03I:B00kCdh0?e=A049F
E011EU40@eQB03]@A`13FDd0AeeA049FC@0nDTT0CV9I0P1<H5L0:P1=HEP0E6QO05M[HP1=HEP0CV9I
04]OEP1:GUD0Bf5E04QPD`1=I5X0DFQN051WG@1DJf<0CfIN05=ZHP1FKFL0EFaV05ieL01[PGh0FG9_
05=/J@1ILVh0F75[055[H@1GLFH0CVQM04mYG`1HLF/0FgA`05M`K01VOg/0E6]S055XGP1?IU`0D6MM
055XGP1@Ied0EFaR04mVG012FDl0IGab04YQE`80AemB00T0A5a>04IND@0nETT0@5Q<03]BB013FU00
AUeD04UPF01:HET00P1;HUX02P1;HEh0@5MA03iEC`14FeD0B5mG04MNEP14Fe<0A5]A049IC`0mE4X2
03aDA`0D03]BBP0eC4@0=di603]BBP0iCTL0>4e603E:@`0hBdD0?E1:03M:A00/?CL0:3Tc02Dd;`0Q
<2/08S4/02Th<`0_?ST0<3lj02`k=P0[>SD202Lf<@0E02Dd;`0P;bP093@Z02Lf;`0O;RP08S4^028^
;00Q;2/09c4`02H`;`0T;R/08R/V02<]9@0Q:b<07RPP01dV8@0N:2<07bXT01dX900L9b<072PT0080
7B`Y01<06BPU01l];@0R;2/0;S@b02<Y9`0Z<2h06AlM03Dk>@0G7A/0728P01/Q7`0L8R007R@R020V
900T:BT07R8S01`P8@0Q9BH05a/L00806alP00L04aLH014E5P0L82404ADF01dQ8@0G6AP061XG0080
6adJ00D06Q`I01PJ5`0H6QL05ALD01LI5P0201/M6P0:01HH5@0;30L05aPC01DF4@0H6A@051D@01LH
4`0J6aH05aPC01DF4@8051D@01T04Q<>01LI500@5@l04Q@?01HH4`0E5a804a@?01LH4`0E5A0051<?
01DD400D4Ph04@d:03hm>@0[:RH02@P4010?2`0I61@05QDA00l>2P0B4@d020L300`;1`0G5Q803Pd9
00802`X800X061LE01XI5`0_;R`051<A014@3P0@3`d04A0>01<B400B4@l03`h<0P0@3Pl2014?4080
40h?01<0518C014?400@3Pl04@l@010>3`0>30d0518C004000050`@02PP901`J6`030@805A<D01LE
5P0D4Q<03P`=00d;300?3@h04`l>00804@d<0P0C3`h00`0A3@`04Ph=018>3@03018>3@0I018>2`0N
7AT04A4900`<0P0m?S40LG9T07EfJ00^;R803@d501<B3P0:20/04PlH00h:3P0?2`X03PX900`81`0A
3@`061@C01DA400@30/04Ph=014=300>2PT03@T800h:2P0500h:2`06010<3@060P<00`00018>3`0?
2``02@D61P0>2P/500l;300?010<3@0?2``030P900/7200<20T03PX;00l;30030000@Cdn034];P03
00003@T:018>3`0B30h040X<00803@L900<03PP:00d72@0>20X00P0>20X02P0=1`T030H800`6200>
20X03`T;010:300=1`T030H800h82P0A2`d200/51`0300h82P0=1`T040X<00H03PP:01803`T;018<
3P0400001P02014;3@0<1PP0100501<>500R7B<00`0400d73P0F3aH040H>00`22P0?1@d05@XB01@9
4@0=0PXDooooo`006oooool0100<41405a/L00X>3`0;3a0200hB4`0C00H:2`0B5QL0310A00hB4`0;
3a003a<D00/=300@4Q003@l=00lA3`0E5aD071hL018D4P0N81h051HD00h@3P082PP04aDC00h@3`02
00d?3P0400h@3`0?4A003a4@014C4P803a4@01D0418A00lA400=3`h03Q0=00T;200;3@X0828O01lQ
7P0>40d04aDB03Tk>01bM74061XG00h@3@0?4@h03Q0;024S7P0<3PT051HA00`>2@0:30L00P0A4`h0
2`0?4@`03@l:00d?2P0>40/03Pl:01LH4`0D5A003@h9018C3P0?40/0414<00804A8=00X0414<014B
3@0<3PX04Q@A00X<2@0B514020X700lA3P0A4a003Q0=0`0=3``00`0>40d03@l;00h@2`0200lA3080
3@l:00l03a4<00h@2`0=3`X03a4<00/=200>40/04aD@018D3`0?4@`051HA01XL5`0F61<03@l:00h@
2`0?4@`00P0=3`X05P0@4Pd0;BhY00d>2@0?40/06AXE00d>2@0B4`h0414<01DF4@0?40/020T401DF
4@0A4Pd04aDD01DG5P0A4a804Q@C01PJ6@0=3`h0418A01<E500Q8b8200d?3P0301LI600=3``03Q0=
00803a4>00@04Q@A01HH5@0@4Pl04A<@0P0@4Pl0100A4a00418?014C400@4Pl200lA3P0F010B3`0A
4a003a4>01<E4P0F61D0EUQE02DW900C5A804A<>018D3`0A4`h03a4<00h@2`0@4Pd03Q0;018D3`0<
3PT02@/600lA300B50l03a4<018D3`802`d800H04Q@?00d?2P0?4@`0418=014C3P0B50l3010B3@03
014C3P0>40/03Q0;00804A<>028051HA00lA300B50l071hI02PZ9@0l?ST04QD>010C300C5Pl04A@=
00lB2`0B5@h04aH?00hA2P0D5a004A@=018E3P0<3`P041<<01HI4P0C5Pl041<<00lB2`0=40T041<<
01<F3`0J7AH05APA014D3@0D5a004QD>00hA2P0@4``04aH?0P0B5@h02@0A50d01`X501<F3`0?4P/0
51L@00`?200@4``05aXC01DH4@02018E3P0W01@G400B5@h04A@=010C300=40T04aH?01HI4@0@4`T0
41<:014D300A50d04A@>01DG4@0F618051L@01@G3`0E60l051L=01LJ4`0B5@h04aH?014D3@0@4``0
9RTR01@G400B5@h04A@=01HI4P0G6Q<04aH?01TK5P0<3PT04aD@02la;00e=c805QTB014D2`0C5Pd0
5AP?008051L<00<05QT>018G400B5a000`0C61403P0D6A805AXC01dR6`0E6Q<03A8;04Y?B00g?3D0
6b0J010E3`0I7QP0=c`f02hc;@0?50h05AXD0P0G71H201PM5`0301LL5P0E71D061lH00806R4J00P0
61lH01DL5@0E71D051/D010G400F7AH07B@M01HM5PH05QlL03`06B8O01/T8@0D7AX06B8O01PQ7P0P
:bL07RTU01`X900N:RH08BdY020/:00N:RH05b<O020/:00e@Cd0?4Q401dY9@0K:2407BPQ02<^:00N
:B<07BTW01dY:@0S;bl0:SPh01d]:P0I:R@093D^024b:00V=bl0:3Ld02De<`12DU009cLf024c<P0_
@D00:cdm02Lk>`0X?3`0;41102Xo@@0X?Cl0<4=702`o@`0[?T80:Se102/n@P0_@TH0;T5503=6BP0n
DED0>4]?03A7B`0fBTl0>e1E03iCF00mDUL0>TmD03U>D`0jCe@203M<D@0U03]@E@0lDEH0=T]@0357
A`0fC4T0>U1=03aBD`0jCe@0>dmF03mCF`13Ef00@eMO04IJH@15FEl0@UIL041EE`0oDe80>Ti=03Y>
B`0oE4l0?55:03aAB@0nDd`0?E9=03iBD00dB4L0B5aK03iCC@0jCdL0?E9;03Y?B@0mDT`0@EI@04AI
D`10EDd0B5eD049HC002049HB`0D04]PE`10EDd0B5aD04aQF@1AIUh0B5eE04YOE`1@IEd0C61H059W
G`1CIel0E6UP051XF`1>IUT0DfYP05I]H`1CJV00E6]S05I]I@1HKfL205YaJ`0R05]aK@1MLg00EVm/
05YcK`1ILV`0Eg5X05A^I01EKf<0EW1T05UcJ@1FL6L0GWMa059[IP1HLF`0F6mW05A[H@1AJ5h0DVUO
05=ZH01BJEl0CfIL04iUF`1:HEL0D6MM04UPEP0kDdH0@5Q;049JC@1:HUD0AEe@04aSF01<HeT0B5mE
04]RF@<0CVEM00h0C6=K04aRG`11F580@5MA04ELEP16GED0AEaD049ID@13FU00@EQ>03eDBP0mEDP0
?UI903aCB@80?eI=00@0?59:03U>AP0gC4@0?5590P0iBd@01@0bA3d09SL`02<d;@0T<bh0:STd0080
;C`g03L0;Sdh02ln>@0_?ST0<D0k02ln>@0^?CP0:3Lb020_:00M;B807RhT020_:@0R<B`09C4_02D`
;P0S;B`08bhZ028/:00Q:b<082XQ01hX800M9al07BHQ01lY8`0O:R@07BPT01dY9@0N:RH07B`Y01l^
:`0K:RL072XZ01dX9P0S:BL06b4O01dS8@0K8Al09R`Z01`R800J81h0728P01lU8`0P9R@08BLU02DZ
:@0F6QX03a<C01hR8P0K7al09BTY01lS8`0C5aL06AdM010D500X;2`05ATH00H06A/H03<06Q`I01HH
5@0H6QL06A/H01DG500G6AH071dH01dN6@0K71L07b0K010A300G61<05QLB01@E400C50l05AHA01HG
4P0E5a803a4=01HK5P0E5a<03@l;018D400C4a004Q<>014A300A40`04a8>01DC3`0E4@h0<c8^02@S
7`0C4Ph06QTE018A3@0<2`L05aHB014@300o?SX06QTE018A3@0G5Q8040l=038a;`0G5QD05aHD00h=
300C4Q004A0>010?3@0A40h00P0C4Q000`0@3`d040h?010>3`0200l=3P8040h?00`04a4B010>3`0=
2``03`d>00d;300<2P/03P`=00/92P0C4A803@/<01XI6@071@H200d;30803P`=0P0?3@h01P0B3Pd0
40`;014=300C3`h04Ph=010<2`<04@d<0`0B3Pd0600>30P05A<>01<A2P0D4`P08R4E02TY700E4`X0
518=00l<2@0B3a402`L>00`8300A3@`04Ph=010<2`0A3@`03PX900d9200?2`X040`;00h:2@0<20L0
3@T800h:2PD03PX;00L040`=00l;3018A4D05Q8C01DA4P091@H03`/<00D03PX;0P0@30d08@0?2``0
3PX;00h:2`0>2P/03@T:00l;300>2P/020@500X61`0=2@X040`=02hZ:`0R7Ql02`L800h:2`0=2@X0
5a4C01@>400@2P`03`T;010:300?2@/03PP:00l92`0@2P`03`T;00h82P0=1`T03PP:00l92`0@2P`0
3@L900`6200200h82P0400X41P0<1PP04P`>010:30L03@L90P0;1@L0400B30h03`T;00`6200=1`T0
4PdA01dH7@2^ZJh0EU5F00/62`0<1`/040H=00h52`0>10/040D<01463@0>0`XDooooo`006oooool0
7`0=4A804aLH00`@4@0>4Q<03a<D00hB4`0@51D02`l@00lC500E6AX02@d>01HJ6`0;3@`01`T801LI
60082PT0<C<b010B4@0B51<03@l>00T;2P0H6QT020X900d?3P0@4Q403@l>00`>3@0@4Q4061XI01/M
700@4Q400P0=3`h05P0>40l03@l>00/=300>40d06A/H014C400>40d04A<@00`>2`0;3@X051HC00`>
2`0:30T030h;010B3`0B50l0HVAO00lA300=3`X04A<>00h@2`0@4Pd2018D3`09010B3@0?4@`0414<
01lP6`0e=S409RLR00X;1P0>3`X0414<00804A8=00X03a0;00h?2P0@4@`04A8>014C400J71T06adJ
00d?300M7a`02`d:0P0=3``01`0<3P/03@l<00d?300>40`03a4<014C3P0@4Pd00`0>40/0100=3`X0
418=01<E400=3`X200`>2@80418=024020X500T;1P0>40/02@/600/=200=3`X030h900/=200<3PT0
3a0;00<4000G61D04a@?01HG4P0B4`h01PL2010A300E5Q402@X5010A300?40/0418A01<E500=3`h0
7R0O03@f=@0K7A`03a4@00d?3P0I6aX03Q0?01@F5@0E5aH00P0>40d01P0@4Pl04aDB018D4@0=3``0
30h;00d?30803Q0=0P0?4@h0;P0B5140418?00h@3@0>40d0418?018D4@0D5Q<05QPE018D4@000@00
6A/H00`>2`0>40/03@l:00T;1P0>40/04aD@00`>2@051`8092HQ028T7`0F61<05ALB00h@2`0Z;2L0
3a4<01<E400D5Q4030h901dO6P0>40/0418=014C3P0B50l04A<>010B3@0F61<04A<>01@F4@0@4Pd0
3Q0;01DG4P0C5A0030h901<E400F61<200@60@07014D3@0=40T04aH?01@G400:3@H01`X301@G4002
00lB2`0601<F3`0>4@X05aXC01@G400@4``02`h70P0A50d01`0:3@H04A@=00X=1P0=40T03Q4:010C
300C5Pl00P0?4P/04P0D5a005aXC01@G400B5@h03Q4:01@G400F6A804QD>00L:0`0G6Q<03a8;03Dh
<@0[;RL00`H0028U7P1>DDX05QTB014D3@805APA00D04aH?018E3@0?4PT03a89010C2`02014D3@0:
010C300A50d04aH?01<F3P0A50/04aH=01@G400?4P/05APA01HI4P8030l801L04A@=018E3P0G6Q<0
6ahG01TL5@0C5Pl030h9018D3`0K7AP04Q@?01HH4`0?4P/030l6018E300K7QD071lD01TL4@0E60d0
41D>01@I4P0?50d092TR01@I4P0201<H4@09014F3`0oA3d092TR014F3`0E6Q<04aPB01@I4`0@5@l0
6QlI00805a`F00<05Q/E01PM5`0I7QP00`0I7QP03@0C6Q<051/D01DL5@0E71D051/D01<J4`0530D0
6b8K01<J4`0L8a`05ahG01`S700C71T00P0E7Q/0<@0D7AX04AXG00lH5@0G81d072DR01TR7`0O:2D0
72DR01lZ9P0I92005B4M01HR7P0L:2@07BTU01/W8`0Q;BT06RHR024]:@0L:2@05b<O01dZ8`0L9b00
8RdW00lJ500Z=S@07b/[028^;P0P;Rh093@a020a:`0S=2d0:c`b03a=A@0c@Sh09SHc02Ti=P11DE00
D6=Q02`o?@0[?Cd09c/j02Tm?00]@D80:Sm002Pm?P0]@4@0:Se102Tl@00Z?D400P0[?T80;00hBdl0
=TU=03A7B`0jCE40=DQ<03U=D@0jCe@0?U=H03mDF@0mDUL0?55F03iCF00kD5D0=T]@03M<D@0iCU<0
=T]@03E;B`0kDT`0?UAA03iCD`0mDUD0@5AK04MKH`17Ff@0AUYS04EIH@13Eeh0@5AK03a@E@14F5T0
?U9A03Y>C00/@C`0Bf1K03Y?B014FE80?U=?045EE01BIVD0Oi>C049GDP0gC4<0?U=:0P0fBd801015
FU00AU]B03U?@`0oEDT203mEB00:04MMC`1?I5/0IW]d06UnM`0oE4d0@eQA04QMEP1;H5T0DFIO04mT
G@80F6eV01/0FFiV05A[H@1CJeh0EfiT05Q_I@1BJEl0CfIN05A[H`1EK6@0Fg9/065hLP1OMG40FW1]
05E^JP1PNG@0FG=Z05I`I`1ILfL0E6iQ04iXF`1FL6@0CVQO05efL01EKVT0E6eW05]bJP1FKF<00P1B
JEl0401CJV00DVUO059YG`1;HUP0AUeC055XGP16GE<0BF5D04mWFP18H580B61C04=KCP18Ge@0@eY@
04IMD`19H5L204]RFP0H04UPF017GUH0BV1M04]RG019H5X0AEaF04=JDP14Fe<0@5M?045HCP10Edd0
?UE;03eEB00oEdX0?EA:03]BB00hCdD0>e1703eBB@0lDDP0>Ti503E6?P0dACd0;d0h0P0X>C40D00Q
<2/0:CPc02Xi=00/>cH0=4<n03]:A@0^?CP0<d8m03A3?P0eA3l0;3/f02<b:`0J:R0062PN024`:P0O
;RT08bl]02Lb<@0Q:bX07bXV01hX900L9Qh0628J01/U700N:2007RLR020Z9@0P:bD07RTU01/W8`0H
920062LT020_;00O;R/07B/[01`W9@0R:2H09B/Y024W9@0R:2H03aDC01PN700I7ad07R@R028X9P0S
:BL08RPV04M<B`0o@d806QhM01PL6`0B5QD06QhM01dQ800=4A0061`K01`P7`1ZKVd0720O01/M6P0J
71T061XG01LI5P0H6QL06adJ01TK600F61D05aTF01<E4P0>40d05ALD00l@2`0I6QD0=CHa03dn>@0I
6QD05QLB01TJ5@0G61<051D@0P0C50l08P0A4`l06A/J02lc<P0[;B/030h;010B3`0F5Q@08B4O01`L
600F5A405A@@01@B3P0B3P/05QDA014@300B4@d061LC00`;1`0D4`l02PT501@C3`1CDTh03`h:01<B
3P0G5Q8030/900d<2P0K6QP03@`:010?3@0C4Q0040l=00l>300A40h201<B4003010?3@0B41404@l@
008040h?00H04@l@018@4@0?3@h030X;00X82@0=2``200h<3@0B00/92P0A3a004@l@018@4@0<2P/0
5Q@E018@4@0=2``03P`=014?400>30d02`T:010<2`0?2`X040`;018>3@0@30/03PX90P0?2`X0400@
30/04@d<014=300A3@`03`/8018?2P0F4`h05A8:01DB2@0K60l040d501@A30091@8040`=00L21P0F
4Q@200l;2P0:00h:2@0C3`h03`/:00/71P0@30/03`/:00`81`0;1`H03@T800l;2`D03PX;00L03@T:
024M7P2VXZ<061@E00d92P0@30d030P900D03PX;0P0@30d01`0?2``03PX;00`82@0<20T03PX;01XF
5`0H51D00P091@H02`0?2``00`0001DA4P0>2P/02PH7018>3`0?2``05Q0B01<=3`0>20X030H80080
3@L90P0?2@/2014;3@0700l92`0>20X03PP:00l92`0@2P`03@L900`6200200h82P0400d72@0?2@/0
3@L900P210L030H800H03`T;00`6200>20X03@L901PB500>20X200/62P0:01TD600<1`/03@L;00d7
2`0>1@X03`H;00h52P0>0`T040D;01@93aCooooo000Kooooo`04010D5@0?4a@03A4B00dA4P803Q8C
01802Ph?03Lk?00F6Q/07B4R00hB4`0?4a@05ALF018D4`0E5aH0004003/m?00A4a8030h=010B4@0?
4A002P`;00/=300>40l200lA400500h@3`0@4Q403@l>00P:2@0=3`h00P0@4Q402`0H6QT0;Bl^03Tk
>P0?4@h0418?01XL6@0@4Pl030h;01@F4`0B514061XG00803a4>01X04aDB00h@3@0@4Pd03Q0;010B
3@0C5A00418=00`>2@0A4`h030h900d?2P0B50l04A<>00`>2@0N7aX0Q8F004Q9A00E5Q402@X5014B
3@0B4`h0414<00l@2`0@4@`04Q<>01<E4@804aDB00/03a4>00/=2P0;3@X0418?014C400>40d030h;
00d?300@4Pl0418>00d?2P0200/=200500`>2@0?4@`0418=00lA300>40/00P0=3`X0100>40/03@l:
00`>2@0?4@`2010B3@L03Q0;100>3`X0700?40/04A8=01@E400A4Pd03a0;018C3P0C50l04A8=00L9
200H6QT04A<B00`>3@2SYJ@08R@S00d?3P0I6aX02`d<00d?3P0F61L05ALF01HH5@082PL0418?00h@
3@0D5Q<0418?014C400@4Pl400h@3@<0418?00H03a4>00h@3@0=3``03@l<014C400@4Pl200/=2P03
010B3`0A4`h03Q0;0080418=02403Q0;014C3P082PD03Q0;01HH4`0?4@`09BLR01TK5P0H6QD04Q@?
00d?2P0;3@P05QPC02/]:00<3PT02`d800d?2P0@4Pd01`T400h@2`0@4Pd030h900/=200B50l05aTD
00D70P0?4@`030h900d?2P0@4Pd04A<>010B3@0<3`P00P0C5Pl0<P0?4P/04A@=01@G400A50d041<<
014D3@0C5Pl04A@=00lB2`0A50d03Q4:01DH4@0:3@H03a8;01HI4P0@4``03A0900hA2P0A50d04QD>
01HI4P0/;bP06ahG010C300A50d01@P1018E3P0?4P/03Q4:01<F3`0E61404QD>028U7P0F6A8020/4
01HI4P0<3`P04QD>01hQ6P0B5@h03Q4:00d@2@0?4P/041<<00lB2`0=40T03Q4:010C2`0B5@`04aH=
0P0A50/04P0D5`h051L?01TL5@0W:R<04aH?00hA2P0C5Pl03Q4:014D3@0F6A8051L@01LJ4`0J7AH0
61/D01LJ4`0J7AH03Q0;01<E40804Q@?00X06A/F01DH4@0;3PD03a8901DH3`0G6Pl05QT>01PK400?
50d051TB0P0C61403@0I7QL051TB01/P6@083@H0F5eF018G400E6Q<06b0I014F400C61804AH@010E
3`0B5a400P0A5Q009@0F6aD010T306]`JP0I7QP05a`F01LN5`0C6Q<06R4J02<Z8`0b>C805QdF01TP
6@0H7aP05ahG01HM5P0G7QL061lH01<L6@0F7a`04a`I01LP7@0A6QL05b0M02@]:P1ZLg007bPU02L`
;@0J8b007BPT01/V8P0H92005R8N01PT800K9b<07BTU020/:00M:BD00P0L:2@01P0M:BD07BXS01hY
8P0Z=Bl062<M028^;08082`/01L09S@d01h^:`0G:280:CXc03E6?00mCTH0Df9M0310?@0W=c@0<T8o
03=6A00]@3h0:chl02i2@@0/@3l0:3`k02Lm>`0Y?Sl0:ci20313A`0_@TH0<4=702`o@`0202e0A005
03U<D01@HfL0?U5E03U<D011EEX00P0oE5T06P0nDeP0>e1E03Y?E00kD5D0?E9G03]@E@0dBDh0<DI;
03I;D00iCTh0?5==041FD`0oE5@0?E9E049FG@13Eel0BUiW04EIHP1:GVH0Ae]R03U=E00oDeL0?U9C
03eAD00hC4X0>Di90P12Ee80500nDdh0?e=A049FE@0mDE00C61P041ED017G5D0>Tm604EKC`0oEDT0
?59503aBAP0oEDP0>e5403iDA`19Ge80B5iA04QME01GK6D0GW=/0P16Fe@02@1=HU/0CfAM059WH01G
K6D0FVmX05]`J@1JKfL0E6]Q05I^H@0205YaI`0O05I]H`1AJ600GGA/05ieK@1PMg40GgI`05abKP1I
Kf`0EVaY05Q^JP1OMVh0F6mW05YbIP1FKV40GWIY05UaI@1QN6h0GgI^05Q^JP1QN780G7=[05I]H`1C
JV00EFaR05I]H`1CJV00BF1F04MNE012FDl0EFaR04iUF`0204UQE00804QPDP17Ge80AemB04MND`15
G580AUeC04MNE@1?IUh204UPF01F049ID@1<HUl0A5]E04=JE016GEL0A5]C045HD016GED0?EA:03aC
B@0oET`0?EE803UAA00mDTT0?55803mDB`0kD4L0>Ti503iBB@0hBD40;Slg02`m=@0Y>34093</02Dd
;@0U=2l0;Sdh02/j=@0X=c80;C`g02ln>@0c@Sd0;C`g02He<00M;2L072/V01h]9P0/?380:STb02<b
;00Q<2/09S8`02@_;P0O:BP07bXV01lY9@0I8a/06bDM01lY8@0N:2007bPS01dW8@0J9Al06bHR020/
:00D81`09cHc020_;017EU<0938b01TS8P0M8b40728P01XP7P0K8Al07bDS01dS8@0K8Al08RPV02H/
:P0R:2H0:Bl]07^0OP1EFEP03Q8A01hR8@0B5QD05ATH00lC4P0B5QD0720O01XN7@0E6AP06AdL01lQ
7P0L7Q/401TK600301`N6`0J71T05aTF00805ALD00<05QPE01LH4`0G61<01@0G61<07`0F5a805AHA
01@E400F5a805aTE020R8@1lP840@dE500lA40082PT05QHE01HF500D4a004Q4=018A300C4@`04Pl:
010?2`0J6AD07ahJ01DD400@3`/01`H201TH500<2`L07A`H018A3@0920D07A`H018A3`0>3@/00P0H
5aD0500?3P`05A@B01DD4P0@3`d05A@B00/:200B4@l05A@B014?400C4A803`d>028P8@0c<C804@l@
01<A4P0B41403@/<010>3`0?3@h02PP90P0@3Pl08P0A3a004Q0A01<A4P0C4A803P`=00P61`0C4A80
30X;01/I6P0E4a@05a<B00H20@0K5aH02PH500P40`0G4a803PX900d9200>2PT040`;00h:2@0<20L0
40/8014<2@0B3@T050l:01@?2@0C3PP05Q4<00P3000=20D03PP:01D?4@0?2P/2018>3@0700l;2P0<
20L03`/:014=300=2@P02`L600`81`0200h:2@0E00/71`0K5aP020@501XF5`060P<06aLH00X61`09
1@H09b<T00d92P070`@061@E014=3P0<20T02`L8018>3`091@H06ADF00T51P0>2P/02`L800803`/<
00@02PH7014=3P0Q7Ah081`M0P0?2``00`0@30d03PX;00h:2`0200`82@0H00d92P0;1`P04@d>00l;
300>2P/00`0000/7200D41406ADF00P41@0U8B802`L800T51P0?2``08adO028L7P0C3@l030H801@>
400<1PP02P@600d72@0A2`d03`T;0P0=1`T2014;3@0<00L10`0?2@/03PP:00h82P04000050h@010:
300400004@/=00H00P0>2@d03@P<0P0<1`/01P0>20`03`T=0107300@1``03`H;01052`803`@:5?oo
ool001_ooooo0P0>4Q<0200<41402`l@00`@4@0<41403Q8C01PL7@0A5AH05a/L0P0;3a001@0<3@h0
3Q0@01LH6@0@4Q804Q<D00803a4A00<03a0A00h?400=3`l00P0=3Pl00`0>40l03a4@00lA400300lA
40803Q0?010030h=00/=300>40l04A<B00h@3@0A4a0020T703Hh=@1SIF805ALD010B3`0F61D03a4>
014C400F61D04A<@0P0>40/0600@4Pd04aD@014C3P0?4@`03@l:00lA300A4`h03@l;00d?2P0B50l0
1@H301PI500=3PX051D@01<D3`0=3PT04A8=010A300A4Pd04a@?01HG4P0E5Q80418?00h@3@803a4>
00<03@l<00h@3@0?4@h00P0>40d0100?4@h04A<@010B3P0>40/200d?2P0:00lA300B50l04A<>00lA
300>40/03a4<014C3P0B50l04A<>00h@2`803@l:00<03Q0;014C3P0>40/01@0>40/200l@2`803Pl:
01`03a0;014B3@0@4@`03Pl:00d>2@0?40/04A8=010A300@4Q402P`;00/=300B51<04aDD02PZ:@0?
4A003Q0?018D4`0:30/06adL00h@3`0?4@h02P`900h@3@0?4@h04Q@A00h@3@0A4a00418?0P0>40d2
00lA3P0800h@3@0@4Pl04Q@A018D4@0C5A804Q@A00lA3P0>40d200`>2`0400h@3@0@4Pl03a4<00d?
2P804A<>01P03@l:00lA300=3`X0418=014C3P092`H05ALB00T;1P0;3@P0418=01DG4P0B50l030h9
014C3P0?4@`030h900d?2P0@4Pd02@/6018D3`0=3`X02`d801<E400=3`X200lA3003018D3`0G6A@0
5ALB00803a4<00H04Q@?00lB2`0B5@h04QD>010C300?4P/2010C300G00lB2`0@4``04A@=010C300>
4@X041<<00/>1`0930D05aXC010C300?4P/06A`E014D3@0B5@h04aH?014D3@0=40T071lH018E3P0>
4@X04QD>00T<1@0C5Pl00P0A50d3018E3P0701XM5P0D5a003a8;01DH4@0<3`P03A0901@G400301<F
3`0J018E3P0A50d041<<010B300@4``041<;014D2`0B5@/041<9014D2P0C5Pd04A@<014D3@0I71H0
3A0900lB2`0A50d0:B`U02P[900B5@h03Q4:014D3@0C5Pl04QD>014D3@0C5Pl200lA300801<E400F
61<05ALB010C300B5@`051L>01LJ4@0E60d201<F2`05018G400D6A805AXC014F3`0>4``00P0?50d0
2P0L8AX04QL@020U7P0B5a004aPA018G4@0F6aD04AH@01TN600R9b43018G4@0<00lD3P0J7aT05AXD
01<H4P0<4``06R4J01<J4`0H7aP0HVUR01dT7@0>5@h04aXC0`0G7QL03`0I81T04AXG01PQ7P0@6AH0
5QlL01XS800R:bP09Bh[07b5PP0X<Bh04AXG01hW900E81`07bXV01/W8`0201TU8@0301XV8P0K9b<0
7BTU008072PT01H07RXV024]:@0R;bP08bhW02D`:P0X<bd0<Shl02<_;`0K9bL08S0`02<c<00[?3H0
:c`e049CB@1_P7H0d]kL09j^ZP1HJ6@0<T<n02Lj=`0aA440:chl0P0]@D004@0/@3l0:d4o02e3@@0`
@dL0;T5502Tl@00/?d<0<4=70395B@0`@dL0<TE903e@E00jCE40?E1D049FF`0nDeP0?55F0080>e1E
00D0?55F03I;D00aAT/0=DY?03]@E@0203eBE`0?03Y@D00lDTl0@5IC04=HF@11EU/0@5AK04EIH@1=
HFX0@eMO04UMI01<HFL0@5AJ03iBEP10DeL0@UIG0080@UID01`0AeaG04UNF@0oE4l0Cf=Q08nSXP1<
H640@UEH04EIE`1;H5X0@UM?04QME014FTh0?UA7041FB00oEDL0@5I904EKC`18GU40B5iB04iTG@13
FE<0AUaE04UOF@1EJfD0CfEN059XHP1DJV<0F6iW0P1JL6T02@1IKfP0EFaR05I^H@1IL6H0FW5W05U`
IP1HKfL0FW5Y05]bJP0205edKP0W05]bK@1HKV/0GWA`05ecK@1PMVl0F6iT05]bIP1IL6<0Jh9e05ie
J@1JL6H0FFmW05abK01^Q7h0G7=[05U`IP1FKF<0EfiT05I]H`1CJV00B5mE04]RF01:HEL0E6]Q04QO
E@0oEdX0AUiA04ALC`18H5<0CFEH04eTF@18GeD0BV5G05=ZH@1HKfL0B5mG04AKD`15G5@0BEmL0080
DFQR00D0BF1J03mFCP0lDd/0>e9:03iEB`02041GC@1903eEB00lE4L0?59704IJD011ET`0>Tm503e@
AP0nD4L0=TLn02dm=00/?C@0:CP`02De;00W=Rl08S4/02He<00W=S40<3lj03A3?P0b@C`0<D0k02Xi
=00S<Rd072/V01d/9`0Q<2/093</01l^:00T<bl0:cTh02`h=`0Z=CD082XZ01XT900P:BL082TT01/T
7`0J91d07BLO01hW8P0M9b8072LQ01dX900Q;2P07RXV02@c<00G9R<0=DA101PV9P0M:2H08BLU02@Z
:00S:BL07B<Q01/Q7`0I7ad05adK01XP7P0N92806b4O01dS8@0S:2H0720N01TN6`0A5Q<04aLE01LL
6@0D6AH051PF01TN6`0J7a`05QXH01LL6@0201/M6P0501XL6@0F61D05QPE01TK600E5a@00`0D5Q<0
0`0F61D06A/H01LH4`0501LH4`0301@E400C50l051D@00804a@?03804aDA010A4`0`=3H0414D01@E
5`0F61P04A4A01HF500D4a004Q4=01<B3@0D4Pd04a0;01HE4@0C4Pl05A@@018A3@0K6QL0:BPT05YI
E@0K6QH04Q4=01LF4P0E51003@`801<B400?3P`040l=00d<2P0C4Q00:bXX014@3P0@3`d030/900h=
2`0U92804Q4?01DC500D4Q<030X;010>3`0H5QL03@/<014?400>30d03`d>01/I6P0G5AH02`T:014?
408040h?01D03`d>00h<3@0>30d04@l@00h<3@0=2``04a4B00L51P0B41404`l>00l;2P0<20L040`<
01`H5`0?2`X040`;00l;2P0@30/04Ph=010<2`0>2PT00P0A30X03P0B3@X04@`800l:1P0>2@H050l;
01/E500Q6a/050h>01<=3P0>2@T040`;014=300@30/03PX90P0?2`X200d9208040`;01803PX900l;
2`0=2@X02PH703/g>00:1PL03@T:010<3@0A3@h0BDE600h:2`0C3a001`<400l;300>2P/03@T:02XV
9`0C3a03014=3P802`L800H030P900T51P0<20T040`=00h:2`0810D200l;300O01<?400=2@X03`/<
014=3P070`@03@X:00l<3@0F4a@0514B014>3`0:1`P04Pl@02TV9`0;20T03@X;01HC500J5aP040`=
01PB500I4aD03`T;00d72@0E3a4040X<00h82P0<1PP02`D700`6200>20X040X<00/51`02010:3004
00h82P0:10H03@L9014;3@802PD600D07aTK00/51`0?2@/02`L900d92`0200l;3@0600h92`0<1PT0
40L;01072`0?1PX040D:0P0?10TDooooo`006oooool00`0A5AH041@E00hB4`0200hB4`0>00lC500@
51D020`=018F5`0>4Q<05ATJ00hB4`0B4aD030d?00l@4P0I6Q`03@h@00`=3`0A4Q@200d>4003014B
500?418030d?00803a4@00@0418A00h@3`0?4A0051HE0P0>40l0100@4Q4051HE01<E500B51<2014C
400;00P:1`0G6AH0=SPe00X<2@0<3P/03a4>00/=2P0=3``0418?00d?300B50l00P0A4`h04@0?4@`0
30h900X<1`0<3PT05ALB00D70P0[;BP0=3Ha00T:1P0H6A@04Q<>01HG4P051P404A8=018C3P0C50l0
4Q<>00<0414<00<0:2TU02la;P0L7Q/00P0=3``0100>40d03@l<00`>2`0>40d3014C400700lA3@0=
3`X03@l:00h@2`0@4Pd04Q@?014C3P0200h@2`05010B3@0A4`h04Q@?014C3P0>40/00P0=3`X00`0>
40/0418=00lA300500lA3006010A300?40/03Pl:00h?2P0?40/0414<0`0=3PT05@0>3`X03a0;010A
30072@P08R@S00d?3P0>40l061XI00lA400@4Q404A<B00lA400=3`h0DE=B010B4@0?4@h06A/H010B
3`0C5A803a4>00/=2P02010B3`803Q0=01003a4>010B3`0C5A804aDB018D4@0A4a003a4>00d?300@
4Pl030h;00h@3@0B51404aDB00d?300A4`h0418=0P0F61<0200@4Pd04A<>00h@2`0@4Pd03Q0;00/=
200A4`h02`d80P0B50l07@0F61<05ALB018D3`0G6A@03a4<00h@2`0@4Pd04aD@00X<1`0A4`h03Q0;
00d?2P0B50l03@l:010B3@0=3`X04Q@?01PJ5@0G6A@0418=00h@2`0@4Pd041<<00hA2P0?4P/04A@=
010C300?4P/041<<00803a8;01@04A@=00lB2`0=40T05QTB00lB2`0D5a003a8;010C301<CdP04aH?
00/>1`0@4``05QTB01@G400@4``061/D01@G400C5Pl04A@=00/>1`804A@=00L04QD>010C300>4@X0
4QD>010C300>4@X04QD>00@04A@=00H04aH?01DH4@0E61404QD>014D3@0A50h2018D3`0:014D300@
4`X041<8014D2@0D5``05QT@01@G3`0@4``04Q@?01<F3`805QTB00H0EEQA059ECP0G6Q<04A@=018E
3P0D5a0201<F3`0[018E3P0I6aH051HA01`N6@0R91l06A/F01DH4@0A50/04aH=01HI400D5``04aH;
01DH3@0?50d0314:014F3`0F6a@04aPA01LL5@0I7QL051TB01TN5`0>4``02@h701TN5`0B5a404AH@
01DJ500K81X0724K014F400=4P`05a`F01<H4P0F6aD0;S<]01LL5P0E71D03aH?01@K500B6A804APA
028Y8P0201PO600B01TP6@0K8Q/06R4J01HM5P0?61D0624N010I5P0K92408BXW01XS800H8Ah03QLD
01DN6`0G81d05AhK01PS7`0O:RH07BTU0P0K9b<07P0L:2@07BTU01XV8P0J9R806bLS01dY9@0O:bL0
7b`U028]9P0L9b409C0Z04UED`0iADD082`/02dk>`0X>3D0;d0j02m0>@1DIE/0Sj2F0>WhlP2L[JL0
@55;0393?@0X>cL0;d8n02`o?@0/@3h0;D4o02a0?`80:d4o00<0:Si00313A`0`@dL00P0dAd/0300`
@dL0<TE90395B@0fBDd0A5MK04YMH@13Ee`0>DiC03E:C`0dBDh0>4eB03aAEP80@eQM0P0mDUL203mD
F@0Z045FF012F5H0?eAE041EF@14FEh0AEUP04UMI@18G6<0@5AK045FF`14FE`0@5EH03iBE011E5P0
AEUJ04EIF@10E580?U9@03aAC019GUT0A5QG061dM@1KKg00AEQL049FE@16FUP0AEYD04QME019Ge<0
@eU<03mFAP0jDD40@UQ;04UOD`12F4`0AEY@05I]I@1AJ680D6MQ04aSG@1RNG<0E6]U0P1FKFL305U`
JP0905Q_J01GKV@0EViQ05M^I01HKfD0FG1V05]bJP1JLFT0Fg9Z0080GGA^02d0G79^05]aKP1RMg80
GgA^06=hK`1LLVH0I7Y^06IlK`1CJE`0FFmS06EkK`1SN6l0EfaV05EZH`1LLf/0G7=Y05]bJ01JLFL0
EfiT05A[H@1:HEL0C6=I04YQE`1<HeT0BV5G04YRE@11FD`0@5Q:04EMD01<I5L0C6=H04=JD016GE<0
@EQ?04ELE012FE40BF1H04IME@16G5T0DFQR05=ZI01:HE/0?eI>03]BBP0mE4`00P14Fe40:`0lDdT0
>51303UAA010ETX0BEeB03a@A@0jCT<0@U=903a=@`0hBCl0;cle02`l<P0V=R`08C4W028b:00[>SD0
;C`g02/j=@0`?cX0<d8m0350>`0Z>C@08C0[01XY900H9b8072/V020_:P0X=c808S4/02Lf=00X=SL0
:3<e02D_<`0N:2X07BLY02Xc<`0X<Bh072DR01LP6P0K9Ad07BHQ01hX8P0M:2800P0O:RH01P0Q;BT0
6BPU01l^:`0lBdP06RPX028/:`808bTW01H082HT01/Q7`0J81h0728P01PN700G7A/07R@R01dS8@0K
8Al08RPU01@I5@0=4Ph05AXF01TN6P0G71P06QlK01HK5`0H7AT06QlK01LL600E6QH06A/H0P0L7Q/0
2@0E5a@04aDB01XL6@0K7AX06Q`I01LI5P0F61D05aTF01PJ5`0301LH4`@05QLB01d05aPC01PI500H
6A@05aPC01@F4P1lOH40hNCY02d^<`0e=SX07QlQ01DE5P0F5Q@051<@018A3@0C4Pd05A<>01@A300A
40`04Q4=01<B3P1SHUh0UIB@018A3@0A40`030/701TH500@3`/030/7018A3@02018A3`0G01@C4@0A
40h040l=01`K6@0B4@l051<A00h=2`0920H071/I00X91`0L6Q/05aDF01<A4P0?3@h03@/<018@4@0A
3a003`d>00h<3@0F51D04a4B00X82@0@3Pl00P0?3@h200h<3@0C00d;301PGUl03`d>01TG60091`P0
6QPI014?400T81l03@T800`81`0C3`h01@4001HB4@0>2PT03@T800h:2@0@30/03PX900`81`03014;
2`0=010:2@0>20P03@P501hI5P0O6AT07ALG00/61P0A2`/03`X900d9200?2`X040`;00l;2P0200h:
2@0B00d9200<20L03PX900l;2P0>2PT02@D501PD5@0:1PL030T9014=3P0H51D02PL700<0000U8B80
4`l@00h:2`0C3a00:BDV0P0H51D03`0l>3T061@E00X61`0>2P/05Q8C014=3P0>2P/04Ph?014=3P0C
3a003`/<00X61`0=2@X04`l@00`82@0201<?40803`/<010030P901/G600100003`d>00P61`0=2``0
2`T:04E3A02/ZZ/0:BLX01PF5`0?3@h040h?00@20`0<1PP03@L90P0:10H01@0@2P`03PP:00l92`0@
2P`03`T;00802`D700l03`T;01<=3`090`D0208400`6200B30h02`D7014;3@0I4aD091hP05A>D00I
4aD04`d?00/7200=2@X00P0?2``01P0>2@X030H801072P0@1`X03`H901052@803`@85?ooool001_o
oooo0P0A5AH04@0?4a@03Q8C00lC500?4a@041@E014E5P0G6a`02`l@020T9@0D61T02``>014B500B
4aD03@h@01<D5P061`T04A8D00803PlA00X04Q<E010A4`0=3Q0030h=00X<2`0?4A004A<B01DG5P0L
7Qd04Q@C0P0>40l01P0?4A003Q0?00d?3P0?4@h04Q@A00lA3P803Q0=00@07R0M00h@3@0>40d02`d:
0P0<3P/05P0:30T04A<>018D3`0A4`h03Q0;00/=200:30L02`d801LI50051`80:bdX03<e<0092PD0
5aPC0001000@4@`02P/601LH4`0C50l04A8=010A300?40/200d>2@0=01hO6`0Q8b004A<@00P:1`0=
3``04A<@00lA3P0<3P/03Q0=018D4@0A4a00418?00h@300200`>2@0500d?2P0>40/03a4<00lA300>
40/00P0?4@`400h@2`803a4<00<03Q0;00d?2P0?4@`01@0?4@`2010A300400l@2`0>3`X03Pl:010A
30@03a0;00P0414<018C3P0I6aX071hM01DG5P0210<051HE018D4`80418A00`04A<B00h@3`1?DE00
418A00P:1`0M7a`03Q0=01DG500A4a003a4>010B3`0?4@h200h@3@80418?0P0B51402P0A4a003a4>
00d?300;3@X03a4>00d?300B514061XG01DG500:30T200d?2P804Q@?0P0=3`X0<@0>40/04A<>00d?
2P0?4@`0418=00lA300C5A00418=014C3P0@4Pd03a4<01@F4@0A4`h04aD@01LI500H6QD030h9018D
3`0?4@`04A<>00h@2`0H6QD08R@O00lA300>40/0418=018D3`0C5A00418=00h@2`0>4@X03A0900hA
2P0C5Pl051L@01<F3`0B5@h041<<014D3@0B5@h03a8;00d@2@0@4``03Q4:018E3P0<3`T05QTB05YM
EP0L7aP00P0C5Pl00`0E61404QD>010C300201HI4P0W01DH4@0@4``030l8010C300A50d04QD>010C
300>4@X04QD>00lB2`0@4``04aH?00lB2`0C5Pl051L@014D3@0C5Pl051L@018E3P0?4P/041<<01<E
3`0C5A004Q@?018E3@0@4`X041<8014E1`0D5``05AP?01DH400B50l04Q@@014D3@0N8AX03A09024T
7@0K7QL041<<00805APA0`0F6A803P0E61405aTD014C3P0H6QD07AlJ01DG4P0C5Pl04QD<01@G3P0F
6A0051L<01<F2`0E60d05Q/D0P0@5@h07P0D6A804aPA010E3P0E6Q<07b@M00lD3@0L8AX03A8;01<H
4@0I7QP04QLA01hS7@0O91h04QLA01HK5@0L8A/061dG00L<1P0D6A<0=S/e024V800L8a`051/D00dD
3@0I81T07RDN01`S700K8Q/05QdF01DL5@806B0I00h04aXC010I5P0G81d051dJ028[:00Q:RL04a`I
01XS800T;BX08BXW00lH5@0L9B805b8N01/V8P806bLS00<07BTU01l[9`0O:bL00P0M:BD0600N:RH0
7b/W01l[9`0O;2D07BPQ03E0>P0P:bD09S8`02Hb<P0R;Rh0;cdm02lo?00a@S`0<T<l03I7?@1<GE<0
T9nH069cK@0U=S00=4Do02/n>P0^@Cd0;D0l02a0?P80:clm00P09cdj02Hl>P0Y?3l0<4=70354B00h
Bdl0>diB03I9C@80>4]?00D0>Da@03mBEP0mD5@0>TiC03aAEP0203Y?E00603iCF012Ee`0AEYO04=H
G@0oE5T0@UML0P16Ff00:P14FEd0@UMJ045FF@12Ee`0AEUP04EIHP16FV80A5QO04=GGP0nDeL0?55B
041FE011EUL0A5MK04UMGP1:GUh0AEUG045ED`10E580@EEC04eQH017Fe`0?51A04MJGP16FU/0B5aK
04YNF`17G5D0Bf5E04EKCP0oEDP0>e5404AJCP1:GeH0A5U@04IKD`1EK6H0CfIP04UPFP1JLF/0PYVC
05acK@80F6mY0`1IL6X00`1HKfP0FG1V05Q`H`0305M^I00I05U`J01LLf/0GGA/05ieK`1OMW00GgIa
05meLP1SN7<0GgA^069gKP1KLFD0HgU]06EkKP1OMFP0GG=W05idJ01LLFP0G75[065fK`1MM6`0GgI/
05ieJ`1LLfT0F6mU05E/HP03059YG`0A04iUF`1<HeT0B61C04=KCP12FTd0AemB04aTE`1:HEH0@UU?
04IMD`18GeH0CVEM04IME@19H5P0AUeE04QNF`17GUP00P19H5X07013FU80?eI>049ID@16GE<0@UU?
03U@AP0iDD@0?EE804EJC`13Ed`0=DTn03Y>@`13E4X0>T]103I6?00/?380:c/a02Pe;00T<BP09C8Y
02dl=`0b@C`0;C`g02/j=@0`?cX0<D0k02Pg<P0O;RT201XY900L01l^:@0R<B`09C@`02@c<00Y=cL0
9cDh02/f>P0[=CX08BX_028[<00Y<S@09Rl^028[:P0M9R806bDM01dV8@0N:2807RTS020[9`0N:RH0
:cLc024`;@0E924082l/020^;P0f@3l092XX020V90806R0N01@082HT024W9@0H7Q`05adK01lU8`0P
9R@07B<Q01/Q7P0>4`l05a`H01lT800=4Ph05Q/G01/P700H7AT06AhJ01`Q7@0H7AT05AXF01/M6P80
7R0M00T05aTF01DG500L7Q/071hK01XL6@0H6QL05QPE01LI5P0H6QL00`0G61<00`0F5a805AHA01DF
4@0201PI500N01XK5P0I6QD061TD01DG4`0N7b<0GV5V01@E6@1TIFT0=cPj00l?400F5Q@051<@01<B
3P0D4`h05Q@>01DB3@0=30P05aHB01/J5P0Y:2@0;RdY00h=2@0T8al04A0<01<B3P0@3`/04A0<00d<
200C4Q004A0>0P0D4a402P0@3`d03Pd;010?3@0D4a405A@B00D40P0:2@P03@`:01@B4`0=2``2014?
400900d;300?3@h040h?018@4@0=2``040h?01<A4P0A3a003P`=00803`d>0P0@3Pl0500A3a00HEmP
00l=3P0I5aP020H701TG600@3Pl0FUIE00L30P030000;BTX00<0000A3@`03PX900d9200>2PT040`;
00h:2@0<20L04@X:0`0C2P/00`0B2@`04PT:01hE5P0201H=3P0<00/40`0D30X03`X800d9200>2PT0
40`;00l;2P0=2@P03PX900d9200:1PD02`L60P0=2@P01`0?2`/03`/<00/7200M6AX04@d>00h:2`0C
3a000P0<20T05`0B3Pl00`0001LC500X92D071PI00d92P0D414020@5018>3`0?2``06QHG01@@4@0<
20T03PX;00`82@0?2``030P900/7200@30d05A4B00h:2`091@H05A4B00803`/<01007a/L030/;@0B
41405A<D00@20`0C4A80108300d<300Z:2T0108300<10P0B41403@/<00l>3P0?2@/040X<0P0?2@/0
5P0B30h040X<010:300G4A<06Q@F010:300;1@L040X<00h82P090`D04`d?00/51`0=1`T01`4300@0
000:10H0100002DO8@05004030H800h:2`0=2@X200`82@0600h92P0?2@/040L:01072P0?1PT040D9
0P0?10PDooooo`006oooool00`0@51D03a<D00dA4P0200dA4P0=00hB4`0:3Pl03A4B00lC50052@X0
4aLH00dA4P0>3a80414D02HW:P0a<SD05aPK01HG6P03010A500F014B5@0B4aH04Q<E01`N7@0>40l0
418A00lA400;3@`0418A00lA400@4Q403Q0?00d?3P0?4A004Q@C014C400@4Pl02P`:014C4@072@H0
4Q<A014C40803Q0=00H0418?00h@3@0<3P/02`d8010B3@0A4`h200lA300?010B3@0C5A005ALB00lA
300<3PX03Q0;00d>2@0E5Q4030d801LH4`0:2`H04Q<>00l@2`0=3PT03Pl:00803a0;00/03Pl:00l@
300=3``03@l<010B3`0?4@h030h;00/=2P0>40d03a4>014C4002010B3`0300h@300=3`X03@l:0080
3Q0;00H03@l:00h@2`0>40/03a4<010B3@0?4@`200h@2`0500lA300@4Pd03a4<00lA300=3`X01P0@
4Pd00`0A4Pd0414<00l@2`0200h?2P0I00l@2`0B4`h04a@?01<D3`0@4@`03a0;018C3P0G6AP020X9
01<E500=3`h06A/J00X<2`0=3`h02P`;01HH5`0>40l05QPG00h@3`0E5a@0=CLd01<E4P0I6aP03Q0=
00d?300200lA3P803Q0=00D0418?014C400?4@h0418?014C4002010B3`0900lA3P0@4Pl03a4>018D
4@0F61D04aDB00/=2P0A4`h03a4<00804Q@?00h03a4<014C3P0@4Pd04aD@00/=200B50l030h9010B
3@0E5a804Q@?01DG4P0D5Q403@l:00`>2@803@l:00d0418=01<E40082PD03Q0;00lA300C5A003a4<
01dO6P0Y:bH051HA00/=200<3PT03Q0;00804Q@?00T04A<>00lB2`0A50d04QD>01<F3`0F6A806A`E
01<F3`0A50d00P0B5@h0200?4P/03A0901@G400@4``02Pd6010C300=40T04QD@0P0?4P/02@0@4``0
4QD>01DH4@0C5Pl030l8010C300B5@h03A0900lB2`03014D3@@04QD>01004aH?018E3P0@4``051L@
018E3P0?4P/051L@01HI4P0C5Pl03a8;010C300C5A404aDB018D3`0B5@d04QD:0`0A5@L02`0A50T0
4QD=018D3`0B514051HA01HI4P0@4``06QdF01TL5@0B5@h05QTB00805APA0P0F6A804@0C5Pl05QPC
01@F4@0B50l051HA01HH4`0F6A805QT@01LJ4@0F6A004QD:014D2@0C5P/03a@=01HK500C61403Q<<
00<05AXC00T02Pl803i3?00I7QL051TB01<H4@0C61804QLA01LL5P0H7AL00P0E6Q@01P0C61805Q/E
01XO6@0A5Q007R<M00lD3P8051/D00d072<L00`C300H7aP07B@M010G400I81T072<L01PO600E71D0
5ahG01@M6P0G81d06R<P008092dZ00X0<CXg01DN6`0I8Ql08b`Y01<L6@0G81d062<O01TT800J9R80
6bLS0P0N:RH201l[9`0H020/:00R;RX08RhZ028^:P0R;bP082/T02Xe;`0K9R0082`Z01l[:`0T<300
;cdm02Lg=00R<bd0;Chg02ho=@0a@SP0?4]403a=AP0^?cP0<d@n02Lj=@0^@C`0;d8n0P0[?cd04`0/
@3h09cdj02@j>00]@D<0;D1402/n@P0dAd/0@5=G03a?D`0hBdl0>diB049EF@14Ee/0?E1D03Q<D@0i
CU<0>e1E03eBE`0nDeP00P0oE5T0;P11EU/0AEYO04QMHP14FEh0?eAI03iCF012Eed0AUYP04MKHP16
FV80Ae]T04MKH`11EE`0B5eR04AIFP10EU<0B5iK041EEP10DeT0@eIJ04MKF`17FeX0AEUG04=GE@16
FUP0H7Ac04=GF016FEd0CF1V04MJGP14F5T0B5aJ03mDCP17G5<0@eU=03iDA`12F4/0BV1D04aQF01=
HU/0CfAO04aSGP1BJVD0EfmZ05A/I`1VOWT405Q`J`80FG5/00<0FW9/05YaI`1JLVD00P1JLFL07@1K
LVP0G7=[05ieK@1OMVh0H7Ma069iL`1TNWH0I7Yg06EjM@1QMVh0HGI]05M]H@1LLVD0Fg5S05edI@1P
MVT0H7IZ05icJP1NLf/0H7E^05edJP1RNFl0HgY`05mfK01IL6H0EVeS05U`IP1CJV00EfiT0080CfIL
00<0A5a?04MODP1:HUD00P1<I5L0@01;HUL0BF1F04IMD`1AJ5l0EVeU04MNEP1:HET0DFQP04QNF`16
GEL0AeiH04QOF@15G5@0@UUA041GC`11F4h0?UE;03]BB010F4/0AEe@04IJCP0mDDH0=d]003]>@P0m
CT<0>4Xo02`l<P0V=R/0:3P^02/h;`0/>Bl0;S/b02/j=00`?cX0;3/f02/j=@0b@C`0=4<n02Xi=00R
<B`082lZ02@c;P0X=c80:STe02dl>`0V=3@09cDg01l/<P0T;SH0;CLo02Pa>@0R:c807RH[01dU9`0U
;Bl09Bh[01dW7`0O:2<07bTS01hY8`0P:bL08B`X020/:00E924201`[:00801TW9`0T;bd08bTW01hT
8P0H7Q`06R0N028X9P0Q9bD201HL6P0801dS8@0L8R006b4O01XP7@0D6A@05a`G01<H4`0G71L301TN
6@8082DP00P06QlJ01PM600N81d07b4N01dO700I6aP061XG01/M6P8061XG00@05QPE01DG500F61D0
61XG0P0G61<0100F5a805AHA01@E400D5A0201LH4`0V01HG4P0E5Q4051D@01<D4@0I6Ql02@/B024Q
:00D5AX07b0T018B500F5QH051<@01<B3P0E50l05aD?01LD3@0A40`04A0=01<B3P0?3PX04A0<01PG
4`0@3`d03Pd901DD400A40`05QDA014@300C4Q003`h<00h=2`0A40h04a8@010?3@0?3P`04A0>01LF
500=30X201@C4@803@/<00<040h?01<A4P0B41400P0@3Pl01@0B41403P`=014?400G5AH061HG0080
3P`=00<03`d>010>3`0@3Pl00P0A3a004P0>30d030X;014?40040P<03`d>01<?3P0B3Pd04`l?03/g
=`0H51<03@T8010<2`0?2`X040`;018>3@0@30/03PX901<:2`804`X<00/04`X=0148300A20/040L:
00d41@0E30d04@T701H>2`0A30X04@d<00l;2P02010<2`<03PX900H03@T800l;2P0@30/03PX900l;
2`0@30d200h:2`0G00d92P0<20T04@d>01/G600>2P/03@T:00`82@0F4Q<030T901@@4@0;1`P03@T:
00/7200I5AH040`=028N7`0M6AX03`/<00h:2`0:1PL03PX;010<3@0>2P/00P0<20T0:`0A3@h02PH7
01@@4@0=2@X02@D601@@4@0H51D02PP900l=3P0=2``03P`=00P61`0>30d030X;00X82@0?3Ph00`82
01LE5P0L6Q/02`D700`6200>20X03@L900`6200;1@L030H8010:300B30h030H800P2100:10H02`D7
014;3@0_:B/04@/=00d72@0;1@L03@L901<=3`0910D05a4C010:300B30h00P0>2P/200`82@0600h9
2`0?2@/040L:01072P0?1PT040D90P0?10PDooooo`006oooool0100B5QL04ADF010D5@0?4a@2010D
5@0[01HJ6`0:3Pl04aLH01<G600:3Pl041@E00l@4P0G61/0QhR:0=_Lh015ATT0414C00d>4P0B4aH0
4Q<E010A500B4aL05AHH01XL6`072@P03Q0?01<E500?4A004Q@C014C4P0G6AP051HE00`>3@0:30/0
30h=018D4@0A4a00418?00d?300G6AH02`d:00`>2`092`P030h;010B3`0>40d03@l<00d?2P02014C
3P803@l:00/03Q0;02@V8@0E5a801@L200lA2`0K7AP04Q@?00L80`082@@02``700d>2@0201<D3`80
4A8=00D0414<00d>2@0<3@P02P`800`>2`0200lA3P0400`>2`0;3@X03@l<010B3`@03a4>100@4Pd0
1@0>40/03@l:00`>2@0=3`X03a4<00@04Q@?00D0418=00d?2`0<3PT030h900lA3002010B3@04010C
3@0@4Pd041<<010C30804A8=01803a0;00h?2P0>3`X03Pl:01<D3`0E5Q4051D@00h>300=3PT0410>
01<E4P0>40l04aDD00X<2`0E5aH030h=00X<2`0D5QD2014C4P0800h@3`0D5QD00@<002T[:0041P<0
4aDB00h@3@0C5A8400h@3@0;010B3`0A4a005ALD01@F4`0C5A804A<@00h@3@0<3P/04Q@A00lA3P0<
3P/00`0=3``01@0?4@`030h900d?2P0=3`X030h900803a4<00X051HA00/=200G6A@03Q0;01LI500D
5Q403@l:00`>2@0=3`X03a4<0P0D5Q4200h@2`0F014C3P0=3`X05aTD00lA300@4Pd04Q@?00`>2@0A
4`h030h900/=200A4`h0418=00`>2@0A4`h05aTD01<F3`0G6Q<05APA014D3@0E61406ahG014D3@80
3a8;02X041<<00d@2@0;3PL030l800L:0`0E614051L@018E3P0A50d041<<01@G400A50d03a8;01@G
400F6A<02P`700lA300A4`h02P`700lA300A50d03a8;00hA2P0C5Pd05AP?018E300?4PX030h900/>
1`0B5@h05QT@018E300=40L051L>01XM500I71D04QD>014C3P0B51004Q@A018D3`0B5@d2018E2P0?
01@G2`0C5P/04A@9018E3@0B50l04Q@@01DG4P0A50d04aH?00/>1`0<3`P04QD>01LJ4`0E614051L@
00805QTB00X04QD>01@F4@0F61<03@l:00/=200F61<06A`E018E300C5Pd051L>0P0C5P/0<`0G6Pl0
5Q/D02`a:P0T:B802Pl8014F3`0E6Q<05a`E01/P6@0>4``07B8K01HK500D6A803A8<01PM5`0<4@/0
5a`F02db;00G71H05AXD01LL5P0B5a406AhH014F400S:2805A`E02Xa:P0A61405QdF01@K500>5@h0
4APA030g<00f?CH08BPQ01<K500N:2005b0K01TR7`0L9B807RLT02Xc<01OJ6D05QlL01PQ7P0W<2d0
82TV01XS800P:bL06BDQ01/W8`0201`X90806bLS00<05b<O01XV8P0M:BD00`0Q;BT0E`0P;BH08RhZ
02di=@0O;2X062HV03=1@@0U=3@09cLf02Pk=`0]?SX09STc02m2?00iBDH0:3Pe02/n>P0]?c/0:3/g
02i1?@0^@Cl0:Shl02a0?P0^@T40:d4o02Pn?00Z?D40;T5502m2AP0eB4`0>Da@03a?D`0hBdl0=TU=
03mBEP0jCE40=DQ<03I:C`0jCe@0?U=H049GG010EEX0?U=H03eBE`11EU/0@eQM049GG010EEX0@eQM
04]PI@1=HVL0B5eR045EF`16FV40DfM^05=WK@0kD5D0A5UL04MLG016G5T0Bf5N04=HE`18Fel0Ae]L
04UMG@1:GUd0BEeK04eQG`1KKfd0Cf=R04YNG`12EUL0C5mS04UMGP14F5T0CF5P04EJE@1EJV<0EV]R
03Y@A015Fdl0B5eD04MLE@1@IF00DVMU061iM@1AJVH0F75]05aeL@0205E^JP80FFm/03/0FG1[05Y`
K@1KLV`0GG=_05U`IP1JLFL0GWAZ065fK`1QN700HgUa05mdK`1NMFl0H7Ia069fM01UNWL0IWai06Ai
M01QMfl0HWU_05]`I`1OMVT0GGEW05idI`1PMf/0GWE[05ebJ@1OMFd0GgI^05edK01TNg80IGab065h
KP1IL6H0EVeS09J]X`1eS880GWE[04aSF@1?IU`0AUiA04ALC`1:HUD0Bf=F04MODP19H5H0CfIL07jE
R`1FKFD0@UUA045HD01>Iel0BV5K04MNF01@If40DFQP04UPF@11F500?eI>03aCB`0303aCB@0;03mG
BP11FD`0?eE803mEB010ETT0>4a00396>P0hBSh0:S/_02De:P0W=b`00P0[>2l06`0/?380<d<m02m0
>P0/?CL0<T<m03I5@00c@Sl0:CPe02<b;`0R<Bh0:3Ld02/j=`0[>CT0:SHg01/V:00T;c<09C0f02Ha
=`0]=Sl09c0g02@]=00Q:Bl072@W01dU:00O:2H07BPP01lX8`0201hY8`0801lZ9P0Q;2P062@P018N
6P0K9b@04QhL01XV900J8b4201/Q7`0G01LM6`0E6aT05adK01XP7P0G7A/061hL01`R800H7Q`05adK
01dR7P0C618061dI02@Y900P9Al06QlJ01DJ5P0J7aT09R/V02<X900J7aT06QlK01lQ7P0L7Q/00P0I
6aP01P0G6aX061/J024S8P0O8B006adK01HH5@805QHD0P0G61<01`0F5a8051D@01@E400C50l061TD
01LH4`0D5A000P0B4`h04P0C514030dA024T:@0C51T030dA00h?4`0F5QL05QHF01@C4@0C4Ph05A@@
01LE400G50l071/G00l>2P0;2PH030/701HE4@803`h:01l03Pd900l>2P0:2@D04Q4=00/:1P0<2`T0
5A@B01LF500D4a404A0>00h=2`0F5A<051<A010?3@0G5Q@0;Rd[00l>300:20T04a4B00d;300;2@X0
4@l@010>3`0C4A804@l@00d;300B41403`d>00P61`0?3@h03P`=00803@/<0P0;2@X0200?3@h020H7
014?40091`P05aDF010>3`091@@04`l>0P0?2`X05@0G4a803`/:00h:2@0=2@P03PX9010<2`0>2PT0
30P7014;2`0C2P/040X:00h72@0<0`H02@<501@=3P0A20T04P`<00/40`0D30T0510>01@@3`0200l;
2P0@010<2`0>2PT030P700h:2@0B3Pd061@C01DA400?2`X02PH6010<3@0C3a0020@500`82@091@H0
4`l@00L3108040`=02P05A4B00L3100=2@X04@d>00P41@0A3@h02@D6018>3`0=2@X061@E01LC500:
1PL030P900T51P0810D02@D600l;300A3@h06ADF03Da<P0:1PL01`<400h:2`0D41403PX;00/8200>
2P/01P@500T61`0;1`P040h?00T71`050@807A/L00h;300D41400@00024M7P090`D02P@60P0?2@/2
00`6200?01<=3`0=1`T02@<500l92`0B30h03`T;010:3004000050h@00L10`0A2`d0100001<=3`0;
1@L05@lA00803`T;00<030H800/51`0>20X00P0A2`d01P0>20X03@@701072P0@1`X03`H901052@80
3`@85?ooool001_ooooo00T05QLI01<D5P0:2`d05AHH00h?4@0E5QP04a@F01LH6P0A4Q@00P0=3Q00
3@0;30h04a@F014B4`0H6QT08B8T01`N7P0=3`h02``>01hO800_<C005AHG01<D5P0B51<00P0A4a82
010B4@803a4@00<04A<B01@F5@0C5A@00P0>40l0900@4Q405aTF00/=2P0A4a0030h;00h@3@0@4Pl0
3Q0=00/=2P0>40d03@l<00`>2`0?4@h0410>00d=2`0>3P`0410>00l@2`0>3`X0414;00l@2P0>3`T0
3Pl800l@2P0A4`d03a4<00/=200=3`X03a4<00h@2`0?4@`04Q@?014C3P0>40/02`d800d?2P803a0;
02P04A8=018C3P0A4Pd03a0;00d>2@0>3`X04Q<>01@E400B4`h03Pl:00lA30062@800`H000lB2`0<
3`P02`h700lB2`0<3`P03A09018E3P0;3PL02Pd600lA3@0210403a4?00h@3@0J71T02`d802<V7`0I
71D03Q49018E3P0E60l03a89018C3@020`009bPS024R7@092PD04Q8@0P0>3P`03P0@40h04A4A00l?
3@0;2`X04A<@00`>2`0A4a0071hK00X<2@0;3@X04A<@00lA3P0=3``03Q0=0P0@4Pl05@0=3`h03Q0?
00d?3P0=3`h04Q@C01<E500I6aX0418A01DG5P0C5A@030h=01TK6P0C5A803Q0=014C400B51403Q0=
01@F4`0>40d04A<@01<E4P02018D4@0701<E4P0B51403Q0=00lA3P0H6QL03a4>00d?3006010B3`80
30h;01<03Q0=00lA3P0>40d02`d:00lA3P0@4Pl03@l<00lA3P0A4a003Q0=01@F4@0B50l051HA00h@
2`0<3PT04A<>01<E400?4@`03Q0;0080418=01403a4<01DG4P0@4Pd02@/603@f<@000P0061XE010B
3@0B50l04A<>00h@2`0?4@`04A<>00d?2P0>40/03a4<014C3P0201<E400k01@F4@0?4@`04aD@014C
3P0@4Pd05ALD01dN800I6Q`03@l>01@F4`0F61D05APB00L:0`0B5@`04aH;00X=0P0G6`d03a49018D
4@0B50l03a8:01<F2`0B5@X041<800d@1@0>4@H051L?0001000W:BH02`d901DH4@0?4P/04aH=01LJ
4@0H6a802`h401<F3@0K7QD05QT@00L:0`0B5@h03Q4:018E3P0A50d041<<01DH4@0D5a004aH?02<V
7`0F6A8010L001<F3`0H6a@030h9010B3@0G6A@02P`701dO6P0?4P/00P0E60l0500D5`h04aH;01<F
2`0D5``03Q<<03Hk=00`=Bh03Q<<01dR6`0C614061dF01DJ4`0C61404QL@01<H4@0G71D05a`F01@I
4`0B5a4051TC0`0F6aD00`0D6A<04aPB01DJ500201HK5@0>01LL5P0I7QP06QlI01TN600G7AL05A`E
01lY8@22S8@0_lW102D_9`0E7aL05R0H01XS7P0G81/201@M600501LP6`0I8Qd06R<N01lX8`0E7QT0
0P0H8A`0?@0N:B<072PT01`[9P0B8A`072/V02He<00P;bX08c8]01/Z9@0C8Qd07B`W01h]:00O;RT0
8C0]028a;P0Z>CH0:3Lg020`<00W=cL0:CXj02Dg=`0S=cH0:Sdm02Di>00Z?Sl0BE]O03a>D00dB4T0
<DA502a0@@0Z?Sl09c/l0396A`0_@d80;T9202a0@@0U>CX09S/o03=8C@0^@dP0<DI;041EFP0hCE80
=T]@041EFP0nDeP0=DY?03aAEP11EU/0@UML03eBE`15FUl0Efaa055VJ`0nDeP0?55F03mDF@16Ff00
AeaQ04EJG`14FE`00`16Fe`02@17G5d0B5eN04AIFP11EUL0@eQI049HEP10EU@0@EME04AJF00204MM
F`0804AJF012F5D0A5YG04QNF`16G5T0BEmL04]QG`16G5X204MMF`1[04YPGP1;HEh0AUaI06ImM`1Q
N780@5MA04AKE@1:HE/0D6MQ05I/J@1DJVL0CfQU04iWI01GKFX0FW1]05M]JP1PMg40HgQc0725P01N
Lfd0FVmZ05U^I`1XOGL0GW=/05ebJ`1SMg00FVeY05ebK@1QMG00DfIT07b@SP1LKfd0Jgem06EhM`1Y
OG`0Igih069jM01NN6l0H7M_05igKP1KMF`0HGQ`061hL01LMVd0G7=[05eeK`1QN780Jh9l07:7P@1T
NG80G75Z05]`J@1DJF80G75X05Y`I@1KLFD0EfeQ04YPE016G500BV1D04eRF@16Fe80B5eD05AZHP1F
KFD0b>;I08fVX01:Hed0A5eG04QRG01BJfD0AeiF05I]I@1AJ5h0>e9904AKD@15G580?EA:03iEB`0m
E4X0@EQ>03aCB@13Fdh0?5A604ALCP0cBcd0=T`o03A:?@0`A3P0<D@h02Pi;`0T=B/09cH_02/j=@0/
>cH0:chh02Lj=00V>C<0;3lk03A4@@0dA4<09CDd02/i>P0R<340<3i1020^<@0^>Cd00P0S;Bh06@0Z
=3H082X/02`f>012BTd07RHY01XR9@0S:bh02Q8D01DM7`0P:RP0<Chg01TT7P0Q;2H06RDO02lj=00L
9b408B`V01/V800R;2L07bPU01HO700K8al06b0L01TN6P0H7AT00P0F6aL07P0G71P061dI01XO6`0K
81`061dI01HK5`0=4`l0A4Y601TO7@0[<Bh0JFm[01LM6P0P9R@05adI01/Q7P0E6aT05adI014G500L
7Q/06Q`I018G500O8b804ALG01<H6@0e>CX0_/;302h_<00Y:BT051<A01PG50H05ADC00`0410>00l?
3@0E5A<04A4?00h>300R8b40IFMV02/_;P0@4Q403a4@01@F5@0@40l201<C4@0601<B400B4@l04a4=
01@@3@0B4@l04A0>0P0@3`d0100A40h04Q4?01@C4@0D4a44014@3P0@018@4@0F51D01P@501XH6@0D
4Q<04a4B01HD5@0=2``03P`=01HD5@0G5AH03P`=00/:200?3P`04a8@00T81P803@`:00H02`X800d<
2P0@3`d040l=00h=2`0=30X6014=30803@T800P03PX9010<2`0A3@`04@d<00`81`0=2@P03PX900l;
2P8040`;1P0?2`X0300?2`P04@`900l;200=20P03PP800h:2@0;1PD040/800l;200=2@H03PT6010<
2P8030P700/04@d<010<2`0?2`X03`/:014=300810<08alN03Hb<@0I5A@02PH500`81`0200/71P0?
010<2`0>2PT03`/:00L30P0F4Q403`/:01@@3`0300003`/;014=3P050@803`/<01XF5`0?2``040`=
00807QXK0P0=2@X200l;300S00L3100A3@h02PH7014=3P0B3Pl02`L800h:2`0B3Pl02PH7010<3@0<
20T02`L800`82@0<1`T02P@600T51P0<1`P03PP:00d92P0>2@X03PP:00d92P0>20X02@<500h82P0:
10H04P`>014;3@0=1`T03`T;00h82P0<1PP03`T;01LA4`0U7b401P0=1`/01`090`L03PP<014;3`0@
2Ph03PP<00d72`0<0`H00P0?1PT0100=10L03PD801462P0>0`L201<8300301052@0B1`/050T=01Co
oooo000Kooooo`803PlA00H03@h@014B500D5AL02P/=00h?4@0A4Q@200h?4@0=014B500=3Q004Q@C
00h@3`0@4Q4051HE01DG5P0A4a803@l>00lA400F61L03Q0?01<E5002014C4P80418A0P0?4A002@0>
40l03a4@014C4P0@4Q403Q0?010B4@0A4a80@dE201@F4`02010B3`0?014C400;3@/03Q0=00`>2`0?
4@h03Q0=00`>2`0?4@h03Ph<00l?3@0A4@l04a<A00l@2`0;30L03a0:00803Pl900<04149014B2P0@
4P/00`0?4@`200h@2`09010B3@0B50l04A<>00h@2`0=3`X03a4<010B3@0?40/0414<00<04A8=02@0
4Q<>014B3@0?40/03Pl:00l@2`0A4Pd05ALA00lB2`0>4@X06A`E01<F3`0>4@X041<<00lB2`0>4@X0
30l800hA2P0K7QL0EUQD01lQ800A4a8020X700/=2P0?4@`05APA014D3@0=40L041<:018E300@4`P0
2@X701HG4@0?40/04Q<>020Q700;2`T2010@3P804Q8B01`04A4A010@400=3``05ALD018D4@072@H0
2P`9014C400>40d0418?01@F4`0B51404A<@010B3`0<3Pd03Q0?018D4`0C5A@04A<B00h@3`0@4Q40
3@l>00`>3@0E5aH04Q@C00D71P0C5A803a4>0P0A4a001@0?4@h04aDB00d?300@4Pl04Q@A0080418?
00D04A<@05UKF019BdP05QPE00d?300200h@3@H0418?00T03a4>00h@3@0@4Pl04A<@010B3`0=3``0
3Q0=018D4@0A4a000P0C5A804P0?4@h07R0K01HH4`0C5A003Q0;00lA300F61<03a4<014C3P0D5Q40
5QPC014C3P0>40/03a4=01DG4P0J71L0?d4l00lA30805ALB00`03Q0;00d?2P0A4`h04Q@?014C3P0K
7AP05ALB010B3@0=3`X03Q0;00lA300Z;2L2010B3@0h01@F4@0A4`h04Q@C01XK7P0F5aX03@l?01<E
4P0D5Q<041<=00X=1P0H6a804QD:00T=0@0D5`/03a4:01DG500E5a804A@<01<F2`0A5@L03Q8401TM
3`0E60d04A@<01`N6@1>D4d07R0K014D2`0@4`X04A@;010C2P0B5@`08bHM028U700A50`04A@;01DH
3`0C5Pd04QD>01DH4@0C5Pl04QD>01DH4@0C5Pl04A@=01<F3`0D5a006ahG018E3P0_<R/08B<N01DG
4P0@4Pd03a4=01XL5`0E614201HI400G01DH3`0E60d05AP=01HI3P0J7aP051TB01hS700Q9Ql04aPA
01LL5@0E6Q<04aPA01DJ4`0F6a@04aPA01@I4P0G71H061dG01HK5@0D6A<05AXD01PM5`0F6aD00P0C
61801@0E6Q@05Q/E01DJ500D6A<05Q/E008061dG00`061hG01HM5P0H8QX0=3hf04==A@0I91`06bHN
01`W7`0J8ah06B8M01PQ700I8Qd201XS7P0>01LP6`0M9R406B8M01lX8`0J8ah072LQ01hZ9P0R<B`0
6RTT01`[9P0P;bX06bXU01PW8P0S<Rd201h]:00V02@c;P0M;2L07R`/02hn?@0T=3<08S8a024c<`0b
A4@0:3Xl02Tm?P0U>CX09cXn02Hk?P0bAdX0;3m50313B@0cAT`0=DQ>02i1AP0Z?D80:ci302<f>`0_
@TD0;D5402Xm@P0dAd/0<TM:02e2AP0hCE40Bf1T0356BP0iCU80>e1D03iCE`0iCU80>e1D03iCE`0k
D5@203Y?E00A041EFP14FEh0@EIK03mDF@0nDeP0?eAI04EJG`17G640AU]P04EJG015FeT0A5YH049H
EP10EU@0?eEC03iDDP0mDe400P0oEE<00`10EU@0@UQF04EKF@0204ILF@0704QNF`1:H5d0B5iK04QN
F`16G5T0B5iK04UOG00304EKF00>04UOG01:H5d0FW1]06EkN01;HEh0@UQE04EKF019Ge`0CVAQ05E[
J01IKf`0EVm/05A]JP1JL6d205]aKP0406EjM@1QMW40IGYe05Q[I@<0Gg9/00h0HWI^05]^I`1PLfd0
FVeX05U/I`1NLFh0J7]h08RKV01WNWT0K7im069eM01SMgH0Igii06=kM@80HGUc05/0H7Qb05ifL01R
NW@0HWYd05ifL01LM6h0GWI`06=jM01QMW40HgQc065fL01NLf`0Fg1Y05aaJ@1KL6L0E6UO059XG01@
IUX0AeeA04AJCP1:GeH0EfaS05=XG`1=HUX0CfEM055XH01@JF80F75Z04QQF`19I5l0Af9M04QSG016
GE@0AUeC04=JD018GeD0AEaB03YAA`0nED/0>E1603YAA`11F4h0>e9804=KCP1:HeH0BF=D03E?@00c
BSd0;dDh02e3=P0V>Rl093D/02Df;P0[>SD0;chk02hn>`0/@3/0;T8m0314?`0cAT<0;d0o02`m?00S
<c<09cDg028`<P0a?d809S@h038m@P0]=SL082TY020X:@0[=3@0<3Ti020X:@0M9BH06b@T01@K700L
92D07bPX01LR7`0W=2d04QlH01`X8P0N:B<0=3li020Z900T;BP07bPS01`T7`0M8al05adI00806AhJ
00<061dI01LL600G71P00P0G71P0;00F6aL061dI01XO6`0I7QX061dI01HL6@0K8Al05Q`J01dS8@0B
61H06b4O01LM6`0E6aT0728P00hD4P0H7Q`0=C/h01`N6`0H6QD06b0M02L];@0H7Qh05AXM01PM8010
ADP07AhP014?400H5aD05aDA01/J600J6QP061PF01LG5@0H61H06QXH01@D4P0E5A<04Q8@01LG5@0Q
8Al071dK02d_;00@5A405QPE0P0@4Pl00`0A4@l05QHD01@D4P02018A3`0301DB4@0G4a804A0>00@0
4a8@00<04A0>01@C4@0C4Q000`0A40h0200B4@l03P`=010>3`0M6a`05Q@E01<A4P0?3@h04a4B0P0?
3@h02`0B41404a4B00d;300E51804a8@04M6A00m?3X03@`:010?3@0>3@/03`h<00@040l=1P0@30/0
1`0B3Pd03`/:00h:2@0A3@`05Q8A01TE500@30/00P0?2`X200h:2@0300d9200?2`X03`/:00@03`/:
00<03`/8010<2@0?2`P00P0=2@H0400>2PL03`/8014=2P0@30T03PX700l;200@30X03PX9010<2`0C
3`h03@T800`81`0?2`X02`L600`81`0A3@`200l;2P0500h:2@0D40l061@C010<2`0=2@P0100@30/0
300=2@P04@d<01<?3P0C3`l08AdN018>3`0?2``0510A00T51P0>2P/05A4B01PD5@803`/<00H03PX;
00`82@0>2P/03@T:00l;300E4A8200`82@0801PD5@0U8B803@T:00D10P0=2@X030H800d72@0>20X2
00`62003010:300>20X03PP:00@03PP:00D04P`>01D?4@0>20X04P`>010:300200d72@803PP:00<0
30H800d72@0@2P`01P0=1`/00`0>20`030H:00/52@0200d72`0400`62P0>0`L04@H:01052@803`@8
00L040D901<9300<0PD04@H:00l4200B1`/040L901Cooooo000Kooooo`0600d>400C51H05QLI00h?
4@0L7Al03a0B0P0C51H0100>3a40414C014B500;30h200h@3`0600`>3@0;3@`03Q0?018D4`0E5aH0
4A<B0`0=3`h00`082PT03a4@00h@3`0200h@3`803@l>0P0>40l0400=3`h03Q0?010B4@0B51<030h;
00lA3P0F61D0418?01DG500F61D03Q0=00`>2`0@4Pl03Q0=00`>2`0?4@h200h>3004010@3P0B4Q00
3a0;00`=20803@h801`03Pl9010A2@0B4`/03a0:00lA300B50l0418=00/=200<3PT06adH024S7P0H
6QD03@l:00h@2`0F61<05aPC00l@2`0>3`X03a0;010A300B4`h04a@?014B3@0>3`X030d800h?2P0A
4Pd04aD?0P0>4@X04@0E61404A@=00d@2@0=40T03a8;018E3P0A50d03Q4:01<F3`0Q8al01`T8010B
4@082PL03a4>00/=2@0;3PL030l800<03Q4800T03a8801TJ500C50h01PL203@e<0000@007QhL00d=
2`0>3P`00`0>3Ph03P0A4A4020X700d?300C5A807AlL01@F4`0@4Q002`d:014C400F61D04A<@00h@
3@0A4a004aDD0P0@4Q402`0A4a803a4@018D4`0G6AP04A<B00P:2@0G6AP04aDD00T;2P0C5A804A<@
00<0418?00@04A<@00`>2`0?4@h0418?0P0>40d01`0?4@h02P`900h@3@000@004A<@01<E4P0J71T0
1P0?4@h00`0A4a00418?00lA3P02010B3`0300d?300@4Pl04aDB00804A<@00<0418?00`>2`0>40/0
0P0;3@P04P0?4@`06Q`G024S7P0I6aH0418=00`>2@0=3`X03a4<010B3@0>3``05QPC01hP6`0A4`h0
0P@00001000A4`h03Q0;00d?2P803a4<00<03Q0;01<E400?4@`00P0=3`X0100?4@`0418=01DG4P0D
5Q42014C3P0>01lQ700P8R0051HE018D4`0=3``0418?018D3`0?4@/03Q4:01LJ4`0@4`X04A@901LJ
4@0?4P/201<E400H018E3@0B5@`04A@9014E1`0=40D020/201<F3P0620<071hK01@F400;3PD041<:
018E300D5`h041<:01<F3@0A50/05AP?018E300G6Q40?D0g01HI4P0G6Q<05APA0P0C5Pl02P0B5@h0
20/401lR6`0?4P/02Pd601PK5013ASl05QPC00T;1P0@4Pd200h@2`0N01<F3`0F6A005QT@01DH3`0E
60d05QT>01PK400F6a@04aPA01DJ4`0H7AH05Q/D01<H4@0B5a004AH?01/P6@0O91d05Q/D018G400G
71H0724K01XO6@0D6A<04aPB01PM5`0G71H05AXD01@I4`0F6aD061dG0P0G71H201PM5`0_01LL5P0G
7AH05A`E018L500F81P04adE01LR6P0E81P05R4I01PQ700I8Qd06R<N01/T7`0J8ah06B8M01XS7P0O
:2<072DP01lX8`0K91l09C0Z01/W8`0P;bX06bXU01`[9P0P;bX07bhY02Xi=00Y>3<08C0[01d/9`0`
?cX0:CPc02dk>`0Z>ST062PW02Ph=`0R=3@0:C/k02Hh>P0Y?Ch0:3`m02`o@`0Y?T40<DI90395B`0^
@DL00`0/?dD0700]@4H0<4=:03A7CP0X>d80=TU@03Y=E00V>Cl0=4U<0356B@0cB4/0>e1C024f>@0k
D5<0AeaO04=HF`0eBTd0=da?03E:C@0hCE40>4eB03]@E@15FUl0?eAI03iCF013F5d0@5EJ03mDF@13
F5d204IKH00404IKG@15FeT0@eUG041FE080?UAB00`0?E=A03iDDP0oEE<0?UAB041FE013FEL0AeeJ
04EKF014FUL0BV1M04eSH018GU/204=IEP0904EKF017GEX0AUaI04MMFP0mDe00C69O04UOG01?IF80
AUaI0080AeeJ00D0C69O04mUHP1AIf@0EfeZ05Y`K@0205A]JP0<05Q^J`1KLFh0Fg5^061eL01SN7<0
G75/05IYH`1PLfd0HGA^05a_J@1TN6l0GW9Y0P1JKVD02`1WNW@0HGA^059UH@1ZOGT0H7=`06YmN`1Y
O7X0KH5o06UnN@1UO7H0HgYd0080I7]e01@0HWUc06=jM01RNG<0GWE_05acK@1OMW00HgYd06MlM`1Q
MW00IW]d06AiLP1JKfL0GW=Z07Z?QP1QMf`0CVAH04UOD`16G500BEmC055VG@80FVmV04D0E6UP04mU
G@1>IEd0CfUP04QQFP1EKVP0Af9M04IQG00oFU<0BV5H05YaI`1EK680HWU_03YAA`0oET`0>4m5059Y
G`24Vi40MXf303A;@@0hD4<0>51203M?@@0]ACL0;dDi02]1=@0]@cL07S8X020a:@0T=Bd0;chi03M6
@`0hB4D0<4A00395@`0eB4H0;d9002@d<`0P<2l08S8b02@b<`0U<c<0<Cm002Le=P0]>3X08R`/02Xc
<P0U;Rd08BXY02@];00D7A`04a`K01XS8P0[=3<06b@S00`E500H8al08BhW01DR6`0M:B808B`V034l
=P0M9b408b`W024Z9@0E7AP07B<O01XP700G7AT00`0F6aL0<`0G71P061dI01PM6@0H7AT06AhJ01XO
6`0I7QX061dI01dR7`0K8Al01P`:01PN700G7A/07bDS01@J600;4@l06R0N01dS8@0L8R005A/H01hP
7@0H6QD04AHB01LM7@0S:BT06QlR01DJ7@062`h06a`M014?400P7ad06AHC01XI5`0G5aD04a<A018B
400D518061PF01DE4`0N7Q`092@R01@D4P092@L03a0>00h@3@0730P06A/H01LI5P0D5Q<05ADC010@
3P03018A3`04018?3P0A3@`04A0>01<B40805QDC00@04a8@014@3P0B4@l04Q4?0P0@3`d0500A40h0
4Q4?00h<3@0F51D0B4I702HT9@0L6Q/03P`=010>3`0A3a0040h?00l=3P0>30d03`d>00l>300B4@l0
8B0N01PG5@0>3@/020L50`0>3@/200l>3003010?3@0?2`X03`/:00@03`/:00L0510?014=300@30/0
4Ph=01DA400F4Q4040`;00<03`/:0P0>2PT600l;2P0300h:1`0@30T03`/800803@T602L03`/8014=
2P0@30T03`/800h:1`0?2`P03@T700/71P0?2`X040`;00`81`0A3@`08QhM00T5100400003PX900d9
200D40l03PX901HB4@0K5aH04@d<00/71P0?2`X05A4@02TU900E4A0040`;00/71P0J5QD01@4100d9
2P0@30d04`l@00l;30060P<02PH700l;300B3Pl00`0>2P/03P0?2``02PH700d92P0H51D030P904Y6
A`0N6Q/01P8300<0000>2P/06ADF014=3P0<1PP03@L90P0>20X00`0?2@/04`d?00h82P0500h82P0<
01H@4P0H4Q@03@L9010:300?2@/03@L900/51`0=1`T03`T;00h82P0<1PP03@L91P0=1`/02@0>20`0
2@<700`62P0D3Q806A<G01D?4`0?10P04PL;01462P0200l4200701052@0I3Q804`P<01dB5P0C20`0
30<501`A5@0Dooooo`006oooool01@082@/03a0B018C5@051PP051DG00804A8D00P04Q<E00h?4@0>
3a40414C00/<3P0;3@`03Q0?00lA40803@l>00P0418A00430P0F61L05QPG00lA400A4a8051HE00lA
40<03Q0?0P0=3`h0100:30/02@/:00X<2`0<3Pd200d?3P0@00lA3P0@4Pl03@l<0001000>40d05aTF
00h@3@0=3``04A<@00lA3P0<3P/03a4>014A3`0=3@/030`:00l?3@80414<0P0=3PP04@0>3`T04149
018C2`0?40X03a4<018D3`0@4Pd02`d800`>2@0A4`h04Q@?00h@2`0;3@P0418=01PJ5@0G6A@0414<
00803a0;00<0414<018C3P0A4Pd00P0?40/0100>3`X03a0;00l@2`0?4@/200/>1`<03Q4:03H041<<
014D3@0A50d04A@=010C300<3`P01@L301DG50092`P01`T600`>2`0@4Pd030l800hA2P0A50d03Q48
00d@1`0>4@P020T300<4000L7AP0LG9]01TJ5@0;2`X03@d;00h>300@41003@d=00h>3P0B4Q804Q@A
00lA3P092`T030h;0001000U9b@030h;010B3`0B514030h;00/=2P0A4a003@l>00/=300@4Q404Q@C
00/=300<3Pd03@l>00lA40092`X06A/J00d?3P0C5A@200lA3P8030h;00<03@l<00`>2`0<3P/00P0?
4@h01P0>40d03@l<00h@3@0I6aP03Q0=01@F4`803Q0=00<05QPE00lA3P0?4@h0100?4@h00`0A4a00
3a4>00h@3@0200lA3P0700`>2`0B51404Q@A00h@3@0B51405QPE01@F4`02018D3`03010B3@0A4`h0
5QPC008061XE00<03Q0;00X<1`0;3@P00P0>40/01`0F61<02`d800L9100D5Q405aTD01DG4P0?4@`0
0P0F61<01P0?4@`03Q0;010B3@0;3@P03@l:00lA30<04A<>02d03Q0;01DG4P0C5A003@l:01DG4P0H
6QH04A<@010B3`0=3`X0418=014C3P0?4@`03@l:00lA300@4``05AP?01LJ4`0?4P`03Q0;00lA300B
5@d04A@;014D2@0B5@X03a8700/>1@0H6a<03A09018D3`0C5Q002@`3014D2`0?4PT06A`C00hA200M
81L06A`C014D2`0@4`X03a8901@G3P0G6Q<05QTB01DH4@0D5a000P0B5@h03@0@4``04QD>018E3P0L
7aP04QD>0413?00A4`h03a4<02PZ9@0I6aH04Q@?01HI4P0F6A000P0E60l0700F6@h05aX?01PK400A
5Pl06AhG01LL5@0A5Pl05AXC01@I4P0K81T04QL@01<H4@0F6a@041D>01LL5@0F6aD0724K01XO6@0E
6Q@04aPB01PM5`0I7QP05a`F01HK5@0H7AL06QlI01TN600G71H201PM5`0<01TN600J81X06R4J01HP
600K9Ad08bdU01PS6`0D7aL03QTA01HO6P0H8A`06B8M0P0J8ah0@00I8Qd07BHQ01/T7`0O:2<0:C8]
01`U800G8Q`07b/W01d/9`0H9b806RTT020_:P0Q<2/09SD`01TX8`0O;RT0;Sdh02`k=P0M;2L07R`/
02/k>P0R<S409CDd01la<@0/?Sh09SPj02Hj>`0Y?Ch0<dI:02Tn@@0Z?d80;d9602Xm@@0X>cl0:ci4
03=6C@0gBU40<TE=02/mA`0_@D/0<dEA0312CP0^@4X0?eAF0:Fj^`1WO7d0<dQ902Tn?`0nDe@0D6EV
04AIFP0fBd`0?E9C049GF016Fel0>4eB03Y?E017G640@eQM041EFP13F5d0@EIK041EFP13F5d204IK
H00]04=HFP10EU@0?eEC03mED`0nE580?eEC041FE012F5H0@eUG049HEP11EeD0@eUG04QNF`17GEX0
AE]H04UOG01:H5d0A5YG03mEDP12F5D0AE]H04QNF`1:H5d0Bf5N04EKF@1@IV@0CF=Q059XIP17GE/0
DFMU04aRH01DJVP0FFm]05Q^K01JL6h0F6i/05I_K01HLFh0GWAa065gM01RN7D0H7E`06IkMP1KL6/0
G6mY0080GW5[00`0HGA^05eaJ01OLfP0Ef]P05mcJ020U8/0M8Qo05IYH`1VNG<0J7]f06f0O01ZOGT2
06UnN@0H06ElMP1TNgD0IWeg06MnN01UO7H0HgYd065hLP1MM6h0Fg9/05ieK`1SNW@0Jh1i06AiLP1X
OGH0IW]d05Y_I`1KL6L0IG]_05=YG@18GU80AUa?04MMD01<HUD0D6IJ0P1>I5P0<01>HeX0BV1G04IM
D`1=Ieh0B65J07^DSP1FLFX0BVEN04AOF01gSXD0BF1F04IMD`1RNFl0>E16041GC@13FU00=di404UP
EP1:HEL0=Te304EMD00jD4<0>Dm30398?00_A3X08cL^02Di<00W>3408S<]02<d;P0]?3T0=TE203Q8
A@0bAD<0<49203=5A@0^@4009CDd02@d<`0X=SH08S0`02<b;`0Z=SH07b/[01hZ:P0T;Rd09Bh]02Tb
<@805b0O01<04a`K010I600I8R40>D9102D^;@0M9RD0;3Lc02<`:@0K:2406RHO01<N600G8Q`051hH
02L`:`0S;2L05QdI01`R7P0I7a/05a`H00805Q/G00D05a`H01PM6@0I7QX06b0L01`Q7@0201/P700P
01TN6P0G71P05Q`I010F500Y;bd07B<Q020V900A5aD0;38`01dS8@0I7ad03A<A018H5P0Y;b`07R0M
01@F4@0C61@02@l?010F5P0@5AP04QLJ01XO8P0D5QH05Q@E01XI5`0C40d061LE01DE4`0B4Q004A4?
01<C4@0F5Q@2018B400<00d=2`0P81h0<C4_01TJ5`0G6AH051TE010B3`0E5a@03@l<01TI5`0>3P`0
4a<A0P0G5Q@0100C4@l03`/:014@3P0C4Q0201HE4`0401<B400A40h04A0>014@3P8040l=00/04A0>
018A3`0<2P/040h?03lm?P0M6a`05aDF00`:2`0A3a004a4B018@4@0200l=3P08010>3`0>3@/04Q4?
00X91`030P004a8@00X91`0<2`T200d<2P<03Pd;1P0?2`X301<?3P04018>3@0?2`X03`/:00h:2@80
3`/:0`0@30/600l;2P0700h:1`0?2`P03`/800d91P0>2PL03`/8010<2@0200h:1`803`/801l03PX8
00`81`0=2@P03@T800X61@0B3Pd0:BDT014=30091@@04@d<00`81`0>2PT02@D501<?3P0D40l03`/:
00h:2@0=2@P02PH501`H5`0<20L03@T800h:2@0O6aX06aLG014=3P050@804`l@02@P8@0N6Q/03PX;
00804@d>00`03@T:00h:2`0?2``03`/<00L310091@H0510A00P41@15@D804Ph?00/7200E4A82014=
3P0700T51P0<1PP03PP:00l92`0>20X03`T;01<=3`0600h82P04014;3@0D3Q002P@600l92`803PP:
00<02@<500X41P0:10H00P090`D00`0=1`T03@L;00d72`0400d72`0900`62P0;1@T04@/?01PB5P0J
51P050hB01052@0B1`/04@H:00803`@800L040D901@93@0900801`0001H;3`0A1PX04PL;01Cooooo
000Kooooo`0I00l@4P0>3a404Q<E014B500>3a404Q<E00/<3P0C51H03a0B00`=3`0?4180414C00d?
3`0?4A40418B010A4P0?41403Pl@018C500P8R806AXK01hO7`0D5AH03a0A014C4P02010B4@803a4@
01L03Q0?014C4P0@4Q404Q@C01@F5@0A4a803Q0?00h@3@0=3``0418?00lA3P0D5Q<030h;00d?300>
40d04aDB014C400<3P/03Q0=018B400=3@/030`:00l?3@02014B3@0600l@2P0>3`T03Pl9010A2@0A
4PX0418;0`0?4@`200h@2`0700`>2@0>40/04Q@?018D3`0>40/030h900l@2`02014B3@80414<00P0
3a0;00h?2P0>3`X03a0;010A300?40/03Pl:00d?2@803A090P0>4@X01@0@4``04aH?01<F3`0>4@X0
30l800804aH?00T03a4;01/M6@082PH06Q`H00`>2P0?4@`03a8<010B300@4``00P0>4@T05P0=40P0
3@h801DF400?40/05QLC01DF4@0B4Q003`l=01<C4@0E5AD04A4A00l?3`0C4a<04Q@A01HH5@0@4Pl0
4A<@01XL6@1jO7T03a4>010B3`0A4a0200h@3@0O014C400=3`h02`d<01TK6P0O8B004A<B00lA400[
;B`0>cdl00lA400H6QT02P`;00lA400C5A805QPE010B3`0?4@h04aDB00lA3P0>40d04A<@010B3`0>
40d03@l<00h@3@0<3P/03Q0=03Pj=`0>40d0418?00`>2`0600h@3@0301<E4P0@4Pl03Q0=00803a4>
01L03@l<010B3`0A4a003Q0=01DG500L7Q/06adJ00d?2P0A4`h03a4<010B3@0C5A004Q@?00d?2P0>
40/04A<>01<E400?4@`02`d800lA300F61<04A<>00lA3@0200h@2`0;010B3@0L7QT071hI01<E400@
4Pd04aD@00lA300A4`h04Q@?01<E400@4Pd00P0?4@`01@0:30L04aD@01@F4@0?4@`03Q0;00803a4;
01`0418<010C3@0A4`d041<=00d?2P0A4`l06A/G014C3@0?4@d04aD@00d?2@0>4@X04aH>014D2`0A
50X04QD;01XM4`0?4PT02Pd501XM5P0A50h04aH>018E300U:1l03A0701/N5@0930<04QD<0P0>4@P2
01DH3`0301@G3P0G6Q<04aH?008051L@00D04A@=018E3P0<3`P071lH01@G400201HI4P07014D3@0E
5a8061XE02la;00L7QT05QPC01<F3`0301@G3P0501DH3@0F6@h061/@01@I4P0A5Pl00P0H7AH02@0?
50d05Q/D01<H4@0A5Pl08bPQ02/`:@0K81T04QL@01DJ500201PM5`0401LL5P0E6Q@05AXD01TN6080
5Q/E00<061dG01TN600H7AL00P0G71H02P0H7AL06AhH01dS700N9Ah072HN01<M5@0L9Qh062<K01TT
700C7QH301PQ700O01TR7@0K91l072DP01DN6@0S;2L07BHQ01DN6@0P:B@0E5mI02Pd<00N;BP06RTT
01l^:@0Q<2/07bhY024`:`0S<Rd082lZ01d/9`0`?cX0JGQc07J4Q00Y>CP09CDd02Hf=@0U=cL09SPh
02Pj?00U>CX09c/l03=6BP0202Pm@00E02`o@P0]@D<0;D1302/nA00]@4L0;d9903M9E00eAe@0=dUG
03Y;FP0iBU/0>D]G03eCE02K/;00D6EU03A:B@10EUD0>Dm>049HE`0cB4P0>U1?0080AU]K00d0Bf1R
03aAEP0oE5T0@UML041EFP0mDUL0?eAI045FF`12Ee`0AU]P04MLH@15FUl0@5EG00<0>e5?00H0?59@
03eCD@10EU@0A5YH04MMF`18GU`204EKF@0:04QNG01:H5d0B5iK04QNF`17GEX0A5YG049HE@17GEX0
BEmL04YPG@80CfER00D0CVAR04QNG01=Hf40F6i/05I/JP02055WI@0N05Y`KP1PMW@0G79`05]aK`1J
L6h0FW=`05aeLP1MLg00GgEb06=iMP1QMW40IGYe05I[IP1QM6h0Gg9/05e`JP1RMVh0Gg=W05ibI`1D
J5d0DVIK06YnL`1TN6h0GW9X065eJ`1]PGT0Jgmg06aoNP1[OWT0JWmj0P1WOGP02`1YOgT0JX1k06Z0
NP1WOGL0I7Ye05meK`1MLfd0HGMb06MmN01UNW<0HgQ`0080HWM_01T0G75X05AZG`1<HUH0C69F04mU
F01;HE@0@eU<04EKCP1CJEd0Bf5E04eSE`1>I5T0B5mD04IMD`17HEL0BVAK06b6OP15H5T0A5mH051[
HP1JLFP0>E1603mFC010Edd0?EA:0080@eY@03@0AEaB03aCB@14Fe40?5=903E<@P0fBcl0<TLl0315
>`0]@3P072hY024b;P0]?ST09CDc02<c<00W=c@0;Cdj02hn?@0cADH0;Sm003A5AP0a@T80;C`l0350
@00/>cT06bTV01dZ9`0S<2/09c@^02Hb;@0]=S@05QlM01lX9P0I8R0051dK01<L6P0J8b407bPV020Y
9`0M9R@0:C8`02Lb;@0J9b007BXS01/W8@0I91h062<M01hX8`0Y<Rd08BXU01XR7@0J81`051XF0`0H
7AT201TN6P0h01XO6`0L8Ad0724M01/P700I7QX05a`H01HK5`0I7a`09B/Y01XP7P0O9B<0E5YH03a2
@00k@Cl07B<Q01DK6@0K8Al07B<Q01HL6@0?4@`07b8L01@I5@0L8R00JFm^03Tn@00=4Q@08BLW01<E
5@0E51806QTE01HC400I61D05QLC01DF4P0D5A405AHB01LH500@40d06a`H00l?300M7AX0?Slk02@U
8P0@4Pl061dI03Tk>02j_;T0TYBA01hN700A4@l05ADC01TH5P0H5aD05Q<B018>3@0A40h401<B400=
014@3P0@3`d040l=00l>300@3`d04A0>018A3`0C4A803`d>01LE5P0@3Pl04@l@01<A4P05010>3`09
014?400?3P`030/901HE4`0@3`d03Pd;00T81P0;2PP03`h<00804Q4?00<03`h<00d<2P0@30/01@0@
30/01P0A3@`04Ph=018>3@0B3Pd03`/:00d920803`/:00@040`;014=300A3@`04@d<1P0?2`X01P0=
2@H03`/800l;200=2@H03`/8010<2@803@T600/040`901<?300@30T04@d;010<2`0>2PT03@T800/7
1P0>2PT04@h=00d9200200h:2@0900T5100;1`H040`;00l;2P0>2PT03@T8014=300>2PT02`L60080
4@d<00/03`/:01@@3`0E4A00514@01@@4@0b;Rl0;b//010<3@0?2``03PX;014=3P0300l;300300h:
2`0?2``040`=00803PX;00<0510A00/7200@30d00P0=2@X0100400404`l@010=3@0>20X200l92`80
3PP:00<04@/=00h82P0>20X0100>20X01P0=1`T040X<00T31@0@2P`03PP:00`6208040X<00@03PP:
00/51`0<1PP040X<1P0=1`/04P0<1PX03@L;010:3P0A2`l03`T=00/52@0B1`/050T=01872`0@1@T0
3`@801052@0K4Q@0K65U01/B500;0@@03@<601H;3aCooooo000Kooooo`0901PI6`0;30h04Q<E02@U
9`0=3Q0030d?01<D5P0N7b4061TK00803PlA00d04a@F014B500>3a4030d?00h?4@0?41803@h@018C
5@0@4A<00@8401XK7@0B4aD01`P:00804A<B0P0@4Q4200lA400S00d?3P0>40l04A<B018D4`0;3@`0
1PP700/=2P0D5Q<05QPE00lA3P0@4Pl020X700h@3@0?4@h04aDB014C400=3``03Q0=010@3P0>3P`0
3`l=014A3`0?40/03@h9010A2`0?40X03Pl900h?1`0?40P04A<<00lA300;3@P03@l:00lA300>40/0
0P0=3`X01@0<3PT02P`700/=200>40/04A<>00<04Q<>00<03a0;00d>2@0=3PT01@0>3`X07@0=3`T0
3a8;018E3P0@4``03Q4:00`?200930D041<<018E3P0<3`P03a8;010C300?4@/04Q@?00d?2P092`H0
20X5014C3P0?4@`03@l:00/>1`0=40T03a8;00hA2P0N7aT01@H0014B3@0=3PT05aPC008030`:02@0
4A4?01HF5P0@410030`<00h>3P0:30T02`d:00`>2`0M7a`04A<@018D4@0?4@h0418?018D4@0E5a@0
51HC00lA3P0C5A@02P`;00`>3@0@4Q403@l>01PJ6@2;SH`0TI>B01PJ6@0B51<04A<B00H81`0?4@h0
4Q@A00/=2P0:30T03Q0=00X<2@0?4@h2014C400900lA3P0=3``03Q0=010B3`0D5Q<00P@100d?300=
3`d05ALD00H03Q0=00<05QPE018D4@0?4@h00P0@4Pl200lA3P0>014C400>40d03a4>010B3`0=3``0
4aD@01HH4`0@4Pd04Q@?01HH4`0D5Q404aD@00lA300>40/2010B3@<03a4<00D0008001LI500<3PT0
418=00lA3002018D3`05010B3@0>40/03Q0;014C3P0>40/00`0=3`X04`0>40/04A<>010B3@0?4@`0
2P`700h@2`0C5Pl03Q4800hA2P0A50d041<<014D3@0B50h05ALB024S800Z;2T030h;00T;200I71H0
0P0@4``0400E610041<:00lB2@0C5Pd03Q4800D8000G6Q806ahG00H90P0L7aL092LN0454>`0A50/0
6A`C00L:0@0B5@`2010C2P0E01<F3@0?4PT04QD<01DH4@0@4``04QD>01@G400?4P/04A@=01@G400G
6Q<03a8;014D3@0K7QL04QD>01HH4`0A4`h05QPC01@F4@0H6QD04aH?00804QD<00D04aH=01@G300E
60d05aX?018G400201LL5@805AXC00L041D>01XO600?50d051TB01TN5`0?50d05AXC008051TC0380
5Q/E01LL5P0F6aD04aPB01HK5@0D6A<04aPB01DJ500G71H05Q/E01hS7@0K81X05a`F01HK5@0E6a@0
51/D01HP600I8a/03aTA01hY8@0@6a<082/S01/T7`0J8ah0624L01TR7@0M9R4082TT028[9P0I8Qd0
72DP02H_:P0M9R408bhX02Hb;P0J:B@07RdX02Th<`0W=S408S4/024`:`0H9b807bhY02dl=`0`?cX0
Ohj907^9R@0M;B`0<D5002De=080:C/k01D0:S`n02Lk?00U>CX0:Se102Hk?P0]@T<0;T9202i2@`0/
@440:ci20354BP0fBE00>TaG03]=F`1bQ980FV]l03I7F@1KKG/0=DY;02Y0?P16G5X00P0eBdT02P11
EeD0?59@03A:B01FK6X0D6IT02m5@`0iCU00BUmT055VJ`13F5d303iCF006045FF`13F5d0B5eR04QM
HP14FEh0@5EG0P0nE5802P0mDe40?UAB03mED`0nE580@EME04ILFP19Ged0B5iL04MMF`18GU/204YP
G@0404QNF`17GEX0BEmL04UOG080CF=P0140Bf5N051VH`1>I640DfUW04eSH@1IKfd0Bf5O055WI@1M
Lg40DfUW05]aK`1OMG<0FFm]05]aK`1NM780IWml06EnN`0205meLP0E06QnN`1YOWT0HGIa04eRG@1P
Lfd0HWE_05mbK01KKfL0G71T05=XF@1FJUh0Cf=G055UF@1QMFX0Ig]`061dJ@1^PWT0J7ac06n2N`1c
QX00JWmj0080J7eh02L0JWmj06b1O01/PG`0Jh1k06QmN01RMg80H7E`06EjM@1[P7/0IGYc06QmM@1P
MF`0GW=Z05ebJ01<HUH0CF=G04iTE`1<HUD0AUa?04EKCP1BJ5/0CVAH04eSE`1AIe/0C69F045HC@13
FU00C6IK04YTFP12G5<0B6=L04iYHP0oFU40A5]A041GC@0iD4H0?5=904eTFP0oET`00P11F4h0=`1A
J5h0AUeC02]2>00lDDP0?5150393>`0`@CT0:CTe01LW9P0O;bl08S8b020`<00R<S40:3Pf02`l>@0]
?C`0=TQ902ln@@0eADD0;Shn02Hd=00[>SL0E6=O02di=@0R;bP06bPQ028_9P0R;BD072DR024Z9`0L
9B806b@Q01`U8P0G81d04a`I028[:00O:2D041TF028[:00Q;2L062DN01`Y8P0F8Q/05R4K01@O6@0O
:B<07bPS01HO6P0L91l0728N01HL600L8Qh06b0L01XO6`0I7QX00P0J7a/00`0I7QX05a`H01HK5`02
01DJ5P0J01HK5`0G7AX03A<A01lU8`0L8R004QPF02@Z:00W;B/051XH01XP7P0G7A/04aTG01DK600I
6aH041<<01LL5P052`L092XX02D[:`0>51@00`T901XL6P0:2@D07QdI01TG4P0F5A4501DF4@0D01`M
600?40/04Q<>01HG4P0:2`H04Q<>00X<2@0M8Qh0;S0]0<G7a02;SHX061PF018B400A4@l040l=00l>
300B3`h04`l>018A3`0A40h2010?3@03014@3P0B4@l03`h<00<03`h<01X04A0>018A3`0?3@h04a4B
00@20`0H5QL04Q0A010>3`0>30d030X;00d;300?3@h04@l@00h<3@0D4a404A0>00d<2P061@<03`h<
00L6100<2`T04Q4?01LF500F5A<04A0>00h=2`H04@d<0`0?2`X01@0A3@`0510?01DA400B3Pd04@d<
008040`;0P0>2PT600l;2P0<00`81@0?2`P03`/800d91P0?2`P04@d:00/7100>2PL04`l<01LC400C
3``03`/90P0<20L06@0B3Pd040`;00h:2@0>2PT06QHE014=300>2PT040`;00D1000<20L040`;014=
300@30/04`l>018>3@0?2`X00`00018>3@0<20L0510?00@0000?2`/01`<400h:2`0E4A800`0=2@X0
4P0;1`P03@T:018>3`0@30d03@T:00l;30050@803PX;00D10P0;1`P02PH700H20`0=2@X04@d>00H2
0`0L61T02PH700h82P803`T;0P0<1PP700h82P0900`6200A2`d02`D7014;3@0?2@/02P@600P2100:
10H03@L9008030H800<03`T;00d72`0=1`/0100=1`/04P0;1@T030H:00/52@0:10P030H:00l93@0B
1`/050T=01872`0@1@T03`@801052@0X7B40bl3402PM8@0700005``@01052ACooooo000Kooooo`0?
01<D5P0B4aD04a@F01@E5`0C51H03PlA014B500R8bD04a@F00l@4P0H6A/01`P:01DF600=3Q002``>
008030d?02h0414C014B500;30h03PlA00P92`0A4Q@051DG00h@3`0;3@`01@L601LI600=3`h03a4@
01@F5@0>40l02@/:00h@3`0A4a8030h=018D4@0?4@h0418?014C40051`@02`d:014C400620D05ALD
00h@3@0G6AH010H3014A3`0=3@/02@T700h>300B4`h03Pl:010A2`0B4`d04a@>01<D300@4@T03Q09
01LI500?4@`03@l<0P0:30L04`0D5Q403Q0;00lA300>40/03@l:00lA300B50l02``701XK5P082@@0
414<01HG4P0=3PT04Q<>010A300<3@P04Q<>01DF4@0?4@/00P0:3@H0100=40T041<<010C300>4@X3
00`?200400d@2@0>4@X03a8;00hA2P803A0901/03Q4:00lA300@4Pd03Q0;00X<1`0F61<00`D0010B
3@0?40X03@h800`=200>3`X03a0;00l?3@0>3P`05ADC01@D500>3Ph0410@00l?3`0B51402P`9010B
3`0F61D071hK00X<2@0@4Pl00P0?4@h02@0>40d03a4>010B3`0;3@`030h=00l@3`0F61L020X9010B
4@0202/];006014C4P0@4Q404Q@C010B4@0:30T03Q0=0P0<3P/00`0?4@h02`d:010B3`03010B3`03
00h@3@0=3``03a4>00D03a4>00D02`d:010B3`0@4Pl051HC00X<2@0201HH5@0Y00/=2P0<3P/06Q`I
00P91`0E5a@04aDB02<U8P0N81d051HC01HH5@0J71T0418=00h@2`0=3`X03Q0;014C3P0B50l03@l:
010B3@0?4@`04A<>010B3@0?4@`030h9014C3P0D5Q404aD@00d?2P0:30L0418=00d?2P0>40/04aD@
018D3`0?4@`04A<?018D3`092`H05ALB00h@2`092`H00P0>40/0400B50l0418=00h@2`0@4``030l6
00/>1`0E61404A@=00hA2P0>40X03@l:014C400C5A8030h;00h@3@0C5Q02010C2P0Z014D300B5@h0
4QD>018E3P0<3`P061/D00/>1P1?DTT0?T4h018E300J7A@07b8I01HI400C5Pd05AP?010C2P0?4PT0
4QD<010C2P0A50/04QD<010C300A50d05APA01LJ4`0F6A805APA00lB2`0G6Q<04QD>00X=1P0;3PL0
4QD>01XL5`0:30L05QPC01TK5P0A4`h05QTB01/N5@0J7A@05QT@0P0A50T04@0G6Pl03a@=01<H4@0G
71D051TB014F3`0B5a003Q<<01<H4@0D6A804AH?01<H4@0A5Pl03A8<01PM5`0M8Q`06AhH00805AXD
00P051TC01hS7@0N8ad06b0J01`Q6`0K81X06QlI01LL5P8061dG00`06R0J01DL5@0H8QX051hF02H`
:00/=bl07RTQ01HQ6@0N9b80624L01LP6`0K91l2024Z9@1;034j=@0P:B@06R<N01dV8@0O:2<08B`V
02<_:`0P;bX09C@_01`[9P0R<B`0<d8m02Xi=00M;2L093<^02He<00X=c80<D0k03A2@P0X>3L0;cln
02/k>P0U=cL0<49202Hh>P0Y?Ch09CTj02Dh?00T>C`08SLh02e1@@0^@T40<4A503=6BP0aA4X0<4=:
03I8D`0kCE/0[;k<07:3T`0dAEL0<TAB03aAE00/@D80<TM804IKG00iCTl0AU]L03Q=CP19GUl0>4e>
04eRH`0`ADH0=da>03aAEP11EU/0@UML03I;D016Ff00AEYO04MLH@1:Gf@0@EIK049GG016Ff00@5EG
03aBD011EeD0AE]I041FE014FUP0@EME04AJF017GE/0B5iL0080BV1N00<0BEmM055WI01CJFH00P1:
H5d204]QGP0704eSH01;HEh0BEmL04UOG01>I640CVAR059WJ00205I[K00305M/K@1MLW<0FFi_0080
FVm`01D0FFi_05Y_L01OM7D0K8F2061iMP1PMW<0GG=`069hM@1RMg80GgA_065fL@1OLV`0GG1Z065d
KP1QMFd0G71T05]`H@1GJel0DfMK05M[G`1SMf`00P1RMV/01`1VNW40Jgmf06f0N@1ZOGL0J7eh06Un
N@1ZOgX00`1[P7/03`1bQh80KH9m06UnN@1YOWT0JWmj06QmN01YOWL0GgA[06=hK`1TNVh0EVaP04eS
E`1=HeH0CVAG04]QE00204]RDP0?04MNCP1?IEP0BV1C04iTE`1>I5P0BF1C04eUF01;IEX0BVAI04MQ
EP14GeH0@UeD041KDP0mE4X0@EQ>0080?UE;0280@eY@04AKD@11F4h0@eY@051WG@1:HEL0<TTo02i3
>P0/?C<0:cXc028a;00T<c408c4b01PV:@0N;C006BP[02@d=00_?ch0;Shk03Y:B@1MKFh0:CTi03E5
A@0^?3`0938b02/j=`0R;R/082`X01l/9@0S;RL0:C@/02dh<00K92407bPU0`0L9B80400C71T05QlL
01/T8@0O:2D0624N01XS800J9B009C8[01LT7@0L:24072LQ01TT7P0L9R4072DP01XS7P0I81`201TO
6`0901dR7P0F6aL05AXF01LL600E6QH0>3di0415@@0J7a/06AhJ008061dI00<06AhJ01TN6`0H7Q`0
0P0I7ad05@0H7Q`05adK00/A3`0K8Al0728P010F500c>CL04aTF020R7@0B5@h05AXD01HL600C6AL0
318B01<I6@0A5aL04Q@B01PG4`0N7AT04@l:01PG4P0201@E3`0H01PI4`0I6Q@05aPB018C3@0V9b40
5aPB01<D3P0I6Q@04a@?00h@3@0J7a/04Q@A03@f<`0Y:bP03`l=010@3P0@3`d05A@B02<R800;20L0
510?00X91`0I61H03Pd;0P0A40h01@0B4@l03@`:018A3`0C4Q004Q4?008040l=0P0E4a@010071@H0
3@/<01HD5@0C4A82014?400601HD5@040P<03P`=00h<3@0B4@l02`X90P0920H02P0A40h01@@200/:
200>3@/03`h<00h=2`0?3P`040l=00d9200@30/2018>3@05010<2`0?2`X04@d<00d9200?2`X00P0F
4Q40200D40l08alN00d9200>2PT04`l>018>3@0C3`h04@d<0P0>2PT02P0@30/03PX900d9200H5140
2@D200d91P0B3P/02`L400X60`0A3@X200l;200300h:1`0C3``02`L500D03PX900d02`L6018>3@07
0`804`l>00X61@0>2PT04`l>014=300@30/0FUIE07YfM@0<20L04`l>00803PX900`03@T800h:2@0>
2PT03PX:00d92P0?2``040`=00l;300=2@X03PX;00/7200:1PL200h:2`0400/7200=2@X03`/<00d9
2P<030P91P0=2@X2014;3@0800l92`0<1PP030H8014;3@0@2P`03`T;00h82P0<1PP200/51`0300d7
2@0<1PP030H8008030H800/02`D7018<3P090`D03PP:00X41P0I4aD02@<500d72`0:10P0208600/5
2@0200d72`H030H:00`0304500d21P0?10P04PL;01462P0>0`L05``@02XO8`0J3a<03P<701<8300=
0PHDooooo`006oooool0500A4Q@0414C014B500B4aD0414C00d>400:2`d051DG010A4`0>3a404Q<E
00/<3P0C51L030d@00h?4P0@4A@03a0C014B5@0720/04a@G0P0?41<02P0;30l020T;00d?3P0H6QT0
418A00/=300620L0418A04M9B01HFUT200lA400600P:2@0>40l02`d:00lA3P0=3``0418?0P0>40d0
100=3``06Q`I00H81@0?4@h2010B3`0700l?3@0<30X0410>014A3`0<3@P03@h900l@2P02010A2`0<
010A2@0?40P03Q0900d?2P0:2`P051HA014C3P082PD04A<>010B3@0A4`h03Q0;0`0;3@P0500C50l0
2P/601<D3`092PD03a0;010A300A4Pd0414<00d>2@0A4Pd04Q<>010B300@4``03a8;014D3@0C5Pl0
4QD>00lB2`0=40T03Q4:0`0?4P/2010C2`0L00lB2P0>4@X03Q4:00lA2`0=3`X04Q@?00lA3@0:30T0
1`T5018D400@4@/03a0:00h?2P0@4@`04A8=014A3`0@40h05ADC01DE5@0@41004A4A010@400G6AH0
3a4>00h@3@0<3P/051HC010B3`804A<@01803a4>00h@3@0>40d03a4>00lA400J71/071hM01DG5P0=
3`h04Q@C00P:2@0C5A@02@/:00lA400@4Q402`d<00h@3@0A4a0200d?300700lA3P0;3@X04A<@014C
400B51404A<@010B3`0700lA3P0C00`>2`0B51405QPE00<50`0B514030h;00/=2P0=3``0I6IS02X/
:@0N81d092HS014C400C5A80418?018D4@0C5A803Q0=00h@2`0200lA30<0418=01404aD@00lA300?
4@`04A<>010B3@0>40/04Q@?00h@2`0<3PT03@l:014C3P0B50l03Q0;00`>2@0=3`X04A<>010B3@02
00h@2`0;01/M60082PD04aD@020R7@0A4`h051HA01<E400=3`X04A<>018D3`0@4`d00P0C5@l07P0@
4P`03Q4;014C3@0?4@`04Q@?01DG4`0A4`l0418<018D400A50`04A@:018E300B5@d04A@=010C3@0C
5Q003a4;00H90`0H6a<07b8I01DH3P0C5Pd05QT@01TL4`0A50/03a89010C2P0D5`h04QD<014D2`<0
5AP?01l04QD>01<F3`0F6A805QTB01DH4@0C5Pl04A@=018E3P0D5a0061/D03@g<00E614051HA01<E
400I6aH04Q@?01@F4@0D5a005AP?01<F3@0D5`h06ahC01dP5@0H6a003a@=018G400F6a@05AXC01<H
4@0E6Q<04AH?00805AXC05P051TB01LL5@0G71D04AH@01TN600L8A/06QlI01PM5`0J7aT051TC01TN
600G71H061dG01/P6P0H7AL03Q<=01TN600D6A<06QlI01/Q6`0C6Q<04adE01PR6P0V<2P08bhV01PS
6`0L9al072DP01XS7P0H8A`06B8M01dV8@0P:B@09c0[01lX8`0Q:RD092dX020Y900M:28082`X01`[
9P0S<Rd08S4/02Pg<P0eA3l09C@_020_:P0W=S409SD`024`:`0U=2l0:CLg02Hf=@0Y>CP0:c/j02Tk
>`0]?cl0:C/m02e1@P0Z?Sl0:Se102Xo@P0X?Ch0;41002a0?`0^@T40<DE60354B@0`@dT0<dE=0395
CP0iBeH0?U1M02`nC011Deh0<dQ;03eBEP0_A4H0=T]>05=XK017G5l0G75c08fRYP1:Gf80@eQJ04QM
H@19GV80>TmD0`11EU/02@0iCU<0AEYO03iCF00nDeP0AU]P041EFP0oE5T0@eQJ045GE@0204=IE`03
04YPGP1=Hf40AE]I0080B5iL0140AeeK04QNG01;HEl0BV1N04aRG`1>I640Bf5N04aRG`1>I640BV1M
04]QGP1AIf@0DVQU04mUHP1>I640CV=T059WJ00205U^K`0505Q]KP1IKVl0G75b05aaLP1NLg@00P1R
MgP03@1PMGH0I7ej05igM01UNgP0HGMd06=iMP1WO7L0I7Ud06EjM@1QM6h0GW5[069eK`1SMfl00P1M
LFD0101JKV<0FFeQ05]_I01TN6h206UmL`0706]nM`1^PWX0KH1k06YmN01YOGT0Jgmk06b0N`0206b0
O00J06b0N`1]PG`0K81k06b0O01]PG`0Jgmj06IjM01XOG@0Igeb06=iKP1PMVX0F6iR059XG015Fdh0
C69E04YPDP13FTX0A5];04iUE01?IUL0CVAF055WFP1@IUX0BV5D04YRE@18HUH204MQEP0704IQE`15
HEL0A5mF04MNE019H5H0A5]A04=JD00204ELDP0d04AKD@0hCdD0>e9803I=@`0^AC/0<DHm02hm=00c
@CX0;C/g02lk?@0/>Sh0934h02Le?00O;S<09C@g0351@@0_@3d0>4Q603E5A@0c@T80;3`j02Pg=00`
?C/09S<`02Hb;P0^>SD0;3Pb02<^:00S;BH09c4[024Z9@0M9R808R/W01HO6`0V;b/0>T<o01hW8`0G
81`072DQ01hW8`0M9R806bHQ01/X8@0F8a`07BTS02/f<01XLfd082XT01lX8`0L9B006B4L01LM6@80
5Q`H00T051TE01PM6@0M8Qh05a`H01hS7`0S:2@06b0L01XO6`0I7QX00P0H7AT0;00I7Q/06AlM01TO
7@0I7ad05Q`J01@J600Q9bD051XH00lE4`0P9R@03aDC018H5@0B5@l04QD=01@I4`0A5a<04aTE01HL
6P0G7A`020d;01HH5@0Q81`06QTD01DC3@0H5a805AH@01@E3`0F5a405aPB01DF400C50h07b0J01dN
600I6Q@03Pl9014C300D5Q<02Pl;01DG500@4Pl051HC01<C4@0?3`d051@B0P0@3`d08`0J61H04@d<
01LF500B4@l020L5020O7@0>3@/061LE01`K6@0C4Q0030/900d<2P0B4@l05A@B018@4@0=2``07Q`M
00h<3@0A3a004a4B07=aLP18ATL020L701/I6P0C4A801`H600H50`0B4@l02`X801TH5P0=30X051<A
00X91`0>3@/03`h<00803Pd;00<03`h<018>3@0D40l00P0F4Q401@0D40l04`l>01<?3P0B3Pd04@d<
00@040`;00<030P7014=300D40l00P0?2`X03@0A3@`03PX900h:2@0@30/03PX900d9200K5a@04Ph;
01@@3`0A3@/03@X8018>2`0=2@H00P0A3@X00`0=2@H04Ph;00/71@0500h:2@0<00l;2P0@30`0F5AC
01LC4P0?2`X04Ph=01@@3`0<20P03`/:04Y6A@1/J6L05A4A0`0>2PT01@0=2@P03PX900h:2@0?2`/0
3@T:00<030P90P0=2@X00`0?2``04@d>010<3@0200`82@0300l;300@30d03`/<00803PX;00<03`/<
00d92P0=2@X0100=2@X02`0>20X03`T;00l92`0=1`T030H800l92`0=1`T03PP:00l92`0>20X03@L9
00@030H80P0=1`T02`0>20X04`d?00X41P0?2P/05Q0B02@N800C3@l02P@800/52@0=1`/03PP<00P0
3@L;00X04PL;01462P0A1PX04PL;01052@0<0@D03@8601H;3`0C20`03`@80P0A1PXDooooo`006ooo
ool03@0D5AL04Q<E018C5@0C51H04Q<E00l@4P0=3Q003PlA01<D5P0B4aD03a0B01<D5P0F5a/00P0>
3a<0:00?41@03PlC014B5P061`/030dA00H72`0?41@030dA01DF600<3@h020X900`>3@0J71/04A<B
00T;2P0D5QD01PP7014C4P0=3`h04Q@C00h@3`0<3P/051HC00lA3P0A4a006A/H00lA3P0=3``01PP5
01TK600K7AX01`T6018D4@1:BTP0410>00X:200=3@/01@H100@5000>3`T200l@2P0M00l@200>3`L0
1`T400`>2@0L7QT0BTa703Pj=@0>40/020X500`>2@0>40/03@l:00`>2@0=3`X02`d802DV8@0=3PT0
71dH00P9100F5a803@h901@E400E5Q4051D@01<D3`0B4`h0418<00lB2`0=40T00P0>4@X02P0=40T0
30l800d@2@0@4``04QD>014D3@0?4P/04A@<018E300@4`X300hA2P0?00P:1@0E5a802P`900X<2@0U
9b@02P`9014B3@0?40X03Pl:010A300B4`h04Q8@00d=2`0?3`d03`l?00803@d=00X030`<00X<2@0:
30T04aDB00lA3P0D5Q<04aDB018D4@0A4a00418?0`0>40d03P0620L051HE01@F5@0<3Pd04A<B018D
4`0E5aH061XI00/=300?4A00418A014C4P0>40d0418?0P0<3P/01@0?4@h03@l<00`>2`0=3``03Q0=
00803@l<00<030h;00lA3P0?4@h0100?4@h03`092`P03@l<01dO700A4a004aDB01LI5P0E5a@04aDB
0001000<3P/06Q`I01@F4`0C5A803@l<00/=2P0201<E4P0300`>2`0=3`X03a4<00804A<>00h03a4<
00h@2`0@4Pd02`d800h@2`0B50l03a4<00h@2`0A4`h05QPC01TK5P0H6QD04Q@?00lA30<03Q0;0P0?
4@`09@0>40/051HA00@60@0C5A006Q`G01LI500620<061XE01TK5P0=3`X04aD@01DG4P0A4`l04A<@
00d?300=3`X05ALB014C3P0>40/07AlJ01hP6`0@4``05AP?01@G400<3`D03Q46010C2P0C5Ph04aH?
018D3`0L7QT0?d4l010B3@0>4@T03A0700T<0@0=40H00P0B5@`0100@4`X04A@;018E300D5`h200d@
1`0401HI400B5@`061/B01@G40805APA01L051L@018E3P0A50d06A`E00/>1`0F6A805aXC03/n=`0D
5a0061XE00lA300>40/03@l:01PJ5@0K7QL051L>01<F3@0G6Q4082<H028U6P0L7a@04QL@01<H4@02
01DJ4`8051TB02@05Q/D01LL5@0D6A804QL@01@I4P0A5Pl041D?01@I4`0F6aD05AXD01HK5@0I7QP0
61dG01LL5P0D6A<06AhH01hS7@0I7QP04QLA00`A2`0R9b4061dG01@J500F7AH082XR01dW7`0J91`0
51lG01<N5P0P:b<06R<N01`U800J8ah05b0K01TR7@0O:2<201PQ700<020Y900U;RT08BXU01lZ900[
=c<082lZ01h]:00L:bH06bXU01l^:@0Q<2/08S4/0P0Z>C@0;`0V=C00:3Lb02/i>@0_?ch0;3`k02dm
?00/?Sh0:C/k02Tk?@0^@T<0;41102/n@P0Z?d809c`m02Hj>P0kCdh0@EED03Y>C`0aADH0<4=70313
B00fBDl0=4M=03M:D@0_@TT0=4M>02i3B@0_@dX0>4eB04EIG`0lD5L0@5EK04QMHP1ZOXD0?e=I04ML
H@1<H6L0?eAI03A9CP1LLGH0?eAI04IKH00lDEH0AEYO04iSJ01BIf`0CF9W0080@eQM00`0AeaN045G
E@13FEL0AE]I05ecL@1RN7H0Bf5O04MMF`1<HV00CfES04YPGP1;HEl404eSH00304iTH@1@IV<0CVAQ
00<0C69O00<0CVAQ05E[J01GK6d00P1GK6d08P1HKFh0G75b06=hN@1YOWl0HWMh05Y_L01MLW<0HGIg
05mdM@1TOGX0GgQe06MmNP1RN7D0I7Yg06IkMP1TNG@0IGYe065dKP1OLV`0I7Ma06MjM01PM6/0H7AY
05mcJ01PM6T0HWI]06IjL@1YO7H0J7]e06YmN01]P7`0K7mk06UlN01[OWX406f0O00O06aoN`1[OWX0
JWei06]nNP1]P7`0Jgij06QkM@1OM6/0I7Y^05idJ01IKf<0EfeQ04iTE`1UNfh0DFMI04IMC@17GTh0
BV5@04]RD01?IUH0D6MH05=YG01AIeX0Bf9E04MODP13GE00AEmC04IPE@17HeL0BFAJ04UTF`0204EL
DP0M041GC@0oET`0@5M=03iEB`0mE4X0>4m503YAA`0dBd40:D0f02Xn=@0^>S80<Sdi02`h=P0/=c/0
;cU202/h@@0]>T<0<T5803=2A`0iBDX0<DA203I9A@0kBTH0;chk01h]:00fAD40B5A@02Hb;P0N:RH0
0P0Y=3005@0R;BP082TV024Z9@0W<2/072DP02D^:@0I8Qd092dX04=<A`0Q:RD0624L01/T7`0P:B@0
7RLR01hY8`0D8AX05B8K01PT7P0c?SP0JgI`01dW8@0201XS7P0301XQ7@0J81`06R0L00806QlK00h0
61dI01DJ5P0H7AT05Q/G01DJ5P0H7AT05a`H01TN6P0J7a/06b0L01PM6P0C6AL05A/I01LM6`8061hL
01@05Q`J01TO7@0^=380FEmM02D[:@0F71T05aXC01lR6@0F6a@03A@=00hD400J81h0728P01PN700J
71P03`h901dL5`0G5@h05aHA01DF408051D?0P0C50h0=`0I6Q@06a`F01LH4P0E5Q004Q<=01DG4@0C
5A001@X601@F4`0>40d05QPE014A3`0F5Q@040l=01PG5@0<2`T05Q@B01PD4`0@3`d05QDC00`;2@0G
5Q@020L501DD4P0C4Q0040l=018A3`0F5A<04Q4?00T81P0H5QL020H7018@4@0;2@X0518C00`:2`0k
>CX06QPI020N7`0610D0?C/l02@R8`0@3`d01PD301LF50071P@051<A00d<2P0:2@L03@`:00h=2`0=
30X030/900d<2P0>2PT00P0?2`X01P0@30/03PX900d9200A3@`0510?018>3@8030P700<03PX900l;
2P0=2@P00P0<20L00`0?2`X04`l>014=300200h:2@0?010<2`0>2PT03@T8014=2P0E4@h06aLD00P4
0P050@002PH300d91P0@30T03@T600`81@0K5a@0510>00D03PX900d03`/:01@@3`1oNgX0920O00/7
1P0@30/02PH500h:2@0F4Q401`@300d9200300004Ph=00803PX900@03@T800h:2@0>2PT03PX:1@0=
2@X01P0<20T03@T:00h:2`0;1`P030P900d92P<03`/<0P0>2P/00`0?2``03PX;00h:2`0300d92P0O
00`82@0:10H030H800h82P0=1`T030H800h82P0;1@L030H800l92`0@2P`03`T;00d72@0:10H02`D7
00`6200=1`T03PP:00l92`0400002@<501LA4`0F41805@lA018<3P0:10P02`D900X420070@D02P@8
010:3P0600h8300<00h31`0=0PH03@8600l4200@1@T03P<701@93@0>0`L04`P<01@93@0<0@D03`@8
5?ooool001_ooooo00h04A8D00h?4@0=3Q003PlA00l@4P0<3@l04A8D00l@4P0D5AL04Q<E00d>400C
51H07QlS01<D60<0414E0P0D5AT0900;31003a0D010A5@0<3A4061TK014B4`0:30/03a4@02DW9P0K
7A`03Q0?00X<2`0>40l0418A00L9200H6QT02`d<00lA3P092`P06A/H00`>2`0;3@X03Q0=00`>2`02
10406A/H00lA3P0620D04A<@01TI5`020P003Ph<01/K6@0G61<061TD010A2`803a0:00P03a08010A
2@0G61800040014C3P0@4Pl0004001TK5P803@l:00<03Q0;00d?2P0<3PT00P0>40/01P082@@0414<
05EFD@0A4Pd05QLB018C3P80414<00D04A8=00h?2P0=3PT03Q0:00d@2@0300`?20802`h702H03A09
010C300B5@h04A@=00lB2`0@4`/04QD:010C2P0>4@P03A0700d@2@0:30L02`d800/=2P1CEE@0O7im
00X<2P0A4Pd03a0:00h?2P0@4@`04Q<>018B400A4@l0410>014A4@0B4Q80410@00l?3`0:30T02`d:
014C40082PL03@l<010B3`0A4a00418?00lA3P803Q0=00l03a4>00d?3P0C5A@04A<B00h@3`0I6aX0
5ALF00h@3`0A4a802@/:010B4@0B51<05aTH00`>2`0>40d00P0;3@X00`0@4Pl03a4>00`>2`0200d?
300300h@3@0=3``030h;00H03a4>01@01PP501hO7@0;3@X05aTF00T;20072@H04A<@00lA3P0=3``0
71hK05EGE00c=C803a4>00d?30092`P03@l<010B3`0=3``03@l:00lA30804A<>00@03a4<00h@2`0?
4@`030h90P0A4`h0200;3@P030h900lA300H6QD071hI01XL5`0A4`h03@l:0`0@4Pd200lA300`010B
3@0c=C006A/F01@F4@092`H06A/F01dO6P0D5Q405aTD00h@2`0@4Pd04A<>018D4P0E5aH04A<B00`>
2`0@4Pl04Q@?010C3@0I71D06QdF00lB2@0F6@h05AP?00hA1P0@4`P04QD<01<F3P0B50l04A<@04i@
C@29RhH0:2XU00L:0P0E60l051L<01LJ400G6Q4051L>01<F3@0B5@`04aH=01@G3P0@4`X04aH=01LJ
4@0@4`X06A`C0`0E61402`0C5Pl04A@=010C300L7aP020/401LJ4`0@4``0:2/T01XM5P0n@3/0828M
00804Q@?00D04aD@01LJ4`0A50/04QD<01DH3`0201DH3@0301LJ3`0F6a@05AXC00805AXC00@051TB
01<H4@0F6a@05a`E0P0D6A800`0G71D04QL@018G4@0301@I4`0?01HK5@0H7AL051TC01<H4P0@5@l0
51TC01XO6@0D6A<061dG02P]9`0O91h06QlI01<I4P0G7QL072HN00805R0H0P0G8QX01P0I91`06R<N
01dV8@0K91l0624L01XS7P807bPS00H072DP020Y900S;2L08BXU028]9`0T<2`201`[9P0601l^:@0P
;bX08S4/028a;00S<Rd09cHa0P0X=c800`0[>SD0;3Xj0351@00202lo?P0302i0@00/?Sh09CLi0080
;D5202d0<4=70356B@0_A4D0<4A404QLF`1:GUd0>Ti=0396A@0dB4T0<DA702Dh?00gBTh0;D1405=V
JP0fBDl0<dM>03A8D@0oDeX0;41804EIHP19GFD0CV9Y04iRJ`18G6@0DFE/04AHH@0oE5X0AeaQ08>H
W@15FUl0@EIK04AIGP0mDUL0GG9g06AiOP11EU/0=DY?03Q=DP17G5h0B5iL04ILFP12F5H0DVQV05E[
J@1:H5h00P1@IV@01@1>I680AE]I04QNG01AIfD0DFMT00D0D6IS0P1?IF801`1@IV<0DVQU05Q^K01O
M7D0GG9e05]`L`1JKg800P1KL7<03P1UNWd0H7Eh05ebM@1RMgX0IGYm061eM`1UOW/0GGIc06AjM`1S
NGH0J7ik06UnN@1QMW40HWMb0P1QM6h0201WNW@0JWeg06=gKP1RMVd0HgM^06AhK`1VNG<0JGaf0P1/
Og/01@1_PWl0LhJ407>6Q01`Ph40KH1l00@0KX5m0280K7mk06j1O@1[OWX0JGah06YmN@1/Og/0Jgih
06IkLP1XOW80HWQ/05idI`1HKV40CVAG05A[F`14Fd/0@eY:04YQC`1?IU@0DfYH04iUE@1AJ5P0DVUI
051VF@1<HeD0AUi@049LC`14GU40AV1C04MSE`1:IUX0BfMK04QOE@17GU@0@eY@0P14Fe40:011F4h0
?eI<03=:@00_AS`0;D@j02i5>`0cAch0<Cdf038m>@0[=CH0:38h030jA00e?d/0=D5=04ECG00mC5<0
=TI702Lj>00[?SX0;C`f01/Z9@0G9Ql0=T8n04EAC@0[=c<07RTU01lY:00Q:bX08b`Z020Y:00N9b@0
8BXU01lX8`0X<B`06b@O00PA300M9R407bPS01hW8P0M9R4201hW8P07028]9`0K:24062DN014M5P0U
<2X082/U01DO6P0201XS7P0901/R7P0K8Ad06R0L01PN6P0I7QX05a`H014F4P0G71P06b0L00806QlK
00P06AhJ01PM6@0H7AT06AhJ01HL6@0C6AL05A/I01LM6`8061hL01<020h<01DK6@0C6AL0;38`01XP
7P0?5A8061/D01XM500@5@h06R4J01@J5P0:40h01P`:00P>300N81`020L2018A300J6A405QH>0080
5AH>00D04a@<018C2`0C50`061TA018C2`0201`M5@0700d>1P0@4P/03a4<018G4`0>40d02`d:010B
3`0201HF500M01<C4@0A40h03@`:01<A3`0I5A@040l=01LF500B4@l051<A01hM6`0>3@/04A0>018A
3`0I61H07ahL01TH5P0=30X05Q@E024O800D4Q<03`d>01@B4`0<2P/00@00018@4@0D4Q<05Q@E014?
40040P<00P0H5aD02`05108040l=00T81`0@3`d02`X800h=2`0?3P`03@`:00`;2@0=30X04@d<00<0
4Ph=0P0A3@`00`0>2PT04Ph=014=300200d920803`/:00H040`;00h:2@0>2PT04Ph=01@@3`0A3@`2
00h:2@0?010<2`0>2PT03@T8014=2P050@00510=014=2P0E4@h04@d:00/7100<20D02`L401<?300`
;2T08AdK00D03PX900d04Ph=00<0000L61L01`<200d9200E4A001`<300`81`0@30/04Ph=01lK6P0B
3Pd03`/:00803PX900l03@T800h:2@0>2PT03PX:00h:2`0@30d04Ph?010<3@0>2P/02`L800`82@0:
1PL01`<400h:2`0?2``01@0=2@X400h:2`0600d92P0<20T030P900T31@0<1PP03PP:0P0=1`T01`0>
20X030H800d72@0?2@/040X<00l92`0>20X00P0;1@L0100=1`T03PP:00l92`0@2P`2014;3@0:00d7
2@090`D0100000H00P0>20`03`T=010:3P0=1`/02P@800T31`H03PP<00`04@H:00l4200?10P040D9
01462P0?10P05``@00d21P0D2@d05@X>00`11@0>0`LDooooo`006oooool00`0D5AL0414C00l@4P02
010A4`803a0B02X0414C00l@4P0=3Q003@h@00l@4P0D5AT03@hB00`=4P0=3Q802``A00d>4`0E5QX0
30dA01HG6`0<3A805QLL00H72`0=3Pl05QPG00/=300A4a803Q0?00d?3P0N81l04A<B00H81`0D5QD0
2`d<018D4`0?4@h071hK00d?300O8Ah0>cdj00h@3@0:30T04aDB00P:1`0A4a003@l<00h@3@0=3@/2
014A3`0?00P81`0<3@X05AHA014B300?40X03Pl900l@200@4@T03@h8010B3@0;3@P04A<>018D3`09
2`H03a4<00804Q@?01P03a4<00`>2@0<3PT0414<00P91@0A4Pd0;RlZ00l@2`0@4@`03Pl:010A300?
40/04Q<>00l@2`0@4@`04Q@>00hA2P0=40T03Q4:00lB2`0=40T030l800d@2@0>4@X300lB2`0300lB
2@0?4PL03Q4800803A0700`03A0900lA300?4@`03Q0=0453@P1@DU403@l=010A300?40X03Pl:010A
300A4Pd2014A3`0;00d=2`0>3Ph04Q8B00l?3`0>3Ph0418?00d?300?4@h02P`901HH5@0V:2D0100?
4@h01`0@4Pl04A<@018D4`0@4Q405QPG01@F5@0C5A@00P0=3`h03`0A4a803Q0?01@F5@0>40l04A<B
014C400B51403@l<00`>2`0A4a00418?00lA3P0@4Pl04A<@018D4@02014C40H03a4>00L05aTF03Dg
=0092`T04aDB014C400E5a@04Q@A00803Q0=00X0418@01HH5P0I6aP04Q@A01<E4P0?4@h0418?01<E
4P0A4a003Q0;0P0?4@`3010B3@06014C3P0?4@`051HA00lA300=3`X05ALB1`0A4`h0500B50l04A<>
00lA300?4@`04A<>03Tk=P0];b/05ALB02@V8P0H6QD020T600d?2P0?4@`0418=00`>2@0@4Pd08R@S
01hO8P0D5AP051HE0P0>40d0500>4@/03Q4:00lB2@0?4PL04aL:01@G2`0C5`T05AT;01@G300C5Ph0
4aD@01<E4P0G6AL09BLT01<E400G6Q804QD:01XN4`0l?c@071lF0P0D5`h0100B5@`04A@;014D2`0C
5Pd201@G3P0601PK4P0E60l05APA01DH4@0D5a004QD>0P0A50d04`0F6A803Q4:01LJ4`0@4``06QdF
01hQ6P0c=C0061XE014C3P0C5A004Q@?01HI4P0H6a805aXA01HI400C5P/051L<01HI3P0F6a@00P0D
6A802`0F6a@05a`E01HK500B5a0051TB01HK500L8AX082DN01TN5`0G71H05Q/E00<05a`F0P0F6aD0
4P0J7aT061dG01PM5`0J7aT05Q/E01LL5P17C4H041D?024V800I7aP06B0I01LQ6@0K9Ad09c4Y02hi
<@0X<b/05b8J01/T7`8072DP00d07BHQ01lX8`0O:2<0;CHa02H_:P0S;2L08BXU01lX8`0T;bT09S8^
028a;00P;bX08C0[00808S4/01X09C@_02Lf<@0V=C009C@_02Lf<@0Y>3<09cDe02`l>`0`@3l0;Cdl
02`n?P0cADD0=4I803Q<C@0eBDX0<DA802a1A00X?Ch0=DU903M;BP0dB4L0;D5002e1?`0`A480<DE3
0396A@80>4a;03@0L8B303mCD`18G6@0A5QR03Q<EP1hS9H0F6af051TKP12EV00@5AN04]OJ@13Ef40
A5QR045EG@15FUl0J7f204IKH012Ee`0Bf1U04EJG`1cR8d0LXN<04UNH`12Ee`0@5EJ04aQH`19Ged0
BV1N04UOG@1?IF<0DFMU04aRH01;HEl0BEmM04YPGP19Ged0EVaZ069hM@1EJfP0DFMT05=YIP1@IV<0
CfER051VH`1BJ6D0FW1]05]aKP1IKf`0F6i/05aaLP1KL7<0GG9e0P1QMWT02P1NLgH0Fg1c05icMP1V
Ngh0K86406UnP@1RMgT0H7Qh05mhM@1^Q84206QnN`0306^0N`1SN7<0IW]f0080IgYd00L0Jgih06ao
N@1YOGD0IgYc06IiL`1XNgH0K7mj0080KH1m00H0K7ml06n1P01bQH@0LXB306n1P01_PWl20723O`0O
06n2OP1^PGd0KH1l07:5P@1^PGd0Jgij06aoN`1]P7`0Jgih06UnM@1UNfl0HgU]05Y`H`1DJU`0HgY[
08NNSP1RNFT0CVED04iUD`1=I580DFQF04aSD`1AJ5P0CVEE04eSE@1=I5H0AemA04EODP16H5<0Af5D
04MSE`0204YVFP0f04UPEP16GE<0@EQ>04=JD011F4h0?EA:03A;@@0gCT@0=Te30317?@0W?S@09CT`
02`g<00]=c<09c0b028[<P0^>4<0>T=A045=FP19Ef80=4=:0311@`0Y?3X0;3li028b:00S<bX09SH]
02Hc:`0[=S408bhY02@_:`0Q:RT08B/Z028Z:`0M9BH0624P01dW8@0G8AX05R0I01`V7`0H8Q/06B<L
020Y8`0T;RL07bTR01hX8@0P:R<07RTR01/X8@0L:B806RHP02<^:00<5a4082XT0P0L9B001@0L8al0
6AlK01LM6@0E6aL05Q/G00805a`H00T05Q/G01TN6P0M8Qh07B8N01`Q7@0I7QX05a`H01HK5`0H7AX0
0`0I7ad04@0F71X051XH01DK6@0N92804QPF014G5@0J81h051XG018E3@0N8AP05Q/D01HM5P0=50d0
?dE206]aKP0M8al04A<>00805QD@00@05aH>01DE3@0E5Ph05aP@0P0D5@d0600F5`l07b0H06i_I`1d
MFd04a@<010A2@0B50`06A/F01HK5`0D5Q<03a4>01HH5@0@40h02`/9018A3`0Q81h0CDa:01HC4P0>
2PT061LE01@C4@0@3`d05aHD02d/:P804A0>0P0@3`d05P0C4Q005A@B01@C4@0=2``0=38c02PV9`0@
3Pl03`d>01<A4P0>30d04@l@00H41@0E4a@04Q0A01hL7@1GEU@0Hf9P04m>C00B4@l05aHD00/:2@0>
3@/2014@3P0400l>300>3@/03Pd;018>3@804@d<0`0@30/01`0=2@P040`;014=300B3Pd040`;00l;
2P0;1`H00P0B3Pd0100D40l04`l>00l;2P0A3@`200h:2@0?010<2`0>2PT03@T8014=2P0c;b`0A40m
010<2@0A3P`03PX7010<2@0=2@H02`L400`81@0L61D0510>00D03PX900d03`/:014=30050P40510?
00d9200D40l02`P7014=300:1PH03`/:018>3@0<20L03`/:00803PX901003@T800h:2@0>2PT03PX:
00h:2`0B3Pl0510A018>3`0>2P/02`L801DA4P0K5aP04@d>010<3@0?2``030P90`0=2@X03@0>2P/0
3`/<00l;300?2``03PX;00d92P0<20T02`L800`6200=1`T03PP:00d72@0>20X00P0A2`d01@0@2P`0
3`T;00d72@0>20X03`T;00803@L90P0>20X200l92`0703D_<@0X8R@030L8014;3@0<1PP04@/=00h9
300200/52@03010:3P0A2`l03@L;00H03@L;00D06@hB01D:3P0B1`/04PL;01462P0200l4200500d2
1P0A1PX04@H:00h31`0@1@T05?ooool001_ooooo01<04Q<E00h?4@0<3@l03@h@00h?4@0=3Q0030d?
018C5@0=3Q002``>014B500?41@03@hB00`=4P0D5AT05aPM014B5`0?41@03a0E00803a0D02h051DI
04I7C00J6al03Pl@01HH5`031@@03a4@00`>3@0830/03Q8A018F5@0;3`h03a8A03e1@00L81l0414?
00H6100B4Q004A8?01/K6@010`003Q0=00P:1`0N81d0ATQ501@F4`0620D0410>00d=2`092@L03@d;
00/<1`041@003a0:00`=1`0;30H030d600h?2@0>40X03@l:03do>P0J71L0004001lQ700:30L0418=
0P0A4`h04`0?4@`04A<>01DG4P0720<01@H1010A300?40/01@H101DF4@0;30L02@X500h?2P0;30L0
3Pl:014C3@0<3`P02`h700d@2@0>4@X00P0=40T300`?200P00d@2@0>4@X03Q4900`?1P0;3PD02`h7
00`?200=40T030h900X<1`0?4@h05aTF00840@0B51803a0;00d>2@0<3@P03Pl:00l@2`0?3`d051@B
00h>300@41005QHF018B4P0@41005ALD014C400B51402P`9014C400E5a@200d?300H00h@3@0?4@h0
418?01<E4P0<3Pd02`d<024S8P0L7Qd03Q0?00d?3P0D5QD0418A00L9200>40l03a4@01/M700J71T0
6A/H014C400>40d04A<@00h@3@0=3``03Q0=100@4Pl600lA3P0?01DG500:30T04aDB00`>2`0C5A80
DeEB04Y<B@0A4a002@/800H81@0A4a003a4>010B3`0>40d030h;00804A<@00L02`d:010B3@0>40/0
3@l:00h@2`0A4`h04Q@?008030h900@04Q@?00lA300J71L0;2hY0P0A4`h2018D3`05014C3P0@4Pd0
3a4<014C3P0@4Pd00P0<3PT0:00?4@`030h901PJ5@0=3`X07R0K0043000E5a804aD@00h@2`0E5a80
3@l:01HH4`28RXP0QXN902DV:00<3Ph07R0M02<U8P0O8A`04QD>014D2`0E60h041<800hB100A5@L0
41@600lB1`0B5@d061XE01dO6P0I6aP02P`7010B3@0B5@d05aX?00X>000[<2D04QL@00X@1P0B5@`2
01@G3P0901DH3`0G7A<05Q`B01hT6P0e?C808RTQ01@G400C5Pl04QD>00804A@=00<04QD>00lB2`0I
71D00P0B5@h0>`0J7AH03Q4:00d?2P0?4@`061XE01<E400J71L061/D01TL5@0D5`h04A@<01HI400G
6Q404A@;018G400@5@h04AH?01LL5@0J7aP06b0I014F3`0C61405Q/D01`Q6P0O91d04aPA01DJ4`0E
6Q@05AXC01HK5@0C61803a@=01<H4P0L8AX06QlH01HK5@0F6a@04aPB01`Q6`0E6a@072<L01dR700J
8AX07bHO01hX800P:R808bdU02Ha:@0S;RH05b8J01dV8@0J8ah072DP020Y900S;2L082TT02D^:@0Q
:RD082TT00807bPS00T09C0Z024]:@0R<B`07bhY01h]:00Q<2/0830]028a;P0Y>CH00P0Z>SL02@0/
?3T0;Cdj02`l>`0/?3/0<TE302Xk>P0V>3P0<dE502`n@00203=7B00M0396A`0_A4L0;4520314@P0Z
?S`0<4A203iBD00kCdd0=4Q60355@`10E580;D8m03A9A@0lD4h0?E=A041DG01>HVd0Cf=/05M[M@15
FF@0E6Qb03mCG01=HF`0D6A^03]?F01?Hfh0Ae]S04AIGP0`ADX00P18GF803011EU/0@UML05Y_LP1>
HfH0A5UL04YOHP10EEP0Bf1R045FE`17G5d0CF9S04UNG`80CV=T00/0CF9S055VI`1EJV/0BEiO04iS
I01KLFl0DVQV04iTHP1BJ6H0D6IS04mUH`0305=YIP0X059XI@1CJFH0FFm]082EV01eRXl0HGIj05Q]
L01JKg80GgAg06MlO`1VNgh0HWMi05aaM01LLG80H7Ef05mgM`1[Q840PYRE06^1O`1PMW<0I7Qf06Um
N`1]PGl0KH9m06aoN`1]PWd0JWii06j1O@1YOWT0IWYe06YmN@1]PWd0L8>107>6Q01aQH<0LXJ407F8
QP1bQH@0KX5o0723O`80L8=m00@0L8=o06n2OP1]P7`0LHB00`1`Pgl05P1/Og/0IgYd06=hL@1RMfh0
Igea05Y^HP1MLV80TJJE0?;omP2:Whh0AEY904eTE01AJ5P0A5Y=04YPD`1?IEP0BV1C04UODP1>IEP0
B61C04UQE019HEH204QRE`80BF=H01l0C6=K04IME@10Edd0@5M=03aCB@0fCD<0?5=903M>A00`B3/0
:T4f02To<`0Y?C80:C@_030i>00]=cT09c4i03@nBP0oBeT0IgB104mMIP0Y>3l0:SXk02Hf<`0V=c40
8c<Z02<c:@0V=R`0:CH^034l=P0X<bd07bXU008092l[02407BLV01TR8@0H8Ah051dG024[8`0O:B40
51hF01XT700M9al092hV02H`:00O:B408B/S02<]9@0L9b006bHP020[9@0Q;2H05B0J02lh<`0L9B00
624L01XS7P0L91l0728N01/Q7@0Q9b<07B8N01LL600J7a/05Q/G01DJ5P0H7AT00P0G71P0DP0I7QX0
6QlK01`Q7@0K81d061hL01TO7`0I7ah061hL01LM700K8B404aTG01`R8@0K8B4061hL01TN700L7aP0
5AP?00`@2@0V:bD03a@>024V8P11AT802Pl;01HG4P0A4P`05A@?01TI4@0D50`05AH>01PI4P0E5Q00
5AH>01TJ4`0B4`d07AhF02d^9`0H6A<04Q<;00h?2@26R8<0=CLd014C400C4a40A4A203Ph=P0M7A/0
4Q4?07QgM@3Ddm40928P01/G5P0@3`d05QDC00/:20081`D02`X901`K6@0?3P`04Q4?01<B400A40h0
40l=014@3P0B414040h?01PF5`02004040h?01DC500I5aP020H701lM7P091`P040h?00l=3P0S8R00
Lg9`05UHEP0@3`d02`X801PG5@0@3`d2018A3`0400l>300>3@/03`h<018>3@8040`;0`0?2`X03@0@
30/03`/:014=300D40l03`/:00/71P0D40l03PX900H20@0:1PD03PX900X61@0A3@`00P0>2PT02`0@
30/03PX900d9200C3``04@d:02HR7`0:1P@04@d:00H2000:1P<040`90080510=00<04`l<00X61@0>
2PT0100>2PT03@0;1`H04`l>00P40`0810<02@D400h:2@0@30/06ADD00L30P0?2`X02@D400D1000C
3`h00P0>2PT0100=2@P03PX900h:2@0>2PX200h:2`0800l;300>2P/03PX;00/7200S7b00=30a024M
7P0>2P/200d92P<03PX;00P03P`=00l=3P0=2``03@/<00d:2`0=2@X030P900/720<03PP:00P030H8
00h82P0D3Q005@lA01<=3`0>20X02`D700`620<03`T;100>20X0300600804`d?014;3@0>20X01000
01D?4@1:A4P0=2hb010:3P0500<03PP<018<40H030H:00@04PL;00l4200=0PH03P<70P0?10P01P0>
0`L04`P<01462P0?10P040D900l421Cooooo000Kooooo`0800hB5@0:3Q403A4D00lC5P0<3a803@hB
00`=4@0@41@2018A5P0?01<B5`0D4aP03PdB01@C5`0o?d40BDQ=02<S9P0?3a403@`A014@50051@L0
6a/N07elP@0I6A/03`l?00803Q0?0P0<40l200/A3`0L00PA3P0=5Q<06b@Q0>kim@25RhT04Q0>014@
3P0@3`d03`l=00l>300>3P`03Q0=00D7100A4a00;C8^01/P70021`<03a0;018C3P0>3`X04Q<>01<D
3`0:2`H03Pl:010A300<3@P030d700d>2@802P/601H061TD00H70P0@4@`03Pl:01HG4P0=3PT04Q<>
00X;1P0A4Pd03Pl:01XK5P0=3PT01`P3010A300>3`X03@h9014B3@0>3`X02``700`=200?40/0414<
0P0?40/0:00@4@`04A8=014B3@0A4Pd0414<01hO6P0=3PT030d9010A30031000414<018C3@0?40X0
30d8018C3P0A4Pd0414<00/<1`0:2`H04a@?01DF4@0@4@d03@d;00l?3@0B4Q004a<A014A3`0>3P`0
30`:00h>300<30X03@d;014A3`0>3P`03a4>00d?300B51405aTF018D4@0<3P/300d?30802`d:00l0
3Q0=01<E500;3@`04aDD01HH5`0<3Pd06A/J03Xl>`072@P07b4P00L9200J71/07AlN00lA400>40l0
0P0=3`h06P0>40l03a4@01@F5@0C5A@0418A00lA400>40l03@l>01@F4`0<3P/01`T6018D4@0@4Pl0
1`T6014C400:30T04Q@A00`>2`0G6AH0C4i;04M7A@0G5aD02`/901<C4@0@40h051@B100C4a405P0A
4@l0410>018D4@0@4Pl04A<@01<E4P0A4a003a4>010B3`031@8051HC01DG500;3@X05aTF01DG500F
61D03a4>00/=2P0A4a0051HC018D4@0A4a02010B3`0A00h@3@0>40/04A@>010C300?4P/03Q4:00d@
2@0<3`P041<<00d@2@0C5Pl04QD>014D3@0l?SX0=cTf01HH5@0?4@h00P0C5A008@0>40/04A<>010C
300=40T030l800hA2P0@4`T04A@901<F2`0@4`T03A0700hA200B5@`04A@;010C2P0?4PP03a87010C
200=4`X01`h701DL500B5`l02a4701LM4@0=4`L05QhA01HP5@0a?380_L[007R6O@0K81T04A@=01<F
3`02010C30<04aH?00d05APA01@G400C5Pl04A@=00lA300C5A0051HA01HH4`0K7AP04aD@01TK5P0G
6Q<051H@00<041<<00T061dG01XO6@0A5Q0082DO01HK5@0l@C/061dG01LL5P0F6aD00P0H7AL06`0G
71D05aXC01TL500I71<05aXC01LJ4P0H6a8061/D01XM5@0H6a8061/D01`O5`0K81T07bHO01/S7027
THT0HfYS014K4`0Q:b<08bdU03<m=@2f`;P0@de502/e;@0B71@082/S01dX800202<^9P0?01dX800O
:R806bHN01lZ8P0M:2006bHN024/900]>38082`X02Hf<`0G9b@08S8_02@d<@0U>3H08c@c00809STg
04@09SPh02Pl>`0[?ch0:3Xj02Hh>00Y?C`0=dY902Xn?@0W>cX0<TI503A8A`0/@3l0=TY903Y>C`0/
@3l0<dI203A7@`0R=C40@eIC03U=B`0U>CL0;T900316@`0dBTL0<DM403I<BP11EUL0>DiD03eAFP10
E5/0@eMO04EIHP15FF40?51G04IJH`15FF40?U9I04AHH@0nDUT0BEeT04IJH@18G680DfQ]04aQI019
GV40Bf1Q04MLG@11EUH0AeeK04QNG016Fed0DVMZ04=HF`19GV40DfQ[04QMH01<HF@0CV=V059WJP1F
Jfh0Jh2304QMH01dR8`0K821059VI`1@I6D0E6QW05Q/K@80EFUX00h0E6QV05EYI`19GE/0F6a[0<CI
gP2P];/0HGIl05aaMP1PMGX0GgAg05Y_L01LLG80H7Ie06=hN@80I7Yh0380IW]l06MlO@1YOgh0JGio
06UoO@1[PGl0LXR606j4PP1YOgd0JWim06Z0OP1]PX00JGek06QnN`1ZOgd0KH5o06j4P@1`QX40L8F0
0727P@1bR880LXN20726P@1_Q7d0JGed07>4N`1eQWh0P96;08FETP1/O7/0M8B307>3P@1aPGh0Kh1j
06ioN@1[OWP0J7eh069fL@1PM6/0G6iR05QZF@1SM640UJJC07J8M@1@HU80CF5E04YOE@1=HUT0D6EL
04mTF`80CV=J0P1?I5/0<01<HEP0Bf5I04aSF`1>IEd0C6=K04QOE`18H5X0?eQB041JD@15G5@0?EA:
03M>A00fC400>U1403I<?`0aAc/0:clc02Hg;@0W<S0082X/02D`=00/>D<0:3I304EBHP15DV40:SQ1
02/j?`0]>c`07RXV02Db:`0V<Rl0;CTe02@`;00]>S@0=d@m02dj<`0S<2P07b`S020]900L:1l06bHN
020[8`0c?CD05R0H020Z8P0G8AT05R0H01dW7`8072HN00@07bTQ02D_9`0Q:b<07RLQ0P0R:bP0400O
:2D06b@Q01lU8`0P9R@092XX01@J600L8R005Q`J01LM6`0N92406QlK01dR7P0J7a/07B8N01DJ5P0M
8Qh201TN6P0K01XO6`0M8Qh08bPT02P/;0093@h07R8U01@H6P0F6Q/05QXL01LK7P0H71d0>Si008:6
R@0;3a004aLH01DG4P082@<05aPC014C3P0L7QT09bTT020R7@0F61<051D@01TJ5@0F5a805AD@0080
4a8=01H051<>01@C3`0E50l05A@@00l>2P0I61<051<>010?2`0L6aH03@`901TI5`0D51803Ph<010?
3@0B4@l051<A01LF500@3`d081lM03<b<00D4a4061LE0P0D4a42018A3`0A014@3P0@3`d030/900h=
2`0J6AL03Pd;01<B400F5A<02@D401<?3P0H51<04@d<01TE500D40l040`;01HB4@0B3Pd00P0A3@`0
1@091@@04`l>01PD4`0I5A@0510?00<04@d<0P0B3Pd0100@30/03@T800`81`0>2PT201<?3P03014=
300810<04`l>00<03@T80`0?2`X04P0@30T01P80014=2P0?2`P03@T6014=2P0B3P/03PX700l;200>
2PL0510=00d91P0>2PT02@D4010<2`0;1`H06QHE00L30P<02`L601D030P700H20@0:1`H03@T801LC
4P0:1PD03`/:020L6`0:1PD03@T800/71P0:1PD02`L600d9200?2`X040`;00l;2P0>2PT03@T800`8
1`0=2@P00P0>2PT0100=2@P03PX900h:2@0;1PH200h8200E00l92@0]9bL05@l?00h8200C3@d0618B
01H@400?2@T03PP8014;30050@805A8C00d;300;2`/05aLG02l_;`0000004Q4A0040000I5AH03@P:
00803@L70P0>20P200l92@06010:2P0P6QX01@0001@>3P090`<030H61P0=1`T600h82P030:ZTZ01Q
Fel040X>00802`D900<03`T=00/52@0<1PX00`0>20`00`0=1`/04@H<00h32@0201P=4`0800l42P0E
2Q004`P>01D:400<0@L02`0600X11@0G318Dooooo`006oooool02P0;41<02@hA00lC5P0B5QT03a8E
010A5@0?41@0410D010?500>3A8200d<4@0>014A4`0;2`d05QHH01XJ700@41803@d?018B500=3@l0
6ATK010@4P0e=CL030`>00l?3`0?40l200h@3`0900d@3`0<4@l02a8?018J5`053``02A<@049<B@0S
:BL04Pl>00804Ph=00`040l=00l>300>3P`03`l=00T;20082PL04AHB00`B3P0A5Q803a0;00d>2@0>
3`X2014B3@0E010A300=3PT03Pl:00l@2`0:2`H030d800l@2`0E5Q401PL301@E400>3``04Q<>00l@
2`0=3PT051D@00h?2P0D5A002``7010A300?40/03Pl:0080414<00X03@h900/<1`0=3PT0414<014B
3@0B4`h051D@018C3P0?40/0414<0P0A4Pd05@0@4@`03@h901<D3`0?40/03a0<00`=200e=S40DE9=
00T:1@0M7QT0>CXe01<D3`0=3PT030d801@E400A4Pd02``700l@2`0>3`X03`l=010@3P03014A3`09
010@3P0>3P`0410>00h>300?3`d051@B014A3`0<3P/02`d:00803a4>00@030h;00h@3@0A4a00418?
0`0>40d03`0;3@X03@l>00d?3P0>40l04Q@C01DG5P0?4A00EEMF018D4`0?4A003Q0?01@F5@0;3@`0
3a4@010B4@02014C4P0;010B4@0?4A004Q@C00lA400<3Pd03@l>018D4`0E5aH02P`901PJ5`0720H0
0P0>40d03@0C5A8051HC010B3`0C5A803a4>00P:1`0B5140410>00d=2`0A4@l04a<A018B400E5A<0
0P0B4Q00600C4a404Q8@010@3P0?3`d04A<@00lA3P0@4Pl04Q@A010B3`0>40d04A<@01LI5P0?4@h0
418?01PJ5`0C5A80418?01/M6P0I6aP04aDB00h@3@0:30T04Q@A014C4080418?00H03Q0=00h@2`0A
4`d041<<00lB2`0>4@X200d@2@0;01<F3`0?4P/04A@=010C300C5Pl05QPB01<E400H6QD03Q0;014C
3P0G6A@00`0B50l0100C5A0051HA01<E400C5Ph301@G30@04aH;01H04QD:010C200?4PL03a8700hC
300E7AH06b4J014F3P0@5@/051T=00dC1`0D70l05b4F041=@P32dLL0Kgif01PO600L7aP04aH?01LJ
4`0M81T051L@100F6A80100E614051L@01DG4P0F61<201<E400501PJ5@0E5a806A/F01PJ5@0F61<0
0P0E5a80200G6A@03a@>01XO6@0H7AL05Q/E00`A2`0M8Q`05AXD0P0D6A<0100F6aD05a`F01HK500K
7QL201dP5`1901`O5P0M81L07b8I01dP5`0I71<061/B01/N5@0M81L06R0F01PO600K9Ad0@Ta402/e
;@0J91`0628J01TS6`0nB400/K^c05IPF00O:B407BLO01dX8@0L9b008RdV02<^9`0Q;2D092lX01lZ
8`0R;BH08bhW028]9P0S;RL0934Z02Pd<00S<c00830]03];B00^@Cl07S4_02Li>@0Y?C`0:3`k02Lk
?00W?3d0:Cho02/o?P0/@3l0<4A302Tm?00fBTT0FVi]03M;BP0[?ch0<4A303=7AP0^@T40;d=10395
@@0jCDP0=4M202i1?@0[?cd0@5AB03A8AP0`AT@0>4i<03eCD@0gCdh0=Ti?045EF`13Eeh0@UIM04=G
GP0204EIH00Q04MKHP1:GVD0AUYQ04EIH012EUd0@5AK04=GGP18GF<0FFic04MLH@0oE5L0C65S04UN
G`16G5X0@eUG04UOG01:H5d0AeaM04YOI018GF80CfAY05AYKP1>HfP0CfAY04aQIP1DJFh0H7Ej07>8
S@1HKG80FFea04ePI01?HVH0Ffia0080FFe^00@0EFUY05Q/J`1EJFL0GG5_0P1GJfT03`1UNGl0I7R0
05iaN01WNh00HgMm069fN@1UNGX0IWYk06QmN`1ZOgd0Jh1o06f2P01WO7d0JGio06^0P@0206YoP00:
06f2P`1[P840KX>40766Q`1_Ph@0KH6206^0P@1[P7l0K86006n4PP80LHJ30240L8J00726P@1aQh80
LhV10767P01^Q7`0JWmf06b0M@1_P7D0KGif07J7P@1lSHT0Jg]j0761P01bPX00LX9o0721N`1]OWL0
J7]e06QkN01QM700GW9X05e]H@1EIE<0EVE@05ASCP1IJEH0E6IF05QZG@1<HEP0C65K04mTG@1>He`0
0P1=HU/01@1@IEh0DVMP04iSG01<HEX0Bf1I0080C65J01T0B5mG04ALEP14GEL0@5UC03aCB`0kDTP0
?EA:03mEB@0hCD40;d@h02a0=00X?Bl09CH/02@_;`0O:Rh08Bhd02@b>`0U=D80@51N0392C`0W=Ch0
:3Ll02/g=`0P:bH0:C@^00809c<a01/08bl]02@`;00T<BX08BhW02@a:00O;2<07R/R01PU6`0H9QX0
7R/Q02@^9`0G81X07BHP01`U7`0M9b0082TS01hW8@0L9Al05b0J01/T7P0L9Ql07bHS02<Y9`0R:2H0
7bDS01`R800M8b400P0K8Al02P0<4Q006R0N018H5P0I7ad07R<P01@I5@0O92006AhJ01LL600?5102
01TN6P0:01PM6@0G71P05a`H01TN6P0Z;Rh0720R02P/;P0G6ad04aLI01HJ70806QhP00D07R8T01PL
7P0@51H06alP01`L6P0201@E400701HG4P0G61<071dH01DF4@0C50l05QLB01TJ5@0201DF4@804a8>
0P0D4`l201DD400D01HE4@0I61@03Pd900d<200G5Q804a8>01<B400H5aD06aXH01HE4`0C4Q005QDC
00d<2P0K6QP0H5mM05eLFP0F5A<03Pd;010?3@0A40h2018A3`8051<A00L04a8@00l>300C4Q00R8N5
01PG5@0D4a405a<B00804Ph=00<04`l>00d9200E4A000P0E4A001P0?2`X040`;01@@3`0>2PT040`;
018>3@804`l>00<04@d<00h:2@0@30/00P0A3@`02`0@30/03@T800`81`0B3Pd05a<B00/71P0A3@`0
3PX9018>3@0>2PT03`/:00<040`;00d03`/:010<2@0B3P/02`L500l;200C3``02`L5018>2`0V8Ql0
;BTV01/G500D40d030P500803`/:01402`L602hZ:@0T8B0040d<01/G5P0A3@`03PX9010<2`0:1PD0
5A4@00`81`0B3Pd030P700`9200E4A0030T800d9200300`81`0700d9200?2`X040`;010<2`0?2`X0
3PX900d9200300h:2@0900d9200>2PT03PX9018=3@080P805a4A010:2P0?2@T03@L700803PP80100
4P`<010:2P0<1PH03@L7014;300<1PP02PL801<C4`0=3@d0Oh600<_=c011@d803`l?00X82@0A3@h0
3`T;0P0=1`L200h820803`T900H06A<C03Xd=00G4A403`T900h8200<1PH600d72@H03PP:01P05a8E
00h9300>20`03`T=00/52@0B310040X>00l93@0<1PX03@L;010:3P0B310091TO01873@0A1P`04`P>
00h32@0A1P`040D;00h42@0?10X040L;01@:3`0C20hDooooo`006oooool01@0;41<02`lB014E600D
61/0418F00803a0D00/03`lC00l>4`0A41D04Q4F014@5@0@41804a<E010@4P0>3Q00410B00h>4002
00d=3`0401XJ700=3@l01@D700`<3P<03`l?00d03a0?00h@3`0>40l02Pd<00lC4P083P`03aLD0088
1P0A5A@04@l=018>3@0A3@`03`h<00803@d;02403Ph<01`N6`092`P00@@103<h=01jOg/06a`G010A
300C50l03a0;00/<1`0A4Pd03Pl:00/<1`0H6A@05AHA00d>2@0E5Q404A8=01/L5`0I6QD00040014B
3@0D5A002``701<D3`0=3PT05AHA00/<1`0:2`H0414<018C3P0<3@P00P0?40/02@0=3PT04a@?01<D
3`0@4@`061TD02LX8`0P8A`03Pl:00l@2`04010A300F00X;1P092PD061TD00D60@0D5A00<c@_0042
000=3PT0:BXU00D60@082@@03Pl:014B3@0:2`H061TD02d^:@0M7QT04A4?010@3P0?3`d03Ph<00l?
3@804A4?01404Q8@00l?3@0>3P`04A4?00d=2`0@4Pl030h;00lA3P0E5a@04aDB018D4@0<3P/03Q0=
00lA3P0;3@X030h;01@F4`0200h@3`802P`;0P0@4Q4020010`803@l>01LI600B51<01PP701TK6P0=
3`h0418A0P0B51<06P0@4Q403@l>010B4@0>40l03@l>00h@3`0B51<05ALF01@F4`082PL00P@1020R
7`092`P05QPE00h@3@0=3``02`d:010B3`0G6AH04aDB00h>300J6QP04a<A00`<2P0A4@l051@B0P0@
40h2014A3`803`l=01803a4>00h@3@0?4@h04A<@00lA3P0=3``04Q@A0002000I6aP03@l<00`>2`0=
3``051HC01DG500?4@h03@l<010B3`0?4@h2014C4080418?00<03a4>00lA300B50h00P0A50d02@0@
4``03a8;00lB2`0D5a002Pd600hA2P0D5a006A`E01`N6002018D3`0B00d?2P0C5A0061XE01@F4@0C
5A003Q0;014C3P0E5a804Q@?00lB2P0=40D02`h300d@1@0?4PL03A0500hA1P0B5@X04A@90P0@4`P0
4`0A50T04aL@00L>1`000`003A4901LJ4@0?4PL04QD:014G2`0A6@h03AP>01/X7P0N:R803Q<=01PK
500@4``06A`E01XM5P0B5@h00P0F6A8301DH4@0701HI4P0G6A@05aTD01DG4P0D5Q405ALB01@F4@02
01HH4`0B01DG4P0G6A@06A/F01`N6@0C61807B8L01hS7@0E6Q@041D?01DJ500F6aD05AXD01HK5@0H
7AL06QlI01TN600G6Q<06QdD0P0K7QD05P0L7aH07b8I01dP5`0I71<07B0G024T6`0N8AP061dF024X
8@0D7QH072HN01PR6P0G8AT06bDM020Z8P0C7AD072HN01DO5`0U;bL082XR01hY8`0M:28201lZ9080
7RTS0P0Q;2H0200S;RP09C0Z02@_:@0P;BH07bh[02Dd<@0N;R/0:CTf0P0bAD<02@0V>3P09SXi02Hj
>@0V>S/09CXk02Hk?00/@3l0:3`k02e1@00202i2@@0D04=GEP0cAdH0;T910396A@0V>ST09c/j03I:
B00^@Ch09STe02Dh=00dAd<0RIfK0=CXiP11EE<0<TQ603=9A`0nE580@5QH03iFF010E5X204AHG`0M
049FG@13Eeh0AEUP051TJ`17Ff80@5AK04QLH`0oDeX0?U9I03Q<D`0nDeP0HGIk059WK00nDeH0AEYL
04EJF`13FEL0AE]I04YPGP1;HEh0Bf1Q04IKH01;H6D0BUmT04MLH@1?I6T0DFI[05=XK@1LLGH00P1?
I6T03`1HKG80FVib05EXK01OLWH0H7Af05IZJ`1KKg00F6a/05a`K`1HK6X0Gg=a061dLP1IKF/0FVec
06EhO`0206YmP`0;05mbN01QM7P0J7am06QlO@1WNgX0JGel06]oOP1^PX40JGel06]oP01]PH800P1/
P8401`1_Ph@0L8B50765QP1_Ph@0K82107:6Q`24V9T00P1cQhH307:6Q00<07:7PP1cR8<0LhR307:7
P01`QGh0KhAm06j3NP1eQW`0Kh1g06]lM01_P7X0MHF30P1`P7l04`1cPh40M8B107:3O@1]OWH0IWYa
06MjM01NLVX0F6aP05UZFP1CHe00CEa705]ZE@1NKUX0DfIC05EWF@1=HUL0DVMP05=XH@1@IEh00P1=
HU/0101?I5d0DVMP04mTG@1;H5T204QMEP0e04UNE`18GEH0@EUC04=LEP10FE<0?EA<041GC@15G580
@5I:03Q<@@0aACX0;T8f02Lk;`0P<BL09C0_01hY;@0P;C<08S0h02Pi@`0hB5D0?TiJ03M5CP0]?440
9c8b01`W8`0S;RP0930]028^;00W<c40930/020]9P0U<R/0934X01l/8`0N:b806RLM01`Y7`0R;bH0
9RlZ02L`;@0R:bL08b`W02@]:P0T;BT09c0[02H_;00M9R807RLR028[:00R:RL082HT01lU8`0L8R00
0P0I7ad03@0O9B<0<CLe01/Q7`0G7A/07R@R028X9P0G71T05AXF02<X900I7QX05a`H010E4@0I7QX0
0P0L8Ad06@0H7AT05a`H01LL600M8B004QHG01/O800G6a`08RHW03Tm?P0B5QL05QXK01TM7P0J7Ql0
51PI01DI6@0E5A<071dH014B3@0J6aH04a@?01HG4P0C50l061TD020Q700M7QT00P0G61<601@C3`0B
014@300D4`l061LC00l>2P0C4Ph04A0<00d<2P0C4Q0061LE01@C4@0A40h04Q4?010?3@0F5A<0Ogil
06i]J`0D4a403Pd;0P0D4a42018A3`0G014@3P0@3`d03Pd;018A3`0D4a409B@R014@3P0M71X04`l>
01@@3`0?2`X05A4@00d9200G4a8040`;014=300C3`h05a<B01<?3P0:1PD03`/:00d9200?2`X00P0B
3Pd01@0=2@P04`l>01<?3P0C3`h04Ph=00804@d<00P03`/:01LC4P0A3@`03`/:00X61@0K5aH03`/:
014=30804Ph=00T040`;00h:2@0A3@X02PH301@@3@0B3P/01P80010<2@091@800P0E4@h05@060P00
2PH300X60`0=2PT04Ph=010<2`0Q7A`081`K00d9200F4Q403PX900X61@0=2@P03`/:01<?3P0N6QT0
?c/j01<?3P0<20L05a<B00`81`0200d9200400`81`0=2@P03@T800h:2@803@T800@030P700/71P0;
1`H03@T80P0>2PT01P0=2@P03PX900h:2@0A30/01P0001@>3P8030H600@0208200d71`0?2@T040X:
0P0?2@T03@0C3@d03PP9010:30091PH03@/<00/;2`11@d80Kg5`01lQ800920T030P901@@4@0>20X0
1P0>20P01P090`<050h>00/51@0B30`01@0001<=3@H03@L91P0>20X0200G4AD05Q0D00l93@0=1`/0
3`T=00X4200=1`/030H:0P0:10P03P0=1`/03`T=01hC6@0B1`d04@H<01<83P0A1P`04`P>00l42P0=
0PP060dC01X?5@0R5ad04`P>5?ooool001_ooooo01P03a@G00dA500A5AP04QHI00h@500=3Q803PlC
00`<400;2Pl03@`A00l>4`0=314020P:018B500@41803Ph@014A4`0<30h03@d?01DE5`0<30h0410B
00X:300@4183010>3`0:010?3`0?3`l03Q0?00h@3`0;3@`03A4@00X?3P0@51<03@l>014?3@<03`h<
0P0=3@/0700:2PP05ALD00X<2@0J71T0N7ei0=?He00K71L0414<018C3P0>3`X030d8018C3P0;30L0
51D@02d^:@0/;BP03Pl:00L80`010P002P/600H7100j>cH04Q<>00L8100:2`H04a@?00T:1@0C50l2
00`=2004010A300A4Pd02P/600l@2`80414<00P051D@01<D3`0?40/05AHA028S7P0M7QT03Pl:00l@
2`80414<01/03a0;01@E400=3PT01PL201DF4@0D5A004Q<>01dN6@0?40/03Pl:01@E400>3`X04Q<>
010A300B4`h020T4014B3@0T9B004A8=014A3`0@40h03Ph<00d=2`0>3P`04A4?010@3P0B4Q000P0@
40h0700D51804A4?018D4@0;3@X03a4>01/M6P0J71T0418?00d?300C5A805ALD00d?300@4Pl09BLT
01DG5P0D5QD07b4P01hP7`0@4Q4061XI01`N7@0C5A@020X900lA40082PT04Q@C00`>3@0>40l2014C
4P0400h@3`0<3Pd03a4@010B4@<04A<B01D03a4@00h@3@0=3``06adJ01PJ5`0A4a003a4>00d?300?
4@h020X700T;200@4Pl03Q0=00T91`0D51802`/900T91`0C4a404A4?00l?3@0@40h00P0A4@l0200@
40h03`l=00lA3P0>40d03a4>014C400?4@h03@l<0P0@4Pl0200?4@h03Q0=01@F4`0=3``05ALD014C
400:30T02`d:0`0A4a03010B3`0300lA3P0?4@`04aH@00<04QD>0P0A50d03@0R9Ah03A0900hA2P0A
50d03a8;00X<1P010`003a4<01HH4`082PD04Q@?01dO6P0F61<00P0?4@`02@0C5A004A<>018E3@0A
50/03Q48014D2`0C5Pd041<:00lB2@02010C2P0C014D2`0B5@`04aH=01XN600<4@/04A<>02h`:@0R
8a/05aT>01PJ3`0=40D04A@;01PP5`0@718051lH018G4@0C5Pl051L@01PK5002018E3P8051L@100E
614201DG4P0501PJ5@0G6A@051HA018D3`0E5a800P0D5Q402P0F61<061XE01/M600H7AL07R<M024V
800M8Q`05Q/E01<H4P0G71H201HK5@0501PM5`0I7QP061dG01DH4@0H6a@00P0I71D06`0J7AH07B0I
01/N5`0I71D08bHO02HY8P0O8Q/06AhG01lV7`0I8a/05b4I01dW7`0H8QX06R@L018L500S;BD08B/S
01lY8@0P:R806R@L02D`:P0S<2T07b`U01dZ8`0L:B806BHO020]9P0201h[900=024^9`0T<BX0934Z
01d/:@0W=c@07bl/020`;@0bAD<0>4]902@f=P0T>3L09CTh02Pl?@0202Pm?P1=02/o?P0Z?Sd09c/j
0314@`0X?3/09c/j02e1@00_@d80<dM60355A00[?ch0;40n02<f<`0gBTH0>di:02m2@017FeT0HgMe
03eAD00dBTP0<TQ603Y?D00oEeL0@5QJ03Y?E@13Eeh0AEUP04IJH@1:GVD0BemV059VK@16FV40@EEL
04YNI@12EUd0AEYP04MLH@0oE5T0AEYN04QMH019GV40CF9T04=HF@12EeP0AeaL04YPGP1;HEl0CF9T
049GG017G640FFic05]`M@1FJg00CV=X04mTJ@1BIf`0Fg1e05mdN@1PMGX0DFEY05Q[K`1[OX80Jgn1
05U]KP1GJf`0E6QX05mcLP1KKfd0GG5_05ibL01MLG00GW5e06AgO@1SMW`0IgZ0069eN@1XNgl00P1W
Ng`01`1VNWT0Ig]j06UmO01/P7l0JWim06b0O`1^PX400P1]PH00301`Q8<0Kh>206n3PP1^PX40L8B3
07fAT02FZZT0N8b;07J:R@1bQX@0LHF307:6Q080MX^600X0M8V40766O`1`QGh0M8V207N<P`1fQgd0
Kh1g06ioM`1`PG/0LH5o0P1cPh80101eQH<0MHF207>4OP1]OWH206IjL@0C05eaI`1DJEX0EVME05IV
DP1AH4T0E6=<05QXE01EJ5D0G6iP05=XG@1AIUd0EV]T05=XH@1?I5d0CV=L04mTG@1@IEh0CfAM04YO
F00304MLE@0d04EJD`0kDTX0>U5903]BBP0nEDd0@EI=041EC00lDDP0<dLl02/o=00Z?S<0:S``02Hf
;00T;bh072L[024^=00U<S/0:CY402hoB@0iBU<0<d9902Pg>P0Y=C@08bhZ02Pc;@0S;b/08BdY02Te
<@0V<Rh08BhW02Pe;P0N:b@06bPO01`Y800K:1l07R/Q02@a:00R:bP09c0_020Y9`0P:BH07bPW02</
:P0^=c@0;CHe028[:@0M9R<072DT01dU8P0N9280728P01/Q7`806AlM01005Q`J01LM6`0;4@l08RPV
020V900K8Al04aTF014F4P0M8Qh051TE01PM6@0A5Q8061dI01`Q7@0N8al06AhJ0P0J7a/04@0E6AP0
2`l@01<G600A5AH041@E01lS901LH640S92A02L[;00D61T061`M010D500A4@l07QlJ01DF4@0I6QD0
4a@?00805AHA00D07AhI02@U800L7AP05aPC01HG4P0601@C3`08018A3@0F5A40;RdY01XI5@0K6QH0
4a8>014@3P0@3`d2014@3P08018A3`0A40h04Q4?010?3@0E51802@P601LF500>3@/201@C4@804Q4?
00`04A0>010?3@0B4@l03`h<01dL6P01000061LE00H50`0;1`H0510?00l;2P0A3@`201<?3P09014=
300?2`X04Ph=01@@3`0A3@`03@T8010<2`0>2PT03`/:00804`l>00<03`/:01<?3P0C3`h0100B3Pd0
5P091@@061@C00@0000E4A004Ph=00/71P0@30/04@d<018>3@0A3@`03`/:00h:2@0B3P/05A4>01/G
500=2@H00`0001<?300E4@h040`900h:1`091@<201PD4@04014=3@0E4A008QhM06]WIP800`0000`0
2`L600d9200<20L04@d<01/G5P0R7Qd00`0001LC4P0:1PD0100000/71P0A3@`200d9200300h:2@0=
2@P03@T800@03PX90P0=2@P300h:2@0:00d9200>2PT03PX900d81`0=1`L03`T900`61P0S7Ad03`T9
00d71`<040X:00h04P`<01D?3`0C3@h030H8014=3P091`P030`<00L9200H6QT010H5010?3`0<20T0
4@d>00X41PH03PP800H03`T9014;2`0:1@D050h>00L10@0?2@T600d72@H03PP:00@01@0300l93@0B
31002P@80P0=1`/00`0:10P02`D900`62P0300`62P0<00l42P0D2@l06@hD01H;4@0A1P`04`P>00h3
2@0A1P`02`0600L00P0@1P/050T?5?ooool001_ooooo00T04QLJ00dA500>4QD03a<F00`?4P0=3Q80
6AXN018B5`0?3Q<00P0A41D00`0=31403`lA00l?4@0200h>4008014A4`0B4Q@04Q8D01TI6`092@/0
3Ph@01TI6`0=3@l4010>408040l@00H03@d>018A4P0A4Q<03a4A01DF5P0<3@d200l>300;00h>300>
3@/03@d;00`<2P0B4Q002P/900d>2`0@4Pl03Q0=01hP7@0A4Pd00P0<3@P03P0?40/04A8=014B3@0B
4`h02``7014B3@0G61<0414<00d>2@0D5A001@H201/L5`2PXI`0ATM20P0A4Pd01@0O81/03@h9014B
3@0=3PT04A8=00803@h900`03a0;010A300?40/03@h900h?2P0?40/03Pl:00`=200=3PT03Pl:00d>
2@0>3`X300l@2`0:014B3@0?40/03Pl;00d>2@0>3`/04a@?010A3@0?40/04A8=010A30804A8=02@0
20T4014B3@0@4@`02``7014B3@0B4`h0410>00l?3@0>3P`03@d;00h>300@40h03Ph<010@3P0A4@l0
4a<A01PH5P0F5Q@03a4>00X<2@0?4@h05aTF01<E4P0<3P/02`d:010B3`0B51402`d:00h@3@0O8Ah0
3Q0?018D4`0X:RT09bTX00lA400@4Q42014C4P0500d?3P0@4Q40418A014C4P0>40l0100?4A000`0>
40l0418A014C4P02018D4`0:010B4@0=3`h02`d:014C400?4@h06adK010B3`0E5a@03@l<010B3`80
4Q@A00D03a4>00`>2`0>3P`04A4?010@3P02018B400500P81P0@40h04A4?018B400C4a400P0B4Q00
4P0A4a003a4>010B3`0B5140418?00h@3@0A4a003a4>00P:1`0M7a`04Q@A01PJ5`0@4Pl04A<@00lA
3P0B51404aDB00lA3PD0418?00<0418=018D3P0B5@h0100B5@h02`0H6a@03A09014D3@0B5@h04A@=
02PZ900K7AP03Q0;01DG4P0?4@`04Q@?00805aTD00H04aD@018D3`0C5A004aD@01<F3`0C5Pd2018E
3004014D2`0@4`X04QD<018E30804A@;0P0B5@`0600@50d051TC02DW8P0c=Bh05aP@00d<0P0F50/0
5aP>01LH400?4`/041P@01@L5P0D6A<030l801DH4@0=40T07B0I01/N5`0B5@h04aH?01LJ4`0H6a@0
5aXC01@G408051HA0P0I6aH0100D5Q405ALB01LI500F61<201DG4P0;01HH4`0I6aH04AH@014F400G
71H06AhH01HK5@0U:R@05a`F01HK5@0E6Q@00P0F6aD01`0D6A<05a/D01TM5P0I7AH061`E01TM5P0K
7aP00P0I7AH202<W800K01hR6`0V:b@07bHO024[8`0?6A407BLO01/U7@0]=bl082XR01PR6P0P:R80
7BLO01TS6`0T;bL0:3<]02Pd;`0P;BL07RXU020]9`0L:2<07RXU024]:00Q;RP082dW028_:@0U<Bd0
7RdZ00808S8_01408c<`02Xm>`0P<c40:3Xj02Hj>@0W>cX0;41102a1@P0Z?d00;40o0355A00W>cX0
:cln02e1@00bATD0<DE402a0?`020396A@0703A8A`0nDU40;T4n02Tl>@0aA440:chl03=7A@0202m3
@P0M03I;B`0gC4`0?55B03eEEP0jDU@0@EIL049FG@0oDeX0?51G04AHG`1;GfH0A5QO04=GGP1:GVD0
B5aS04=GGP13Eed0FFib05aaM@1<HFD0AeaO04]PH`1>HfD0@eQI049GF019GUl0BUmO04]PH01=HV@0
0`1DJFh204QMHP0Z05M/L@1WO840FVmd05AYKP1;H6D0FFic05Y^L`1FJFd0GG1d05M[K@1DJ6T0Gg=d
05ibLP1PM7<0HGEc06QlNP1SMgD0HWIe065dM`1UMgX0I7Ij06aoPP1WNWd0J7Ym06UlOP1ZOGh0Jgin
06aoO`1]P7l0KX6006f0O`1^PH40L8>306n2PP1`Ph80LXF507B7QP1dQhL0LhJ50764Q01cQXH0NHb;
0P1gRXT08P1eRHL0M8R607F8QP1gRhL0Mh^607F9Q01cQh40LhN007J:Q01iS8H0LX=k06n0N01hRH<0
MhN406moO@1cPh80MhN607J6Q01cQ7h0Kh1h06UjL01RMV/0HGEY05idI@1CJ5L0DfAB05EUD@1CHT`0
D5m904eMB@11E440AeU904AIC@1:H5D3055VGP05051UG@1?I5`0CV=K04eRFP1:GeL00P17G5@06P15
FU80@EI>03iEC00jDDP0?EA;04EKD`11ETd0>Tm603I;@P0`@cT09SP_02<f:`0/?C80;She02Td=00^
>Cd0=D9802llA00cA4d0;d1903A5C@0/>d008S4c02lk>P0U<2`07BPS0P0P;2L08`0T<2/08BdX01`Y
8P0N:b@062DN01PU7@0L:B406bPO01`Y7`0Q;RH07RLV024Y:P0R:R/08BTZ020X:@0K8b@072@U01lW
:00O:2P08BXZ020Y:@0N9B@0728P01XP7P0K8Al0728P01/Q7`0L8R005adK01<I5`10AT@082HT01@J
600K8Ah051TE0080724M00H0:c0/01hS7`0H7AT0724M01dR7P0E6QH201XO6`0:01@H5P0E6AT06QhN
01PL700?4a<07B4Q06Q/K02BUYH08bLW01/O7`805QXJ00L05aLE01`M600J6aH06AXE028S7P0D5A00
5AHA008071dH0P0D5A00100C50l05A@@01DD400E510201@C3`0@01<B3P0E51003`h:02XY9@0C4Ph0
5QDA010?2`0D4a404Q4?010?3@0A40h04a8@01@C4@0A40h03`h<014@3P8051<A00<04A0>010?3@0A
40h00P0B4@l301@C4@0<01DD4P0<2`T05QDC00T81P0K6QP0>SHe018>3@0E4A0030P701@@3`0=2@P0
5Q8A0P0C3`h00`0A3@`03PX901DA4004014=3006018>3@0C3`h040`;010<2`0>2PT03`/:0P0@30/0
200N6QT0EU9A01HB4@0<20L06ADD00h:2@0A3@`03`/:0P0>2PT200l;2P0L014=2P08104030P502hZ
9`0M6AH04@d:00h:1`0:1P<03@T600h:1`0C3``030P6010=300;20L03``;01PE500B3Pd04Ph>01<?
3P0@30/030P700/71P091PD04Ph=01HC4P0m>CP0510?018>3@803PX900H03@T800h:2@0?2`X03PX9
00d9200?2`X6010<2`803PX900T03@T800h:2@0>2PT03PT800l92@0A2`/040X:02PR8P0D3Ph00P0?
2@T0400>20P03`T9014;2`0B30`05@h?00H10P0>2PX02PP800L51P0C51804Q<B00P81`0:20P030P8
00T41@0C2`d300l92@803PP800L03@L700X4100F41003PP800/51@0>20P03`T900H03@L91P0>20X0
1`0R72005@lC00L11@0=1`/040X>00P21P0<1PX00`0>20`03P0?2@d03PP<00`11`0E2Q0060dC01<8
3P0>0`T03`@:01D:400A1``040H;03db>00e:S003P@95?ooool001_ooooo01P041DH00T>4@0:3Q40
310C00d?4`0A4QH05QLK00l?500=31404A0E01<B5`0@3a@04A4C00d=3`0D51H05ADG00h>400=3@l0
4A4C00d=3`0F5QP02PX<01/K7@0;2`d6010>4@08014?4P0K6A`01P@701HF6000008071`L00h>3@0>
3P`200d=2`8030`:00H03Ph<00@40P0D51809RHT01@D4P0820H2014B3@0>00X;1P0@4@`051D@00d>
2@0?40/05AHA014B3@0?40/03Pl:00l@2`0>3`X051D@00`=200B4`h200`=200D01TJ5@0/;BP051D@
014B3@0;30L0414<00P910092PD05aPC01<D3`0<3@P03Pl:00d>2@0;30L030d8010A300A4Pd03a0;
00d>2@0>3`X300l@2`0B010A300:2`H04a@?01DF4@0720<02P/600h?2P061`803Pl:01dN6@051P40
414<01DF4@0?40/030d8014B3@0B4`h030d81P0>3P`03P0@40h04A4?00h>300=3@/03`l=00/;2@0<
3P/03Q0=018D4@0=3``020X700lA3P0A4a00418?0P0?4@h200h@3@0>00h@3`0D5QD051HE010B4@0C
5A@03@l>00X<2`0>40l04A<B00X<2`0<3Pd00`D4014C4P0@4Q4200lA4004010B4@0A4a804A<B010B
4@803a4@01H04A<B018D4`0I6aP03Q0=02<U8P2k_KX08bDR018D4@0H6QL030h;00h@3@0A4a003Q0=
00lA3P0>3P`02PX800`<2P0?3`d0410>018B400A4@l04Q8@100C4a404P0B5140418?014C400C5A80
4A<@00lA3P12A4407b4N00`>2`1PHUl0CU1=00H81@0C5A804A<@00h@3@0D5Q<06A/H01LI5PD0418?
00<0418=00lA2`0?4P/0100?4P/06`0>4@X04aH?01<F3`0<3`P041<<01TK5@0B50l051HA018D3`0A
4`h05ALB00d?2P0>40/04Q@?01@F4@0B50l04A<>014D3P0D5`h05QT@018E300?4PT04A@;01DH3`0F
6A0051L>014D2`0200lB2@0Q00/?200M8Q`03a4<00h@2`0N7QH04Pl601XG3P0A3PD030`401`N5P0A
5Pl03a@?01PJ5@0@4``06ahG018E3P19C4D0?3lh014D3@0D5a006QdF01`O600J7AH05APA01HH4`0C
5A005aTD01HH4`0B50l06A/F01XL5`0I6aH05aTD00805ALB00T05aTD01/P6P0E6Q@05a`F01XO6@0`
=Bl0L7E_01/P6P0I7QP00`0G71H0100D6A<05AXC01LL5@0G71D201DJ4`0E01HK500K81T061dF01hS
700K81T07B8K038i<@0i@c/05R0H01<M5@0U;bL03aTA061ZHP0I8a/07BLO01hX800@6Q808B/S018M
5@0L:2@082`X00806RHR02`08BdY01l[9`0M:BD09S8^02Te<@0T<2`082`X028^:P0U=340;Shk02`l
>@0P<2d0:chl02Hi=`0Y>c/093Pg02Hj>@0Y?Ch09c`m02@i>P0_@d809CTh02a0?`0eBDP0;40o03=7
AP0[?ch0<4A303Q<B`0^@T40LXJ50<?GeP14EeD08cHd03=6A00bAD<0<dM602e1@00cAdH0=4U:03=8
B@10EEH0AemQ04ALGP80?E5H01<0?51G04MKHP1SMgh0HWIm041DF`1=HFP0H7Ak059VK@1>HVT0B5eQ
04QMH012EeX0B5eP04aQI012EeX0AEYL04=HF@12EeP0Bf1Q0080BEiO0240CfAX05EZK`1?I6T0QIZO
08fRY`1KL7D0D6EZ06^0Q@1BIf`0GG9g05Q]LP1GK740Ffmc05Y]L@1OLWH0FFa_05M[K01LL740GW9b
05ibL@1TN7H0NHf;06f1O`1RMW@0J7Yj06YlOP1UMgT0J7Yl069dMP1SMGL0JWan06]mO`1^P8000P1_
PH4206j0P00b0722PP1aPh<0LH>30763P`1dQXH0NH^;07N9R@1fR8P0NXb<07j@T021Ti<0LH>307>5
Q@1iS8X0NXf;07R;R@1dQh<0LhJ207B7P`1gRX@0MXV307>6P01`Pgd0LX=k07B5OP25UY00Pi>@07>3
P@1gQhH0N8R707F5PP1^OgL0JGY`06AfJP1NLf@0FVmP05meI01FJeP0DV=@055QC@1>GDP0>dXe051P
C@1CIED0DF=E03]@A00iCd<0AeaC04]PE`1?I5/2051UG00b04iSFP1;H5L0BUmF04QME017G5<0@eQ?
03eBB@0nED/0?5=903mFC011ETd0>4e40356?@0_@cX0?4e503Q9@@0^?cD0:CX`02Pg<00P:b`0=d96
03e;CP0X=Sd0;d1702/l@`0`@DL0:STl02Lg=`10C4/0<C`h01dX900K:2407b`U01h[900O;2D07BXS
01XW800K:2407R/T028_:00O;2<07BXQ024^9`0O:2P072@V02<[;@0N9RP06b<U01lW:@0P:2X201hV
:00E024Y:`0N9RP06R8Q01XP7P0H7Q`06b4O01hT8P0M8b4061hL02L]:`0M8b406AlM01DK6@0J81h0
61dJ010E4@0G71P08BHR03Pm>@0S:2@05a`H008082DQ00D05AXF01TN6P0J7a/061`J01/O7P02018F
5@0501dQ801;Cdh051PG02@X9`0H71/00P0I7A`03@0=4Pl06ATG010A300F5a8071dH03Pi=00I6QD0
5AHA01TJ5@0E5Q40414<01@E400E5Q400`0E51003`0D4`l04a8>01<B3P0Q81`030/701HE4@081`<0
3`h:01@C3`0;2PP040l=01@C4@0?3P`03@`:01@C4@0201DD4P0400X91`0D4a4030/901TH5P8051<A
0P0B4@l0100A40h040l=01@C4@0>3@/200l>30806aXH00X0Pgmn01@@3`0P71/040`;01<?3P0?2`X0
3@T801TE500U8B007QXI0P0>2PT0500?2`X04Ph=014=300>2PT03`/:01<?3P0A3@`040`;00h:2@0?
2`X04@d<018>3@0?2`X081`K00<0000A3@`03PX900`81`0B3Pd03@T80P0;1`H02`0>2PT040`;00/7
100C3``06QHC018?3@0300005Q8?00d91P0B3P/05Q8?008040`901P01`<000/81`0W8b800`0000d9
200H51<0510?014=30091@@030P701HB4@0<20L04`l>00<0000Q7A`03@T8018>3@0810<03`/:00d9
200?2`X040`;00l;2P0=2@P600`81`<03PX900X03@T800h:2@0>2PT04Pd<00@0000E3`l03PP800X4
100;1@D04@/;0P0?2@T03`0@2PX04P`<014;2`0>1PL07A@E00`61P0I5A@02`X800D5100000004A4?
014>3@0<1PH03PP800h61P0300l92@0900h8200=1`L03@L700h8200:10@050h>014;2`04000040X:
00H03@L91P0>20X020090`L02`D9018<400>20`0208601D?4`0=1`/02P@80P080PH01P0<1PX03`T=
0146300@1@/0304700d220804PL=00H03P<901H;4@070080:1dS02DL800L4ALDooooo`006oooool0
2P0<4A@03Q<F00hB5@0;3a802Pd@00/<400<3A40410D010?500>3A8200`;400801DE5`0=3@l030`>
00h>400?3a404a<E010@4P0C4aD200X:300D014A4`0C4aD03Ph@010@4P0H61X020H901DC5P0A3a80
61HI03Hd=`0D4QD02PP;01LE600>3Ph03`l>00d=2`0C4a40410>014A3`0;2`T200l?3@80410>01@0
3`l=00h>300C51000040014B3@0D5A0020T400`=200G61<01@H100T:1@0=3PT05AHA00h?2P0<3@P0
2``700`=200=3PT030d800/<1`803@h900l03Pl:00l@2`0?40/05AHA01<D3`000@004a@?00d>2@0I
6QD02``700l@2`061`805aPC00`=200?40/00P0>3`X0100A4Pd04Q<>00l@2`0>3`X2010A30803a0;
00@0414<018C3P0D5A003Pl:0P0=3PT01@0F5a804A8=014B3@0?40/03@h900<03Pl:1P0>3P`02`0E
5A<0410>00l?3@0?3`d03@d;014A3`0B51401`T600lA3P0B514030h;00@04A<@00D0418?00lA3P0?
4@h030h=00d?3P02010B4@0D00h@3`0<3Pd030h=01@F5@0=3`h02@/:00lA400B51<030h=00X<2`0;
3@`03a4@010B4@0<3Pd020X9018D4`0D5QD0418A00lA400B51<200/=2P0F01<E4P0[;BX04aDB00h@
3@0D5Q<04aDB018D4@0A4a00418?00lA3P0A4@l04a<A00d=2`0>3P`04Q8@00/;2@0=3@/04Q8@01<C
4@0<30X04Q8@00`<2PH03a4>00h06A/H00h@3@0=3``04aDB01DG500C5A80418?018D4@0@4Pl030h;
00h@3@0@4Pl0EUQE010B3`8030h;00H07b4N00/=200@4P`051L@00d@2@0C5Pl201DH4@803a8;00P0
41<<014D3@0A50d03@l9010B3@0F61<04Q@?010B3@803a4<1@0A4`h0:`0@4`d04A@=018E3P0A50d0
41<<018E3P0C5Pl06A`E0002000I71D051L@018E3P0=4@/05ahG0002000L7QH04a<;01@A200F4`X0
4@h5014A2@0E5`l041D>01<H4`0E5a804aH?014D3@0F6A806A`E01LJ4`0A50d04aH?01@G400C5Pl0
5QTB01hQ6P0E5a807AlJ01@F4@0G6A@06A/F04i@B`0H6QD00P0G6A@02P0F61<05aTD01PJ5@0B5a40
41D?01<H4P0J7aT0724K01DJ500@5@l201@I4`0301<H4P0D6A<041D?00<05ahG00/061lH01TP6@0J
8AX061lH01`S700940T06B0I01XQ6P0T:b@06B<K01XT700201/U7@0301`V7P0M9al072HN00806bDM
00H08R`T02<]9@0D7aL06RHR02He<00>7AP201l^:@0F024`:`0M;2L0:CPc02/j=@0U=2l093<^02`k
=P1PKf`0<T4n01l_;00V=S<09cXh02`o?@0]?cl0:Cdl02Di>00aADH0:Cho02@i>P0/@3l0<TI50314
@`80<dM600P0;D500314@`0`A4<0;d=20355A00iCD`0?U9A03A7A@80;d9002L0=4I60355A00^@T40
>4a=0315B00bAdX0CF9U03]CE@14G5h0@EEL041DF`0iCE@0BEeT082DV`1iSI@0Ae]R04EIH01BIVd0
EVYa04iRJ@19GV80AU]L04=HF@12EeP0AEYK04UNG`1;H680DFIY05AYK01=HVD0Bf1S04iSIP1AIVX0
D6EZ05AYKP1YOX<0L8F:069gO01CJ6d00P1AIV/0301DJFh0EFY_05Y_M01IKG40FFa`05e`M01JKW00
Ffm`065eMP1UNGT0HGEd069fM080IGUg01l0JWil06eoO`1KKFd0RifM07>5Q@1MKfl0IWQh06anOP1[
OGd0Kh610763Q@1`PX@0LH>407>5Q@1eR8H0MhZ807F8QP1dQhD0MHR608RKV@1jSH/0M8N507N:R01e
R8H0NXf;07B6QP1cQHD0MXV707R;R@1gRXP0N8^70080MhZ602P0MXV307N:Q01cQX00JGaf06]lMP1f
QX80NHV607F5Q01cPh80MHF407N7QP1cPh00KGif06UjL01RM6P0Fg1Q05EZF@1HKUX0EfaI05=TD@1;
FdP0BUU603i=>P18EdL0AeU;03i@@P0eBSh0?59604UNE@1?I5/0EfaS09V^Y@1JKfH0L8El04MLD`1>
HeX0BUmF045FC@0mDTT0@EI=0P1:H5@06P0nE4P0=DY102/o=P0O<bX0;Slg02dn=P0/?CD0:CPa02@c
;00S<Rd09S4b03M2AP0e@dH0:SPm02Hh?00[?D40:S`o02dl?`0U=CD0930_02@_:`0P:bL08RlW01`Y
800Q;RD08BhW0P0J9b0201l/9@0F020]9P0Q;RL062DN020/:00S:b`09bla01hV:00O9bT08RX/01lW
:@0P:2X08RX/020X:P0N9RP082PZ024X:00H7Q`05Q`J01XP7P0G7A/06R0N01`R808061hL00@05Q`J
01DK6@0E6aT06R0M0P0J7a/04@0N8al06AhJ01DJ5P0F6aL07B8N01TN6P0B5a<06b0L01TN6P0@5180
61`K01TM700@51<0HVIU0>7Ui00k?ch061`K008051PG00h05a/J01TN6`0J6QP06Q/F01HG4P0C50l0
5AHA01<D3`0H6A@03Pl:01@E400G61<06AXE01@E40804Q4=0P0G5Q80200D4`l05QDA01LF4P0A40`0
30/7018A3@0E510040l;1P0C4Q000`0H5aD040l=00P71@0201@C4@03014@3P0B4@l04A0>008040l=
00@04A0>018A3`0C4Q004Q4?0P0@3`d2014@3P0501PD4`0:1PD05A4@01`H5`0B3Pd00P0?2`X02@0E
4A004@d<014=300<20L07ATH020L6`0?2`X040`;00d9200301HB4@0401<?3P0;1`H02PH501TE5080
4@d<0180510?00d9200=2@P07ATH00X61@0B3Pd04@d<010<2`0?2`X030P700/71P0B3P/00`0000l;
200N6QL0VYJC02XV8`0?2`P300h:1`803@T600`03@T8010<2`0>2PT04@d<018>3@0?2`X03PX900d9
20091@@03PX900/71P0>2PT500`81`803PX900<030P700/71P0<20L00`0>2PT00`0A3@`03`/:00h:
2@02010<2`0700P40`0?2`X0<bl^01HB4@0300003@P700d71`02010:2P803@L700X030H600/51@0>
20P04`d=014;2`0=1`L03@D600l61`0>20P03@T80P0<2`T02P081`D030/900l;2P0:10@0208200l6
1`0E3`l0100001TC4`04000201LA4@0<014;2`0<1PH030H600d71`0;1@D03@L7010:300:10H04P`>
00`620090`D030H81P0=1`T03@0<1PX03@L;00h8300>20`03@L;00`62P0@2Ph03@L;00`62P0>20`0
3@L;00X4200700800P0F2a401@0700803@880146300@1@/04@H<00804PL=00<04@H<01052oooool0
4oooool001_ooooo00D02PlB00`A500=4A@02`lB00/=4@0200d>4P05010@5@0B4AH040lD00h=4P0?
3Q<00P0C4aD01P0=3@l030`>010@4P0@41803`lA00`<3P804A4C0P0<30h04`0>3a802@T<010@4`0=
3A005A@H010?4`0A41@07adQ00h<400?3A40518F00`<3P0?4Pl03a0>00/<2P0?40d051@B00`<2P0>
3P`00`0?3`d04`0@3@`03`h<00l@2`0B4`h05AHA00l@300K71L030d802h_:P0G61<04A8=00h?2P0A
4Pd02``800d>2@0>3`X04A8=018C3P0?40/01P0>3`X0300:2`L07AhI00`=200N7aX051D@00/<1`0C
50l051D@00D60P0?40/03Pl:01HG4P803Pl:00D0414<014B3@0>3`X03@h900h?2P0200l@2`80414<
00d04A8=00l@2`0;30L04A8=01<D3`061`8092DP01<D3`0A4Pd03a0;010A300A4Pd0414<00H03Ph<
00`03`l=014A3`0?3`d03Ph<01<C4@0E5A<04A<@024S800k?CX051HC01HH5@0?4@h2014C4080418?
0P0?4@h00`0=3`h03Q0?00lA400200lA400600d?3P092`X0418A00h@3`0=3`h0418A0P0>40l0400@
4Q404Q@C018D4`0A4a803a4@010B4@0B51<02`d<00lA400F61L02@/:00d?300F61D020T700`>2`0?
4@h3014C40803a4>00D03Q0=00d?300<30X03`l=010@3P0200l?3@0701<C4@0A4@l03`l=01<C4@0B
4Q0051@B00`<2P0600lA3P0601HH5@0>40d03@l<010B3`0?4@h03@l<0P0C5A803P0A4a003a4>010B
3`0B5140>3Xg01@F4`0E5a@03Q0=01/M6P0>40/04A<=01@G400=40T04QD>0P0D5a00300A50d05APA
01LJ4`0F6A804aH?01<E3`0C5A00418=00h@2`0E5a8051HA018D3`804aD@00D04Q@?010B3@0?4@`0
4Q@?014D3P0200h@2P0E018D3P0D5Q004QD?01PK5@0B50h0A4M101/M5`051`@04ALB018J4`0E7QH0
310801@E3@0I6Q0061L=01HF300C4`/04aD=018E3P0G71L04aD@00804aH?0P0D5a003P0E61405QTB
01LJ4`0G6Q<051L@01<F3`0F6A805QPC01XL5`0C5A006adH01@F4@0B50l061XE0P0G6A@00`0F61<0
5aTD01PJ5@0201LL5P0F01/P6P0P9Al07R<M01<H4P0H7AL06b0J01TN600H7AL07B8L01hS7@0H7QT0
5A`F01LM600F7AL05Q`G01`S7@0H7aT05A/F024W8P0K8Q`07bHP01`S7@H06bDM00/072HN020Z8P0M
9al07BLO01lY8@0L9b409C8^01HU8@0W=S805bLS01h^:P0201d/:00A02<b;P0U=C408c<_02@c;`0X
=c<0;chk03A3@00iBDH0:SXg028e<`0[?S`09cTi02a0?`0^@T40:3`m0315AP0^@d@00P0cAdH0100_
@d80<DE40396A@0_@d820396A@0O0314@`0^@T40<4A30396A@0eAdH0=dU803E8A`0cADD0=4Q803I:
BP0fBT`0>TmB03eBE@0mDUH0?5AG055YK@1>HVT0D6A[04iRJ@19GF@0B5aS04UMI016FV40B5aS04mS
JP1<H6L0BUiU04YOH`19GUh0BUmO04]PH00204]PH@0c04]PHP1AIVT0E6U/04mTI`1?I6P0DVM[05=X
K01EJVl0F6eb05aaMP1JKg@0EFY_059WK01YOX<0NHjC05icN01KL7D0HgQm05U]L@1ML7@0H7=g061d
MP1PM7D0HWIg06AhN01QMG@0IGUg06QlNP1WNgT0Jgmm06aoO@1[O7X0NHZ906UjNP1TMG@0HgAc06am
O@1^Ogl0LX>30761Q01`P8<0LX>40763P@1dQH<0MhR607J8Q@1fQhD0N8Z707R9Q`1jRhT0Nhf:0080
N8Z700T0OHj<07R9R@1hRHT0NX^:07Z<RP1jRhX0NXb807V:Q`1hRXH00P1iRhD06`1dQX00KGmi06]l
M`1hR8D0MHF307B4Q01iRHP0Lh>207F5Q01`P7`0IGI^05m`IP1MKf80GW=R05AYEP1IKe`0CfAA04aM
B`1;FTX0A59203]9>`0lBSh0=4Hk0353>00mDTP0DFIM059WGP0204mUFP0306MmLP15FU00D6IK0080
C65G02d0B5iC04AJC`12F4d0A5Y>041FBP0kD4@0=T/o02m3>@0[?SD0:Sdd02/l=00W=c409SH`02Lf
<00V=Bl093<_02df>@16DED0AUAG03M5B@0_@D@0<dE602m1@@0]?C`09cLf02Te<`0W<Bl08B`X020]
900V<bX0:cP_02@a:@0M:R<082dV02Db:`0P;2L08c0Z01h[9@0S;bX082`X02</;00T;Bd082TY028Z
:`0Q:BX00P0L9BD02`0N9RL07bPX01hW9`0M9BH07BDS01XP7P0H7Q`06R0N01HL6P0E6aT06AlM0080
61hL01l06b4O01dS8@0N92806AlL01LL600L8Ad07R<O01HK5`0H7AT07R<O01`Q7@0H7AT06QlK02P]
:@0U:RH061dI01XN700G6aT06b0M034e<`1iOG/08bLU01@I5P0G71T03a@A010E4P0G71P051D@01DF
4@0F5a8051D@00804a@?00L061TD018C3P0G61<0414<018C3P0D5A0061LC008051<?00D04a8>014@
300I61@06APD01HE4@0201<B3P0301@C3`0C4Ph04a8@00D04a8@00P03Pd;01HE4`0Y:2H061LE00/:
2@0E51804Q4?014@3P8040l=00<04A0>018A3`0A40h00`0B4@l0800A40h03`h<00`81`0G4a802@D4
01TE500`;2/03PX9010<2`0A3@`03@T801<?3P0G4a80:bLV06MSHP0@30/06ADD00X71P0F4Q404Ph=
06=OGP0G4a804`l>014=30091@@04@d<00l;2P0>2PT030P7010<2`0=2@P040`;0P0?2`X02P0>2PT0
3`/:01<?3P0G4a803PX700d91P0<2@L06aLD08f9QP0_:bP200h:1`803@T60P0<20D00`0?2`X04@d<
00h:2@02010<2`0700d9200?2`X03@T8010<2`0;1`L04@d<00h:2@0500`81`0500d9200>2PT03@T8
00`81`0=2@P00`0>2PT0300@30/03PX900d9200>2PT04@d<00T5100>2PT081`K010<2`091@@03PT9
00h8208040X:00@03@L700h8200G4A405@l?0P0;1@D2018<300N0108200@1PH03`P700d91`0>2PP0
30/800X91P0=30T040`:00`71@0<10<04@P800P10@0E3`l0@S`l01D?3`0A2`/040X:00`61P0:10@0
3`T9018<300?2@T03PP802lY:`0J5AH03`T;00d72@0@2P`04P`>1P0=1`T02@0<1PX03@L;00h8300>
20`03@L;00`62P0?2@d03@L;00`62P0200h8300900/52@0I3Q@03`@:00d2200H3A<03`D:01<83P0@
1@/04@H<00804PL=00<04@H<01052oooool04oooool001_ooooo00X0314D00lC5P0?4aH03Q8E010C
5P0D5AT04Q<G01@D600C4QL040lD0P0>3A80200B4Q@02PX<00d=3`0>3Q006ATK038b=00Y:B/03`lA
0P0=3@l04`0;2`d04A8D00`@4`072`h041@G00L93@0@4AD04a@H00d<4@0;2Pl03@/@00l=4P0=2a00
3@d?00d@3P0<3P/02P`900h@3@0;2`T00P0=3@/04`0>3@/03`h<00l>300@30/03@`:00`<1`0?40/0
414<00/<1`0L7AP0UiRC06UZI@061`804A8=01@E400>3`X05AHA00`=200>3`X00P0D5A001@0A4Pd0
3a0;00l@2`0?40/03Pl:00803@h9010030d800P910051P4030d800/<1`0<3@P010D101PI500;30L0
:2TT01HG4P051P40414<00h?2P0A4Pd0414<100>3`X0300?40/04A8=014B3@0?40/04Q<>01PI500?
40/06AXE00`=200o@3/04a@?014B3@803a0;00<0414<00l@2`0>3P`01@0>3P`0300F5Q@07QhL01@D
4P0:2PP04A4?00X:200A4a000P@101HH5@0>40d02@/800P:1`<0418?0P0?4@h00`0>40d03Q0?00h@
3`0600h@3`0F00lA400A4a804Q@C00lA400;3@`0418A014C4P0@4Q4051HE01XL6`0@4Q404aDD00d?
3P0H6QT0;2h]01hP7`0E5a@01@L401TK600H6QL02P`900lA3P804Q@A0P0A4a02010B3`0501<C4@0?
3`d051@B01<C4@0?3`d00P0D51801@0C4a406ATG01DE4`0C4a402`/900H03Q0=00H030h;00/=2P0=
3``04Q@A014C400?4@h2014C4080418?00d04A<@018D4@0=3``02@/8014C400<3P/051HC00d?2P0;
3@L04QD>00hA2P0B5@h04A@=00803Q4:00X04A@=01@G400B5@h04A@=014D3P0B50l03Q0;00/=200B
50l04aD@0`0B50l0900A4`h0418=010B3@0C5A00418=00/=200?4@`05ALB01@F4@0>40/04A<>01PJ
5@041P<04aD@02@V8@063@P02aH>03@o=`0D71<06QdD01PK400I6a0071hC01PI4@0F6A404aPA01XO
6P0B50l05APA01LJ4`0C5Pl04A@=01@G400C5Pl051L@01HI4P<05APA00L03@l:01HH4`0D5Q404A<>
01@F4@0I6aH061XE00805aTD01/05QPC01LI500H6QD05a`F01HK5@0H7AL06QlI01PM5`0@5@l061dG
01/P6P0I7QP061dG01dR700N8ad051XF020V8P1KHEd0EeeI01TO6`0B61@05adI02`b;P0;4@d0318>
02hd<00N92000P0L9Qh0400K9Ad06R@L01XT700I8a/05b4I01hX800L9Qh06R@L01`V7P0H8ad072/V
028b;`0Z>SL0:c/h024a;P0O;b`2024a;P0802<c<00V=S<0:3Pe02Lg=00^?CX0:CPe02hn>`0_?c`2
02Hi=`0802@f=P0X?3/07S8a04AHF@1WO7d0;T=403M;BP0fBTT303E9B00303A8A`0bATD0=d]:0080
>4a;00<0=d]:03Q<B`0bA4@00P0dATH03P0bA4@0=4Q903M;C013EUX0=da?03U>D@0oE5T0DVY^04EM
H@1?HfX0AUYQ04=GGP16FV40B5aS0P1:GVD01@1<H6L0D6A[04aPI`1;GfH0C65T0080BV1N00P0BEiN
04MLG@16Fe`0AeaN04eRI@1@IFP0CF9V051UJP80DVM/00`0EFY_05Q]LP1GK740EFY_05Q]LP1JKg@0
O96F09V^/`1YOX<0DFI[06EjO`1RMW/2065dN00706IiO01TN7T0HgMh06MkN`1YOG`0KH5o06n3P@02
06]oO@0M06alN@1fQX<0KGej06moOP1ZNWT0J7Qg06]kN`1bPX80MHF5071oPP1aP8<0MHB607>3PP1e
QH80MhN407J6P`1eQH80MhN407B4P@1kRhP0N8R507Z:Q`29VIH0UjNT07b<S01nSXh0O8b;07Z:R@1l
S8/00P1kRhP0<01iRHH0NX^507Z;Q@1eQX00LhAn07f=RP1hR8H0Nh^:07B4Q01[Ng/0NXZ90720O`1]
OWP0HW=Y05Y/H01JK5d0GW=R04YOC01=He00DFIE051QD@14DdH0?T]1034n=@0]>c<0;3de03Q9@`1<
H5T0E6UR04]PE`1:H5@0DVQL04AJCP1<HUH0CfEI04iTF017GE40@eU=04AJCP15Fdl0@eU=03eCAP0e
BCh0=TXo02m3>00/?CD0<T<k02Pi<@808C0[01009cHa02Pg<P0Y=C<09Rlc045<D012D5<0<3m102Tk
>`0_@T00<DA202Ti>00V=SD0:SHd02H`;`0P:bL082dT0`0O;2<0500V<b`0;3Tb034n=`0T<2`0:3@`
01dY9@0]>CD07b/W02@]:P0Q:RT08R/Y02</:@0O:2L07RLU024Z9`0Q:RT08b`Z028[:00L9B@06B4N
0`0K8Al0800G7A/05Q`J01LM6`0M8b408RPV020V900I7ad05adK01HK600F6aL06QlK01`Q7@0F6aL0
6AhJ01`Q7@0G71P051TE01PM6@0U:RH08bPT01PM6@0L8Ad041DA01PM6@0:3`/06QlK020U8@0G71P0
5AXF01lT800U:RH061dI0P0H6A@201XK5P805AHA018061TD01@E400E5Q403@h9018C3P0G61<061LC
01@C3`0B4@d04A0<010?2`0H5a<05aHB01TH500H5a<04a8>010?2`0B4@d601<B400800d<2P0E5180
5QDC00X91`0Z:BL030/9018A3`0A40h2010?3@04014@3P0B4@l03`h<014@3P804a8@00P040l=00d<
2P0C3`h030P700l;2P0I5A@06aLF010<2`80510?02<04@d<01@@3`0710<02@D400<0000A3@`03`/:
01hJ6@0=2PT06QHE00/71P070`<05A4@01<?3P0@30/020@3018>3@0?2`X03PX901DA40060P406ADD
00l;2P0B3Pd040`;00d9200@30/0510?01DA3P0H51404`l<01HB3`0:1P<00`00010<2@0200l;2080
3PX700<03@T6014=300B3Pd00P0?2`X0200>2PT02PH5010<2`0B3Pd02@D402/W9P1<B4L04Ph=2`0=
2@P300h:2@0Y00d9200;1`H02`L600h:2@060P402`L600X61@091@@040`;00d81`0@2PX04@/;00l9
2@0=1`L03PP801D?3`0D3Ph03`T9010:2P0B30`03`T900l61P0A1`H040P600h91P0=2@H030X600/:
1P0=30P040`901081P0?1`D04`T801/B4`0600002PD500@0000F41004P`<00`61P0;1@D00P0>20P0
1@0:10@02`D502`V:00G4A<04@/=00804P`>00<02@@500d72@0=1`T0100=1`T02@0<1PX03@L;00h8
300>20`03@L;00`62P0>20`03@L;00`62P0200h8300800`62P0A1P`04PL=00l42P0D2@l02P4500h3
2@0?10X40146300300l42_oooooooooo01;ooooo000Kooooo`0E00dB5@0?4aH03a<F00hB5@0A51L0
5QLK010A5@0B4QL04Q4F010?500A41D04Q4F01PH6P0=3@l05ADG00X:300B4Q@0CdmA02d];`0>3Q00
2PX<008030`>02@04a@F00D;3P0730l041DH01DJ7@0830l01`/>00d>4P0:2`l04A0E00/:3`0920d0
3`lA00`@3@083@T03a@@01@F4`092@L061PF00d=2`0>3@/03`h<014=300@30/03@`:00`<1`092PD0
4a@?00/<1`0U9R40^[^f07AeL00<3@P04A8=00X;1P000@0200/<1`0400d>2@0B4`h04a@?010A30<0
3a0;02L03Pl:00d>2@0=3PT04Q<>01HG4P0J6aH03a0;00/<1`0=3PT0414<00h?2P082@@0;2dX00/<
1`051P404a@?010A300A4Pd0414<00h?2P0?40/03Pl:00d>2@0?40/04A8=010A300?40/02``701LH
4`0?40/06a`G00d>2@0E5Q404A8=00l@2`0=3PT03Pl:00l@2`0>3`X01P0>3P`0300;2`T05ADC010@
3P0<30X05QHD01<C4@0L7Q/03a4>00d?300M7a`05QPE01TK6080418?0P0?4@h200h@3@H03Q0?00@0
418A00d?3P0=3`h03a4@0P0@4Q404P0=3`h03Q0?00d?3P0<3Pd04aDD01dO7P0A4a805ALF00/=300>
40l06adL018D4`0<3P/04A<@00h@3@000@004Q@A00`>2`804Q@A0`0A4a003@0@4Pl04Q8@00`<2P0@
40h051@B01<C4@0B4Q004A4?000000051@<0410>01LG5@0A4@l01P0>40d01`0;3@X03@l<00lA3P0C
5A804Q@A014C400@4Pl00P0>40d3010B3`0=01TK600D5Q<05aTF01@F4`0B51402`d800h@2P0I71D0
5QTB01XM5P0F6A804QD>00lB2`0200hA2P0900lB2`0@4``04Q@>01LI500H6QD04aD@01@F4@0F61<0
4Q@?0080418=00P04A<>018D3`0B50l04aD@00lA300=3`X04Q@?01HH4`804Q@?00/01@L201XL5`0E
5a80418=01/M600=5@l02aP?030m=00E81D04a/@00lE2@0201HI3P0C01@G3P0E610041D>01<H4`0C
5A005QTB01TL5@0E61404aH?01HI4P0C5Pl051L@01DH4@0F6A805aXC01HI4P0<3PT051HA01dO6P02
01HH4`0>01DG4P0H6QD05aTD01LI500F61<05aTD01PJ5@0E6Q@051TC01<H4P0D6A<05AXD01@I4`0E
6Q@201TN600?01PM5`0J7aT05a`F01HL600<5A007RLR01`U800=5Q408BXU020Y901:Ddh07BHQ030i
=00U;RT04Q/F00807BLO00L072HN01/U7@0J91`06R@L01/U7@0P:R808B/S008092hV01/06RDO028a
;00O;b`07Rh[06MgM00X>3D0;Cdj020`;@0N;R/07bl/02<c<00U=C808c<`03U8A@0X=c@093@a02dm
>P0X>cT09CPf0312@P0bATD0;D5005ibL`25VY/0BUmP02m3@P0aAD@00P0cAdH0500aAD@0<4A302/o
?P0bATD0=DU803I:B@0eBDP0=TY903=5A@0`@T80<TA403I8BP0fBT/0=DU:03iAE@0oE5T0D6EZ03Y?
E01?If/0?UIJ0`1<H6L0601:GVD0AEUP04QLH`17Ff80AUYQ04eQJ01;GfH0Ae]R04]PHP1=Hf00B5iL
04AJF013FEL0AEYK04YOH@1BIfX0E6U^059WK01FJg00F6ac05EZL01DJFh0EV]`05Y_M080G75f0P1M
LWL01@1UNWl0H7Ej05mdN@1VNh00HgMk0080HGAh00L0Ig]m06EiNP1TN7T0J7al06QlN`1]PGl0Kh>1
0080Jgmm01@0KGej07J7P@1_P7X0MXJ306IfL`1XN7L0K7al07>3P`1eQHD0LX6407J5R01gQhP0MhN6
07R8Q@1iRHH0MXJ307>3P01dQ840O8b907j>R`80MXJ300X0Pi>@08JFT`1nSXh0PI6A07f=S01iRHP0
O8b;07Z:Q`1kRhP0N8R50P1kS8H08`1dQGl0MhR208NGU01cPh80JGUh07R8R027UiL0OHf<06moOP1^
OgT0IWM]05maI@1KKEh0Fg1M051UDP1<HU00GgAS05i^H@12DDL0?T]2045>A`0fA3h0<T<m049BC`1E
JF@0D6EP04aQF01=HeL0F6iR03iDB01>I5P0B5iB04eSE`14FTh0?eE90080@EM;00P0?UA803E9?@0_
@cL0<dLk02i2=`0[?380<T<i02Lf;`808C0[0100:3@b02`h=P0/>3P0:S@g03m:CP0mBdh0;Sdn02do
?`0eB4H0<4=002Hf<`0T=340:3@b02<];00O:RH082dS0P0K:1h05@0T<BP0:cP_02`i<00[>34082`X
02Hb;P0M:BL0;SXh020/:00U;RX082TV028[9`0R:bH07RLT024Z9P0U;RT08b`Y02@]:@0Q:RD06R<P
01PO7@0301`R800901/Q7`0J81h06AlM02D[:@0`=S@0:Bl]01TO7@0G7A/06R0M00805a`H00@06b0L
01PM6@0H7AT061dI0`0F6aL01`0J7a/06b0L01DJ5P0O92004aPD01PM6@0L8Ad00P0P9B403`0K81`0
51TE01`Q7@0J7a/03a@@01@E400@4@`04a@?01PI500F5a806AXE020Q700I6QD061TD01HG4P02024R
7@0<01DD400C4Ph05A@@01@C3`0@3`/05A@@01@C3`0G5Q8061LC014@300>3@T04A0<1P0C4Q0201@C
4@06014@3P0=30X0<c8`014@3P0B4@l04A0>0P0@3`d02P0A40h04Q4?00h=2`0A40h04a8@018A3`0?
3P`030/901LC4P0:1PD201DA400K00P40`0A3@`040`;01<?3P0D40l06QHE010<2`0C3`h06QHE01HB
4@0810<061@C00`8200D40l04Ph=01/G5P0?2`X01P<201HB4@0B3Pd03@T801<?3P0B3Pd04`l>00X6
1@0A3@`03PX900804@d<0P0=2@P0200?2`X020D301TE4P08104020D3020L6@0300004@d:0`0@30T2
00l;20804Ph=0P0?2`X0200>2PT02PH5018>3@0G4a802@D401lK6P0n>ST030P72`0=2@P200h:2@80
3@T80P0<20L01`0>2PT030P7010<2`0;1`H03@T801@@3`0?2PX00P0A2`/01@0?2@T03@L700h8200>
20P03`T900804P`<00H03PP800d71`0@1`L04@L601081P0>2@H300d91P0G00h:1`0@2`P04@T70108
1P0C2@P05@`=00h8200D3Ph01@00018<300?2@T03PP800`61P0=1`L030H600X4100B30`04P`>00D0
0@0:10H03PP:010:300<1PP01P0=1`T01`0<1PX03@L;00h8300>20`03@L;00`62P0>20`00P0<1PX0
100>20`03`T=00`62P0;00H201@93`0501052`0K41H02@0400l42P0@1@/00P0A1P`00`0@1@/03`@:
ooooo`0Cooooo`006oooool0200<4A@03A4D00`@4`0:3Q403Q0D01<D600<3A403PhC0P0@3a@08@0C
4QL05aHK04Q8BP0B4Q@02PX<018B500;2`d04Q8D01@D5P0:2P`030`>014A4`0>3Q0030d?01DL7P0@
6A/05b0R03Lo@@0@5aX0314D00hA5@092a00418G00/;400:2@h03a0C00hC4@0=4Ph01@X6014C4006
1`@05ADC00h>3002010?3@0:018>3@0A30`04@d<00d=2@082@@03a0;014B3@0@4@`08R<N01`M6080
2``700<03Pl:01@E400<3@T00P0<3@P0100?40/0414<00h?2P0=3PT500h?2P0C010A300>3`X00P<0
01@E400e=S40414<018C3P082@@04Q<>038c;P0@4@`03a0;00/<1`0>3`X03a0;00h?2P0=3PT03Pl:
00l@2`0200h?2P<03a0;00T0414<01@E400;30L04A8=01<D3`0?40/04Q<>010A300>3`X00P0?40/0
0`0>3`X03Ph<00h>300400h>300900`<2P0@40h03`l=00l?3@0B4Q004A4?00T;200H6QL04A<@0080
3a4>00@03@l<00lA3P0?4@h03a4>0`0>40d200lA400<00h@3`0=3`h03a4@00lA400=3`h03a4@01<E
500A4a802`d<00h@3`0D5QD0418A0P0=3`h0100A4a8051HE00h@3`0>40l200`>3@0800h@3`0A4a80
3a4>01@F4`0i>cP04A<@00/=2P0D5Q<600lA3P0500/;2@0D51803Ph<00h>300E5A<00P0A4@l01@0/
;2X0<S8`010@3P0=3@/05QHD00H0418?0`0A4a001P0@4Pl03a4>00lA3P0@4Pl03@l<00h@3@804A<@
01D0418?00lA3P0=3``03Q0=014C400@4Pl0418=01DH4P0J7AH051L@01HI4P0C5Pl041<<018E3P0@
4``03a8;014D3@0B5@h041<=01<E400E5a800P0A4`h01@0B50l0418=00lA300@4Pd04Q@?00804aD@
00D04Q@?010B3@0@4Pd04aD@01@F4@02018D3`0K01@F4@0O8A`061XE01LI500:30L051lH02Lg;@0J
:R002aL<018L4@0=5@P05Q/@01@H3@0E6A005a`D014H400B61<04QLA01DH4@0H6a@06A`E01PK500G
6Q<061/D01HI4P0E614061/D00806A`E00L06adH00lA300H6QD051HA01DG4P0I6aH061XE00805aTD
00<05QPC01LI500H6QD00P0F6aD201@I4`0301DJ500I7QP05AXD00806AhH00l061dG01XO6@0F71H0
3Q@@01dV8@0G81/04a`G01TR7@0F7aX07RLR02/d;`0N9b80>T<n010I500Q:RD01P0N:200>00L9Qh0
8B/S024[8`0S;BD09c4Y028]9`0O;RX08c<a05EUH`38emH0AEEC028b<00V=S@09CDc02@d<P0U=C<0
9cLe02Ph=P0^?CX0;C`i02dm>P0_?c`0:Sdk02Lj>00]?cl0:Shm02e1@00^@T<0=da=0397B00`A4<0
<TI503M;BP0eBDP0<TI503A8A`0^@T40=4Q703I:B@0dB4L0<TI50355A00eAdL0<dE603E7B00kCDl0
>dmA03Y>D014Ee/0@eQM03mDF@1SN7d0^=3D06Z2QP1=HFP0B5aS0P15FF005019GF@0Cf=Z04iRJ@1<
H6L0D6A[04eQJ01;GfH0CfEV04iTH@18GU`0@eUG04MMF`1<HF80D6EW05=XJ`1DJFh0DfQ]05Q]L`1I
KG@0F6ab0P1HKG80701LLGH0GgAi05icN01MLWL0G75f05U^L`1VNh00GgAi05U^L`1XO800HWEi06=f
NP1ZOX00Ig]l06]oP01^PX80I7Qg06IjN01XO7X0IGUg06QkN01[O7H0L81j06inN01dQ800JGUe06Uh
MP1_OWh207F4Q00407R6R@20Si80O8^=07^:R@80O8b900<0N8N407F4P@1eQ8400P1gQX<0C@1kRhP0
PY6>08:ASP1lRhP0QIBD08VHV@22TI00NhZ9082?S`1nSHX0OHf:07V8Q@1mSHP0O8b707F5O`1lS8L0
Nh^:0761P01aPH40Y;Bd0<?Cd`1lS8/0M8B306n0N@1YNW00IGM[05i`H01DJEH0DfQF04iTDP1DJEX0
E6AI04=AB@0kAd<0FVIS05=PG`17EeH0CUiN05Q[JP1>Heh0AU]B04ILC`1@IUT0Aee@04mUF01;HE@0
Bf5E04EKC`10ETT0?UA703Y@A00fC3l0AEU=03a@A00cAc/0:Sdb02Df;00T=B/093</02@c;P0R<B`0
9C4_02Xf=@0^>SX0;CHj03E0A00a?d80:STi02m2@00gBTL0;d8n02Lg=00U=C808bl]020Z:@0Q;2P0
82dS00808c0V00h0:CH/02Pe;00Q;RD06BHO01TU8@0Q;BT082`Z02Hb<@0T<2h09c0Z024Z900Q:b@0
72HO01dV80<082XS00L07bTR01/U7P0I8Q`06R8N01lU8`0N92806R0N0080728P00`05Q`J01`R800U
:bT08BLU01HL6P0G7A/0724N01PM6@0G71P06QlK01LL600F6aL301TN6P0P01LL600E6QH05a`H01HK
5P0L8A`04aPC00lD3`0J7aX05AXE00`A300D6A@05a`G01TN6@0>4`h09R/V03<d;`0R8ah05QLB01TJ
5@0E5Q404a@?01XK5P0F5a8051D@018C3P0O81/07AhI01<B3P0B4@d05aHB01HE4@0A40`2018A3@05
01@C3`0F5A404Q4=010?2`0A40`01P0C4Q001@0?3P`03Pd;01PG5@0B4@l04a8@00804Q4?00L04A0>
010?3@0@3`d04A0>018A3`0@3`d04A0>008040l=00/03`h<00h=2`0?2`X0510?014=300@30/04`l>
018>3@0@30/04@d<00h:2@0201<?3P0602<O7P2ETI0081`K01DA400:1PH05a<B0P0?2`X060091PD0
510?00l;2P0>2PT030P800l;2P0F4Q403PX901@@3`1BCTd0>cLf01<?3P0?2`X03PX9014=300@30/0
3`/:00l;2@0=2PP030P5010<2@0;1`H05a<@010<2@<03`/80P0>2PL00`0A3@`04Ph=00l;2P0200l;
2P802`L600<04@d<01DA400:1PD00P0@30/500h:2@803@T80`0>2PT04P0=2@P03PX900h:2@0=2@P0
3PX9010<2`0>2PT030P700l;2P0<20L02`L600`81`0;1`H04@`;01<=3@0B30`03`T900d71`<03PP8
02803`T900d71`0;1@D03`T901<:2P0C20L04@P600h91P0>2@D030T500d91@0<2@D03PT501491P0B
20L04`P700d51@0>20P04P`<00X4100D3Ph03PP800l92@0>20P040X:00h8200=1`L06A<C020J700B
30h03`T;00X51P0;1@L040X<1P0=1`T01`0<1PX03@L;00h8300>20`03@L;00`62P0=1`/00P0<1PX0
2P0>20`03`T=00d72`0B1`d040H;0146300I3Q@0:QlU00X11@0?10X401052`0300l42_oooooooooo
01;ooooo000Kooooo`0B00lB5`0?4QH0310C00/?4P0?4AD04a@H018C5`0B4QL040lD00d<4@0>3A80
40lD01LG6@0B4Q@020P:00X:300A4A<03Ph@0P0@4180300<30h04A4C014A4`092Ph04ALK00082`03
2`h03ADH00052@0;41<03A0D00<72P803@hB02003PdB00`=3`0Z;b`09b`X0043000@4Pl02`d:00X:
200?3`d040l=014@3P0B3`h04Ph=014=300@4@d0410>01PJ5@1LGEX05QHD00H80`0B4a0010@200X<
1`0@4@d05QHD00l@2`0>3`X03@h900h?2P0?40/03Pl:00`=20803@h902@03Pl:00l@2`0?40/0414<
00P9100G5aD030d801`M600=3PT01`P501lP6`041@003Pl900`=1`031000414;00/<1P0<3@P02P/6
00T:100;30L03Pl:00h?2@0=3PT030d800h?2@0@4@`03a0;00X;1P0E5Q403Pl:00T:1@0:2`H04a@?
014B3@0?40/3010A30H03Ph<00`03`l=00/;2@0>3P`0410>00d=2`0>3P`05aTF00D7100?4@h051HC
00h@3@0<3P/300lA3P0=00h@3@0=3``03@l<010B4@0?4A003@l>00`>3@0>40l0418A00d?3P0F61L0
8B<R01/M700200d?3P0B00lA400>40l0418A01@F5@0E5aH0418A01HH5`0:30/04Q@C01@F5@0=3`h0
4aDD01DG50082PL08bDR00T;200M7a`01PP51@0A4a002P0B51403a4>02PZ9`0E5a@01`T6014C400>
40d03@l<00P:1`0D5Q<2014C400300lA3P0A4a004A<@00@04A<@00T03Q0=00lA3P0>40d03a4>014C
400C5A804A<@00d?300?4@h00P0C5A800`0A4a00418?01DG5002010B3`0400lA3P0F61<08bDO01dP
6@8041<<0P0A50d01`0>4@X041<<014D3@0A50d041<<014D3P0A4`h00P0>40/00`0D5Q404Q@?00lA
3008014C3P80418=00h04Q@?01XL5`072@@05aTD00h@2`0F61<03a4<014K4`1=GE<07BXP01@P5@0Z
=2T06R8G01<J3P8041H<01H04aT@00lF3P0A614041D?014D3@0D5a006A`E01XM5P0E614051L@014D
3@0B5@h06A`E01hQ6P0Q91d0418=01@F4@0o@C`0:bdX01@F4@0K7AP061XE0P0G6A@02`0F61<05aTD
01LJ5@0D6A<05AXD01HK5@0E6Q@051TC01DJ500D6A<05a`F008051TC00h06AhH01XP6P0M91d03aTA
01hX800O:B408bdU04UBC@0K91l05b0K01TR7@0R:bH06R@O02D^:@807RPP02X07bTQ020Z8P0P:b<0
82/S01lZ8P0W<RX08RdU01lZ8P0Y=2`0=44j01TX8`0Q<Bh0830]05UYIP0`@3h07Rh]02Hf=@0W=cH0
9CDd028b<@0T=3<09cLf02`l>@0U=C80:C`h03Y<B00cAT@09STg02/m?@0^@T409c/j02e1@00_A4D0
<dU703E9B00`A4<0<dM60314@`0^@T40<dM602e1@00bATD203=7AP0S0355A00bATD0<4A403I8BP0e
BDX0=4M903U<D00mD5@0?4mC03Y?E01NLgP0CV=X08NOX`1EKG40B61T04=GGP14FEh0C65W04eQJ01=
HFL0CfAY055UK01?HfT0AU]P04QLH`1=HVD0B5iL04EKF@14FUT0BUmP055VI`1FJfh0F6e`05Q]LP1G
K7800P1LL7L0:01JKg@0GG9g05ebM`1MLWL0H7Ej06AiOP1SN7d0Igb105aaMP1dRHh0MX^@05e`MP1W
Ngl0I7Qi06IjN`1]P7l0JG]k07B4Q01lS8/0KWim06QkM`1TMg<0GW9`05icK`1SM6h0JWUb06MfL@1_
OWT0OXf807F4P@1aOgl0MH>307B2P`1lRXd0R9JI082>T01jR8P0O8^807f<R@1jRHH207R7Q00[07N6
P`1dPh00O8^807j=RP1hQh@0PY2?08ZHV@2@WYl0QYBE07j<S024TY80PY2?07j=RP1iR8D0OXf907f<
Q`1eQ7l0Ohj;0;o?cP21TI00JWYj07j>SP27UiL0OHf<07^;R01_P7T0IWM]06IhK01NL680DfEE04eR
D@1BIeH0?e53041BAP1CHUX0AEA=04MFD@1MK6X0GFe/05MZJ01EJFL0BUmJ051XF`0204YRE00m05A/
G`1?IeX0D6IJ04]QE@19Ge<0@UQ<03eCAP0eBch0<DLj03iCA00gBCd0:3X^02Hh;00/?C<09cP`01l^
:00U=2l08c8_020/:`0V<S80;3Li02Pc=P0Y=cX0:3Hg02Hf=@0[?SX0<4<o02m2?P0Y>CH0:3Ld020]
:`0O:BP09C0/02Db:@0X=B`07b`S01`Y800P;B@07b`U01PU7P0N:RH08bl[02Da;`0K9bD08Rh/02Pa
:`0R:bH082TS01PR6P0L9B007bPR01/U7@0N9b8072HO01XT700M9R4082PT028X9P0N92805A/I01PN
700201TO7@0^01XP7P0H7Q`05adK01PN700I7ad05adJ01HL600J7a/06AhJ018G4`0F6aL07R<O01LL
600C61@05a`H01PM6@0F6aL05Q/F01@I4`0G71H07B8L01hS7@0G71H06AhH01@I4`0?50h07B8L00dB
300W;2H0=cTd01dO6P0<3PT05aPC01PI500G61<0414<01@E400E5Q402P/601@E400F5a8051<?01DA
3P0E510051<?00l>2P804Q4=00D04a8>01@C3`0E510051<?01@@3@0601<B4008018A3`0F5A<01PD3
010?3@0G5Q@030/9018A3`0A40h2010?3@04014@3P0B4@l04A0>010?3@<03Pd;00D03`h<018>3@0<
20L03PX9018>3@02010?3@0U00P61`0B4@l05A4@01LC4P0B3Pd08AdL01lK6P0=2@P030P700H20@0>
2PT040`;01HB4@0>2PT04@d<00l;2P0D40l03PX9010<2`0C3`h03@T804E1@03kmoH0i>3O02<O7P0@
30/02`L600l;2P0@30/03@T8010<2@0C3``05a<@00/71P0O6aP0100000d91P0300`81@802`L400<0
40`;014=300>2PT00P0?2`X01@0<20L03PX900T510091@@0510?00802PH51@0>2PT05`0=2@P030P7
00h:2@0?2`X03PX900`81`0>2PT03@T800`81`0?2`X04Ph=014=300>2PT0510?00X61@0=2@P030P7
00@0000D3`l04`d=018<300?2@T03@L700803PP801L030H600d71`0B30`04@/;00d71`0?1@D04PP6
01481P0>2@H03@P400`91@0;1`@02PL200`70`0@20H04PP601471P0<0`@04P`>014;2`0400002`H3
00`71002010;1`08014<2@0;1@D01@0000/51`0G4A<01`4300P210090`D200/51`H03@L900L030H:
00d72`0>20`03PP<00d72`0<1PX03@L;008030H:00/03PP<00l93@0=1`/03`@:0146300900@04PL=
00d4200B1`d03P<900l42P0201052`0300l42P0>0`Wooooo01?ooooo000Kooooo`0801LG7`0A4QP0
2``A00l@5@0C51T02P/@00h?4`0>3a8300h?4@0900d>400?3Q<030/@01TH7@0;2Pl07QdR00l>4`0H
5a`00`8700803`hC00<03PdB018A5P0@4AH00P0A4QH01@0@4AD03PlC00`=3`0O82<06AXL00802`/=
00P04Q8D00`<301;CDX09RPU0041000@40h04Q8@010@3P804A4?01004a<A00h=2`081`D06QXH01HI
5P051`H01P/704Y=B`0620L041DA00X=2`0I6aX06QlK00P;2@0@4Q402``90P0?3`d0400<30X02PX8
00`<2P0>3P`0410>00d=2`0;2`T06ATG01DE4`0?3`d01`L5034a<@0A4@l00P8001hO6P0;30L200h?
2@0d00l@2@0@4@T0414900`=1@0G61002``600l@2@0?40P05aPB00h?200:2`<02P/500d>1`0@4@T0
3a0:00/<1P0=3PT04Q<>00/<1`092PD04Q<>01HG4P092PD04A8=01@E400720<0414<00/;2@0A4@l0
3`l=00T91`0<30X04A4?00/;2@092@L09bLU00`<2P092@L04Q8@00h@3`0C5A@02`d<01@F5@0F61L0
2`d<00lA400>40l03@l>00h@3`0?4A004Q@C010@3P803`l=00D03Ph<00l?3@0@40h03`l=010@3P02
00l?3@0;018B400E5a@04Q@C00/?3P0J7Qd01PX900hB4@0<40l03A4@010D4`0A5A@00`0?4a806@0<
3P/04A<@00d?300<3P/061XG00/=2P092`P04Q@A010B3`0D5Q<0=SPe01LI5P083@T0>Slk00@91@0:
3`/06QlK01DJ5P0?51004QLC00D:1P0<4@d00PL301@I5@0D5Q<00P0>40d0100B514061XG00`>2`0@
4Pl200lA3P0G010B3`0A4a004Q@A00`>2@0;3@P04A<>018D3`0?4@`0418=00/=200B50l030h900h@
2`0G6A@03Q0;01dO6P0W:B@092HQ01DG4P0?4@`04Q@?014C3P0B50l00P0D5Q401@0B50l04A<>018D
3`0B50l04A<>00804Q@?02805aTD01DG4P0=3`X03Q0;02<U800@4Pd03a4;01<F3`0D5a004aH?018E
3P0C5Pl05APA00hA2P0N8AX05APA01TL5@072P<05adE00/E300=50`041L?01LN5P0F6a@03A8:010E
3P0I7QL061dF01<H4@0A5Pl041D?01@I4`0C61803a@>0P0B5a40>`0<4@/082DO00dB300G71H0=S/e
07YoN@0n@cl07R<O01`Q7@0F6aL051TE018G4`0?51004QLC01DJ5P0Q9R804QLC01XO6`0E6Q@05QdF
01DL5@0G7QL06R4J01LN5`0E71D04aXC01TP6@0F7AH07bHO01PO600I81P06R4I01@K4`0B71<06B<J
01TS6`0A71@05R4I01/V7P0L9b406RHO01PS7@0M:2006bHN01XU7@0L9al07BTP01`Y800I9Qd08c4X
01l_9@0K:b40=DDk05a/HP0O<2P07S4[024d;P0P<bd08SD`0080;D0l07<083<`02Hi=`0S=S@0:3/i
02`o?@0V>CL09CPf02Hj>00[?S`0:clm02Xn?00X?3X0;D4o02a0?P0]@Cl0;d=202e1@00_@D40=TQ8
03Q:BP0cADD0;d510394A00cADD0>4Y:03E7A`0fB4P0;T100314@`0hC4h0>4]?03I;CP0mDE@0=da?
03aAE00iCU40B5eP04aQI019GV40B5eP04UQH`16Gf40AEeQ045IF`1<I6L0CFEY04]QI@1;H6<0BEaR
04YMHP1;GV80BeiT04QLH016Feh0AEYM04YOHP1>HfH0D6EX05EZK`1NLgP0FVmd06AiOP1WO840GgAi
06AkO`1JLW@0FG5c06=iO01SN7/0L8F805mcMP1NLGD0HGAh06YmP@1TMg/0HgEi06QmOP1VO7T0KX:0
06YkN01bOWX0Mh9n09NPV`1cOWP0KWag06ioN@1TNG@0IGag06f0NP1YNW@0K7eg07>3P01bPWl0L81o
06moO`20T900L7n207b;SP1gQXT0Pi:F07Z:Q`1kS8H0N8V306n0NP1^OgT0MXJ307V9QP1fQX<0Nh^:
082@S`1lS8/0P92?086AT@21T9<0PI6B0080PI6A03/0PI6@07n?SP1nSX/0NHV607B4P@1gQh@0OHf:
0:bl^`1nSXd0NHV807n?SP1bPX00Lh>007B4P@1^OgT0MHIn05a]I@1?H5H0GFmS05EWE`1BIE80BE];
04EGA`13EDP0>Ta004mPEP1FJV00G71W05U^I`1BIf40Bf9J04QSE01;IUL0BfEH04]UFP1<IUd0D6MQ
059YH`11F500@UU?04EKC`0hCT40?55203Q:?P0hB3d0>d]002<c:@0T<b`07RdV02<b;P0U=3409cDe
01TW9`0S<C80:cTj02dm?@0/?3`08S8a01lb<00202Lg=00702Ti=P0X=c809SD`024`:`0M:BD06bLS
02Db:`0202<`:@0Y024^9`0O;2D082`X01DQ7@0^>SH05B4M020/:00M:BD062@P01/T800K924072DQ
020Y900U;R/08b`X01TR7@0H8Ah06B8N01@M600I8Ql082PU018H5P0L8R008BLU01dS8@0N92807B<Q
02<Y9`0L8R007B<Q01hT8P0H7Q`05Q`I01DN6@0J81`061hJ01dS7`0R:2@06AlK01TN6P0J71T00P0I
6aP09P0J71T071hK01@F4`0F61D07R0M00lA3P0H6QL06Q`I01@F4`0?4@h06A/H00T;200C5a<061dI
00/@300C61@06A/H00/=2P0F61D0418?018D4@0F5Q@05aLE01DE4`0D4a007ATF010;1`0A3P/07A`G
01@C3P0H6A<04a@>010A2`0C4Pd05a@?01@A300G4Ph05a<B0P0?3P`01@0E51804Q4?00h=2`0H5aD0
4Q4?00803`h<0P0B4@l02P0F4Q40510?018>3@0A3@`04`l>01@@3`0C3`h04Ph=010<2`0?2`X200h:
2@0B01@?300F4@h020@3010?3@0<30`02`/;00l?4@0D51@03@`:01DA400D3``03@P501XF5@0C3`h0
510?01HB4@0?2`X03@T80`0>2PT03`0?2`X04@d<014=300@30/02`L601HB4@0T81l0T8b;09:>S@0G
4a803`/:00d9200>2PT04@d<018>3@0200l:1`04010;200A30T04@`9014<2@H03PT60`0?2PL02@0A
30T04Pd:018=2P0B3@X040/800/60`0<1`@03PT600d81@0500d91P0500h:1`0@30T040`9014=2P0?
2`P00P0=2@H01P0D3``020<001D@3@2h/k00DDa900l:1`D030L400<03@P600h8200>20P0100>20P2
00d71`0L00h8200?2@T03`T900/51@0F3P`03PT701D?3`0400003`X900d71`0=20D03@P600d71`0?
1`D03`H700T31`0A2`l030L600@0000D40L03PX400/7000?2`003`/501<>2`0>20X030H:00h82P80
3@L900`030H800d72@0>20X0>38d02dW:@0H4Q@02P@600T31@0<1PP02P@600d72@0?2@/200`62007
00d72@0<1PP02P@600/51`0>20X03`T;00/51`0200h32@0801H;4@070080>2dc00`11`0A1P`04`P>
01873@0?10X200d221Cooooo000Kooooo`0800/;4`0A4AT03PhF00d>4`0?41D02``A00h?4`0>3a82
00l@4P80414C0P0@3a@0;P0E51T01`H;02TX;@0f=CX02@P=01LF6`0?3Q<05A@I00h=4P0=31402`X@
00h=4P0?3Q<040lD00d=3`0;2`d03`lA018B4P0;2`/03`l?018B4P0=3@d03`l>00X:200B4Q003@d;
01PH5P0=3@/04Q8@00/;2@0:2PP03@d;01HF500^;R`071lN01PK6P0930/04Q@C05=FE@062@P041<B
00L:2@0930/03A0?00`>3@0>3`d200l?3@0A00d=2`0;2`T03@d;010@3P0A4@l03Ph<018B400Q8Al0
71`J00`<2`0D51@0OWin01dM700B4Q0030d:01<D3`0?40X00`0?40P0200?4@H03a4700X;1@0F5a00
4A8;00X;100A4P/03a090P0A4P/01P0?40T03Pl8014B2`0C50l04A8=00l@2`80414<00D03@h900T:
1P0C50l0414<01<D3`02010A300J01HF500>3P`030`:01@D4P0C4a403Ph<014A3`0E5A<0<30^018B
400:2PP04A4?00h@3`0B51<030h=00d?3P0:30/05ALF014C4P0@4Q403a4@00h@3`0?4A00418A010@
3P0A4@l2018B400c014A3`0@40h0410>014A3`0@40h04A4?01<C4@0E5A<05ALF00d@3`0]<2l06ahM
00`?3P0@4a802`h=00d@3`0<3`h02`h=00`?3P0?4Q404Q@A00`>2`0G6AH051HC01<E4P0;3@X051HC
00lA3P0<3P/03a4>02@V8`0B51405Q/G00L<200G7AT03A8>08:7P`0^=3002Pl;01XP70052PH03Q<?
00`B3P052PH0418?01@F4`0C5A803Q0=01<E4P0:30T03a4>00803Q0=00H0418?014C400A4a0051HA
00h@2`0@4Pd2014C3P0<01@F4@0@4Pd04A<>014C3P0?4@`0418=00`>2@0@4Pd051HA01<E400?4@`0
418=0P0C5A000`0?4@`0418=018D3`02018D3`80418=02803a4<010B3@0@4Pd0418=01LI500>40/0
5ALB00T;1P0B50l04aH@01@G400E61404aH?014D3@0B5@h04aH?00hA2P0?4P/04aH?01hQ6P0l?cP0
5QXC01DJ4`0C61405Q/D028W800K81T04QL@010E3P0F6a@05AXC018G400D6A8041D?0P0C6180300D
6A<05a`F01<H4P0G71H03A8<020U7`0X;BL0HFIP0>7Uh012Ad<09b`X01/P70804AHB00h06QlK01LL
600b=c<06b0L01<H500E6QH0724M018I4P0I81T06b8K01HM5P0G7QL06R4J02dd;@805QdF00d06R4J
01/R6`0H7aP05ahF01dU6P0L91T06R@J01`V700G8AP07BPP01TT700H8a/06RLP00807R/T00T06RDN
01/V7`0L9b006bPP01`Y8@0K:2006RXQ01l_9P0M;RD00P0J:b803P0M;RD08SH]01X^9P0K;bL07S4[
01ha;00Q=2l0;3lk02<f<`0Z?C/09STg02Lj>00T=cD09c/i0P0X?3X0:P0W>cT0:Shl02e1?`0dB4H0
<4A202e1?`0aAD<0=4Q60355@`0a@d<0<TA40353@`0^@400<TA403M9B@0fB4P0>Ta<03Q:BP0iBd/0
=4I603]?CP13Ee/0?55D03M<C`0nDeH0?eAG04MLG`24VI`0A5UL041EF017G5l0@eQK04ALGP1:Hf@0
@UaM04=MGP1?IfT0@UYL04mUJ018GF00BEaP04aOH`80CV5U00D0Cf=W04iSJ01>HfP0D6EZ059WK002
05AYKP0S05Y_M01HKG80I7Un06QmPP1TNGh0IWf005eeM`1LM7H0W;>e07F:S@1HKG00JGf006QkO`1W
NWh0IgUm06QjOP1ZO800JGim06QnN`1bQh80Kgih07^4O`2>UHh0/[Na07=jL`1aO7H0L85k06QmN01T
NWH0IGQd0762O01eQX00L81m07:2O`1gQhH00P1hR8P01`1mS8l0M8>607V8R`1nSI40Nh^807f>R01o
T8X00P1nShT02020T8d0PY:?07n?S020T8l0PI6@07b<R`1mSHd0Q9>F0P23TYD01P21TI40P92@082@
T022TY40PI6@07f=RP80MhN402H0NHV607j>S@1aPH00M8B307N7Q01eQH40NXZ60721N`1cQ7d0IGI_
05i_I`1OL6P0D65G05AUE@1EIeD0CF1=04QJBP15F4T0?eA504UMD@1AIUX0EF]O05AYH01>I5/0Af5F
04]VE`19IED0BFEG04]VG@1<IUl0BfAO04eTG`1>IEh0B5mE04mTF`1aQgX0=4Tj0311=P80=DDj01<0
9CD[02/j<`0V=Bh07bh[02Pf=P0S<C40<T11028`<@0O;bl0:CXj02Pk>@0R=C<09CPf0351?P0c@d00
:3Pe02@c;P0P;bX07RdX00807b/W00`082`X02Da;@0T<2`07BTU01XV8P0L:2@07b/W02Hb;P0J9R80
8BdY02di=@0O:bL2020Y9P807bPU02008BXW020Y9P0J8b006R<P01/T8@0G81d06b@Q028Z9`0R:2H0
8BLU01dS8@0P9R@07bDS01hT8P0I7ad051XH01HL6P0I7ad05A/I01@L600A6QD05b0K01TP700D6QH0
6R0L01dS7`0O92007R0M01/M6P0J71T071hK01XL6@806A/H02L05QPE01PJ5`0G6AH06A/H018D4@0P
8Ql07AlL01HH5@0E61D05Q/G01XP700P9B40;C8^00X?2`0F61D04A<@018D4@0E5A<051@B01<C4@0A
40h061<@014<200F4`l05A@?010?2P0?40/05AHA018C3P0D4`h05A8>014>2P0D3`/05Q8A018A3`0F
5A<051<A00l>300@3`d00P0A40h0100C4Q005A@B01<B400?3P`201@@3`804`l>0P0B3Pd00`0C3`h0
4Ph=010<2`0200l;2P0A00l;200>2@H03PX601HE4@0@3Pl0@41101DF600;30h03`l@02l_;@0C3`h0
4`l=01PC3`0=2PT04Pl>01DA400@30/00P0T81l200l;2P0300h:2@0?2`X040`;00804@d<00P02PH5
01DA400<20L09B4P01DA400D40l03`/:00h:2@<03`/:0P0?2PL0100@2`P04@`9014<2@0A30T600h9
1P0400l:1`0A30T04Pd:01<>2`804@`900H030L4010;200@2`P050l<01D@3@0@2`P500d91P0=00`8
1@0=2@H040`9010<2@0=2@H03PX700l;200:1@@04Pd:00h91P1=B4D0:RDR00d81@0500h91P0300h9
1`0>20P03PP800@03PP800<03@L700h8200>20P00P0?2@T01P0B30`02`D5010:2P0400006A<C03La
<@D03@L700h03@L800h8300@2Pd04@`:00l;0`0@30808alB01@A0P0;1`406QH=010;1`0>20P050hB
00h82P803@L9018030H800d72@0>20X04@/=00h82P0:10H02`D700d72@0>20X030H8010:300C3@l0
3@L900/51`0@2P`030H800/51`0<1PP200h82P0:00/51`0900@040D;01L<4P0B1`d0;b@Z01P=4`0?
10X04@H<01<83P804@H<00<04PL=ooooooooool04_ooool001_ooooo00X03PhF00l?5`0821001`P=
00l@5@0A4QL03@hB00h?4P0?4180414C0P0B4aD0600=31403`hC01<B5`0<2a00:bX_04A3B00P7b@0
4a8G02DT:@1JFEh05aHK00@3200@3aD04A0E018A5P0@3a@030`>00X:300@41804a<C010@400A4A40
410@00/;2`80410>00`06ATG00`<2P0?3`d02`/900P81P0@40h051@B00l?3@010@002@T700`>3@01
0`82018D4`080001000?4A003Pl>028T8`0A4a803@l>00T;2P0A4Q4200l?3@0500d=2`0<30X03Ph<
00d=2`0>3P`00P0=3@/02P0B4Q003Ph<00d=300Q8B400P8201hN7@000000=cPc00h?2P0@4@/200l@
200;00d>1P0=3`@04Q<<0042000J6aH030d800H70@0C50l04A8=00l@2P0A4Pd00P0>3`T05@0E5Q40
6Q/F018C3P0>3`X04Q<>01<D3`0;30L04A8=010A30051P<08B8M00d>2@0?40/0Fe]I03Ph=P0C4a40
2@T700<30@0:2PP04a<A00H6100200P81P09014A3`0E5A<030h=00`>3@0>40l05QPG014C4P0[;B`0
4A<B0080418A0`0>40l01`0>3P`0410>01<C4@0C4a404A4?00h>300?3`d00P0>3P`00`0@40h04A4?
010@3P0200h@3`0L02X/:`0N81l03@l>00lA400A4a804Q@C010B4@0?4A004Q@C01LI600;3@X05QPE
00d?300A4a00;S0]00T;200=3``03Q0=01HH5@0B5140418?00`>2`0G71P051TE00X?2`0K81`04aPD
014F4P8041DA00X051TE00P=2@0<4@d05AXF00T;200>40d03a4>00d?300F61D03a4>0P0@4Pl01P0?
4@h04A<@018D4@0B51403a4<00h@2`804Q@?0P0>40/01`0D5Q405ALB01XL5`0H6QD03Q0;010B3@0E
5a800`0B50l01@0A4`h0418=014C3P0>40/03a4<00804A<>0`0B50l04P0A4`h04Q@?018D3`0D5Q40
JfeX01hP6`0<3PX07AlJ014C3P0G6A<04aH?01@G400B5@h03a8;010C300E61405aXC01<F3`8051L@
00T0:B`U00lC300E6Q<02a09018G400Y;RL07b@M01DJ4`0?50d00P0F6a@03`0D6A805a`E01<H4P0D
6A<05AXD01/P6P0O91h05Q/E01`Q6`0O91h02a0:01XO6@0N8ad0EU]E01lT800201LL600B01@I5@0A
5Q804aPD0003000Y;RX061dI01@I5@0F6aL02a0<018I4P0I81T06b8K01DL5@0F7AH06B0I01lV7`0D
6a@06B0I0P0C6Q<04@0H7aL05A`D01/S600K8aP06B<J01XT6`0E7aH082/S01lZ8P0R;BD0934Z01l/
9@0F8a`07BPR020[9@0Q;2H082dV00807b`U07T08C0Y01PX8@0D9Ad06BXR02<d;00W>3008CD/01/_
9`0N<B/08SD_02@g<P0V>CD093Lc020c<00X>cT09STg02i1?`0[?S`09c/i02a0?P0[?cd09c/i02e1
?`0cAdD0=4Q602e1?`0Z?S`0<TI403A8AP0^@T009cTi02@f=P0X>SX0=dU903Y<C00dATH0>4Y:03A6
AP0hBTX0@E=C03]=C@10E5<0?E5E03eBE@0lDE@0@EII03U>D@0mDUD0C65T03aAE016Feh0B5eP03]@
D`0jDU@0B65S05=]KP19Hf@0Bf=U059ZK014Fed0B5eP04YMH@1?HVH0D6=W04mRIP1?HfL0DVM/05]`
M@1HKG80FFic069gO01NLgP0G75f05Y_M01LLGH0EV]`05=XK@1RNG`0KhN905M_L@1aQhX0J7f006=h
N`1ZOX80J7]o06anPP1[OH40KX2406anPP1/Ogl0LHF307:5P@1dPgh0VjBO0=GLe@3Nh]d0O8=l07R3
O@1^OW/0K7mk06n3P@1iS8P0S9fG08RIT`1dQ840MhN407V9R020T900Jg]k08RGVP1fQHP0R9NJ07f<
T01kRhP0Nhb607f>R021TX`0PY>=086ASP22TXl0P92=0080PI6@02L0P92?08:BTP25U9L0QIBG08BC
UP21TI40P92@07n?S`20T8l0PI6@082@S@1kRhP0N8R507N7Q01hR8L0OHf<07R8Q`1cPh00LhAo07>4
OP1ZNgD0QYN@06enMP1VMfl0Gg1X05UZH01>Gdl0EVQE055TD@1<GTh0CV9B051UEP1:GU80CfAH059X
G01AIUd0CVAK04YTF@1>JEX00P17HeD0901<IUd0CFIO04IOF@1IL6X0?EA=04ELDP1KL6L0KhEh02]0
<@0dACX0=4@i02dm<P0Y>Bl0:CPa024`:@0L:bP0;C/k03E3@`1@GUl08c4b02@d=00V=cL09CPf02@g
=@0W>SP0;Shk02lo?00Z>SL09cHa02@c;P0S<Rd09C4]02Hb;P0M:BD08BdY01l[9`807BTU00h072PT
01dY9@0L:2@0<Cdi01dY9@0W<bl07BTU01dV8`0Q:RL08R/X024Z9`0R:bP082TV01`U8P<06b@Q01<0
7BHS01lV900F71X051XH02H/:P0;4@l06AlM03Y0?P0L8R0061hL01XP7P0L8R006AlM01LO6`0C71L0
8R/V02`c;`0G7AT05Q`H00807B8N00D071hK01TK600I6aP06adJ01XL6@0201PJ5`0?01`N6`0N81d0
5ALD00d?300>40d0DUAA038d<@0A4a008BDQ0:jc[`21Qh<04aPD020U8@0C61@0418?00804aDB01h0
51@B01<C4@0A4@l0410>01hJ5`0>2@H09R8O00d<200M7QT04aD@01HH4`0C5A005AD@01LC400C3``0
5A0=01TE500B4@l04A0>018A3`0@3`d05A@B01@C4@0F5A<06aXH01dL6P0J6AL05A@B018>3@0C3`h2
01@@3`04018>3@0?2`X04`l>018>3@<040`;01L040`900L2000H4a001PD101XH6@21PX<05QLI0000
0P0F5QL0DU9@01DA400=2@D0?STe05EAD00A3@`06aLF00<0000?2`X0D4a;010<2`0?2`X03PX900l;
2P02010<2`0701PD4`050@003@T8010<2`0B3Pd04`l>010<2`0200h:2@0300l;2P0=2@P02`L60080
3`X700@040/8014<2@0A30T04@`91P0?2PL00`0@2`P03`X700l:1`03010;2006014<2@0D3``04Pd:
01<>2`0B3@X03PX71@0=2@H0100A3@X061@A01XF4`0F4Pl200l;200600`81@060@004@`900h91P04
00004Pd:1P0>2@H00`0?2@P03`T900h8200200h8200300d71`0>20P03PP800@03PP800H02`D501lI
6@0>20P0618B01@>3P0;1PH600d71`0=010:300>20X03@P500l;0P0J5PX0QX=d06AQDP0J5`P06QH<
00h91@070P002`D700h82P0200d72@0900`6200=1`T03PP:00l92`0>20X040X<014;3@0?2@/02P@6
00802`D700@03@L900h82P0>20X03@L90P0<1PP01P0=1`T03PP:00h82P0<1PP03@8801@93`804@H<
00D030<700X01@0=0PP040D;0146300200l42P0301052ooooooooooo01;ooooo000Kooooo`03014A
6@0B4QX04Q8J00805aPM01@02P/@00`=4@0=3Q403PlA00l@4P0@4A<04A8D018A5P0A41D04Q4F00h=
4P0=31403PdB00X93P0A41D03`lC01LF6`071P/061LL00h=4`803PdB02403`hC010@4P0@41804A4C
010@400>3Ph03`l?010@400?3`l03`l=014A3`0820H04a<A00L71@0?3`d04A4?00h>300:2PP03@d;
00`<2P0F5Q@03@l>018D4`0?4A00418A00P:2@0@4Q409bTX03do?P0@4Q402``;014C4P0:2`X00P0?
3`d0200>3P`03@d;00l?3@0>3P`0410>01<C4@0?3`d03@d;0P0?3`d01P061P@0410>00X:2@0B4Q00
4Q<>010A2`803a0:01003Pl800d>1P0=3PH03@h9014A3P0@40h04A4>00/<200@40h03`l<010@3@0@
40h03@d:00/<200A4@l051@@0P0A4Pd200l@2`0I010A300D5A000`@001LH4`1IFUD09BHQ00l@300L
71X0410>00h>300C4a403@d;018B400=3@/04A4?01HF500?3`d030`:00h>300D5QD04A<B00h@3`0D
5QD02`d<014C4P04010B4@0400lA400>40l03@d;00h>30804A4?00D03`l=00d=2`0C4a404A4?018B
400201@D4P05010@3P0A4a803a4@00X<2`092`X00P0B51<0600>40l03a4@00d?3P0;3@`03Q0?018D
4`0@4Pl030d;00X<2@0B5140:R`Y01<E4P0>40d03@l<010B3`072@H0418?02LY9P0^<bl02a0<00dB
3P0B5a<03A4=014F4P80314=00D04QLC00/@300<4@d03Q<?01LI5P02010B3`0401DG500O8Ah05QPE
018D4@804A<@00T04Q@A01<E4P0D5Q<06adH014C3P0@4Pd03Q0;00d?2P0@4Pd00P0C5A001P082PD0
5ALB00h@2`0E5a804A<>010B3@804Q@?00H03@l:00X<1`0@4Pd0418=018D3`0C5A02010B3@804A<>
0100418=014C3P0A4`h04Q@?018D4@0W:B@0DUA?00h@2`0J71L04A@>01@G400E61404aH?014D3@0B
5@h051L@0P0C5Pl01@0?4P/061/D00X=1`0X;2D04aPA00<051TB01/04aPA00lD3@0@5@h06AhG01/P
6@0F6a@05AXC014F400B5a4051TC01PM5`0L8A/04aPB014F400I7QP0=CXd02@Y8`0F6aD0724K01PM
6@0K81`061dI01`Q7@0G71P05Q/G01LL600Q9R800P0G71P0100H7AT05Q/G01HM5P0H7aP201HM5P0E
01TP6@0E71D05ahG01DL5@0J8AX08RTR03<j<`0K8Q/06b8J01dT6`0H7aL05R0G01`V7P0K9Ad05B0H
01HQ6P0H8ad06RLP01`X8`0K9b<07BPR00808B`V01007BXS01h[900R;bP0<3lh02/k=00S=2`07c0X
01d^9P0N;bL07C0Z024d;P0V>C<08cH`020c;P0U>3@0:chl0P0U>3H02P0Q<c<0;3hn02Tk>`0X?3X0
;D4o02i2@00]@Cl0<DE303I:B00_@d4202i2@080=DU700H0;T9003Y<C01?HF40B5YJ03M9B@0fB4P2
03U;B`110312@P0kCDd0CEmO03i@D00lD4l0?51C03Y?DP0hCE00?U=F03Y?DP10EEP0AEYM04QMH011
EUT0@eQK04UNH@13Fed0A5eO04IPH@1=IfP0Rj>U0;G=c`1>IFL0Bf1S04ePI01?HVH0D6=W04mRIP1>
HVH0DfQ]06AiOP1IKW<0EFY_06=hO@1NLgP0FVmd05ebM`1PMGX0GW=h069gO01PMGT0HGIg069gN01W
O7d0HWMh0765QP1UNGX0J7am06YlOP1]Oh40KX22071oPP1^P840M8R607R:Q`1gQ800NXAn09ZRW02L
Xi`0NX=k07N2O@1fQH80MhV507^>S01dQH<00P1oSh`03P1iRHH0P92=07n?SP1lS8`0QYJF0:jn_P21
T9<0OHb?086@TP20T8d0OXn907f>R01nShT0Oi2:0P21THh03`23Ti00P92?082@S`23Ti80Q9BD08JE
V025U9L0Q9>F08:BTP21TI40P92@07f=S01nSXd0Ohn<07b<R@0207Z:Q`80MXJ303D0L81m06moO01d
QH00LX=m0721N@1[O7@0DfAL06MhKP1@HEL0G6iR04eNCP1AHe00BEa904EGA`1;Gdl0D6EF059VFP1E
JUh0E6YN059WGP1AIel0DFUO04mYG019I5H0BF=G04]UF`1<I5`0AeiG03]BC019GeP0@eQ?03aAB00e
BSh0:clc0352=P0Y>Bh0:3P]02lo=@0Q<2T07B`U028a;P0J:2P07bd]02Hd=@0E8b@0:c/k02Xk>`0Y
?3X0;3lm02Xm>`0V=S<09CDb02Lg=00202Pg<P0C02Dd;`0T<2`08bl[02Da;@0T<2`082`X02@`;00W
<bl08RhZ020/:00W<bl0Ce]G02Te<@0L:2@08BdY01lX9@0S;2T08R/X01hW900201dV8`0301`U8P0K
92406R<P00807RLT00P07bHT02<Y9`0O9B<07R@R02<Y9`1EFeT0GF=Q01/Q7`<061hL01805Q`J01PO
700B6aH06R<N01lV8P0A5a<05A/G01PN6P0E6QH05QPE01DG500G6AH06Q`I01/M6P0A4a005ALD02DW
900J71T201HH5@0;00lA3P0L7Q/02P`901/M6P0U:2D0Jg1/05iTH00J7a/03a@@00`A3@0B51400P0E
5a@07@0E5A<051@B01<C4@0C4Q003`/801`G501FDe005aLB01HG4P0A4`h04Q@?00lA300B4`h05Q<@
01@@3@0F4Pl05A<A00l>300F5A<092<Q024P7P0D4a404A0>010?3@0A40h04a8@01@C4@0A40h04Ph=
00<04`l>00@04@d<010<2`0C3`h04Ph=0P0A3@`05P0B3Pd04Ph;01XE4P0A3@X03Pd900/92P0F5QL0
EeQJ03/l?P0<30d05ADC010<2`0A3@T08A`H03`h=`0=2PT06ADD01PD4`0E4A009B4P014=300@30/2
00h:2@0>00l;2P0@30/030P700h:2@0D40l04`l>00d9200<20L03`/:00d9200>2PT040`;00h:2@0<
20L200l:1`04010;200A30T04@`9014<2@H040/800`04@`900d81@0;1P<030L400l:1`0A30T050l<
018=2P0=20D03PT6014<2@0>2@H500d91P0<00h:1`0?2`P04@d:010<2@0=2@H02`L400`81@0C3P/0
3@P501D@3@0A30T050l<1P0<1`@0100>2@L040X:00l92@0>20P200d71`0300h8200?2@T03PP800<0
3PP800H03`T900h92@0:10@03`T900T4100@2PX600d71`0=00l92@0A30X04`h801XF2`15@CD0jNSH
0=_Ha`1?C3d05A4500`80@0=20<06A<C00h82P0200d72@0400`6200=1`T03PP:00d72@8030H800@0
3@L900h82P0=1`T04@/=0P0<1PP0100F4180618D010:300<1PP200l92`0400h82P0=1`T03@L900`1
1`804@H<00L05P/A00h32@0D2@l04`P>01H;4@0E2Q004PL=008040D;5?ooool001_ooooo00P04a<K
01TI8@0J6R8071dR01TJ7`0<3A8030dA00`=40@03@h@00T04Q4F00l>4`0?3Q<051<H00`;400@3a@0
7A`Q00X93P0510T00P0<2a003@0A41D04Q4G00h=4P0<2a003@`A010@4P0B4Q@02`/=00X:2P0<30`0
3@d=00h>3P0@41000P0B4Q002`0C4a404A4?00/;2@0:2PP01`L500/;2@0<30X04Q8@00d=2`0A4@l0
4A4@00804a<A00X020P601TI5`0H61H05ADC01XJ600f=S@08R8P00h>300B4a403@l<0P0>40d0400=
3``03a4>014C400=3``02`d:00`>2`0>40d03a4>00P91`0K71L07AhI010A30020`001`P300X;1P0=
3PT300d>200;00h?2@0F5a<0BDU900L71`0B4Q8051@D01DE5@0C4a<04A4A010@400>3Ph00P0<30`0
0`0=3PX03a0;010A300200d>2@0K00l@2`0:2`H03a0;01LH4`0B4`h00@8000`=200=3@/02PX800T9
1`0<30X04A4?01LG5@0J6QP04Q8@00@40P0B4Q0061PF01<C4@0=3`h04Q@C00h@3`0D5QD04A<B00lA
400=3`h03Q0?00<0418A00<03a4@010@3P0@40h0100@40h01@0D51804A4?018B400F5Q@051@B0080
3Ph<02403@d;01<C4@0L71X04A4?0000000B4Q004a<A018B400@40h03`l=010@3P0I6aP04A<@01HH
5@0=3``02P`900d?30092`P0418?01PJ5`0<3P/01PP500D710000@0051HC00d?300E5a@030h;00X<
2@0?4@h02P`900L91P0U9b@00P0?4@h01`0B51403Q0=00`>2`0<3P/05QPE00d?300@4Pl00P0?4@h0
200@4Pl04A<@018D4@0L7QT04Q@?014C3P0?4@`03Q0;0P0A4`h01@0o@C`0<S@_04=5@00F61<01`T4
00<04aD@0P0B50l01`0C5A004Q@?010B3@0B50l04aD@018D3`0A4`h00P0@4Pd01`0?4@`0418=010B
3@0H6QD04A<>00X<1`0B50l00P0C5A000`0;3@L03A0900hA2P0200hA2P0400lB2`0C5Pl06A`E014D
3@803a8;00T030l802X^9`0A5Pl08RLP024V7`0:3`P0724J01DJ4`0@5@h00P0G71D0100C61404QL@
010E3`0D6A<201<H4P0E01DJ500C6180724K00lD3P0U:R@010T300`A2`0N8ad061dI01hS7`0?5100
5a`H01HK5`0D6AD041DA01HK5`0m@Sh0<cPd02/`;00D6AD05A`E00806B0I00T05A`E01LN5`0F7AH0
7RDN01@K500F7AH092/T03@k=00J8AX00P0N9Ad07P0H7aL05R0H01hX800N:2005b8L01`W8@0M:280
72PT028^:P0Z=S807BPT020[9`0M:2@06BDQ01`X900T<2`0;chi02@d;`0I:R@062TS01h_:@0S=2h0
8cH`02Lj=@0^@Cd0;D0l02@g=00R=C<0:3/i02Lj>@80:S`l00@0>Ta<03E7A`0Z?S`0;D4o0P0_@d40
D`0]@Cl0;40n0355@`0bAT@0;d=10396A00dB4H0<DE30353@`17FET0?4i>0312@P0kCDd0@E=C03M9
B@0hBTX0B5YJ05=UI@0nD500?U9A03iBEP0kD5<0>4e@041EF00oE5L0AeaO045FF@0oE5L0?U=F04=H
F`14FE`0?EEG04]TI@1LMWL0D6Y[04eUI`1WOh40CF=V04]PH`1;GV80CV5U055TJ01BIFT0DVI[06Un
P`2=XZL0KH:705EZK`1cR8d0KhB905U^L`1NLgP0GgAi05Y_M01RMg`0GgAg06^0P@1PMGH0I7Uj065e
MP1YOGh0JGam06IhNP1/Ngh0N8N:06]jO@1WMWT0Kgn107>6Q01`P7l0MH=o07V4OP2DWIP0PHZ50:2Y
Y01hPgl0NXV6082@S`1kSXd0OXj=086?S`22T900P8j>0080Ohf=00h0PY2@08FCT`1jR8T0NXR907f;
S024TY<0Ohj;08:AS025U8l0PY6<086@R`24Ti00PY6>08FDT@80PY2@00<0RING08ZHV@24TiH00P24
TiH0B023Ti<0PY:B08:BTP1mSH`0OXj=07f=RP1iRHH0MhN407R8Q@1mSHX0NXZ707N7Q01dQGl0L85k
07:3N`1UMVh0KGie06n0MP2IZZ00FV]Q045CA`1:Fd/0AeU603e@?@0oDD40Bem?051UEP1GJel0EV]O
05=YG@1@IE`0D6IM059YG`1=IeX0C6IJ04YTF@1;HUP0BF1F04MNE01@IEh0B5eD03=8?`0Y?C@0=d]0
02i2=`0c@cP0;cld03Q8?@0kBd409C@]0391>P0U=340<Clo02Hd=00R<3408Bl`024a<@0[?3`09STg
02Xm>`0Y?3X09CDb02Hf<`0/?3T0:STd02Pg<P0V=C009S8^02Da;@0T<2`0<3`h02Hb;P807b/W00L0
6bLS01dY9@0S;b/0<Shj02Da;@0I9B407BTU00808R/X01407RLT01TR7`0H8Ah06R<P01/T8@0J8b00
6B8O01lX9@0N9b@05AdJ01/Q7`0S:BL05Q`J028X9P0e>cT0:c4_01`R800401XP7P0801`S800E7QT0
5QlJ01@K5`0E6aL06b4M01LL600E6QH501PJ5`0A01@F4`0F61D06adJ01DG500I6aP0828O00T;200G
6AH06Q`I01TK602CUi<0ADY601`R7P0D6AD05a`H01PM6@0D5Q<00P0C5A8301<C4@0401@C4@0B3Pd0
510?01PF50803`l=01L04QDB01<H500B514051@B01HE4`0C4Q005a<B01DD4P0?3P`051<A01hM6`0K
6QP040l=01<B400A40h040l=014@3P0B4@l03`h<01<?3P0B3Pd04@d<010<2`02014=300J01<?3P0B
3Pd04@d<014=300B3Pd04`l<018=2P0G4Pl02`X600d;30051@H09BHX01TJ700=3Pl05ADC01<?3P0F
4Ph050l;010<2`0P71/0]k>b028N7@0:1PH0AT91014=300@30/300h:2@0=00l;2P0E4A00510?00/7
1P0810@04Ph=00H20@0?2`X03@T800h:2@0@30/03`/:00h:2@0200l:1`04010;200A30T04@`9014<
2@H040/80`0A30T00`0@2`P03`X700l:1`02010;200400d81@0?2PL04@`900h:1`D03@T600d03PX7
00d91P0<20D04@d:01@@3@0@30T03PX700T40@0;1P<03PT601<>2`0;1P<02PD300D03@P500L03`T8
010:2P0?2@T03PP800d71`0<1PH03PP800803`T900T03PP800d71`0=1`L040X:00P20P0M5aL040X:
00l92@0@2PX01P0=1`L03@0<1`@04@`801@?200C3`@0=30T092=OP1gM6D081d>00d9000D40L061<=
00h:200>20P00P0=1`T0200<1PP03@L900h82P0E3a404P`>00h82P0=1`T030H80P0:10H01P090`D0
2P@600h82P0>20X030H800d72@8040X<00X03@L900`6200>20X04PL=0146300>0`T03@8800h32@0<
0@L04`P>0P0E2Q000`0C20h04@H<01873@0Dooooo`006oooool0200>3QH0410H00T94@061``02``A
00`=4P0<3A4030d@0P0<3@l200/<3P0a018A5P0A41D040lD01@C600:2@h04Q4F01DD6@0@3a@030/@
00l>4`0G5Q/03PdB01dL8P0E51T03`hC00`;400>3Q003`lA00`<3P0=3@d03`l?00h>3P0<30`03@d=
014A3`092@L06ATG00P81P0G5aD0410>014A3`0?3`d02PX800h>300;2`T03`l=00/;2@0P81h02`/9
01<C4@0B4Q001PH400T91`0F5Q@06ATG00/;2@0E5A<030d:00d?300200h@3@0B00d?300?4@h05aTF
01<E4P0:30T03Q0=018D4@0?4@h04Q<?00P910061`8051D@01HG4P041@00414<00`=200<3@L03@h8
0P0>3`T03P0`<2d0Ph>301<C4`0=3@d02PX:00d=3@0>3Ph03`l?00h>3P0?3`l0410@00l?3`0?3`d0
3a0;0P0>3`X200d>2@0600P9100=3PT020T500@5000T9B00414<0P0C4a42010@3P0401<C4@0:2PP0
1PH401<C4@805QHD00@03Ph<00/;2@0:30/05ALF0`0?4A00100>40l030h=00d?3P0@4Q42014C4P0G
010B4@0B4Q004A4?014A3`0@40h04A4?018B400A4@l03@d;00h>300B4Q004A4?00X:200W9bD03Ph<
00d=2`0I6AL03Ph<00l?3@0A4@l04a<A018B400?3`d00P0=3@/01@000@005ALD018D4@0620D04A<@
00804Q@A01P03Q0=014C400=3``051HC014C400H6QL03Q0=010B3`0<3P/05ALD00/=2P0=3``06Q`I
03<e<P1GFEH02`d:00h@3@0=3``04A<@010B3`0=3``05aTF014C400>40d200d?300F00h@3@0?4@h0
418?00d?2P0@4Pd061XE01LI500=3`X02`d801XL5`0`<Rd02`d802PZ9@0E5a804Q@?01DG4P0C5A00
418=00d?2P0@4Pd04aD@01@F4@80418=0`0C5A02018D3`06014C3P0B50l04Q@?01<E4002100071hI
0P0A4`h00`0K7AP03Q4;014D3@0201<F3`0=01@G400F6A8041<<01HI4P0=40T05aXC00d@2@0N8AX0
2`l802X_:028SHH0O85j010E3P0201<H4@09010E3P0E6Q<04QL@00lD3@0B5a0051TC01PM5`0G71H0
51TC00805Q/E00T04AH@01/P6P0<4@/07b@N020U7`0B5a404AHB01/P700?51000P0M8Qh201HK5`08
014F4P0Y;RX0314=01TN6P0P9B404aXC01/R6`0M91d201DL5@0a01PO600I81T041L@01LN5`0D6a@0
5ahG01HM5P0J8AT072<K01LN5P0F81P06bDM01XT700E81X08B`V02Ha:`0Q;BT07RXV028^:P0P:bL0
8RdY01hY9@0I9B407RXV02Lc;`0L:bH07blY02Lh<P0/?CL09SLa01TZ900M<2X07S4/02Xm>@0^@Cd0
9CPe01d`;P0W>SP0:3Xi02Xl?00W>CT0<D=302Pj>P0]@Cl0;T9002m3@@0^@T00:3`j02Di=`020396
A080;40n0P0bAT@01@0fB4P0;d5102Pj>P0fB4P0?e5A0080=TQ80400@59B051RHP1CIFD0?U1@045E
E00iCE00?E9E03mDE`16Feh0?U=F049GFP17G5l0@EII04EJG@11EUT0AEYM04iVJ01=IVP0>59C03mI
FP1CJfd0BV9T051WJ@1:Gf80BUeQ04iQI@1CIVX0EFQ/05EYKP1AIV/0I7Un05icN01QMW/0KH:705eb
M`1FJg00GG9g061eNP1MLWL0Igb106MlOP2=XZ<0KH:306AhN@1aQHH0JWio06]nP01[OGl0NXV<092O
XP1eQ8L0IgIi06]jO01/OWh0JGUh07F2P@1gPgl0SYVC08N@R`3<em40OHV607N5Q@20T8l0O8b<0P1m
Rh/02023TI40PHn?07b:RP22T900MhF508fKV`23TI80RYRI0P1lRX/03@1iR8D0P8n:08RGTP25U8l0
PY6<08BCT01mS8T0PY6>08:@T025Ti<0SYbL09:PX@24TiH00P23TYD308>CT`80P92?0500OHf:07N7
Q01eQH80MXJ307:2O`1dQ840NX^507J7P@1_P7T0N8V10721N@1]OWD0BU]A06enM015ET`0BeeA04MH
B012E440>Tdj045C@`1BIUH0FVmP05M[G`1FJel0D6IJ04eRF@1=HeX0D6MO04aVF`1=Ie/0BfEJ04UP
EP17GU@0B5mE03iCBP0mDTT0C65H0355?00bAS`0<44g02De:P0W=b`0<T8g02`l<P0C8Q/0:cXc02<b
;`0c@D405R@T01`Z:`0a?d009CDe02Pi>@0O<S008cHd02Dh=P0V=S<0:SXg02Ti=P0U=2l08C0[01l^
:@0Q;BT08RhZ02Te<@10C4P0=40l028^:P0O:bL07RXV020/:00O:bL062@P028^:P0O:bL072PT01lX
9@0P:BH07BHS01XS80<06b@Q00X06B8O01PQ7P0O:2D07BHS028Y9`0J81h0728P020V900R:2H09R`Z
0P0H7Q`0200G7A/06AlM01XP7P0K8Al05ahK014J5@0G81/05ahJ0P0I7a/0600B61@061dI01/M6P0L
7Q/06Q`I01PJ5`0F61D06A/H01PJ5`0@4Pl05ALD01/M6P0?4@h04Q@A01`N6`0K7AX08bDR0;^o^`1M
HUh04ALC018G4`0J7a/06AhJ018D4@804A<@0P0A4@l0400B4Q004a<A018>3@0T81l04Q4?01`L6P06
20D04QLC01XO6`0F6aL06AXG01XI5`0F5A<06ADD01/J600A40h200T81P0300/:200B4@l04A0>0080
40l=00D04A0>010?3@0<2`T0510?018>3@0200l;2P04014=300B3Pd04Ph=018>3@804@d<01H04`l>
01<?300?2PL05Q4>00/:1P0<2P/04Q8C010A4`082@/030`=014A3`0300004Pd:010;1`0C3`h03``;
02@P7`060P405A4@00L30P0A3@`040`;100>2PT01`091PD05A4@01<?3P0F4Q409b<R00h:2@0@30/0
0P0=2@P2010<2`0400l;2P0?2PL03`X7010;20<04@`91P0@2`P0200A30T05A0=01HA3P0E40d03`X7
00d81@0@2`P04`h;0P0A30T00`0?2PL030P500d91P0400d91P0=010<2@0>2PL02`L4014=2P0D40d0
3PX700l:1`0400004@`900l:1`0@2`P03@P5014<2@0500h91P0700l:200@2PX03`T900h8200=1`L0
30H600h8200200l92@0900h8200=1`L03@L700X4100R71`03`X:014;2`0?2@T03@P800D03@L700h0
3@P601D@300I50h061@<00X6000C3`<08AhA03Lc9`0>2P003`/200d9000F4@/03@P700h820803@L9
00@030H800d72@0>20X02`D70P0:10H0600<1PP03@L900/51`0:10H03PP:014;3@0<1PP02P@600h8
2P0=1`T04@/=010:300=1`T030H800h82P0B1`d03`@:00h32@0;00H05P/A00l42P0=0PP040D;0146
308040D;00<04@H<ooooooooool04_ooool001_ooooo01H04A4I01TI8@0@41P03a0E01@E6P0:2a00
4a@H00d>4@0H6A/00@4301DF60082@/04A0E01<B5`081``030/@04E4B@0Q82D04a8G00`;400?3Q<0
4Q4F0P0>3A804`0@3aD040lD00`;400@3a@01`L900h>400@4180410@00/;2`0@41004Q8B00d=3@0@
40h03Ph=00l?3@0@40h05QHD00@40P0>3P`00P0A4@l00`0?3`d03Ph<00l?3@0200d=2`0700h>300?
3`d03`l=00l?3@0=3@/03Ph<00l?3@02010@3P0=00l@3P082PL0418?00`>2`0C5A803Q0=061RG`1J
G5T06A/H00h@3@082PL0418?00h@2`0400l@2P04010A300?40/03Pl:01DF4@803a0;01004a@?01DE
4`0@41003@d=014A4@0E5AD04Q8B01@D501IFET0Bd];014A4@0E5AD02`/;010A3P0=3PT03Pl:0`0?
40/01P0>3`X03a0;018C3P0B4`h04A8=00l@2`803Ph<00<0410>014A3`0@40h0100@40h0100>3P`0
3`l=014A3`0G6AP201<E500?00h@3`0?4A00418A00d?3P0C5A@03Q0?00lA400I6aX09BLV00l?3@0E
5A<03Ph<014A3`0B4Q004A4?00803`l=0P0>3P`200l?3@803Ph<0P0?3`d2010@3P0=00h>300@40h0
30`:01DE4`0L71X02PX800lA3P0A4a003a4>00h@3@0@4Pl051HC038d<@02014C400400`>2`0>40d0
4A<@00h@3@<03a4>01`0418?014C400B5140418?014C400D5Q<04aDB018D4@0@4Pl03Q0=00`>2`0=
3``03Q0=00d?300B514071hK01@F4`0A4a0051HC00h@3@0A4`h04aD@01@F4@0C5A00418=00h@2`0@
4Pd04Q@?0P0C5A02010B3@80>C/f00@030h901<E400?4@`05ALB0`0B50l201<E4003018D3`0A4`h0
4Q@?00<04aD@00L04Q@?010B3@0@4Pd0418=01DG4P0M7aX06adG00804aH?00H051L@01<F3`0B5@h0
41<<014D3@0C5Pl2014D3@0=01<F3`0H71D07B8K092ESP1dNG8051TB03Hk=00T:B8041D>01<H4@0F
6a@04QL@01@I4P0201<H4P8051TC0P0E6Q@00`0B5a404aPB01DJ500301DJ500>01XO6`0H7AT05a`H
01LL600;40`05a`H01HK5`0K81`06QlK01<H500F6aL061dI02L^9`0N9Ah201XQ6P0601PO600K8Q/0
5A`E01PO600K8Q/06R4J0P0G7QL0300M91d072<L01XQ6P0H8QX06R<M01XS7P0M:28062<N01/V8P0I
9B<06bLU024]:`8082/W02P07bXV01hZ9P0P;2P08BdY01l^:@0L;2L0DfAN01h_:@0O<2X08C8/02@g
<`0P<bl09cXf01ha;`0oDU009CPf02Hh>00]?cl09cTi02/m?`0eAdT0:C/l02Tm>`0^@T00<dM50314
@P0aAD<0>4a:0314@P0aAD<0=4Q603I:B00dB4H0<4A203Q:BP0bA4@0<D=303e?C`0_@D40?e5A0P0k
CDd0E00lCTh0?Dm?04EGE`0gBdX0?E5E049GFP13F5/0@EII04=HF`17G5l0B5eP04UNH@15FUd0AU]N
04aQI01:HV@0BV=T055[K01CKFh0I7an05ifN01;HV@0CF9U051SI`1DIf/0DfIZ05EXK01JKW<0Fg1e
05aaMP1OM7T0H7Ej065fN`1RMg`0HGIk05mdN@1RMg`0IW^006EjO`1TNG/0M8R706j2P@1XO7/0HgMf
06=eM@1bPh<0Lh>307N7Q`1gQXH0K7Yk06]iNP1ZNWX0IgMg06ajNP1fPh80Oh^808:=R01mR880NHF0
07^7Q@1lRXX0OHb<07n>SP21SXl0QI2B08RCU@26TI<0Q8nA08NCT`24T900QI6A08JBTP23Shl0P8b<
086=S025THh0PXj:08B@S027Thl0Q92<08JBT023Shd0RiNE08nKV`80RIFE0340RIFG08NFV@23TYD0
QIBG08NGU`22TY80Pi>C086AT01nSXd0OHf:07R8Q@1_Og`0Lh>007V:Q01gR880MHJ007B5OP1`PGT0
Jgad06MhKP1NKfD0F6UO05=UF@18FTh0A5I8045B@P0oDCh0>D`i04IHB01KKel0EfaM05M[G`1FJel0
EfeQ059WGP1;HEP0DfYR04aSFP1=I5X0CfIL051WG@1ZPGD0IWa`04QNDP0mDTL0>Ti503U:@P0^?cL0
:S/b00809CDZ0180:CT^02<c:@0Q<2T08c8[02He<P0T<S809S@d07N5QP0d@T<0:CTi02dn?P0R=C<0
>4]902Xm>`0^?S/0:c/h02Lg=00X=c8202Lf<@0302Te<@0X=3009c<_00808bl[00H08RhZ01dY9@0I
9B40930/02Da;@0S;b/201l[9`05020/:00N9b@072DR01`U8P0J8b000`0G81d0@`0H8Ah07bPU01`U
8P0J8b007B@R020V900O9B<0728P01PN700I7ad06R0N01LM6`0F71X0728P01hT8P0K8Al05QdJ01@M
600C71L05AdH01LM6@0H7QX05Q`H01TN6P0O8Ah071hK01LI5P0J71T07b4N014C400G6AH05QPE01PJ
5`0Q8b008R@Q01@F4`0E5a@071hK01PJ5`0[;R/0724M01LM6@0C61@04AHB018G4`0D5Q<06adJ02DW
900C4a4071`J010@3P0B4Q004Pl>01<A3`0C4a405AHD00/>2`0@5A403A8>00lD400C5A804a<A014@
3P0E4Q405A@B01@C4@0B4@l00P0?3P`00`0C4Q004A0>014@3P02010?3@803`h<00<04Ph=010<2`0A
3@`00P0D40l00`0@30/03`/:014=3003018>3@0F014=2P0B3@X03`/8018A3@0?3@h0H65R03/l?P0=
3Q003@d>00X:2@0B3Pd04`h<00l:1P0>2PT04@d<010<2`0C3`h05a<B00l;2P0=2@P04Ph=00l;2P80
4Ph=01l030P7010<2`0@30/04Ph=01DA400B3Pd03`/:014=300@30/03`/:014=300B3Pd04`l>02XU
8P0;1P@03@T7010;200C3P/06QDB018=2P0;1P<020<101@?300A30T04`h;00d81@0A30T050l<010;
200<1`@04@`9008040/80P0?2PL03P0>2@H030P501<?300;1`D03@T700h:2@0<20L05Q8?014=2P0@
30T03@T600X60`0<20D03`X70P0>2@H02P0=20D030L4010;200Y92406QDB00X5100?2PL030L400l:
1`0@2`T500l92@0400h8200=1`L03PP800h820803`T900D03PP803D_;`0?2@T040X:018<300600h8
200700h91`0910404Pd700h90`0@30804@d301@@1@0300h:0@0400h:0P0>2@<03PT400d71`D03@L9
1P0<1PP600l92`0601@>4024OX00MFma01H@4P0?2@/03@L90P0A1P`00`0@1@/04PL=00h32@020146
300500l42P0F2a405P/A00l42P0A1P`05?ooool001_ooooo01<04a<K01PH800A4AT0414F01@E6P0>
3a@0414E00`=400A4Q@01`P:00X;3@0<3@l051<H00/:3`0A41D030/@04i=DP0>3A805A@I00802`X?
01/040lD00h=4P0?3Q<030/A018A5P0E51T02`X?00l?4@0@41803@d?00l?3`0<30`03@d=00h>3P0;
2`/03@d;00L71@030`4030`:0000000H61H030`:00l?3@0@40h03`l=010@3P0A4@l00P0>3@T05P0?
3PX040l;010?2`0@3`/04A0<00d<200;2PH030/700h=2@0@4@d03a@@00/@300?51004AHB01lT802b
][<0XJJR02ld<0083@T03A8>014F4P0:30H200l@200F00l@2@0?40X03a0:018C3@0m?ST0820N01PH
5P0?3`d051@B01HF500?3`d030`:010@3P0B4Q00410>00/;2@0R8R00820N00P81P071`D02@T700l@
3080414<0`0?40/300h?2P<03@h90P0>3P`01@0?3`d03Ph<00h>300=3@/04Q8@00805ADC00/030`:
00X:200B4Q000@<201@F5@1HFUT051HE0001000G6AP030h=01hP7`0200`>3@0802d_;P0[;B`03`l=
01LG5@0@40h0000000T91`0G5aD2010@3P803`l=0P0@40h200l>2P8040l;0P0A40`0200;2PH04a8>
00l>2P0=30P04a8>00l@2`0?4@h0418?0`0?4@h01`0@4Pl02`d:00`>2`092`P0418?00h@3@0=3``0
0P0A4@l3010@3P0@00l?3@0B4Q00410>010@3P0B4Q004A4?00l?3@0C5A803Q0=010B3`0B51403Q0=
00/=2P0D5Q<06adJ01<E4P80418?00L030h;01<E400C5A004aD@014C3P0>40/030h900804A<>0P0B
50l04@0A4`h0418=00h@2`0210005QPC014C3P0I6aH030h9010B3@0A4`h04aD@01@F4@0E5a804aD@
00lA300@4Pd04Q@?00804A<>0P0@4Pd01`0A4`h0418=00h@2`0@4Pd05aTC01TL5@0F6A800P0B5@h0
300D5a004aH?00d@2@0?4P/05QTB00d@2@0;3PL04QH?00dB2`0S:24061dF014F3`803a@=00D04QL@
01DJ4`0@5@h05AXC01@I4P0201<H4P8051TC0P0E6Q@201<H4P@051TC00X05AXF01HK5`0G71P0724M
0456@P0J7a/061dI01DJ5P0F6aL06AhJ0P0H7AT0100H7aP051/D01@K500F7AH201<J4`0901HM5P0H
7aP06B0I01LN5`0H7aP06b8K01TP6@0J8AX06b8K00806B8M00L0624L014L600R;BX06B<R024]:`0H
92806RHT00807bTX01T07RPW01hZ:00P;2X082`Z02@c<00U=34062PU02De<P0Y>CH08C4^01lb<00Q
=3808SDc02<f=00^@3l0;Clo02Pj>P0Y>c`0:cdo02`n@00/?T40:S`n02i2@@0aAD<0=TY80080<TI4
04P0>4a:0396A00`A480<TI403I:B00hC4X0=d]902do?`0fB4P0>4Y:03e?C`12E5@0A5IF03I8B00k
CDd0>D];03mAD@0iBd/0=DU8049FF@0oE5L0BEiQ04MLG`10EEP0A5UL04QMH01;H6<0AeaO04QMH01>
HfH0Bf=U04URH`1;IFH0CFMX05I^L01=IFL0BV5S051UJ01BIFT0F6]_05MZKP1HJfl0FVic05U^L`1L
LGH0HGIk06AiOP1WO840J7f206EjO`1TNGh0IW^006MlP@1VNh00Jh2206f1P01]Ogl0MHN706IhN01j
RXX0S9bL0761P@1ePh@0MXB506mmOP1`OWl0M8:407>1PP1ePh@0NhZ807j=RP1oRhL207^7P`0A082=
R`21Shl0Ohf>07b:S@22SI40Q8nC08NBUP26TI<0QI2B08JAT`21SHd0PXj>08>?S@21SH/0P8b:08:>
S028U9000P25THd0H@23Sh/0PHf908ZFU02:UY@0T9bJ096MW@2;UiL0SIVI08jKW02:V9/0QiJI08RG
VP28V9P0QIFE08JFUP22TY40Ohn>07f=RP1iRHH0MXJ307Z:Q`1nShT0NHZ307>4O01`PGT0K7ed06Mh
KP1SM6X0GVmT05U[G`1AHeL0AEM:04AFB012Dd<0@eE2041C@01:G4`0F6aL059WF01=HED0DVMK04aR
EP19GUD0C69J04iUG@1BJF40BF1H04AKD@17G5<0K89f07J<O`0iCD40=DPm03E6?P0a@SX0:3Tc02Df
<00V=R`08S8W024a9P0^?S@07RdV02Lf;`0b@Ch0;cdm01HT900lBT/0@Dm@05YZJP0[?3`07C0^03]>
C00_@T00:SXg0310?@0U=C80:3Lb02Th<`0X=c809S8^02Da;@0Q;BT07b/W020/:00Q;BT07RXV01`X
900T<2`08BdY01l[9`0N:RH06bLS01TU8@0O:2D06b@Q01XS800I8Ql00`0G81d0200K924092dZ020Y
9P0K92406b8P01TO7@0H7Q`06AlM0P0K8Al02P0J81h05A/I018H5P0F71X06R0N01LM6`0G7Q/0624L
01LP6`0G7QX301HL600301LL600I6aP06A/H00806A/H02@06adJ014C400H6QL05aTF01`N6`0T9R<0
7AlL01DG500C5A805aTF01DG500B5A804aPD010F4P0A5Q804aPD01@I5@0E5a@03Q0=01TK600?3`d0
5aLE010@3P0E5A<040h?01`J6`092@T01`T801lS8P0;3P`04QPF00lE4`0C5QD05ADE00T92@0;2@X2
010?3@04014@3P0@3`d04A0>01HE4`804A0>0P0@3`d200l>300801@@3`0E4A004`l>014=300@30/0
4@d<00h:2@0?2`X2010<2`0H00l;2P0>2PL04`h;01@@30081`<00@0002LW:00G61X0BT]=028R8`0E
5A<00`0002@P70070P003PX9010<2`0?2`X040`;018>3@0<20L040`;01@@3`0>2PT030P70`0@30/0
2@0>2PT03`/:018>3@0B3Pd04@d<00`81`0=2@P03PX900l;2P0200h:2@0A01D@3@0<1`@04@`900l:
1`0910402`H300/61@0G4Pl05Q4>00d81P0400001`8000h91P0B3@X05a8?01<>2`0>2@H00`0@2`P2
00l:1`0J00h91P0>2PL07a/H00`81@070`800`00044m>P1eLFh061@A00d91P0<20D04@d:00h:1`0<
1`@03@P500/60`0?2PL04Pd:014<2@0G4Pl0100000`7100k=S<06A@A00D0000;1PD6010:2P0500l9
2@0>20P03PP800h8200=1`L00P0;1@D0100>2@T01`4100X4100=1`L500h8200700h91`0>2@D03PT5
00`70`0C3PP030L101<?1`0300h90`803PT500<03PT600d71`0=1`T0100=1`T600`620H03`T;00`0
2@<509jHVP2MUiT03`T;014<3@0D3Q003`@:0146300D2@l030470146300<0@L2014630805@X@0P0A
1P`Dooooo`006oooool0800821003@dE00X:4P0<3A8051DJ018C60082@d04a@G01LH6P0A4Q@010D7
00l@4P0:2@h030/@01@C600H5a`01`H;01LF6`0=314030/@014@5@0?3Q<030/@00h=4P0:2@l051<H
00l>4`0:2@h06ATK00P82P0?3a40410@0P0>3Ph02@0?3`l0410@00d=2`0G5aD0820N01@D4P0F5Q@0
1@D300d=2`02010@3P803Ph<00@03`l=00h=2@0>3@T03`h:0`0@3`/0;@0B4@d03`h:00d<200<2`L0
3@`800P91@0:3`/03A8>00D:1P0;40`06AhJ05MLF01BEe<05a`H00/@30093PX03Q<?00P;1@0<3@D0
3@h600l@2@0A4P`04Q<=04]<A`2GV9<0=3@b010@3P0;2`T03`l=010@3P0>3`X030`:00h?2`0@4@`0
3Ph<01PI5@0>3`X01PH401HF4`0I6QD04a<A00l@2`0B4`h04A8=010A300200l@2`03014B3@0@4@`0
3a0;00803Pl:02403a0;00l?3@0?3`d0410>00l?3@0>3P`03@d;00h>300B4Q005ADC010@3P0=3@/0
3Ph<00H81`0M7ah07b4P07EgMP0/;Rd01@H500T;2P0@4Q404A<B00X<2`082PT03a4@010@3P0=3@/0
6ATG01LG5@0?3`d030`:014A3`0@40h00P0?3`d0100@40h04A4?00l>2P0?3PX2010?2`804A0<00X0
3Pd901DD400@3`/03@`8018A3@0A4Pd04A4?01LI5P0H6QL04Q@A0P0<3P/020082PL061XG00/=2P0D
5Q<03Q0=00/=2P0B4Q004A4?0P0@40h00`0?3`d03Ph<018B4002010@3P0<014A3`0?3`d03@d;00/=
2P0B51405ALD010B3`0>40d04aDB018D4@0G6AH04Q@A0P0@4Pl01@0=3``03Q0;00lA300@4Pd04A<>
00803a4<1P0A4`h01P0B50l061XE01PJ5@0;3@P06A/F00H80`803a4<00L0418=014C3P0A4`h04A<>
00lA300@4Pd04A<>00<0418=00P04Q@?01DG4P0D5Q40418=00lA300D5Q005QTB01<F3`8041<<00P0
4QD>01PK500B5@h041<<01@G400<3`P05APA02@X8@803A8;00T04aPA02<X8@0G71D04aPA01XO600L
8AX04AH?01TN5`0F6a@00P0C618201@I4`805AXD0P0G71H201HK5@0E01LL5P0H7AL06QlK010E4@0F
6aL08RLS05MLF00Q9R805a`H01@I5@0G71P06AhJ01@I5@0F6aL05A`E01<J4`0E71D06B0I01/R6`0L
8a`05ahG008061lH00l05QdF01PO600N9Ah06B0I01/R6`0M91d06b@O01XS7P0H8A`051lK01TT8@0J
92<05b<Q020/:P0J9R@00`0N:2L07`0N:RP082`Z024]:`0N;BX09cLd00lO700^?S/09SHc01h^:`0D
9bD08cHd02Tl>P0aA4808S@c02@f=P0dATH0;Cm003A6B00gBD/0;Cm202Xl?P0^@T40;d=103=7A@0_
@d40;T9003=7A@0aAD<0;d=10314@P0fBTP00P0jCT`203Y<C00G03I8B00dATH0?e5A03U;B`0nD500
>de=03a>CP0nD500=DM704eQH016FUd0AU]N04QMH016Feh0@5EH03iCEP18GF00Bf1S04QMH01:Gf80
CfAW04aTIP18HF800P1;IFH01@1GKg40CVIX05=YK01AIVT0DfIZ00<0FVea02d0Ffmd05Y_M01LLGH0
H7Ej06AiOP1WO840IGYo069gO01SN7d0IW^006QmPP1YOX<0KH:406YnO@1/OWh0LhF506MiN@1kRh/0
Ri^K07F5Q@1gQHH0N8J707B2P`1fQ8D0NhV;07^9S01mRh`0P8j?082?S01oRhL0NhN307f9Q@22THl0
Q9:C082>S`1jR8/0OhZ>08:=T@29U9P0RIBF08NBU023SY00P8b<086=S@22SX`00P21SH/01P24T8h0
Qi>?08NCS`29UI40Q92<086=R@80RiNE00H0Si^I08fIV@29UID0S9RH08jIV`29UiX208JEV01508JF
UP25UID0QYJF086AT01oShh0OHf:07b<R@1nSX/0PY:?07j?R@1gR840L85i06enMP1ZNg80IWM]06Qi
K`1SMFX0GFmS05AVFP17FD`0AeU904=DA015Ed@0A5M404aNCP1DJ5P0CF9C04UMD@1@IET0B5iB04IK
DP1?IEd0CFAL05A[I@1GKVL0EfiT04eRF@19Ge<0=de003]?@`0kCD80>T]103E6@00]?ST0:CXd01LW
700[>c005bLL028b:00K:R<0;3/d01h]:P0jB4P0<Clo02Pf=`0W=CH08c<c02<d=00O<S00;T4o024d
<P0T=340;cll02<c<00X=c80:CPc02Pg<P0U<Bd08bl[00<07b/W00@08BdY020/:00P;2P08bl[0P0N
:RH01@0P;2P07BTU01XV8P0Q:RL06b@Q00806B8O0P0H8Ah00`0E7Q/051dJ01XS800201XS800801lV
900M8b406R0N01dS8@0P9R@07bDS01/Q7`0H7Q`201LM6`0M01TO7@0K8Al072<P01TR7@0H8A`061lK
01LM6@0H7QX07R@P01lT800K7AX06A/H01XL6@0I6aP05aTF014C400O8Ah0828O01dO700D5Q<04Q@A
01@F4`0C5A805QPE01XL6@0F6QH03a@@00hD400@5A400P0D6AD0500C5A804A<@01TK600B4Q005ADC
010@3P0B4Q0040h?00h<3@0I6QX041@C00T=300H7Q`07B<Q05QNG00I7A`03Q0?01@D500D4Q<04A0>
0P0B4@l200l>3003018A3`0A40h04A0>008040l=0P0?3P`01`0B3Pd05A4@01<?3P0?2`X03PX9018>
3@0A3@`00P0B3Pd2014=300?00l;200B3@X04Pd:01XI5@0G5AH00`<400h?4@1dMGL05aPI01HF500V
8R40HUiJ01TD400D40l040`;00802PH500T03`/:010<2`0C3`h06ADD01HB4@0?2`X04@d<01DA400?
2`X00P0<20L0100>2PT040`;014=300>2PT200d9200<00h:2@0?2`X040`;00P30@0?2PL05A0=014<
2@0?2PL05A0=00l:1`0@2`P03`X70P0B3@X01`0P6aP04@`900d81@0?2PL03@P500l:1`0D3``00P0@
2`P200l:1`0A00h91P091@<0510=00l;200E4@h01P8000<0000R7Q/04@d:00P40@0:1P<04Ph;00l;
20091@802`H300d81@0>2@H00P0B3@X01`0?2PL01`8000h91P0:1@@01000018=2P0F4@l01@0?2@T0
100@2PX03`T900l92@0>20P200d71`0601<=3@0L5QH040X:00T30`0<1PH02`D51P0>20P01P0?2PL0
30L300h91@0H4a003@P4014<20<03PT500@03PT600h91@0>2@H03@L72`0=1`T700h82P0=02hX:P11
>cd040X<020J700U7b404`P>00h32@0A1P`02P0501D:400?10X03P<900l42P020146300300l42P0>
0`Wooooo01?ooooo000Kooooo`0401<C6`0A4AT03@dE00`=4P80414F01T0414E00d>4@082@/04a@F
014B500?41805A@I00l>4`061PX030/@00d<4@0B4AH030/@00h=4P0@3a@03@`A01TH7@0V9BX03PdC
00X93P0D4aP030/@00l?4@0>3Q00410B00803`l?00l030`<00l?3`0D51@03@d;030`;P2XZ:H0:BTW
010@3P0>3P`0410>014A3`0@40h030`:00X:200;2`T00P0>3@T01@0?3PX040l;010?2`0@3`/04Q4=
00804a8>01404A0<00d<200?4@d01``800dB3P0@5A402Pl;01TN6P083@T04aPD00/@300?51001P/7
00hC3`0;3`P03a4600l@2002010A2@08010A2`0T9Al0DE9=018B400=3@`04Q8B010@400=3PX200h?
2@0300h?2P0?40X03Pl:008030d700D04Q<=00/<1`0A4P`061TC010A3002014B3@03010A300?40/0
3a0;0080414<00D03a0;00h?2P0=3PT03@h9010@3P03014A3`0F010@3P0?3`d09BDS01`L6P0?3`d0
3Ph<010@3P0?3`d03@l>00L81`0A4a80:B/Z00X<2`0@4Q404A<B00/=300=3`h04Q@C00d?3P0A4a80
6QXH00P81`804A4@00@03@d;010@3P0A4@l0410>0P0?3`d0100@40h04A4?00l>2P0?3PX2010?2`@0
4A0<01803Pd9010?2`0A40`03@d900/;2@0K7AX07b4N01DG500=3``0418?014C400L7Q/03@l<014C
400?4@h03@l<018B400A4@l3010@3P0800l?3@0B4Q003`l=00l?3@0A4@l0410>00h>300X:RL200X<
2@09010B3`0?4@h03Q0=00lA3P0A4a00418?014C400B51404A<@00<04aD@00@04Q@?014C3P0A4`h0
4Q@?100A4`h03@0B50l04aD@01<E40082PD04Q@?00/=200B50l04aD@018D3`0A4`h0418=00lA300@
4Pd00P0A4`h01@0B50l0418=00lA300?4@`04A<>008051HA00<04Q@?014C3P0B50h00`0B5@h201<F
3`0B01@G400B5@h05APA01LJ4`0@4``07B0I02lc;00>4@d05a`E01TN5`0D6A804aPA01@I4P0N8a`0
7B8K018G400G71D051TB0P0C618201@I4`805AXD00/06AhH01PM5`0G71H05AXD01HK5@0H7AL0724M
014F4P0L8Ad04aPD02P]:@0201@I5@0301LL600I7QX05a`H00805AXF00H06B0I01PO600D6a@05QdF
01/R6`0M91d301TP6@0?01LN5`0H7aP07RDN01/Q7@0M8al07R@P01dV8@0M9R8072DR02@_:`0nBDH0
7BLV01TU9@0N:RX09S8b00<082XY01/082`Z028^;00S;bd07bh[02Dd<@0N;R/0;cll02Hf<`0eAD80
:Sdk02@g=@0Y?3X0AeUI03Q:BP0Z?3`0BeeO0312A00[?Cl0<D=70312AP0bA4H0;d=202i2@00bAT@0
<4A202i2@00aAD<00P0`A480200bAT@0>4a:03Y>C00iCD/0<TA403=5A@0gBDT0>de=0P11De<204mQ
H@0L04=EE@18FUX0C5iN05EYJ01?HfH0C65T04=HF`15FUd0B5eP041EF01=HVD0D6EX04iSIP1@IFP0
E6U/055YJ`1>IfT0CfUZ04]UIP1?IfT0AemQ05AZK@1BIfX0E6M[05a_L`1ML7@0Ffib05eaMP80GW=h
00D0GgAi065fN`1SN7d0IW^006QmPP0206YoQ080J7f205T0Jgn006f0OP1bQH<0LHB207:5P`1jRXT0
NhZ907^9R@1jR8P0OHZ:07^7Q`1lR8P0Q8nB08F@U023TI80QI>C08BCT@21T8`0Ohj9086@S026U9@0
QYBE08>ATP20Rhl0QXnF08VBV@2@VIh0U9fR096JW`29TiD0QHn@08J@T@26T8l0Q8n;08F@S02:UI40
RIB@08ZET@2?VYH0S9NC08JAS@2;UI@0SINF092JV@2=UiP0RYBE08jHV@2?VI/0RYRK08ZIW027UYT0
QIFE08NGU`28V9P0Pi>B086AT01lS8T0NXZ707b<R@1jRXH0NX^507B5O@1]OWH0JW]a06IgK@1RLfT0
HWAX05QZGP1@HUH0Bee?045CA@10DT80A5E504MIAP1:GDX0CV1@04mSD`19GTl0BEeA04mTF01;HED0
C65H05=YH01@Iel0DVMR04mTGP1=HUT0@eQ?03mDB00203M<?@0L03A7>`0_@3H0;Sdh02Xi=@0Q<2/0
72`Q02Lg;00M;B80CemE03e<A@0S<R/0:3Ld02Hd=00J:2P0;C/l02@b<`0[>c/0:c`l02Xm>`0/?cd0
>Te;02hn>`0I:BH08S8_02Lf<@0Y>3<0:3Lb02@`;0<08BdY0P0P;2P0>P0R;RX08bl[01hZ9P0L:2@0
7RXV028^:P0Q;BT082`X024Z9`0L9B806b@Q01XS800I8Ql05b0M01<L6@0E7Q/072DR01TR7`0G81d0
6b8P01/Q7`0I7ad06R0N01`R800K8Al06AlM01hT8P0Q9bD0728P01TO7@0Q9bD08BPU01PQ700G81/0
620K01TO6`0J81`082DQ01hS7`0I6aP05QPE01XL6@0K7AX0828O01TK600M7a`05ALD01/M6P0H6QL0
4aDB01TK600H6QL04Q@A01@F4`0F6QH04AHB010F4P0B5a<201<H500F014C400B514051HC018B400C
4a4051@B010@3P0A3a005QDE010A400I7A`0BDe<02hd<P18CT`0^Knm02``;`0=3`h05AHE00d<3@0?
3P`040l=014@3P8040l=00<04Q4?014@3P0A40h00P0@3`d200l>3008010<2`0B3Pd04@d<00l;2P0@
30/0510?010<2`0A3@`2018>3@0I014=300@30T04Pd:014=2P0Z:BD04Q0A00d>3`0?41803PlA00l?
40092@L05A4@01TE4@0;1P<04Ph=01@@3`0H51<05Q8A014=300@30/04@d<01LC4P0J5QD04`l>00l;
2P02018>3@0M010<2`0?2`X03`/:01<?3P0E4A004Ph=00l;2P0>2PT03`/:01<?3P0E4A004@`900X5
0`0?2PL05A0=00d81@0910<03PT700`71@0@2`P040/900L20@0A30/04@`9010;200E40d050l<010;
200A30T00P0@2`P200l:1`0:00h91P0A3@X01`@200l;200=2@L02`P6018>2`0=2@L040`900l;20<0
3PX700d03PT601PC400M61D040/800`7100@2`P050l<00h91P0>2@L03@P501HA3P0G4Pl030L600D0
3@L70`0?2@T200h8200700d71`0B30`0<B/[00d71`0<1PH04`d=00l92@0600h820803@P500P04@`:
01dG5`0A30X03PP700h9200>2@L03PT800h820803PT700<03@L800d72@0=1`T00`0=1`T<00h82P0>
00l92`0A2`d04P`>01@>400910D05a4C00h32@0=0PP04PL=01D:400>10T04`P>00l42P0A1P`200l4
2P030146300?10[ooooo01?ooooo000Kooooo`0C00d=5@092A4020P@00X;400@4AH05QLL010A5@0J
6ah03PlA00H72@0@4A<02@X<00D42@0:2@h01`H;02`[<00=31404Q4F014@5@0200`;400N00d<4@0E
51T07QdR018A5`0F5AX04A0E00d<4@0<30h05aLI00d=3`0A4A405ADE00h>3P0<30`04Q8B01@D4P0O
7ad0CTi<00P81`0A4@l061PF00l?3@0@40h03`l=00`<2P0:2PP02`/900l=2@0@3@P04@h91P0B3`X0
6`0A3PT040d800P:1P0F71P01`d900P>2P052`L03aDA00`B3P0E6aL02@l;00P>2P093`/051XF00lC
300B50T04A8:00l@200=3PH030d701@E400T9B006a/I00l?3P0;2`/03`l?010A3@0300l@20803Pl7
00L05AH>00X;0`0720005AH>00L8000310003Pl900803Pl:100?40/2010A300300l@2`0>3`X030d8
00803Ph<0`0@40h06@0?3`d0<S8`02LW9@0D51802`/900`<2P0=3@/061XI0001000J71/0008100h@
3`0C51<04Q@C014C4P0620L02P`;018D4`072@P01PH402DU8`1@D4h03@d;018B4@0D51800P0?3`d2
00h>30803`l=00@03`h:014>2@0B3`X04Pl:0P0C40/201@A300A01HC3P0H5A005Q<>014@300<30X0
418?018D4@0?4@h030h;00d?300C5A803Q0=00d?30092`P03a4>00`>2`0?3`d00`0@40h3014A3`0>
00l?3@0@40h04Q8@014A3`0@40h0>C/h00h@3@0<3P/04Q@A00X<2@0620D03a4>00h@3@0?4@h3010B
3`0401HH4`0D5Q404Q@?014C3P80418=00@04Q@?010B3@0@4Pd0418=0P0B50l01`0C5A003a4<00h@
2`0E5a8010H101LI500C5A000P0B50l2010B3@09014C3P0B50l04Q@?01<E400A4`h0418=00lA300@
4Pd04A<>0080418=00@04Q@?01HH4P0E61404aH?0P0B5@h301@G400801LJ4`0D5a0030l800/>1`0D
61403Q<<01HK500;40T2018G400601HK500E6Q<05AXC018G400A5Pl051TB0P0C618201@I4`805AXD
01L06QlI01TN600F6aD051TC01DJ500G71H07R<O00`A3@0=4Ph082DQ01hS7`0I7QX05AXF01XO6`0F
6aL0724M02P]:@0K81`07RDN01lV7`0K8Q/06B0I01dT7@0401XQ6P8061lH00d072<L01`R7P0L8Qh0
728N01/T8@0M9R<07RLT00dG5P1aNgX0;cTh028^;P0T<3005b<S00808B//01P08R`]028^;P0U<C40
9S8b028`<00P;bh072`[02De=00Q<C00;Shm02Hi=`0]@3h08cHd02<e=@0S=CH0;Cm103e?D@0a@dH0
:C/o02Xl@00`@TH0=4I80355A00^@T0203=7A@0]0314@P0cAdD0<DE303I:B00kCdd0?U9@03Y>C00g
BdT0?U1@03Y<C00iBd/0=4I60312@P1=Gel0GFm_04YLG01=Gel0D69R04]MG@0nDU40G71c04EJG@1<
HF@0D6EX04AIG011EUT0B5eP04iSIP1<HF@0CV=V059WJP1>IVP0CFIX04QRH`1DKVl0DFU[05E]K`1I
L780EFY]05IYK@1PLgL0HGAh05iaM@1PM7P0HGIk0080H7Ej00l0HWMl06AiOP1XOH80KH:706n4R@1/
PHH0IGYo06AiOP1VNW/0IGQf06j1O`1aPh40OHf<08BDT`1iR8P00P1kRHT02022Shl0PXj>08>?S`27
TYD0R9>G08JAT`26Ti@0R9JF0P27Ui@02028V9D0RYRH08bGV@2;UYP0RYFJ08bEW02;U9/0S9FJ0P2@
VIh02@2<UYP0RiFF08^EUP2:U9<0R9>?08VDT02=V9@0SiZF08bGT`0208fHU00<08ZET@2<UYD0SYRG
092JV@2>V9T0S9JG092JV`2>VI/0RYRK08^JW@27UYT0Pi>C0P28V9P0@P25UI@0QYJE086ASP1nSX/0
P92=07R9P`1fQh40LH9j06]lM01WN6h0H75W05UZH01DIUX0@eE803i@@P10DT@0?e5303i@@019FTX0
BUa:04mRC`1AHe<0Cf=C04aQDP1<H5@0C65E059XG01DJF00DFMO055XH01DJF@0CfAN04]PE`10E4/0
>dm303I;?00jC3h0=4Hj0311=`0hAd80@4m;03I5@P0Z>S00:SX_020`9@0U=B/0;Sdf02ln=`0]?3T0
8Bl_02Xh>00T<S<0@Dm@01XZ:P0Y>SX0:3/i02e0?P17FUP0<D4n01XZ9`0Q<Bh09C@_02Lf<@0U=2l0
8bl[024]:@808RhZ00D082`X01`X900N:RH082`X01`X900201hZ9P0401dY9@0O:bL082`X020Y9P80
7BHS00X06b@Q01PQ7P0H8Ah0624N01/T8@0S;2T07BHS01LP7@0H7ad06R0N0`0K8Al02`0M8b40728P
01TO7@0I7ad05Q`J01DK6@0H7Q`06R4N01PQ700G81/05ahJ00<05adI00/05Q/G01LI5P0H6QL061XG
01LI5P0E5a@03a4>01TK600H6QL07R0M014C4002010B3`0701@F4`0F61D051HC01DI5@0C61@04ALC
018G4`0201<H500F018D4@0H6QL04Q@A01@D4P0H61H0820N01DE4`0F5QH02`/;01HH5`0;3`h0720O
01PO7@0740d06R0N00hB4@0Y:bX03@l>00l?3`0=30X03`h<014@3P8040l=00<04Q4?014@3P0A40h0
0P0@3`d200l>300401PD4`0D40l04@d<014=30804`l>00<03@T800l;2P0A3@`00P0C3`h08@0C3``0
100001XF4P010000518C00h>3`0F5aT020T;00d=3P0M7A/01`<201<?2`0K5Q802`L600l;2P0G4a80
510?00`81`0>2PT040`;00h:2@0C3`h040`;00`81`0@30/03@T800h:2@0=2@P02`L600h:2@0A3@`0
3@T800h:2@02010<2`803PX901804@`901D@3@0@2`P02PD201HA3P0P6aP03`X7014<2@0910402PD3
03Pc<01/If@040/801<>2`0L5a@06aHC010;200<1`@2010;20803`X701X03PT601<?300300000`00
018>2`0G4a005Q8?014=2P0F4Pl04`l<00l;200=2@H03PX7018=2P0O6QL081/H00l:1`0<1`@040/8
00d81@070P0040/8014<2@0500002`H300d81PL03@L70`0>20P01@0?2@T02`D501@>3P0@2PX02@<3
00802`D51P0>20P02P0;1@D03`T900`6200D3Q004P`>00`62@0>20`03PP:00h82`0>20X200h820H0
3@L91P0>20X600d72@0>00T31@0A2`d02@<500/51`0F41805a4C00T0100@1@/03P<901X?5@0;0PH0
AS]100l42P0B1`d200h32@0301873@0?10[ooooo01?ooooo000Kooooo`0U018B6P0=3AD02``A00`=
4P0@4AH05aPL00`=4@0l?Cl0<S<e00T:300<3@l0414C00D42@0E51T04A0E0000100=31403PdB014@
5@0;2Pl03`hC00h=4P040`P0000402l^=011@4D04A0E00l>4`0C4aD020P:00h>400F5QH071`L01@D
500=3@d04Q8B00X;200200/;2@0401LG5@0:2PP030`:00d=2`803`l=00H03@d;00`<2P0>3@T03`d9
010=200A3PT3018?2P0=01<@2`0@3@P03P/600l<1`0@3@P03@d9059GD`0_=300314=00lD40093PX0
1``801@I5@0200hC3`0300X?2`0B5a<030l90080414901L03a0900h?2@0>3`T03Pl:0083000@40h0
30`:00l?3@0@41003`l;00l@200@4@/0414:00h?1`0?40X030d601TJ4P0G618030d601<D300@4@/0
30d700`=200200h?2P803a0;00H04A8=018C3P0D5A004a@?014B3@0=3PT200`=200400h?2P0?40/0
3a0;00l?3@802@T70P0:2PP05P0<30X03`l=00h>3P0A4a802`d<01<E500=3`h03Q4@00X<2`0>40l0
51HE01<E500;3@`02@X:01lO7@051@<06a/I00`<2P0=3@/04Q8@00l?3@0>3P`200d=2`0A00h>300?
3`d03`h:010>2P0@3`X04Ph;018@300A40/03@T600l=2@0C4Pd0510=010=2@0?3PX07AdK01@F4`0@
4Pl00P0B51405@0?4@h05ALD00X;2@0@4Pl01PP500h@3@092`P03Ph<00l@300@4@`0410>014B3P0B
4`h0414=00l?3@0@4@`04a<@01<C4@0B4Q003@l<00L91P0200lA3P0400d?300E5a@04A<@00h@3@80
3a4>00<03@l<00h@3@0?4@`00P0>40/03`0?4@`0418=010B3@0C5A00418=00lA300@4Pd04Q@?01<E
400620D06Q`G01@F4@0<3PT04A<>01LI500500lA300X014C3P0C5Pl04aD@01<F400B5@h04A<>018D
3P0C5Pl04Q@?010B300@4``04aD@01TL5@0H6a@04QD>00hA2P0?4P/04aH?01DH4@0F6A8051L@01DH
4@0L7aP06A`E00lC300F6a@061dF00dB2`0Q9Ql03A8;014F3`0A5Q004QLA01DJ500A5Q0061dG01<H
4P0C614051TB01@I4`805AXD00<07B8L01/P6P0H7AP00P0G71P03`0J7a/03a<B018F5@0D61L0720O
00`A3@0M8Ql05a`H01/P700C61@08BHR03Hk=`0N91l05QdF01/R6`0201XQ6P0301hU7P0H7aP06R4J
00806b8K0P0H7aP03@0K8Q/06b4M01/Q7@0J81`06B8M01`U8@0N9b@08bhZ01dX900G8al09S8`028^
;00S;bd00P0Q;B/02P0R;R`08C0]02@c<@0V=3@09cDe02Ph=`0M;B`0;3`k02<c<P0I;2X202Dh=P1?
01lb<00U=cL0;T1102Tk?@0W>C/0<TA603E7B@0bA4P0<49502e1@P0_@d80;40n0355@`0bAT@0<4A2
0396A00cAdD0>De;03mCDP12EUD0>dm>03M;BP0eBDL0=4M503E9A`0oDe40D6=Q08VMW02[_[h0Cf5S
05U]KP1;GV00CEmQ05ibL`2DZJX0BEiQ04QMGP16Fed0?eAG04mTI@1;H680DFIY04mTI@1BIfT0EFY]
05AYK01?J6T0@UaM05QbL`1=IFL0EFe_05I]K`1FJfh0Efa_069fN@1SN7/0H7=g061eN@1RMg`0H7Ej
065fN`1TNGh0Igb106MlO`1XOH00KH2406YmP@1UN7`0I7Mk06UlO01SMW@0LX:107^;RP25UI@0Tj>S
08FDU@1lRX/0OXb=08NDU@0208VDUP0608^FVP27TYP0QI2D08NBU029UiP0RiVI0P2=Vi/02P2=VY/0
SYVK08jIW@2?VZ00UYnV096JW`2=UY/0T9VN09>LX@2DWZ0208jHV@0V08bFUP29Ti80RYBC08nIV02D
WYd0SYVE08^ET`2<UYD0RiFD08jHU`2<UYD0SYRG08bGU`2<UYL0SYZJ08bFV027UIP0RIRK08BCUP20
Si80QIFE08JFUP1kRh/0OHf<07b<RP1mSHX0PI6>07V9QP1gR800LX=k06]lLP1VMfd0G6eS05=UF@18
FTh0=TPj0353<`0hBSX203]=?@0P04YLC01<GTh0CfAC05=UE`1@IEH0Cf=G04eQE@19GU80E6YN05M/
H`1?IE/0DFQP04iUG`16FUL0@5E>03U=A00mD4@0@eE703e?@@0b@cP09cP`02dn>00b@T008c<`02hn
=@0R<RP0;cle02hm=P0]?3D0;3/f02Pg=00[>SL202Pf=P0=02dk>`0/?3/0:c`l02/n?00W>SP09STf
01DU8P0H:B<08S8]02@c;P0U=2l09C<^02<_:`02028^:P0<02<^:P0N:RH06RHR01`W8`0N:RH072LS
020[9`0M:BD06RHR01`W8`0O:RH082TV0P0N9b@02`0L9B80624N01LP7@0D7AX04AXG01DN6`0B6aP0
4AXG01<J600F71X06AlM008061hL00/07B<Q028X9P0M8b406AlM01XP7P0K8Al061hL01TO700J8ah0
6R0L01LM6@0201DK5`0C01DJ5P0G71P071hK01dO700G6AH04aDB01DH5@0C61@06QlK01LJ5`0Q8b00
5QPE01TK600B51405QPE01/M6P0E5A<03Pl=01<H5002014F4P0F01DG500F61D05ALD01PJ5`0?4@h0
410>01DE4`0N7Q`03`l=01@D50061PH05ALF00D71P0<40l041DC01TO7@000@004a@C014A4@0G5aL0
3@/<018A3`804a8@00<03`h<00d<2P0=30X00P0A40h2010?3@803`h<01T07QXI01LC4`0B3Pd04`l@
01@@400A3@`03`/<018>3P0D40l05Q8C01LC4`0H51<05a8?00h:1`0J5QD030/9014A4@0<30`0>CTk
00l?3`040`4040`;00h:200?2PL05Q8A008040`;0P0>2PT0500J5QD04`l>00/71P0?2`X040`;00h:
2@0B3Pd03`/:018>3@0A3@`03PX9014=300D40l040`;01HB4@0J5QD06ADD01<?3P0@30/040/80P09
1042010;200=00X50P0B3@X030L401<>2`0E40d02@@101<>2`0A30T03`X701D@3@0F4@h040/800l:
1`02010;20803`X700`03PT600X60`0E4@h03`/800P40P0<20D01@40014=2P0D40d03PX700`81@0>
2PL2010<2@0<01PC400G4Pl02PD200l:1`0B3@X03PT600d81@0A30T020@200`7100E40d040X91@0>
20P300d71`0800h8200?2@T03`T9018<300;1@D09R0P018<300<1PH700h8200600/51@0A2`/01`83
00d72`0@2Ph030H:0`0>20`200h82P0300h8200=1`T03@L900@03@L91P0>20X600d72@0>01@>400;
1@L0618D00X41P0@2P`0100000`11`0B20d01`0201H;4@0C2Ph0Mfab00`11`0@1@/200/01P030105
2`0<0@Oooooo01?ooooo000Kooooo`0=00d<4P0@3aD04Q4F010?500?3Q<03`lA00P82P0T92H08R8R
010@400;2`/051@D00d=3`02010@4P803Ph@00<04A4C010@4P0@41800P0?3a402`0>3Q003PdA018A
5`0M72406APM00/:3`0A4A<03@d?010@4P0?3`l03Ph>00803`l?00`0414@00X=301:CD`0CU5@018D
4`0A4a0030h;00h>300?40/0414<010?2`0?3PT200h=2@803`h:00`03@`800h=2@0?3PX040l;014@
300@3`/03Pd9010?2`0B4@d04A4<010@2`0?3`X200h>2P0700l?2P0@40/03`l;00d=2@0A4@d0410;
00h>2P02010A2`0<00l@2`0>3`X03Pl:00`=200@4@`05QLB010A300=3PT08b<P02TZ9@0C50h04A8=
0P0>3`X01P0?40/04A8=010A2`0>3`X03@h900h?2P80414<00H03Pl9014B300D5@l04a@>00l@2P0>
3`T2010A2`0E00`=1`0?40X04a@>018C300?40T04Q<<01<D3P0@4@/04A8<00h?2P0?40/03Ph<01@D
4P0L71X05aLE010?3@0<30X05aPE01<E4P0D6AD04aTE00803A8>00L03A4=00l@3P0@40h03@d;00l?
3@0<30X0410>00804A4?00<04Q8@00l?3@0C4a400P0@40h01@0C4a403`l=014A3`0@40d03a0<0080
4A0>01`03`l<014A3`0B4@l03Ph;010?3@0B4Pl030`:02<U8P0@4Pl04A<@01<E4P0>40d04A<@00lA
3P0];b`04Q@A01DG500>3`d03Q0=018D3`0@4`d03Q4:00d@2P0>4@X03a8;01DH4@0H6aD04QD>0P0@
4`d00`0=3`X04Q8@014A3`02010@3P0501<C4@0=3@/04Q8@014A3`0@40h00P0A4@l01P0B4Q004a@?
010A300A4Pd051D@018C3P80414<00T04Q<>01@E400C50l0414<00l@2`0@4@`051D@01DF4@0B4`h0
0P0@4@`00`0P8A`08B8M014B3@0201<D3`0801DG4@0B5@`03a8:018E3@0D5`h051L?018E3@0A50/2
018E3@0301<F3@0C5Ph04aH=00804QD<00@04A@;01<F3@0D5`h05AP?0P0@4`X0:00E60l05aXA01PK
4P0C5`h04QP>01@J4@0E6Q804aPA01<H4P0G71H05Q/G010D4`0F6QX06alO05AHF00D6a<04a/@018I
400B6A4051/C01LN5`0B61@05A/G01@J5`0C6AP05adL01PN7@0K82<05a`P01@I6`0G7Ad06R0O01/Q
800D6QL061hJ01DK5`0Q:2405ahG01TP6@0F7QP201PQ700301LP6`0J8ah06B8M00807BHQ02D09BhY
024Z9@0F7aX07RLR01dW7`0U;bL07RPP01TS6`0N:2407bXS01`W800N:R8082dU01l^9@0N;RD072`T
01l`:@0O<RX083<[024c;@0R=2h08C8^02@e<P0S=S<08cHd02@g=@0V>CL09cXh02@g=P0X?3/0:cln
02e1@00/@3l0:Shm0396A@0aAD@0;T910080;d=303X0;D500397B00bB4H0;TA203I<B@0gCDX0?E=@
03I<B@0^A4<0>4e>03E:CP0oDeT0>4e?03YAB00kDDL0>E1603U?A`1AIf40N8j;08nTY01;Gf<0CF9V
04QMH`1;GVH0DFA[051TI019GEd0B5aK04]OGP1<H600BemN05Q/J`1@I6@0DFET05M[J`1FJVX0DFIV
06ImO`1ILG<0E6a^05I^L01KLgD0EVi`05eeM`1KLgD0G7=f05YbM01IKg80H7Ij06j3R01JKg@0KX:6
06f0Q01[OX40K82006YmOP1/Ogh0KX1o0P1_PGh01P1aP800NHR806ilO@20SY00OXb>08^IW080PY2D
00D0PXnD08>@UP28UI`0RIJM08ZEW00208ZCVP0;08bEV`2>V9d0T9ZP092JW`2EWj@0TI^P09JOY@2C
W:<0TY^Q09ZSZ02?VI/00P2FX:8209BNX00<09:LWP26T980SINI08^EUP2DWZ00SINH08nGV@2?V9P0
TIVJ092JV`2AVi`0T9ZK0P2<V9P03@2=Vi/0SibL08fKV`2;V9T0RiVL08ZGW@29UY`0QiBJ08JCV024
TYD0P8jA07n=S`1mRh`00P1oSHd04@1lRhP0LhAl0762N01WNFd0H79V05]]H@1IJed0FVaM03e??P0d
Ac@0>4/g03Y=>@14F4D0I7U[05I[G`1<HUD0CF9F0080CfEI00<0DVQL055WF`1AIe/00P1CJEd03P1@
IUd0AEaF04EKEP12Ee00?e9903e=@`0mC440>4Ll02ho=@0/?SH0:Sdh02Hk>00/@Cl0<T=20`0c@d40
=@0[>cP093@a02/k>00W>3<0?Tm:0352?@0M;RT08S8_02Ph>00]?Cd09SHd028c;P0]?3D08C4X020]
9@0X=Bd08BhV02Da:`0N:BD0:cHb028/9`0W<2/0:38/02D_:P0P:B@07BLQ01/T7`0O:2<07bTS01`V
8@0M9R407RLR020W8`0P9R807bDQ01XP700O9B409B/W01`R7P0H7QX05adI01DK5`0H7QX072@O01XS
7P0I8Qd06b@O01dV8@0L9B006B8M020Y900K91l0624L00807BHQ00@07B@P01TN700I7A`06AdL0P0G
6aX0300l@3l06alN01/O7P0I7A`03a<B01@H5`0H7A/04APF01DK6@0F6aX05Q/I018F5@805QPG00P0
61PH01LF5P0E4a@04a4B01<C4@0C514051DB01@D4P805ADC02X06ATG01@D4P0@40h04a<A01HF500D
51806QXH00l?3@0C4a40410>014A3`0G5Q@07ahL01HE4`0C40l0518@018@3P0C3`h04Pl>014@3P0F
5A<05A@B010?3@0C4Q005aHD02DT8P0C4Q004A0>00h=2`0C4Q006QHG05=?DP0g<cD04@`@014<3`0=
2@/04@`@014=400A3@l04@`@014=400A3@h2010<2`0;014=300B3Pd04@l=014?3@0e<S804@l=014=
300G4a803`/:01<?3P0>20P00P0F41001@0B30`03`T900h8200@2PX04@/;00804`d=0P0@2PX01P0?
2`X02`L600l;2P0<20L06QHE00d920803`/:010040`;00l;2P0=2@P030P700l:1`0@2`P04@`9018=
2P0A30T040/801@?300J5A804`h;00h91P0E40d04`h;0P0A30T02`0@2`P03`X7010;200B3@X03@P6
00h91P0:1@<04@`900/60`0B3@X040/800@03`X700L040/800`7100F4@h04Pd;00h91P0G4Pl03@P6
00803@P500@040/8014<2@0?2PL03`X70P0@2`P05@0?2PL03PT600h91P0>2@H03`X700h91P0<1`@0
3`X7010;200?2PP02`H300d81P0A30T03PT701D@3@0L5aH04P`<010:2P0A2`/03@L700l92@0200d7
1`0801@>3P0E3`l03@L700`61P090`D06Q@F069LGP0`:R`200l92`0300h82P0;1@L02`D700803@L9
01<04P`>00d72@0;1@L03PP:00d72@0;1@L0618D00h82P0@2P`04P`>00T31@0E3a40618D00h82P06
008030L801@>400@2P`03@L900803`T;0P0>20X00`0=1`T030H801052@0501052@0601@93@0>0`L0
60dA00l6200B1`/03@<65?ooool001_ooooo00P040lE018A5P0A41D04A0E01@D5`0I6A/030`>010@
4@803Ph>00<04a<C018B4P0>3Q000P0@41800`0>3Q003`lA010@4P03010@4P<04A4C00T04Q4G02LV
:`0d<cP06APM010@4P0E5AL0410B00l?3`0>3Ph00P0?3`l02`0?4A004QDD01LK6P0K7ah03a4@00L7
1@0<30X03`l=00l>2P0>3@T03@`800803@`700D03`h:014@300@3`/03@`800`;1`0200d<2003018A
3@0C4Ph04Q4=00@040l;0`0?3PX0100@3`/04Q4=00l>2P0=30P201<B3P03010@300A4Pd04A8=0080
414<0P0?40/0300=3PT051D@01LH4`0>3`X0;RlZ03Hg<P0@4@`03Pl:00d>2@0>3`X03a0;00h?2P80
3@h900H03Pl:00l@2`0?40/04Q<>01<D3P0@4@/200`=1`03014B300=3PP02P/50080414;02802@X4
00l@2P0C50`0414901<D300E5Q004A8<018C3@0>3`X03a0;014A3`0F5Q@06ATG01<C4@0C4Q008R4O
01XK6@0G6AH03Q<?01LM6@052`L02Q0<010E4@0<30X02@T7010?3@0E5A<01PH404I6A00=3@/030`:
01hN700@40h051@B0P0B4Q00:@0D5180410>01<C4@0B4Q0030`:01PH5P0<30X04A4?00h>300@40h0
3@d;00l?3@0C4a403Ph<00<50P0:30T05QPE01<E4P082PL030h;00/=2P0H6QL0FUaI02X/:@0=3``0
3Q0=01/M600E5a803Q0;00`>2@0=3`X03a4<01<E400G6A@0418=00`>2@0@4Pd04Q@?018B400N7Q`0
5aLE00803@d;00@06a/I018B400A4@l0410>0P0A4@l01P0B4Q004a@?014B3@0A4Pd04a@?018C3P<0
4A8=0P0B4`h3014B3@0301@E400E5Q404a@?00804Q<>00<061TD01LH4`0<3@P00P0?40/01`0@4P/0
5QT@018E300B5@`0=CP_03<f;@0F6A000P0B5@`301<F3@03018E300A50/04QD<00<04aH=00P03A07
01DH3`0>4@P03Q4801LJ4@0?4PT04AD=018G408051TC00/04aPB01<H500F6aL05AXF014E500B5QD0
20`;01hR800E71D05A`D01DL5@0301HM5P0W01<I5@0F71P05A/G01@J600H7Q`061hM03@i?00X;C00
61dP01DK6`0D6QX02a4?020V900B61H05Q`H01`S700940T06R4J01HO6P0G81/0624L01dV8@0P:B@0
5QlJ01hW8P0K91l082TT024Z9@0I8Qd072DP01dV8@0R:bH07RLR01XU7`0M:2807bXT01dZ8`0O;2D0
82dV00807bhW01407RlW02<d;00U>C4093La024d;P0P<bh08cHb02@g<`0T=c@09CPf02Hi=`0Y?3X0
:chl02Pl>`0Z?Sd0:cln02a0?`0302i2@@0B02m3@P0aAD@0<TI503A8A`0eBDP0;d=402e1@@0bATD0
<TI404EJE@1ZOgX0=DU703A8B@0lD540>DaB03a?EP0dAd/0?EA<0P0iD4P02P12FE@0>e5>03eCD@16
Fe`0AEYO059WK01DJ6l0AEUP04aQIP18G5`204UMG00604YNG@1=HF00Cf=R059VI@1CIfH0E6QW0P1F
JVT02@1EJFP0FVmb05EZK@1GK6l0G75d05icMP1FJfh0G75d06^0P`0205ebM@0;06YoPP1TNGd0H7Ej
0766R@1YOH00Kh:606j0PP1YNg`0KGmo0761P01cPh400P1cPh00801gQXD0O8Z;075oP01oSHl0Pi6D
08ZHV`23TID0R9FK08ZGW@28UI`0QY>K08ZGW`2=V:00RY>J08^DV`2?V9l0TY^R09FNY@2GX:L0TibS
09FNY@2FWjH0RiBK0;S1a`2ka<T0V::T09FOX@2LYZP0U9jP09FOX@2FX:80RYBF0P23SHl0;@2AVid0
T9ZL096IV`2BVY`0UIfO09BNW`2BW9d0T9ZK09:NWP2AWId0S9ZJ08^IV@2AWil0X:j_09:PX`2@WJ<0
RiRN08FCUP23TI@0PY2C07j<S@1mRh`0O8Z;07j<S01oSHd0O8^807F6OP1bQ7T0Gg5U065cI`1PLVD0
?e530312<P0cAC@0>Tdj03Q;=`0mD3`0DFIC08>GR`1WO7<0CV=J04YOEP1>HeX0DFIM05EZH@0305AY
H00/051UG01;H5L0B5mG04=IDP0lDDP0>da203Q9?P0hB3d0>DTo0392>@0/?cT0:chj02Xo?@0_@d@0
<45102hn?@0dA4<0<40o02Ph=@0Z>SL0:c/h03]<AP1KK6H0?Tm901h_:@0/?3T0;3`l0310@00[>cP0
9CH`02dl=@0S<bT07b`S02Tf;@0W=2/0:C@^01lZ9P0R;BT08BXU02H_:P0X<B`09BhY01lX8`0L9B02
020Y900501lX8`0M9R407bPS020Y900M8al00P0N9200100L8Qh08BLS02H/:00K8Ad201TO6`0B01<I
5@0N92009RdY01PQ700G81/0624L01TR7@0H8A`07BHQ01hW8P0G81/072DP01@M600C71L0;S@a01dQ
800G6aX061`K0P0M8B00300I7A`051PG02<W9P0=3`h05ATH01`P7`0E6QT03Q@B018H5P0I7Q`061`K
01HJ6@805ALF00@05QHF01LE5P0F51D0518C0P0C4a4301@D4P0401DE4`0B4Q004a<A018B40803`l=
01l051@B018B400>3P`06ATG01@D4P0B4Q005aHD01PG5@0?3P`03@T801@@3`0G4a806QDE00`81`0?
3P`04Q4?010?3@0A40h040l=0040000D4a406APF00T81P0N7A/02PT700l;300M6AX061@E014=3P0?
2``02`L800H04@d>0P0B3Pd2014=308040`;00h02@D400l;2P0F4Q404`l>00l;2P0D40l07ALG00P3
0`0400002`D501@>3P0L5QH040X:014;2`804P`<00X04@/;010:2P0B3Pd0510?01TE500?2`X06aLF
00h:2@0@30/03`/:100>2PT300l:1`09010;200A30T04@`9018=2P0A30T07QTF034/:@0D3``03PT6
00804Pd:00P040/800h91P0>2@H040/801@?300>2@H04`h;00/60`<03@P50P0@2`P200h91P0=01@?
30050000100000`71@0>2@H04`h;01TD4@0C3P/03@P500X50P0<1`@03@P500l:1`02010;200E00l:
1`0>2@H03PT6010;200;1P<02PD2014<2@0<1`@02PD2018=2P0H4a004Pd:00H1000B3@X05A0=00l:
200;1@D030H600l92@0=1`L03PP8008040X:010050h>01<=3@0>20P03`T9014;3@0400005@lA01XD
5P0F41804@/=00`6200A2`d02`D700H00P0<1PP02`D70P0=1`T0200?2@/03PP:00/51`0B30h03PP:
00l92`0B30h01P020P0=1`T01P0>20X05a4C00P2100C3@l04P`>00l92`<03@L90`0<1PP601052@06
00L0000C20`01`0000h31`0X7B405``@5?ooool001_ooooo00`04A0F01<B600D4aP04a8G01DD600H
61X04Q8D00h>3`0<30`03`l?014A4@0>3Ph600l?4@0300h>400?3a403`lA00<04A4C00T040lE01TH
7@0O7R<03@`A00h>400A4A<0410B00l?3`0>3Ph00P0?3`l02`0@41001`X900T=300<40l030h=00T9
1`0W9bD04a<A014@300?3PX03Pd900803`h900<03@`8014@300B4@d00P0A40`00`0B4@d030/7010?
2`07014@308040l;00@051<?01LF4P0C4Ph03`h:0P0C4Ph0100A4@`04A8=010A300@4@`200l@2`07
018C3P082@@01@H1010A300=3PT03a0;01DF4@02010A300700l@2`0@4@`04A8=00l@2`0=3PT03Pl:
00l@2`0200h?2P0@014B300E5Q004Q<=00d>200>3`T05QLA01DF400;30H04A8<01TJ500?40X0414;
018C2`0@4@T04a@<01@E3`804A8<00l051D@01<D3`0@40h03`l=00h>300820H07QdK04Q7A@0?40h0
71hK010E4@0A5a<061hJ010F4P0:3`/00P0=3@/02@0B4@l03@d;010@3P2j^[P0:RXX010@3P0>3P`0
3`l=01@D4P02014A3`0M01@D4P0?3`d05QHD014A3`0=3@/04A4?02PX9P0T92804A4?018B400?3`d0
4A4?01@D4P0?3`d03a4>01PJ5`0S9B80828O01LI5P0J71T03a4>00/=2P1ZK6T0:2XW00d?300B5140
61XE01@F4@0?4@`00P0=3`X00`0>40/0418=018D3`02010B3@0;018D3`0D5Q403Ph<018B400K6aT0
5ADC01<C4@0c<c404Q8@014A3`0@40h00P0A4@l0100B4Q004Q<>014B3@0B4`h201<D3`03018C3P0C
50l04A8=00804A8=00<04Q<>01<D3`0A4Pd00P0E5Q402P0D5A004a@?01@E400@4@`051D@014B3@0F
5a805AHA01@F400F6A0201<F3@03038e;00a=2/05aXA00804QD<0P0C5Pd301@G3P0G01DH3`0G6Q40
5aXA01DH3`0D5`h0:RdT01`O5P0B5@`071lF00lB2@0C5a004QLA01@I5@0D6A@04QLC01<H500E6QH0
4aPD01@I5@0G71T041DA01DI5`0E71D00P0F7AH03`0F71P05QdF01DL5@0B61@05A/G01@J5P0C6AD0
5adI01PN700R:2P06b0S01<H6`0F71`06R0P01TO7@0201`R800601HL600;4P/05QdF01TP6@0E7QT0
624L0P0I8Qd01`0L9B00624L01dV8@0I8Qd072DP01lX8`0K91l00P0J8ah0600M9R4072DP01TT7P0J
9Al07BPR01l/9@0P;BH08BhW020_:00Q<2T0834Y01d^9P0R=Rh093La028e;`0U>3<0;D0l02Hi=@0W
>SL0:3/i02Tl>P0/?cd0;T4o02Tm?080:3`k00D0:Cdl02a0?`0_@d80;d=203A8A`0203a@C`0Q03I:
B@0dB4L0<dM803Y>CP0_@d80=4Q604EJE@1GK6L0=d]903A8A`0jCTl0AEQM04AGGP0jCE<0?UA@04=I
EP0jD4d0@5ID04EKF@1;H640CV=U05=XJ`1BIf`0EFU`04EIH01?I6T0C61P051TH`1?Hf80CF5P04iR
H@1AIF@0EFUX0080FFe/00H0EFUX05=WIP1DJ6L0Efa_05EZK@1KL7<205mdM`0@05icMP1IKW40FFia
05ebM@1XOH00LhR;0725R@1/PHH0VJja07:6RP1^PHD0MHN906j0P@1/OWh0Kgmn07:2P@80Lh>001`0
M8>307R6Q`1dPX<0NXR:08:@T`29UiX0QI>G08FBV02:Uid0SY^R08^HX02:Uil0SYRP08nHW`2@VJ00
TY^R09FNY@2FWjH0VJ:Y09>LX`2BVj80UIjU08nHW`2ka<X0^<7609^UY`2DWZ00UZ2R0P2CWIl05P2B
W9h0T9ZL09>MW`2DWZ00UInQ08jHVP2CVid0UIfO09RPXP2GXJ80U9jO092JV`2DX:00TinO08^IV@27
UID0TInO0:Vg]`2DXZD0TIjT08^HWP25TiH208BBU@0I07j<S@1mRh`0OH^<082>SP22T900P8n<07N8
P01]Og@0HG=W069dJ01GJE`0=dTk0394=00jC3/0@EA103e@?@11E400DfQG06AhK@1KL6L0CfAK04YO
EP19GUD0BUmF05EZH@0305I[HP10055VG@1:GeH0@eY@03eCBP0hCT80>T]103e=@`0nCT<0>TY003M7
@@0cAT80<DA202a0@00[?d009CHf02Hf=@0c@d80<40o02Lg=00^?S/08C4^02m0>P12Ddd0;d0j01l`
:P0[>cP0:3Ph02hn?P0[>cP09CH`02dl=@0T=2X082dT02@a:00O;2<092lY024/:00N:BD08BXU01dV
8@0K91l072DP01hW8P0O:2<07RLR01`U800K91l06R<N01`U800M9R408RPT024W8`0M8al06R0L01`R
7P0R:2@06R0L01PN6P0M8al05A/G01lU8@0V;BT0624L01HO6P805b0K00@05AhI01PQ700K91l05QlJ
0P0J8ah04`0L9B00KgAa059FE@0L81l05QXI018F5@0M8B0041@C01<G5P072`X06alN01DI600G6aX0
5a`K01hT8P0@5Q@09R/Y01@H5`0@51<00P0D5QD0100E5AD05Q@E01HD5@0E4a@601@D4P03018B400C
4a404a<A0080410>00T051@B010@3P0B4Q009BDS01dM6`0D51804A0>01@C4@0A40h00P0C3`h0700@
30/04Pd=018>3@0D4a404Q4?00h=2`0C4Q004Q4?01@C4@0F5A<010<102DT8P0R8Al0>cXh02<O7P0:
1PH04Ph=01hJ6`0C3`l040`;018>3`0B3Ph04Ph=018>3`0B3Ph04Ph=00l;2P0@30/2014=30804`l>
00`040`;01TE500D40l03@T8010<2`0G4a80T8Z:03hh>00A2`/04`d=010:2P0>20P6014;2`08018>
3@0>2PT03`/:00@0000G4a803`/:014=300?2`X200d920803`/:00d04@`900h91P0=20D03`X7010;
200A30T04Pd:00T40@0M61D0?3Ld00h91P0:1@803`X7008040/801T03`X7018=2P0D3``0;RTV00T4
0@0@2`P03`X701<>2`0<1`@03PT600l:1`0D3``05A0=018=2P091@<03`X702HQ7P1YI640?cXg00P3
000E40d05Q4>010;200=20D03`X700@040/801803`X700h91P0>2@H03`X700T40@0<1`@05A0=00d8
1@0B3@X0@Sdj03<^:`0@2`P06A@A01@?300<1`@04P`;010:2P0?2@T2010:2P0I00h8200<1PH03@L7
00h8200<1PH02P@400/51@0B30h01@0100L20`070@<01P0201<=3`090`D04P`>00d72@080P@04P`>
00l92`0<1PP03PP:010:300>20X030H800l92`0200d72@0:018<3P090`D03PP:00h82P0400004@/=
00X41P0F4180100001H@4P8030H8100;1@L601052@0601872`0C2P`05``@00X00`14>Cd01`005?oo
ool001_ooooo00d02`X@010?5@0C4QL04A0E00h=4@0<30h02`/=00h>3`0A4A40410@00d=3@0?3`l0
410B00803`lA0P0@4180100?3a403@d?00d=3`0>3Q0300l?4@09014@5P0@3a@02`X?00`;400F5QP0
20P:010@4P0?3`l03Ph>00803`l?00/0410@010B4@0>40l030h=010B4@0?3`d0;bl]018A3`0@3`/0
3`h:010<2@02010=2004014@300E51005QDA01<B3P<04Q4=0`0A40`201@C3`0<014@300B4@d051<?
01<B3P0B4@d05aHB01/J5P0F5A404A0<01<B3P0B4@d03`l:0`0?40/01P0>3`X03@h900T:1@0A4Pd0
61TD010A30804A8=1P0?40/3010A30803a0;0P0=3PT0800?40X04A8<010A2`0@4@/05AH@01hO6@0A
4P`04a@>024R700J6aD04Q<=014B2P0>3`L04A8:01<D3P0?40X0414;01HG4P0A4Pd03`l=010@3P0A
4@l05QHD018A3`0Y:2H08R<Q00/=2P0D6AD08bTU028X900A5a<02a0<0P0J6QP01P0A40h05QHD01<C
4@1ZJVP0@40n01XJ60803Ph<00`04Q8@010@3P0@40h04Q8@00h>300=3@/03Ph<01TI5`0=3@/0@D4o
01`L6P0=3@/2010@3P0I01@D4P0J6QP05aLE024S800J71T05ALD01@F4`0A4a003@l<01@F4`0B5140
418?00d?300C5A803Q0=00lA300A4`h04Q@?014C3P0?4@`03@l:018D3`0@4Pd04Q@?01<E4002018D
3`0901PH5P0B4Q005QHD01DE4`0C4a40410>018B400A4@l0410>00804A4?00<04Q8@014B3@0B4`h0
0P0B4`h01@0C50l05AHA01<D3`0C50l04Q<>00<04a@?00L04A8=01@E400D5A004a@?01@E400F5a80
4a@?00805aPC00H05AHA00d>2@0A4`d03a8;00hA2P0@4``2014D3@03018E3P0C5Pl04aH?00@051L@
01P04aH?01@G400E61405APA01@G400H6a@0;S4Z020S700D5a006ahG01<F3`0G6QH04aPE01@H5`0C
5aD04QLD01@I5@0E6QH04AHA01<H4`0F6aH06AhH01HK5P0D6QL301DK6@0401DK600E6aL04aTE01HL
608051/D00D061lH01PN6P0J82006R0Q01PN7P0201<I6@0>01TO7@0G7A/051XH01/Q7@0C6AD07R@P
01LN600G81/07RLR01dV8@0E7QT0624L020Y900O:2<201dV8@05020Y900O:2<07RLR01/T7`0K9B00
0P0N:B<0100L:2807R/T020]9P0O;BH201l^9`08024`:@0Q<RX072hX024d;P0R=Bl08C@^02Hi=00^
@Cd202Hi=`0402Lj>00X>SX0:S`l02/m?@80;40o00H0:cln02a0?`0`A4<0<dM603A8A`0bATD203E9
B00K03M;BP14F5L0Cf=T03M;B`0iCD`0?E9=0356@@0kD4/0>Di904MKFP0oDe<0@EAH04EHG`19G6<0
@EIJ04=HF`0kD5<0AeaO04]PH`1>HfH0D6EX04eRI@16Feh0CV=W04QMHP1=HVD0C61P0080D6AS00@0
DFET05AXI`1GJfX0DFET0P1FJVT205AXI`0W05M[JP1LLG@0F6e`05mdM`1RMgX0H7Eh069gNP1YOX40
LXN:08ZOXP1_Q8L0GgAg06n3QP1WNWh0QiZN06n2Q@1_Ph@0LXB606n0P@1bPX80M8B407N6QP1iQhL0
NXR807f9RP26TI<0T9^M08B?TP2;UYX0SYVM09bW[02DWjD0RiJL09:LY02BW:D0TI^T09FNYP2GWZH0
V9nW00<0VJ2X00L0UijV09bSZ`2KXZX0XZVa09nV[P2DVj80VJ2V0080UinR01P0TIVL09fUZ02NYZT0
UinR09:JW@2EWJ00Vj>V08jFV@2JXZD0UIfO09JNX02IXJ<0V::S09JPX@2BW9d0SYZJ096MW@2BX:00
SI^K08^IV@2?WId0T9jQ08jKX@2:V9/208JDU`0808JDU@25Ti@0PY2A07n=S@1nS8`0NhV907R7Q01e
QW`206MiK@0?05i`I013EDP0?e5304AFAP11Dd<0@EA204=EA01:GD/0DVMG04mSF01HKF@0FFiU05=X
G`1AIUd0EfaS00@0DVMN02L0CV=J04QME015GE40?EA703Q=@@0lCd<0@556041@A`0b@CX0>d]703iA
D00nD5<0=DU=02Xm@@0T=CH0:SXi03E5A00`@3l0:3Pe02dm>P0[>cP0<T<m02`m=`0]?SP0:c`f02De
<P0R<S80:3Ph02Xj=`0T=2l0:STb02@d:P0R;bH08c0W034n=@0]>3808B`X01TT800Q:RD01@0P:B@0
100L9B006B8M01TR7@0K91l201`U800302<Y9@0Q9b<0728N00806b4M00@07bDQ01`R7P0I7a/082HR
0P0K8Ad00`0M8al061hJ01LM6@0201PN6P0501LM6@0F71P08bTU01dS7`0D6QH00P0L8Qh04P0e>SL0
82@S01@H5`0L81l06AdL01dQ800H71/06QhM01@H5`0L81l051PG06]_KP0O92<03aDC01DI600I7A`0
Bdm>05IHE`805QPG100E5AD201DE4`@051@B00D05QHD01@D4P0C4a405ADC01HF500201@D4P0?014A
3`0N7Q`05QHD010@3P0E51804A0>01<B400G4a80510?01HB4@0[9RD06QHE01DD4P0A40h040l=0080
4A0>00`051<A00h=2`0C4Q00=C@b03hm>`0M71X04Ph<01DA3`0:1P<03PX901@A3P0E4@h201<?3@04
01<?300C3`d04`l=01<?3@<04Ph=0`0A3@`02P0>2PT04Ph=00l;2P0?2`X0510?01<?3P0]9bL04`d=
018<300G4A42014;2`03018<300A2`/04@/;00804@/;00T04P`<018>3@0<20L040`;01<?3P0g<c80
=S8a018>3@0@30/00`0?2`X00`0@30/04@`900l:1`0200h91P803`X700H04@`900/60`0;1P<05A0=
00L2000I5142014<2@08010;200?2PL040/8018=2P0O6QL02PD2014<2@0>2@H201<>2`0@014<2@0>
2@H05Q4>01`G500E40d040/801D@3@0C3P/07aXH01LB3`0>2@P04Pd:010;200?2PL040/8014<2@@0
40/800D03`X700h91P0>2@H03PT600d81@02014<2@0?00L20@0D3``0J6=P05]FD`0E40h02`H400h9
1P0;1P<040/9010:2P0?2@T040X:01<=3@0@2PX03@L7008040X:00X030H600d71`0>20P04@/=00h8
2P0H4Q@050h@00/51`0A2`d01`830`0?2@/201TC5@0300d72@0?2@/03`T;00803PP:00d030H8010:
300=1`T04P`>00P2100:10H02`D700d82@0910D06aHG04@n@00A30d081XL00<03PP:0`0?2@/60105
2@0600`31@0F30l0DTM;01/B500C2@`03PD75?ooool001_ooooo00d03@`B014@5P0B4AH04A0E010@
4`0A4A<03@d?010@4@0G5aL05ADE01<C4`0K6a/04A4C00803Ph@0P0@41800`0=3@l03`lA00l?4@02
00l?4@803Ph@00T03@`B00d<4@0>3A803PdB018B500820X0410B00l?3`0>3Ph00P0?3`l02`0@4100
51HE014C4P072@P01@D500T81P0J6AL03Pd;010<2@0A3@X040`900803``700@04A0<01DD400F5A40
4Q4=0P0>3@T0100=30P03Pd900h=2@0<2`L300h=2@0<010?2`0B4@d04A0<010?2`0B4@d05A@@01<B
3P0@3`/04Q4=010?2`0>3PX0414<0P0?40/200h?2P07010A300?40/02``700/<1`0C50l04A8=00d>
2@0300h?2P0900`=200;30L03@h900l@2`0>3`X03a0;014B3@0C50l04A8<00802``600H03Pl9010A
2`0@4@/04A8<00h?2@0=3PP2014B300500/<1P0A4PX03a08018C2`0C50h00P0@4@/06P0F5a804A8=
00l?3@0=3@/02PX800l?3@0G5Q@01PD301DF500:30T04AHB00lE4@0A5a<0318>00dB3P0;2`T010@2
018A3`0=3@/02`/901<C4@1iNGL092@R00D50`0>3P`04a<A0P0@40h02@0C4a403Ph<01<C4@0B4Q00
410>01<C4@0J6QP0000000/;2@0200h>3006018B400I6AL05ADC01TK600A4a002`d:0P0<3P/02@07
2@H04Q@A00X<2@0P8Ql04Q@A00lA3P0E5a@04aDB01@F4`0301DG500@01<E4P0>40d03a4>00lA3P0:
30T04Q@A01lQ7P0N7Q`03Ph<028R800C4a40820N01LG5@0B4Q004A4?010@3P804A4?00P04Q8@00l@
2`0C50l04a@?014B3@0D5A005QLB018C3P<051D@00<04Q<>014B3@0@4@`00`0A4Pd0100C50l05AHA
01<D3`0C50l201TJ5@08018C3P0D5Q0030l800hA2P0E61404A@=01@G400H6a@201<F3`8051L@00<0
5APA01<F3`0A50d00P0A50d00`0B5@h04aH?01HI4P0201/N5`0401PK500F6A8061/D01LJ5`804aLH
02P04QHG018F5@0D6AD05AXE010E3`0F6aD05Q/D020V700K81X05A/K01DJ7@0D6Q/051XJ01HL6P0I
7ad05A/G01PN6P0G7QL05QdE01XQ6@0K8QX04ALE01<I6@0G7A`061hL01XP7P0N92809B/Y010F500K
8Al06AlM018H500f?3P04a`G01XS7P0I8Qd04Q/F01@M600K91l06B8M0P0J8ah02P0I8Qd06R<N01`U
800L9b<06RDQ024/:00R;RX07b/W024]:@0N;BP201d/9`0501`]9`0O<2X08C8/02<f<00R=C000P0Q
=300100U>3D0:3/i02Pk>@0W>CP202Hh>00e02Li>@0X>SX0;D5002i2@@0_@d80<4A30396A@0dB4L0
>Ti=0396A@0eBDP0=4Q703Y>C@1@I6<0Nhf=041BDP0hBdT0<dI202Xm=`17FU@0>Te904IHF00lCTh0
BUaP04AEG011E5/0BEeV04EIHP18G6D0F6ac04iRJ@1;H6D0DFI[051UJ01BIfX0C65S04]PH`16Fe`0
CF5P04YNG@1<H5l0DFET05IZJ@1GJfX0DVIU05=WIP1DJ6L0EVYY05U]K01KKfh0HGAh05Q[K`1PLgL0
0P1RMGT0401PLgL0Jgj208bOX`2U^;`0M8N;05a_L`1WNWd0M8R906MkO01hRhd0OHnA07^;R`1hR8P0
NXZ:07f;S020SXl208:@T@0@08RDUP2BWIl0Xjj`092KWP2JYJT0UJ2T0:>^/`2IY:X0T9^Q09FPY`2D
WZL0UZ2Y09ZSZ`2JXJT0W:>[09jU[@80WJB/0180W:>[0:B[/`2IX:P0WZF]0:B[/`2SZ[40WjJ/09bT
Y`2OYjX0UIfP09RPX`2IXJ@0UinR09JNX@2maLP0g^KY0:fe^02DW9l209FMW`0U09NOX@2FX:40UZ2Q
09FOX02Q[Jd0W:RX08nMW@28UYH0RING08nMW@2<VYd0RiVL08VGVP27UIH0QI>D08BBT`2;VIT0R9JF
08>AT@1oSX/0NXV607F4O`1aPWP0JG]_069dJ01DIUX0@E=604AFB016F4X0@59403mA@`17FD/0E6IG
05EYG@1LL6L0Fg1Y05M/I@0205AYHP0]05Q]IP1JKfP0EfaU05AYHP1BIf00CV=L04UNE@1:H5<0@EM7
03Y?@00kCd<0?4m403U:@P0cA3h0@E5?04=EE`12E5P0>4]B02Tl@P0Y>S/0;cln0310?`0]?C`0;Cdj
02hn>`0W=c@0;Chh028c;@0U=S008C8/01XZ9`0V=SH0:SXj02dm>P0U=C009cH_02<c:@0U<RT08BhU
069_IP15D4X05R4M02<^:P0J8ah07RLR008082TT00D06b@O01PQ700J8ah06B8M01/T7`0201lX8`07
01`U800M8al07B<O01XP700O9B407R@P01XP700201dS7`805adI02805Q`H01<I5@0C6AD04QPD01<I
5@0E6aL051XF01PN6P0U:bL082HR01/Q7@0J81`05Q`H01hS8@0S9bH07R8Q00hB4@0C5aH07B4P01<G
5P0_<c8092PW01LK6P0K7ah0:bl^00hB4@0I7A`06QhM01dP7`2[[J`0Wj6P01PJ6@0G6AP051HE0P0B
51<01@0C5A@05ADC01DE4`0E5A<051@B00804a<A00T04Q8@01<C4@0E5A<04a<A018B400D51805QHD
00d=2`0B4Q000P0>3P`06@0D4a407QdK01TH5P0E4A0040`;00h:2@0H4a806ADD00h=2`0F5A<07QdK
01@C4@0B4@l030/901XI5`0A40h01PD301dL6P0A40h03`/800l<2P0P7AP0924L00P50P0300001@0C
40/0400C3``0510?01@@3`0B3Pd040`;00l;2P0>2PT05Q8A018>3@0C3`h0510?00l;2P0;1`H02P@4
018<300C3@d200h8200301@>3P0B30`04@/;008040X:0P0B30`01`060`803@T801TE500C3`h06ADD
00L30P0@30/00P0A3@`00`0@30/03`/:00h:2@0400l:1`0800d81@0<1`@03`X700`7100?2PL06QDB
00h91P040002018=2P0:010;200>2@H03PT6010;200810803`X700h91P0=20D02`H3014<2@8030L4
0P0=20D0300<1`@03PT600T40@0A30T03`X901@?300M61D02`H300d81@0<1`@03PT600l:1`803PT6
0P0@2`P02P0?2PL03PT600h91P0=20D03`X7014<2@0<1`@020<000`7100C3P/201/F4`0400l:1`0<
1`@04@`900l:20803@L700l03PP8018<300=1`L02@<300l92@0>20P02P@400`61P0;1@D07QPH01<=
3@0H4Q803@L700X4100A2`/00P0?2@T05@0>20P02`D500T30`070@403@L9010:300=1`T02`D700l9
2`0=1`T04P`>00d72@0A2`d02@<500X41P0?2@/06Q@F00P2100:10H06aDG00T31@0300X41P802`D7
0P0<1PP601052@0600X00`0A20X0?34e00/01008004091TM5?ooool001_ooooo00d02`X@00d<4@0=
314030/@00l>4P0C4aD03`lA00d=3P0B4Q804A4A00l?3`0G5aL04A4C00803Ph@0P0@41800`0=3@l0
4Q8D014A4`02010@4P0;00l?4@0>3Q003`hD00`;400D4aP030/@010@4P0E5AL0410B00l?3`0>3Ph0
0P0?3`l01@0@410020X901HH5`0B51<03`l?00802`X800X03`h<01<?300D40d0510=018?2P0A3PT0
30/7018A3@0D4`l04Q4=0P0@3`/02P0?3PX04a8>01<B3P0@3`/03Pd900d<200<2`L03Pd9014@300@
3`/200h=2@06010?2`0?3PX03Pd9018A3@0@3`/03Ph:0P0A4Pd02P0@4@`03a0;00l@2`0A4Pd030d8
00d>2@0C50l030d800h?2P0C50l2014B3@03010A300>3`X03@h900<03@h900L03a0;01<D3`0G61<0
5aPB00l@2P0;30H03Pl900804A8<00@03@h801<D3P0C50h03@h80P0?40X05@0C50`0414901<D300D
5@l04A8<018C3@0A4Pd03Pl:010@3P0A4@l03@d;014A3`081`D07A`J00`=2`0G6AH000D100hD401B
F5@0:c4]00T>2P0201HF500900/:20092@L07alM00`<2P0B4Q0020P701LG5@0@40h051@B00804A4?
01h051@B010@3P0G5aD04Q8@00D50`0S8b404a<A01LG5@0@40h04A4?00h>300?3`d04Q8@00d=2`0:
30T030h;00h@3@0A4a0051HC014C400;3@X05ALD0001000C5A8051HC00`>2`0A4a00418?00h@3@0=
3``300lA3P0>01HH5@0E5a@03Q0=024S800h>SL0RXZ80000000J6QP03@d;014A3`0<30X04Q8@014A
3`0@40h2014A3`0O018B400?40/04a@?01<D3`0A4Pd051D@01HG4P0A4Pd051D@01HG4P0E5Q404Q<>
010A300?40/04A8=010A300A4Pd04a@?01DF4@0C50l03Pl:014B3@0@4@`02``701DG4@0F6A8051L@
018E3P0@4``03a8;014D3@0201<F3`0M01@G400E61405APA01DH4@0C5Pl04QD>014D3@0C5Pl05APA
01@G400=40T05APA01LJ4`0>4@X04A@=014D4P0C5aX04aLH018F5`0B5QD051PG01LL5`0E6Q@06QlH
018G3`0H7Q@03Q@=01LM7@0F6al00P0E6Qd02P0H7Qh06b4P01LM6`0J81`06B0J01PO600M91`07B@M
01hT8P0L8R0201XP7P0901TO7@0E6aT06b4O010F500J81h09R`Z03Y0?P2?UI805QlJ00806b@O00@0
6B8M01`U800K91l06R<N0P0M9R402@0K91l07BHQ020Y900K9R8062<O020[9`0Q;BT07RXV020/:002
01d/9`0<01`[9P0L;BL07RlY024b;00T=c408C@_020c;`0S=S809cXg02Pk>@0/?cd0:cdl0P0Y>c/2
02Xl?00402/o?P0/@3l0;T9102m3@P80<DE401l0<dM60355A00iCD`0=TY90396A@11EE@0@eEE03E8
AP0fBDD0?4m;03]>B01:GEL0AUUE03a?C@0lCTh0JG]n05EVK@0kCUD0@eIP04EII01:GVT0E6Qa055U
K01JKWD0C65V051UJ01HKG00CF9S05EZJ`1>Hf@0DfMV0080C61O00L0DVIU05AXI`1DJ6L0Ffm^05Q/
J`1GJfX0FFe/0080Ffm^02L0H7=g05IYK@1NLGD0HGAh06=fNP1/Oh<0GW5e06EhO01/Oh<0IWUm06j1
Q@1[OX40P9BE06EiNP1lSi00M8J807J6QP1mSHd0Nh^;07j<S@21Si00Pi6B08BBT`23Si40Q8nA09NR
Y027TYD0Uj:V08fHW02EX:D0T9^Q09:MX`2MZ:l0Uj6Z09JPZ@2KXj/0VZ6Y09bSZ`2OYZh00P2PYjl0
6P2KXZX0XJR`09nV[P2OYZh0VZ6Y09bSZP2RZJl0UIfP09^SYP2JXZD0UinR09bTY`2h`<<0WZJY0:J^
/@36c]40W:BW09RPX`2DW9h0UIfO09JNX02EWj00UZ2Q09NQXP2BWYh0TIfM0P2AWil05@2@WYh0RiVI
08^IVP2;VI`0RYRK08NEUP24TY<0PHn@08:@T020SXh0OH^;07b;R01iR8D0MHAo06n0MP1^P7@0G6iR
04mQE@17FD`0A5I804EGB@02049DAP0T04YLCP1GJE/0F6aP06=gKP1KL6T0EfaU05Q]IP1EJV<0CfAM
05Y_J01EJV<0D6EN04eRF`18GEH0@eQ?04QOC`10EDD0>Tm003a@A00kCdD0=TU303e=BP16F5P0A5IJ
041AF00fAdl09CHm02Pg>@0/?3/09cLf02Xj>@0a@Ch0<T8o02lo?00b@cd0;3dg0P0[?3H03P0a@Ch0
;3`l02lo?`0a@Ch09SHa02Lf;`0R<RP0:SL^01dZ8@0T<BP09C0Z02Xe<@0I92007RLR0P0L9B000`0M
9R407RLR01lX8`0201LP6`0c01XS7P0P:B@07RLR01/T7`0M8al07R@P01XP700O9B407R@P01XP700W
;BT0:S0/01/Q7@0L8Qh07bDQ01/Q7@0I7a/061hJ01XP700M8al0728N01PN6P0E6aL051XF01hT800G
7AT051XF01lT8@0F6QT051PG02<W9P0J7Qd03Q8A01HJ6@0;3`h04QHE01TM700g>cX0;C4`01`P7`0M
8B001PX901dP7`0[;B`0>C/j01TK6P0H6QT051HE018D4`0A4a804Q@C00<05ADC02L051@B01<C4@0C
4a403@d;01<C4@0G5aD0410>00d=2`0D51805ADC00h>300I6AL05QHD014A3`0;2PP04a8@00h=2`0D
40l06aLF01LC4P0A30`05a<B00X91`0L6aT0:RTW01TH5P0E51803@`:01@C4@0@3`d04a8@00P71P0B
4@d040`901/H4`050P001P<001DB3@0F4`h01P0C40/6014=300301@@3`0:1PD030P700803PX902H0
5A4@01@>3P0A2`/02`D500l92@0C3@d02@<301<=3@0A2`/03`T9010:2P0B30`04`d=01@@3`0<20L0
40`;00`81`0I5A@02`L6010<2`0A3@`04Ph=014=300>2PT03@T800h91P0?2PL040/800l:1`0<1`@0
2`H300d81@0E40d03@P500P30P0D3``03@P500l:1`8040/801H03`X7018=2P0D3``050l<00h91P05
00004Pd:00T40@0>2@H04Pd:01@?300>2@H02@@100d81@0U81d04Pd:00T40@0D3``02@@100d81@0B
3@X040/80P0>2@H300l:1`8040/801@03`X700h91P0>2@H030L400h91P0?2PL03@P5010;200=20D0
30L500/60`060@003PT601@?300@2`P03@L6018<300?2@T03PP8014;2`802P@40P0A2`/07`0=1`L0
3`T900`61P0A2`/01000014;2`0>20P04@/;00l92@0=1`L02P@400l92@0B30`03`T9018<300=1`T0
40X<00`6200:10H040X<00h82P0B30h02`D7018<3P0=1`T040X<01PB500;1@L03`T;01@>40060080
0P0?2@/200d72@803PP:00<03`T;010:300@1@T01P0@1@T01@0B1`/03`@801462P0G31001`0001Co
oooo000Kooooo`0800h=4`0@3aD04a8G01<B5`0@41<03Ph@010@4P0@4144010@400600l?4@0A4A<0
3@d?00`<3P0@41804A4C1P0?3a40200=31803@`A00X93P0=31403`lA00d=3`0>3Q003`l?100>3Ph0
1`0?3`l04A4A00l?3`0@3Pl03`h<00d<2P0B3Pd00P0?2`P0100C3P/04Pd9014=2@0@3PX500l>2P04
01<B3P0?3PX03Pd900l>2P804Q4=0`0?3PX01@0@3`/04A0<010?2`0>3@T040l;00804Q4=00P040l;
00`<200I6QD020T4014B3@0=3PT0:R/V014B3@804Q<>01P02``700h?2P0J6aH06Q/F00l@2`0A4Pd0
4Q<>010A300>3`X03a0;00T:1@0<3@P03Pl;01HG4P0R8ah06Q/F018C3@0?40X04A8<018C3@0A4P`0
51D?018C3@0A4P`2018C3@04010A2`0B4`/04A8:014B2P80414;03803a0:00`=200D5A0051@B02/[
:@0C4a403Ph<014@3P0D4a404Q<A010B3`0?51003A<?01XP700=4`l02a0<01DE4`0A4@l040l>01@D
4P0A4@l03`l=010@3P0B4Q004A4?00h>300A4@l03Ph<00l?3@0B4Q003`l=00d=2`0C4a403`l=02LW
9@0D51802PX800d=2`0?3`d02`/901@D4P0L71X03@d;00/=2P0D5Q<03Q0=01<E4P0?4@h04Q@A00h@
3@803@l<02P03a4>00d?300A4a002@/8014C400:30T061XG01DF500G6AH03a4>00`>2`0?4@h04A<@
01<E4P0G6AH0;Rh/010@3P0A4@l04Q8@00h>300D51804a<A01@D4P0B4Q0051@B00h>300G5aD03a0;
03ho>P0[;2L03Pl:00/<1`0D5A004a@?00h?2P0E5Q4061TD01HG4P0C50l04Q<>0P0A4Pd01@0C50l0
51D@01DF4@0@4@`04A8=00<04Q<>00P04a@?018D3`0@4Pd0418=018D3`0D5Q405aTD00lA3@805ALB
02d02`d801hP6`0C5A003@l:01HH4`0B50l071hI010B3@0G6A@051HA018D3`0E5a805aTD01DG4P0E
61L0720R00hB4`0D61T05a/J01<G5@0G71L051TC01DJ4`0F71@04aT?01PM5P0B61P05Q/O01DJ7P0D
6A`05a`N01DK6P0G7A/0Ff5N02P^:P0B61<09bhW01LN5`0E6aL06b4N01hT8P0I7ad04aTG01/Q7`0L
8R000P0J81h01@0E6aT0:S0^02le=00C71P06R<N0080624L00H08BXU01hW8P0I8Qd06R<N01dV8@0N
9b8201lX8`0@01hY9@0K9b<07b/W01TU8@0Q;bX08c8]01d/9`0M;BP07RlY020a:`0Q<bd08SD_01lb
;P0R=C409CPd02Lj>080:Sdk0P0Z?3`09P0Y>c/0:3Xl02/m?`0_@D<0;40o02i2@@0bATD0=DU803A8
A`0bATD0>De<03Q<B`0oDe80@5AC03Y>C@0lD4l0=DQ603Q;B@0cAT80=dY403e@BP11E4h0>di904QK
F00nDE00LhF604MIG@12E5X0BUeY04iRK@1?Hfd0Cf=[055UK01CJ6h0CfAY051UJ01@IFL0CfAU0P1>
I682055UI00?04eQH01EJFP0DFET05]_KP1JKVd0FFe/05Q/J`1KKfh0Gg=b065eM01QM7P0Jgj2065d
N01/Oh<0JWf10080IgYn00P0JGb006f0Q01^PHD0KX650722Q01cQHD0MHN707V:RP80Nh^;0100NHR8
07R6Q`1jR8/0PHjA08RCU`2;UYX0SIRK08bFV02>V9X0TY^O092IWP2CW:40W:F[09^TZ`2HXJP0VZ>[
0P2LYJh0102OYJl0Y:Ra0:>W/02SYk020::V[`030:>W/02UZK80Y:Ra0080XZJ_00@0XJJ]09nTZP2O
Y:P0WjBX0`2NXjL01P2h_L40Y:V]09ZOX`2OY:P0Vj2T09VNXP80VJ6S00P0V:2R09RRX`2HXZ<0VJ>T
09BPX02CWil0T9jN08nMW@80SYbL0180SI^L08nMWP2>W9d0R9JG08FCU026U9@0PHn?082?S@20Sh`0
Ohj;07N6PP1^OGH0HgEY06anL01hRW`0IWQ/04EGB`18FTh204]MD@0l04eOD`1AHeL0FF]O05eaIP1L
L6P0GG9[05aaJP1KL6T0EV]T059WH01DJF80EFYS05=XH@1?I5d0BUmH04QLD`16FD`0@5=403U=@00c
Ac`0?E590396@`10De80B5YL04]MH@1BHfX0?DiE02hmA00U=3H09SHe02De=00W=cH0;Shk03A4@@0f
AT<0;3dg02/l=P0^?cT0:S/e02Hf<`0Z>SX0:c/k0310?@0Z>cD09SD^02/k<@0W=2/08c0W01`Y800P
:bD08bhZ028]:@0M9R406b@O01`U800P:B@07bPS01hW8P0I8Qd05b0K0P0M9R405`0I8Qd07bPS028X
900S:BD06b4M01XP700I7a/05A/G030f<P0nA4006b4M01TO6`0S:BD06QlK020U8@0K81`05a`H01HK
5`0J7a/082DQ01lT800M8Qh05a`H00806QlK00@06AhK01<G5P0E6AP07b<R0P0@51<0100H71/06AdL
01TM700E6AP201XN7@0301DH5`0F61L05QPG00@05QPG0P0E5aH01P0E6AP04aLF014D4`0C514051@B
01DE4`805aLE00H061PF01<C4@0I6AL04Q8@01dM6`0E5A<2018B400<00`<2P0A4@l0410>01/K6@0C
4Q005A@B00`;2@0J5QD0=c<b01DA400E41006ADD0P0@3`d04@0D4a404A0>014@3P0A40h08b8P020O
7@0Q81h040l=010?300B3P/06AHB01/H4`0/:B@04a0;00l<1`0D4@`04Pl:008040d800H04@h9018>
2P0D40l04`l>014=300@30/300l;2P0601DA400B3Pd040`;018>3@0?2`X040X:100A2`/7010:2P05
00l;2P0@30/03PX900`81`0>2PT00P0B3Pd2010<2`0400h:2@0?2`X04Ph=01@?30803PT601/02`H4
01TD4@0810804Pd:014<2@0@2`P03`X7010;200B3@X040/8018=2P0@2`P030L4018=2P0G4Pl040/9
00d81`0>2@H03PX701<>2`0;1PD040/8014<2P0A30T040/800d81P0>2@H00P0?2PL02P0@2`P03`X7
00l:1`0E40d04`h;014<2@0@2`P030L604Q3@00C3P/200l:1`0@00h91P0=20D03@P500l:1`0>2@H0
3@P500l:1`0@2`P03`X700d81@0>2@H03`X7010;200?2PL03PT600h91`803PP800X03@L700h8200?
2@T040X:00T30`0@2PX03PP8010:2P0A2`/03`T90P0>20P01`0=1`L03PP800l92@0F41004`d=00h8
200<1PH00P0>20P06P0b;2h0;RPZ00h92P0B30h040X<00d72@0<1PP02084014;3@0;1PL03PP:01<=
3`0?2P/04`d?00`7200:10H09b4S05A>D00@2P`030H800d72@0<1PP040X<014;3@0@1@T04@H:0P0C
20`01@0A1PX040D901882`0A1PX040D900803`@800<03P<7ooooooooool04_ooool001_ooooo0P0@
3aD2010?500>010@4`0@41803Ph@00l?400?3`l0410@014A4@0B4Q804A4C01<C5@0?3a40410B01<C
5@0>3Q0600l?4@0:010?5@0E51T03@`A00/:3`0?3a4030`>014A4`0@41003`l?00d=3@802`/;00d0
3`l?014?400B41404@l@014=300@30/03PX9018=2P0C3P/04@`901491P0@2`L040h:00D03`h:00<0
4A0<010?2`0?3PX00P0@3`/0200A40`03`h:00l>2P0?3PX040l;014@300@3`/03Pd90`0?3PX04P0@
3`/03Ph901HG4P0:2`H051D@01LH4`0d=C009BHQ02X[9P0X:B@061TD00X;1P0>3`X0414<00d>2@0>
3`X0414<00l@2`803Pl:00h04A8=00`=200=3PT03Pl:00X;1P0@4@`0414;00h?2@0?40X0414;00l@
2P0B4`d0414;00l@2P80414;00@03a0:00l@200?40P041490P0@4@/0600A4P`03Pl:00T:1@0?3`d0
6a/I010@3P0?3`d03@`:00`;2@0B4a404Q@A00X?2`0C6AD092XV02T_:`0C61@04a<A014A3`0@3`d0
4a<A014A3`0?3`d04A4?018B40804A4?01L051@B010@3P0@40h04a<A00l?3@0Y:BL07AdK01@D4P03
0`4030`:014A3`0<30X04Q8@010@3P0C4a405aLE00d=2`072@H03a4>00`>2`0A4a00418?00X<2@02
014C400D01@F4`0:30T06Q`I010B3`0I6aX05ALF00P:2@000@00A4I5034c<P0E5aH03@l>018D4`0A
4a803Q0?01<E500;2`T051@B01LG5@0E5A<201<C4@80410>00X03@d;010@3P0;2`T04Q8@010A300O
81/04A8=01@E400;30L051D@0P0C50l0100N7aX0;c0[01<D3`0A4Pd200l@2`06010A300C50l05QLB
01LH4`0@4@`04a@?0P0E5Q400`0C50l04aDA01<E4P02018D4@0?01<E4P0E5a@05ALD00`>2`0I6aP0
5ALD01HH5@0I6aP05QPE01DG500=3``04aDB018D4@0J71T05ALD008051HC01h04aDB018D4@0D5Q<0
>3/i08>7QP0c=cH061`K010D4`0E6QH051TE01HK5@0D6A<05Q/E01@I4P0E6QD03aDE01<H6`0D6A`0
5AXM01PM800H7Qh06AlO00X@3P0F71X03aDC01<I5@0K8Ad082HR00XA2P0G7AT2020V8P0T01LM6`0O
9B<07bDS01TO7`0J82005A/K01TO800M9R<08R/V01dV8@0H8A`07BHQ01/T7`0H8A`06B8M01/T7`0M
9R407RLR01hX8P0=61@0:CDc020/:P0L:bP06BPU024`;@0O;b`0830]01lb;P0P<bl08C@`028e<@0R
=C<093Le02Hi=`0W>SP0:3/j0P0X>SX0200]?d00;d5302do@@0Z?3l0:3Xl02e1@00aAD@0=DU80P0g
BdX0500fBTT0>Ti=03iBD@16FUT0AEUH03Y>C@0dB4L0>4]9045AC`0jBTL0@E9<03U:@P11DTX0@55;
04MGE00lC4/0@U5C03i=DP1>GfH0CV5Z0P1?Hf`0301=HFT0CV9Y051UJP1>HfL0C65T04aQHP1>I6<0
DFMU059XIP1AIF@0DfMV05AXI`<0Ef]Z00l0DfMV05IZJ@1IKF`0GW9a069fM@1SMgH0J7Yn06UkO`1V
N7`0O8jB07>5R@1YNgl0Jgf106eoP`1`PXH00P1bQ8P06@1eQhP0MhZ807Z:R@1jRXX0NHV907Z8R@1j
R8X0Ohf@08JAU@2:UIX0S9NM092IX02DWJ40TifO09FOX@2JXjL0VJ:W09bUZP2X/KL0Y:fd09VRZ@2L
YJd0Y:ff0:>/]@2SZK800P2VZK820:FX/@030:BW/02VZK80YjZc0080YjZc00L0YZVb0:JY/@2TYjh0
XjJ[0::UZP2PXjP0Wj:W0080WZ6V00/0VYfR09fPY@2LWj@0UYVN09^OX`2EWIl0UYjP09RPXP2GXJ80
UZ2Q09BNW`02096MW@@0SifM00@0SYbM08nMWP2=Vi`0R9JF0P26U9@0@P22THh0P8n<07j=R@1lRhH0
M8=n06YiLP1`PWH0H79T05U[G@1@HUH0AeU=05MYG@1=GU@0Cf1F059SF@1FIed0GFiU061dJ`1OLV`0
FFiY05M/I`1HKFP0EfaW059WHP1HKFP0EV]V055VH@1>Heh0Bf1K04YNE@1@HUH0?4i103Q<@@0fBT40
?U9>03iDDP12EeP0B5aO05i`M01TMWX0AUAI04EBF00V=SL09CDd02<c<P0W=cH0<40m03E5@P0[>cP0
:S/e02/l=P0]?SP0;Sli02lo?00]?Cd0;3`l02Lg=00U=C009cH_02Hf;00]>S4082dT049?AP0V<B/0
4ahJ02<^:P8072DP02h06b@O01XS7P0J8ah072DP04A=B00B6aH07BHQ02hg<P0N9b808BXU01lU8@0T
:RH06b4M01TO6`0N92008RPT01XP700B61@07bDQ028X900G7AT051TE01`N6`0G6AH08B<P01`N6`0E
5a@0828O01lQ7P0R92406adJ01TK600L7Q/06QdK018F5@0e>CP0If]Z02lc<P0>4Q4051PG01PL6`0K
7ah06AdL01HJ6@0B5QD04A@C100G5aL201HH5`0601@F5@0F6QT00`L600D9200F6aT04aDB1@0D5180
5P0G5aD07QhL01HF501cLg40Kfm]01HF500>3P`06ATG01HF500>3P`01`L5010?3@0?3P`020L5018>
3@0X92<03PX9010;2P0I5A@04Q4?014@3P0B4@l200l>300<014@3P0U92808B0N01LF500:2@L05A@B
01<?300A3@X0:RHS02TU8P0>2PL061@A0P0A3@X2010<2@05018>2`0C3``05A4@01@@3`0B3Pd00`0A
3@`01`0<20L04@d<01@@3`0@30/03@T801@@3`0A2`/0100B30`00`0A2`/040X:010:2P04010:2P03
00l;2P0A3@`04@d<00803`/:00l040`;01PD4`0C3`h02`L600l;2P0E4A0040`;04U4@@0M61D07aXG
00d81@0P6aP03`X701<>2`0@2`P00P0?2PL2010;200B014<2@0B3@X040/800`7100?2PL04`h;00l:
200F4@h01`8000l:1`0A30T071LD018=2P0@2`P01P8000l:1`0J5A802PD40P0@2`P0100A30T040/8
010;200?2PL200@00005010;200<1`@03@P500`7100?2PL0100@2`P01P0A30T03PT600d81@0?2PL0
40/800l:1`<03PT600P03@P500h91P0>2@H040X9010:2P0?2@T03PP800l92@@040X:0P0>20P01P0=
1`L03`X700h91P0>2@H03@P500h91P803`X70P0A30T0700<1`@02`H3014;2P0E3a405Q0B00X41P0A
2`d04P`>01D?4@0C3@l03PP:00/51`0F41803`T;00L20`0<1PP0100001dG6@0=1`T030H8014;3@0B
30h02`D701D?4@070@<030H8018<3P0@1@T401462P0701052@0V6al060dA00l4200A1PX04`P<00h3
1`0Dooooo`006oooool01@0A41H040lE00l>4`0?3Q<0410C00804A4C00/04A4B010@400?3`l03Ph>
00d=3@0=3@l04Q8D00X:300820X04Q8D01@D5P0600l?4@08010?5@0I61d07A`Q018A5P0;2`d03Ph@
010@4P0?3`l200h>3P8030`<00L04Q8B00h<3@0=2``03@/<014=300E4A0040`;008050l<00@04@`9
01<;200C3PX040h:1@0?3PX0100D4`l04a8>018A3@0A40`500l>2P04010?2`0A40`04A0<00l>2P<0
3Pd901003`h:00h>2P0A4Pd02@X500l@2`0@4@`092DP018C3P0I6QD09BHQ024R7@0@4@`02P/600/<
1`0<3@P03Pl:0P0@4@`02@0?40/03Pl:01PI500A4Pd04Q<>01@E400?40/05QLA00l@2P0300h?2@04
00d>200@4@/03a0:00h?2@80414;00T03Pl900h?1`0?40P04149010A2`0A4P`04Q<=01XK5P0;30L0
0P092@L05P0;2`T05ADC014@3P0:2@L03Pl=00lA3P0;40`08bTU0=GKe`2=Thl051TE00l?3@0:2PP0
3`h<01<C4@0A4@l0410>014A3`0B4Q00410>00l?3@0C4a42010@3P1101@D4P0A4@l0>CTg02/[:@0O
7ad02PX8010@3P0D5180410>01HF500A4@l03Ph<00`<2P0410803a4>01@F4`0<3P/02P`901@F4`0F
61D02P`900d?300E5a@02@/802LY9P0H6QL03Q0?00d?3P0>40l06Q`K09nQX02a/k805ALF01/M700C
5A@02`d<00lA400B51<05ADC01/K6@0C4a404Q8@01LG5@0E5A<05QHD01DE4`0@40h05ADC014A3`0E
5A<0414<01<D3`092PD05AHA00X;1P0D5A005aPC00l@2`0A4Pd08b@O00X;1P0E5Q405aPC01DF4@0D
5A000`0C50l01`0E5Q405aPC01PI500C50l0414<014B3P0C5A800`0B51408@0C5A8051HC01PJ5`0G
6AH03a4>01PJ5`051`@04Q@A01XL6@0:30T061XG01@F4`0W:BH05aTF01@F4`0H6QL05ALD014C400D
5Q<05APE03Pm>@0>4Q4020`:018G4`0P9B406AhJ01<H500B5a<05a`G01HK5@0F6aL04QPH01HL7002
01HK7P0Y01TN8@0H7Qh082HV01DK6`0N92<04ALG01TO7`0I7ah051XF014H4@0V;2P05Q`H02dc;`0O
9B<05A/I024W9@0H7Qh07B<S01HL700G7Ah0;CHc02df<@0P:B@05AhI01PQ700J8ah06B8M01XS7P0L
9B007RLR01lX8`0O:B<0<Cdk02Lc<@0?6aT07B`Y02/j=`0M;2T07Rh[01l`;@0N<Bd00`0O<Rh03`0T
=cD09STg02Lj>00X>cT0:3/j02Pj>P0U=cL0:cdn0312A00_@D<0;T1302do@@0_@d@0=4Q703U=C002
03Y>C@0X03]?CP0iCD`0?U9A04AHE`13EeH0>Ti=03=7AP0kBdX0=4A103]<AP0mCTP0CUmG04AEC@19
FU@0?De:04MGEP1AH680DV5V04mQI@1<GfH0C61W04eQJ01?HfT0DFI[059WJP1AIVP0CV=T04aQHP1=
Hf40CfES055WI@1EJFP0DVIU05IZJ@1CIfH0G71_05=WIP1IKF`0G71_05ibL@<0HGEd00h0HgEi07:4
R01[OH40L8:606n1Q@1`PXH0KGn306j0Q01aPhL0LhF907B6RP1gRHX0NHb:07b<R`80O8b<01@0O8Z;
07b:S023TI@0SIRL08nJW`2=V9h0TY^R09NPYP2FX:80Uj6S09VRYP2FWj@0V:6V0:>//P2RZk80VjB[
09jW[`2V[kP0Z;6j0:N]]PD0YjZc1@2XZk@05@2XZk<0Y:N^0:BW[02SYZ/0XZFZ0:6TZ@2PXjP0XZFZ
0:2SZ02RYJX0W9nT09FHW@2HW:00VIjQ09RPXP2KXjD0VJ>T09NQXP2DWYl0T9bL096MW@0308nMW@0e
092NWP2?WIh0SifN08bJV`29UiL0QiFE08FCT`26UI80PY6>07j=R01mS8L0MHAo06UhL@1]Og<0EfUK
04eOD@19Fdl0AEM;04mQE@1=GU@0Cf1F05=TFP1GJ600GFiV05iaJ`1DIf<0GG9]05aaK01DJF@0CV=N
055VH@1GK6L0DfQS04mTG`1@IF00DFIQ059UG`1BHeT0@51603mCBP0iC4H0?59>04EJF`12EeX0?E5E
045DF017EU/0<3m2034o@P0R<S809SHe02Ph=`0Y>CP00P0W=c@0300/?3T0;Sli02dn>00Z>cD0;3dg
02hn>`0b@T80<D5102Hf<`0V=S40:cXc02Lg;@80:cP_00/0F6EL03@o>@0B7AT08B`X024Z9@0R:bH0
7bPS01/T7`0L9B007bPS04M@B`0201LP6`0302`e<00O:2<08R/V008082HR00l06AlK01LM6@0K8Ad0
7B<O01`R7P0D6QH082HR01dS7`0D6QH0720L020R7`0G6AH08R@Q02HX9@0F61D00P0J71T0300K7AX0
6Q`I01TK600J71T071lM01TM700H71/06AdL018F5@0D61L06QhM01TM70806QhM00<05QXI01<G5P0E
5QH0100F5QH0200E5aH07R0O00lA400F6QT082@S02@X9`093P`04aDB0P0D51805P0C4a404Q8@018B
400@40h04A4?03De<`2][J/0YjNU018B400K6aT051@B00X:200P81h06QXH01LF500K6QP04A0>00X7
1P0H51<02`L601TD500C3`h400l>300E010?3@0C4Q003Pd;00h=2`0G5Q@051<A00/:200G4a804`l=
018>2`0:1PD04Ph<01DA3P0@30/040`:010<2@0A3@`04Ph<01<?3P0D40l04`l>00@04@d<00P04`l>
014=300E4A004`l>00d9200B3Pd04@/;018<30804`d=00<04P`<014;2`0@2PX01@0@2PX0100?2`X0
4@d<018>3@0A3@`200l;2P0701`H5`0X92<05Q8A00T5100C3`h0510?01`G500200@0000600/60`0A
30T03PT6018=2P0?2PL03@P50`0>2@H04P0A30T04Pd:00l:1`0=20D03PT6010;2008108081/H01TD
4@0@2`P05A0=04Q3@00F4@h0100000h91P0?2PL02`H300`710803PT600X03`X700h91P0>2@H03@P5
014<2@0O6QL02`H301HA3P0:1@8040/80P0A30T04@0B3@X04`h;01<>2`0C3P/04@`9010;200A30T0
4`h;018=2P0@2`P03`X700d81@0<1`@03@P500l:1`0@2`T03`T900<03PP800@040X:00d71`0C3@d0
3`T90P0>20P09@0=1`L03`X700h91P0>2@H03@P500h91P0?2PL0100000/60`0F4@h03@P500D0000>
2@H0100000X41P0=1`T040X<00h82P0<1PP02`D7014;3@0;1@L03`T;00D00@0M5aT05@lA014;3@0b
;2h030H800P3100H4Q@05Q0B00`6200F4180208400d82@0?2@/00P0@1@T201462P8040D900H07A8F
01<8300=0PH03`@801872`0@1@TDooooo`006oooool0200A41H040lE010?500@3a@0410C014A4`0?
3a403`l@100?3`l01P092@/06a/M01@D5P0<30h0410B00h>40H03`lA00L03`hD01PG700^;C807A`Q
00L72@0C4aD03Ph@00803Ph>0`0?3`l01`0@3Pl04Q0A01TG600G4a@03`/:014=300F41000P0E40d0
100G3`d05`l<01D@300@3PX500l>2P03014@300@3`/040l;00<040l;0`0?3PX05P0@3`/04A0<018A
3@0A40`040l;00l>2P0@3`/03`h:00l?2`0=3PT03a0;010A300>3`X05AHA00`=200@4@`04Q<>00l@
2`0<3@P03a0;014B3@0?40/2010A30804A8=00H0414<018C3P0=3PT0824L02PY900F5a8200l@2P05
010A2`0>3`T03@h800d>200@4@/00P0?40X00`0@4@/04A8<010A2`0200l@2004010A2@0@4@/04A8<
018C3@802P/601404A4?00h>300@40h03`l=00l>300;2PP04A8?014C400;40`06b4M07EkM`1EFeL0
3a@@01<C4@0E5A<03`h<018B4002014A3`0@01<C4@0B4Q003`l=00d=2`0A4@l03`l=010@3P0D5180
4Q8@00l?3@0C4a403Ph<01LG5@0?3`d03Ph<00d=2`804Q8@00X04A4?010@3P0@40h030h;018D4@0A
4a003a4>01dO700@4Pl04aDB0P0B51406@041P<05QPE00L91P0@4Q4051HE00/=300E5aH0;S0_02d_
;P0C5A@05aTH00X<2`0L7Qd092HU00lA400G5aD051@B00`<2P0B4Q005aLE014A3`0E5A<04Q8@00X:
200B4Q000P0?3`d0400A4Pd04a@?014B3@0C50l03@h901<D3`0B4`h03Pl:00/<1`0E5Q402P/601/L
5`0G61<051D@018C3P0A4Pd2010A300701@E400F5a805aPC01DF4@0B4`h04A<?018D4@04014C400>
010B3`0P8Ql05QPE010B3`0U9b@0:2XW01TK600K7AX0418?01LI5P0C5A808B<P01HH5@0D5Q<201/M
6P0Z01DG500F61D05aXF00/>2P0J7aX051TC018G4P0H7AT05a`H01DJ5P0F6aP06QhM01HJ600H71/0
5adK01XP7P0J81l05adM01XP800H7Qh041DH01/P8`0F6ad06b0S01LL7`0I7R407B<O01PO600F7AH0
6R0L055GD`0J81h04QPF02D[:@0L8R806b0S01lT9`0K8B805AhK01XS7P0O:2<06b@O0P0J8ah00`0L
9B007BHQ020Y9002028[9P0@028/9`0I9B<0:3Ld07f<R@0_?S/07Rh[02Hf<`0P<2d08C<_028e<@0S
=S808SHb024f<@0V>CL09cXh02Tl>P<0:C/k00T0;Cm102m1@`0^@480;Cm302m1A@0a@dD0;T9303I:
B@0iCD`00P0hC4/0100jCTd0=TY903Y>C@0jCTd203]?CP0D03Q;BP14E5<0>TY703m@BP1oT8T0cmgH
07>4O019FU<0B5QE04aLFP12DU80CUeP04]MH01@IFL0CF9U04aQH`1>I6D0CfAV04mTI01?IF@204iT
HP0<051VI01DJVP0EVaZ05U]K01BIVD0Ffm^05IZJ@1cQhH0H7Ac05a`K`1OLg80HWIe0`1SMgH0301W
NGd0LH>706UkO`1[OH40KX2407B6RP1_PHD0L8:607:4R01eQh/0MXR<07Z;S080OHf:01H0PI2>08>A
T@25Ti@0QY:E08ZEV@2AW:80TYbS09:KXP2DWJH0VJ6W09NOXP2IXJ@0Vj>W09VPYP2KXZP0X:N^0::Y
/@2TZk<0XjZc0::Y/`2TZkD0Z:jg102Z[KH20:^^]`80ZZff00D0ZJbe0:R[]02WZ[80Y:N^0:BW[004
0:FX[@030:BW[02OXZL0W9nT0080WZ6V00L0X:BY09^PX`2IXJ<0VZ:T09RRX`2FX:40TYbM0080TIfM
0`2?WId2092NWP0>08jLW02<VYX0RYRH08RFUP25U940Pi:?07f<R@1hQh80NHR307:1N`1UMF/0G6iR
04aND01;GDl304mQE@0G059SF@1FIeh0FV]S05a]I`1OL6X0GG1Z05iaK@1HKFP0EV]V05U^J@1JKfX0
EfaW04mTG`19GUT0AEYE04MLE`19GUT0BEaG041AB00jBd<0?e9=03M:A`0lD5400P16Feh03016FUh0
=d]=03a<C@0a@4009C<c02`l?00X>3L09SHe02De=00T=3408c<`02Xj=`80;Sli00<0:c`f02`m=`0_
?c`00P0eADD03`0]?CX0:S/e02dl=@0Y>Bl09c@[02<`9`0`?C@08bhX01`W8`0Z=C408b`W028[9P0O
:2<072DP01hW8P02024Z9@0<01hW8P0H8A`07RLR01lX8`0Q:RD082HR01LM6@0L8Qh07bDQ01dS7`0L
8Qh08BLS0P0J81`00`0O9B406R0L01TM6P0202@V8`0=01TK600L7Q/07R0M020R7`0J71T05ALD01`N
6`0P8Ql07AlL01LJ600J7Qd06alN01DI600201HJ6@0701LK6P0E6AP05ATH01`P7`0E6AP051PG01XK
6P0201LE5P0301LF5P0F5QH05ALF00804aLF00D03Q8A01LM6`0N92804QLE01@F4`0201@D4P0H01<C
4@0B4Q004Q8@01hN70092@L05QHD01/K6@0W9bD051@B00h>300D51805QHD014A3`0M7A/05A@B010?
3@0B4@l04`l>01`H5`0B3Pd04Pd=01HB4@0F5A<051<A0P0@3`d0400A40h04Q4?01@C4@0D4a4030/9
00h=2`0A40h04@d=00h:2`0C3`l04`l@018>3`0>2PX03`/<014=3@0B3Ph2018>3`05018>3P0B3Pd0
4@d<010<2`0?2`X00`0@30/01`0?2`X04@d<018>3@0B3Pd040`;014;2`0B30`00P0C3@d00`0B30`0
4@/;010:2P05010:2P0H010<2`0?2`X04@d<018>3@0@30/03PX901HB4@0O6aX05A4@00l;2P0A3@`0
30P700l:1`0I51403PT602@O700810803PT6010;200>2@H03`X7018=2P0?2PL030L40P0@2`P0400?
2PL03PT600h91P0>2@H050l=01dH5`0A30/04Pd;018=300=20D050l<00/60`0B3@/03PT600P40P0B
3@X200l:1`0:010;200?2PL03`X700`7100g<Rl0IV5N018=2P0<1`@04@`900h91`803PT60P0?2PL0
6P0@2`P04@`9010;200?2PL040/8018=2P0A30T040/800l:1`0>2@H03@P500h91P0?2PL03`X800h8
200=1`L030H600d71`0>20P02PD501XD500>20P040X:014;2`0@2PX03`X70P0>2@H06`0=20D03PT6
00l:1`0C3P/030L400/6100>2@H030L401@?300@2P/03@L9014;3@0;1@L03`T;01H@4P0910D03PP:
00`6200A2`d03@L902LQ8`0>2@X030H800l:2`0A2`d05Q4B00/51`0200h82P0400`6200:10H040/<
00h82P8040D90P0?10P201052@0300l4200B1`/04PL;00803`@800<040D9ooooooooool04_ooool0
01_ooooo00X03PdC010?5@0B4AH04Q4F010@4`0>3Q0030`>00d=3P0>3Ph03`l?0P0@41001@0A4A<0
7QhP01HF600D51H06a/M00L03`lA00L030/A014@5@0K6Ql061LL010@4P0C4aD03`lA00<03Ph>0P0=
3@d03@0>30d04@l@01/I6P0H51D030P700l;2P0@2PX04@T701H>300K4a404`/800T4000@3PX01@0?
3PX0100E51004Q4=00l>2P0>3@T2010?2`<03`h:00@040l;014@300B4@d04Q4=0P0C4Ph03P0A40`0
40l;014A30092PD04A8=010A300A4Pd04Q<>00d>2@0;30L03Pl:01DF4@0G61<04a@?0P0@4@`500l@
2`0<00`=200>3`X01`P400H70P0B4`h04A8=00l@2P0B4`d03a0:00d>200>3`T0414;0P0?40X00`0A
4P`04a@>018C3@02014B2P0N010A2@0@4@/0414;00l@2P0B4`h07b0K014A3`0>3P`06ATG02/[:@0>
3@/04A0>01<D4P0A4a003A8>00/A3@042PH061hJ01LL600:2PP03@d;00d<2P0A4@l0410>014A3`0C
4a404Q8@00h>300B4Q0051@B0P0@40h0300B4Q003`l=00h>300D518030`:01TI5`0<30X03@d;01TI
5`0E5A<04Q8@014A3`80410>00`07R0M00h@3@0K7AX0<C<`04A6@`0C5A804Q@A014C400@4Pl03a4>
018D4@0A4a0300d?3P0601@F5@0@4Q404aDD010B4@0:30/02`d<0P0N81l0100?4A004A4?014A3`0B
4Q0201HF500C01@D4P0U9B<08B4O01LG5@0Q8Al07alM01dM6`0@4@`03a0;01PI500=3PT06AXE01<D
3`0@4@`04a@?01PI500J6aH05QLB01TJ5@0300l@2`05010A300A4Pd04A8=014B3@0B4`h00`0E5Q40
100D5A404aDB01<E4P0C5A82014C400>02DW902SYJ80Bde:01lQ7P0B51400040018D4@0C5A806A/H
014C400B51403Q0=01<E4P0D5Q<201LI5P0;01DG500G6AH07R4K01PN500G71D07R<L018G400I7QP0
5Q/F01PM6@0H71/00P0H71d0;P0Y;Bh051XH01LM6@0G7AT05Q`J01TO7@0G7Ad06AhQ01PM800G7200
7b@X01<H7P0J7b@06R0L01/R6P0J8AX041HB00lE4@0B61D08BLU01`R8P0N92@06AhQ01/P8`0I7R40
6R<P024Z9@0[=2l09c0[01lX8`0J8ah072DP01dV8@0P:B@08BXU028[9P0R;2L0:cLe01d[:`1EHf<0
:SPh020_;`0A8B007S4_028e<`0U>3H202Hj>00:02@h=P0U>3H09cXh02Tl>P0Z?3`0:cdn02Xl?P0a
@dD0<D=602m1A@80;T1403L0<D=502m3A00gBdX0>Ti=03M;BP0eBDP0>4a;03A8A`0iCD`0=TY903M;
BP0jCTd0=dY803Y:B@0oCTX0=dI107b;Q02da;X0IgM]04IECP1;FUL0AeIC04mMGP1IIfX0CEaO05AY
I`1=Hf40Bf5O04eSH01=Hf40Bf5O04eSH@1?IF<0DFMU05E[J@1HKV`0FFm]05AXI`1@I6<0HgMf05mc
LP2;Wih0KH6005]_KP1OLg80HWIe06IjN@1YOG`0JWim06eoP`1^P8@0JWb007:4R01^P8@0LhF90080
LXB800@0M8J:07N9S@1iRhl0OXn@0P21THh04`24Ti40R9JF08^IVP2=VY`0SiZN09:KXP2EWZH0Uj2Y
09RQZP2KXjT0VZ:U09bTY`2OYj/0WJBZ0:2W[@2U[;<0YJbd0:N^]P2W[[L00P2U[;H00`2Y[[L0Zjjg
0:b_^0030:f`^@80[k:k00D0[K2i0:Z]]P2Y[;D0Z:^c0:NZ/@020:NZ[`<0YZV^00<0ZJba0:JY[P2P
XjP00P2MX:D02`2LX:@0WZ>V09^SY@2IXJ<0UZ2Q09BNW`2BW9d0TinO09:NWP2@WYh0SifM0080SYbL
01T0TInO08jLW02;VIT0RYRH08VGU`25U940OXf807N6P@1`OgX0M8=l06mnM`1RLVP0BeeA04=EA`18
FT`0DF=G05EWG01DIE/0EVMO05Y[I01NKfT0Gg1Z05i_JP1JKFT0G6m]00<0Ffm]01P0FFe[05AXIP1>
HV00Ae]I04EIE`18G5X0BEeK04IIE@16EE00?De803M:AP0a@d<0>4e?02m7B`0W?d<0=TY=03A8B@0d
A4@093<a02He<P0c@d809SHe024a<00R<S4202De<P0@02<c<00W>380:CXd02Xk=@0[?3H0;3`i02Xj
>P0]?Cd0;cll02Ti=00R<BX093@Z020]900S<2L09c@[02Ha:`808bhZ00@08R/V01dV8@0K91l072DP
0P0N9b80200P:B@07BHQ02lh<`0K91l082TT01/T7`0L8Qh05Q`H0P0N9200100L8Qh07R@P01XP700K
8Ad201TO6`0>01lU8@0X;2P05ALD01PJ5`0P8Ql06adJ02@V8`0L7Q/05QPE018D4@0M7a`092HS02LY
9P0S9R@201HJ6@0F01TM700D61L05a/J01LK6P0?4a807b<R03Di>00O8b803a<B01@D500H51D05Q@E
01HE5@0E5AD051HE01`P7`0E6AP06AlM08N=R`2:T8h02a0>01<E4P8051@B0`0C4a403P0@40h01PH4
014A3`0<30X03@d;00l?3@0L71X03@d;00X:2@18B4H0]kNe0491?`0H5aD071/I0P0C3`h01P0E4A00
6A@D01LC4P0I61H05QDC00d<2P803`h<00d040l=00T81P0@3`d02PT701<B400>3@/05Q8C01/F6P0:
1@T04@`@00d8300E41@040/?00<04PdA00@04@`@00l;300A3@`04@d<0P0@30/02@0A3@`04Ph=00d9
200N6QT04`l>00`81`0C3`h03`/:010:2P04014;2`L040X:01P040`;00`81`0=2@P040`;00l;2P0=
2@P03PX900/71P0=2@P04@d<00h:2@0:1PD03`X7010;200:1@804@`9018=2P0M61D040/8014<2@0E
40d06QDB01@?300>2@H200d81@0@00h91P0?2PL03`X700h91P0R7AX0ZZFR01hI5P0@30X01`8001TD
4@0:1@8061<@014<2P0=20D06QDB00d81@8040/800L04@`9010;200@2`P03@P501TD4@0^:BH03`X7
00804Pd:00@02`H5014<2@0A30T04@`90`0@2`P01P0=20D030L400h91P0?2PL03PT600d81@803PT6
00D03`X700h91P0>2@H03PT700h8200300d71`0800l92@0I4a<0;bTY01LA4@0D3Ph03`T900/51@0?
2PL200h91@0F00d8100>2@D03`X600X50@0>2@D05A0<00/60P080`00:B@Q01dG5`0>20X03`T;00@0
00090`D04@/=01D?4@0<1PP03@L900T31@0:10H01`8300l92`805Q0B00T04@/=01H@4P0C3@l03@L9
02HP8P0:10H030H800h82P0?2@/00P0@1@T200h31`8040D90P0B1`/201<8300301462P0=0PKooooo
01?ooooo000Kooooo`0800d<4P0@3a@04a8G01<B5`0@41<03@d?010@4P0@414200h>3P0800d=3@0<
30`03`lA00h>400000801@D701XJ700C4aD600l?4@803@`A00<020P:010@4`0G5aT00P0A4A<04P0@
41003`l?00d=3@0<30`02`/;00l>3@091`P03`h<00d92@0;1`H04`l>01<>3P0D3``071LD02<N6`0E
40`02@@0010>2PD03`h:00D08B0L01XI5@0D4`l03`h:00h=2@0400l>2P0H010?2`0A40`04Q4=018A
3@0D4`l05A@@018A3@0@3`/0410<00L80`0>3`X02P/600d>2@0>3`X05AHA01@E400?40/04Q<>01HG
4P0C50l03a0;010A300?40/03Pl:0P0=3PT03@0B4`h01@H100X;1P0A4Pd05QLB01LH4`092PD0414;
01<D3P0?40X03@h800h?2@0A4P`00P0@4@/01`0B4`d04a@>018C3@0B4`d04A8:014B300@4@/00P0?
40X06`0<3@P08b@O010@3P0A4@l07AdK038b<00B4Q805ADE014B4P0<40l041@C00lE4`0F71X03A<A
01DJ5`0J71T04a<A00d=2`0A4@l0410>014A3`0C4a404Q8@00h>300F5Q@061PF01<C4@02014A3`0C
00d=2`0B4Q004a<A00/;2@0?3`d030`:01<C4@0F5Q@0410>00h>300@40h04A4?018B40071`D0418?
018D4@072@H06adJ00/=2P0200`>2`0[00/=2P0B514030h;01@F4`0E5a@03Q0>010B3`0;3@`04A<A
00lA3P0<3P`03a4@01@F4`0;3@/02@/:01<E4P0C4a404A4?010@3P0<30X03Ph<018B400E5A80414<
00D60@0@4@`03a0;00/<1`0@4@`02P/601PI500;30L0824L01<D3`0@4@`02``7018C3P0A4Pd04Q<>
00`=200B4`h04A8=010A3002014B3@03018C3P0C50l04a@?00<04a@?020051DA01@F4`0D5Q<051HC
01<E4P0A4a005ALD08J8Q@0m?c`051HC00X<2@0L7Q/05QPE00`>2`0M7a`0418?01PJ5`0:30T05QPE
01@F4`0C5A804Q@A01@F4`0H6QL05APB02D[8@042P008BLN01PM5P0R9b405Q/E01DJ5P805QXI00@0
7B4P03Xn?P0@5Q@051XF0P0E6aT06@0H7Q`05adM01TN8@0E6Qd06AhQ01HK7`0N8bL08BH[02H/:P0A
5a<04QPE02P^;00630X08bTW02P^;00A5aD07B<Q01XP7P0E6a/061hM01PQ700K9Ad07RLR01XS7P0F
7aX00P0K91l05P0L9B007bPS020Y900Q:RD08B/T01XV8P1@Ge`09cHc020_;00Q<Bh09cLd01/^:P0O
<Rh08cHb02@h=P0U>CL08cLe02Dh=P0W>SP0:C`j02/m?@0/?Sl202`n@00V02m1A00a@dL0<4960394
B00dATX0<dM803a@C`0nDU40>De<03M;BP0jCT`0=4Q703Y>C@0hC4/0>4a=03Y>C`0dATP0?4a<04=A
DP0nC4`0BUUF04aME`18FE<0?De905QXI@1<G5/0BEUI04iMH013EEL0DFIT04]QG`1:H5h0CVAR051V
I01>I680D6IT059XIP1DJVP305E[J@0B05U]K01BIVD0H7Ac051TH`1eRHP0Cf=R065eM01SMgH0IGUh
06UmO01/P7l0KH6006YlP01fR8`0L8:606j0Q01[OH40MXR<0P1dQXX0101gQh`0NH^?07f<T@22TI<2
08>CTP0C08JEU029UiP0S9ZK092MW`2BWJ40TY^R09JOYP2JXjX0VjB]09fU[02NYJ/0WjJ/0:2W[@2L
XjT0WJB/0:F[/`2VZ[<0YJVb0:Z^^0020:jb_@0E0:f`^P2/[kP0[Zjh0:j`^@2^/KX0/;2j0;:c_@2b
]Kh0/;:k0:j^^02Z[KH0ZZ^e0:Z]]02Z[K80ZJbb0:NZ[`2VZJh0YJR]0:>VZ`2UZ:d0Y:N/0080X:>X
0240XJFY0::WZP2OYjT0WJ>V09RPXP2GWj40UYnP09FOX02CWil0TYjN092LW02>W9`0SY^K096OW`2>
W9`0RiVI08ZHV029V9D0QIBA07j=R01gQX40L7mj07F4O@1`OgP0I7AZ05][H019Fdd0A5I804aNDP1J
K640HgAZ05EVGP1IJV800P1MKVP0;`1KK6H0EVUU051UH01_Q800MX^6069fM01@IF40EV]V04MKF@13
Ee@0@eQC04UMF`1;H5`0AeaG04IGD@0jBTH0<DA003=7A@13F5P0=4U:0397BP0lDE40A5IF03i>C@0[
>CD0@U5>02`k>P0U=C@093@a02@d<P0Q<Bh07bl/02<c<00U=S009cPb02Pi<`0W>3809cLd02/k>`0_
?ch0=dM602ho>P0T<b`0:3L`02Hc;00P;BH09S</00<09S4]02L092dX01`U800K91l07bPS020Y900O
:2<08b`W05MPF`1nQh808BXU01HO6P0R:bH06R4K01TO6`0L8ad05A`E01@J5P0J8A/05ahG02@Z9P0N
91l03A@=01lU8@1MHUh0<cDb00d?300I6aP07R0M02/]:P0S9B80828O01XL6@0K7AX061XG01XL6@0G
6QP05ATH01TM700G6aX00`0H71/01P0B5QD05QXI02DY:00E6AP041@C01PH60805Q@E00X05QDE01DE
5@0D5QD030h=01HJ6@0D61L0Ngmn07f1P00E6QT04aDB1@0D5180600E5A<06ATG01<C4@0L71X04a<A
01@D4P0<30X061PF01TI5`0g=cD0`/;003He<`0?3P`05aHD018>3@0A3@`04`l>014=300?2`X04a8@
014@3P0:2@L03@`:00l>30804A0>00/05aHD00P71@0?3P`040l=014=3P0j=SL040`=01DA4P0F4Q<0
2@D6014<400201<>4P03018=4@0@2`l03PX;00804Ph=0P0A3@`301<?3P0702l[:P0K5aH02PH5014=
300>2PT03`T9010:2P02014;2`03010:2P0?2@T040X:00D040X:00<040`;00/71P0;1`H00P0?2`X0
4`0>2PT03`/:014=300A3@`020@300X61@0C3`h040/:01HA3P0U81d03PT601<>2`070P004@`901<>
2`0I51407aXG01LB3`0A30T00P0<1`@0400>2@H040/800l:1`0>2@H03@P501hI5P0?2PL05Q4>00l:
1`0D3``02PD204a7A015@3d0100001PC400:1@<200h91P0:00l:1`0>2@H03PT6010;200=20D03`X7
00h91`0400002`H300l:1`803PT600T03@P500`7100;1P<03PT600l:1`0>2@H03`X7010;200?2PL0
0P0=20D04@0?2PL040/800l:1`0=20D03PT700l92@0@20T040L800l92@0A2@X02`8302<M7@0>20P0
4PT:00l92@0>20H03`X700803PT502<03@P400h91@0?2PH04@`800X50@0>2@D03`X600L2000=20D0
4P`<00H00P0C2`h03@@7014;3@0C2`h04@P;00T31@0B2Pd01P0000d72@0E3A004@P;00X41P0=1PP0
2002014:300@2P`06A0C03lg>P0A2`d04@P;00`51`0@1`X04@H:00l4200200d21P0300l4200A1PX0
4`P<00803@@70P0C2Pd00`0=10Ooooooooooo`0Booooo`006oooool0100E5AP04A4C00h>400@4182
014A4`06018B500;2`d04a<E00X:300@41803@d?1P0@3Pl0100?3@h05Q@E00l=3P0A3a0201<A4P05
018@4P0=2`d03@/<01<A4`0C4A800P0A3a001@0>30d03@/<014?400D4Q<051<B00803`h;0P0?3PX0
4P0>3@T03`h:018A3@0B40`04a4=01@B3P0A3`/03P`8010?3@0A40h02@P6018A3`0:2@L040l=01@C
4@0A40h03`h<00h=2`803`h<00P03`l=010@3P0?3`d0410>01@D4P0D51<02`/:010@3P803@d;00T0
410>010?300=30P03Pd9010?2`0?3PX03@`801PG4`0I61@00`0@3`/01P0A40`05ADA01@E400@4@`0
3@h900h?2P<04A8=01<04a@?014B3@0@4@`04Q<>010A300G61<06Q/F00l@2`0>3`X04a@?00T:1@0E
5Q403Pl:01@E40092PD04a@?014B3@0A4P`0414<00803a0;00@0414<00`=200C50l05QLB0P0A4Pd0
6`0?40d03@hB01HH7P0R92/0Q8N=04]>D`0?4aH08BDW069VI`0F6QX041@C00hA400@4Q403Ph>014A
4@0@41003`l?014A4@0?3`l04a<C010@400<30`05ADE014A4@0@41004Q4?014@3P02010?3@09014@
3P0B4@l040l=018A3`0C4Q004A0>018A3`0C4a40410>00804Q8@01h0410>014A3`0C4a404A4?01<C
4@0?3`d0410>01@D4P0=3@/04Q<?010A3@14AD00DE9>018C3`0A4Pd051DA00l?300=3PT0410<014A
3P0@40d04aDB01@F4`0@4Pl0418>00X<1`0A4`h03@l:01<F3`0A50`2018E3@0E010C300B4`h04Q<>
010A300B4`h04a@?014B3@0B4`h04A8=010A300A4Pd04Q<>01<D3`0@4@`04Q<>01@E400C50l04A8=
00l@2`0B4`h04a@?00<051D@00P07R0L02HX9@0I6aP051HC01<E4P0>40d04Q@A01PJ5`804aDB00H0
5ALD00lA3P0C5A806Q`I01TK600H6QL201<E4P0901@F4`0`<Rl03Q0=01TK600Q8b006adJ01HI500K
81T06QlH00806AhG03d0:RlX0415?P0K81X0724K01LL5@0O91h051TC01@J600E6aX061hN024W9`0@
5QH06AlO014G5`0D6QX06R0P01<I6P0E6Q`07B<U01XR9P0G7R<05alR01/S9@0H82805b0N01dV8`0K
91l06B<K01XT6`0I8aT05b4G01dT6`0H7aL082LP01hT800Q9b<08BXW028[:01BFeP07bXT02/f;P0L
9al08RlU020]900T<RX093<[028a:@0R<b/09CH_01TZ8`0X>S@09CPb02Hi=00T=c<0:3/i02Lk>P0]
@D00:Cdl02m3A00/@440<4A50080;d9600H0;3m30354BP0eB4h0=DQ=0395B@0dB4X203M;BP0A03M;
B00eBTD0<TM303I:B@0hBdh0?U5F04QKHP0oD5X0@U1J04MDGP1<FV<0AEEL03e?D`14EUX0@UIG04=J
F@18Geh00P18H5d05@1<Hf<0C61T05MZK`1EJ6d0DFAY05=WJ@1GJVd0G71b05eaLP1CIfP0EVY[05]_
KP1DJ6L0EFMW05Y/K01iRh/0KX2005MYJ@1VN7P0I7If06IhN00206]mO@090722PP1hRXX0L8>706j1
Q@1aQ8P0LH>707>5R@1iRHh0NXV>0080NhV>00<0O8Z?07n<TP24TYH00P26U9H01P2:UiT0T9^O09>N
XP2HXZH0U9fR09FLXP80WjJ/00@0WZF/0::Y/@2PYk00XjNa0P2WZkD05P2XZkL0Zjfi0:na_@2a/[h0
[k2l0;6b_P2c/[l0];?00;:a_P2b/;d0][G10;Bc`02d/[l0]KC00;Je`P2d/[l0/Jnl0;>b_`2][;P0
[:nh0:V^]@2X[;D20:V^]0040:N//P2VZjl0XjR/0:6VZ@80XZNZ00@0XJJY0:6UZP2PY:T0WZ:V0P2L
X:D0702LXZH0Vj>V09VRY02FWj40TifO09BNX02FXJ80TYjN096MV`2>VYP0S9RF08VET`23Sh`0P8b8
07f9Q@1kQh<0Mh=o06mkM`1YMVl0E65G04mND@1DI5L0FFUL05QYG01IJel0DfAJ05U[H@1HK68205AX
G`0705U/I@1DJF80FG1X05=ZHP1>IEh0CVEM04]RFP0204AKE00/04AKD`13FU<0AEaD04IME@0nE4d0
?UA<03Y@B@0gC4H0=T]503Q<AP0iBdL0<D4m03a;A`0M:RL0;c/g02Th<`0Z>SD08C4]01l`:P0S=2l0
8c@^020a:`0W>380<T<m02Pi<`0dACl0;d0j02Tj=@0Z>3L0:3Hf02Le=@0W=C@0:3@c02Lc<P0W<C40
9S0`02<];@0Q:BX08RX[02@]:`0W<BT07BLO01lY8@0R;2@2024Z9@0803Q1?00_>3D0@T]801/T8@0O
:2D04a`G01`R6`0L8AX301dR6`0801/P6P0Q9Ql092TR01dR6`0Q9Ql051TB024V8@0K81`2024V8P04
01TN6P0O92006b0L01PM6@807B8N02<06b0L01<H500L8Ad05AXF01TN6P0H7AT051TE01PM6@0D6AD0
6b0L02DZ9P2FViL092TU01HK5`10@T005QHF00h>3P0F5QH0820P02@T900G5aL06AXI01/L6`0G61P0
5QLF01<D500C4a<051@D01HF5P0G5aL05QHF01DE5@0@410051@D01HF5P03018B4P0801@C4@0B4@l0
51<A01/J600L6aT05QDC01PG5@0B4@l301<B4008018@3P0C3`h04`l>018>3@0E4A00510?01HB4@0C
3`h2010<2`804`l>00<03`/9018>2`0B3P/00P0A3@/0100B3Pd04`l>018>3P0A3@h2010<3@03014=
3P0B3Pl040X:00804P`<00D040X:014;2`0B30`04@/;010:2P0200l92@0D010:2P0A2`/04`d=00l9
2@0G4A406Q@D01<=3@0B30`04`d=018<300@2PX03`T900h8200?2@T04P`<010:2P0?2@T040X:014;
2`0B30`6010:2P0600`7100C3P/071LD00/6100?2PL030L40P0?2PL2010;200300l:1`0>2@H03`X5
00803`X50`0?2PH00`0B3@X02@@4014;2`0200l92@0=00`71@0I514081/H01@?300<1`@03PT600l:
1`0<1`@02PD200h91P0B3@X03`X700d81@0200h91P0400l:1`0>2@H03PT600h91P803`X701h040/8
00l:1`0?2PL03`T800h8200=1`L03PP800l92@0>20P03`T9010:2P0>20P03`T9014;2`0D3Ph06A4A
024G600D2``04`T:01892P0@1`P050X;01<92P0A1`P03`D601061`0A20P030H300d8100@2`L200d8
1004010;1`0=20@030L300h91@804@`800L03`X600h41@0@1`P04`T:01061`0?1@H04@L8008040H7
0P0A1`P201882@0601<92P0A1`P03`D601061`0F3@h06a8C0P0A1`P201061`803`D600`040@80145
2@0?0`L03@<600l5200C2Pd030@700d82@0>2@X02`L800/82@0<2``Dooooo`006oooool00`0B4Q@0
410B00l?4@02010@4P0700d=3`0A4A<04A4C00<31@0?3a4051@F00D51`06014?400800H41@091`P0
1P@500`:2`0D4Q<020H701<A4P0A3a02010>3`<04@l@01X0518C018@4@0?3@h04a4B01PG5@0@3``0
3`h:018A3@0E510040l;00`;1`0B4@d040l;014@300B4@d040l;00d<200>3@/03`h<00`;2@0D4a40
2`X800d<2P0D4a404Q4?014@3P8040l=0`0?3`d200h>3008014A3`0I6AL04A4?014A3`0H61H02PX8
00`<2P0?3``200l>2P04010?2`0A40`04Q4=01PG4`806QTE00D06aXF010?2`0;2PH03@d800l@2`02
010A300h00l@2`0=3PT03@h900l@2`0>3`X03@h900l@2`0C50l04Q<>01DF4@0H6A@04Q<>010A300>
3`X08R<N00@5000J6aH02``701DF4@0<3@P04Q<>010A300?40/04a@?01@E400A4Pd030d801LH4`0J
6aH03Pl:00`=200@4@d051DI014B5`0?3aH0ZJZ_04Y;C`0A4QD09RLY09^LWP0D5QH01`T801<E4P0?
4@h051@D01DE5@0>3Ph05QHF00X:2P0L71`00P8201XJ6P0>3Ph05ADE00d=3@0A4A4201<B40804A0>
0P0C4Q000`0A40h051<A01@C4@0201<B400601DD4P0E5A<05QHD01@D4P0A4@l03`l=0P0@40h03`0D
51804a<A01@D4P0A4@l020P600L80`0C50l09bPS03Df<@0I6QD02P/600/<1`0720<02@X5018C3P02
01LH4`0B01@F500?4A002`d:014C400?4@h05aTD01HH4P0E61404A@=03Tl=@0k?SL05APA01HG4P0B
4`h051D@00l@2`0B4`h07AhI0P0?40/01P0A4Pd051D@01LH4`0H6A@04Q<>01<D3`8051D@00@04Q<>
014B3@0@4@`04A8=0P0C50l0100D5A00:2TU03<e<P0M7a`300h@3@0U018D4@0C5A80418?018D4@0D
5Q<04A<@01@F4`0G6AH01PP5010B3`0Q8b005ALD01hP7@0g>CH061XG01<E4P0G6AH05QPE014D400>
4`d04QLA01`Q6`0b=c40Ri2:0<[?b@0l@C/05AXD01LL5P0H7AL07B8M02@Z:00D6QX05Q`L014G5`0C
6AT05A/K01dS8`0201`R8P0B02<Y:@0F71`0@4E7020X:`0K8bH06B4T01/S9@0I8B<06R<Q01/T8@0I
8Qd06B<K01XT700K9A`06B<J02T`:00S:R809RdV0P0L8Qh0?@0K92806bDT030k=`0J9Al08BhU01PU
700U<RP08c0W024_:00R<BX09SD^02De;P0P<B/0<44k01d^:`0C9R808cHb02m2@00T=cD0:cln02e1
@00X?3/0<4A502a0@@0]@D808cHj03E8C013EUX0;d9803I9C`0gBU00<dI:03E9B`0hC4/0>dm>041D
DP12EU@0<4A203eAD00dAd/0>diD03I9D@0oD5X0AeEP05MUL01]NhH0Cf1X04MJH00nDEL0@eQK04EJ
F`1<HF80Bf=S04MPG@17Gel0BemT05MZL01_PXP0G6me04AGF`1BIFT00`1DJ6T0501DJ6L0EFUX05AX
I`1KKFd0EVQX05AVIP1KKFd0J7Yj06eoO`1YNg/0J7Yj06]mO@1]Ogl0LhF507Z<S01bQHT0LXB807F7
R`1fR8`0N8N<0P1jRHh05`1nRi40P8fC07n<TP20SI<0QY:G08ZEV@2;UYX0SiZN09:MX@2FWj@0VJ:W
09JOY02GWZ@0WZF[0::Y[`2VZk40XjR`0:FY]02X[;L0Y:Nb0:b^^P2b]<00/;6m0080]KG100<0/[6m
0;Zha@2h]/<00P2e/l001@2d/[l0]kG20;Fc`02g]L80][C100<0/[2m00D0];:o0:j]^P2^/KX0[K2i
0:^^]`020:^^]@050:R[/P2WZZl0YJR]0:FY[02X[:l00P2Z[[402@2QY:T0X:>X09nRY`2NXJH0Wj:W
09nTZ02JXZD0VJ6T09JNX@0209>MW`1G09FOX@2EXJ40TIfM08fIV@2=VIL0RYJD082<RP1lR8@0NXJ2
07J3O01aOWL0K7Ub06EbJ@1AGU@0FVUL05m_HP1HJ5d0DF9F05QZGP1KK680FF]Q05M[H01GJf80EVYQ
05AXG`1>He`0E6UR051UGP1=HU/0C65J04QMEP19GUL0A5UB03eBB`0lDDX0?U=<045FC`12Ee00>e19
0397@00aA3h0<TDo03E8@P0W>380>4Q202/j=@0g@cl09C4]02<b;@0T=2l0<44k02m0>P0V=c40:3Tc
02m0>P0S=2h0;Chh02`m=`0`@C/08c@^02Df<00W=S<0:STf02Pg=00T<c009S8`02Te<`0U;bh092h]
024[:P0O:2L082TX028[:00Y<b/07RPP01lY8@0R;2@08R/V02@]:00N9b8072DR02</:@0J8b009c0]
02Xc;P0R9b407B8L00807R<M01<06b0J01XO6@0E6Q@02Pl901LL5P0V:bD0GfAN02db;@0E6QH0:c0/
0497@`0O92003A8>01dR7P0I7QX06QlK01<H500I7QX08BHR00804aPD00d06AhJ01XO6`0H7AT06QlK
01<H500J7a/04QLC02@Y9@0>4`l051TE020R800N7Qh03`l?008051@D00L04A4A01@D500E5AD051@D
018B4P0C4a<07AdM00<05QHF00`05ADE01@D500B4Q805QHF010@400B4Q804A4A00X:2P0?3`l03`h<
014@3P0D4a42014@3P0H01DD4P0R8Al09bHT014@3P0?3P`03Pd;01TH5P0[9bH03PX9010<2`0=2@P0
2`L600l;2P0E4A004`l>018>3@0C3`h04Ph=010<2@0F4Pl05A4=01<?300B3P/04Ph<0P0B3Pd01P0A
3@d040`=010<3@0A3@h04Ph?010:2P804P`<00<040X:014;2`0B30`00P0A2`/2010:2P804@/;00`0
40X:00l92@0D3Ph05Q0@018<300@2PX03PP8010:2P0C3@d04P`<00l92@0=1`L2010:2P804@/;00<0
40X:00l92@0@2PX01@0@2PX00`0G4Pl03`X700X50P0200l:1`0301XE4P0?2PL03`X7008040/800<0
3`X700h91@0?2PD00P0?2P@300l:1P0800T40@0>20P02`D501<=3@0Q6a/04@/:010;200C3P/200d8
1@803`X700<03PT600d81@0<1`@00`0=20D200h91P0300l:1`0>2@H03PT600803PT60`0?2PL0200>
2@H03PT7010:2P0A2`/030H600X4100?2@T04P`<0`0?2@T0100A2`/04`d=01D=3P0M4a@201882@05
01<92P0@1PL04`T:01882@0A1`P00P0@1PL0100A1`P03PH400h91P0?2PL200d81@0300l:1`0:1@80
3PT600802`H300D04@`900T40`0@1PL04@L801882@0201061`0401882@0@1PL040H701061`<04@L8
00H03@<400h41@0?1@H03`D600d3100;0@820147208040H70P0?1@H0300@1@T03P<701072P0C2Pd0
3PD800H0000;1@L03PP:00d92P0;1`P030P900`:2aCooooo000Kooooo`09010@4P0?3a403`lA010@
4P0?3a4030`>00d=3`0A4A<03Ph@00803`lA00<02@T;010>3`0@3Pl01@0@3Pl01P0J61T02`T:034_
<00A3a0020H700h<3@<04@l@00l04a4B01DC500@3Pl04Q0A014?400?3@h04Q0A01DD4P0A40d040l;
01<B3P0H5a<04Q4=00/:1P0B4@d00P0@3`/0200A40`03`h:00h=2@0F5A<03Pd;00X91`0?3P`040l=
0P0A40h01`0@3`d03`h<00h=2`0>3@/03`h<00l?3@0>3P`00P0=3@/200h>300600D50`061P@01`L5
01<C4@0P81h020P60`0@3`/2014@300>00T81P0:2@D061LC01hM6@0@3`/030/700h>2P0?40/0414<
014B3@0@4@`03Pl:00l@2`0@4@`300l@2`03014B3@0?40/03Pl:00@0414<02X01`P300H70P0<3@P0
20T401HG4P0E5Q402P/600h?2P0F5a806Q/F01PI500C50l02@X5014B3@0D5A003@h900h?2P0A4Ph0
4A8D00l@500@4AD04a@H014B500A4Q<030d?01lQ800>40h02P`900lA3P0>40d051@D014A4@0@4100
3@d=018B4P0@41006a/K00D51@0W9bL06ATI01DE5@0;2`/2010?3@803Pd;0`0@3`d201<B400`018A
3`0C4Q005A@B018B400C4a404A4?00h>300=3@/03Ph<01<C4@0@40h030`:00d=2`0?3`d03@d;00T:
1@0>3`X02``701TJ5@0B4`h02P/6018C3P0C50l04A8=00X;1P061`801PH400lA400>40l04aDD024S
8@0E5a@04Q@A01DG4`0:30L01PT2034d;@0_<R/01`X301HG4P0A4Pd05QLB00l@2`0D5A009RLR01@E
400C50l04Q<>0P0C50l00`0D5A004a@?01@E400201@E400<01<D3`0B4`h03a0;010A300B4`h04a@?
01@E400H6AD06Q`I010B3`0?4@h04aDB0P0?4@h2014C400@01HH5@0A4a002`d:01HH5@0A4a007b4N
010B3`1_LFh09RPU01dO700T9R<06A/H01HH5@0H6QL05ALD01@G4`8051TC00D06QlI038g<@29SXP0
bLk803Tn>00201<H4P1Z018G4@0M8Qd0728P01<I6@0d>SX0318B01XP800I7al05adM01`R8P0A5aL0
7B<S014G5`0k@D408RX/01`T9P0I8B806R8T01TR8@0K92806R<P01PQ700I8Q`06b@O01`V7P0K9Ad0
82LO01TP600M91d05adI01`R800R:bX06R@S01dW9P0J9B007BXQ01HS6P0U<RP0934Z02Dc;00W=Rl0
:3Lb02Lg<@0T=3408S8_02Hh=00W>SP08cHd02e0?P0^@Cl0:3`k02m3@P0/@3l0<4A502e1@P0dB4T0
PYFI0395B@0U>3`09CPn03U<DP0/?dD0>4]?03U<C`0jCTl0?E5@04AHEP18G5X0=DU703a@D00cATX0
AEQN03Y<E@12E5h0AEIP065_NP1fQ8d0AUMO04iQI`1;GV@0AEYM04aQHP1BIfP0C6AT04QQGP1;Hf<0
F6]`06n2R02>XJL0N8^A05AWJ`1JKG40EFUZ05=WJ01GJf`0EFUX059VI@1EJFP0G6i^05e_K`1JK6`0
HG=c06YlO01YNg/0Jgem06UkN`80K7in00@0KX2007>5Q`1`PhL0M8J:0P1kSI409`1gQX/0NXV>07n>
T`23T9H0Q96G08FBV026TiT0RYJK08fHW02?VYh0TYfQ09JQY@2IXZL0VjBY09ZSZ02JXJL0WZF[0::Y
[`2W[;80Yj^e0;6e`02c]l80YjZe0;2b_P2g^LD0/kC00;:b_P2d]<00]KC10;Fc`02i]l@0`;k;0;Zh
a@2e/l00^[S50;^iaP2h]/<0][C10;Bb_`020;:`_@050;Bb_`2a/;`0/[:l0:ja^P2/[kP00P2/[kH0
1`2Y[;<0YZV^0:FX[@2TZ:/0Yj^^0:R/[`2Y[K00102PXjP07P2QY:T0X:FY09ZRY@2IXJ@0UinR09BN
X02CWIl0U9jP09BOX@2?Vi/0RiNG08fIV@2;UiD0PHf;07b8Q01jQh00L7ee06EbJ@1NJf80EF9H05ES
EP1CHUD0FVYM05i^H`1IJUh0EFMK05e^I01LKV@0F6aQ05EYH080E6QO00P0CfAM05=XH@1>He`0Bf1I
04YOF014FE80@EI?03aABP80>4e60P0kD4T01010EDh0>Tm803=8@@0bACl203A7@@0W03A5?`0R<Rd0
7RdX02Da;@0Q;BT09SD`02Hf<@0fAd40=DI002/l=P0`@C/0>4U30311>`0^?cT0:S/e02Hg<@0K;2H0
9CH`02Dd<@0Z>CH0:3Ld028a;P0U<Bl0:CDc02@^;@0S;B`082XY01hW9P0O:2L08BXW02@^9@0K9Ad0
7BLO024[8`0T;BP0:C8]020Y900U;R/082TV00807BHS02d08R/V024V8@0Q9R007R<M01`Q6`0K81X0
7R<M01lT7P0J7aT061dG010E3`0S:2805AXE01TN6P0P9B409BXV01DJ5P0H7AT08bPT01TN6P0J7a/0
61dI030e<@19CTX092TU01LL600K81`061dI01LL600J7a/05Q/G02/`;00/<Bd04AHB020U8@0N8al0
5APF01lO7`0F5QH05aLG01<C4`0@41006QXJ01<C4`0A4A400P0E5AD0100B4Q805ADE01DE5@0E5AD2
01@D500:01<C4`0U9BD05aLG01LG5`0O7al05aLG01TI6@0D4a405A@B01HE4`8051<A00l05aHD00<2
000:2@L02`X801TH5P0=30X0BTU705UEE00P71/04Ph=010<2`0C3`h0510?01HB4@0E4A000P0C3`h0
2P0B3Pd040`901HB3`0E4@d04Ph;014=2P0A3@/04@d<018>3@0A3@d2010<3@03014=3P0B3Pl040X:
00804P`<00D040X:014;2`0B30`04P`<014;2`02010:2P0@014;2`0B30`03`T900l92@0B30`04`d=
010:2P0>20P03@L700l92@0A2`/04P`<014;2`0@2PX03`T9014;2`804P`<00<03`T900h8200@2PX0
1@0@2PX01P0910801`8000@0000D3``01`8001@?30803`X70P0@2`P00`0?2PL03PT500l:1@0200l:
10<03`X601805A0=01PB4P0H4Q801`8200@0000@2PT03PT600d81@0:1@803PT600l:1`0>2@H03`X7
010;200>2@H02`H300X50P0<1`@200h91P0500l:1`0>2@H03PT600d81@0>2@H00`0?2PL02@0>2@H0
3@P600h8200?2@T03@L700/51@0=1`L03PP800`61P0200/51@0600d71`0>20P030D501061`0:0@80
40H70P0C2@X00`0B20T04@L8014720030147200300l71@0>2@H03PT600803PT600L03`X700L2000C
3P/04@`900@00009104040/800805@/<00@04PP900l51P0=0`@03@<41@0@1PL00`0A1`P03`D60106
1`020147200400h41@0<0P<04@L80147208040H70P0?1@H01`0?1PT03@@701072P0D2`h04PT<00`3
1P0<1PP00P0>20X00`0<1PP03@L900h82P0Dooooo`006oooool00`0A4A<0410B00l?4@02010@4P07
00d=3`0A4A<04A4C02`/;P0B4Q@02`/=01PH6P0600h<3@0701DC500Z:2T040h?030^;`0:20T04@l@
010>3`05018@4@0=010>3`0<2P/03@/<014?400@3Pl03@`:014@3@0@3`/04a8>01LF4P0A40`030/7
018A3@0200l>2P06010?2`0?3PX03Pd901LF500E51805aHD0P0?3P`00`0<2`T040l=014@3P02014@
3P04010?3@0?3`d03Ph<00d=2`@03Ph<00H05aLE00H61@0B4Q002`/901TI5`0B4Pl2014@300D018A
3@0@3`/03`h:018A3@0?3PX030/701LF4P0H5a<04a8>014A3@0B4`h0414<00l@2`0@4@`04a@?014B
3@0>3`X03a0;018C3P0D5A0201<D3`0@014B3@0@4@`03a0;00h?2P0@4@`06Q/F05AED00J6aH061TD
00/<1`0?40/0414<018C3P0E5Q404A8=010A30<04a@?01h0414<014B3@0E5Q40410<01<E4`0@4Q40
2``<01@F5P0D5Q@03Q0=01<E4`0@4@h030h901<E400>40/0418=01LG5@071`L0410@00d=3@0A4A40
30`<00/;2`0l?3`0a/K604];B`0A4A406ATI014@3P0@3`d200l>3003010?3@0A40h03`h<00804Q4?
00H04A0>018A3`0D4a403`l=014A3`0B4Q02014A3`0X01@D4P0>3P`03Ph<01<C4@0E5A<04Q8@014A
3`0I6QD03a0;00d>2`0I6QD03Pl:018C3P0?40/05AHA018C3P0A4Pd0824L02d]:`0A4Q<02``>01@E
5P0Z;2/06adL01<E4`0A4a005ALD014C3`0?4@`04Q@?01<E400B4`h03a0;01@E400A4Pd05aPC02HW
8P0F5a8051D@01<D3`<04Q<>1`0C50l07@0A4Pd04Q<>01<D3`0E5Q4051HB01DG500@4Pl05ALD01LI
5P0@4Pl051HC01HH5@0A4a004aDB014C400C5A806adJ018D4@0E5a@06Q`I04a>B`0N81d05QPE00d?
300I6aP04aDB01HH5@0H6QL04QDA00@05AXD01P08RLQ03Pm=`0A5Q005Q/E01/P6P0L8A/05a`G020V
900D6QX07R@T01lU9@0E6a/061hN018H600U:b/07B<S028X:00J820061hN01hW9@0I8R005b0N01TR
800H8Ah201XS80806B8O04d072DR01dV8P0L9B007bHO01TP600Q:28082TU028[:00M9RD08bd/01/U
900Q;BP08RlW024^9@0W=2X082`W02Hd<00W=S808c8_02<b<00X>3L0:CTh0393@P0fB4P08S@d02Tk
>`0X>SX08cLf0355A00`A4<0<TI70355AP0oDe@0UjZ^03a?D`0jCE40=dY@03=6C00fBDl0>4]?03I9
C00eBDX0=TY903]?CP0nDU40?51?03mCE01>HFH0J7^205=UKP1;GVH0E6E]055RJP1DIFd0@E9I059U
J`1;GV@0BUeQ05EZK@1HKG00CfAU04eUI@1EK6d0DFAY05IYK`1KKW@0EfY^05=VJP1GJfd0FFe^05Q/
J`1JKVd0FFe/05M[JP1IKF`0Ffe_05a^L00206EgN@0>061bM01UMgT0KGn106]mO`1`PX@0LXB60763
Q@1dQXP0O8jB07>5R@1eQh/0NH^?07j=TP23TIH208FBV00S08JBV02:UI/0SYVO09:MX`2BW:<0UIjU
09VRZ@2LYJ`0WjJ^0:>Z/P2X[kL0ZJff0:N[]02Z[[L0[[6j0;:d_`2o`Ld0_/3<0;6c_`2e]/80^KW5
0;Vha@2f]<40^KO40<2mbP2f//00`[k<0>?Ok@3Fe>40`;k;0;fkb031_l`0_[c90;bja`2i]l@00P2g
]L801@2f]<40];>o0;>c_@2`/k`0[[6j0080[k:i00<0[K2g0:^^/`2Y[;400`2WZjh00`2UZJ`0XZFZ
0::UZP030:>VZ`0R0:6VZP2LY:L0Vj>V09ZRY@2FX:80UInQ09BNX02@Vih0SYVL08bGV@2;UiP0RYJF
08>?S01iQX00N8Em06UfK01LJEh0F6IH04aJC01FI5L0EfIJ05][H01JJUl0EfQM05a]H`1KK680Gg9X
05Y^I@1AIE`0D6AL05Q[I@1EJV<0DfQQ04aQFP80BUmH00<0A5UB03mDC@0kD4T00P0hCDH03`0fBd@0
<DHo03U<AP0gBT@0>4]503a=A`0iBT@0<d@n03=2?@0Y>3<0HG1[02lk=`0X=300:STd02Tj=00202`m
=`0402dn>00b@cd0=TM102Hg<@80:CXd01409SLa01`]9`0X>C<08c8_02Th=@0X=c@08c8_02Da;`0W
<c4092h]028/:`0P:RT07RLV01lX9`0Q:RL082XQ01XT700201`V7P0401dV8@0R:bH0;3D`02/d<@80
7RLT02L07BHS02</:00N8ah092TS01hS7@0I7QP0724K024V800K81X06QlI028W8P0n@cd05Q/E01/P
6`0F6aL07b@P01HK5`0K81`09BXV01LL600P9B406QlK01TN6P0N8al0<cPd01<H500H7AT06QlK01<H
500J7a/08BHR01/P700A5Q807B8N01PM6@0B5a<03A8>01HI5`0A4A400P0G5aL0200N7Qh07AdM01@D
500E5AD05aLG01@D500G5aL0=cLg0`0C4a<201@D500:01HF5P0D51@04A4A01PH600F5QH03@d=01XJ
6P0F5A<051<A018A3`8051<A00P04Q4?00h=2`0H5aD04Q4?01HE4`0;2PT07A`J03Da<0804`l>0140
2@D400P4100F4Q40510?01DA400D40l04Ph=014=300B3P/0510=01<@300A3@X040`9010<2P0@30/0
4Ph=014=3@02010<3@03014=3P0B3Pl040X:00804P`<00<040X:014;2`0B30`00P0B30`2014;2`80
4P`<00h03PP8018<300A2`/03`T9010:2P0>20P04@/;00l92@0>20P040X:018<300D3Ph040X:014;
2`804P`<00<040X:00l92@0@2PX01@0@2PX01@0?2PL05a8?01dH5@0U81d03@P600<03`X70P0@2`P0
0`0?2PL03PT500l:1@0200l:10<03`X600/04`h;02/V9P0G4A40@cdm02HP800C3@`040/800l:1`0;
1P<03PT600l:1`0200`7100400h91P0@2`P03`X700l:1`<03PT600<03`X700h91P0>2@H00P0=20D0
1`0>2@H03`X700h91P0=20D03PT700h8200?2@T00P0D3Ph00`0?2@T03@L7010:2P04010:2P030149
2P0I3a004@L800804`T:00<03`D601061`0A1`P00`0B20T0100A1`P04PX800h91P0>2@H200l:1`09
00h91P0;1P@03`X7010;200>2@H03`X700/71@0H3Pl05@/<00@04PP9200@1PL0100?1@H040H70188
2@0C2@X20147208040H700h03`D600h51P0>2@/03PT:00d82P0=1`T03`T;010:300?1PT04@P;0107
2P0>1@P03`D801062QCooooo000Kooooo`0<01@D5P0A4A<03Ph@010@4P0A4A<0410B01HF600@4180
8B4S01<C5@0=3@l04a<E1P0>30d0500J61T03`h>01lM7P0100009B<T00H41@0B414040h?014?400D
4Q<040h?00d;300?3@h03P`=00l=3P0@3Pl03`d>00h=2`0?3P/03`h:0P0@3`/01@0?3PX03Pd9018A
3@0>3@T03@`800803`h:00P03Pd900d<2P0I61H08B0N00d<2P0?3P`02PT7010?3@804Q4?01`04a8@
014@3P0@3`d03Ph<00d=2`0?3`d04A4?00l?3@092@L06ATG01hN700<30X0JVYX0:6QW`0G5Q<04A0<
00l>2P0>3@T04A0<01DD400>3@X02`X601LF4P0I61@03@`800h=2@0C4`l0414<0P0>3`X0100@4@`0
4Q<>01DF4@0A4Pd200`=20803a0;0240414<00h?2P0C50l0414<00X;1P0;30L00@8002PY900;30L0
51D@00`=200C50l05QLB018C3P0?40/051D@01HG4P0B4`h05AHA01HG4P0B4`h0414<01<D3`0@4@`0
3a0;00X;1P0H61D04A4?010A300A4Pd0004001hO6@0<3@L00P0B4`d03@0@4@`05aLE04U9B@0K6a/0
5ADE00d=3@0A4A4071`L01HF5P1BDU808B4Q01<C4`0;2`/00P0D4a42018A3`8051<A00P040l=018A
3`0B4@l04A0>018A3`0D4a403`l=014A3`804Q8@02004a<A01HF500?3`d0410>01XJ600M7A/051@B
010@3P0B4`h03@h901@E400P8A`030d800d>2@0I6QD05AHA010A300B4`h07QlJ02LW9@0?41<02P/=
00/<3P0E5QP03a4@014C4P0C5A@020X700d?300C5A803@l:00T;1P80414<00D04A8=01<D3`0E5Q40
5aPC018C3P03014B3@03018C3P0C50l04Q<>00<04A8=0P0B4`h02`0G61<051D@018C3P0C50l05AHA
01@F4P0D5Q<030h;00lA3P0F61D04aDB00806A/H00d04Q@A01<E4P0@4Pl05QPE02PZ9`0R92402@/8
01LI5P041P<06adJ02HX9@0<3P/09BLT00805ALD00P06adJ01TM6@0K81`04aPD01HK5`0J7a/05a`H
01`Q7@807b@P03H04aPD01`Q7@0I7QX0318@020V9P1dNWX051XJ01LM7@0L8R8051XJ01XP800D6QX0
41HF01PN7P0N92@06B8O01DN6@0G81/06b@O01TR7@0J8b006b@Q01XS800J8b8072DT01dV9@0K9280
92dX01LQ6@0L9B00:C8_03@m>P0a>c/07bTZ01dY9`0O:bL082lX02De:`0O;bH08Rh/02<`<00P;Rh0
7bd]028a<@0V=SH052@T06YkO028VY`0?e5C028d=P0a@dD09SXi02e1@00/@3l203=7B00903U=CP1:
GF40<dI:045DF013EU`0>TeC04YMH`0lCe<0>dm@0080>De>0580>dm@03a@D@0kCe00?4mC051SJ@1F
JG00C5mV05MZL@1JKG@0D6=Y04EHGP1;GV@0D6=Y04YMH`1;GV@0Cf9V05AWJ`1CJ6/0DVMZ05I[KP1?
HVH0E6M[05Q[K`1GJVh0DfMX05AXJ@1DJ6P0Ef]Z059VI@1IKF/0Gg=a05]_KP1RM7H0HG=e06IhNP1X
NW`0JWan06n1P`1eQhT0K7j006j0PP1`PX@0LXB607F7R@2BY:P0P8nD07b;T01mS940PHjD08FBV026
TiT0RYFK08^FW02=V9h0TIbR09BNY@2GWZH0VZ6Y09nV[P2QZ;00Y:Ra0:JZ/`2^/[/0/KBm0:f`^@2`
/k`0];Bn0;2`^`2^[[X0/;2l0;Bd`02i]l@0_;[70;fja`2m^LL0_[[80;njb035_ld0b/CB0=KBh03A
cM/0`;c:0P2l^<H0202k]lD0^[K40;Jb`02n^/P0`[k<0;^ga@2d/Kh0/k>m0P2b/[`01P2c/k/0];Bl
0;>c^`2`/KH0[Jjc0:Z[[`80ZJZ^00<0YjR/0:BW[02UZ:d00P2UZ:d07@2SYZ/0XJJZ09jVZ@2NYZT0
WJFX09VSY@2GXJ<0UInQ092KW`2AW:00T9^N08RCU@22SXh0P8b907B1NP1ePWT0IG=W05UWF01KJEP0
DEm>05]YG01OKF<0Hg=X05i^I01GIed0FV]Q05a]I@1LKfH0EVYQ0080D6=M00H0EVUS05EXHP1@Hed0
AeYD04QKE@1>HE/204YME`0B049EC`0nDD/0?e9<03e@BP0gBT@0=DI003=4?P0fAd40>TU403E4?`0[
>SD0:3Lb02Lf<@0kBTD05bHQ020_:P0fAD00:SXg0P0W=c@04P0/?3T0;cll02lo?00]?CX0=TI302lo
?00Z>SL07BdZ02@d<@0R<B`093<^02He<00U=2l0930/02<_:`0T;b/08bhZ020[9`807bPU00/08BXU
01lY800L9Qh07BLO01TS6`0F7aX06R<N02D^:@0M9R<051dJ010I5P0201<L6@08020U8@0N8al07B8N
01/P700J7a/05AXF01XO6`0Q9R8201/P700W01HK5`0R9b<06b0L01PM6@0B5a<06QlK02@Y9@0I7QX0
9R/W010E4@0J7a/07b@P03m4@00S:2@05Q/G01TN6P0C61@07B8N02DZ9P0A5Q804aPD01XO6`0?5100
51TE01`Q7@0=40h05aLG01XJ6P0I6AT09RHV02<S8`0E5AD04Q8B014A4@0@41008R8R06IVIP0D51@0
4a<C00804Q8B01004a<C01DE5@0M7Ad04Q8B00d=3@0M7Ad08B4Q01<C4`0E51805QDC01PG5@0E5180
4a8@018A3`0G5Q@06QTG0P0D4a402@0E51801`H500l;2P0C3`h07ATH01LC4P0C3`h081`K010<2`02
01<?3P8040`;0P0C3``0100B3`/04@d:014=2P0B3P`2018>3@06014=3@0@30d040`=014=3P0B3Pl0
40X:0P0B30`01@0@2PX04@/;018<300C3@d04P`<00804@/;00P04P`<01<=3@0>20P05@l?010:2P0>
20P04@/;00l92@8040X:00<03`T9010:2P0A2`/00P0A2`/01@0@2PX03`T9010:2P0@2PX04@/;00H0
40X:00H06A@A00`7100>2@H02PD401<>2`0D3``200l:1`8040/800<03`X700h91@0?2PD00P0?2P@3
00l:1P0@00d81`0H4Q805@l?02PR8P0H4Q802P@3010;200A30T030L400h91P0@2`P05A0=01@?300=
20D02PD200d81@@03PT600<03`X700h91P0>2@H00`0=20D02@0>2@H03@P500d81@0=1`H03PP800l9
2@0B30`04@/;00h8200300d71`0B00h8200=1`L03@L700/3100C2@X03P@501882@0C2@X04@L800h4
1@0?1@H04PP901<92P0B20T04@L801<:2`0?2@T03@L70P0?2@T03@0<1PH050h>00d71`0<1PH02`D5
00L10@0E3`l04@L800h41@0;0@803P@501061`0A1`P00`0@1PL00`0?1@H03P@500h41@0201472004
01061`0A1`P04PP901<92P804@L80P0@1PL03P0?1@H03PD600T51P0:20T040h?01HB4`0@2`d01`43
00l62@0A1`/04@H:00l4200@10P04@D95?ooool001_ooooo00`05QHH014A4`0>3Q003`lA018B500A
4A<05QHH00h>40092@/04A4C00h>40071`T600l=3P0;00H41@0C4A800@0001DC50071@H05aDF00l=
3P0<2P/040h?01LE5P0D4Q<00P0?3@h0200D4Q<04a4B00h<3@0?3@h04A0>00h=2P0?3PX03Pd90P0=
30P0100?3PX04Q4=00h=2@0=30P200l>2P0500h=2@0;2PP05A@B01`K6@071P@00P0B4@l0100>3@/0
3`h<010?3@0A40h200l>300H00d=2`0<30X0410>018B400@40h04Q8@00l?3@0000004A4?01lO7@18
B4H05QDB014@300=30P02`X601<B3P0K6QH08b8N01LF4P0<2`L03Pd9018A3@0A40`0410<0`0>3`X0
1@0?40/04A8=01hO6P0Q8Qd05aPC0080414<01@04Q<>010A300?40/06Q/F01TJ5@0A4Pd04Q<>010A
300<3@P04a@?01DF4@0D5A004Q<>010A300<3@P04a@?02DV8@0W:2<04a@?00d>2@804A8=01d03@h9
010A300B4`h0414<010A2`0=3PT0414<00d>200F5a407AhH0083000G618000400083000A4Pd051@B
08j>SP0V9RH04Q8B01@D500;2`/03@d=01dM7@0E5AD051@D018B4P0:2PX051<A01<B4002018A3`09
01<B400D4a404A0>01<B400D4a404Q4?01<B400E51803@d;0080410>00h03`l=010@3P0B4Q005QHD
010@3P0D51805ADC014A3`0C4a403a0;01HG4P000@003@h901PI50803Pl:01T030d800h?2P0C50l0
4a@?014A3`0A4QD05aPJ01@E5`0C51H02`d<018D4`0C5A@061XG01DG500B51404A<>00lA300A4Pd0
4Q<>00l@2`0C50l04Q<>00d>2@0C50l04A8=00@0414<00<04Q<>014B3@0@4@`00P0A4Pd00`0B4`h0
6AXE01DF4@0201<D3`0^01@E400G61@061XG010B3`0B51405ALD00lA3P0C5A805QPE01DG500J71T0
3Q0=00`>2`0I6aP02`d:01/M6P0H6QL06Q`I00h@3@0K7AX01@L402HX9@0F61D04Q@A01@F4`0A5A40
5AXF018G4`0H7AT04QLC00hC3`0F6aL07B8N01XO6`0F6aL07R<O018G4`0M8b<041HF02D[:`0L8R80
5A/K01PN7P0C6AT051XJ01hT90805Q`L00X06AlN01PQ7P0D7AP0624L01dV8@0K91l06b@Q01`U8P0K
92406R<R0P0L9B@0800K9280FF9M03a6?P0P:B@06B8O020Z:@0N:2T07b/[02@`<00R;R/09C@_02dl
=@0R<RT0:3@b028_;`0N;2`08Bl_02Dd=00V=SH0<T9202m0@@0dATP06R`^02do@P0/?T00:Sho02Tm
?00W>cX0=4Q903=7B00aADH0<dI:0P0dAd/01@0jCE<0<DA:03Q;C`0lCe<0?51A0080>dm@00d0?E5B
03e@E014Ee/0?E1F04AGG@0hBe80@5=J06UlP`1;GV@0F6]a04]NI017FV00AUUO0080C5mU01T0AeYN
04mRIP1EJVd0DfQ[059WJP1GJVh0E6M[05a_L`1HJfh0EFUZ05a`L@1IKF`0GG5`05IZJ@1PM780K81n
06EiN01PLW@0I7Ih069dMP1ZO7h0L8:406eoP@27VI/0MXR:0080LXB601X0M8J807R:S01nT9@0N8N<
07f<T@23TYL0Q96G08FBV028UI/0SYVO096LXP2BWJ<0TijT09JNYP2HWjL0Vj:Z0:2W[`2SZ[80YJVb
0:>W/02[[[L0[k:k0:^^]`2a/K/0/k>m0;Ng`P80][K201d0_;_70;Vga02g]L80_;W60<S4dP36`]00
`K_90=G?g@3Bc=X0`Kc:0;nkb@31_L/0aL7?0;nkb@2k]lD0^[K40;^ga@39aM<0dLgK0<O3d@2k^<H0
/k6l0;6a^`2b/[`0];Bl0;Jf_P2e]Kd0[Jjc0:^//@020:RY[@030:VZ[P2WZ:`0YJR]0080YZV^00<0
YJR]0:>VZ`2PYJT00P2OYjX06@2NYZT0VZBV09RRY02FX:80TIbR09BOY@2BWJ40QY6C07j:RP1mRHD0
Lh1g07B1M`1TLV@0EVAC05YYEP1?GD`0Hg5T05YXGP1RLVL0JWY`065aI`1BHeT0GVmW05U/H`1CIeh0
0P1BIEl205=VH00404ePFP14Ee40AUUC04mRG080CV5K00X0AEQB03mBC013EU00AEQB04=FD00eAT00
<T8l0391?00eA3l0<3lj0P0V=C00=@0W=S4062LR02Xi=00a@3/0>4M202`l>@0[>cP0;3`i02hn>`0_
?c`0;Shk02dm>P0a@Ch09CDb02@d<@0R<Rl0:SXg024`:`0R<B`093<^02He<00U<Bd08RhZ02D`;00T
;b/08B`X01lX9@0P:BH08R/V01/U700K9Ad07RPP01XT700H8A`06b@O01dV8@0O:2D08b`Y024Z9`0T
;BX07RLT02<X900I7QX0724M01lT800H7AT05AXF01LL600E6QH082DQ01PM6@0`=C405Q/G008061dI
02008RLS01/P700D6AD05Q/G02`a;@0E6QH08RLS01DJ5P0W;2P061dI01TN6P0M8Qh05AXF01dR7P0Q
9R806AhJ01<H500@5A406b0L00P=2@0J7a/04A<A01lO7`0I6AT04a<C01dM7@0E5AD06QXJ018B4P0D
51@05ADE00h>3P805QHF00H05ADE01<C4`0A4A404A4A01<C4`0>3Ph2014A4@0F010@400C4a<03Ph>
00l>300F5A<06QTG018A3`0=30X040l=01HE4`081`D03Pd;00d<2P0:2@L05QDC014=300C3`h02PH5
018>3@0C3`h04@d<00h:2@804Ph=0P0@30/201<?300701<?2`0B3P/04Ph;01@@3P0D40l04Ph=014=
3@02010<3@03014=3P0B3Pl040X:00804P`<00D040X:014;2`0B30`04`d=018<3002014;2`0:018<
300C3@d03PP801H@400A2`/03@L7014;2`0?2@T03PP8010:2P804P`<00P03`T900h8200B30`03`T9
00h8200?2@T04@/;018<30H040X:0P0>2@H0100L5a@03@T701@?300;1P<200l:1`8040/800<03`X7
00h91@0?2PD00P0?2P@300l:1P0B01<>2`04000050h>00l92@0>20P03PT700h91P0B3@X03@P500h9
1P0A30T091lL02TT8@0I51403`X7010;200A30T03`X70P0>2@H00`0?2PL03PT600h91P0300d81@09
00h91P0=20D03@P500X50`0;1@D03PP800/51@080P802P@400803PP80P0?2@T01@0>20P03@L700h6
1P0G3@h04@L800804`T:00d03`D600h41@0?1@H04PP901<92P0B20T04@P901<:2`0?2@T03@L700l9
2@0@2PX030H600802`D500X040X:00H0000:10@0BD=301L=3P0C2@X03P@501061`0B20T04@L80`0@
1PL00`0?1@H03P@500h41@0201<92P0401D;300D2P/04`T:01882@804@L80P0@1PL02`0?1@H03PD6
00/92P0?3Pl081hO02`X:@0S7R003PP:00l62@0A1`/04@H:008040@800<04@D9ooooooooool04_oo
ool001_ooooo0P0?3a40100@418020P:00d=3`0=3@l2014A4`80410B0P0?3a40200>30d040h?018@
4@0B414040h?00h<3@0A3a0040h?0P0>30d03`0?3@h040h?01HD5@19AdP06aTJ014?40091`P04a4B
00h<3@0A3a004Q0A014?400=2``030/900h=2P0200h=2@0400l>2P0@3`/040l;010?2`804Q4=03P0
4A0<010?2`0A40`03`h=01PG5@0=30X040l=014@3P0:2@L040l=018A3`0D4a404a8@010?3@0?3P`0
3@d;00`<2P0=3@/03`l=00h>300?3`d04A4?010@3P0?3`d03Ph<00l?3@0=30T05QDA01/J5P0B4@d0
3`h:014@300C4Ph04A0<00h=2@0?3PX04A0<010?2`0>3PX03a0;014B3@0B4`h04A8=00l@2`0>3`X0
3a0;00/<1`0A4Pd04Q<>010A300Q8Qd04a@?01@E400<3@P03Pl:014B3@804a@?00d04Q<>014B3@0A
4Pd04A8=00d>2@0@4@`03a0;051AC01LGEP04a@?010A300A4Pd0414<00803@h900D0414;00l@2P0?
40P04149010A2P02014B2P0301@E3`0B4`d0414;00804A8<00T03Pl:01@D4P0C4a<05ADE018B4P0<
30`03`l?00d=3@0C4a<00P0A4A40200G5aL06QXJ018A3`0C4Q004A0>00l>300B4@l05A@B1P0@3`d0
300<30X03`l=00h>300=3@/03`l=00h>300F5Q@04a<A010@3P0?3`d0410>014A3`804Q<>00@051D@
018C3P0D5A007AhI0P0B4`h05P0@4@`04A8=014B3@0@40h09BLW02l`<P0C5AD051HE010B4@0G6AL0
5ALC00d?300L7QX03a4;014C3P0C5A004A8=01HG4P0F5a@04A8=010A300C50l2014B3@05018C3P0D
5A005AHA01DF4@0D5A000P0B4`h0500C50l051D@01DF4@0K71P0824L018C3P0A4Pd05QLB01DG4`0G
6AH05ALD014C400@4Pl051HC01HH5@0A4a003a4>01PJ5`16B4D07R0M0P0F61D08`0D5Q<04aDB01DG
500F61D05aTF010B3`0G6AH06adJ010B3`0H6QL061`H01@I5@0E6QH05Q/G01LL600F6aL06QlK018G
4`0F6aL0;C8^01lT800G71P061hN01<I6@0a=cL0ATa<01`R8P0F71`05adM01`R8P0K8B406AlO01hT
900P9RH051dJ0080624L01d05b0K01XS7P0I8Ql05b0M01`U8P0O:2L06R<R01/T8`0W<2h0QHj903]4
?P0P:bL072HU024[:P0M:BT07b/[01XV9P0N;BX0:CPc01/Z900U=Bd08bl]02Ld=01FI6@0EfEU02Pg
=`0S<c<09cLg02/l?@0202Li>`0D02/m@00W>C/0;4100314@`0_@d80;d=40396A`0]@D80<DA803M:
CP0jCE40>TeC03U<DP0jCE40>De?03U=CP0kCe00?E1D03mBE`0nDEL2045DF`0G04IIH01=H6L0@5=J
05AWK@1AIVX0CfAW04YOHP19G600B5]Q04YMH`1FJFl0Gg9h06AgO@1FJFl0DFAZ05a_M@1EJ6`0F6a]
05]_L01GJf`0EFUY05U]K01KKfh00P1FJVP01@1OLg40Jgmm061dL`1UMgX0JWb00080K7j200<0KGn3
06n1Q@1cQHT00P1cQHT06@1fR8`0NXb@07^=T@1lRi00PY6F08nNX`20SI<0SibR08NCV@2>VIl0TIbR
09FOY@2GX:L0VZ>Z09ZPZP2f^/D0_l?>0:Z^^@2TYk80ZJ^g0;6c_`2a/Kd0];C00;Rg``2j^<D00P2k
^LH0302n_<T0`;k;0<6nc031_L/0`[k<0<Foc@36`<h0b<7@0<_3dP3:`]40bL7@0<O1c`80a<3>0180
aL7?0<C0cP33_ld0`[k<0<6mb`30_<X0_KW70;bhaP2k^<H0^KO20;Rh`P2i^L<0^;S00;Ng_`2e]Kd0
/;6f0:j_]02[[;020:VZ[P040:^//02XZk00YJR]0:BW[080YZV^0340XZN[09nWZP2OYjX0VZ:U09NQ
X`2IXjD0U9jP09FPY@2;UY/0SIRL086<S@1kQhH0O8R3071mM01[N6h0JgU[065_GP1CHTl0G6YI05MU
F@1OKV@0HW9X06YjL01KK6<0KWmg08VJTP1LKVL0CV5K059UH@1<Ge/0D6=O05IYH`1;GUP0DVEO05EX
HP1>HE/0D6=M04IID`10Ddd0>Te703mBC011E4h0=TM103E3?P0T<Bd0<Shj02Te<@0[=c<09c<_00<0
93<^01D0:3Lb030o>P0`?cX0<D4n02@d<@0c@d009cLd02Ti=P0U=C80;cll02Xj=`0^?S/0;3`i02Lg
=00Y>CH0:3Lb028a;00S<Rd08S4/02Da;@0Z=S800P0Q;2P0500S;RX08BXW01dV8`0P:B@072HN01hX
800Q:b<07bTQ01dV8@0Q:RD06b@O024Z9`0M9R<06b@Q01lX9@0P:BH06AhJ02<X900K81`04QLC0`0J
7a/06P0L8Ad07B8N01/P700J7a/07b@P07AiM@1_M7008bPT01@I5@0N8al06AhJ01/P700J7a/05a`H
01<H500F6aL07B8N01@I5@0K81`061dI018G4`0J7a/051TE01<H500F6aL061dI0P0A5Q806`0G6AL0
5ADE01HF5P0H61P04a<C01DE5@0F5QH04Q8B01HF5P0];Bd071`L01DE5@0A4A4051@D01TI6@0>3Ph0
6a/K018B4P0F5QH04a<C01@D500>3Ph0410@018B4P0A40h04Q4?01<B4002014@3P08018A3`0C4Q00
4Q4?014@3P0@3`d04A0>01<B400F4Q43018>3@0400l;2P0C3`h04@d<014=30804Ph=01L04`l>01<?
300E4@h04Ph:014=2P0C3``04`l=00l;2P0A3@`05A4A00`82@0H51D0510A07=_L02?RHT06aHF01LA
4@0?2@T05@l?01<=3@0A2`/050h>01<=3@02010:2P0F018<300G4A406A<C018<300@2PX04`d=00h8
200Y8b<04P`<01LA4@0C3@d04P`<00l92@0B30`0208202lY:@0K5QH040/;00l92@0@2PX03`T900h8
20803`T900<040X:00l:1`0?2PL00P0@2`P0100?2PL03PT600l:1`0?2PL200h91P0>00l:1`0A30P0
4@`801<>2P0<1`@06aHB07IaK@1`JfL05a8?00d71`0<1PH040X:00h8200<1`D200l:1`0=00`7100@
2`P04@`901@?300P6aP0<bh[02<N6`0H4a003@P700h91P0=20D03PT6010;200300l:1`D03PT600L0
3@P600h8200@2PX03`T900d71`0>20P03`T900D03@L700@03`L70147200B20T04PP9200A1`P04P0D
2``030H600h8200;1@D030H600l92@0@2PX02@@401PB4P0A2`/020<305mIF@0L4Q<06@l@01882@0>
10D03`D601<92PH04PP91@0@1PL04`0?1@H060h?01892P0<0`@03P@50147200A20T02@H700h<3@2B
T940iN7R03Td=P0=1`T02@4301H<3`0B1`/03`D701862P0<0@@05?ooool001_ooooo00<0CdmA00X:
300G5aT00P0>3Q00100J6Q`04A4C010@4P0@418300l?4@0300h<3@0?3@h03`d>00803`d>100>30d0
400@3Pl04@l@018@4@0@3Pl0:2HW018@4@0D4Q<02PP9018@4@0<2P/03P`=010>3`0A3a0040h?00l>
300?3P/200l>2P<040l;00`04A0<00h=2@0;2PH02`X6010?2`0D4`l01PD300`;2@071P@03Pd;01<B
400?3P`5018A3`0600l>300:2PP02PX800h>300A4@l0410>0P0?3`d200h>300<00l?3@0@40h040l<
01<B3P0D4`l03`h:010?2`0A40`03`h:010?2`0A40`040l;0P0>3@T04P0?3`X03a0;014B3@0B4`h0
4A8=00l@2`0D5A003a0;00H70P0:2`H03Pl:00d>2@0C50l02``700h?2P0=3PT03a0;010A30<04Q<>
0`0A4Pd02@0K71L01`P301LH4`0:2`H07b0K01LH4`0>3`X03a0;010A300200h?2P03014B3@0A40/0
4A4900804Q8:00@04a<;01<B3@0G5Q4051<>0P0>3@T03`0@3`/04A0=01`L700E5AD0410@00l?3`0<
30`03Ph>01DE5@0A4A404a<C00h>3P0H61P0?Cdm010?3@0201LF500301<B400B4@l05aHD00H04Q4?
00H07alM01PH5P0G5aD04A4?00T91`0B4Q06014A3`0N01@E400?40/03Pl:00d>2@0?40/061TD014B
3@0>3`X04A8=01@E400>3`X02@X501HH5@0F61L04aDB01DG500C5A804Q@?010C3@0C5A0071lH018E
3@0D5a004A@=01@E400L7AP0GUmJ028S7P0C50l06AXE100D5A0201DF4@<04a@?00T04Q<>010A300?
40/0=cPc01<D3`0B4`h03@h901LH4`0A4`l00P0E5a@02`0B51403a4>014C400C5A8061XG010B3`0G
6AH0OX1m02LY9P0H6QL051HC00804A<@00D051HC01LI5P0J71T04aDB01HH5@0201PJ5`0601/M6P0E
61H04aLF014E500@51<04QHE0P0E6AP05@0C5aH061`K028V9@0M8B0041@C01XP800G7Ad08BLW02dc
<`0E6a/06AlO010F5P0I7al07R@T01/Q8@0M8b<08BLW01XS800L9B80624N01HO700301XS808072DR
01L0624N01LP7@0I8Ql092lY01HQ6`0G8Qh09c<a03<o?`0/=cT09C<d02Hd=00Q;bh07c0Z01h_:@0Z
>S80:cLc028_;@1DHf00DV5N024`;P0a@D00:SXi02dn?@0202Tk>`0302/m?@0W>CT0;40o0080<TI5
03h0<TI703A8B@0_@d@0>TeA03Q;C`0iC500>TeC03Q;D@0bADT0=TY;03Q<C00jCTl0>diB03a?EP0l
CUP0BE]U041BG00jC5H0>4]B05=VK01GJW00CV=V04YPH@17G5d0B5eP04aOH`1>HFD0DfI/05QYL01N
KgH0FFYb05MXL01OL7L0FVi`05Q/K@1LL740G71_05Q/J`1JKVd0EVYX06EiM`1WNgT0GgA_06EjM@1P
M780Jgf006j0Q01_PHD0KX2406n1Q@1`PXH0M8J:07F7R`1fR8`0N8Z>07^=T@1mSi<0PY2F092MX`2o
c=80RIJL086<TP80UZ6W0100VZ>Z09bU[02LYJ`0WjJ^09fR[02WZKH0ZJ^h0:RZ]`2b/Kl0`L3>0<O5
d`2f]<80]kG30;Zga@2n^/T0`;c;0P30_<X03033_ld0aKo=0<Bnc035_ld0b<3?0<[2d@3=`]80clCD
0<k3d`3=`]80bL;A0<S2d080bL?A00<0al7?0<K0cP35_ld00P34_/`00`33_L/0`[c:0<6lbP020;fk
aP070;^ia02i^<00^KS00;Vh`02i^;h0][Fk0:n^/`020:^Z[`0V0:j^/P2VZJh0Z:^`0:V//@2UZ:d0
Y:N/0:J[[`2LY:L0X:R[09jVZ@2FX:80UInQ096KW@2=V9X0RYFG08RCU01nRXP0PHf907B0N`1aOWD0
F6EK061^H01VM6<0BeU8061^G`1PKF<0H6iU05][H@1OKVL0GViW07R9P@2W^;80JWag05AWH`1NLFd0
EfYV04YMF@1GJ68204mPFP1204eNF01@HE/0Gg1Z049CC@10DD/0>T]503U:A00dACl0:3Lb030k=`0[
=S80:C@`02Pc;`0b?CT06bLS02Hb;P0Q;RX093<^02/j=@0_?ST0;3/f01l_;@0V=SD0:c/j0392@@0_
?ch0<T9102dm?00[>cX0;Shm02`l>`0V=SD09CDb02He;`0T<b`09cH_02Dd;@0T<BX09S</02<^:00Q
;2H08bhX028[9P0N9b8082TT01DO5`0F81P06B<K01LQ6@0H8A`07BHQ01XS7P0M9R<07bPU01`U8P0M
9R<08R/X01lS8P0?4a804ADD01XN7@0L81l06AdL01hR8@0K7ah06QhM0P0K7ah0200F6aP0?D8n030e
<@0H7AT051TE024V8P0L8Ad061dI0P0F6aL201PM6@0=01LL600C61@0;C8^02db;P0730P03Q<?01<H
500B5a<051TE01LL600B5a<04aPD01PK6@0201PH600F01/K6`0E5AD051@D01LG5`0@410061PH03/k
>`0^;Rh04Q8B01LG5`0T92@0;Bd]01XJ6P0H61P05aLG00L71`0J6QX02`/;01hN7P0@41004A4A014@
3P804Q4?0P0?3P`00`0B4@l040l=014@3P02018A3`804A0>00L03@T801<?3P0M6AP06ADD010<2`0B
3Pd04@d<00<04Ph=01D04`l>01<?300D40d04Pl;014=2P0C3``04Ph<010<2`0E4A00510@00T51P0:
1PL03`/<03Da<P0l=SH02P@401H@400E3`l08A/K00h8200?2@T00P0B30`0600@2PX04@/;01<=3@0=
1`L03`T900d71`0>20P04`d=018<300Y8b<04P`<01<=3@0A2`/05a4A01H@400?2@T040X:04@n?P0[
9BD07QPH01<=3@0@2PX03`T900h820803`T900<040X:00l:1`0?2PL00P0@2`P04@0?2PL03PT600h9
1P0<1`@03PT601<>2`0A30T03PT500h9100:1@007QTC01/F4P3RgMT0]:n[01dH5@0@2PX030H60080
3@L700@03`T801<>2`0B3@X03PT60P0@2`P01`0A30T03`X700D0000L5aD0AT4n020K600>2@H00P0=
20D0100>2@H03@P500`7100=20D500h91P0600l9200?2@T03`T9018<300A2`/03`T91P0=1`L0100?
1`L04@L801882@0B20T80147200B00/21@0H4Q@050h@01D?4@0:10H05Q0B00H00P0B30h03`T;00h8
2P0I4aD030L800d3100>10D04@L801882@0A1`P040H71`0B20T20147200E01061`0?1@H03`D600L0
000@1PL0718C00h41@0A1`P01P00014=3P0;1`P08alP04I0@P0G4A<04`d?01@;3P0=10L02`8500X1
100>0`L06@hB01Cooooo000Kooooo`0601LG6@0=3@l0DE5C01@D5P0A4A<000020P0@418300l?4@03
00h>400?3@h03P`=00803@/<00<03P`=00l=3P0>30d00P0>30d2010>3`09014?40081PL02@L800L5
1P0H5QL03@/<010>3`0=2``03`d>00<040h?00<03`h<010?300@3`/0100@3`/0200A40`03Pd900`;
1`0;2PH040l;01<B3P0E51804Q4?0P0>3@/02`0@3`d03@`:010?3@0?3P`03Pd;00l>300@3`d03`h<
00`<2P0;2`T03Ph<0080410>00X03`l=00h>300>3P`03`l=010@3P0A4@l04Q4>014@300@3`/03`h:
0P0@3`/0100>3@T04A0<01@C3`0B4@d200h=2@0A010@300@4@`04A8=014B3@0@4@`03a0;00h?2P0A
4Pd07QlJ01`M600<3@P03Pl:014B3@0<3@P03a0;010A300A4Pd01P0@4@`02P0?40/06Q/F0042000B
4`h04A8=02<T7`0<3@T03@h900h?2P0?40/200h?2P03018C3@0@3`X0410800<0410800/040l:01HE
400C4Ph03`h:00l>300A40h04A0?01DE5@0>3Ph03@d=018B4P02014A4@0<00l?3`0C4a<05QHF010@
400B4Q80:2PX00h=2`0G5Q@06APF01@C4@0A40h05QDC1P0A40h02019BDL08B4O01@D4P0E5A<030`:
00h>300?3`d04A4?0`0B4Q002`0A4@l030d8010A300H6A@05aPC00h?2P0<3@P0414<00h?2P0B4`h0
4a@?00804A8=0180418=00lA3P0J71L04Q@@00X<1`0520404QD=01`O600N8AP04QD;01LJ4@0D5`h0
51D?00h?2P18BD@061TD00/<1`0I6QD401@E40804a@?00`0414<018C3P0C50l051D@018C3P0A4Pd0
?Chi01@E400G61<03a0;01DF4@0@4Ph201@F4`0901<E4P0@4Pl03a4>01@F4`0;3@X06A/H01@F4`0a
<c0030h;00804Q@A00`04A<@01<E4P0A4a004aDB01HH5@0@4Pl05QPE01LI5P0H6QL06Q`I01<F500C
5aH2018F5@0<01<G5P0D61L06AdL01`P7`0G6aX04ADD01XN7@0M8B003A<C02H/;00A5aL020h>0P0J
82002P0C6AT0728R024W9`0J82005Q`L01XP800T;B`09Bh]01hW9@0H8B0201XS800O01TR7`0J8b00
6b@P01hW900N9b8072DP01/V800I91h09S0^02Xf=P0G8b<0BEAF0390@@0Q;c008S0`00lO700E9R00
8S<[01/W8`0Z>3<0;3/f02Th=@0X=c@093@c02Ti>00[?3/0:cdm02`n?P0^@400;Clo02/o?P020396
A@1;03=7B00dB4T0;d=403M:CP0iC500>4]?03M:D00fBDl0=4M;03I:B`0kCdl0?e9F041CF@12E5d0
A5IP04UKI@0lCUP0CEmY041CFP14Eeh0D6EX04aQHP17GEh0AEYK04UNH@1?HVH0D6=W051SJ@1BHfX0
EfQ_05MXL01EIVh0FV]b05]_L@1GJf`0Ffm`05eaL01JKVd0FFe/05M[J@1YOG/0KH5o061eL01TNG@0
HWId06QjO@1/OX80KX2406n1Q@1bQ8P0M8J:07J8S01gRHd0NH^?07^=T@1mSi<0OY2D08JCV@2CX:H0
^LK<08jKX@25T9H0Uj:X09JQY`2JXjX0W:F/09fV[@2PYjl0YZVd0:^]^P2Z[;T0/;6n0:f/^P2`[kd0
_Kc:0080^;K400<0^kS60;nkbP32_/d00P33_ld20<S2d0090<O1c`39`M00bl?B0<g5e03@aMD0dLKF
0=35e@3?a=@0cLCC00<0blGC00<0bL?A0<S2d036`<h00`35_ld01@34_/`0`kk<0<6nb@2n_<L0^kW4
0080^KS000P0^[W10;Zi_`2f]K/0[jjc0:b[/02][;40/K6f0:f^/`80Zjjc03l0Z:^`0:JY[P2UZZh0
WJFX0:>[[P2RZZd0Uj6S09BNX02AVid0RYJF08nKV@2=VIL0OXZ608FBR`1cP7P0FVMM04aIC`2MZih0
a]C506QfIP1KJEX0HVmU05m^I01OKfD0H6mX05][H`1RLf/0IGI`05QZI@1LKf/0GG1/05Q[I`1LKf/0
Gg1Z05AUG`1=GUP0BU]E04UJE01CI5h0@55;03a=A`0fAd40<d@n02ho>@0W=S40;3Lc02D^:`0[=S80
9c8^028]:@0Z=S807b/W01l]:00X=c80;C`g02`k=P0[>SD09cLf03a<B`0X>3L0=DE402<c<P0`@3l0
0P0/?3/08P0^?Sd0;Cdl02Hf=@0S<c0093<]028a:P0T<b`08S4Z024^9`0T<BX082/U01dX8P0P:bD0
82TT01`U800M9al06bDM01XT700M9al072HN01hW8P0T;BP07BHQ01hW900Q:RL07RLT01`U8P0S;2T0
720O02da<00S9bH04aLF01XN7@0M8B02024U900901dQ800J7Qd06alN020T8P083@T05AXF01hS7`0F
6aL03A8>008061dI0P0K81`02P0J7a/05Q/G018G4`0V:bL0E5UE04Q=B@0C61@0724M01XO6`0C61@2
01@I5@804QLC01005aTG01HF5P0F5QH06a/K01LG5`0E5AD0410@018B4P0D51@0820P01LG5`0C4a<0
4A4A01TI6@0Q8B40410@0P0?3`l02P1fMWH0KFe]00l?3`0K6a/03@d=01@D500@3`d04Q4?01DD4P0C
4Q02018A3`0<00l>300@3`d04a8@01<B400B4@l040l=010<2`0E4A007a/J01dI600D40l04`l>1@0B
3Pd00`0B3P/04`l<01<?2`02018>2`0?018>300A3@`030P7018>3P0<20T03@T:01LC500300001P00
018<300E3`l0100001XD500B30`03`T900<04@/;00@04P`<01<=3@0@2PX04@/;0P0>20P0200@2PX0
3`T900d71`080`<0618B01LA4@0D3Ph03@L70P0@2PX01`0E3`l05a4A03Xd=00C3@d040X:00l92@0>
20P00P0?2@T00`0@2PX03`X700l:1`02010;200F00l:1`0>2@H03`X700`7100?2PL05Q4>018=2P0=
20@020@101lJ500<1`4040/704E0?016@Cd05A0=00h8200<1PH03PP8010:2P0C3@`05a8?01D@3@80
3PT600h03@P500`7100400008ahK01<>3@0Q71T0;bXW014<2@0>2@H03`X700h91P0=20D030L400d8
1@D03PT600H04@/:014;2`0A2`/050h>01D?3`0A2`/600h8200400l7200A1`P04PP901882@P04@L8
01808APK02DO8@080`@04`d?00P2100:1@H04`d?01@>400<1PP0208400h82P0@2P`0308300d3100@
1PL04PP90147200@1PL80147200F01061`0?1@H03P@500d3100A1`P03`H702<I6P0>10D04PP901XA
4P0;1@L02P@600@0000;1@L02@<500/51`0B2@`02`8501@;3P0E30l03PD801P?4QCooooo000Koooo
o`0600h>400H61X0GEeO02DU9`0@418061PJ0P0@418200l?4@803Ph@00<03`d>00h<3@0>30d00P0>
30d03P0?3@h040h?014?400@3Pl03`d>00h<3@0=2``04Q0A014?400F51D040h?00X82@0C4A804@l@
0P0@3Pl0100?3@h03P`=00d<2P0@3``5010?2`0F00l>2P0B4@d04Q4=010?2`0?3PX040l;01<B4007
1P@02`X800d<2P0C4Q005A@B018A3`0?3P`03Pd;00l>300A40h04Q4?00l?3@0>3P`03`l=010@3P80
3Ph<00l03`l=00h>300?3`d0410>014A3`0C4Pl040l;00l>2P0A40`040l;00l>2P0@3`/04a8>01DD
400C4Ph00P0@3`/0100B4Pd04Q<>014B3@0A4Pd200l@2`0<01<D3`0:2`H04Q<>018C3P0<3@P04a@?
00l@2`0H6A@051D@01HG4P0E5Q40414<1@0>3`X200l@2`0401HG4P0?40/0414<018C3P803Pl:00H0
3a0;010A300>3`X03Pl:018C3@0B4@`2018B2P804A0;01P04A0<018A3P0A40h04A0?01<A4P0C4A<0
3`d?00h>3P0;2`/03`l?01DE5@0B4Q804A4A00d=3@0F5QH0410@00h>3P0D51@03@d=00d<2P0C4Q00
5QDC01<B400@3`d7014@3P0802LW9@0B4Q00410>014A3`0=3@/05ADC00l?3@0@40h3018B400301<C
4@0C50l051D@00807AhI01`051D@010A300A4Pd04a@?01DF4@0@4@`05QLB028S7P0O8A/030h801<F
3`0@4``071lG02lb:00K7Q@0>3/a03Xm<@0N8QD06A`@01/N4`0H6A@030d801<D3`0G61<030d801HG
4P0B4`h04a@?100B4`h201@E400601DF4@0C50l04A8=010A300D5A0030d80`0E5Q40F`0F5a<04aDB
01<E4P0D5Q<04aDB014C400?4@h04aDB00h@3@0G6AH01`T601TK600F61D04A<@01<E4P0F61D03a4>
014C400I6aP04A<@01@F4`0G6AH04aDB01HH5@0C5Q@051PG01HJ6@0H71/05a/J01HJ6@0B5QD06QhM
01dQ800E6AP0720O01XN7@0I7al0728R01DK6`0G7Ad04QPH01/Q8@0I7al07B<S02@Z:P0N92@05adM
01XO800P:2/08BT/01`U9P0H82806b@T01/T8P0I8Ql06B8M01`V7P0O:2807bTQ01`V7P0O:R@07RTT
01`X9P0S;bl0930`08:?T010CTl0938c04ADD`0R<Rl08C8]02<d;@0S<BX09C</02Xi<P0X=c409CD_
02ho>P0_?c/0;Sll02m2?`0`@d00;T4o02m2@00_@d80=4Q703=7AP0eBDX0>4a=03A8B@0cATX00P0n
DED203Q;D@0V049EF@0hC4d0@5AE04MJG`19G680C5iX051RKP1HJWL0C5iZ04EGH@1>H6T0AUUP051U
J01;HF80AUiM04EMG@1=HV<0CfAW04iSIP1HJg40FFYb05a]M@1MJgH0G6Ye05][L`1KKW40EVYY05U]
K01KKfh0FFe[05Y^K01IKF/0HGIa06IkMP1OM6l0J7eh06UmN`1aPXP307:3RP0607F6S@1gR8l0NX^B
07b=U01nSiH0P96H0P21TYT03`25TYP0RYNM08^HWP2@Vj40TYfS09:LX`2HXJP0W:F/0:2X/02SZ[80
YZfe0:^^^@2^[K/0[:^i0;Je``020;Fc`@0C0<2mc02m^LP0_KW80<2kbP35_/h0b<7A0<W3dP3;aM<0
cLOE0<k7eP3>a]D0clOF0=;8f03DbMT0e/WJ0=O:f`3Eb=T0e<OH0=;8f0020=3:f0040<o9e`3<a]@0
blGC0<W3d@80al7?0P36`<h01@35`<h0`Kk90;nmb02l^/D0^[W10080^KS000T0][Fk0;>b^02^[K80
[Jba0;2_]02d];T0][Nl0:nb]`2Z[K800P2[[[<08@2RYj/0X:R[0:F]/02RZZd0VJ>U09JPXP2BW9h0
RYJC09FQV`2EXI`0OHZ3082=Q@1bOgL0GFYP04mLDP1OKF00L7ia05e[GP1TLFH0JWM^05e[I01MK6D0
G6]T05i^J01FIf40F6US05IXH`1DIf<0CF1N051SH@1TMg<0H71/05=TGP0204aME`0L04IGD@0oD4X0
@E9<03M8@P0a@S`0<44k02ho>@0^?CP0:C8_02P`;P0Y<Rl0<3Tf02Ha;@0T;b/07RXV024_:P0/>cH0
;Sdh02Ph<`0[?3L0;cln03a<B`0^?Sd0;cln0310?`0V=SD0;cln0310?`80;cln00h0:SXi02De<P0W
=S008S4Z02<b:`0Q<2T08RlX02Hc;00Q;2H07BPR020[9@0R:bH072DP01dW7`806B<K00P06bDM01TS
6`0J8ah082TT01lX8`0O:2D07RLT01dV8`8072DR01808BDT01XN7@0J7Qd07B4P020T8`0I7A`08BDT
02P/:`0R9RD061`K01/O7P0N8R007B8N06Y_J`0L8Ad08BHR01@I5@0J7a/201hS7`0:01HK5`0I7QX0
6QlK01PM6@0B5a<06b0L01XO6`0Z;b/0<SLc01LL608051TE00H05Q/G01/P700K81`06adK01DE5@0B
4Q8301LG5`0301XJ6P0L71`04a<C00805ADE00l051@D01PH600@41005ADE00h>3P0J6QX05ADE05AD
E01EEED051@D01/K6`0;2`/03`l?00h=2`0B4@l00P0I61H0100E51804A0>010?3@0A40h201<B4008
018A3`0A40h05A4@018>3@0E4A0061@C01@@3`0A3@`201<?3P<04Ph=01@04Ph;01<?300D40`04`l<
018>2`0A3@/04Ph=01TE500<20P04Ph?00d92P0A3@h05A4B01PB4P0;1PH050h>014;2`0C3@d030H6
014;2`8040X:00@04P`<01<=3@0B30`050h>0`0A2`/04@0?2@T04@/;01XD500@2PX04P`<00l92@0D
3Ph03`T9014;2`0?2@T05Q0@00l92@0J51@01@00010:2P0?2@T03PP800803`T900<040X:00l:1`0?
2PL00P0@2`P05`0?2PL03PT6010;200=20D03`X701@?300A30T030L300h91@0B3@T02`H301@?2`0:
1P@05A0<00d81@0=1`L03PP800l92@0>20P03`T8018=2P0A30T03PT600804@`900L03`X7010;2@0D
3``03@T601TD4@0=2@L03PT600<040/800<03`X700h91P0>2@H01@0>2@H01@0?2PP03PP800d71`0@
2PX04P`<00L03`T900@040P80147200B20T04PP9200A1`P0100R6A`0:bDW014;3@0D3Q02018<3P09
00`6200B30h05@lA01LA4`0I4aD04@/=01<92P0B20T04@L8008040H71`0A1`P00`0@1PL03`D600l5
1P0200l51P0;00h41@0C2@X04PP904<i>P0a9bP04@P900`4100A1`/04@L:01482`0<1@H00P0@1`X0
1P0/9RP050h@00h92`0@2`d061<E02l[;1Cooooo000Kooooo`06020P8P0410H02PX<01@D5P0?3a40
2@T;0P0?3a4300h>400300d=3`0>30d040h?00804@l@00<040h?00h<3@0>30d00`0@3Pl02@0>30d0
3@/<00h<3@0100003`d>01DC500A3a002PP9010>3`0400l=3P0400l>300@3``03`h:00l>2P803Pd9
0P0=30P00`0A40`04Q4=00l>2P0200d<200703Th=P0M71X07A`J010?3@0<2`T03@`:014@3P03010?
3@0:014@3P0@40h03Ph<00d=2`0?3`d04A4?010@3P0?3`d0410>00l?3@803Ph<00X03`l=014A3P0@
3`/04A0<01DD400?3PX03Pd9018A3@0A40`03`h:0P0@3`/04P0?3PX04A4<018C3P0A4Pd0414<00l@
2`0>3`X01`P5024R7@1OH5/0A4E00042000>3`X051D@01dN6@0C50l05QLB01@E40<03Pl:00/03a0;
010A300@4@`04A8=00L80`0=3PT02``701XK5P0K71L0414<00l@2`02010A30803@h901l0414<01<B
3@0E4Pd05A8=01@@3@0C3``04`l>01@@4@0C3a004PdA01<>4P0D3aD04PlC010@400>3Ph04A4A010@
400=3@d0410@01@D500B4Q803@d=00l?3`0C4a<04Q8B010?3@0?3P`04A0>01<B400B4@l03@`:00H0
4Q4?01802`/901<C4@0E5A<03`l=00`<2P0A4@l04Q8@014A3`0?3`d0410>018B400C4a4051D@00`=
200=3PT0414<00l@2`0A4Pd201<D3`0B01LH4`0@4@`04a@?020Q700N8AT030l600lB2@0F6@l03Q46
02LZ7`0U:1`0Qh]m0:^_X01aMFH0<3@U02DY6`0E5Q004A8=0P0B4`h00`0D5A00414<014B3@02018C
3P<051D@00@06AXE01HG4P0D5A004a@?0`0A4Pd07@0D5A005aPC00l@2`0B4`h051HB018D4@0A4a00
51HC01HH5@0E5a@051HC01hP7@0>40d04aDB01XL6@0H6QL051HC018D4@0C5A805aTF018D4@0I6aP0
=3Hc01dO700?4@h061XG01@F4`0F61D05QTG00805QXI0`0G6aX0<P0J7Qd08bLV028V9@0F6QT061`K
020T8`0<4Q808BLW01lU9@0N92@07bDU01LM7@0D6QX04aTI01XP800K8B405Q`L01TN800E72806B0V
01PP900H82<06b<U01/T8P0J8b006b@O01`V7@0K9A`06bDJ01/U6`0H8ad0930/024]:`0K9bL0930`
04=AD`0/>Sd05bDV02De=00V>CD0;d8n01DW800K:R<0;Sdc02/k<@0/?380<T<j02<d;00cA3`0;d4k
0P0bACl02@0]@3`0<4=102m3@P0bATD0;d=20314A@0fBT/0=DU:03I9C@0203iAE@0`03U<DP0kCU@0
@eIJ03I:B`11EEH0B5]Q04MJH@19FfH0CEm]04aNK013EF80CEmY0:>e_`1/OhH0?E9E04aTI017HEh0
BF9O04iVIP1>HfH0BUmR05EXKP1LKGD0GFif05e[MP1LJ7@0FfUb05Y]KP1HK6/0FVi]05Q/J`1HK6X0
GG5_065eL`1VNgH0Jh1k06IkM01fRh@0OY:@07N9SP1gR8l0MXN>07B5S01gR8l0NHZA07b=U01nSiH0
PI:I0`23U9/05@2>Vj40RYNM08bIW`2EX:H0V:6X09^TZ`2MYZd0XZVa0:F/]02V[KD0ZK2h0;:e`02m
_<X0^;K40;Vga@2h]/@0]k?20<2lb`32_/d0a[o?0<W2dP020<c5e@0C0<k7eP3Bb]T0e<cK0=G=g03D
c=/0elcL0=S<g@3Ic=d0f/gN0=_=gP3Ibm`0elWJ0=K:fP3Dc=/0dl_J0=;:f@3@b=L0c/KE0<g5e002
0<c4d`0S0<[2d@39`M00al3?0<:obP31_lX0`;k90;fla02k^/80^KS00;Fd^P2c/[P0/:nd0:n^/`2a
/;D0/k>h0;:c^02]/;D0ZZfb0:^^/`2Z[K80YJZ^0:6Y[02RZZd0W:BW09JPXP2GXJ<0TI^M08VFS`2;
V8h0RYN>07J3NP1cP7H0Hg1V05YWG@1PKF<00`1QKV@03`1GI5X0IW=Z05aZH`1LJf@0DV5L05i^J@1K
K6H0H71]05Y/J01KKVX0GG1^05MZJ01BIF40DV9O055PF`0204iMF00J04]JE@13DTd0@U5<0391?00a
@3/0=D@o0350>`0`?3P08R/X02H/:P0L8R008BXW01hX9@0f@Cd0;3Pd01`Y9@0Q<2/0:STd02/k=P0_
?c`0;3`k0720P010D500AUIF01/[:`0Z>SX202Ph>00S02@d=00V=SH09CDe01h^;@0W=Rh093@Z02De
:`0R<RP08BhU02<`9`0R;BD072LO020[8`0S;BD07BLO01`V7P0Q:b808B/S02@^9P0P:R807RLR028[
9P0N9b808R/X01XS800P:BH09Bh[01/T8@0P92<0HfMV04eAD00F6QT05a/J01`P7`0K7ah00P0M8B00
5P0K7ah06QhM01`Q7P0F6aL0=S/g01/P700I7QX041DA01PM6@0I7QX04aPD018G4`0R9b<082DQ01DJ
5P0A5Q806QlK01DJ5P0I7QX082DQ018G4`0F6aL201@I5@807B8N01l07b4O01XJ6P0C4a<05ADE01HF
5P0G5aL06QXJ01/K6`0A4A4061PH01hN7P0>3Ph06QXJ010@400B4Q8030`<014A4@092@T0410@01@D
500?3`l02`/;00X:2P0H61P03Pd;014@3P0E518051<A018A3`0@3`d04Q4?00804A0>00T040l=014@
3P0B4@l04Ph=00l;2P0A3@`040`;00d9200?2`X00P0C3`h2018>3@0E014=300A3@X04@d:01@A3@0C
3``04@d:010<2P0C3`h03`/:018>3P0D4140:bLX03@`<@091@H03`T901hH60080P80100001XD500@
2PX04`d=008040X:0P0B30`00`0?2@T04`d=00h82002018<300=010:2P0E3`l02`D500`61P0C3@d0
40X:01<=3@0:10@04@/;01<=3@0:10@03`T901@>3P02010:2P0500l92@0>20P03`T900l92@0@2PX0
0P0?2PL2010;200400l:1`0>2@H04@`900l:1`803PT600T03@P500d8100A30L01`8001TD3P0;1P80
6A@@00@0000?2PL00P0?2@T200d71`0500d71P0?2PL03`X700d81@0A30T00P0B3@X0200C3P/01000
04<n>`1WHUl05Q4>00/60`0=20D03PT60P0?2PL700h91P0700d71P0<1PH030H600/51@0=1`L040X:
014;2`0500l92@040108200A1`P04PP901882@P04@L800`071<F00T31@0:10H0DD]=06]UI`0G4A<0
4@/=018<3P090`D040X<01hH6P0>2@X201882@040147200@1PL040H7014720H040H700@03`D60106
1`0A1`P04@L80P0C2@X04P0<0P<04@L800L0000700006Q0A00L0000900404@H901L<400B1`/03@D7
00`31P0>20X03PT:01PD5@0K5aP040h?00X:2QCooooo000Kooooo`06014A4`0B4Q@06ATK00L72@0;
2`d051@F0P0?3a4200h>40803@d?01803P`=010>3`0C4A804a4B010>3`0>30d030X;00h<3@0@3Pl0
4@l@010>3`0?3@h030X;00l=3P0H5QL02@L800l=3P0B414300h<3@05010>3`0A3a004Q4?00l>2`0?
3PX00P0>3@T00`0=30P030/700`;1`0200l>2P0900d<200<2`L03@`8020O7@081`D040l=00h=2`0B
4@l05aHD00H03Pd;0P0<30X00`0?3`d04Q8@018B4002014A3`0D010@3P0?3`d03Ph<00h>300@3``0
40l;01<B3P0G5Q803`h:00h=2@0C4Ph03`h:00/:1P0<2`L03`h:00h=2@0@40/04Q<>014B3@0@4@`2
00h?2P0<018C3P082@@06a`G01LH4`092PD05QLB00/<1`0M7QT0414<01@E400B4`h03@h90P0@4@`2
014B3@0O018C3P0C50l061TD01@E400B4`h01PL200X;1P0D5A00414<014B3@0@4@`03@h900`=200?
3`/04A0<01<@2`0C3``04Ph;014=2P0A3@`05a<D01@@4@0@2`h04@`@01<>4P0D4A@0410@00l?3`0@
41003@d=00/=300201@F5@0600d?3P0E5AD051@D00`<300D51@04a8@0P0?3P`00`0D4a404a8@00d<
2P0601<B4008014B3@0?40/02P/600l@2`0D5A403@d;01@D4P0A4@l200h>3006014A3`0C4a404A8=
00/<1`0?40/04Q<>0P0@4@`06`0D5A00414<01LH4`0B4`h03Pl:01LH4`0B5@d06A`E02X]900e>2h0
30l401PK4015BC`0e][<0?kol`2i_Jh0@4@e024U5`0G61<051D@02DV8@0;30P07QlJ01HG4P0B4`h0
4a@?01@E400201HG4P805aPC00h05AHA01@E400D5A005AHA01HG4P0E5Q404a@?01DF4@092PD04a@?
01<E4@0B5140418?01<E4P805aTF010061XG00lA3P0M7a`05QPE01@F4`0;3@X061XG01@F4`0B5140
5aTF01@F4`0P8Ql0ATQ502LY9P0<3P/06A/H0P0G6AH01@0I71X05QXI01DI600D61L05QXI008061`K
00P07b<R02<W9P0K7ah051PG01DI600E6Qd07R<V01<I6P804aTI0P0J81h0CP0F71X06b4O01hT900I
7al06R0Q01LO8P0K8RP06b<V01TQ8`0L92H06R<Q01TR7@0K91l07BLO01`V7@0K9a/07bXN01XW7P0J
9b008BdY02<_;@0O;Bd07bd_01`Z;@0R<S807Bd/01`_:`0/?cT09cTc02Pg<00Q<2T08C8Z02Dd;@0X
>C40;Slg0352>P0]?cP0<dI003A7@@0`@cd0=DQ402/o?P0]@D80:Cdn02Xn?`0bADP0<TE903M:CP0j
CE40>Da@03M:CP0hBe00?4mC03E8C010DeP0AEQN04=FG@13EEl0AeUS04EGH@14EV00EfUc0:^na@1?
HVT0DFAZ04eUI@19HF40Bf=S055VI`1=HVD0BEaP05AWK01OL7L0H75h05m]MP1OK7D0GVed05]^K`80
Ffm^00X0Ef]Z05U]J`1OLg40H7=a06QkM`1]P7`0IGQc07V<R025V9H0LhB90`1dQH`01@1iRY40NhbC
07j=U022TIP0Q9>J0080QYFL0200QYFJ092LXP2;UY`0WJR^09>MX`2?V9l0XJV`09nV[P2RZK40YJ^c
0:B[/`2X[;L0ZZ^h0;Jd`P2h]/@0_K_90<>ocP2o^lX0`ko>0<Joc`39`]80cLKF0<o8f03@amP0dLSI
0=C<f`3FcMh0elkN0=K>g@3Ic]l0f/kO0=[=gP80flkP00<0fLcM0=S9g03Gbm/00P3Gc=`04P3Eb]X0
dlSH0=76eP3@amH0clOF0<k6e@3;`m80b/;A0<W1d033`</0`/3;0<?0b`31_/T0_Kc40;Zi`@2g][h0
][Fk0;>b^080/K2e06l0/[:g0:b]/P2[[[D0[:nf0:V//`2XZk00ZJfc0:>X[02OYjX0V:2S09JNX@2G
XJ<0T9ZL09:MU`2<VHl0RIF;07V6O01ePWP0HW1S06MeJ01KJE`0I79V06YgK@1IIU`0Hg1V05YZH01K
JV<0Gg1Z04iMF01GIf@0EVIS06=cLP1KK6X0EFQT05AWH`1EJ6@0EfYV04iOF@1BHed0Cf1J04aME`1;
FUD0BEQC045@B`0b@3/0=40l03Y6A00c?cd0;CLf02Pa;P0V;b`0;CHc02`e<P0`>cL0T9ZI05=OG@0^
>cT09SDb02hm>P0[>SL0:3Pg02Lf=P17EED09CDd02@c<P0Z>3P0:3Pg02Xi>00Y=cL08c<b02Lf=@0W
=CD082l/02<a:@0U<RT0:3D/02@a:00M:R407bXR020[8`0I91`07BPP024[8`0K9Ad06B<K01`V7@0O
9Ql082XR01/T7P0G81/06R<P020Y9P0W<2l06R@S02D_;P0]=cH082TX02X_;@0e>CP0:Bd/01TM700N
8R407B4P01PL6`0C5aH061`K01dQ800K7ah05ATG01`Q7@0=4Ph00P0H7AT05@0M8Qh06b0L01TN6P0G
71P08bPT03Hk=`0X;BT06AhJ01DJ5P0J7a/061dI018G4`0K81`06A`I01/M6P0G6AH04Q@A01PJ5`0G
6AH07AhM01lO7`0301DE5@0:01HF5P0E5AD07AdM01DE5@0C4a<06QXJ01<C4`0?3`l030`<01DE5@80
61PH00X05aLG01@D500=3@d06QXJ01DE5@0H61P03`l?00l>300@3`d04A0>0P0>3@/03@0A40h04a8@
018A3`0@3`d03`h<010?3@0C4Q0040`;018>3@0F4Q404@d<00/71P0B3Pd00P0C3`h2018>3@804@d<
01l04@d:01@@3@0D40d040`9010<2P0C3`h05Q8A018>3P0T8240;b//01LC500E4A805Q0@00l92@0F
41005a4A00h8200A2`/05@l?014;2`0@2PX04P`<014;2`0=1`L050h>00l92@0B30`04@/;00d71`0B
30`05Q0@008040X:00`03@L701@>3P0>20P04@/;00d71`0@2PX03PP800@0000G4A4040X:00l92@0>
20P200l92@03010:2P0?2PL03`X7008040/801003`X700h91P0A30T040/800d81@0;1P<030L400h9
1P0E40/061<?00/60P0>2@H03PT5018=2@0?2PL03`T90P0=1`L0400@2PX04P`;018=2P0C2`T03@H4
00d81@0?1`D03PP500l:1`080000:bDR03Xe<P0<10804@`900/60`0<1`@900h91P0700h81`0>20P0
3`T900d71`0>20P050h>01D?3`0500l92@040108200A1`P04PP901882@P04@L800h01P0000H00P0A
2`d08A/M03H`<P0=20T04P`>00`6200=1`T050h@018<3P0>20X03P@500l51P<04@L8200@1PL00`0A
1`P04PP901@:2`0201H<3@0;03@Z:`0=1@D040H701/A4P0:0@406a4B00T00@0E2`d050P<00l4200=
0`H00P0@1`X01@090`D02`D700d92P0<2@X02@L801Cooooo000Kooooo`0400l=3P0B41404Q0A010>
3`803`d>00P020H7014?400=2``030X;014?400>30d040h?00l=3P803P`=0P0?3@h01`0>30d05aDF
06aZJ`0R82403@/<00h<3@0?3P`00P0<2`T02@0=30X03`h<014@3P0D4a4040l=01@C4@0?3P`04a8@
010?3@0500l>3007010?3@0=30X051<A00`;2@0L6aT05aHD014@3P0300d<2P0600l>300A40h04Q4?
00l>300>3@/03@`:0P0>3@/04`0A40h040l=00d<2P0A40h05A@B01<B400B4@l02`X801@C4@0A40h0
30/901@C4@0=30X01`L501@D4P0T92803`l=01@D4P0>3P`00P0@40h0600A4@l03Ph<00d=2`0?3``0
4Q<>01@E400A4Pd03Pl:010A300E5Q40H65L038c;P0@4@`02``701<D3`0?3`/05A@@028Q7@0A40`0
51<?014@300E510051<?01<B3P804A0<00D04Q4=00h=2@0C4Ph04A0<00d<2002018A3@<04a8>0P0@
3`/01@0A40`03`h;018A3P0B4@l051<A00804a8@0P0@3`d07@0@3`h040h>010>3P0@3Ph03`l=01/K
6@0D5Q<02`l;014F4P0?5a8031@?00`A3@0>4Ph03a4>00h?300C4a405QHD010@3P0?3`d0410>01@D
4P0>3P`04Q8@010@3P0>3P`0410>014A3`0?40/03a0:0080414:00/04A8<014B3@0B4`d03@h900h?
2`0E5A<02PX8010@3P0C4a40410>018B400201<C4@0K018B400@40h04a<A00l?3@0@40h05ADC00d=
2`0A4Ph04aD@018D3`0A50h04QD>01PK4`0K7Q@0@D@i09ZNT@3Lh=80PXIh01`P4@0D60X05AH@01<D
3`0D5A005AHA018C3P0@4@`04A8=0080414<01<05aPC010A300F5a8051D@018C3P0C50l05QLB01DF
4@0D5A005aPC01<D3`0F5a805aPC01DF4@0D5Q8051HC018D4@0C5A805ALD008051HC00L06A/H01HH
5@0F61D06A/H01HH5@0H6aP05a`H008061dI0`0F6aL0;`0C61@041DA01DJ5P0I7QX05a`H01DI5`0=
4A00=SXi04a@C`0K7ah061`K01DI600M8B00;S8a02``;`0I7A`061`L05QMHP25RY007R<W01<I6@0J
81d061lI01`S6`0I81T07R@O020V900L8R006R0P01lT9P0P9BL0728Q01`U8`0T;B/092dZ01`W8@0M
:2807BPQ01`X8@0N:b<07RXQ01`Z7P0M:al07blU024`:P0R<Bh08C0`00808C4a05/08C<a020c;`0P
<bd08cH_02<d<@0Y>SP0:Sdj02Tk>00X>cP0:chi02/n>00Z?CL0;T4k0314>`0cAch0=dY603=7B@0_
@TP0<4=902e0AP0gBTl0<dI;03U<D00mD5@0>diB03M:CP0gBdd0=4M=045BG@13E640@E9L049CF`17
F5h0A5II04IHF`11DUL0DV=Y07F6S@1LKGH0E6M^04eQI`1?HfL0DfM[05AWJ`1FJFd0Ffea05i`L`1Q
L7@0Y[Fi0:2_/@1PKW00IWEg061bL@1ML6h0GW5_065dLP1PLG00GFm]06MgMP1_OWd0LX6007:1P@1d
PH40Lh:207:3QP1gRHd0NH^?07^:S`1nS940OhfB08:?U@29UI/0QY:H08NCV@2=VIl0SiZP0:>]/P2I
XJL0UinU09fUZP2QYZl0Y:Va0:R/]@2Z[KT0[[2m0;6d`02c]L80^[W80;nkc030_<d0a;oA0080b<7C
00h0b/?E0<k5f03?a]T0dlWL0=G;gP3Gbml0f<cP0=W=h03Jc^80g<oS0=_@hP3Kcn<0gM7U0=oCiP80
g];V01@0gM7T0=kAi@3OdN<0g/kP0=c<gP3KcMh0fLcM0=O:f`3Eb=T0dlOH0=76eP3?a=@0cL;B0<_1
d@39`]40b<?A0<O2c`34_/X0`Kc80;fja@<0]kJn06P0]KJk0;Be^P2c/kT0/k>m0;2`^`2][KP0[:bf
0:Z[]02UZK00Z:fc09^PYP2PYZT0V:2S09:JW@2OYjT0S9FB08J@RP1hPgX0JgM]06IbIP1ULF<0H6iN
06AbHP1/OFh0JGU/061`I01RLfP0IGI/05IYH@1KKVP0G6e[061cLP1JK6d0HWAe05QZJP1HJfL0FFaX
05=VG`1BIeh0EV]T06=hLP1>HU`0AeYD04AED@16EE80?de:03]6A@0c?3`0?DA6030f>@0Z<S@09S0_
02<^:P0Y=3007bXX01l[:P15DE40>DA5030k?@0f@D@0<Ca0030k@00c?d<0;3Pf03I2?`0V<c00;CXg
038n>`0_?3T0:3Db02`h=@0/>CH0:SHc02Da;P0Q;BT09S0[02<]:00T;RT08bdW024[9@0L9B008BXU
020Y900Q:RD08b`W01hW8P0J8ad08RPR02L/:00M8Qh082HS01TR800L9B@0:S@d018M7P0V<S<06RLW
020];`0P:R`08bTV02P]:@0R9b<082DQ01hS7`80724M00D06QlK01/P700L8Ad06QlK01/N700201`N
7@0A01XL6`0M7ah07R0O01hP7`0I6aX05aTH01/M700L7Qd06adL01XM700H71/061XI01TK6P0J71/0
6Q/J01TJ6P0I6AT00P0G5QH03P0I61P071TJ01lM7@0E51804A0>01PG5@0F5A<061LE01DD4P0F5A<0
61LE01LF500E518051<A1@0C4Q003@0D4a404a8@01HE4`0F5A<040l=00l>300G5Q@0L6m]00l>300D
4a806APF018A3`0?3P`01P0A40h00`0B3P/04Pl;018>2`02018>2`804Ph=00L04@d=010<3@0B3Pl0
4Ph?010<300C3`h04Ph=00<040`;00T04@d<00/71P0B3Pd0FeMF061LF`0@30/03PX9018>3@0A3@`0
0P0@30/04@0A3@`04Ph=00`81`0A3@`03`/:010<2`0D40l02`L600d81@0>2@H03`X700h91P0@2`P0
5Q4>01D@3@0D3``03`X7008050l<00P03`X700l:1P0@2`P03@P500l:1`0B30`03`T9010:2P@040X<
00X040X:034/:P0?2PP03PT6010;200:1@8030L4010;200?2PL03PT60P0?2PL0200@2`P04@`902DP
7@0D3``03PT600`7100@2`P03`X70`0@2`P01P0>2@H03`P601481P0C2@P050X9018920804@L600H0
4@P601471P0A20H04@P601471P0@20L500h8200500l92@0>20P03@L700d71`0>20P00P0@2PX01@0B
30`04`d=010:2P0B30`040X:00803PP800/03`T9014;2`0;1@D030H600l71`0D2P/04@L801D;300B
20T03`D60147200301061`0A0147200C2@X04PT:00l92@0=1`L030H600h8200A2`/03`T900`61P0?
2@T040X:00h8200?2@T04`T:01882@0A1`P00P0@1PL02`0A1`P03@<401882@0B20T03`D601882@0C
2@X03P@500l51P0@1PL04@L800804`T:00<07A<D01<92P0D2P/00P0?1@H00`0E2``03`D601061`02
01882@0601061`0?1@H050X;01882@0@1PL03`D60P0@1`PDooooo`006oooool02@0@3Pl03P`=00d;
300?3@h040h?00l=3P0N71d03`d>00d;300201<A4P@03`d>00<040h?018@4@0C4A800P0=2``04P0^
;2d030X;01LE5P0>30d03@`:00h=2`0?3P`04A0>018A3`0C4Q0061LE01DD4P0G5Q@030/900l>300>
3@/04A0>010?3@803`h<00T03Pd;00d<2P0?3P`05A@B00h=2`0K6QP05QDC018A3`0?3P`00`0>3@/3
00l>30<03Pd;01@03`h<014@3P0>3@/030/901@C4@0I61H05A@B018A3`0;2PP04A0>01DD4P0?3P`0
4Q4?01<B400?3`d04A4?00d=2`0>3P`051@B014A3`<0410>01<03Ph<00/;2@0<3@T04Q<>00l@2`0=
3PT05aPC01DF4@061`<0@T<n02d^:@041@40;c0[0411?00=3@T030/700h=2@0?3PX04Q4=00<04a8>
00L04Q4=014@300A40`04Q4=00d<200A40`04Q4=00803Pd900d030/701DD400A40`03@`800l>2P0B
4@d04A0<01TH5P061@<04A0>01HE4`0R8Al02PT700H04A0>01`051<A01PH5P0=3``00PL300dB3P0A
5a<03A<?00/A3@0?51004A<@00d>300A40h071`J018B400N7Q`0410>00h>300@40h061PF01@D4P0A
4@l0410>00l?3@0<3@P03a0:00l@200@4@T0414;0P0A4P`01@0?40/03@d:01<C4@0=3@/05ADC0080
4Q8@02T04A4?010@3P0@40h04A4?018B400@40h04a<A018B400@40h04Q8@01@D4P0@4Pl04A<@014C
3P0B50h05APA01PK4P0I7180:RdR02P[8010A3L06Ad?00hA1P0B4`d04A8=018C3P0E5Q404a@?018C
3P0C50l04Q<>00l@2`0C50l030d8010A300E5Q404a@?01@E400G61<05QLB01DF4@0301<D3`0601@E
400F5a8061TE01DG500C5A805ALD0P0F61D03@0E5a@05aTF01@F4`0P8Ql08bDR01DG500E61D05a`H
01DJ5P0C61@051TE01HK5`0E6QH00P0B5a<301@I5@0G01/O7@0>4Q405ATH01lS8P0E6AP06QhM01PL
6`0@51<04ADD02HZ:@0Z;Rd06alO03Tn@P18CE<07b@X01@J6P0P9R805QdF01XQ6@0G7QH06B0I01XP
7P0G7A/00P0I7al0:00K8B406R0N01XS800N9b@072DR01dX900I920092lY02dj<`0U<R/07BXR01dZ
800N;1l07RhT020_:00P;b`07bl^020`<00Y>CT0;D0m02<f<P0N<B/09cXc02/n>P0X>cT0:C`j02`o
?@0^@Ch0:chj02Lj=P0^@C`0:chh0313?@0nDDX0?U5=02Lk?00lCe@0@eIJ03U<D016FEh204MJH00[
03E8CP19G680A5MM03Q;D00dAdh0@e=R04eMK01;G6H0AUMO049CF@0kCDl0A5IH04=EF00oDED0BEYQ
05=TK@1?HVT0B5]R05IZL01CIV`0DfIZ05i`M01OLGD0Gg5c05]ZK@2GYZT0Ri^K06AbL`1LK6`0GVm^
069eL`1KKV`0HWEc06MgMP1OKfh0JWYi071nOP1bP800M8:207V5Q@1iQhP0MhJ:07^:S`0207b;T00N
07j;T@20SI<0QY>I08jIW`2;UY`0RYFK096JX@2CW:<0U9^Q09VPYP2LXjT0XJR`0:b`^@2_/[d0[Jnk
0:na_@2d]<40^;O50;Zia`2l^/X0`[k?0<S1d`39`]@0b<7C0<_2e@3@amX0e<_N0=O;g`3Jc^80g=3T
0P3NdND07@3Od^H0hM;W0>;Dj03Qe>P0hM;W0>;Dj03ReNT0h]?X0>;Dj03PdnL0hM;W0>;BiP3Qd><0
glkQ0=k>h@3LcN00f/_N0=O9g03FbM/0e<OI0=35eP3?a=D0cL?D0<_3dP3:a=80bL?A0<Fob`33_LT0
_kc70080^KJo04D0^;No0;Nf_02f]K/0/kBj0;>c_@2a/K/0[Zjh0:f]]`2[ZkD0YZV`0:N//P2KX:@0
XjR/0:F][`2]]KL0YJj^08fFT`25SXT0L7Ya05eYG`1LJ5`0J7AV06UgIP1]NfX0KWm_06=cIP1VMV`0
NX^10762NP1KKfL0GG1Z05e`KP1RMGD0Gg5c061bM01IJf/0EfYV05EXI01CIUl0E6UP04aQFP1KLFX0
?U=<03U<AP0nD4/0>4Q5041<BP11C4/0F69S03U1@`0W;C00:C4c02H`;`0]>CL09C4_02Hb<P0^>SX0
82`/01/V:01gPX@0;3Li02/f>00/=c/09S4c034m>P0M:BD0>DE102Te<@11CDT00P0]>CD0300/>3@0
:cLc02Te<@0V<Rh09C4]02Xc;P0Q:RD092dX02/d;`0F7aX09RlZ02</9`8082TT00L08BXU01lX8`0M
9R408bPT02D[9`0L8Qh08bTW00806b@S00/0MX2103E1@@0L:2P0;3Li01HT9@0U<C408BHS02DZ9P0Q
9R8082DQ01lT800201dR7P0>01/P700M8Qh07B8N01`Q7@0L81d071hM01TK6P0G6AP061XI01XL6`0H
6QT05aTH01XL6`0K7A`201XL6`0501/N7@0D61L051HE01/M700G6AP00P0F5QH04P0E5AD061HG01LE
5P0H5QL07a/L051>C@0i>3H061LE01/J600Q81h06QTG01hM6`0J6AL051<A01DD4P0G5Q@05QDC01DD
4P8051<A00l04a8@018A3`0B4@l05A@B01@C4@0C4Q004Q4?01<B400E51807A`J00P71@061@@05QDC
01lN701KFUP01@0A40h00`0A40d04Ph;018?2P03018>2`804Ph=00L04@d=010<3@0B3Pl04Ph?010<
3@0C3`h04Ph=00<040`;00@04@d<010<2`0D40l01P810P0:1PD00`0G4a8040`;00l;2P0200h:2@0>
00l;2P0@30/04Ph=01@@3`0C3`h04Ph=00`81`0A3@`03`X701@?300:1@801P4000/60`080`0201LB
3`0;010;200A30T040/800`7100?2PH04@`900h91P0?2PL03`T900/51@0>20P0100>20X0200>20P0
5Q0?00D000080`003PT6010;200E40d03PT60P0=20D200h91P0>00l:1`0C3P/0<bh[020K600<1`@0
2@@101D@3@0=20D03PT600l:1`0A30T040/801491`0A1`H301881`L04@L600<040L700d71`0=1`L0
0`0=1`L02P0>20P03@L700d71`0=1`L03PP800l92@0A2`/050h>018<300>20P200l92@0<00/51@0>
20P05@l?01@>3P0:10@02`D50108200F30d03P@500P0000700005@/<0P0A1`P201061`040147200B
2@X03`H700d71`803PP800@03`T9010:2P0?2@T03@L70P0@2PX01@0;1@D02P@401<92P0B20T04@L8
008040H700L04@L801@:2`0A1`P03@<401D;300L4Q<04`T:00803@<400`03P@500l51P0@1PL04@L8
01H<3@0900401`0001882@0A20P04@L800l51P0@1PL20147200401061`0?1@H03P@5014720804`T:
00<040H700`20oooool04oooool001_ooooo00<030X;00l=3P0@3Pl00P0?3@h01`0@3Pl0<c4b01HD
5@0=2``040h?00h<3@0C4A800`0>30d02@0?3@h04Q0A01<A4P071@H03`d>00`:2`050`@06aTJ00D3
1002010?3@0;014@3P0@3`d03Pd;00h=2`0D4a404a8@01HE4`0>3@/04a8@01@C4@0B4@l00P0@3`d0
2`0>3@/03@`:00`;2@0@3`d04a8@00/:200B4@l02PT700L6100A40h03`h<00@03Pd;030040l=00h=
2`0>3@/03Pd;00l>300<2`T03Pd;01@C4@0@3`d030/9018A3`0D4a4030/901DD4P0Q81h04a8@00h=
2`0<2`T04A4?00@40P0:2PP05QHD0000000C4a40410>00h>300;2`T03Ph<01HF500E5Q8030d800X;
1P0>3`X04a@?014B3@0?40/030d800X;1P0K71L0@D8m059CCP0B4Pd02`X601<B3P0I61@051<?010?
2`0C4Ph2018A3@804A0<01<04Q4=01DD400E510040l;00X91@0=30P05QDA01XI5@0D4`l03Pd9018A
3@0F5A4051<?02@S8@0O7Q`05QDC01LF500U92806APF00H04Q4?01@05aHD01@C4@0<3@/03A8>01DJ
5P0<4Ph03aDA00/@300<4@d03Q0=00h=2`0A40h06QXH00/;2@0C4a402PX801@D4P0B4Q005aLE01<C
4@80410>01003`l=00`=200D5@l04a@<014B2P0?40X03Pl900`=1`0I6QD02PX7014A3`0H61H092@R
010@3P0C4a404A4?0P0?3`d0100A4@l04a<A010@3P0B4Q0200l?3@0?01DE4`0>3P`04Q@A01<E4P0B
5140418>010B3@0A50d04A@<01LJ4@0X:b804QD;024T6@0?4PT05QLA008051D@01P05AHA018C3P0?
40/06Q/F01/L5`0F5a806Q/F01@E400H6A@051D@018C3P0C50l05QLB01DF4@0D5A004a@?01TJ5@0G
61<04a@?01DF4@0H6AD051HC01<E4P0D5Q<201HH5@0901PJ5`0E5a@030h;01lQ7P0W:BH05ALD018F
4P0G71P05Q/G00805AXF0P0F6aL201PM6@0O01@I5@0@5A404AHB01LK6@0A5A@03a<B018F5@0G6aX0
720O01XN7@0K7ah05QXI01@H5`0C5aH082@T01lT:00I7R805adN00lE5@0Q9bD06R0K01HM5P0E71@0
6R4J01`R7P0I7ad0728R01HL700H7Qh0728P01hW9002020Y9P0601`W8`0H8al0:cH`03U6?`0Z=c00
7BXR0P0N:b40?00N;R@07bhY020_:P0O;bd0:3Ph02lo?`0cAT@0:3/g028e;`0W>S@0:Sdk02`o?@0^
@Cl0;d9002i1?P0/?c/09STe0313?P0Y?3H0;T4k041DC00lCd/0>Ti=03mCE@15F5`0=TU=03U<D@10
DeT0<4=903e@EP0gBU00A5MM041CF@10DU`0GVim06AdPP1LKGL0DfA^055RJ@1AHfL0A5IH04UKGP1C
IFT0C5eT05AUK@1AI6/0C5mU05U]L`1BIF/0EfY^069dN01MKg<0IgUk05e/K`1VMGP0G6a/06ilO@1N
KVh0Kh1o05a_K@80H7=a04T0HW9a06YjN@1[NgX0L7in07:0P01dPX80NXJ607^9RP1kRHd0OHbA07j=
TP1mS940P8fC086>U027U9X0RiJL08ZEV`2@Vj40UYnV09FNY@2FWJ<0W:>Y0:2W[@2TZk<0[;2i0:nb
_@2`/[h0/K>o0;Jga02k^/P0_;_90<2mc@33_m00al3B0<[3e@3<aML0dLSK0=G<g`3Gc^40floS0=kB
iP3Pe>P0hMCX0>;Dj03Se>T0i]CZ0>KEj`3Ue^/0i]CZ0>KFj`3Ue^/0imG[0>KEj`3TeNX0i]CZ0>KD
j@3Sd^D0hM3S0>3@h`3Ncn80g<gP0=W;gP3Gb]`0e/WK0=;7f03Aa]L0clCE0<g5e03;aM<0b/CB0<O1
c@35_l/0`;g80080^kS104P0^[W10;Rg_@2g][`0];Fj0;Bd_02b/[`0[jni0:f]]`2/[;@0YZV`0:>X
[02RYj/0XJJZ0;6i^`3Dg=h0U9bM08:;R01mQX40KGM_05iZH01PK600Kg]]075oKP1/NVT0J7UZ06Yj
K`1YNFh0K7ec05m`J01WNW<0L8=m05]^K01CIVD0Gg5c05QZK01JK6/0FfiZ05U/J01DIf00DVIM04=H
D@13FE40@5E>049EC`0hBTD0A5=@03a8AP13CTh0HVa]03Dm?`0d>Sd0<CTl03Do@00b?Sd08Rh^02Te
=@0lB4P0<Cdm03E0@P2R[Jl0@4a<03M2A00b?Cl0:SHf030l>@0R;RX0=T8n02Te<@0lB4@0:3@`02Hb
;P0W<bl202Xf<P0;02Hb;P0X=300:C8]020Y900U;RT0<CXe01DN6@0Y<Rd08BXU01hW8P0M9R400`0L
9B003P0P9B408bTU01dS7`0X;R`06b@S01PQ800X<S<03a/K010L700I92H0<Cm002@`<00O9B8092TU
0`0P9B400`0N8al0724M01/P700201`Q7@0801/P700L81d071hM01XL6`0K7A`06Q`K01/M700M7ah2
01/M700N01TK6P0K7A`06adL01XM700A5A@04A<B01XL6`0D5QD04Q8B01HF5P0I6AT071XK01LE5P0C
4A806QHG02TW9P0E51804Q4?00d<2P0100006aXH02/Z:00Q81h04a8@01DD4P0M71X08R4O01HE4`0E
518051<A0P0B4@l03@0A40h05QDC01<B400A40h04a8@01DD4P0C4Q002@P601TH5P0J6AL05QDC00D4
0P0Q81h01@0B4@l00`0B4@h04Ph;018?2P03018>2`804Ph=00L04@d=010<3@0B3Pl04Ph?010<3@0C
3`h04Ph=00<040`;00L04@d<01@@3`0F4Q404Ph=01dI600?2`X0510?008040`;0P0>2PT2010<2`04
018>3@0:1PD03PX901PD4`802@D400@07APE03<^:`0T7a`05A0=0P0H4a0201D@3@<03`X700<030L4
010;1`0B3@X00P0?2PL00`0>20P02P@400h8200400h82P0800h8200:10<03PT601HA3P0E40d03@P5
00`7100@2`P200l:1`05010;200A30T04Pd:00l:1`0M61D00P0C3P/0100<1`@03PT600h91P0?2PL3
010;200401091`0A1`H04@L601881`P04@L600<040L700d71`0=1`L01P0=1`L200h820803`T901<0
40X:00l92@0<1PH04@/;01<=3@0@2PX03`T9018<300D3Ph030H600d71`0@20T04@L800h41@0M4a@0
7Q@E01X@4@0B20T04@L8008040H700@04@L801882@0?1PL03PP80P0?2@T02`0>20P03@L7010:2P0=
1`L03PP800l92@0<1PH03PP801<92P0B20T04@L8008040H700L04@L801D;300B20T03`D601L=3P0M
4a@05@/<00803P@500X03`D601061`0@1PL04@L800X00@0G3@h060h?01dC500@20P04`T:1P0@1PL0
1P0B20T040H700h41@0=0`@040H7014721Cooooo000Kooooo`0700X82@0C4A805A<D010>3`0=2``0
40h?01HD5@0300d;300300/92P0A3a003@/<00803@/<00T03P`=010>3`0A3a005A<D00h<3@0?3@h0
3@/<010>3`0>30d00P0>3@/400l>300501<B400@3`d051<A00l>300D4a400P0B4@l2010?3@0800l>
300>3@/03@`:00`;2@0A40h02`X801@C4@0?3P`2018A3`03010?3@0?3P`03Pd;00803`h<00@040l=
00l>300?3P`03`h<0P0@3`d200l>300F010?3@0B4@l05A@B01@C4@0>3@/04A0>01`K6@0<2`T02`X8
028R8018B4H0DE5?00`<2P0H61H030`:00h>300@40h051@B00l?3@0>3P`061PF01/K60803@h900l0
4a@?00X;1P0:2`H04A8=01<D3`0;30P0414<00L80`0?40/05QHA01@C3`0F5A404a8>00d<200@3`/0
0P0?3PX200h=2@0;00l>2P0@3`/04A0<01<B3P0E51004Q4=01<B3P0N7AT092<O01dL600E51000P0C
4Ph01P0?3PX04Q4?01XI5`0T8b80>cXh00P71PL04Q4?01<02`X800l>300C4a4041<@038h=01GGET0
728N00lD400<3``03Pl=014A3`0G5Q@030`:01<C4@0D51803`l=010@3P0>3P`04A4?00803Ph<00@0
3`l=014A3`0?40/04Q<=0P0A4PX2010A2`0900l@2P0A4Pd04A4>01<C4@0>3P`06QXH010@3P0C4a40
4Q8@0080410>00<04Q8@01<C4@0A4@l00P0@40h0900J6QP0:BTW014A3`0@4Q404Q@C014C4P0@4Q40
4Q@B01<E4@0@4Ph06adI05QKE@0I6aH0418<01LJ500A4Pd0414<018C3P0C50l04Q<>010A300C50l0
61TD010A300D5A004A8=01@E400B4`h0414<014B3@0D5A004a@?018C3P0E5Q407QlJ01/L5`804a@?
00@05AHB018D4@0A4a004aDB0`0E5a@04P0G6AH05ALD01`N6`0H6QL04A<@01LJ5`0C61@051TE01DJ
5P0C61@04AHB01<H500H7AT06QlK01LL600C61@05AXF01LK6@807B4P01@061`K01HJ6@0D61L04aLF
024U900L81l061`K01hR8@0G6a/082DX018G6`0M8R@04aTI01/Q7`0I7a/05ahH01PO600M91d0728N
01LM6@806R0N05@06b4O020V900O:2D072DR01dV8`0O:RH062<O01lZ9P0U<Bd072PT01dY9@0Q;RD0
8BhT020`9P0P;bT08C0[024a;P0S<c8093@c02@g=@0W>SH09cXe02Dh<`0U>3H0<49203E7A`0`@d40
;3lm02e0?P0X>cL0<D@o02Xm=`0/?cT0>Da603A7@`25VIL0BEeL03a@D00mDE80@5=F041CE`1<GfD0
SJ2V03Q;DP0mD5P0@59K05U[MP15EF<0Cem]04iOJ@19FV<0B5UP04EGF`17FEd0A5IJ05]]L@1?H6L0
D65Y05MZL@1CIfd0Ef]`05=VK01RMGT0KGn306AfNP1QLgD0NXV<086@T`1QLG40IWAe05][J`1YNgT0
Ffi/05e`KP1/Ogd0L81o06]kNP1^OWd0Lh6107F3P`1fQ8@0NhN707b9RP1nSI42082?U00^086>U024
TIL0QY>I08^FW027TYP0RYFK09ZSZP2MYZd0UYjV0:2UZ`2QYJh0YZZc0:b`^@2^/;`0/;6m0;Fe`@2g
]/@0^k[80;nmb`31_ld0a/;B0<[3e@3<`mH0d<OJ0=G<g`3Jc^80g=3T0=gAi@3PdnL0hmKZ0>CGj`3U
f>`0imO/0>WGk@3/enh0k=W_0>_Ik`3]f>l0k=W_0>cJl03^fO00kMW_0>_Ik`3/f>h0j]S]0>OFj@80
iMCW00P0i=?V0>3Ai03Mc^40g<gP0=W<gP3FbM/0eLSJ0=?8f@80clOF00@0c/KE0<[4d037`Ld0aKo;
0P2n^l@0DP2m_<@0^k[00;Vh_P2h]kd0][Jn0;>c^`2`/;P0[jng0:j^]@2XZk40Y:V]0:2UZ02KX:<0
SiNI09nWZ027T8h0O8F107V3O01bO7<0JWI[06YfJP1_Nfd0IG=T06YhJ@1bPWH0KWic06=bJP1RLf/0
HG9Z06aoN020Thh0KX5n05]^K@1MKfl0G6i^05Q[JP1CIV80EFQT05Q[I@1EJF40BUmH04aPFP11E4h0
@eA>03I6@P0a@3d0=D4o03E0@00g@D807bLY04A<C`14CE00?DQ:030k?@0U<3809S4c02dh>@0c?cl0
;SXj03Y6A@0[=cD0>4A302<_;@0a?CX0;CTe03E1?@0T<2`0;3Pd02di=@0_>cL0:3@`02/g<`0b?SX0
;CTe02<_:`0T<2`08R/V01lX8`0N9b809RlZ02</9`0K91l2028[9P0H024Z9@0N9b807RLR01lX8`0R
:2H061hL01hT8P0oB4D0;SLf01/T8`0N:2L08bd^02H`<@0S;bl06RDW01`V9`0O9B808bPT01lT800P
9B408BHR01hS7`0K81`06QlK0P0K81`01@0J7a/06alL01TK6P0I6aX07b4P00806Q`K028071hM01/M
700I6aX05QPG01hP7`0O8B0061/J01HJ6@0J71/06adL01@F5@0D51@05aLG01XJ6P0M6a`061HG01<A
4P0G4a@05Q@C010?3@0E5180:2LU01lN700K6QP06APF01DD4P0B4@l05QDC01TH5P0H5aD05QDC01DD
4P0D4a404a8@0P0B4@l0300E51804Q4?014@3P0D4a405QDC01<B400B4@l05QDC00`;2@0B4@l03`h<
01HE50D04Q4?00<04Q4>018>2`0B3`X00`0B3P/2018>3@07014=3@0@30d04Ph?018>3`0@30d04`l>
018>3@03010<2`07014=300G4a804@d<00h:2P0V8R404Ph=00h:2@02018>3@8040`;0P0B3Pd0500E
4A004Ph=01<?3P0V8R404`l?00h:2@0;1`D050l<00h91P0=20H04`h;00P3000>2@H04@`900d81@0>
2@H04@`900l:1`0C3PX04`h;0P0?2PL00`0@2PX030H6010:2P04010:3003010:2P0@2PT03@P50080
3@P500<04@`901HA3P0?2PL00P0>2@H02`0@2`P04@`9018=2P0>2@H04Pd:00/60`0@2`P030L4014<
2@0@2`P04@`9008040/800D03PT600l81P0A1`H04@L601061@0801471P0301081`0>20P03PP800@0
3PP800<03@L700h8200?2@T00`0?2@T03P0@2PX03`T900`61P0@2PX04@/;01@>3P0@2PX02P@400l9
2@0A2`/03`T90108200>10D04PT:0P0b:2T0100B2@X04`T:01882@0A1`P201061`0:01482@0C2P/0
40X:010:2P0>20P03@L700`61P0B30`03PP800d71`8040X:00@05Q0@01<92P0B20T04@L80P0@1PL0
0`0A1`P03P@501061`0201061`0301<92P0B20T04@L800D04@L800L05P`=00l51P0=10D030<401<9
2P0?1@H04@L800@040H700L04@L800d3100@1PL04`T:01@:2`0A1`P03P@501Cooooo000Kooooo`03
01PF5`0B41403`d>00804@l@00L03P`=00l=3P0D4Q<04Q0A010>3`0?3@h02@L800803`d>0P0>30d0
500?3@h040h?00@20`0K6AX030X;01DC500@3Pl0108300h=2`0=30X03Pd;010?3@0C4Q0051<A01DD
4P0<2`T04A0>00l>300@3`d02@P61P0?3P`0200>3@/04A0>00X91`0=30X01PD300/:200A40h040l=
0P0?3P`2010?3@03014@3P0@3`d03`h<008040l=01D04a8@00h=2`0;2PP05A@B01/J600D4a403Pd;
00l>300;2PP051<A00H50`0A40h0A4=106a/JP2ATHl06ATG00L71@0B4Q004A4?00/;2@0=3@/00P0>
3P`01@0?3`d03a0<01<D3`0B4`h0414<008071dH00/0414<0001000E5Q40414<014B3@0F5a801PH4
01`K5`0?3PX020L300`;1`05018A3@0801<B3P0E51004A0<014@300E51003Pd900P70`0A40`300`;
1`0900h=2@0@3`/04Q4=00P71@0A40h0>3Le05EDDP0@3`d02`X800H04A0>01<05Q8A00l>300=3@/0
5aTF07b1O@3Wk>P0:Rl[01TM6@0?4@h03Ph<00/;2@0<2`T0;2`Z010@3P0E5A<0<30^01DE4`0A4@l0
410>00803Ph<00@0410>018B400A4Pd03@h80P0?40P02`0A4P`04Q<=01<D3P0:2`H04a<@01<C4@08
20H05QHD014A3`0@40h04A4?00804Q8@00<04A4?010@3P0>3P`00P0E5A<0100R8R00?Shl020P7P0?
414200l@4P09014B500F5aT06Q`K01XL6`0A4a808R@Q06Y/JP0B51400P@100803a0;00P04Q<>01DF
4@0E5Q404a@?02`]:00_<2/0824L01`M60805AHA00l04Q<>010A300A4Pd051D@01<D3`0B4`h04A8=
01@E400B4`h03a0;010A300C51004Q@A014C400C5A800P0F61D01`0E5a@051HC01HH5@0`<Rl0:B/X
010B3`0B5A800`0G71P201HK5`8051TE0P0F6aL0500G71P061dI010D4P0F6QT07B4P01hR8@0G6aX0
4aLF028V9@1GFeX0DUIE01TM700?4a806alO02@Y;00S:2/06b0S01HL700B61H07bDR0P0J81`02`0L
8Qh06AlK01LM6@0R:2@05Q`J01DK6@0L8R007BHS01/T8@0Q:RT08B/Z00808bd/01007BTW01/W9@0Q
;B`09C8[02@a:00Q<BL08C0Y028a:P0S=2h09SHc02De<P0T=c<0:Sdi02e0?00/?c/0:C`j0P0^@400
1@0/?Sh0:cdl02`o?@0[?S`0;D0l0080;d8n02/0<4<n02m2?00_A3l0=DU703]?C@0dB4L0?U9D04=F
FP0aA4X0EFQ`03Q:E01;GFT0AeUU03e?F`10DUh0BE]W04YLIP1:GF@0B5]R041CF@1@HfT0BUeS04eP
IP1:GF<0E6M]05MZL01JKg@0E6Q^059UJ`1GJVh0FVa`05QZKP1UMgT0HG1c06AcMP1JJVX0HFm`06Yj
NP1LKV`0HGAb05mbL01`Ph40O8b;0080Lh>200H0NHN707^9R@1kRHT0O8R807f8RP20SI8208:?U@04
08>@UP2:UI/0SIRN08bGW@80SYNN01P0Uj2W09bSZ`2IX:P0XjN`0:V/]@2/[kP0[k6m0;Bd`02h]l@0
^kW70;bjb031_/d0a<3A0<K2d`38`]@0e<_N0>3Dj03MdND0e<SL0=O:gP3NdND0hMCX0>CEjP3Wf>d2
0>WJk`0H0>kJl@3`f_40l][b0??Lm03cgO@0lm_c0??Ll`3bg?<0lm_c0?;KlP3afo80lMWa0>oJl@3[
f>h0jMK/0>SEj`3WeN/0iM?Y0>7AiP3Ncn@0g<gR0=W<h03Gb]h0eLWL0P3AbMP0B@3?amH0c<CA0<[2
c`37`Ld0`kg70<6na`30_LH0_K[10;^h_`2h]kd0][Nl0;Be^P2a/[L0/;6f0:j_]02Y[;00ZZnb09BJ
VP2JX:00UYnN08B=RP1jPh00QXn:07j8P01aNg<0K7Q/06eiK@1/N6X0GF]N06EcIP1]OG80IGE[06=b
K01aPW`0VJZT06aoN`1SMW80Gg9^05e`K@1QM780G6m]05IYI`1@Hel0EfYV05a_J`1AI5h0BEaF04]N
F00fBD<0>da603U9A@0^?CX0:SHd038n?@0_>c/0>TA504I@DP15Ce40;cXn02hi?@0/=c/0;CPj02lk
?00c?cl0;CTg03A0?P0W<bl08RhZ02<`:@0W=2d0>4A002Xf<P0N:RH00P0X=3003P11CDT0;c/g02di
=@0d@3`0:cLc020/:00T<2`08b`W02H_:P0M9R409RlZ05aUH00Y<Rd08b`W0P0V;bX0:`0Q:RD082TT
024Z9@0J8b409c0_01lX9`0T;B`09Bh]02`e=00e?ch0:38a02/e=00B71d0;CLh01hW9P0P9B808bPT
01dR7P0N8al07b@P01hS7`0K81`06QlK01/P700L8Ad06QlK020T8@0N81l06A/J01`N7@0E5aH05aTH
01XL6`0R92<0:2XY01/M700I6aX071hM01<F5@0K7ah08bDT01DG5P0B51<00P0E5AD03@0F5QH05aDF
01PF5`0G5AH06ADF01LE500F5A<06QTG010?3@0?3P`08R4O01@C4@0F5A<00P0I61H00`0G5Q@04a8@
01<B400501<B40<04Q4?0P0C4Q001`0B4@l06QTG0040000P7ad010<101/J600;2PT01@0A40h00`0A
40d04Ph;018?2P03018>2`804Ph=00L04@d=010<3@0B3Pl04Ph?010<3@0C3`h04Ph=00<040`;00L0
4@d<01<?3P0>2PT0:RHU04a8A`0@30/03`/:00804@d<0P0?2`X2014=300>01LC4P0k=cH0:2@S01hJ
6@0;20L0920O01<>2`0<1`@020<000/60`0A30T040/800d81@0C3P/200l:1`804`h;00L08QdI01`G
500D3``040/800l92@0<1PH03`T900@03`T;00L03`T901@?3@0G4Pl05Q4>01<>2`0=20D02PD20080
30L400/03@P500l:1`0@2`P04@`900l:1`0H4a004@`900h91P0:1@805A0=00l:1`03010;200600h9
1P0@20H04@L601061@0?1@@040H51`0A1`H00`0A20P03`T900l92@0300l92@0500h8200=1`L03PP8
010:2P0?2@T00P0>20P2010:2P0<00d71`0@2PX03`T9010:2P0>20P02P@400l92@0>20P03@L700d5
1P0H3Pl040H70P070000100D2P/04`T:01882@0A1`P201061`030107200A20T03PP800<03@L700X0
40X:00l92@0<1PH03`T9018<300@2PX04`d=01<92P0B20T04@L80P0@1PL20147200501@:2`0C2@X0
40H701882@0A1`P01P0@1PL020070000?cDf05eCE00J41402`8301882@0A1`P040H70P0?1@H0100@
1PL04@L800d3100E2``201dC500301L=3P0@1POooooo01?ooooo000Kooooo`0601`J6`0B41403@/<
010>3`0A3a003@/<0P0C4A806@0=2``03P`=01@B4`0@3Pl04a4B010>3`0>30d03`d>010>3`0?3@h0
40h?00h<3@0=2``040h?00H51@0F51D05A@B00T81`0E51803`h<010?3@0?3P`04Q4?00`;2@0?3P`0
0P0@3`d0100;2PP03`h<014@3P0@3`d200h=2`803`h<00L04A0>00h=2`0?3P`02`X800l>300A40h0
40l=00D03`h<01h04a8@018A3`0@3`d040l=00h=2`0F5A<02PT801LF500@3`d030/900h=2`0A40h0
3`h<01<B400;2PP04Q4?02DT8P0>3P`06a/I00h>300G5aD01`L5018B400820L0410>00d=2`0E5A<0
6ATG00l?300F5a8201@E400902h_:P0Z:bH04Q<>01@E400=3PT02``801@E400Q8Qd05QHA008051<?
00T03`h:00`;1`0B4@d04a8>00l>2P0>3@T030/701PG4`0@3`/00P0?3PX2010?2`03018A3@0I61@0
4A0<008040l;00P04Q4=01<B3P0B4@d05A@B01<B400A40h051<A00l>30@04Q4?01`04A0>018A3`0B
4@l05Q8A01<?3P0C4Q004Q8@020T800b=c<05Q/G00`?300@4@l06aXH01/I5`0@3`d0ATE301PH5P0B
4Q00;Rh/01`L6P0>3P`04A4?010@3P0?3`d04A4?01HF500E5Q403a0:0P0@4@T3010A2`0501LH4`0<
30T02PX8020P7P11@Cl00P0@40h0100A4@l04a<A01<C4@0B4Q02010@3P0901TI5`0?3`d03`l=020P
7P0=3@/04A8D01XK7@0@4A<04Q<E008051DG00T03Q0@01HH600O82404Q@D01lP8`0A4Q<051DA01HG
4P0A4Pd0100E5Q401P0J6aH05QLB010A300?40/04Q<>01@E40804Q<>00d04a@?018C3P0B4`h051D@
01PI500G61<04Q<>01HG4P0C51005ALD014C400C5A805QPE00804aDB0P0F61D0100E5a@051HC01DG
500O8Ql301LL600500hC3`0B5a<05AXF01<H500D6AD00`0F6aL00`0G6aT05QXI00hB4@0201XN7@0<
014E500E6AP0=c/j02hb<@0F6QT07b<R01@H5`0G7Ad06AlP01dR900T:RX05Q`L0P0K8Al06P0O9B80
6AlK01hU7`0K8Q`0=S`g01`R7`0Q9b@0:Bl]01hW900L9B8072DT01PR8P0S;Bd08bd^02Te=P0h@d@0
9c<c02Da;00T<BT08S8Y02<b:`0T<b`093D^02Ph=00X>C@0:3/g0P0[?S/0>00Z?C/0;d5102do@00/
?Sl0;3hn02do?`0/?Sd0<4=102i1?`0aA440<TE10313?P0_@Sd0=DY503a@C@0dB4H0;d=203Y>C`0f
BDd0A5MN041CF`1;GFL0BE]W04IHI@11Df40H79n05MYL`19FfD0AUUQ04UKI017FV40BeiT04mRJ@1;
GV@0BeiS059UJP1@HfP0DFI[05AXKP1EJ6h0FFa`05e_L`1LKW80G6i`05i]L01OKW40J7Qh06EcM01N
KVh0IGIe06AgM@1ZOG/0K7mm07B4P`1mSH`0N8R70`1kRHT00`1oRh/0PHb>08>AU@0208BAU`0Q08RD
VP2<Uid0SiZP096KX@2EWJD0U9bT09JNY@2LXj/0XJF^0:NY]02_/K/0/K:m0;:b_P2g]/<0_K_80;jk
bP31_/h0a/3B0<W4e@3<a]T0d<OJ0=kBiP3[go<0j=__0=c@i03OdNH0iMO/0>OGk03ZfNl0kMgb0?3N
m03`gO<0lmoe0080m]kf103ggoL20?KNmP1H0?GMm@3dg?@0lm_c0?;Kl`3_f_40kM[`0>_HkP3Yend0
imG[0>?Bi`3Pd>D0g/oT0=_=hP3Jc>00f<[N0=O<g@3Db]X0d<OF0<c4d@3;`m00b<7>0<:laP34_/P0
`[k70;fj`@2k^;l0^k[00;Be^@2b/kP0[Znd0;6b]`2][[40ZJf^0::XZ02LXZ40UYbK08RASP23S8P0
Q8f808F?Q`1mQgl0LG]b06ahK01]NFd0JgMZ06EcI`1SLFD0HW9X06EdKP1YN7@0K7aj07N7Q@1SMW<0
G6m[05U/J01JKFX0Ffi[059UHP1FJFH0FVeY0723O`1jSHX0A5MC04]ME`0oDD/0=4I003E5@00a@Cd0
<d8o02Le<P0Y=SD082`/034l?00e@440>dI803E0A00a?400:SDg02Pc=@0Z=SH0:cLe04IBD00Z=S80
9C8[02Xg<00S<2P09S<Z04EAC@80:cLc00L08RhZ02Da;@0d@3`0;CTe02/g<`0^>SH0:CDa00808RhZ
01/07RLR02@]:00P:B@09BhY04mHD`0]=S407bPS02L`:`0P:B@0;3D`01`U800Q:RL09Rl_04mHF00R
:b/08BXY020Y:00K92<082TX01XS8P0J92<08B/[01XS8`0N9bH07b@Q028W8`0N8al00P0L8Ad0200N
8al041DA024V8P0O92007R<O01DJ5P0T9bD08R@S0P0M7ah01P0H6QT06A/J01/M700Y:bX0=CLf02HX
9`805aTH00T061/J01/O7P0S9B@05QPG01<E500K6a/05aLG01HF5P0F51D00P0H5QL0100G4a@04a4@
014@3P0H5aD201<B400701@C4@0Q81h0=SDc01PG5@0D4a405aHD01@C4@0301<B408051<A00H04a8@
00h=2`0?3P`051<A01HE4`0C4Q02014@3P0I01@C4@0?3P`05A@B00h=2`0B4@l051<A00T81`0D4a40
4A0>00l>300@3``03PX701DB3@0@30T04Ph;014=2P0C3`h04@d<010<300A3@h04Ph?014=3P0@30d0
4`l>018>3@03010<2`0400l;2P0=2@P05A4@00X71P804@d<01D04`l>00h:2@0?2`X05A4@00h:2@0?
2`X0510?00h:2@0D40l02@D5018>3@0?2`X040`;00l:1`0C3P/04Pd:00h91P0E40d09b8O014<2@0D
3``00P0A30T2018=2P04018=2@0@2`P03@P500h91P804P`<00X040X:00/51`0;1@L03`T;014;3@0?
2@T03`T8010;200>2@H03`X70P0@2`P00`0B3@X04`h;014<2@0200l:1`08010;200>2@H040/800l:
1`0B3@X03@P500l:1`0=20D2010;20803`X700<050`:00d40`0=0`800P0A1`H02@0B20L05@/:0188
1`0A1`H04PP701<9200B20L04`X:00X51@0200l92@0500h8200C3@d030H600d71`0>20P00P0?2@T0
200>20P03@L700P30`0A2`/050h>00d71`0@2PX03@L70P0>20P02@0@2PX03@L700d71`0A2@T04PP9
00l51P0F30d05@/<0147200201<92P0701882@0A1`P040H701061`0D2``02@<300d71`0200`61P05
018<300?2@T03PP8010:2P0A2`/00P0?2@T201882@@04@L80`0@1PL06`0?1@H04@L800l51P0=0`@0
2`<30147200>10D040H701882@0F30d05@`=01hD5@0<0`@050X;00`3100@1PL03`D60147200@1PL0
3`D601H<3@0>10D04@L801/A4P1EBd`04@L801882@0Dooooo`006oooool01P0C4A804Q0A010>3`0?
3@h03P`=00d;30804Q0A0P0A3a005@0@3Pl03P`=018@4@0?3@h03@/<00h<3@0?3@h03P`=00L51P0I
5aP06QPI00/92P0I5aP00@0003@c<@0O7Q`02`X8014@3P0B4@l03Pd;010?3@02018A3`06014@3P0>
3@/03@`:00h=2`0A40h040l=0P0=30X00`0>3@/03`h<010?3@02010?3@803Pd;00@040l=00l>300?
3P`03`h<0P0>3@/2018A3`0:014@3P0@3`d03Pd;00l>30081`D051<A00d<2P0:2@L040l=00l>30<0
40l=00X04A0>018A3`0B4Q00410>01HF50051@<02@T701@D4P0o?cd061PF0P0A4@l200T91`0C01<C
400B4`h04Q<>018C3P0H6A@05AHA00d>2@0?40/06Q/F01DF4@0F5a80<34/01PH4`0920@02`X601@C
3`081`<03`h:01hM6@0201HE4@0@014@300P7a/03@`8018A3@0D4`l04Q4=014@300B4@d03@`801<B
3P0?3PX03Pd901<B3P0E51004A0<014@3P8040l=00@04A0>018A3`0B4@l04a8@0P0B4@l04P0A40h0
4Q4?01<B400F4Q40510?014>3@0>3P`04A8@018G4`0?51003Pl=01<C4@0L6aT06aPG010<2`0@3`d0
4A4?00l?3@804A4?00X020P6010@3P0K6aT03Ph<01<C4@092@P06AXE00h?2@0@4@T04A8:0P0A4P`0
200@4@/02@X501LG500820H03Ph<01hN700=3@/03Ph<0P0?3`d06P0@40h04Q8@018B400A4@l01PH4
00h>300D518030`:00P81P0D5QD03@h@018C5@0C51H020T;04m@DP0Y:R`02P/=010A4`0D5AT06a`P
00P92`0E5A805aPC01PI500B4`h01PL20P0B4`h01@051P404Q<>010A300=3PT05QLB00804A8=00`0
4Q<>01<D3`0D5A0051D@020Q700;30L03a0;01LH4`0B4`h051DA01XL6@0G6AH201`N6`0>014C400D
5Q<04aDB01`N6`0Y:bP07R0M01DG500Q92406QlK018G4`0C61@06AhJ01hS7`0F6aL201DJ5P0m01TN
6P0K81`06AhJ01DI5`0F6QT051PG01/O7P0H71/041@C01TM700/<2l05QXI01DI600R9RD07b<R01TO
7`0C6AT082HV02L];@0K8B406R0P02D[:`0S:BL051XG028Y8P0K8Q/051/D01XP700R:2@08BLU01DN
6`0G81d05QlN01/U9P0U;c007RPZ02Ha<`0lAd/0:SDh02<_;@0S<2T08S4Z02<b:`0T<b`093D]02@e
;`0U=S00:3/g02/n?00/?cd0:cdl02Tk?@0[?Cl0;Cm102do?`0^@400;Clo03I9A`0cAT@0<DA203=6
@P0203A7@`0=03A9A00gBdT0>4a:03Q<B`0nDE@0A5MK04QKH@13EUh0FF]e04eOJ`0nD5`0BUaX04YL
IP0204UKI@80BUaV00/0BE]U04YLIP1@HfX0D6=Y04ePI01>HFD0E6M[05Q]LP1GJg40EfY`05U/L002
05e_L`0;05maL`1SLWD0JWUl06YjNP1XMWL0JWYj06QiN01ZOG/0KH1n07:5P`1hR8L00P1iRHP09P1j
R8P0NHN707Z8R021SHd0Q8nA08JDV026TiT0R9FK08bGW@2?VZ00TIbR09FNY@2GWZH0V9nW09bSZ`2R
ZK40Z:be0:^[]`2`/;`0/k>o0;Rf``2m^lT0`;g<0<>ocP38`M<0blCF0<g6f03@b=d0eL[O0=_>hP3Q
e>P0i=O[0>CEjP3Ven`0j]W_0>gKl@3_gO<0ln7g0P3eh_P00`3hhOT0nN7i0?WQn@040?WQn@80n>3h
01H0mmog0?GMm@3egOD0m=gd0?;Ll`3_g?80k]_a0>_HkP3Ye^`0j=K/0>OEj`3RdnP0g/oT0=_<h@3J
bn00el[L0=G:fP3Cb=P0clOD0<g5dP3:`/l0a;k80P33_LL0<P30_L@0_K[10;Vf_@2c/[L0]kRl0:VZ
[@2XZJ/0ZJZ/0:FYZ@2PYZ@0VZ2N08Z@S@1oR8<0P8V408><Q`25ShL0OhV107AnM@1/N6`0JGEY06Mc
I`1aOW@0Kgab06]kLP1[NWL0JgUi06UiN01TM7<0GW5_05IYI@1GJVH0GW5]05mbK01EJ6@0FVeY05IY
I@1TMg<0Kh9o04=FE015EE80@55;03E6@00eA3l0=DA002hm>P0X=c@09C8a02Pd=00hA4@0=T930P0d
?d402`0^>C/0:SHf02Lc<`0W<c40;c/i02`h=00U<R`0:3D^02`i<P0/>C00<3df0080:SHb00`0:CDa
02Xf<P0]>CD0;c/g02Pd<00U<Bd0930/024]:@0K9b<062@P01/T7`0Q:RD202</9`<08BXU02007RLR
02Xc;P0T;BP06B8M01LP7@1?FET0n?oo075kO00J92<09Bl^01hX9`0O:2L07BHU01LP7`0R:bX092d/
01XP7P0O92009R/W02DZ9P0O92007B8N01HK5`0k@3`0HfQT01@I5@0X;BT07b@P01LJ600J71/06adL
01`N7@806adL024071hM01lQ800P8R406Q`K01HH5`0I6aX06A`K02@X9`0>40l07R0O02X/:`0=3@d0
5QHF01LG5`0I5aP061HG01XH6@0J5QL061DE01PG5@0G5Q@04a8@010?3@0D4a402@P602/Z:00=30X0
4A0>01TH5P0E518051<A018A3`0C4Q000P0D4a406`0B4@l07A`J00l>30030P0020L500d<2P0A40h0
40l=018A3`0C4Q004A0>010?3@0?3P`01PD302LV900;2PP02PT701<B400F5A80920M01DB3@0C3``0
7QXG00/7100>2PT03`/:01<?3`0201HB4`0301<?400?2``04@d<00803`/:00d04@d<018>3@0?2`X0
4`l>00d9200?2`X05Q8A014=300300005Q8A01<?3P0300005A4@008030P70P0?2`X200h:2@8040`;
00<05A0=018=2P0@2`P00P0@2`P00`0>2@H03`X700l:1`0200l:1`803@P501<04Pd9010;200?2PL0
3`X7010:2P0A2`/09R0P02<M7`0F41802`D700h82P0:10@03PT7014<2@0@2`P03@P500h91P0@2`P0
3PT600803`X700<03PT600l:1`0@2`P01`0=20D2014<2@0E00h91P0=20D02`D401/A400N51<04`X:
01471P0D2PT03@@401061@0?1@@04@L601<9200A1`H040P700T30`0E3`l040X:01dG5`0Z92@04@/;
00D03PP800L03`T900P20P0I4a<08adM01@>3P0F410040X:00803PP800T03`T900h8200>20P04@T:
00/10P0D2P/06a4B00l51P0D2P/00`0B20T03`0A1`P040H701061`0:0@8071HF010;2`1ZI6@0Dde=
00X4100A2`/040X:00l92@0=1`L03PP800l92@060147208040H70P0A1`P201882@0601dC500@1PL0
4@L800`20`0=0`@02`421P0@1PL01@0>10D04PP90147200B20T05@/<00804PP900D040L702HL7@1J
D5404PP900l51P0Dooooo`006oooool2014?4004010>3`0?3@h03`d>00h<3@@040h?0P0?3@h2010>
3`0?00l=3P0=2``03P`=010>3`0U8b@0C4Y;00/92P0=2``04@l@018@4@0h=cD09bHT0040000A40h0
2PT700803`h<00H04a8@01DD4P0D4a403Pd;00`;2@0=30X2010?3@0500l>300>3@/03`h<00h=2`0?
3P`00P0@3`d200l>300400h=2`0?3P`03`h<00l>308040l=01<04A0>00`;2@0>3@/05A@B01@C4@0C
4Q000@0002d/:P0;2PP03@`:01HE4`0=30X03Pd;00l>300F5A<06APF01DD4P0?3`d03Ph<00804A4?
0P0K6aT02`0^;R`03@d;01PH5P0A4@l03@d;00/;2@0B4Pl051D@01LH4`0A4Pd03Pl:0080414<01H0
4a@?02l`:`0K71L051D@01XK5P0B4Ph03Pd900/:1P0V9B405aHB014@300W9R805aHB01@C3`0A40`0
71/G018A3@0<2`L040l;00l>2P0=30P040l;0P0B4@d01@0?3PX03Pd9018A3@0D4`l04A0<00804Q4?
00<040l=00h=2`0?3P`00P0C4Q02018A3`0N014@3P0B4@l04a8@01@@3`0C3`h04Pl>010@3P0A4Q00
4A<@00lA3P0A4Pl04A4?014@3P0C3Pd04Ph=014@3P0A4@l06ATG01XJ600B4Q003@d;010@3P0<30X0
000001PH5P0T92803a0;00l@2P0A4PX04Q<;0P0B4`d02@0A4P`03Pl:018B3`0820H04A4?00P81P0?
3`d051@B018B4002010@3P0M018B400C4a4030`:01LG5@0A4@l03`l=018B400A4@l04A<@01<E500G
6AP04aDD03Xl>`3Adm80EEIH00`=3`0@4A<04Q<G00/<400F5aT051@A018C3P0P8A`061TD00l@2`0/
;BP05AHA01<D3`0@4@`00`0C50l2014B3@0=018C3P0C50l051D@01@E400<3@X06Q/F01PI50082@@0
004001TJ5P0G6AH02P`900T;200200lA3P0=01/M6P0B51407R0M03Li=P0L7Q/03a4>014D4@0?5100
6QlK01@I5@0H7AT07b@P01PM6@0201HK5`0H01TN6P0K81`06QlK01<G5@0I7A`061`K01TM700K7ah0
5QXI01@H5`0N8R405ATH028V9@0O8b804ADD01PN700G7A/0728R01lT9`0L8B@0728S018H600I7ad0
7R@Q0P0P9b00CP0N9Ad06b4M01lU8@0M8al05QlL01`U8P0S;2/072HW02D_<@0T;C807bX^02Ha=`0Q
;3008Rh/028^:P0R<BX08S8X02<c:@0S=2X09SL_02Lh<00W>SD0:C`j02/n?00/?Sh09cTk02Tk?P0]
?d40;T120312@`0a@d<0=TQ80395A00aA480<dI403M:B00hBdT0=DU703M;BP0lD4l0@EEF04IJG017
FUh0@EAJ04MJH@0aA4/0;T1:04mQJ`0oDE/0@eMP04MKHP1<H6L0BemX04MKI@12EUl0C61Y04mSJP1?
I6T0C65T04mTIP1EJVd0G75f05M[L@1JKG<0FFa`05U[K`1NL7@0G6i`061_LP1UM7L0IWIf06IdM@1W
MgL0JW]j06]nO01^PGl0LhJ407V9R080NXZ90P1lRXX09`1mRh/0PXj>08F@TP28TiP0RIBJ08^FW02?
VZ00TibS09FNY@2GWZH0VZ6Y09bSZ`2RYZl0ZJff0:fa^P2_[[/0]K?00;Ne`P2l^<L0`Kg<0<K0d@39
`]@0cLCI0<o6f`3Ab=d0dl[O0=W>h`3PdNH0hmCY0>OHk@3[fNl0k=[`0>oLlP3bgoD0ln3f0?KRn03i
hoX0n^Ck0?cUo@050?gUo@070?cTo03jh_X0nN7i0?SPn03ggoL0m]kf0?GMmP020??LmP0N0?7Jm03/
f?40j]K_0>[Gl03Zf?00i]C/0>3Aj03Od>L0g/oU0=K9f`3FbMX0eL[J0=76e03>`m40b<3=0<S0b`35
_LP0`kg70<G0a`32_L@0]k>j0:f//@2h^K/0[:f_0:Z[[@2`/[40ZJf/0:2VY02HWYX0Ri6<0P22S8@2
08F?Q`0_07j8P01bO7<0JWIZ06YfJP1/N6`0N8Ek07>0M`1[NW@0K7]h06ilO01[Ng/0IWIf05]^K01I
K6P0G6m[05iaJ`1PM6/0DfIP05Y]I`1AI600Cf9N04]NG@14EeD0AeMD03e<A`0jBD@0>dY503=2?P0]
?3T0=4=002Xh=`0fA4@0AeEE03U7B00hATL0;3Ph02Lc<`0U<Bl0930^02Da;`0^>SH0930/02Te<@0`
?CH0;CXc02Tf;`0^>c@00P0X=3008`0Y=C40;3Pd02Xf<P0Y=C40:SHb02@`;00Q;BT082`X01dY9@0K
9b<072DP020Y900Q:RD08R/V02</9`0T;BP082TT03i7@P1RJfH06B8M01`U800I8Ql09c8c07=oO`0n
BTX0:38c01TS8P0P:RT0>450059KF00`>CH04QPF028X9P0[<Bl082DQ00809b`X00/08RLS01hS7`0O
92005a`H02/`;00U:RH07B8N00L<200J7Q/061XI01TK6P0301XL6`0J01/M700G6AP04aDD01<E500G
6AP06A/J01HI600S9bH030h=01<E500T9RD03`l?01HF5P0J6QX071XK01DC500F51D05a<D01PE5@0K
6QP061LE01<B400A40h05A@B00X91`0H5aD2014@3P0301DD4P0C4Q0051<A00804Q4?00<04a8@01@C
4@0B4@l00P0D4a401@0J6AL06APF01<B400C4Q004A0>00<040l=0P0?3P`03P0T8b40M7=a01XI5`06
1@<04Q4?00L60`081040;2TT02hZ9`0@30T07QXG01@@3`0?2`X0510@0P0I5AH03@0D41403`/<00l;
2P0>2PT03`/:014=300C3`h04@d<00d9200D40l05Q8A018>3@0>2PT00P0?2`X01@0A3Pd0;2PW00P4
0`0J5QD01`<2008040`;0P0>2PT200l;2P0701@?300@2`P03`X7014<2@0>2@H02@@100h91P0200l:
1`0400h91P0=20D030L4010;1`803`X701@040/8014;2`0B30`05@l?00L10`0C3@l05a4C01@>400A
2`/04@/:014<2@0@2`P03PT600d81@0>2@H02`H300X50P0<1`@040/8014<2@L040/800<03@P5010;
200@2`P00P0>2@H04`0A2@L02P0000L0000A1`H06a4@01T?3P0?1@@040H500h40`0@1PD04@L60106
1@0?1PH03PP801H@400;1@D081XJ02`V9P0A2`/01P0>20P00`090`<0618B024K6`0201@>3P0400l9
2@0>20P03PP800l92@803PP800H03`L700h41@0e:b`0AC/l02DK700@1PL301882@0=0147200@1PL0
40H700H0000Q6a/030L706QRHP1=AdL030L7014;2`0@2PX03`T900d71`0200h820H04@L80P0@1PL2
014720804PP900H0;28S01T?400B20T040H701882@0:004601061`0<00h41@0E2``0308300h41@0F
30d0200000l51P0D2P/0D4I704<i>P0G3@h01`005?ooool001_ooooo1@0?3@h00`0@3Pl03`d>00l=
3P0200h<3@0F010>3`0A3a003P`=018@4@0A3a003P`=00d;300A3a00>cTj04a:B`0E4a@040h?01dK
700G5AH04a8@00`;2@0?3P`04Q4?00X91`0B4@l03`h<010?3@804A0>0P0>3@/0100=30X03`h<010?
3@0A40h2010?3@0300d<2P0>3@/03`h<00<040l=0P0>3@/00`0?3P`040l=010?3@02014@3P0300h=
2`0C4Q0051<A008040l=00H0:bXX030_;@0H5aD04a8@00l>300@3`d200h=2`0/01DD4P0I61H051<A
010?3@0?3`d04A4?01DE4`0820H04A4?06i^K00N7Q`03Ph<014A3`0820H05ADC018B3`0B4`h051D@
010A300=3PT03Pl:014B3@0<3@P09bPS01<D3`0F5a803Pl:010@2`0D4`l04A0<02l^:P0I61@03Pd9
03hm>@0Q81`04A0<00h=2@0B4@d03`h:01/J5P0N7AT061LC00h=2@0?3PX2014@3006010?2`0?3PX0
4A0<018A3@0@3`/04A0>0P0C4Q00100?3P`03@`:018A3`0C4Q02018A3`0A014@3P0B4@l04a8@01<=
3@0D3Ph0510?018A3`0@4@l03Q0=010B3`0@4@l03Pd;00h:2@0A30`05A4@01@C4@0A4@l00P0L71X0
2`0B4Q0051@B01<C4@0R8R003`l=01@D4P1EEE<05AHA00h?2@0@4@T04A8:00<04A8<02/05AHA01DF
4P0F5Q@05aLE01<C4@0?3`d07QhL01XJ600D51804Q8@014A3`0B4Q00410>00h>300C4a403`l=00d=
2`0C4a404A@?014C3`0?4@d05QPE00d>300Q8b406A/K01PI6`0:2`d05QLJ01<D600E5QP05QHC00h?
2P0C50l04A8=01@E400b<bh08B8M03Xk=P0E5Q404a@?01dN6@0=3PT05AHA008051D@00/04a@?018C
3P0A4Pd05aPC01DF4@0H6A@05AHA01TJ5@0E5Q805ALD00lA3P0201DG501600lA3P0J71T04aDB01DG
500O8Ah051HC018D4@0]<2d08bPT01<H500A5Q805Q/G01PM6@0C61@051TE01<H500E6QH05a`H01HK
5`0I7A/0:Bd/02@X9`0F6QT061`K01HJ6@0K7ah04ADD01DI600P92<05a/J01/O7P0H7Q/06b4N01PN
7P0G71l0724T01hS9P0S:2/061hN01`R7`0H7QX061lH01TP600K8Q/06b4M03Dk=`0C71T07RLT01/T
900N:2X082X/02</<P0N:C0072L^01lZ;`0R;Rh08RhZ028a:`0R<RP08c<Y02<e:P0Y>S40:S/c02Pk
=@0X>cT0:C`j02i0@@0]?d<0;d540353AP80<TA603<0<TA503=5A@0`@T80<49103=6A00hBdT0>Te<
03Y>CP0iCDh0@EAG04ULG`1:GF40@eIK045DFP1EJ6l0EfY`04IIH01:G6@0AEQN04aPIP1<HFL0BemV
04UMIP1:GVT0CF5/059VL@1BIVh0D6EZ04mTI`1CJ6T0F6e^05U^L@1OLgP0G6me05e`M01QLgL0Gg5e
05]]K`1OKW40HW5d06EeM@1WMGH0IWIf06YkNP1[OW`0KX5o07:5P`1gQhH0N8R707V9R01oSHd00P20
SXh08024T900QY6C08RCV029U9X0S9NM096KXP2FWjH0V:6X09VPZ02NY:`0XJN_0:N[]02]/KX0/[Fn
0;Bb`02j]lD0_;W70<6kb`35_m00blCE0<o7fP3CbMh0e<[O0=G;h03HcN@0gm;W0>CDj@3VeN/0k=[`
0?3Nm03ag_@0m>7g0P3ghoT08@3iho/0o>Gm0?kWo`3ojOl0o^Wo0?oXo`3ojOl0o^Wo0?oXo`3nj?h0
nnOm0?cUo03jiO/0n>Cj0?WRn@3ghOT0mmoi0?KOn@3dgOL0lM[d0>gIlP3/f?40jMK_0>GCj`3Rd^T0
hm?Z0>GFk03JcMl0fLcM0=G9f@3=`]00bl3>0<_2c`020<NobP0>0<Bmb031_<<0`;_20;jj`02c/kD0
/[>d0:j`[`2_/K00XZBR0:2UX@2LXYh0TYRC08R?R024SXD2086;P`0I07R2N@1dOWH0L7Ya071lL01d
P7@0N8Ah07F2N01aOWD0JGQc06UgM`1XMWP0Hg9e06]jO@1OLW40H7=_065dL01LKfP0FfmV05=WGP1G
Jf<0CV5K04mRH01DIVD0CemN04QGE00203Q5@@0>03Q6@@0^?3T0;C`i0391?P0nC4/0@e5A04UGE`0g
ADD0:cTi02di=P0Z=S80:SLa02Pd<@0X=30302lk=`0<02`h=@0Z=S<0;3Pd030l>00Z=S809c<_02Hb
;P0Y=C40:3@`02Lc;`0Z=S808bl[0`0O:bL01P0N:RH08R/V028[9P0Q:RD082TT024Z9@808b`W0140
<c`g04QAC00I8Qd07BHQ01hY9@0M:RX092l`01dX:@0R;Bd05b4Q02<];@0T;B`08bXX01hU8`0Q9b@0
9BXW02<Y9P0201lT800;020U8@0N8al07B8N01/P700P9B406b0L01dR7P1<DDd0;C8^01PK6@0K7A`0
0P0L7Qd05P0J71/061XI01LI600G6AP06A/J01`N7@0K7A`05QPG01HI600>4Q40;c4`01TK6P0=3`h0
:RXZ018B4P0F5QH05aDF01PF5`0M6a`06aLH01DC4P0G5Q@401DD4P0301PG5@0;2PP061LE008040l=
00D04a8@01@C4@0B4@l04A0>018A3`0201<B400J01PG5@0A40h04A0>01<B400<2`T03Pd;01DD4P0?
3P`03Pd;014@3P0?3P`04A0>01LF5016AD<04a8@00T81P0N7A/03`h;01TE4P1WI5l0LVi[00l;2@0@
30X04Ph=014=300C3`l201@@4@0501<?400A3@h04@d<010<2`0?2`X00P0A3@`03@0?2`X03@T800l;
2P0=2@P02`L600l;2P0G4a8030P801dJ6@1BCTd030T8018>3@0D40l00P0A3@`05@0?2`X03PX900h:
2@0>2PT04@`9018=2P0A30T040/8014<2@0C3P/040/8014<2@0B3@X04@`900h91P0=20D03`X600l:
1`0@2`P04@`9014;2`02018<300A018<3P0=20T0B494055;C@0H4Q804`h<018=2P0A30T03`X700h9
1P0=20D04@`900`7100=20D040/800h91P0:1@801P0>2@H500l:1`0701081P0X81l0OG=b020F5@0=
10<03@@401@:2@0501471P0701D=300B30`04@/;00`61P0?2@T050h>00d71`0600h8200600d71`0B
30`05@l?00`61P0;1@D030H60P0>20P0200?2@T03PP800h8200A2@X040H701<:2P0F3@d040H7100B
20T02@0A1`P040H701061`0F3@h02`D500l92@0@2PX03`T900h8200300l92@0300h8200=1`L03@L7
00H04@L80P0@1PL2014720804PP900D06a4B00l51P0B20T040H701<92P0701061`0<01882@0@1PL0
3`D600d3100=10D05`d>01<92P0G3Ph0H5IG05E;C00C2@X04@L85?ooool001_ooooo100>30d200l=
3P07018@4@0@3Pl03P`=00h<3@0@3Pl04@l@00h<3@02014?400:00l=3P0>30d03P`=00l=3P0@3Pl0
6QPI014?400I5aP03@/<00d<2P<03Pd;00<071/I00T81P0=30X00P0<2`T0200=30X03Pd;00l>300?
3P`03Pd;010?3@0B4@l040l=0P0>3@/00`0?3P`040l=010?3@0200l>300400h=2`0?3P`03`h<00l>
308040l=0P0;2PP07`0A40h03Pd;00`;2@0A40h0BdY801DD4P0?3P`03Pd;00L6100F5A<040l=00h=
2`0@3`d04Q4?010?3@0A4@l02PX8010@3P0F5Q@04Q8@02d]:`2EUI<0:BTW010@3P0F5Q@02PX801TI
5`0?3``03Pl:00d>2@0A4Pd00P0@4@`0600E5Q404a@?01HG4P0>3`X04Q<>00d>2@0C4`l051<?00/:
1`0G5Q801`H2010?2`0K6QH03Pd9018A3@0D4`l04a8>00d<200G5Q806APD01@C3`0=30P03`h:014@
30<040l;0`0?3PX00`0:2@L030/900l>300200l>300>014@3P0C4Q004Q4?018A3`0A40h04Q4?01@A
400C3@d050h>01<?3P0A40h03`l=00d?300@4Pl200l>300@01<?3P0F4A005A4@014@3P0@40h04a<A
018B400>3P`04Q8@00H6100D51800P8000/;2@0E5A<01`P300d>20803a080P0@4@/02@0?40X020T4
01TI5P0L71X01`L5018B400<30X051@B018B4002010@3P0N018B400C4a403`l=01lO7@0@40h06QXH
02DU8`0F5a803Q4:01XM5P0A50d010H301LI5P0D5Q<051HE010A4`0O82807AhP00H72`0:2`d05AHB
01DF4@0A4Pd0414<00/<1`0B4`h092DP01@E400<3@P04A8=0P0E5Q400`0B4`h04a@?01<D3`0201DF
4@0=01HG4P0E5Q40Gf1K04Y;AP0?40/09BHQ01TK5`0E5a@03a4>01TK600G6AH0418?01@F4`0201DG
5007014C400H6QL06A/H03Pk>00[<2`03a@@01HK5`0201TN6P0401LL600F6aL051TE01DJ5P805a`H
03006AdK028V9@0L81l05QXI01PL6`0F6QT05ATH00/?3P0/<2l0@TI502X^;@0E6AP061hJ01XP700H
7Q`061dP01`Q900M8RH06AhQ01hS9P0S:BL08BPQ01dT700P:1d09RdV02D[9`1=Ddl07bPU02/d<@0P
:2X07bT[01`U:P0N9bh08R`e02<]=P0T;SH08bl_02<_;@0S<R`093</02@d:P0T=RX0:CX`02/l<P0Z
?CL09cXh02Pj>P0^@4830312AP0>0312A00_@D<0;Cm103A6AP0cADD0=DM703U<BP0mD4h0?Dm?03U<
D00jCE80@UEI04YMH@1:GF8204=FG00H05=VK01dQhd0Gg9h045DF@18Ff40@EIK04YOI@1?HfX0CV9]
04iQKP1@Hg40E6Qc05AXL@1CJ6d0E6U/05I/J`1IKVl0Efa_05a`M@1EJ6h0EVU]061bMP1RM7P0H79d
0P1UM7L0201ZNWX0Kgen06alO01_P7l0L8>107:5P`1fRHL0Nh^:0P1lS8/0:@21Shl0PY2@08BBTP27
Ti<0RIBF08ZEVP2<Uid0SYVO09BMY02HXJP0VZ>Z09^RZP2SYk00YZZc0:^_^02`];d0];O00;Vfa02n
^/T0`;c;0<Bmc@39`]@0c/KH0=?:g@3Gbn40fLgS0=_?i@3Nd^X0i=G/0>WGk@3[fNl0kmgc0?;PmP3e
h_P0n>Cj0?_Uo03li_d0o^On0?oWo`3oj?l0o^[o00L0oN[o00T0o>Wo0?_XoP3jiod0nNKl0?WTo03j
h_`0nN;l0?OPnP3dgOL00P3`g?D03P3^f_<0jMO_0>CBjP3Rd>P0h=3V0=_<g`3Ic=d0eLSI0<o4dP3A
a]@0f/oM0<NobP38`</0a[k90P2m^;l02P34`LL0_Kfo0:V[ZP2RY:<0Z:ZW09NIUP2^/jl0YZfV096H
T@1iP7T2075kLP0a07Z4N`1cOG@0LWac07=mM01fPWH0N8Ah07N3N01dPGP0Lh1i06imN@1YMgP0IG=g
069aMP1VMGP0IgUi06=fLP1PLfl0GW5Z05M[HP1BIUd0BemG04ULEP12EE<0E6IV04=CD`0mC4T0=D4m
034m>@0_>cL0:cTe02`k>00[>SL0AUEC03i<C00iAdL0;C/l020^;P0_>cL0;S/c034n=`0^>c@0:CD`
02`h=00Z=S80:cLd02/g=@0`?3X0;c/i02@`;P0202Te<@809c<_00D0:SHb02di=@0T<2`07b/W01hZ
9P0201l[9`0H01hZ9P0U;RT09BhY028[9P0O:2<07RLR020Y900N9b80624L00lH4`0N9b806R<N01lZ
9P0S<34041/M02Lb=00O:b/06B<T01lY:P0Z<c80:2h/02`b<00O9B405a`H0P0Q9R801`0K81`06QlK
01dR7P0O92007R<O018G4`0>4`l00P0P9B401@0G71P06QdK01PJ6@0I6aX071hM00<07AlN02407R0O
01lQ800J71/05QPG01LI600H6aX04QHE020R8@0E5aH03@l>01lO7`0P82005aLG01@B4`0I5aP04a4B
010<3@0A3`h04Q4?01<B400F5A<061LE01DD4P0K6QP01@@201HE4`0>3@/040l=01DD4P0D4a404Q4?
00l>300@3`d00P0B4@l06P081`D02`X800l>30030P0030/9051?C@0L6aT04A0>00d<2P0B4@l03Pd;
014@3P0G5Q@03@`:018A3`0=30X051<A00P7100;1`@040d801hJ5`0A3@X01`<001@@3`0E4A00510@
0P0B3Pl0100D41405A4B01<?3P0A3@`2010<2`0>00l;2P0=2@P03PX901LC4P0I5A@05A4@00l;2P0=
2@P07a/J00h:2@0G4a807QXI00P5100?2`X2010<2`803PX90P0?2`X00`0@2`P04`h;014<2@0200h9
1P09010;200>2@H040/8018=2P0@2`P03@P500/60`0?2PH040/800804@`90P0@2PX01`0=20P04P`>
00`6200M61T07aTK00@0000@2`T00P0=20D0100>2@H03@P500/60`0>2@H200`7100300d81@0<1`@0
2`H300H040/800<04@`900h91P0>2@H00P0@2`P04`0@20H08QPG09J<R`0M4a803`D400L0000A1`H0
4PP701@:2@0B20L04@L601881`0E30`02P@400L10@0A2`/02`D500`61P0B30`01@0>20P00`0=1`L0
3PP800`61P0300d71`04010:2P0>20P03PP800l92@803PP800H02`@401@:2`0J41406@l@01X@4@0?
1@H301882@070147200@1PL040H701892P0A2`/03@L7010:2P0200l92@803PP800@03`T900h8200=
1`L030H61P0A1`P201061`804@L80P0B20T01P0?1@H0308301X@4@0C2@X04@L801882@H040H700`0
5@/<00l51P0L4Q<05`d>01<92P0e:b`03P@501061`0?1@H0:R0Q00T10@0A1`PDooooo`006oooool2
00l=3P@03P`=01X0518C018@4@0?3@h03P`=010>3`0A3a0040h?00l=3P0@3Pl04@l@00l=3P0<2P/0
2PP9014?40081PL0518C00D3100K6AX040l=01DD4P030P003@`:01<B400:2@L030/900h=2`803`h<
0P0>3@/01`0A40h03`h<010?3@0B4@l03`h<00d<2P0?3P`00`0@3`d200h=2`04010?3@0?3P`03`h<
00l>30803Pd;00<04a8@00P71@0?3P`00P0A40h01`0E5180;2/Y018A3`0920H040l=00T81P0D4a40
0P0@3`d2014@3P0S010?3@0E518030`:00l?3@092@L02PX800<30@0K6aT02@T701/K6@0H61H06QXH
01LG5@0=3@X03a0;00h?2P0A4Pd03Pl:00l@2`0F5a807AhI014B3@0B4`h02@X500/<1`0C4`h04A0<
00h=2@0C4Ph01`H201<B3P030P002@P401/J5P0E51000P0B4@d01P0920@02`X600T8100<2`L04Q4=
01<B3P<040l;00D03`h:00h=2@0>3@T04a8@014@3P0200l>3003010?3@0A40h04a8@00804Q4?00P0
4A0>018A3`0D4A005@l?01@>3P0C3`h040l=00l>30803Ph<01@04A0>01<B400D40l050l?01D?3`0@
3`d05ADC01<C4@0@40h04A4?00l?3@0E5A<02PX800P81P0O7ad03`l=014B3@0>3`T03a08010A2@80
4A8<00P0414;014B3@0?40`0410>018B400G5aD03`l=00h>30803`l=0280410>018B400B4Q005aLE
00X:20051@<0@T9003Xj>0000@0030l:00d@1`0G6Q4082<L01DG4P0:30L04aDB020R8@1eMgH0H65S
01TJ700O8B004a<@01<D3`0D5A006AXE00l@2`0D5A006a`G00<4000?40/04Q<>00l@2`0F5a804Q<>
0P0C50l201DF4@0@01HG4P0B4`h07AhI01PI50082@@05AHA00T:1P0D5Q<092HS03m1?P0];b`0418?
00h@3@0G6AH061XG01@F4`806Q`I00X06AdI01DJ5P0J7a/0724M01<H500H7AT06QlK01LL600E6QH0
5Q/G0P0H7AT02P0C61D04aLF01<G5P0M8B007b<R01XN7@0P92<06alN01dQ800T:2L201lS8P0U01TO
6`0H7QX06R0N01`Q900K82<0724U028W:`1<DE@0?dE301/R6`0F7AD06R8G01@K500F7AH0;38^01<L
6@0Q:RL07RHX020Z;00P:Bh07bP_028/=@0U;cP092lg02@`<00U<Bl093<]02Dd;@0V=R`09CL[02Pj
;P0[?380;3li02Pk>@0W>CT0;Cm20312AP020353A`0b0312AP0_@D@0;T1203A6B00eAdP0>4Y:03a?
C@0mD4h0>de=03e@E00nDEP0A5MM04QKH@16FEl0@EAJ03mBEP11E5P0@5=G045DF01>HV@0>diB049G
FP1;HVL0D6M]04eSKP1:H6`0Bf5^05=YM01CJW80E6a`05E]K`1FKfd0EVm/05Q]L01JKW@0KH26065d
N01FJ6`0HG=g061bM01VMGP0I7=f06YjNP1`OWl0KGem07>4P`1cQX@0MXV707V<RP1nSXd207n?SP0U
08BBTP25Ti<0QiFE08bHV02>VI/0SYVN092IX02BVj80Uj2W09bSZ`2MY:`0WjJ^0:N[]02Z[[L0[[:k
0;>g`02f^L80_[W80<>lc035_/h0al3@0<g4e`3Ab=`0eLcQ0=[>i03MdNP0gm?[0>?EkP3WfO00kM_a
0?7Om@3bgoD0m>7g0?SUn`3mj?l0o^So0?oXo`020?o[o`030?oZo`3ojol0o^co00D0o^co0P3mjol0
4P3lj_l0n^Sn0?[XoP3ki_h0o>Cn0?_So@3ihO/0mMkh0?CMm`3bgOH0l=ce0>_Il@3Ve>`0hm7Y0=o>
i@3Ib]d0f/gN0=O:f`80d<CB04H0elcJ0<c2c@3;`L`0a[k90<6l``30^l80`Kg30;2`/P2SYJ@0WInL
0:FWY02KWIX0]KZd0:>ZX`2=U8d0Mgif079lL`1aNg80NXAi07EoMP1dOWD0MGmf07J2MP1gPgL0MX9h
07N4N`1hQGh0LH1l06IdM@1TLWH0J7Ml06AcMP1`PX80I7Mc05a_J`1NLFX0DVIK04MKD01:GEH0I7Ma
04AGE@10DU80=DE50350?@0f@Sh0<3`h02`h=00/>CH0:STf02ln>`0kBTP0=4920392@@0X>3L0:CLg
02Ld;@0Y=Rd0;c`c02dj<@0U<RX09C8[02hj=P0`?3T0;SXh030l?00[=cL072PX02hj=`0b?SX0;c/g
0P0V<Rh0800Z=S80930/02<_:`0U<Bd09S8^02@`;00R;RX092dX02D^:@0S;2L082TT01lX8`0P:B@0
6B8M02Pa;00S;2L08R/V01lX8`0Q;2P06RHY028`<@0B8240;cXl06YdM@0jA4D06b@S00T?3@0D6QP0
:Rl[020U7`0C61807b@P0P0J7a/201hS7`0901lT800M8Qh06AhJ01hS7`0R9b<09BXV01LK600F61L0
61XI00806adL02<071hM01dO7P0L7Qd06A/J01DG5P0C5A@05QPG01PK6P0C5aH05ALF01PJ6@0A4a80
5aLG02HV9P0H61P0518C01TG60091`P04@d>01dK6P0E51804a8@01HE4`0H5aD05QDC01`K6@0;2PP0
5aHD018A3`0C4Q004Q4?01@C4@0B4@l03`h<010?3@02018A3`0J014@3P0D4a404a8@00T81P0];2X0
/[6_024P7P0C4Q003Pd;01<B400>3@/04A0>010?3@0J6AL051<A01LF500F5A<061LD01PD4@0E4Pd0
2@H401HB3`0I5A803`/:01<?3P0C3`l2018>3`804`l@00<04Ph=010<2`0?2`X00P0A3@`03@0>2PT0
2PH5024M700U8B005A4@00`81`0E4A006QHE00P5100>2PT03`/:01DA400;1`H00P0?2`X200h:2@80
40`;00d03`X700h91P0A30T05Q4>018=2P0910403PT6014<2@0C3P/04Pd:00h91P0<1`@040/700<0
4@`901403`T900h8200C3@d01P0201XD5P0?2@/0100001@>3P0A30X03PT600l:1`0B3@X040/800h9
1P0@2`P04@`9010;200200l:1`03010;200C3P/04`h;00@04`h;00<04Pd:00d81@0=20D00P0A30T0
4`0I4Q001`00028H5`0C2PT07A<B01471P0C2@P04PP701<9200A1`H03`D401471P0@20L030H600P2
0P0=1`L03PP800/51@0@2PX01@0>20P01`0;1@D03`T900/51@0;1@D03@L700X4100?2@T00P0>20P0
2@0?2@T03PP800h8200A2@X04@L800/10P0900003P@501H<3@0301882@090147200@1PL040H700H0
000F41002@@400d71`090`<04P`<00803@L700@03`T900h8200=1`L030H61P0A1`P201061`804@L8
0P0B20T01P0C2@X04@L801hD5@0E2``04PP901<92PH040H700`04`T:0147200J41405P`=01<92P0X
7Ql03@<401061`0700004@L800d41009000Dooooo`006oooool04P0@3Q806ALJ02HT9P0?3A404@lB
00`:300B41@06ALJ00h<3P0?3A403@/>018@4P0B414030X;01<A4P0@3Pl0518C00T720803`d>01P0
5Q@E00h<3@0@3Pl03@/<00h=3P0D4a@02`X;014@4P0:2@/051<E00d<3P0920X081lQ014@4P0<2`d0
2PP:014?3P0@3P`04@l=018@3P0@3P`03P`:014?3@0@3P`2014>3@0<00l<2`0>2`X04Q4?014@3P0=
30X03`h<010?3@0=30X07QdK010?3@0?3P`04Q4?0P0?3P`0;`0;2PP05QDC00d<2`0C4Q003Pd;00d<
2P0B4@l040l=01HE4`0C4Q002`X8014@3P0<30X05aLE00/;2@0?3`d05ADC010?3@0:2PP04A0>01LF
500E518030`:028S800I6QH03@d:014B3P0=3@X0=cLd028S7`0C4a003@d:014B3P0<30T051@A010@
300=30P04A0<01<B3P0=30P03`h:014@300I61@08R4M01<B3P0=30P051<?00<03`h:00H04Q4=01@C
3`0@3`/040l;018A3@0C4Ph200l>2P0801<B3P18B4D08b<P010@300E5A404Q8>010@3@0B4Pl2018B
3P0M014A3P0B4Ph04a8?01<?3@0D3`h04Pl=014@3@0@3``03`l<00/;200F5A804Q4>018@3@0A3@/0
50l=00l<2P0H5a@02@T8014?3@0C4Q4020L7010=3`0<2`X03Pd;01<@3`0?3@X051@?00h?2@0@4@`0
0P0C50h09P0B4Ph03a0<01HF4`0D514020P6010@3P0<30X04Q8@018A3`0D4a405A@B014@3P0C4a40
8B4O03Lg=@0B4a40:R/Y01dN700=3P/05ALC01@F4@0K7AP0F5YE01XK5`0>3``0:b`X018C400D5A80
;Rl^02LX9`0E5Q<03a0<01@E400?40/04Q<>01DF4@0@4@`051D@0P0C50l0100F5a804a@?018C3P0B
4`h201@F40804aD?0P0B50h201@F400I01HH4P0E5a405ALA01DH4`0=4Pl03aDB01DH5P0E5aD04Q@A
01PI5`0M71X07adK01PE4`0P7Q/08QlM01HF4`0D6AD05AXF01HK5`0E6QH05Q/G01LL600E6QH051TE
01DJ5P0201@I5@0@01HK600D6AL051TG01dR8P0G6ad04aLI01XN800H7Al09BX/02hc<P0L8B00724N
01PM6P0G71X0724P01lT9080724S07L06b0S03Ll?P0U;2`0620M024Y9@0O9b807RHP01`W800O:280
6R@M028/9P0R;2P08B/Y028];00R:bd08B``02@^=00T;SD08Rh`02<b<00W>3@0:CTd02Li<`0X>S80
9cX`02Xl<`0/?cL0:chh02/o>@0_@T00<4=403=6B00aADP0>4]?03]>DP0[?d@0;T1503U=DP0jCU80
>4]?03iAEP0iC5D0BE]Z04AGIP1:G6P0B5aU03mBF011EUL0@EIE03iCD@15FUT0@EIF03mDE@11EUL0
B65O04aSI01=HfP0CF=Z059WL01GK7L0E6Mb05IYL`1GJg40Ef]_05U]KP1KL6l0GG5c061cMP1jSI00
Kh:405a/L01RLg@0HgAe06imO`1WMWP0KGal07N3Q@1cPH80MHF707R9R`1iRX`0O8^>082>T@22T9<0
QY>F08NCU`27U9L0SINK096KX02DWZ<0U9jT09JOYP2HXJP0W:B/0::W/@2TZK<0YZVd0:n__02b/l00
][K30;Rha@2k^/L0`Ko=0<O2d@3:`m<0c/GF0=?8g@3GbN00f/_S0=k>i`3Sdnd0i]K`0>WHm03]foD0
l]of0?GRnP3fhoX0mnGk0?_YoP020?k/oP060?o]o`3ol?h0oo7n0?oaoP3olOl0o_;o1@3ol?l07`3o
kol0o^ko0?k]o`3mjoh0o>[m0?gYoP3ki_h0n^Gn0?[So@3hh?`0m]kj0?GMn@3bfoH0kmWd0>_Hl03X
eNh0i=;X0=c<gP3Ocn00flcL0=74d`3>`]00cl?@0<k4c`3:`</0a;c70<6la02o^/80^;Fl0:NWY`2U
Yj<00P2LWYX0BP2LWYT0Vj2J08^BRP23RX80MGac07=mL`1dOW@0N89h07N1N@1dOWL0MX5j079nMP1c
OgL0Mh=m07N4OP1fQH00KGaj06EdM01[NW/0Jg]l06IiN01ZOg`0IGUd05Y^J@1EJV<0C65I049EC`1J
KVP0UJRU05QZJ00mCTh0;3`j02Xf;`0hAC`0:cL_02/h<P0^>cL0<Sln030o?@0_?C`09C<b02Lg<`0R
<Rd09SLa020_:P0]>cH0:cTd030n>@0Y=c809C8_02dj=`0`?S/0;S`i02dj>00]>cT0;3Pg05QTH00c
?CT0=D4m02/f<P0S;BX0:CDa02Ha;@0U;b`09S8^02Pc;`0U;b/082XV02</9P0^=S00:S8/02<[9@0M
9Al082PR0P0N9R007@0R:R@07bLQ02<[9@0L9b<0<3m2014O8P0M;2d08Bl_034l>`0Q:bT0<c`i02@Z
9`0Q9b@07B4N01dP7P0P9B406R4L01/Q700L8Qd07B<N01dS7@0K8A`06AhI01dP700L7a/04QDA01`P
6`0I71X061/J00805aXI00@06QdL01TL6`0E61L05APG0P0F6AP201DH5`0I018F5@0G6aX08RDT03`o
?P0I71/05aXI01`N7@0?410061TH04M8A`0T9BD06a/K02XY:00D4a4071/I01HE4`0E51805QDC01<B
400=30X04a8@01@C4@0F5A<051<A01TF5@02014?3@803P`:01/04a0?01XH5P0@3P`05A8A010>300H
5A@08R0N02HT8@0I5Q@04@h<01<@3P0@3P/04a0>01PF4`0Y9b@04Pl=01LD4P0=2PP040d:00P40P0F
4Q004Ph<01dI5`091@<04Ph=00h:2@0A3@`00P0@30`0500B3Ph040`<014=300>2PT04Ph=01<?3P0A
3@`0510?01HB4@0B3Pd0510?01HB4@0<20L05a<B02LS8P0H51<03@T800H20@0C3`h02`L70P0>2PT0
4@0;1`H04@d<010<2`0A3@`04Ph;00d:1`0B3``071LD01PE4@0;2@D040`9014=2P0B3``04Pl;018=
2P0A3@X03PX600804@`900H03`/8010;2@0A30/06aHE01HA3`0C3Pd2014<300>00l:2P0C3@`04@/:
014<2@0C3P/04Pd:018=200C3PX050l;00l:200K5Q<03PT701D@3P0?2PP200d81P803`T800h03PT7
01LA400E3`h040X9018<2`0?2PP03`T70109200D2PX040P8014:2@0C2@T04PT900d61@804@P80380
2`@300l61P0@2@T05Q0@018<300=1`L04`d=00l92@0=1`L03PP800l92@0@2PX03`T900h8200?20P0
50`=01<92P0A20T040P900h41@0@1`P040P901482@0B2@X040P901482@0?1PL05@h>00l71`0M51D0
2P<401<;2`0?1PL03`P801482@0?1PL03PL701D<3@0A20T040P901892P0D2P/04P/;00l61`0C2@X0
3`L800d51@0A1`P04PX;01061`H04@L800X04PP900`3100B20T040H700h41@0C2@X04PP901061`0E
2``04PP90P0@1PL04P0D2P/03P@500d3100A1`P04PP90147200@1PH04@L701061P0>10@03`D50106
1P0G3@d03`D501D;2`0@1PH04@L700l51ACooooo000Kooooo`0901HD6@0D4QL05A<H01LE6P081P/0
4a4F010>4`0A3a@02PP=00804Q0E00T02`T<00d;300A3a005A<D00800@0@3Pl06ALH00h<3@0?3@h0
0P0@3Pl0400?3@h03P`=00d=400>3A804A0E00l>4`081``05QDJ00X93P0H5a`040lD00/:3`0>3A80
820R014=3@0A3@`2018>3@05014=300@30/03PX900h:2@0@30/00P0E4A002P0D40l020L5014@3P0C
4Q001@@3010?3@0W9R@04Q4?010?3@0>3@/2018A3`0300l>300@3`d040l=008040l=00D04A0>00d<
2P0J6AL04Q4?00D40P0200X91`0I018A3`0C4Q004a8@014@3P0C4Q003@`:014@3P0@3`d02`X8014@
3P0?3P`02PT7010?3@0@40h01PH400l?3@0[:bT0X:2N07EeL`0C4a40410>018B400=3@/02`/900/:
1`02014@3009010?2`0?3PX03`h:01@C3`0C4Ph040l;00h=2@0=30P02PT500803@`800<03`h:014@
300A40`00P0?3PX02`0C4Ph05aHB018A3@0@3`/04a8>01TJ5@0<3@P03a0;01<D3`0H6A@02``700H0
414<0P0>3@T01`0@3`/04A0<014@300A40`051<?01`K5`0@3`/00P0B4@d0500D4`l01`@001LC3`0M
6AH071PI018>400J5AT05A0D018=400A3@`04`l>018?2`0=30L04A4?01<C4@0D51804a<A010@3P0>
3P`0410>0P0?3`d05`0B4Q007AdK01TI5`0G4a805A8A01DD4P0C4Q0051@B024Q7`0j>SP03@l<01<E
4P0>40d04QLC014F4P0C4a<02PX:04i>CP0S8b<07QhL00d=2`0F5Q@051D@00804Q<>0P0B4`d01P0F
5a8051D@01DF4@0E5Q404a@?010A30804a@?0P0D5A000`0C50l04Q<>01<F3`0501<F3`0;01LJ4`0E
61405aXC01PK500G6Q<051TD01PQ7P1RJ6H06AhM01LK6P0S9B800P0H5aD01@0H514071DC01491`0B
20H06QLD00806b0L01L05a`H01@I5@0E6QH05Q/G018G4`0D6AD06AhJ01@I5@0B5a<05a`H01HL600D
6QP05Q`L01@I700D6Ad07B8V014F6P0K82<07R@T018H5P0S:BD06alN01dO7P0301`P7`0E01/Q8@0O
9BD082HV01hV:00K8bD06R8T01/S9@0L9b<072LQ03@o>00]>3007b/Q02@`9P0R;BD08bhV02@^;00U
;c009Bla02H`=00O;bl0838b008093Le03d09CPf02Xm>@0Z?CL0:Sdg02/o=P0/@3D0;D4f02i2>00d
B4L0;T=40315AP0hCE00>DiB02a1AP0dB4l0>dmH0396D@15FF@0@EEQ04MJJ`1CIGd0DF9j04ePL@16
FVD0?55E03]ACP0lDdd0@EQA03mEDP11EeD0AU]M04AIFP1?J6D0CfIS04iSI01@IFP0EFQ`05U[M@1U
Mh<0EFM`05Y[LP1PLGP0FVa_05AVJ01OLG40GW1`061bLP1TMWH0IWIf06EeM@1[Ng/0JGMh06mmOP1d
PX<0NHB607J1Q@1fQ8X0O8VA07f:TP1lRI40PXbE0080QY2I02T0RY>L08fFW`2@VJ80TY^T09>LY@2I
XZT0UYnV09jW[P2QZ;80XJF`0:NY]@2/ZkT0]K;30;Vfa`2m^LX0_[[;0;nkc034`]00bLGD0<g6eP3B
amX0fL[Q0=k;i@3QcNP0hlo[0>WDlP3/eoH0kM[h0?7Nn@3ehOX0mn?l0?[Wo@3ljoh0oNcn0?g^oP3m
ko`0oO3j0?kbn`3om?`0ooCj0?oeo0020?oeo@030?odo@3olod0oo7n0080oo7n0P3okol0;P3okOd0
o^cl0?k/oP3kj_d0nNKl0?[SoP3jhOh0nMkm0?OLn`3ef_T0lMWe0>kGl@3Zend0iMCV0=c9g03OcMd0
fLSH0<focP3<_/d0bko;0<k4c`3:`</0`;S30;^e_`2h/[`0/k6h0:FUX`2OXI`0W9jI09fOVP2NX9/0
WjBM08V@R031b<00[;BY06QbI`1/MV/0NXAj07n:Q01aO7P0MH1l07Z6PP1oRhL0NhN506mnN`1bPGh2
06alN`0c07F5Q01YO7X0HGIa05acK01TNgD0G75/05=XH`17G5L0?e9@04QKF@1HJfT0?4a;02dm?@0b
@C`0=dDh038n<@0L:1h09c8Z02hj=`0lB4P0<Cdm01HT8`0N;BP0:STd01l`9`0`@CT0>4I602Pf=`0c
@D80>TQ802<a<@0e@d<0;Sdj02dl>@0`?c`0;C`g02Xi=00e@Cd0>48o020Y9P0`>CH0:S<`01hW900L
9B8092dZ024Z9`0S;2T09Bh[02@]:P0O:2D08bXT0080VZ6J02X09bhW02/b:`0/<b`08bXS020W800O
9Ql082LP01lV7`0L9b<0YkNk04AFF00L;2`03ahM01dY9`0T;b/07bPS01HL600O9B408B<R01`N7@0R
9RD072@N018L500@61407RDN01lV7`0H7QL06AhH020R7@0S9B00828M02<U800M81h0720O01XN7@0L
81l082@S01/O7P0D61L05QXI01LK6P0F6QT201<G5P0F018F5@0A5A@0310?01DI600<40l04aLF04mC
DP0C5aH06AdL02@X9`0D61L06AdL00`=2`0B4@l08b8P014@3P061@<04Q4?01@C4@0B4@l03`h<014@
3P804Q4?00@01P8101HB4@0G4a803PX90P0H51<0800300004@d<01/G5P0300005A4@01LC4P0E4@h0
40`9018>2`0F4Pl0510=01<?300:1P<05Q8?01/G500@30T04Ph;01<?300P71/00`0001DA400B3Pd0
61@C01@@3`0F4Q405a<B00l;2P0=2@P03`/:00`81`0A3@`03PX90P0A3@`05@0>2PT04@d<00d9200E
4A00100001LC4P0J5QD04`l>024M700<20L00`0001/G5P0@30/05Q8A00`81`0@30/030P7010<2`0=
2@P04@d<00`;1`0200d<200700`;1`0>3@T040l;018A3@0@3`/03Pd900d<200200`;1`03018>2`0D
40d04`l<00804Ph;00@0510=01<?300A3@X03`/80`0>2PL0100A2`d040X:010;200?2PL200l:1004
00X5000L5a<06A@@02lY:@802P@601P04@/;00`61P0;1@D02`D500T30`080P8040X:01<=3@0;1@D0
3`T900`61P0=1`L03PP800`61P0D3Ph040X:00/51@0B30`0208200`61P0?2@T02@<300h8200=1`L2
00h8200300X4100;1@D03PP800803PP80`0@2PX01@0>20P040P901882@0B20T04@L8008040H700@0
4@L801882@0B20T04`T:0P0B20T03P0F3@h0AClo01LA4@0E3`l03@L700d8200=1`L03`T9010:2P0;
1@D030H601<=3@0@1PL04@L80P0B20T20147200400T0000?1@H050X;01882@8040H71P0A1`P01P0C
2@X040H701061`0=0`@05`d>01<92P8050X;00D04`T:0147200A1`P040H700T0000201@:2`0500T0
000?1`L0:b4R01061@0?1@@00P0>10<0200?1@@040H501H<2`0;0P804@L601881`0:0P4050X95?oo
ool001_ooooo00X02`T<010>4@0<2Pd0518E00d;3P0M6ah030X=01hL7`0Q7b8040hA0P0>30l0200;
2@X02@L800l=3P0<2P/03P`=00T7200>30d03`d>0P0@3Pl0400?3@h03P`=00X:300E5AL020P:00d=
3`0@41802PX<01/K7@1[Jfd02@T;010@4P0<30h00002014=3@0A3@`2018>3@0C014=300@30/03`/:
00l;2P0A3@`05A4@01HB4@0E4A006QTG01<B400J6AL05QDC03hm>`1`Kfd04Q4?014@3P0?3P`04Q4?
01<B400200l>30803Pd;02403`h<010?3@0@3`d03`h<00d<2P0B4@l06APF01LF500@3`d06QTG014@
3P0?3P`06QTG00d<2P0>3@/03`h<00h=2`0A40h03`h<018A3`0F5A<071`J014A3`0>3P`0000002LW
9@0L71X00`<100L71@0C4a403`l=01DE4`0D51400P0A40`00`0@3`/03`h:00l>2P02010?2`0400`;
1`0D4`l07QdI01DD40804A0<00h040l;00l>2P0?3PX03Pd900l>2P0D4`l061LC01@C3`0@3`/03`h:
00H70P0>3`X061TD00/<1`805QLB1P0@4@`200l>2P8040l;00D03`h:00h=2@0C4Ph05QDA00/:1P02
010?2`0=01<B3P0S8Qd03`h:01DD400D4Q<030X<00d;3P0@3Q403`d?00l>300<2`T05QD@00h=2002
01DE4`0T01<C4@0B4Q00410>00l?3@0A4@l030`:01LG5@0E5A<09bLU01`L6P0H51<04Pl>01@C4@0F
5A<04a8@014A3`0;2`T05QPE010B3`0;3@X041DA00@91@0A4A403`l?01DE5@0B4Q80820N00D50`0E
5A<04a@?018C3P0A4Pd04A8<018C3@0G61<05AHA0P0F5a80100D5A004A8=018C3P0D5A0201DF4@03
018C3P0A4Pd04A<>00D04A<>03/05QPC01@F4@0E5a805aTD01DG4P0A5Q4041TF06idLP0G71X07R8Q
02HX9@0D51806APF01XF4`0S7Q/07QTF02@L6@0Z9b@04aPD01TN6P0D6AD05Q/G01dR7P0G71P05AXF
01TN6P0N8al06AhJ01HK5`0G71P05adI01HL6P0G71d07B8U01`Q9@0K82@05Q/O01@I700H7Qh06R0N
01lU8@0P92<07b<R01`P7`0J7Qd06alN01dS8`0O9BD082HV01lW:@0J92D06B<T01/U9P0S;B`06RDO
03@o>00b?CD072LO024]8`0202Lb:P0502Lb;`0W<C809c4c02La=@0T=3@00P0R=3@00`0R=C<09CPf
02`o>`0202`o>@0f02a0=`0[?cH0:clf02/o=@0gBdX0;4520397B00gC4l0=DY>03Y?E00nDUT0@UIO
049FH@1XO8L0AeYW041CI01@HWX0EfV004ePL@17FfH0AEYN03Y@C@0lDdd0@EMC041FD`14FUP0CF9T
04iSIP1@JFH0D6QU055VI`1BIfX0EVYa05U[M@1MKgT0DF=/05UZL@1NKgH0F6Y]05IXJP1SMGD0Gg5a
05i`L01SMGD0J7Qh06UiN@1[Ng/0I79c07:0P@1_OGh0LGan07AoP`1iQXd0OX^C0P1oS9@09024SYL0
R9:K08NAVP2?V:40TibU09NNZ02EW:H0U9^U09BMY02EW:@0WjJ^0:FY]02TY[80ZJ^g0:n^_02h]LH0
_;W:0;nkc033_<h0`[k?0<K4dP3;amH0clSH0=C9g03Jbn80hm3Y0>KBk@3Xe>l0jmOc0>oKm`3`gOT0
mN7m0?STo@3hi_h0nnWo0?k]o`80o_3o00H0o_3m0?gan`3olo`0ooGm0?ofn`3omod20?ofoP1D0?oe
oP3om?h0oo?m0?ocoP3ol_l0oo7n0?o_oP3ok_h0ongm0?k]oP3kj_d0n^Om0?_To`3kh_l0n]on0?OL
n`3ef_T0lMWf0>oHlP3[f>h0iMCV0>3=h03Td^80gLcL0<k0c@3=_l`0cl??0<o5d03:`</0`;W10;Vd
^`2f/KP0/:jd0::RX02JW9L0Wj:K0::UWP2IW9D0XJJO08jES@32bL40YjnT06UcJ01dOW<0N89h07N2
O01fPGd0NhJ2075mN@1ePGd0MH5o06YiMP1_OW/0KWim0761P01dQ8@0IWQh05mcL@1OMG40HWQe05Y^
K01CIV<0?E1<04=FDP1@HEh0BEUF04iNF`0b@T00?di9049>@P0_>Rd082XQ02dg;`0_>CL0=T9002/g
=`0X=3<07bhY02<b;@0Y>C009SD^02hl?00/>S/0<Cm00P0gADD0<P0e@d<0@4m<02`k=`0Z>C@0;3/f
02dl=`0mBDD09S0]02Xc<00X<Bh07RLT02</:@0O:2D08R/X01dV8`0O:2D08b`Y02D^:`0R:bP0:Bl[
04mED@17CDT08bTU01lU8@0W;BT092XV01`R7P0K8Ad08BLS028X900M:2@0HW9f0391A00R<S807B/Z
01TU8`0E81`06R<N01dS7`0Q9b<0828Q01`M7`0M8B006R4M01<L5`0S:RH05adI01DK5`0H7AT051TE
0P0O8Ah201XL6@0601@F500H6QT06Q`K01hP7`0T9RD0828Q0`0I6aX06@0F61L04Q@C01<E500I6aX0
4aDD01`N7@0A4a806Q`K01lQ801gNGP05QPG018D4`0>40l030h=024S8P0I6QT040l=01@C4@0C4Q00
4A0>01PG5@0B4@l04A0>00l>300@3`d00P0A40h02P0L61L0510?00h:2@0I5A@03`/:00L30P0X92<0
AT91044m?00A3@`200l;2P0J018>2`0@30T0510=01@@3@0A3@X0510=010<2@0:1P<05a<@00/7100?
2`P061@A01`H5`0D40l03`/:00@0000A3@`03@T801/G5P0I5A@040`;00d9200>2PT02`L600l;2P0B
3Pd200l;2P0A014=300?2`X03@T8018>3@091@@03PX900H20P0=2@P0510?00h:2@0M6AP03`/:00H2
0P0F4Q404@d<01DA400B3Pd00P0@30/01`0D40l030/7010?2`0>3@T02PT500/:1P0B4@d00P0>3@T0
1@0?3PX04Q4=01@C3`0E51004`l<00<04Ph;00`03PX700/7100@30T030P500T50P0:1P<03@T600h:
1`0@2P`04@/;014<2@0@2`L200h90`0T00d80P0H4`l02PD101dG5`0<1PP03@L9014;2`0=1`L030H6
00d71`0<1PH02P@400d71`0@2PX02`D5010:2P0<1PH040X:00l92@0;1@D04@/;00T30`04000040X:
00T30`0=1`L03`T900/51@0?2@T030H600d71`0>20P030H600L10@090`<03PP80P0?2@T01@0@2PX0
3`T900l92@0@20T04PP900<04@L800<040H70147200A1`P00`0B20T03`0A1`P04PT:03hh>00E3`l0
3`T9014;2`0>2@T03`T9014;2`0B30`03@L700/51@0?2@T040H70147200201882@804@L800H050X;
01<92P0@1PL03P@501061`0F30d60147200600d3100C2@X03`D601882@0^92D08QPI0P0D2P/0300C
2@X04@L801061`0?1@H02@0001<92P0@1PL03@<403dc=024NW/040H500l510803P@300P03`D40106
1@0C2@P03`D4034W9P0_9B@0308201881aCooooo000Kooooo`0D024O8P0?3A005A<F00H41`0E4aH0
30X=00l=400D4aD07adP00d;3P0A3a803@/>01@B4`0@3Pl02`T:01LE5P0@3Pl0518C00h<3@0?3@h2
010>3`0@00l=3P0>30d0410B01lO8@1]KFl0=cLi00l?4@0A4A<07QhP06m_L@0T92H03@d?00/;3@0C
4a<04@d=014=30804Ph=01H04@d<010<2`0H51<0510?018>3@0C3`h04@d<00l;2P0C4Q0030/9018A
3`0@3`d03Pd;01DD4P0B4@l04a8@010?3@0B4@l04a8@01@C4@0F5A<04a8@0P0@3`d02`0A40h05A@B
00`;2@0C4Q0061LE00X91`0=30X04Q4?00`;2@0=30X04a8@00803@`:01<04A0>01LF500O7Q`05QDC
00X91`0J6AL071`J01TI5`092@L030`:014A3`0D51803Ph<010@3P0B4Q003Ph<01LG5@0J6QP03`l<
00804A0<00X040l;00l>2P0?3PX02`X6014@300>3@T04Q4=024P700I61@04A0<0P0B4@d03`0@3`/0
3`h:01<B3P0@3`/04Q4=01@C3`0B4@d04A0<018A3@0B4`h02@X5010A300A4Pd05QLB010A300600l@
2`804Q4=03D04a8>018A3@0@3`/03Pd900d<200B4@d03Pd901@C3`0A40`051<?00/;1P0@4@`04a@?
03@c=018B4X051@F01LF6@0?3a005AHC010?3@0@40/0414;01@D4P0B4Q00410>00l?3@0A4@l04Q8@
01DE4`0@40h02`/9014A3`0H61H04Q8@01DA400C4@l04Q4?01@C4@0B4@l03`l=010@3P0H6QL02@/9
014C400E6QH03a@@01PH600=3@d051@D00l?3`0B4Q005ADC014A3`02014B3@0?01<D3`0D5@l05AH@
01<D3`0B4`h051D@01LH4`0F5a8051D@01DF4@0C50l04Q<>01<D3`0D5A005AHA00H051HA01/05ALB
01<E400D5Q405ALB01@F4@0E6aL02a<@01LM6`0E6QP06AdL01HH5@0O81h0CTi<04E3?`0O71T08alL
01`E4P0T8al05a`H01DJ5P0L8Ad061dI01TN6P0F6aL051TE01DJ5P0H7AT00P0E6QH0300F6aL05adI
01DK6@0F71`08bP[020U:@0D6Ad07B8V01/P8`0J82007B<Q01HL60<07B4P01H07B8Q01lT8P0P9RH0
6R8Q01/T8`0M9RL072HW01dW:00P:R`08bh/01HR7P0P;2H08RhW020/8`0Q;B@0:cL_02Xf<00Z=C<0
:C@d02Pc=@0W<cH0:CTi0P0W>CT02P0Y?3X0:chl02i1?P0Z?CT0:chi02`o>@0/@3P0;D0i02e1>P0_
@d8203I;C00R03Q=D011EUX0@eQM049FG@0mDEX0@eMR05AXL`1IK7T0A5MV04=EJ`19Fg40CV5a04iR
K@1?HfP0D6IT045GE015FeL0A5YH04MLG@1BIf/0E6U/051YI`1CJFT0EFY]05I[L01HK780FFad05Q[
L`1dQXh0IgQo05EWJ`1IJfh0Gg5c061bLP80Gg5a0180HgEe06IfMP1VMWH0IgMg075oP01bP840NHN8
082;S@22SI40OhbB08BAV025TYT0QI6H08ZEW02>VJ00SYNO09BLY02GWjP209^RZ`0U09ZQZP2V[[D0
][_40:^`^@2Y[;L0[Znk0:VZ]P2d//00^kS90;jkc033_Ll0a[oA0<S1d`3:amD0d<[J0=?<g03Ic>00
g/oU0>ODk@3[eo40jmOb0>kJm@3bg_T0m>7l0?SUoP3jj?d0nnWn0?g]o`3nl?l0oo7o0?oco`3olod0
ooCn0?ogo`3on?h0ooWn0?oio`020?oho`040?ogo`3om_l0ooGo0?oeo`80oo?o0300oo7o0?o_oP3o
kol0onko0?g/o`3kj?h0o>Kn0?cSo`3kh?l0nMkm0?KKnP3bf_D0l=Wc0>_HkP3VeNL0iM;U0>SFiP3P
cmh0cl7>0<k0c@3AaM00bl7;0<Vob032^l<0^kJl0;B_]@2WYZX0V9RE09ZMU@2PXi/0WZ6I09NJTP2:
ShL0PhZ107j5O01YLFH0IW1U06UcJ01iPgT0NhJ007n:QP1iQ800PHf90::^ZP28U980K7]h06imNP1/
O7/206emO00g065cL`1TN7L0H7Ec05M/JP1>HV00Cf9O03]>BP18FUD0Cf1K04AECP15EE40:c/e030n
=P0h@cX0;SH/03<k<`0f?ST0;SDb02/d<P0L9RH092l]02Xf<P0U<2`0;c`f02lm=`0/>ST0<d5203e;
B`10CTh0>4M602ln?015E540;Sdi02He<00U=2l0;C`g04aHD`0]=c<0:c@a02L`;@0O:2D0:34^02L`
;@0^=c@092dZ028[:00S;2T092dZ024Z9`0L8Qh07R@P02<Y9@0R:2@09R`X01lU8@0201hT800j01lU
8@0R:2@09R`X02D^:`0V=3P03ahQ01l^;`0P;B`062<O02D`:`0S;2L07bDQ01TO6`0O8R8092DX020T
9@0G7a/08R/V01DM600C6AD06R0L01TN6P0H7AT08B<P01dO700K7AX07R0M01`N700S9B@0828Q01`N
7@0N81l06adL01PJ6@0I6aX061XI01HH5`0E5aH05aTH01DG5P0C5A@04Q@C01PJ6@0B51<04A<B034c
<P0F61L071hM01@F5@0N81l02`d<02DU900U92805aHD01TH5P0<2`T05QDC01<B40804Q4?0P0C4Q00
2`0B4@l03`/:01LC4P0B3Pd04@d<010=300F4Q4081`K01TE500D40l05A4@00804`l>0180510=014=
2P0?2`P03PX701<?300X9240EU9?01PD4@0B3P`0510=00h:1`0B3P/05a<B07EaL00M6AP05A4@00/7
1P0F4Q4201@@3`0?00h:2@0=2@P04Ph=014=300>2PT05A4@010<2`0A3@`06ADD01<?3P0@30/04@d=
010<2`0P71/0A40o00804Ph=01<05a<B069NG@0F4Q404`l?00T61@0D40l03PX9010<2`0:1PD04Ph=
014=300B4@d040l;00d<200<2`L03@`800h=2@0D4`l04a8>00804Q4=0P0C4Ph01`0B3P/04@d:01<?
300F4@h040`900/7100?2PL00P0>2@H01`0?2PL03`/8010<2@0>20X03`T900l:1`0?2PH00P0=2080
100A30H05A0<00L30@0=1`L200l92`0600l92@0=1`L040X:01H@400H4Q806A<C0P0>20P05@0=1`L0
4@/;00T30`0@2PX05Q0@00l92@0=1`L050h>00h8200@2PX03@L701@>3P0H4Q805@l?01<=3@0?2@T0
3PP800d71`0A2`/03PP800d71`0600l92@0301082@0A1`P04@L800D04@L80`0B20T03`0A1`P03`H7
01<=3@0;1@D04`d=00H10@0A2`/03PP8010:2P0B30`040X:00h8200=1`L040H70147200201882@80
4@L800H0CTA503D[;00E2``040H701882@0A1`P801061`040147200?1@H081HG01X@4@8040H70P0A
1`P0200B20T04`T:01061`0?1@H04PP9018:2P0A1`P050X;1P0?1@@01P0>10<04@P702@J6@0S6AP0
3`H500l511Cooooo000Kooooo`0=01HD5`0<2Pd030X=01PF6@0B41<0OWao02LU:00;2@`0108500H4
1`0@3Q403P`?00/92P0200h<3@0502XX:@0<2P/01`D600h<3@0?3@h00P0@3Pl03P0?3@h03P`=00/;
3@0k>cd0b/[<06i^L00>3Q001@D700X:300;2`d04A4C00X:300B4Q@07adN0P0A3@`2018>3@05014=
300@30/05Q8A014=300@30/00P0B3Pd02@0A3@`02@P701`K6@0F5A<05A@B01<B40061@<040l=01<B
400200l>3005014@3P0C4Q0051<A014@3P0>3@/00P0=30X07`0:2@L04A0>01<B400A40h06aXH01@C
4@0;2PP00@0001dL6P0g=S@04Q4?00d<2P0D4a404Q4?010?3@0A40h03@`:00l>300=3@/06a/I01lO
7@0G5aD04A4?00l?3@0E5A<05QHD014A3`0J6QP0CDe;04U9A`0H61D00P0A40`0400@3`/03`h:00l>
2P0<2`L04Q4=010?2`0:2@D03`h:00d<200<2`L03`h:014@300>3@T03@`8018A3@0A40`3010?2`08
018A3@0E51003a0;014B3@0B4`h07AhI03Lh<`0E5Q46010A300400h=2@0?3PX04Q4=01@C3`805QDA
01@040l;01DD400C4Ph05A@@00d<200E5Q406A`E014C3@0?4@`0FE]J08B6QP0@4A<0000200/=3@0C
5A806adJ00X=1`0<3`P0410>00l?3@803Ph<01h04A4?01<C4@0D518051@B00<30@0?3`d03Ph<018B
400@30/05A<A014@3P0?3P`04Q8@01@D4P0B4Q002P`900T;200N81d02a0<00`A3@0E5AD02@T900l?
3`0I6AT03@d;00l?3@0D51804Q<>014B3@0@4@`2010A2`0<01DF4@0C50l04a@?01@E400A4Pd03a0;
01DF4@0B4`h0414<014B3@0D5A005QLB1P0C5A00L@0E5a804aD@01@F4@0E5a8051HA010E4P0I7ad0
4QPF01TN7@0830/08bDR00h?3@0T92809B@P01XH500O6aP071TD02HV8P0M8Qh03Q<?01dR7P0K81`0
41DA01`Q7@0H7AT05Q/G01LL600D6AD05Q/G01/P700J81`05adK01DK6`0I7R405a`P01<H700K82@0
7b@W01LM7@0B61H05A/G01PL6`0I7A`07B4P01lU8`0P9R@08BLW01`U900N9bH07RPY01`V9`0K9BH0
7BLY01LS8`0L:2H09S8_01PT800J9b00934Y02Xg<00Y=Rl0:CDa02Pd=00W<c<09S<e02Lg=`0U=cL0
:3Xj02`o?@0]@3h0:Sdk02Pk>@0Y?3P0;3lk02m2?P0aA3h0<TI202e3@@0oE5D0=T]<03A9C010EET0
=T]@04EIH00oDe`0@eMR02m3CP1EJGD0@5=R04UKL@16F6d0CV5`04eQK017Ff00CfAU04EKF@18GU`0
AeaM04UNH@1AIVX0DFI[04mWJ@1CJF`0Efa_05Q]LP1IKG<0F6]b05]^M@1aPhT0FV]b051RIP1MKg80
DF=U0080GFm_03@0Gg5a06=eM@1TM7@0Hg=c07N7Q`1jR8T0NHN80:Jd]@2U/;80TIbN07n<TP24TIL0
QI:H08JAU`2:UI/0SYVO08nHW`2AV:00TiZR09NNYP2KXZX0W:>[0:R_]`30a<d0[;2i0:Z/^02h^<@0
/;2l0;Rfa02n^//0`Kg>0<Jod@39`]@0c<GG0=39f@3DcMd0elkO0=g?h`3SdNL0jMK]0>cHl@3]fO80
lMgh0?GQo03fi?h0n^Sn0?[/o@3kk?l0oNoo0?kbo`3olol0ooCo0P3omol01@3onOl0oo_o0?oko`3o
nol0oo[o0080ooWo00@0ooSo0?ogo`3om_l0ooGo0P3olol0;P3olOh0onoo0?o_o`3mk?l0o>Wo0?gW
o`3mi?l0o>7o0?WNo@3fg?T0l][f0?3Jl@3/fNd0i]GW0>;@h03SdN40f/[G0<k0c@3?`/`0cL7;0<Nm
aP36_<@0`K_00;Ze^`2b[K40Xj:R09NHTP2PXiX0WZ6H09RKTP2IW9<0PHMm07R0M@1eOG80J71U06af
J`1_NFh0NH=i07n:Q022SHT0Mh9n08NCS`2`_;P0T9bJ07F4P@1bPGh206alN`1P06YjNP1RM7@0HWAf
05]_L01CIfH0BEeL04mRG`19G5P0EVMQ055RFP1:Fe<0>4Pn03E5>`0f@cT0;cH^02T_9P0_=2d09b`V
02X`;@0[<Bl0?TA4028[:@0S;RX09S4]045<A`0e@3`0<Cdk04=AD@0_?Cd0=dE50391?`0d@d00:cXg
02dl=`0/>cH09SD`02He;`0d@CX082XV01TR7`0U;R/092dZ02D^:`0T;BX0=Chk02Tb;`0U;R/08R/X
01lX9@0K92408RPT01@J5P0M8al08bTU02dc;`0P9R808BLS02D[9`0T:RH07bDQ024W8`0R:bX062@W
01`Z:`0M:BT08Rh[01dX900I91h072DP01/Q7@0K8Al08bLX02@U:@0L824072@P01`U800c>SH092XV
01HL600D6QH04aPD01PJ5`0G6AH08bDR02X/:@0P8R008R@S01hP7`0G6AP06Q`K01`N7@0I6aX061XI
01TK6P0H6QT05aTH0P0I6aX04P0P8R402`d<01TK6P0C5A@08bDT014C4P092`X092HU01@F5@0F61L0
4aDD06a/J`2?SX`0:RTW01<B400G5Q@0<C0^014@3P8040l=0P0B4@l03@0?3P`05a<B00X61@0A3@`0
6aLF02HR8@0I5A@061@C020L6`0>2PT01`<201DA400C3`h00P0A3@X0@P0C3``04@d:010<2@0L61D0
;2PU01LC400D40d03PX701DA3P0C3``0:BDT01lK6P0E4A001000010<2`0;1`H04@d<01<?3P0>2PT0
3@T8010<2`0=2@P02`L600l;2P0>2PT040`;01DA400C3`h04@d<00d9200@30/081`K05MCDP091@@0
3PX9014=300J5QD0Ad=201LC4P0?2`X05A4@014=300L61L03PX901HB4@0?2`X03@`800X91@0<2`L0
4Q4=01@C3`0?3PX04Q4=010?2`0=30P02`X600X91@0<20D03`X7010;200B3@X050l<018=2P0@2`P0
3@P500l:1`8040/801803PT600d81@0<1PP030H600`7100>2@D03`X4010;1@0>2@<05a8>01<>2P0B
30`040X<00X41P0?2@T03@L700h8200C3@d201@>3P0B00`61P0;1@D03`T901H@400>20P03`T901PB
4P0F41003PP800l92@070@4020<300X4100B30`06A<C01hH600M5aL030H60P090`<0100;1@D04P`<
010:2P0>20P200l92@0500h8200?2@T03`T901082@0@1PL00`0A1`P00`0B20T04@L801061`030147
200401061`0@1`P040X:010:2P803@L700T040X:00d71`0>20P040X:014;2`0@2PX03`T901061`0A
1`P00P0B20T2014720801`0000@04`T:01H<3@0?1@H04`T:1P0?1@H01P0D2P/02P0101882@0;0@80
1`0000h41@803@<400H03`D60147200C2@X050X;01T?400>10D200T0000400/20P0A1`P03P@300l5
108040H500P03`D400h40`0<0P404PP700T0000<0P405P`;00d30QCooooo000Kooooo`0D00800@0A
3a004@l@01TG600F51D0SXb=02/Y:P0G5AH040h?01`J6`0H5QL0518C01`J6`0E4a@06QPI04a:B`0P
7Ql00`4200h<3@0?3@h2010>3`0>00l=3P0>30d040h?01HD5@0l>S/07A/L01@B4`0<2P/03@/<00l=
3P040P<04Q0A010>3`010002014=30804Ph=00H04@d<010<2`0C3`h03`/:00h:2@0B3Pd201<?3P0<
020O7@0S8R003@`:00L61@0D4a404A0>00h=2`0B4@l03Pd;00d<2P0@3`d03Pd;0P0=30X300`;2@0O
010?3@0F5A<02`X800/:20071P@020L501XI5`0>3@/07A`J03@c<@0I61H03@`:018A3`0:2@L020L5
014@3P0B4@l03`h<018A3`0?3P`030/900L6100?3P`040l=01<B400B4@l03@`:00T81P0T8b408B0N
00T81P02014@3005010?2`0?3PX03`h:00d<200>3@T00P0@3`/01`0B4@d04a8>00h=2@0C4Ph05QDA
014@300?3PX00P0A40`01@0@3`/04A0<018A3@0B4@d04A0<00803Pd900@02@P600L60P0O7QX03`h:
1P0A40`0100?3PX040l;018A3@0C4Ph201@C3`0B00h=2@0E51004Q4=018A3@0?3PX08B8M00<6000C
61802Pl900@81`0V:RX04ADF00D92P0P92@010T501@I5@0=4P`03a8;0P0B4Q02010@3P<04A4?01/0
51@B00`<2P0=3@/04A4?01@D4P0@30/05A<A014@3P0?3P`04Q4?00h>300H61H06adJ01lQ7P0e=c@0
4aPD018G4`0?3`l05QHF01<C4`0A4A403`l=01HF500D51804Q<>014B3@0@4@`00P0@4@/01P0F5a80
51D@01@E400E5Q404Q<>010A30H04a@?1P0A4a006`0E5a@04aDB01DG500F61D05ALD00dA3`0?5A<0
728P01DJ6@0<40l092HS01LH5P0H61H06AXE01`L5`0H5a<06APC01`M6@0Y;RX05AXF01<H500N8al0
41DA01lT800M8Qh06b0L01dR7P0201PM6@0<01`Q7@0H7QX05Q`J01LM7@0D6A`05AXN01LL800D6Ad0
8BHY024W9`0F71X05adI0`0J81h01P0K8Al07R@R01lX9`0L9B@07RLV01hX:@806bLW00L07BPZ030l
?00S;bd0930]01dY9@0K:2408RlX00809c@]02<09c<_02Lc<`0V<S809C8c02Li>@0U>CP09c/j02/o
?P0]@D00:Shm02Tm?00Z?S`0;40n02m3@@0aAT40=4Q603A:B00lDE80>4e>03I;CP0jCe<0=T]@049F
G@18G6D0Cf=^03eAG015FFD0>4]J04aNLP1>H7D0B5]Z04EHIP16FV40AU]N04=HF@0204QMGP0@04YO
HP1@IFX0CfAY04eUJ@1CJFh0Efaa05U^L`1HK780EfY`059UJ`1EIfh0Cf5U059TJ01MKg80FF]]061b
LP80GW1`00X0HWAd06IfMP1VMWH0JWYj06]iNP1cPH80Tj6R08ZEU`1iQ8H0PHbB0`27TYP0302<UI`0
SiRO092IX02CVZ80UIbT09^OZ02NXZ/0Wj>/0:2T[@2]/;T0ZJbe0:j^^P80^KO401P0_;S70<>lcP35
_]00bL3C0<k5f03@amX0dL[L0=O>h@3Kcn<0gm7U0>GCj@3[end0k]S_0>oLlP3dhOX0mnGm0?WWo`3k
jol0oNon0?g_o`3olol0ooCo0?oeo`3omol20?oho`030?oko`3ooOl0oogo0080oogo0680ooco0?ok
o`3on_l0ooWo0?oho`3omol0ooGo0?odo`3olol0oo7n0?o`o`3nkOl0oN[n0?kXo`3ni_l0o>;o0?WO
o03ggOX0l][f0?3Jl@3/fNd0imKX0>?Ah@3Rd=h0f/[G0=?6d03Dam40c/;;0<RnaP35_<40_[Rk0;Ja
]@2`[:d0Y:BR0:6RVP2QY9T0V9^@08b?Q028Rh00PhUo07b4N@1jPWL0KGEZ07V3NP1nR7l0NH=k07N2
O01mR8@0OXV5071lN01kQh<0NhN507>2O`1_OW/0K7ak06emO01YNGT0HWAd065cM@1MLG80Gg=b059T
I01=Ge`0CEeJ04QID`19FE80@E5703Y:?`0_?c@0;3T_02/b:P0Z;BH0:RlX020U7`0_=2l0:S0/02H/
:P0W;B/08R/X02H_;01PJFH0BEA@05EQG`22T900=dE503]:A`0fAD808S4^02Xi=00^?CP0:STb02Lf
;`0U=2d07R/T02H`;@0P:BH08R/X01hW90809c0]01`0;CHc02</:@0P:BH07RLT01/T8@0G81d07B<Q
024W9@0T:RP0;S@b01TO7@0Z<2h09B/Y028X9P0P9R@07bDS024W9@0Q:RT0:38e02D`<P0J92D07BPU
024Z9`0S;2L08BLS024W9@0S:BL08BDV0P0K7b80300M92<08R/X04aCD@0R:2H03aDC020U900N8R40
8R@S02<U900c=C@0>3Xi01lP7P805aLE00L05ADC01/K6@0N7Q`06QXH01TI5`0J6QP06ATG00805aLE
00<05QHD01PH5P0G5aD00P0>3P`03@0I6AL061PF01LG5@0G5aD0820N01DE4`0J6QP0RXV70:f/ZP0]
;2X05QDC01@C4@0G5Q@00P0A40h0400B4@l04a8@01<B400@3`d0100001/G5P0B3Ph061@C07UeM01B
CTd03PX9024M700C3`h03@T8010<2`0G4a8201DA3P0601PD4@0C3``030P500`81@0400002PH30P0?
2`P0400F4Pl0510=02/W9P0300005a<B014=300F4Q404`l>010<2`0D40l04@d<010<2`0A3@`030P7
010<2`0>2PT2014=300800l;2P0B3Pd040`;01<@3`0G4a803PX9010<2`0:1PD2014=2P0700<0000_
:bP02`L501LC400B3P/071PE02l[:00201HB3`803@T600D03`/8018>2`0D40d04`l<014=2P0300`8
1@0400l;200@30T04@d:00`710803PT600@03@P500h91P0?2PL040/81@0?2PL03@0>20X030H600`7
100?2PH050l901HA2`0A30H03PT5014<200=1`L04@/=010:300@2PX00P0=1`L02@0?2@T03PP800d7
1`0?2@T03PP801<=3@0J51@040X:018<300201<=3@0A00l92@0400003@L701`F5P0:10@03@L7010:
2P0J51@071HF00d71`0G4A406Q@D00`61P0?2@T040X:00d71`0@2PX00`0>20P01@0@2PX040P90106
1`0@1PL04@L800804PP900@04@L801061`0@1PL04@L80P0@1PL01P0=10D02`D5010:2P080P804`d=
018<30<03`T90P0@2PX00`0?2@T040H70147200201882@804@L800D050X;01T?400Y7b008QPI0106
1`0700l51P060147200900004`T:00l51P0<0P<05P`=0P0?1@H201061`804@L800P01`0000h41@0J
41406@l@01061`0=0`@03P@300l5108040H500P03`D400h40`0>10<05P`;01<9200J40l08ALF00h4
0aCooooo000Kooooo`0F010>3`0B414040h?018@4@0@3Pl05Q@E01XH6@0=2``04@l@02PV9`0Q7b00
40h?014?400>30d020L701/I6P0<2P/03`d>010>3`0?3@h03P`=00l=3P804@l@00<03P`=018@4@0?
3@h00P0A3a00200>30d03@/<01DC500;2@X03`d>00d;300>30d04Ph=0`0A3@`2018>3@0801DA400>
2PT03PX9010<2`0C3`h04Ph=00h=2`0F5A<3014@3P0=00D40P0?3P`04Q4?00l>300G5Q@08B0N018A
3`0;2PP06aXH01@C4@0?3P`040l=014@3P02018A3`0L01DD4P0<2`T0>STg055@CP0D4a403Pd;01<B
400B4@l03Pd;01<B400@3`d05aHD01DD4P0<2`T03`h<014@3P0?3P`051<A018A3`0?3P`03@`:01HE
4`0C4Q004Q4?014@3P0:2@L08B0N02PW90804Q4=00D04A0<010?2`0@3`/05A@@014@300200h=2@0;
00l>2P0D4`l04a8>01HE4@0H5a<06APD01XI5@0E510040l;00h=2@0C4Ph00P0A40`0200>3@T040l;
00d<200D4`l040l;00l>2P0C4Ph04A0<0P0@3`/00`0B4@d04a8>014@300201<B3P<051<?02404a8>
00h=2@0E51004Q4=01DD400D4`l09BHQ01<F3`0;40X051TC00`@3`0D61P041@E03Di>P1DF5P02@h:
00hC3`0>4`d03Q<<018B400F5Q@05ADC018B400A4@l030`:010@3P0A4@l04a<A00h>300C4a40410>
01@@3`0E4a400`0B4@l03P0<30X04a<A00h@3@0>40d04aDB00lD400B5a<051@D00h>3P0@410051@D
00/;2@0I6AL04Q8@0P0A4Pd00`0C50l04a@>01<D3P0201<D3`0601@E400H6A@06a`G01`M600B4`h0
4a@?0P0D5A0201<D3`0501DG500M7a`061XG03Pj=`0I6aP00P0C5A805`0B514061XG01LI5P0C5A80
61/I00lD4`0D6AL04AHD01PL6`0G6aL07B0M01TJ600G6A@05QLB01hN6P0Y:B@09bPT0497@`0]<Rh0
4aPD01dR7P0<4@d05Q/G00805a`H02/06QlK01TN6P0G71P05a`H01DK5`0E6aT05a`M01PM800L8BD0
8RL[01hS9`0G71l06AlO01@J600M8al07bDS01/Q7`0P9R@06b8P01LP7@0L9B@06b@S01`V9@0M:2P0
72PX01dY:@0P:bd0>4A602/h>00M:RX09C8`02<a;00X=S009C</02@b:`0W=3009c@d02Db<P0V<c@0
:cdm02Tm?00Z?Sh0;4100080:clo06<0:Shn02i2@P0`A4<0;d=30355A@0eBDT0>4e>03A9BP0kD540
?U=F03Y?D`0jCe@0?E5H045EGP11EF00?e=N045DH@1>HG00BEa^04ePL@16FFP0B5]Y04UMI@1:Gf@0
AU]O04MLG`17G600BEiS04eQI`1@IF/0CVEZ05E[L@1IKG<0FVme05IZL01IK740GG1e05Q[K`1LKW40
FVa_06=eN022U9H0HgEe061bLP1OLG40IGMg06emO@1_Ogl0NHV908BBT`2>W9d0SI^L08B?T@22SHl0
SYVM08RCV029U9T0S9JK08nGW@2BVZ00Ti^R09RNY@2JX:L0Wj>[0::V[P2SZ:l0[:nh0:b^]`2a/k`0
]KC00;Nd`P2l^LL0`kc<0<NodP3;`M@0clGH0=C8g03EbMd0e/_O0=[>hP3NdND0iMCZ0>[Gk@3_f_00
lmgc0?CQmP3ii_/0o>[o0?c[o`3mkol0o_?n0?odo`3omol0ooSo0?oio`3on_l0oo_o0?olo`3ooOl0
1@3oo_l01@3ooOl0ooco0?olo`3on_l0ooSo0080ooKo0140ooCo0?kcoP3olOl0onko0?k/o`3njOl0
o^Ko0?gSo`3lh_l0nMol0?CMmP3_fNh0j]O[0>CCi03Pc]h0g/cJ0=S8e@020=C7d@0D0<ZoaP37_/<0
`kZm0;Ze]02c[jd0[ZZX0:FUX02RXiX0VYj?08J9O@1/Kf<0JFeP08F;P02U[J80Ph^007InL`1lQWd0
MX1g07V3NP1lQh4207R3O`80LWij05H0M81n06akN01/NgP0K7ak06YjN@1/O7`0HG5a069dMP1QLgD0
Gg9d05=TI01:FeP0C5eG05=SG@12DTX0<T8g03Q7>P0T<bH0;3P/028W800V:280<S@^02db;00]<Rd0
;c@_02dc<00]<c40>Clm02H_;00d?C/0=Cln030l>P19F5H0=4=103e<B@0_?S/0<D0k03E4?`0b@C/0
9SD^01`/8`0V=Rd0934Z028/:@0`>CH0;SLd02D^:`0_>3D09Bh[024Z9`0P:BH05QlL01hW900O:2D0
5AhK02T_;@0J81h08BLU02D[:@0W;B/061hL01lU8`0W;B/07bDS02<Y9`0V;2X08RXY01dV:@0O:2X0
9Bh]024Z:00J8Ad08BPT01/Q7@0M8R407R<R01dQ8`0L7b@07b@X01/S8@0[=3406R4O01LM6`0L8R00
6AhL01HJ6@806Q`K00D08B<R028T8`0I6QP06QXH01`L6P0201XJ600501PH5P0G5aD061PF01TI5`0H
61H00`0F5Q@01`0I6AL0:2PV01PH5P0H61H051@B01<C4@0T92800P0B4Q002@0L71X03@d;020P7P0_
;R`04Q4?01TH5P0C4Q004A0>01@C4@0201<B40805QDC00L04Q4?01/G5P0:1PD061@C01DA400T81l0
?CTh00805A4@00H0510?01dI600A3@`05a<B010<2@0A3@X201<?3003010<2@0B3P/05Q8?00804Ph;
02L0510=01<?300B3P/040`;02`X9`0A3@`06QHE00`81`0@30/04@d<01DA400F4Q40510?014=300@
30/0510?010<2`0C3`h04Ph=00h:2@0A3@`030P701@@3`0?2`X04@d<018>3@0D40l040`9018?2`0D
4@d02`L400l<2@0G4`l02PH201LC3`0S7a/040`800h:1P0<2@H00P0F4@h08`0C3P/040/800l;200B
3P/040`900l;200B3@X040`900d91P0?2`P04@/8018<2@0A2`P040T7014:200B30T050h;01<<2P0A
2PP03`T6018;2@0C30X03`T;010:2P0810805Q4=04]6@01HDdd06aH@00X50`0E40`040X:01@>400=
1`T04@/;008040X:0P0?2@T01@0@2PX03`T900h8200>20P04P`<00803@L700L02P@400d71`0A2`/0
2@<302dW9`0m=cL03`T9008030H60P0C3@d01`0?2@T0:R@T02lY:@0A2`/03PP8018<300=1`L00P0k
=CD07@0@2PX03PP800h8200C2`/030<401@:2`0B20T04@L801L=3P0?1PL040H700l51P0C2@X05@/<
01@:2`0A20T02P@4014;2`0=1`L040X:014;2`0?2@T040X:018<300A2`/03`T900d71`0@1PL04@L8
00@04PP900X050X;00l51P0A1`P050X;01061`0B20T04@L801882@0@1PL03`D60P0@1PL00`0C2@X0
3P@501882@0201<92P0>01882@0D2P/03P@501/A4P0<0`@04PP900d3100D2P/03PD500h41@0@1PL0
4@L801882@0>10<401061@0700h40`0D2PT04@P700/20P0B20L06Q0?01471P0Dooooo`006oooool0
1P0L6Q/04@l@01HD5@0D4Q<03@/<00/92P803`d>00P03@/<00h<3@0@3Pl04Q0A01@B4`0@3Pl03@/<
00l=3P804Q0A00H040h?00h<3@0=2``03P`=014?400B414200l=3P0500d;300B41404a4B00h<3@0@
3Pl00P0?3@h200h<3@0300d;300C3`h04`l>00@04`l>01P030P802l[:P1fLW408alN00H20@0E4A00
51<A00L610020@003@`:01<B400A40h02@P702<R800L6aT0J6MU0<g<bP0C4Q008R4O00l>300@3`h0
1`H4055@CP05108300/:200=00X91`0@3`d06APF010?3@0?3P`040l=018A3`0C4Q005A@B010?3@0?
3P`02PT700`;2@0201@C4@0<014@3P0B4@l04Q4?00l>300>3@/051<A00l>300>3@/04a8@00P71@0J
6AL09RDR0P0A40`3010?2`804Q4=01<04A0<00h=2@0?3PX04a8>00d<200>3@T03@`8014@300G5Q80
4Q4=02<R7P0E51003`h:00`;1`0D4`l061LC010?2`0A40`04Q4=008040l;00@04a8>014@300@3`/0
3`h:0P0@3`/200h=2@0N00l>2P0@3`/04Q4=01<B3P0D4`l071/G01<B3P0510003@`8014@300I6QD0
3a8;00lD3@0?50h03a<B010D500A5AH00@D6020T900E6QH041DA00lD3@0:3@H05QHD00l?3@0J6QP0
5ADC01@D4P0E5A<04A4?0P0@40h01@0C4a404Q8@00h>300E4A00514@00804A0>0P0A4@l03@0@40h0
2@/8018D4@0E5a@01@X600H;1`051@D08B4Q01DE5@0;2`/0410>00h>300C4a400P0A4Pd0100C50l0
4Q<=014B300B4`h2014B3@0501@E400H6A@06AXE01LH4`0C50l00P0B4`h0800C50l051D@01<E4P0@
4Pl030h;03@f<`0>40d04A<@02@V8`0?4@h030h;018D4@0D5Q<04QDC00/?3P0B5QD061`K01TM700F
6aL051LD01HH5@0G6A@05QPC01LI500K7QL06alI02H[9`0J7a/04QLC01lT800G71P05Q/G0P0E6QH0
5@0H7AT06b0L01/P700F71P06AlK01`R800H7Ah061dP01`Q9@0C61`04AHJ01dR9@0H7Qh0728P03@j
=P0O9B<07R@R01`R800?61D07RLT01hX9`02020Z:@807b/[02h08Bd]028^<00Q;c807B/^01PV:00R
<30052<P01XY900L:b@07B`U024`:`0Y=cL0;C/k02`k>`0Z?3`0:Cdl02e1@P0^@T<0:Sho02a0@@0X
?3d0;T930396A`0bADT0>Da@03iAE@0`ADH0?U=D045FE`0kD5<0?55E04IKH010E5/0A5QQ04AHH`12
EV40AUYV04iQK`12EF@0@EAS049EH`1;GV`0BemY05M[LP1;GfH0B5aR0P19GF@05P1<H6L0EVYa06Ak
P`1OM7d0Ef]d05eaN01MLGL0HWEi05U/L01EJ6T0EfU[05AVJ01LKW00Nhf?065cL`1RM7@0HgEe06Uk
N`1aPH40M8B407F5Q@1nS8d208:@T@80PXf?01H0S9NK08B?T`29U9P0TibQ09:IW`2>UI/0UIbR09^P
YP2LXJL0WjBZ0:BY[`2XZk80[:bf0;2`^P2c/kd0^;K30;nkb@35_ld0a[k?0<c0e03?`mL0e<OK0P3G
b]h03`3Ic>00gM3T0>7Bi`3Yend0l=[a0?CNm03ghOH0mnCh0?_Yo@3mk?l0oNko0?gboP3nm?`0ooKo
0?oho`020?oko`<0oogo1`3oo_l20?omo`140?oko`3onOl0ooSo0?ogo`3omOh0o_Cm0?obo`3okol0
ongo0?oYo`3miOd0oN?n0?gSo`3lh_d0m]of0>oIkP3XeNP0h]7R0=g;f@3Jb=H0e/KB0=74cP3>`LX0
b;g20<>j_@2n]KH0]:n[0;2]Z02`[JH0Z:RQ09^MT028S7d0KW9S06mcI@1mPG<0Ri650:J^X`1lQ7T0
Mgmd07n9P01mQgh0NhEm07V4OP1mR8@0MX5m071lN01ePGd0Kg]i06akN01]O7T0L81o06YjN@1dQ8@0
IgMg05i`L01JK6`0Cf5Q04YJF@17Ee@0B5UC051OF014Dd/0;3`a02dj<00U<bH06RHJ02H[9@0o@C`2
02/`:P0L030e;`0V;BH0<SPd03<i=P0S;2T0<CXg03Ho?@0c?C`0>TI403Y9AP0kBTL0>TU603=2?@0_
?ST0;3/d02Lf;`0T<b`062PN02@d:P0T<BP082XW02hg=00_>3D0;CHc03Y3@00Z<c005QlL028[:080
72DR00<08R/X02</:@0R:2H00`0R:2H2020V900:02X`;P1>E580>3hl024W9@0F71X0:S0`020X:P0N
9bH07BHU01dV8`808BLS00d06b4M02<W:00O8b@08B@X01PK8P0K82@04a/I014J5`0F7Q/08BLU01hT
8P0F6aX061`K00806adL00T06Q`K01/M700J6aT061PF01XJ600K6aT06ATG01LG5@0F5Q@01@0E5A<3
01HF500?01LG5@0H61H061PF01PH5P0E5A<0410>00l?3@0=3@/03Ph<014@3P0E518040l=01PG5@0[
:RP071/I00803`h<00T04A0>01<B400B4@l03`h<01XF5@0E4A005Q8A014=300:1PD00P0F4Q403`0A
3@`04`l>01LC4P0E4A004`l>010<2@0B3P/04`l<014=2P0?2`P040`900<0000F4Pl04`l<00h:1`02
018>2`0<01lK6P0c;bh0510?01PD4`0>2PT03@T801HB4@0?2`X040`;014=300?2`X04@d<1P0@30/0
600A3@`040`;00h:2@0>2PT040`;014=2P0;1`@02PL200/80`0=2PD03``700h;1P0<2@@03``7010=
200?30L04Pl:01HC3P0F4@h04`h;00l:1`0>2@H040/8014<2@804Pd:00@06A@A01LB3`0B3@X050l<
1P0A2@L201<;2@10018:200@20H04PX801<;2@0=1`T07QPH014<2@0K5Q<0fmK@0?onn00S7QP050l;
01HA3@0C3@d0100000l92`0@2PX04P`<014;2`0=1`L03PP8010:2P0=1`L04@/;00T30`0X8R80=S0`
01/E5@0;1@D0208200l92@090`<03`T901PB4P0?2@T030H6010:2P0C3@d040X:00h8200K5AD07ALG
00d71`0?2@T04@/;00L20P0^:2P0:B<S00/51@0F41003`T900`4100P5QL02`4201892P0N51D0UH^<
01`B4`0?1@H03@<401<92P0H3Pl05P`=01892P8040X:0P0?2@T01`0>20P0208200`61P0B30`05Q0@
014;2`070@400P0@1PL2014720804PP90P0A1`P00`0B20T04@L80147200201061`0301<92P0@1PL0
3P@500<04@L800/03@<401<92P0L4Q<060h?0147200=0`@02P0104To@00Y7b003PD601@:2`060106
1`H03`D400H03@<201<9200?1@@0308101061@0B20LDooooo`006oooool01P0I61H020L500l>300;
2PP040l=018A3`803`h<0P0>3@/0200@3`d04A0>01LE5P0?3@h02`T:00l=3P0C4A804@l@0P0>30d2
00l=3P8040h?0P0B3Pd01@0A3@`05Q8A01LC4P0D40l04`l>00804Ph=0P0A3@`01`0@30/04Ph=01@@
3`0F4Q405A4@018>3@0A3@`00P0J5QD0201TH5l05a<B014=300I5A@04A0>00T81P0A40h09B@R0P0@
3`d04P0<2`T081lM02PW9@0c<S00HV5O01PG5@0<2`T020L5014@3P0I61H0T8n=01<B400F5A<04A0>
00l>300@3`d02PT700h=2`803`h<00X040l=014@3P0C4Q003@`:00/:200>3@/06aXH01`K6@0@3`d0
3``;0`0C3`h02@0A3@`040`;00h:2@0B3Pd05Q8A018>3@0?2`X04Ph=01@A3`02010?2`<03`h:00D0
3@`8010?2`0E51004a8>014@300200l>2P0=014@300>3@T03@`8014@300B4@d0;2/W01XI5@0?3PX0
3Pd901PG4`0K6QH040`9018>2`0201DA3P0301@@3@0F4Pl0510=0080510=0P0C3``00`0G4a003Pd9
00h=2@0200l>2P8040l;0180@T4m02`[9`0A40`04a8>00l>2P0?40/041<<010C3@0@4Pd04A<B014C
4`0A4Q@02``>00P92@0G6AH03@l<01@F400C5Pl201LG5@0<01`L6P0=3@/02PX801PH5P0B4Q004A4?
018B400C4a404Q8@010@3P0C3`h04Pl>0P0@3`d2014A3`0=01PH5P0A4a003a4>01DG500730P06QlK
00h>3P0h>3P0:b/[01LG5`0@40h06QXH01<C4@02014B3@0401<D3`0B4`d04A8<01<D3`D04Q<>00<0
6AXE01HG4P0C50l00P0B4`h0200C50l05QPF00/=300@4Q4061XI00`>3@0F61L02@X90P0G6AP00`0A
4a8030h=01<F5@0301@H5`0401<G5P0C61@04QLC01@I5@805Q/E02004QLA010E3P0F6aD06AhJ018G
4`0D6AD0724M01PM6@0E6QH05Q/G01@I5@0G71P06QlK01/P700G7AT06b4M020V900J82005a`O01PM
8@0J7b<07b@X02X_<P0J8200:2h/028X900L9B804Q/H030i=P0]=S<07RLT01XT8`806bLU03d072PX
01/Y:@0L:RX07R`]02@b=@0L:bh07Rd_02@d<`0O;b`0;Sli02@e;`0W>380:3Tc03=3@P0oCdh0>4U8
02Pl>`0W?3d0;45202i3A00[@440;dA702i3AP0`ADP0;dA70356B`0gC540=T]@03A9C00jCe00=4U:
03I;CP10EET0?55F045EG016FV<0Ae]V04IJI@18G6P0CF1^04ePK`1?HW40@eIT04QKJ@1;GfX0Cf=/
04]OJ019GFD0BemX04aPJ@1@I6`0FVig05=YM01MLWd0Ffmh05AXK`1CIf`0FVea05Y^K`1GJVX0G6i^
0080Ffe_03H0IWQj069dM01SMGD0IGMg06]mO@1cPh<0MHF507N7Q`1kRHX0OH^<07j<S@23SY00QI2B
08VBU`28TIH0RY>H09BMXP2GWZ@0TIRN09ZOY@2NXjT0WjBZ0:>V[@2XZk80Zjje0:f/]P2b/;/0]K>n
0;^ga@34_/`0b<;@0<Vod03>`]H0d/GI0=O9g@3Ib]l0f/_P0=c=i03RdnP0i]CZ0>WGk@3afo00mmoe
0?SRm`3ii_T0o>[m0?k]o`3mkol0o_?m0?ggn`3on?l0oo_o0?omoP3oo?l40?ono`H0oooo0P3oo_l0
103oo?l0oo[o0?ojo`3on?l20?gfoP050?oco`3okol0ongo0?oYo`3miOd00`3mhoh0C@3gh?P0l=[_
0>WFj@3Sd^<0g<[H0=W7e@3C`lh0cL3:0<^na`36^l00`KRi0;ng]@2c[Z/0[JZS0:j[XP2IVY40S8j0
07QlJ`1WJeX0NGe^08N;O021QgT0Ph]n07EmL01nQW/0OhV007j8O`1nR800NhJ007j9Q@1gPWh0L7ah
07B0O01]NGL0K7]h06]jM`1]OG`0IgMf06moOP1RLW80Ffe]05EWI@1>GUd0BUYG04EDD@10CdX0:CPa
034o=`0W=2X0:3D[02Tf:@0Q:b00;3</04E:A@0V:bD09BXS038i<@0S:R80<STb02li<P0J9B40<Sdi
03I0@00d?Sl0>DE303M6@P0d@ch0<T4l02ln>@0[>S<093</02Dd;00V=R`07blU02Lg;@0T<BP08B/W
0080:C8_00X09c0]02Xc<00K924082TV01XS800T;BX0:C8_02</:@0O:2D092XZ0P0S:BT3028X:00J
01dS8`0a=cL0;38b02H/;00K8B40;38b02@Y;00Q9bL07bDU01lU8P0P9R808BLS01`Q7@0W:b`07b<T
024U:@0C5Qd07B8X028Y:P0L9B@05QdM014G5`0K8B408BHV01PL7@0I6Q`201XK7@0701TJ700I6QP0
71/G01`K5`0M71P06QTE01PG4`0601LF4P<061LC0P0I61@03`0J6AD061LC01PG4`0=30P04Q4=01<B
3P0];2P061LD01HE4`0@3`d05A@B02<R800D4a403@`:00l>300201<B40804Q4?01d0510?01<?3P0A
3@`03`/:010<2`0C3`h0510?010<2`0B3Pd05A4@01<?3P0B3Pd040`9018>2`0D40d04@d:010<2@0A
3@X08AdJ01`H5@060`4081`I01HB3`0E4@h040`;014=30081@@0510?00l;2P0201PD4`0500l;2P0A
3@`0510?014=300>2PT01`0@30/03@0?2`X03PX900h:2@0?2`X040`900T50P0=2PD040d800l<1`0>
2`H03``700h;1P0B3`X00P0D4@`00`0E4Pd05a@?00l:1`02014<2@03010;200>2@H030L400803`X7
00@05A0=01@?300@2`P04@`91P0A2@L05@0B2PP04`/9018:200A2@L04`/901D=2`0D3Q002`D500@0
000H4`l0HEaF06aWH@0H4`d02`H200h91@0B30`0618D01@>400>20P03`T900h8200200`61P0D00h8
200A2`/03@L700@0000@2PX05@l?00d8200<1PH02082010:2P0?2@T02@<300/51@0>20P030H600l9
2@0B30`03`T900h8200?2@T200d71`0F014;2`0@2PX03PP800/51@0500003PP801@>3P0<1PH03@D6
00X00@0R61T03`D601T?400Q5aP03PD501061`0>10D04PP901D;300C2@X040L800h820803@L70P0<
1PH01P0H4Q804P`<00H10@0500002P@4014;2`8040H70`0A1`P01@0B20T03P@500l51P0@1PL04@L8
008040H700@03`D601882@0@1PL03P@50P0B20T0300@1PL03P@501D;300L4Q<05P`=00h41@0H3Pl0
4`T:01H<3@0700003P@501D;30H03`D61P0?1@@01P0;0@003`D400X0000:00004@L601@:2ACooooo
000Kooooo`0600`;2@0R8Al020L501<B400A40h061LE1P0?3P`0100>30d04@l@014?400?3@h200h<
3@0900d;300?3@h04@l@014?400?3@h03P`=018>3@0@30/04Ph=00805Q8A00<05A4@01<?3P0C3`h0
0P0B3Pd8014=300D00h:2@0H51<06QHE01TE500K5aH040`<00l>300=30X05aHD02TX9P081`D04a8@
01@C4@0<2`T01@@301<B400B4@l03`h<00/:2@0E518200l>300700h=300F5A<081lM01LF500=30X0
51<A010?3@0300l>300:010?3@0A40h04A0>010?3@0F5A<051<A02HU8`0Z:BL05A@B014?3@<04`l>
00H04@d<018>3@0D40l05Q8A01@@3`0B3Pd2014=3004014>300@3`/03`h:00l>2P803Pd900D030/7
010?2`0E510051<?014@3002010?2`0901<B3P0E510040l;00h=2@0@3`/05aHB010?2`0D4`l04A0<
008051<?00@04@d:01<?300F4Pl0510=0P0C3``01P0B3P/0510=01HB3`0E4@h05a<@020L6@<04Q4=
0`0A40`06@0E510051<?00`;1`0C4Ph040l;018A3@0C4`h04A8<010B3@0C4Q804Q8C010@4P0L6ad0
40l@00`=2P0E51804A8=01<D3P0<30X0>3Pf010@3`0E5A<06QXH00h>300B4Q00100C4a403P0B4Q00
510?018@3P0A40h04Q4?01<C4@0D51804a<A00T;200D5Q<0418?014F4P0;40`04A4A0P0D51@0100B
4Q803@d<01dM6`0C4a42014B3@0501<D3`0B4`d04A8<01DF4@0F5a800P0G61<0100D5A004a@?01LH
4`0F5a8401DF4@0A01<E500G6AP06A/J01DG5P0I6aX0418A02@V9@0H6QT05ALF01/M700C5A@04aHE
014E500@51<05ATH01<G5P0B5a<00P0E6QH05@0C6A<04QPB01@J4`0F71D06b4K01@I5@0F6aL06AhJ
01HK5`0J7a/06AhJ01LL600E6QH05Q/G01XO6`0K81`06R0L01TO6`0I7ad061dN01/P8`0201TN8P0;
01`Q9@0B5aX06R0P04eCD@0M8al04a`I01dV8`0i@Sl08R`Y020[9`0G8R400P0L:2H05P0L:BT072XZ
01h/;00P;S007Rdc02@c>@0N;C406BTY01d];00]?CT0834[02Pi<`0T=Bl08c<`02hn?00X>SP0:Sho
02Pm?P0/@D80;45302Tn@00^@dL20356BP0<0315B`0iCU@0@UIN03mCFP0gC4l0CF9S04=HF@0jCe80
@eQL04AIGP10E5/0AEUR0P18G6L0C@18FfP0BEaZ05AWM@1NLGl0Bei/04iQK`1@I740B5aX04]OJ`1:
GVP0Cf=]051TK@1DJ700GW9l069hQP1NLX00F6ag051TK@1JKW<0FFe^05IZJ@1LKfd0H79a061bL`1Q
Lg@0HWAf069dM01TMWH0J7Yj06eoO`1cPh<0MHF507V9R@1nS8d0Ohf>082>S`25T980R9>E08fFVP2B
W9l0SiRL096IW@2IWj@0VZ2U09fRY`2PY:X0XZJ/0:JY[`2[[[@0/;2h0;Bb_@2h]L00^[S30;njb036
_ld0b/;A0<k3e03BaMT0e/SM0=_<h@3Nc^<0glkT0>7Aj03[fNl0k=[`0>kIl03egO<0nnCi0?_Vn@3m
j?/0ongn0?o`o`3ol_l0ooGn0?ojnP3onoh0oogn00<0ookn1P3oool00`3oooh0oooo0?ooo`020?oo
o`0Q0?ono`3oo?l0oo[o0?oio`3nn?l0oOOn0?odoP3okol0ongo0?oYoP3miOd0oN?n0?cRo@3khO`0
mMke0>kIk03We>L0hM3P0=c:f03IamD0dL7<0<bob03:_L@0a[bo0<6i]`32^[L0][:[0:bYX02SX9H0
Nga`06e`GP1aMF<0N7eZ0080NGe]04L0NH1a07MoLP1mQGP0PXYo086;PP22S8<0NhEm07Z5P@1lQh<0
Mh9n07=oN`1dP7`0KGUg0760O@1]O7T0KGel06EeM01WMgL0Ff]Z05Y[J@1CI600Cf1I04mOF`18F540
?Te704=ABP0U<b/06RLN02<_9P0O:b807BLO028Y9@0T:bH09RlW02de;@0U;BD0;cX`02dh;`0/>300
E61J03@o?P0kAdH0?DY:03U8A@0iB4<0<3lj02`k=P0^?CL0:STb02Lf;P0W=bh08S8X02<c:@0T=2X0
82dT02H`:`0V;b`09Bh[02H_;00O:2D05QlL020Y9P0E7Q/082TV03Ho?00b>cP072DR02@Z:P0S:BT0
8RPX024W9`02028X:00O02H/;00O9BD09R`/01`R8P0b>3P09B/[02DZ;00S9BL07b@R01hT800P9B40
8BHR01lT8P0R9RL061`O01hR9`0G6R<092T_03Ho?`0F7ah07B@T01XP800E6a/061dN01HJ6`0E5QP0
6AXL01`M7`0K71h06QXI01/J5P0301`K5`806aXF1@0J6AD00`0I61@05aHB01LF4P0301LF4P0301@C
3`0I61@030/7008061LC00H0@D0l01DD4@0F5A<05aHD014@3P0@3`d2018A3`8051<A00L04A0>018A
3`0J6AL04@d<01XF5@0H51<040`;00805A4@01d0510?018>3@0D40l05Q8A018>3@0C3`h04@d:01<?
300E4@h04Ph;014=2P0B3P/0510=01TF500f<Rl0XIfJ05]GE00@30T04`l>010<2`0B3Pd05A4@024M
700X92<03`/:010<2`0D40l04Ph=00d9200<010<2`0>010<2@0?30L04Pl9010=1`0<2@<03@X4014>
200D4@/05A8<01HC3@0E4P`04Pl9010=200?2PL2014;2009014:200@2@L03PP500h71@0?2@H04P/9
018<2@0@2PL040T700L04PT70P0C2PP01@0B2@L050/901H>300?2@/03PP800803@P700P05a8<01<>
200U81X02PD100d8100B30`0C4I801H@4PH03PP800`030H600h8200G4A4030H6010:2P0I4a<04@/;
018<300:10@02`D5010:2P0A2`/200d71`0W00h8200@2PX03`T900l92@0<1PH02`D5014;2`0?2@T0
3PP801@>3P060@403PP801<=3@080P8040X:01@<3@0700004@P801<92P0B20T03@@501H=3@0A1`P0
40H70147200B20T04@L800l61`0>20P03`T9014;2`0B30`04`d=00X51@0A2`/04`d=00h92@0<1`L0
3`T900H04@L800X03`D601061`0B20T04PP901<92P0B20T040H701<92P0B20T040H70`0E2``02`0A
1`P04`T:01H<3@0B20T03`D601882@0D2P/040L8018:2P0B2@T07Q@E00H040H71P0?1@@01P0@1PD0
4@L700l61@0B20L05@/:00h40aCooooo000Kooooo`0700X91`0d<c402@P601PG5@0<2`T04A0>00l>
3003010?3@0E00l>300=30X02@L801LE5P0K6AX04a4B00d;300@3Pl03P`=010>3`0A3a0040h?00h<
3@0=2``04@d<00h:2@0B3Pd04`l>014=300B3Pd04`l>00804Ph=0P0A3@`0800@30/04@d<00h:2@0<
20L03@T8010<2`0A3@`06QHE00d9200:1PD040`;018>3@13?ch040l=00X91`071P@03`h<00T81P0H
5aD03@`;01<B400W9R@01PD400h=2`0;2PP07QdK018A3`0J6AP06QTG00/:200E51804a8@0`0B4@l0
0`0=30X03`h<00l>3003010?3@0;00l>300E518061LE00h=2`0@3`d05aHD01DD4P0E4a404`l>018>
3@0A3@`00P0B3Pd01`0E4A0040`;010<2`0I5A@04@d<00h:2@0B40d00P0@3`/300l>2P03010?2`0A
40`04Q4=008040l;0P0B4@d00`0C4Ph06APD01HE4@02010?2`0<00h=2@0<2`L051<?00/:1P0=30P0
5QDA018>2`0D40d05A4>014=2P0?2`P040`90P0D40d0100C3``04@d:014=2P0D40d6010?2`0S01TH
500K6QH04A0<014@300=30P051<?01DD3`0A40/040l;01<A4P0C4A<03P`?00400P0A3a400P4001dL
6P0?3PX040l:01<C4@25QH<0=cLe00l?3@061P@06a/I010@3P0B4Q004a<A018B400A4@l04Q8@01DA
400D4Q004Q4?01<B400C4a400P0D5180300D5Q<06A/H00T;2@0D6AD041DA01HF5P0B4Q806a/K01LG
5`1LG5X07AdK01<C4@804A8=00D04a@?018C3@0A4P`04Q<>01@E400201DF4@0301@E400C50l04a@?
008051D@0P0E5Q40:P0F5a803a4@01LI600;3@`05ALF01lQ800=3`h04A<B01HH5`0D5QD03a4@01DG
5P0U:2L061`K01DI600K7ah05ATH018G4`0D6AD051XF01DL5@0H7aP05ahG01<J4P0A5a4051TE01HK
5`0H7AT05AXF01LL600K81`05a`H01DJ5P0G71P06AhJ01XO6`0I7a/061hJ01DK6@0F6a`07B8U01`Q
9@806AhR00X092T/01LM7@0L8R0051XF01hW900M9R<05QlL00dH500Y=30072PV0P0M:BL05P0M:b/0
7R`/020^;P0S<C<07Rdd02Dc?00M;380<D1302Hf=@0T=3809SLa02ho>@0/?CL09cLd02dm>P0^@3h0
<4A502e2@`0_A4D0;dA702a1A00aAT/20397C01103=7CP0mDEX0Ae]T04IJHP0hCE00CfAU04YOH00n
DeH0?U=G049GG010E5/0@eMP04EII016FVD0AUYV04EHIP12EF<0D6=a04III`1;GV`0C5m]04AGI@1?
HW00Cf=_05AXL`1EJG@0F6ae065eP01IKgd0L8BD07:6T@1@I6d0E6Q/05EYJ01HK6/0H7Ab05e`KP1M
Kfl0I7Ig065cM@1TMWH0IgUi06]mO@1`PX80MHF507J6QP1hR8P0OXb=082>S`21Si00QI2B08JAT`28
TY@0TifO09VSY@2FWZ40UIZN09RMX@2OY:P0XjJ[0:FX[@2XZk00[K2e0;:c^02k^<<00P2n^lH05`32
_<X0ako>0<[2d@3Ba]L0elSM0=[;h03Ncn@0h]3V0>?Ai`3WeNd0k]_a0?3Ml`3cgO@0nN7g0?kVn`3o
j?`0on_l0?o_o`3ol_l0oo?o0?oho@3oo?/0oogl0080ookm00<0ooom0?oooP3oool00P3oool20?ko
o`030?kooP3nood0o_oo00<0oooo00@0ooko0?klo`3onol0oo[o0P3mn?h06`3om?l0onoo0?o]o`3o
jOh0oNGk0?gSo03jh?/0mmgf0?7Jl03ZeNP0hm3S0=g<g03Lb]P0fLOE0=?3cP3=`<T0bkk50<Jl_P33
^kT0^kB^0:bWX02RX9@0VIN:08>5MP1VJEH0KG9L07f2KP0208B8M`0l0827M`1iPG@0PXYm07^3N022
S8<0QY2707j8P01iQ800N8=o07N2OP1ePGd0M81l06ijN01[NWL0IGAa06QhM`1SLg80I7Ac05][JP1H
JF<0DV=J04mPF01?GUL0AeI?03a;A00S<2T0EfAL049?AP0R;BD07bXS024/9P0M9R<09c0/02H`:00]
=bl0:CDZ02Hd9`0_?380<Sle07>2N`0eA440=TA303U7A`0fAD80=dI102/j=@0X=c80;3/e02Lf;`0]
?C<0:SX`01h^900U=BX08S8W01l/8`0Y<bl09c0]02</:@0U;R/06B8O0P0K92401`0[=3407bPU020Y
9P0Y<Rl07BHS02@Z:P0Q9bL00P0P9RH0100Q9bL08RPX028X:00F71`202H/;00505EKF`0e>c/092DW
028T8`0Q8b800`0N8al04P0P92<0:2`_028V:@0I7R@07b</02<X;P1jPh<09Bh]014I600H7Qh0728R
01`Q8P0E6AX05QLI01PI6`0L7Al07AhP01/K6P806APD00@06aXF01`K5`0L6aL06QTE1P0G5Q8201HE
4@805A@@0P0D4`l02P0I61@040l;01<B3P0=30P08B0L00h=2P0@3`d02`X8018A3`0J6AL201@C4@0Y
018A3`0>3@/030/900l>300G5Q@04`l>01dI600J5QD03@T800h:2@0A3@`04`l>018>3@0F4Q405A4@
014=300D40l04Ph;01<?300E4@h04Ph;014=2P0B3P/02@D201DA3P0;1`@0?3Pe02XV8`0D40d02`L6
018>3@0<20L00`0000l;2P0A3Pd04Ph=014=300?2`X02PH501@@3`0/:2L01`0@30/4018>3@0?010<
2@0?30L03``500h;100?30D05A8;01/H4@0F4``04a09018?200A3PL03``500X7000D30X04`/90080
40P600P04PX801@<2P0@20H050`:018:200D30X05@d;018:20H04PP701h04`T801@:2@0C2@P04PP7
01@:2@0E3@/04``>00T30`0;1P<03`X700/6000?2P@03@P200l:1P0=20@02P@400l92`090`D040X:
00h8200?2@T04P`<014;2`0?2@T05a4A014;2`070@402P@400/51@080`<200`61P05014;2`0E3`l0
40X:00`61P0@2PX00P0?2@T400h82006010:2P0?2@T02P@400/51@0?2@T01@000P0=1`L02@0A2`/0
6Q@D0108200K4A805P`=00/10P0Q5aP040H700l51P0301882@804@L800@04@P9010:2P0?2@T03`T9
0`0>20P01@0@2PX020<300`61P0^:2P0O7If00804PP90`0A1`P00`0@1PL04@L80147200301<92P05
01882@0A1`P050X;01882@0A1`P00P0D2P/0300G3@h04PP90147200@1PL03P@501882@0E2``04PP9
00P0000;0@802P0101/A4PH04@L81P0?1@@01P0>10<09adL02<I600@1PD02P4101@:2ACooooo000K
ooooo`0400d<200I61@03@`800d<20<03`h:00/040l;014@300@3`/03Pd900`;2@0=2``05Q@E01TG
600C4A803P`=00l=3P03010>3`0:00l=3P0>30d03@/<01<?3@0?2PL050l<01<>2`0@2`P04Pd:01<>
2`804Pd:0P0A30T00`0@2`P03`/:00l;2P0500l;2P0800@0000F4Q405Q8A00T5100O6aX030/9014@
3P0?3P`2014@3P0=010?3@0A40h030/900<2000I61H030/900l>300B4@l03Pd;00d<2P081`D06APF
00H51002014@3P0801XI5`0G5Q@03Pd;014@3P0?3P`040l=014@3P0@3`d200h=2`0700`;2@0A40h0
40l=00d<2P0?3P`03`d;01<=3@02018<300901<=3@0D3Ph050h>014;2`0B30`05a4A018<300@2PX0
4@l<00804A0<100@3`/2018A3@0@010?2`0?3PX04Q4=01LF4P0D4`l061LC01LF4P0B4@d04a8>010?
2`0<2`L04Q4=00`;1`0>3@T051<?01<?30805A0=0P0B3@X0100D3``061<@01HA3P0D3``201<>2`03
010;200?3PX03`h:00@040l;01D020L300X91@061@403`h:014@300G5Q805a@?018>2P0A3@X05A4B
01D@4`0?2Ph04`hB01LB5@0>2PT05Q8A01<@300J6A@02`/902HV90092@L00P0E5A<010061P@03Ph<
018B400C4a42010@3P0=014A3`0F4Q40514@018A3`0A40h04Q4?014A3`0:2PP0418?00T;200J71T0
1@X601LL600200l?3`0501PH600@4100Bd]901@D4P0C4a400P0A4Pd0100C50l04Q<=014B300B4`h3
01<D3`03018C3P0A4Pd051D@00<051D@00l04a@?018C3P0C5A@05ALF00d?3P0G6AP06A/J01<E500D
5QD06A/J010B4@0<3Pd0<38a04a?CP0R9RD00P0E6AP02P0B5QD051TE01PN6P0F71P061lH01`U7@0J
91`051hE018H4P0N8al201HK5`0J01PM6@0?51005a`H01LL600F6aL061dI01XO6`0I7QX05a`H01/Q
7@0N92806R0P01/P8`0K82@05a`P01@I7@0N8bH06R0P00`B400Q9b<092dZ00lJ5P0I92008B`X01lZ
9P0J9R@201`X9P0^01/Y:@0M:b/07bd]024`<P0/>d80Gfef03M6C00V=CP08S8a02@d<P0R<bd08C8/
028c;@0U=C80:3Pe02Xk>P0_A4D0:d=302e5A@0^ATP0;4A6039:CP0cBU00=4]A03=:DP0fC5L0?59M
03Y@FP0nDeH0>4e>03Y?D010EEP0?U=G0356B`12EUd0@eMP04AHH`16FVD0AUYV04EHIP14F6<0BemZ
04=GHP17FVP0AEQW049EI080CV5_04<0DfMb05AXL`1EJG<0GW9m05=XN@1mTJ40R9bW05Y^M`1KKg@0
GW9a05mcLP1SMW@0GG1^06=eM@1^P840HWAf06MiN@1ZO7`0Kh6107B6QP1hR8P0NHV907^;R`20SXl0
PY2A08>ATP28TiD0RYFG09NPXP2>UYT0VZ:U09^SYP2FVil0VYnS0::WZ`2VZJh0Z:^`0:Z]/P2a/[L0
];Fj0;^h``31^lL0`[c80<Bnc03:`]40clCD0=C7f@3HbMh0g<gR0>;@iP3Td^P0iM?Y0>_Il@3^f_<0
lMgf0?OPn03khoT0o^Ol0?oZoP3okOh0oo7o0?oco`3om?l0ooWn0?omnP3oo_/0oool00@0ooom103n
ool09`3nooh0o_om0?koo@3nooh0o_oo0?ooo`3oo_l0oogo0?klo`3nn_l0o_Wo0?ghoP3om?l0onoo
0?o]o`3ojOh0oNGk0?gSo03jh?T0m]ce0?3Ik`3Ye>L0h/oR0=g<f`3Jb=H0elGC0=?3cP3>`LX0bkk5
0<Fj_@33^kT0]:fW0:JQVP2KVHd0SXao08>5MP1aM640LgQR07b1K00208>7MP1507V0L01fOW40OhMj
07InL`20RX40PXb407n9P@1kQX80NHB007R3O`1fPWh0LWij06ahMP1VMG80Gfi[06=cLP1NKVd0GVi^
05MWIP1EIUh0Cf5F04YKD@17Edd0?Ti403A4>P0iASl0OXZ406E`JP0a?3H07RTT01dX900O:RH0;STd
02@_9`0/=bl0;c`a02Dc9P0/>Rd0<d<h04EDC@0mC4T0<40n0351@00^?CX0<D0k02@c;P0R<BX09cH_
020_:00Y>Bl0:SX`01l_9@0[>c00:3P]02@a:00Y<bl09Rl/01lX9@0P:BH04Q/H01`U8P0T;BX0;CHc
020Y9P0K92407BHS01XS800U:b`08RLZ00808BHY01`08bP[02@Y;00[<3<06AhQ01hS9P0T:B`0;34d
018H600P8B80828Q024S8P0Q8b007B8N01`Q7@0M8B00>cm203Xn@@0H7B<08RH_01`P:@0S:bh07RHX
01hT9`0G71l05Q/N01TN8@0H71l06Q/O0P0I6Qh00`0L7B407AdL01/H4`0201/H4`8071TD00<06QLB
01PE400H5A000`0H5A0301TF4@0601PE400G50l05a@?01PE400G50l0514<0P0G50l03P0I5Q4061DC
01<B400<2`T04A0>01DD4P0?3P`04a8@014@3P0>3@/03`h<014@3P0B4@l03`/:0P0B3Pd00`0?2`X0
4@d<01@@3`02014=300L01DA400D40l03`/:01<?3P0B3P/0510=01DA3P0C3``04@d:018>2`0J5Q<0
6ADB01<?300;1`@05a<@018>2`0@30/061@C01<?3P0>2PT04`l>01PD4`0F4Q404`l>014=300?2`X0
61@C02/W9PH040`;00l03`/:014=300B3Pd04Ph=014=300?2`P040d800l<1@0A3PL05A8;01XG400L
6A80514:014>1`0>2`@00P0@3@H00`0=2P<04PX8018:200201491`08018:200C2`T03@D3018:200>
1P@04@T701<;2@0?1`D601881`8050X901D04`T801471P0C2@P04`/901<=3P0F41001P4001<>2P0K
5Q00IF1J00d81@0I51006aHB01H@400<1PP05a4C00l92@0=1`L03PP8018<300A2`/00`0?2@T01007
0@404`d=01LA4@0=1`L200X4100401H@400J51@04`d=010:2P804P`<00@040X:00d71`0=1`L03PP8
0P0A2`/200d71`0?00h8200@2PX03@L700l92@0>20P04P`<01D?3`0d;2`0Rh6200`20`0N51D01`00
01H<3@0D2P/04PP900804`T:00<04PP901<92P0A20T00`0=1`L200`61P0600L10@0A2`/04@/;00P2
0P0A2`/0>38b0`0B20T00`0A1`P040H701061`02014720804PP900T04@L801061`0A1`P04`T:0147
200>10D04PP90147200D2P/00`0A1`P0200>10D04PP900h41@0C2@X03P@501@:2`0L4Q<01`001P0@
1PL600l5100600/1000Q5aH07A<B00`20@0:0@404`T85?ooool001_ooooo00d05Q@D00/:2@0B4@h0
30/:010?3@0@3``04@l?014@3P0>3@X03P`<00l>300=30X04Q0>00@04@h>00<03``<01<@400C4100
0P0A3Ph03`0@3@d04@d<018>3@0?2`T04`l=018=2`0?2PP04Pd;01<>300@30X04Pd;01<?3@0?2`T0
510>010<2`0201<?3P0U01@@3`0B3Pd03`/:00l;2P0D40l040`;00h:2@0F4Q403`/:00d<2@0>2`T0
40d;01@?3`0L5QL030L701D?400H4a@01P8201TF5@0920H0518A00l<2`0=2PT030T801HC4P0?3@/0
40h<01<@3`081P@0518@00h<2P0C40l0514@01@B400C40l04Q0>014>3@02014?3@0U00h<2P0D4A00
4a4?010>300E4Q405A4@010>300B3@`0510?014>3@0C3Pd05Q8A014?3@0C3Pd03``;00h;2P0C3Ph0
5A4?01DC3`0B3``040d:014>2`0A3`/04Pl<018@300E4Pl04Q0<00l=2@0C40d040h:014>2`0E4Pl0
4Q0<00l=2@0F4a0040d:00h<200201@B3P0:01<A3@0@30T0510=01D@3@0E4@h050l<01<?300E4@h0
61<@01LB3`805a<@01h05Q4>01<>2`0@3`X04a<<00l>2@0@3`/04Q4<014A2P0E50l051<>018A2`0F
5A404A0;00d<1`0D4@h04@l<00l=2`0C40l05A<B010=3@0B3Q4040h=01TF5@0B3`h040h;018A3P0C
4Q003`h<018A3`0C4a42018A3`1;00l?3@0B4@l04Q8@014@3P0A4@l04a8@01<A4@0D4a803Ph=00l>
3@0B4a403Pl=010B400I71X05APF07MkN@0E6QL03a@A02TY:00@40l03Ph=014@3`0E518061LE01<C
4@0E5A404a<?01<C400D51404a<@01<D400F5a<04a<@018C3`0D51404a@@01LH500H61D04a@@01@E
4@0A4Ph04Q<>01DG4`0E5Q805QLC01LH5`0B4a4051DD01XK6P0=3Ph06AXI010A4@0D5AD07R0M01<G
4@0@50l05a/E018F4@0@5A005A/F01PN6P0M8b0072<P01HO6`0D7AT04aXF01/O7@0E6AL06QhL020U
8P0G6aT061`J01DI5`0G6aT06QlL00805AXG04<061dJ01`T7`0/=3408BPX01TO8P0E71l07bDZ01DK
800H7R<0728T01LN7P0M9B@06b@R01/U8P0N9bD0620M01PR7P0N:2H09S0^02@_;@0P;2d08Rd^02Db
=00[>3`0LH270<gLi01aPHP072``02Tj>`0W>3P0:3Th02Df=00U=SD0:S/i02`m?@0_@D00<DA302a1
?`0[@3l0;D5302m3A`0gBe00<dI>03U<E@0iC5H0>4]D03iBFP0oDU/0@5EG03Y?C`0nDe<0@5EG03iC
E`0oE5T0?e=J04AHHP14F6<0AeYW04ULJP10Df40Ae]U04AHH@1<H6X0B5aV04MKI@1@I6l0CF5[0080
Cf=]01<0D6A^05EYL@1HK7@0GWAm05M/L`1EJFl0CV9V05a`LP1FJFP0Gg9b061bL@1NL6l0IWMg06io
P01VMgP0JWal06eoO`1bQ8@0NHZ:0080OHb=02`0P8n@08>@T@24TI80Qi>E08^FV02>VI/0XJV/092H
V`2FWZ40WZJZ09RMXP2RYj`0YJV_0:JY/@2[[[H0/kBm0;Jf_`2g]l40_;W60<2kbP32_L`0b<7@0<g4
eP3Aa]P0e/WL0=_<h@3Ncn@0i=;X0>OEj`3Yend0l=[d0??Km03fgoH0nnCk0?gVn`3njod0ongn0?o`
o`3om?l0ooKo0?ogo`3oo?l0oool0?onoPD0ooon103oool01@3oooh0oool0?ooo03oood0ooon0080
oooo0600ooko0?omo`3oo?l0o_[o0?gio`3nmOl0onko0?o/o`3oj_l0o^Kn0?gSo@3jgoT0m=[c0?;J
k`3/e^H0i=7N0>3=f@3B`L`0e/O@0=?5b`38_<00ak^k0<:i]P2o^;80ZZJM0::OU02ASh<0OGa`07Ef
J027RGH0MGUT0823KP1dN6D0JVeK06ebHP1jOg00O8=e07ElL@1lPgX0NhAj07j7OP1nRHH0N8F407J3
PP1cP7l0KGaj06]iM`1XMg@0Hg=`06AdLP1PL6h0Ff]Y05=SG`1CHe/0BUYA04IFC@0gASd0=D<k03E1
>P10C4H0;cTd02D/:00U;BT0:2l/01`T7P0Q:B<0:c@]024/900c@3L0;S/c02Ph<00Z>c80=DI002Hg
<P0nCT/0=4=103M4@`0b?CP0>TDo02Te;@0U<2T0;SXb02D`:@0Q;B@0930W024/900S;bH0<Sdd02<^
9P0P:bH0:38^01lY9P0R:bP072DR02H_;00P9bD2028Y9`0W02<Z9`0/<Bl09bd[02D[:@0T:RT08RPW
01lU900S:BP09R`[01hT9@0T:R/08RLY020U9`0K82<082HV01hR8@0]<2l0=3Lf01lR800R9B<0720M
020S8P0g>SX0=cXl01hP8`0Q8bL061/O028V9`0E6A/05AXJ01LL6`0H6Qd06QdN01PK6`0M7R4061XK
01TK6`0M7R40>cXh00806ALC02@071XE01/I500M6aH06ALB01/I5@0H5Q8061HA01/I500H5Q806aLC
01XF4P0I5A<05Q@@01DE400T92409RHR01@D3`0C4a005a@A01XF4P0D3`d05A4>01<@3P0F51405A<@
010>2`0G51805Q@A01@B3`0=2`T0514?01LE4P0B40d0510>014=2`0B3P`201DA3`804Ph<01/04@d;
018>300B3P`040`:018>300@30T04`l<01DA3P0B3P/040`9018>2`0E4@h030P501HB3`0=2@H04@d:
010<2@0E4@l050l=014<2P0D40h03`/9014<2P0D40h040`:01<?3@0A3@/00P0C3`d0200A30X040`:
00l;2@0@2`T04@d;018=2`0A3@/04@`:0P0@30X01@0A30X04@d:00l;1`0A3@P04`l90080510<00H0
4`l:01<?2`0@30P03`/5010<200A3@T2014<2@0A00h71P0A2PT04P/:01<<2`0B2`X04@X9010:2@0@
2@P03PL600`61@0E3Pd04``;0148200>1`H050`;03`c<`0M5QD00P0C2PX0600A2PT040P80188200A
2@X04`d>010:2P0B30`04@/900/60`0@2`P06aHC00l:1`0?2PP030L701@>3`0;1@H040X:00`61P0=
1`L06Q@D00d71`0?2@T03@L7014;2`805@l?03L03`T9014:2P0?20P04@L801482@0<10D03@@501D=
3@0D3@d04PT:01082@0:10@03`D601492@0D30d07A@E00l61`0F3`l040L8018:2P0@20T04PT:0108
200=1PH04PP901hD5@0S6AX03PH60148200J414040H701071`0B20T05@/<01882@0H3Pl04`T:01<:
2`0A2`/04P`<014;2`0B30`04`d=010:2P0=20P05@l?00h820070P804Pd=01<92P0?1@H04@L801hD
5@0>10D03PD600@04@L80P0@1PL02P0>10D04@L80147200=0`@04@L801P>3`0B20T03`D60147200C
2@X201882@0601471`0;0`805@/;00`30`0?1PD060h>0P0@1PH0100>10@03@<300l51@0A1`L20106
1@803`D40P0A1`H01P0?1@D03@@301D;2P0>10<04@L600`20ACooooo000Kooooo`804Q0A00D03P`=
014?400<2P/03P`=00X82@02018@4@<03P`=00H04Ph=00l;2P0>2PT03`/:014=300@30/301<?3P<0
4Ph=00l04@d<00l;2P0B3Pd04@d<00l;2P0B3Pd040`;00`81`0:1PD03`/:00`81`0E4A004@d<01<?
3P0B3Pd00P0G4a807`0B3Pd04@d<018>3@0A3@`040`;018>3@0C3`h04A0<010<2@0A3@X05Ph?024F
6P0N4aL05`d@01@;3P0P6Q`030T901DD4P0<2PP0100000`81`0U8B0040`;00H20@0@30/04`l>00d9
200B3Pd03PX901DA400C3`h00P0D40l401<?3P0H01@@3`0E4A005A4@01<?3P0D40l04a4?00d<2P0>
3@/04Q4?014@3P0B4@l051<A01dL6P0920H03@`:028Q7`0A40h04@h<00/7100D40d071PE014=2P0=
2@H05Q8?0`0C3``03P0A3@X061@A01LC400J5Q<06ADB010<2@0>2PL05Q8?010<2@0A3@X0510=01DA
3P0C3``04@d:0P0C3``01`0B3P/040`9010<2@0?2`P04@d:018>2`0D40d00P0C3``0100D40`03`h9
01LG3`0?3`L201@D3003014A2@0B4PX04Q8:00804A4900P04108010?2P0B4@d03Pd;00d<2P0@3`d0
4a8@01@C4@@04Q4?00P04A0>010?3@0?3P`04A0>00l>300A40h05QDC018A3`804A0>0P0B4@l201<B
4004010@400B4Q804Q8B014C4P80418A00l05QXI00dA400g>cX0T9JD00hD4P0@51<04Q8A014@3P0Z
:BL09B@R00h=2`0<2`T051<A01PG5@0D4a400P0B4@l03@0A40h05ADC01TI5`0D51804Q8@01@D4P0B
4Q003Ph<01HF500J6QP05ADC01@D4P0S91l00P0D5A0201<D3`804Q8@00l05QHD01TI6@0?3`l07AdM
01@D500E5a804aH=01LJ4`0L7aP05aXC01<H4P0D6QD061hJ01hT8P0H81l00P0?61L01P0D6QT051PG
01DI600I7A`06alN01PL6`805a/J01l061`K01TM700E6AP05QXI01`R7`0>5a805QlL00hF5P0E7Al0
6b8X01hU;00H7bL08RT_01XQ9P0N9RT041PJ020U:00L8B@07B<S01lU8`0M8b407RLT024Z9`0R:bP0
8R`]02@]<P0W<3D09c<i02hmA01IJW40>DYA008093Hj06L08S@h02Dg>@0W>C/09cTk02Li>@0Y>c/0
;T0o051SH@18FeL0>Te<0353A@0`@TH0;d1803U:E00fAe40<45;03A5C@0lCED0?DmF03Q<C@0aAdD0
>4i<041EEP15FUh0AeaQ041DG@13Ef40AEUT04=FI018FfX0EFQf04QLI@18G6<0Cf=Z045EG019GF@0
DVI]051TJ`1CIfh0Cf=Z051TJ`1GJg80EFY_05U^K`1EJVT0E6QW05IZJ@1KKVd0G6i^05maL@1QLW80
Hg=c06EeM@1YN7T0K7Yk06emO@1^P800LXB407J6QP1iQhP0NXR908:@T@25T980Qi:D08ZEU`2=V9X0
SYRJ09RPX`2GWj80U9bO09ROY@2JWjD0XJJ/0:b_^02Y[;D0[[6j0;Ng``2e]L40/k>o0<2lc@32_/l0
a<3A0<_4eP3?a]T0d/KJ0=W<h03Ncn@0hM;W0>OEj`3[fNl0kmcb0?GLm`3igoP0nn?k0?kWo03mj_d0
o^gn0?gao`3nl_h0o_Ko0?oho`3onol0oogo00/0oooo00D0ooom0?oon`3ooo/0oool0?ooo@020?oo
o`1B0?kno`3ooOl0o__o0?gjo`3lnOl0o_Go0?o^o`3njol0o^Wo0?kVo`3lh_l0nMkh0??Jl03afN`0
jmGR0>3<e@3Kb=00c[o60=S9cP3CalT0aKVi0<Bk]P2m]Zd0ZZJJ09jJSP2GUHP0QhMk07moL`24Q7T0
RHYh06i`F`1mOfX0JVeJ061SD01cMVD0NWi_07YnL01hOW80NGmc07Z0M01jPWT0NHF30761P@1]OGd0
JWYi06EeM01WMgH0IgMd06AdL@1PL6d0FfaV05IWH@1AHU`0AeI?04=BB`10CdP09c@]03E1>`0oBT@0
?dQ302Ta;00N920092TU02/`;00P9Al0:2hT02`e:`0R;BD0;STc02hm>@0b@Sl0:3/i02e0?P0dAdD0
>DU603Q8A@0f@Sh0<c`g038i<P0W;RL09B`U02L^9`8082LP02809RdV020W800a>340HVUR03<m=@0G
8Ah05b8N020[9`0W<2d0;SLd02</:@0Q9bD082@S02<W9P0X;2/09b/Z01TN6P0S:B@08bTU020V8P0N
92007bDS028X9P0O9B<07B<S01hT900P9RH07b@W01dS8`0L8R40N7ak07f1P00R9RD05aTH0P0T9RD0
1`0V9RH092@T024Q8@0P82007alO02<U900I6aX00P0L7Qd201/M700>018D4`0H6QT05ALF01LI600H
6QT0O7aj02XY9@0<2`L051<?018A3@0S8Qh051<?01LF4P0E510201TH500I014@300E4Q004@/;010<
2`0B4@l07alM03m1?P0j?3T04A<@018B400E4a805a<B01H@400F4A00510=01<?300D40d04`l<01PD
4@0N6QL01@40014=2P0M6AH04Ph;00h:1`0200X60`0800d91P0B3P/05A4>01PD4@0E4@h04`l<018>
2`0C3``201@@3@0H018>2`0C3``05A4>01<?300A3@X04Ph;01HB3`0?2`P03@T6014=2P0C3``06QHC
018=2P0?2PL04@`901D@3@0B3@X04`h;01@?300@2`P04Pd:00`7100D3``04`h;0P0A30T01P0?2PL0
40/8018=2P0C3P/05A0=018=2P803`X700X04Pd:01D@3@0J5A805a8?01<>2`0B3@X03`X700X50P0C
3P/04Pd:0`0@2`P01`0A30T01@0001D?3`0;1@D050h>00P20P0=1`L00P0@2PX02@0I4a<07ALG00/5
1@0@2PX02P@401XD500F410040X:030Z:P0700l92@0K00X4100B30`03`T900T30`0D3Ph07QPH01`F
5P0@2PX03@L7014;2`0@2PX030H601@>3P0=1`L0618B03Tc<`0D3Ph02`D5014;2`0B30`03PP801<=
3@0A2`/04@T901H<3@0J41405P`=00803`D600<050X;00h41@0=0`@00P0D2P/0200M4a@081HG01X@
4@0R61T03P@500l51P0;0@803`D60P0B20T08P0A1`P040H701061`0@1PL06@l@01P>3`090@401`00
00P0000M4a@0308300d3100B20T01`0000P0000<0`@03`T900d71`0;1@D03PP800`61P0?2@T0618B
08EoO`0C3@d06aDE01<=3@0I3a004PP901T?4011=cP0;R@U01061`0C2@X201882@0=0147200@1PL0
40H701882@0C2@X04@L800`20`0>10D060h?01061`0?1@H040H70147200201882@0<01<9200>10<0
2@4000l5100=0`802P0001061@0C2@P05P`;01D;2P0C2@P04@L60P0@1PD02P0>10<03`D401471P0B
20L01`0001<9200700002P0001071`0K4A0Dooooo`006oooool03@0A3a004Q0A010>3`0A3a004Q0A
01<A4P0B41403P`=00d;300>30d040h?014?400A3@`00P0>2PT00`0?2`X040`;00l;2P03014=30<0
4Ph=01<04@d<00l;2P0B3Pd04@d<00l;2P0B3Pd04`l>01HB4@0A3@`05A4@018>3@0H51<04`l>018>
3@0@30/0510?01HB4@0B3Pd04@d<00804`l>01d04@d<010<2`0A3@`02`/6018A3`0I5A@08A/K01L>
4@0F3A004`X=01T@4`0N61X02`P9028P8@0F4a<02`L601TE500l>3L07ATH00d9200C3`h03@T801HB
4@0A3@`04Ph=00/71P0@30/04@d<018>3@0201@@3`0801<?3P0A3@`04`l>01@@3`0A3@`03PX9010<
2`0@3@`2010?3@0M00l>300C4Q0051<A00l>300G5Q@020L501PG5@0T8b402PT701DC400=2@H04@d:
01LC400A3@X09B4N01dI5P0F4Pl040`9018>2`0C3``06ADB01lK600N6QL05a<@00l;200>2PL04`l<
00l;200@30T00P0B3P/02@0A3@X040`901DA3P0C3``04@d:00l;200@30T04@d:01<?3003018>2`08
01<?300D4@d030/601@D300?3`L051@<014A2@0>3PH2018B2P804A4900P04108010?2P0C4Ph03Pd;
01LF500I61H04a8@01@C4@@04a8@100B4@l0100>3@/040l=01HE4`0C4Q02014@3P804Q4?0P0C4Q00
6P0B4Q80410@01@D500A4A403@h=01@F5@0=4A003a<B01dQ801>E5802Q0>00`@3`0C4a404Q4?028Q
7`0J6AL04Q4?01LF500I61H071/I01PG5@0D4a404a8@010?3@0F5Q@05aLE0P0E5A<02@0D51804A4?
01/K6@0A4@l0410>01DE4`0G5aD05aPC01HG4@0301LH4`0J01@D4P0C4a405ADC01hN7P0C4a<08B4Q
00h>3P0G61D051L@01LI500L7QT061XE01<H500D6QH05A/G01HL6P0B6QL03aPE014J5`0E71X05QXI
01DI600G6aX06AdL01LK6P0F6QT201TM700H01HJ6@0I7A`06AdL01`R7`0<5A004a`I028Z:P0W;c40
4QTO01PO9P0S:S806B0V01hU:P0L92L08BT[020U:00M8RD07R<U020V900N92807bPU020[9`0Q;2P0
92h_0P0V<CD01@0V<ST05B@[01h_=P0S=3/0;3i2008093Hj02H09cTk02Tk?@0[?Cl0:S`l02/m?@0^
@3l0B5]I049ED@0hBTT0<dE703=5B@0dADd0>4UC03E6D014EEl0Ffad05MXL00lCUD0@eMH03Q=C@0k
D540@eQK04EJGP13F5d0BUiW04IJI015FF@0?4mM049EH`1VNHL0AUYQ04aQIP17G640?eAI04iRJ01>
HVT0Cf=Z05=WK`80DVI_03h0EFUb059VK@1HKFh0EFYX05AXI`1FJVT0Ffi]05a^KP1OLG40HG9b06=c
L`1UMGD0JWUi06ajN`1^OWh0LX:207F5Q@1gQhL0NXR907^9RP24TY<0R9>E08ZEU`2=V9X0T9ZL096K
W@2FWZ40VZ:U09NOXP2PYJ/0][_10;Bi_`2/[kP0[[6j0;6d_@2j^/H0_;c80;ZjaP32_/l0a[oA0<W2
e03?a]T0e<SL0=G9g@3Kc^80hM;W0>CEjP3Zf>h0kmgc0??PmP3hgoX0nn7j0?gUo@3ojOl0onco0?o^
o`3mlOl0o_;n0?ofo`3onOl0oo_o0?ono`/0oooo00D0ooom0?oon`3ooo/0oool0?ooo@020?ono`1F
0?omo`3nnol0o__o0?cio`3mmol0ooCo0?o^o`3njol0o^Wo0?kVo`3lh_d0n=kh0??Jl03_enX0im7N
0=_7d03C`LP0cl370=G6b`3?`lD0a;Zi0<:i]02e[ZD0XIfA09jJSP2EThH0R8Ql08J6NP2:S800OWm]
071bG@1iO6L0I6MD06=VD`1fNVT0NGe^07YnL01jP7@0Nh5g07Z0MP1gOgH0MX:006inOP1[Ng/0IgMf
069bL@1SLg80JGUf06EeLP1MKVP0EfQR05AUG`1@HE/0@e9;03]9@P0gA3d09c@]03i:@`0h@cd0=d0k
02P`:`0J81`08RPT02`a;@0Q9R00:2lW02Pa9`0`>c<09C0Z02/j=P0c@d80?U5?03E8AP0cAT@0>TY7
03Q8A00_>cL0>D8m030g<00_=Rl0<CPa02`c;00X;bP09RdV01dT7@0P9b0202L^9`0>01/U7@0[=C80
5R4M01`W8`0K9240C5EB01LP7@0Y;bd09RXY020T8`0T:2L07R8Q01dR7P0U;2H3028X900V020V900N
92807bDS01lU9@0Q9bL08RPX020U:00M8b<09R`[034e=00`=3<07R8Q01LI600K7A`07b4P02@T900S
8b<0820P024Q8@0T92@06adL01XL6`0P8R407b4P020R8@0T9RD07AlN01lQ800P8R408R@S01lQ8020
P7h0<C0/01HE4@0P7a/08R4M03@c;`0F5A4201PG4`0F02<R7P0L6aL04Q4=01/H5P0M5aL07a/J01`K
6@0B4Q0061XG01/M6P0A4a004a<A01<A400D40l05Q0@01LB4@0B3P/04@d:01DA3P0C3``04Ph;014=
2P806QHC00<04@d:00l;200D40d00P0D40d0200E4@h061@A01dI5P0W8b005Q8?01@@3@0C3``0510=
0P0E4@h00`0C3``04Ph;018>2`02018>2`0700l;200B3P/03`/8010<2@0B3P/03@T600T50P0200l:
1`0401<>2`0B3@X03PT601<>2`804Pd:00@05A0=00d81@0C3P/05A0=0P0A30T2010;2004018=2P0C
3P/050l<018=2P803`X700D04Pd:01@?300E40d040/800l:1`0201<>2`0300d81@0B3@X04Pd:00@0
40/80P0?2@T04004000050h>01<=3@0D3Ph03`T9018<300H4Q809R0P018<300;1@D04P`<00L10@0A
2`/0<R`/02@N7P06000600l92@07018<300G4A4050h>014;2`0Q6a/0;bTY014;2`0200l92@0E010:
2P0>20P02`D500X51@090`<02P@401TC4`0:10@04@/;010:2P0E3`l02`D500`61P0?2@T040P801P>
3`0O5AH060h?00l51P0A1`P050X;00803@<400H04PP901061`0F30d060h?01<92P0D2P/201061`03
020F5`0@1PL04@L800804@L801P040H700l51P0?1@H0308301P>3`0G3@h0:AlP0147200G3@h02P01
00`20`0F30d0200002`R8`0C2P/040X:00h8200A2`/05Q0@018<30090`<0100006]UI@0;1@D200T3
0`0600L0000G3@h07Q@E01L=3P0=0`@040L80P0D2P/03@0C2@X040H700l51P0>10D050X;01882@0@
1PL03@<400h41@0@1PL03P@500l51P0A1`P00P0?1@H03P0A1`P0718A01/A400@20L0718A01071`0A
1`H0308100d30P0>10<040H500h40`09000040H50`0?1@@0200A1`H04PP701<9200?1@@04PP700T0
000H3Pd01`005?ooool001_ooooo00l03`d>00h<3@0?3@h02`T:01DC500A3a004a4B00d;300B4140
4@l@00/92P0A3a004`l>014=300@30/00P0B3Pd0100@30/03`/:010<2`0A3@`4018>3@0@010<2`0C
3`h04Ph=010<2`0C3`h03PX901@@3`0?2`X04Ph=00h:2@0B3Pd05A4@018>3@0=2@P04@d<01@@3`80
4@d<01T0510?01DA400B3Pd04@d<00l>300A4Q403@d<01DD4`0W8b<04Pd>01D@4@0B30h071LH00/8
2@0E51@04Q8C00h>3@0D40l05A4@01@@3`0H51<0510?00l;2P0C3`h0:bLV00806ADD00D03@T801XF
5@0D40l0510?01<?3P03018>3@0301<?3P0B3Pd04@d<00805A4@00@04a4?01/J600H5aD03@`:0P0B
4@l0500@3`d030/901`K6@0e=3805aHD00d<2P0D4Q00510=01hJ600B3P/05A4>03hj>00P71T061@A
018>2`0C3``04@d:018>2`0H51405A4>100B3P/401<?300:018>2`0A3@X061@A01HB3`0C3``04Ph;
01<?300F4Pl06aLD01PD4@80510=00P05A4>01@@3@0B4@`05QD?00l?200F5@l04Q4;01<C30804Q8;
0P0A4@X01P0@40T040l:018A3@0?3P`08B0N02<R80804Q4?0P0C4Q02014@3P04018A3`0C4Q006APF
01HE4`803`h<00@04a8@010?3@0A40h04A0>0P0B4@l201<B400D00h=3@0C4Q804A4A018B4P0D5AD0
3a4@018D4`0H71/03a<B00lD4P0D6AL05APG00l?3@0M71X06QTG01<B400J6AL04A0>01DD4P0G5Q@2
01DD4P0301@C4@0?3P`04a<A008051@B0`0E5A<0500D51805ADC01DE4`0D51806a/I018C3P0E5Q00
5aPC01TJ5@0H6A@05ADC01@D4P0J6QP03`l?01XJ6P0A4A407alO01`M700K7AT06A/I0P0I6aP201HK
5`0801HL600E6aL05AdH01HO6@0E7QX061hL01/O7P0I7A`201PL6`806AdL01h07b<R024U900M8B00
8bLV024U900K8Ah0624L01dV8`0b>cX0BE5C02H]<`0M92/05A`T02@[<@1AFEd07BDX01`T9P0Q9RT0
7R<V020U:00Q:2P07bHU020Y9P0S;R/082XY028/;@0S;S808bhd02Hb>P0V=C`202Df?@1301la=@0Z
?400:3Xn02Xl?P0/?T00;d5302i0@00]?cl0;d5002m2@00]@3`0;Cln0394AP0hBTh0?DiF03U:E00f
Ae40CEiX06AeO@1GJ700>TaC04]NH@0mDU<0?eAE04IKGP15FUh0@UML045EG016FV<0AEUS04EHI@1J
KG/0M8RC04YNI016Feh0BEiR04mTJ01AIV/0BemU04iRJ@1AIFd0EFUb05EYL`1DJ780DFE/05M/K@1E
JVP0EFUX05Q/J`1LKfl0GFm_061bLP1RLg<0IGEe06MgM`1/Ng`0Kgen07F5Q@1cPh<0N8R808>BT`25
Ti@0PHn@08NDU@29U9H0RiJH08nIV`0209:LWP0T09JNX@2PYZX0WJBW0:>X[P30a</0/kNn0:^^]`2`
/[/0[[2i0;Via@2n_LX0^;K30<>od037`=80blCF0=78f`3Fb]h0f<cP0=c?h`3RdnP0i]K[0>_Ik`3a
goD0m^7h0?WPn`3mho`0o^Kn0?oZo`3okOl0onoo0?kbo`3olol0ooOo0?ojo`3oo?l0ooko2`3oool0
1@3oood0oook0?ooo03oood0ooon0080ooko02<0ooco0?oko`3nnOl0oOKo0?ceo`3nlol0onko0?k[
o`3njOl0oNGn0?[PnP3efo@0lMS^0>_Di@3Rc]X0fLSB0=71b03?`<H0c/750<Rl_@2o]K<0^[6/0:RQ
V02FTXH0V9B809:BQ02OWi80Wj2C09>ER01hNVL0LgIQ079eH@1[KU`0MGQV07UmKP0207f2M00]07^1
M@1jPGH0NH1f07R0N01dPh00KWin06]kNP1XN7L0Hg=b06EeL`1VMW<0Hg=`05a]I`1FIf40CUmI04MH
D@16EDh0=T@m038o>00^>S<0@dm902D`:P0]=S40:30/01`T7`0[<Bd0:2dY01hT7@0[<RX0:34X04QC
B`0b?cP0<T8o02/k>P10De40=4M502dn?@0`@3d0<d4m038n=`0/=C00=C`e02/b:`0W;RL0:C0Y0080
8bXS00H09B`U01lV7`0/<b`0;SD^01hX800Q:bP201hY9@0>02@]:P1mQX<0?4E202dc<@0]<C007B4P
01hR8@0P92<0<cPd028Y8`0N92008BLS02L]:@0T:RP201lU8`0h020V9P0S:BT09B/[028W:P0O9BD0
7B<R02@X9`0Q9B@092PW01DG5P0R92<07b4P01/K6`0O7al0820P01lO7`0Q8B406adL01dO7P0N81l0
6Q`K01dO7P0R92<06A/J01HH5`0J71/07AlN01HH5`0h>CH071/G01PG4`0E510061LC01hM6@0E5140
61LC01@C3`0R8Ad061LC00l>2P0H5A<05Q0@01LC4P0H5aD04Q8@014C400C5A804Q@A01<C4@0A3`h0
4@d<01LA4@0G4Q405Q8?01`H5@0N6QL201@@3@0600l;200H51404`l=01<?300@30T061@A0P0D40d0
0`0B3P/03`/8010<2@0201DA3P0301<?300B3P/04`l<0080510=01405A4>01<?300D40d061@A01XF
4`0F4Pl04`l<014=2P0@30T04Ph;01XF4`0h=3406QDB01D@3@0D3``05A0=01<>2`02018=2P0601TD
4@0O6QL050l<01<>2`0@2`P03`X70`0@2`P2014<2@0;01<>2`0A30T03`X700l:1`0A30T04`h;010;
200A30T040/800l:1`0@2`P00P0B3@X00`0A30T040/800l:1`02010;2003010:2P0D3Ph0BdE50080
3PP800H03@L7010:2P0?2@T03`T901@>3P0;1@D4014;2`0300l92@0B30`04@/;00L03`T900H02`D5
00`61P0@2PX040X:00h8200=1`L2010:2P0300h8200=1`L03PP8008040X:01003PP8018<300;1@D0
3`T900d71`0B30`040X:014;2`0@2PX03@D60147200B20T04@L801061`0B20T04`T:0P0@1PL0800A
1`P03@<400h41@0C2@X03`D600/10P0E2``04PP9034W:00F30d050X;01882@0@1PL04@L801<92P0F
30d02`8301T?400N51D0AS`m01L=3P0@1PL05@/<01L=3P0D2P/060h?0557B00C2P/03`T900d71`0C
3@d06Q@D0P0E3`l02`0X8R804@/;01LA4@0K5AD03@L701061`0E2``05P`=01D;300Q5aP050X;00H0
4@L800h040H700h41@0>10D04`T:01@:2`0@1PL03P@50147200C2@X03P@500d3100A1`P030820106
1@804PP700T050/:00d30P0F30/04@L600d30P0>10<04@L601881`0?1@@00P0@1PD301471P0600d3
0`0>1@D06Q0?03P`;`10=SD0BCln5?ooool001_ooooo00l040h?00l=3P0F51D03@/<02@R8`0M6a`0
30X;014?400B4140108301hL7@1WIFH04`l>018>3@0C3`h00P0D40l4014=30@04Ph=018040`;01<?
3P0B3Pd040`;01<?3P0I5A@04@d<010<2`0E4A00510?01lK6P0C3`h04Ph=010<2`0G4a8071PG01XF
5@0A3@`201@@3`804`l>00h04Q0A00/=3`0=3Q00410@00`;300>2P/07a/L01TF5`0<2P/03@d=01lP
7`2k_l00?3`l01TE50805Q8A0P0H51<201@@3`09028N7@0E4A0040`;010<2`0L61L061@C01@@3`0A
3@`040`;00804Ph=01<04`l>014=300>2PT05Q8A01@@3`0E4a407QdK01TH5P0@3`d03`h<00h=2`07
1PD04Q4?00P71@0<2`T04Q4?00D40P0:20H040`9008061@A00T081`I01TE4P0D40d040`901<?300F
4Pl04`l<018>2`0C3``00P0B3P/00`0C3``04Ph;010<2@0201HB3`0F01DA3P0D40d04`l<01<?300D
40d04`l<018>2`0A3@X04Ph;01@@3@0E4@h04Ph;010<2@0D40d05Q8?01<?300A40/04a8=00l>2@0F
5A003`h901<B3@804Q4<0P0A40/2010?2P0<01PG5@0>3@/04A0>01<B400@3`d05QDC018A3`0A40h0
3`h<010?3@0B4@l051<A0P0B4@l0100>3@/040l=01HE4`0C4Q02014@3P804Q4?0P0C4Q008@0I5aP0
5A@E01HF5P0P82007QhN00L9200?4A0000@301HJ6@093@`03A4@00d?3P0E5A<04Q4?02LV900F5A<0
5aHD02HU8`0D4a405A@B01<B400I61H06aXH01LF500G5aD05QHD01DE4`0@40h04a<A01XJ601:BTP0
1`L501`L6P0201DE4`0301`M600E5Q005QLB008061TD0P0F5Q@04P0J6QP04A4A01PH600R8R80E5AD
01LH5`0C5A@05QPG01/M700P8R406QlK01<H500C6Q<05A`E01LO600E7aH04adE01@K5@805a/J01/0
5QXI01DI600H71/05a/J01XN7@0O8b807B4P01lS8P0Q9B@07R@Q01dV8@0I8Ql06B8Q038j?00N9B/0
8BP_01lV;P0F7B<082P/01PP8`0T;2h08BHZ01hS9`0Q9RT08R/Z01lX9`0O:BH00P0R;2/03@0^>C/0
=3m502/f?00T;cP082lf01//<`0U=Sd08cDi02Hh?00[?D40:cdo02`n@00^@4800P0^@400H@0aA4<0
=DQ60395@@0`@d80<TA603A6BP0dADd0>DYD03M8DP0iBU@0>daD03Q9D@0iBe80?U5E03M<C@0kD540
@EII04=HG015FUl0A5QO04]OI`15FF80CV9]06=fP`1NLW/0CfAW04YOH01CJ6T0GgAg055VJP1>HfP0
CF5X04iRJP1DJ740EVYe05=WLP1DJ6l0Efa_05I[J@1GJfX0Ffm^05iaL@1NL700HWAd06AeM@1XN7P0
JWYj071oO`1cPH80Nh^;07F5Q@1hR8P0Q9:C08:@T@1lRX/0R9>E08VDUP2;UYP0SiVK096KW@2BW9h0
V:2S0:6VZP2NXjL0WZ>Y0:R[/P2PXjX0[:nh0;Bd_P2b/[`0b<SD0=;@g@35`m00a[oA0<W2e03<aML0
dl[M0=S<h03Jc^80g]3T0>GCj@3WeN/0j]S^0?3Ml`3dg_D0nN3k0?cRn`3miOd0onSn0?k[oP3nk_l0
o_;o0?oco`3omol0oo[o0?olo`3oo_l02`3oool0103oooh0oook0?ooo@3oooh20?ono`0W0?omo`3o
nol0ooWo0?kgo`3lm?l0o?;m0?g`o`3mk?l0o>Wm0?_Vo03ihOT0mmgf0?7HkP3^enT0i]7O0=_:e03I
bM<0eLO>0<o3a`3<`<@0aKZk0;fc/@2d[JD0Y9jC09jJSP2GUHP0Rhan0:b^X02VZ9X0TI>507IiIP1e
N6<0L7=P07UlJ`21QG@0N7a]07^1L`1jP780N7ib0080MGeb0480MWif06mnN`1YNGP0IgMf06EeM01R
LW40I7Aa06=cL01QLV`0G6eW05AUG`18FE80?Te603U6?`0kB440>TM002@_:@0a?3H0:C@^02lh<`0V
;bX07BHQ038h=00R:2@09bdY02dd;@0W<BT0=d@m03I2?P0iBDL0=4A30313@@0eAdD0=TI303=2?@0]
>SH0:SD_034k<`17CTL0<3L`02<Z8`0/<b`08bXS02T`:@0^=Bh082LP024X8@0[<R/04Q`D01XT8@0M
:2@0=T4m020Y9P0]=S<06B8O020V900O8b80720O02DY:00O8b80724M01XQ6`0F71P06R0L028X900R
:2H201lU8`0e01lU9@0Q9bL092XZ028W:P0P9RH08BLV01/O7P0B5QD07b<R01PJ6@0Q8b80:B/Z020P
800S8b<0820P01/K6`0N7Qh07b4P01hP7`0L7Qd05ALF01PJ6@0J71/04aDD00`>3@0D5QD05QPG014C
4P0H61D04a8>00h=2@0U92005QDA00H50@0L6aL06APD01<B3P0I61@05A@@010?2`0L6AL071HF01TE
500D4a404A4?010B3`0C5A8051HC01@D4P0C4@l04`l>01LA4@0I51<00P0G4a002P0E4@h040`901TE
4P0K5a@0:BDR05YFD`0I5A804`l<014=2P0G4a0201HB3`805a<@0P0D40d02P0B3P/040`9018>2`0C
3``04Ph;014=2P0@30T04Ph;01DA3P0F4Pl201DA3P0:01@@3@0?2`P030P501TE4P14@3d08QdJ01PC
400C3P/061<@01HA3P804@`900L05Q4>01dH5@0C3P/03`X700P3000>2@H040/800<04@`900<040/8
014<2@0A30T00P0@2`P2014<2@0600/60`0C3P/04Pd:00/60`0=20D061<@0P0A30T04P0?2PL03PT6
00l:1`0?2PL06Q@D024K6`1kMGD04P`<01@>3P0C3@d02`D5014;2`0E3`l03@L700@0000A2`/03`T9
00D000805Q0@00<07QPH00D0000?2@T01@0?2@T03P0A2`/07aTI01hH600B30`03`T901<=3@0A2`/0
40X:00l92@0=1`L03PP8010:2P0:10@02`D50`0=1`L03P0;1@D03`T900D0000=1`L03PP800l92@0F
3Ph04`T:00h41@0?1@H04PP901061`0?1@H04PP90P0C2@X00`0A1`P04`T:01D;300200h41@0T0188
2@0?1@H07A<D01@:2`0F30d04`T:01061`0B20T05@/<01P>3`0C2@X06@l@00`30`0L4Q<02P0101T?
400>10D03@<401882@0700008aTJ00d41@0?2@T02`D500`61P0?2@T02@<300`61P0N61P04`d=00h8
200C3@d030H601@:2`0B20T06@l@0P070000200A1`P03P@500h41@0@1PL04PP901<92P0D2P/04`T:
0P0A1`P201@:2`0400h41@0A1`P04PP901<92P8040H700l04@L801D;2P0=0`804`T801lE500b:2L0
4@L600T0000A1`H05@/:01<9200<0P80200000h40`0@1PD00`0A1`H01`0@1PD07Q@C01L=300<0P40
=2XY06iTH`3Vg=/05?ooool001_ooooo00L04Q0A010>3`0H5QL03@/<02TW:00O7Ah05A<D00803`d>
00T01P@5028P8@1]Jf`04Ph=014=300C3`h0510?01<?3P0@30/00`0C3`h4018>3@0B010<2`0C3`h0
4Ph=010<2`0C3`h03PX900L30P0C3`h05a<B00L30P0@30/04`l>018>3@0@30/05Q8A01XF5@0G4a80
40`;0P0B3Pd06@0C3`h05A4@01HD5@0B5QT0310C01@E5`0;2`/03@`:010?3@0B4@l06QTG01DE4`0T
9bH0cm?D04=4A00?2`X03@T801<?3P0>2PT03@T8014=300E4A003@T8010<2`0<20L00P0E4A00700D
40l04`l>014=300A3@`04Ph=010<2`0I5A@06aLF00h:2@0?2`X04@d<01DB4@0F5A<04a8@018A3`0>
3@/040l=014@3P0N7A/03`h<00d<2P0N7A/051<A01TG500E4@h03@T601<?300J5Q<2018>2`05014=
2P0E4@h05Q8?018>2`0E4@h00P0D40d0100C3``04Ph;018>2`0E4@h201LC400301HB3`0D40d04`l<
00L04`l<00X0510=014=2P0@30T05Q8?01LC400B3P/03@`7010?2P0A40/06aXE0P0?3PT2018A3080
4A0;0P0@3`X01@0G5Q@04A0>00h=2`0@3`d04a8@008051<A00/04Q4?010?3@0A40h051<A01HE4`0?
3P`04A0>00l>300A40h05QDC018A3`02014@3P804Q4?0P0C4Q001`1>C4d071XK01HD5@0Q7b005aLG
010@400F61L00P0G6AP0400=4A008BDT01HH5`0@40h06APF040o?@0V9B<02PT700l>300H5aD05QDC
01@C4@0K6QP07ahL01/J600D518201HF5009014A3`0J6QP0:2PV05]KF@061P@051@B01DE4`0H61H0
414<008061TD01P06AXE01XK5P0J6QP06QXH01TI5`0E5AD06QXJ028R8P1:BTX07QhO01lP8P0J6ad0
5QLI01`N7@0G71P04QPB01DL5@0F7AH05QhF01<M4P0B71<04aXD01HJ6@0H71/201HJ6@8061`K0240
5QXI01TM700H71/05QXI020T8`0T:RL07BHQ01dV8`0O9bL06b<U00T@5P0V;C@06B0X01TP9P0M92T0
9Rha01`T9P0O9bX07BDX020X:`0S;2/07bPW01lY:00U;bh0930^03@o@@0iAT`0;CY002Hc>`0S<ST0
93Dl02Xk@P0/?T800P0Z?4003`0[?Cl0;3i002do@@0]?cl0;T1003A6A@0aA480<4<o0354@`0eAdT0
=dU=03Q9D@0cA4h0>T]E03m@FP0203]<E00403Y<D`0oDUH0>e1C03eBE@80?U=H04l0@eQM05IZL@1<
H6P0AEUR04YNJ@1?Hfh0B5aU04]PH@1HKV`0DFMU05I[K01=HV@0CF9W04eQJ01<H6P0E6Qa05EYM01C
Ig80Ef]b05M/K`1GK6X0FFe/05eaL01PLg80H79b06=eM@1VMgL0JWYj06emO@1bPH80MH>407N5QP1h
QXL0NhV:082>S`23SY00PXf?08VDUP2;UIL0SINI092JW02CVih0U9bO09RMX@2MXZH0WjBX0:NZ/@2V
ZK00[:nf0:j^^02d];h0/k>m0=?AgP3OgNX0cL_H0<S1d`3<`mH0clKI0=O;g`3Lcn<0g]7U0>7Bi`3W
eN/0j=K/0>_HkP3_g?80m=ke0?[Qo03mho`0o^Kn0?oYo`3njoh0o^ko0?kbo`3om?l0ooSo0?ojo`3o
o?l0ooko00/0oooo02d0ooon0?ooo@3oood0ooon0?ono`3ooOl0ooco0?ojo`3on?l0ooGo0?gbo`3m
lOl0o>oo0?c[oP3jio/0nNCi0?OOm@3cfo40k]O[0>gFj03QcM/0e/K@0=K9dP3Eb<l0cl?70<c0a034
^[X0^[2^0:nXX02TWY<0ZJFI09VGR01oP700W9j@08j@PP21QGH0LWET07EhI@1cN6@0Oh=b0824L`1e
NV/0LGMY079hK01bNVl00P1aN700>01_Mfl0KGUg06MeM@1VM7@0IWEb06=bK`1UM740IWE`069aK01J
JF<0DF1I04IECP0mC4D0=44j034l=P0d?cT07BPR02Td;P0/=c40;CHa02Tb;@0`>C@0Ae1;02@]:00/
=C00:cD]02lj<`0W=2d0=D4m03E4@P0eB4H0>4]903Q:A`0eAD80;chi02Pc;P0Q;2H09S0X034h<@0R
:B806R4J024X8@0N9Ah09bhW020W800f?CH08RTR01hU7P0b?3@0;CLd018M6@0Z=C409Bh[01LP7@0F
7a`07R@R0P0X;2/0600Q9B@082@S01LL600K8A`05adI01TO6`0O9B408BLU020V900O9B<07R@T01lU
9@0S:BT08bP[024W9`0F71/0;S8a02P/:`0P92<07AlN02LY:00U9bH092@T02LW9`807AdM01d0:BTY
01hP7@0N81d0828O01XL6@0I6aP071hK01hP7@0F61D07R0M020R7`0N81d07AdJ01HE4@0O7QX0>CPd
02PW8`0K6QH07QdI01lN6P0H5a<06APD01XI5@0D4`l04Ph<010:2P0F4Q406APF01TI5`0201LI5P08
01HH5@0D51805A<A01HB4@0G4A405a8A018>2`0@30T201HB3`0501DA3P0D40d0?c/h065MFP0>2PL0
0P0C3``0700?2`P02`L400/7100C3``05Q8?014=2P0E4@h04`l<014=2P0C3``0510=01<?300?2`P0
40`9018>2`0@30T03`/8010<2@0A3@X04Ph;01@@3@0>2PL02@D2014=2P0K5Q<050l<014<2@0C3P/2
018=2P0<01@?300B3@X05Q4>00l:1`0B3@X030L4010;200B3@X04`h;01@?300C3P/04Pd:1P0@2`P0
2P080`003`X700l:1`0=20D04`h;01dH5@0A30T040/800l:1`0>2@H200l:1`0B01@>3P050000:bDU
00@0000@2PX03@L700`61P0B30`04@/;01@>3P0;1@D03`T901LB4P0>20P04P`<00P20P0E3`l06Q@D
1P0?2@T01P0;1@D05Q0@01<=3@080P802P@4014;2`803`T90`0@2PX04`0?2@T050h>01PB4P0B30`0
1`4101H@400O6AT04@/;00L10@0F410030H600X4100G3`l050X;01<92P0D2P/04`T:01061`0A1`P0
0P0D2P/02`0@1PL03P@500h41@0@1PL02P0101882@0@1PL050X;01061`0E2``050X;00804`T:0`0B
20T07`0@1PL03P@501H<3@0I3a003`D601D;300;0@803@<401D;3009000040H701892P0A2`/03`T9
00d71`0?2@T03@L701@>3P0400004@/;018<30080P80618B04Y0@@0H3Pl0200001<92P0E2``040L8
00l51P0@1PL00P0A1`P00`0B20T04`T:01<92P0301882@050147200>10D05@/<01<92P0B20T00P0C
2@X06@0A1`P03P@300`20@090@0050X901lE500900004@L601lE500V71/081HE01H<2`0D2PT03P@3
01061@0A1`H04PP701471P0@1PD01`0000P0000L4Q404`T801L=300Y7ah05?ooool001_ooooo00l0
4@l@01DC500;2@X02@L8018@4@0E4a@0GeeN01<A4P0G5AH03`d>010>3`0J61T03`/:01<?3P0D40l0
100B3Pd00`0D40l04`l>014=3002010<2`0301<?3P0B3Pd04Ph=008040`;0P0B3Pd0200D40l0>cLf
048n?@0=2@P0510?018>3@0A3@`03`/:0P0@30/08@0=2@P040`;00d9200A3@`04`l>020L6`1>C4d0
L7Ah01@H6`0F6Q/04Q8A01PG500B4@`03@`902HW8@0R92004aHC020V900F5aH06ADD014=300?2`X0
5A4@01<?3P0a;B`07QXI01<?3P0A3@d05a<B01`H5`0B3Pd05Q8A01@@3`0201<?3P04014=300H51<0
:bLV02/W9P805A4@00@05a<B018@3P0@3`d03Pd;0P0@3`d00`0C4Q005QDC00D40`02010?3@0N018A
3`0F5A<04@h<01`H5@0A3@X05Q8?010<2@0E4@h05Q8?01DA3P0G4a005A4>01<?300F4Pl04@d:01TE
4P0M6AH04`l<014=2P0H51405a<@010<2@0E4@h040`901XF4`0C3``04@d:010<2@0E4@h04`l<0P0F
4Pl201DA3P805a<@01@05Q8?01<?300C4Pd04a8=01dL5`0K6QD051<?01LF4@0F5A406QTE01@C3P0@
3`/04Q4=014@300D4a4061LE018A3`0E51806APF00d<2P<04Q4?00T04a8@01@C4@0E518051<A018A
3`0@3`d04a8@01DD4P0A40h0100C4Q0201@C4@0I04i;C00M6Q/04@h?01HD5@0B41406a/K01@D500J
71/0J6YY03Pk>P0Z;B`030h=01@C4@0>3@/061LE01DD4P0G5Q@061LE01DD4P0C4Q004Q4?01<B400G
5Q@06QTG01HF500201TI5`0Q01HF500M7A/09bLU01`L6P0c<c407AdK01DE4`0J6QP051D@01@E3`0H
6A@05AHA01XK5P0H61H05QHD01@D4P0D51@071`L00d=3@0M7Ad0=SHh04I7B`0Y:R`05QLI01HH5`0I
7A`04QPC01LN5`0I81P05QhE018L4@0G8AH05A`F00805a/J02P06QhM01/O7P0J7Qd06QhM01TM700O
8b80720O01@H5`0Q9B@09R`Y01LP6`0I8Ql07RLV01LO8@0W;S@0H6M^01lV;P0P9bd07BDY01`T9`0L
92H08BT/01lW:`0P:B`08BX/020Z:P0R;B/09S8a024];@0W<cH0;CY002/h@00R;cP08S4h02/l@`0W
>3l09cTm02m1A@0Z?400:cdo0P0^@4805P0^@400<D=303A6A@0bAD<0<dI203M9B00hBT`0?e5E06am
Q@0hBE<0>T]E03Q9D`0`@DT0@U=K03a>EP0lCeD0?eAH045FFP10EEX0@5EK04QLHP1@I6/204MKH`80
BEeW01P0CF5X04IKG01CJFL0BV1N04QMGP17G5h0Bf1S05=XK@1<H6L0E6Q`05Q/M01DJ780F6ac05U^
K`1JKfd0G71_05ibL@1OLW80Gg5a06EgM`1XNGT0KGem0720P01cPX8207J4Q@0;07^9RP1nS8d0Ohb=
08JAT`29U9H0RiJH08fFV02>UiT0T9VK09BLW`2FWZ400P2JWZ<08P2LX:D0YJR_0:FW[P2^/;L0/[:l
0;Fd_`2c/[`0`l3>0<[7e02n^/P0b/?E0<o6f@3BbM`0f/kR0=kAi@3PdnL0iMGZ0>WFk03Zf>h0kMW_
0?7Ml`3egoH0nn;m0?kTo@3oiol0onWn0?o/o`3ol?l0oo?o0?odo`3on?l0oo[o0?omo`3oo_l;0?oo
o`1E0?oooP3oood0ookn0?ono`3ooOl0ooco0?oko`3on?l0ooKo0?oco`3ol?l0o^oo0?g]o`3kjOh0
n^Gj0?WRm`3fgo<0l]_^0>cFi`3Xe>40fl[F0=74c@3Cb=00d/S>0<^o``35^[`0`;Je0;J_Z@2XXIT0
XIfA0:FSU028RGP0Kg5O0823L`1mP740OX9c07AgIP1bMV@0MW]X07^1L01jOfl0M7]/06Q_H`1[LVH0
KgM/06efK@1[Lf/0J75Y06QdL@1WM7<0JGIe06MeLP1TLFl0IWA`06=aK01MJfD0EfEN04eKD`13DDT0
KGYb041;A@0T;RP09S0[02<]9`0U;bX0:C<^02La:`0^>380=d4l04QBC00/=S00;SPb034k=00jACl0
;c/g03M6@`0`@Cl0<4=103a?C@0/?C/08c8_02Te<@0Q;2H0:c@^02/b:`0302H]9P0`02D/9@0X;bP0
<CPa02H]9P0Y<2T07RDN02@[900T;RH0BUAA02Lb;P0b?CT09Rl/01TR7`0P:BH082HT030d<`0[;bh0
6QhM02<W9P0R9b<07RDO01dS7`0L8Qh07B<O020V900Q9bD08bTW01/Q8@0M8b<08RPX01lT9`0c>CT0
9R`[028V9@0P92<0720O01`N7@0N81l08B<R01hN7P0Q8B407AdM020P800Z:RX092HS01/M6P0Q8b00
7AlL0P0J71T0?@0I6aP05ALD01/M6P0J71T06A/H01TJ5P0I61@081lK01`K5`0I61@07A`H01HE4@0L
6aL06aXF01PG4`0I61@05QDA01PD4P0H4Q8061@C01PG5@0?3`d092HS05aNF`0U9b@06a/I01HD4P0J
5QD05@l?01TD4`0C3``05A4>02DQ7P0V8Ql04`l<01@@3@0K5a@061@A01DA3P0@30T04Ph;01HB3`0D
40d04`l<01LC400I5A805a<@01DA3P0C3``040`901DA3P0I5A805Q8?01@@3@0G4a005Q8?010<2@0?
2`P0510=018>2`0A3@X00`0@30T06@0B3P/03PT6010;200B3@X03`X700d81@0D3``04`h;014<2@0C
3P/04Pd:01D@3@0C3P/050l<018=2P0E40d06aHC01XE4P0C3P/061<@010;200B3@X04`h;010;200?
2PL00P0A30T2010;2003014<2@0B3@X05Q4>008040/801D04@`900l:1`0A30T04P`<00l92@0A2`/0
3`T901@>3P0@2PX04`d=018<300<1PH05@l?018<300@2PX0=S4a01`F5P0;1@D0:bDU01<=3@0=1`L0
0`0@2PX02@0?2@T03PP800h8200B30`03`T900h8200@2PX04@/;018<300200d71`0C014;2`0D3Ph0
3PP800h8200B30`02`D501<=3@0B30`030H600X51@0?2@T05a4A02<M7@0D3Ph02@@400l71`0A1`P0
5@/<01H<3@030147200`01D;300C2@X04PP90147200@1PL050X;01061`0F30d04PP901D;300<0`@0
60h?02/Q8P0J41404`T:01882@0C2@X04@L801D;300?1@H050X;00l61P0B20T04`T:01@:2`0F30d0
4@L801@:2`0?1@H03`H700d71`0E3`l02P@401<=3@0@2PX030H6014;2`0@2PX02P@400h8200A2`/0
81HG00d41@0@1PL060h?00l51P0C2@X03`D60P0B20T0700A1`P04`T:0147200?1@H040H701@:2`0A
1`P03@<401061`0E2``04`T:0147200B20T04`T:0147200<0P8060h=01<9200@1PD05@/;01@:2@0<
0P4050X901D;2P0@1PD03@<301471P0?1@@201061@804@L600L040H501881`0C2@P030<301D;2P0?
1PD04@L601Cooooo000Kooooo`0@00H41@0J61T06aTJ01`J6`091`P05aDF03Hd=@0<2P/04a4B00/9
2P0C4A804@l@02<O7P0L61L04Ph=014=30<04Ph=01403@T800`81`0C3`h05A4@01@@3`0F4Q405A4@
01<?3P0A3@`04Ph=01@@3`0E4A00100000d9200M6AP020@300l;2P06014=300O01LC4P0>2PT02`L6
00X61@0F4Q40BTQ905MJG`0@51L05AHH014B3P0H5a8051@<01/K4P0D50`020T3014E3P093PX03@l<
014=300>2PT06QHE014=300D40l0PWim03`h=`0A3@`061@C018>3@0810<061@C01TE500201PD4`0F
01LC4P0@30/0510?01dI600K5aH03@T801<?3P0E4A003``;01<B400D4a404A0>018A3`0A40h03`h<
00`;2@0F5A<04A0>01DD4P0F5A<04a0>02dY9P804`l<00<02@D201HB3`0A3@X01@0A3@X0100>2PL0
61@A01hJ5`0E4@h2018>2`0:01HB3`0;1`@04`l<00h:1`0300004@d:018>2`0@30T05A4>00l;2080
510=0P0C3``01`0@30T03`/8010<2@0F4Pl09B@P01PG4`020@000P0H5a<03`0F5A404a8>01XI5@0F
5A4040l;014@300B4@d04Q4?01PG5@0C4Q004Q4?01<B400I61H03`h<014@3P0301<B4007014@3P05
10805A@B01XI5`0C4Q003@`:010?3@0601@C4@0=01LC500E4A80510A018@4@0D4Q<05aDF01<C4`0I
6AT0ATQ703Tk>P19BdX0418A01DD4P0201<B400F01@C4@0E51805QDC01DD4P0C4Q0051<A01LF500U
9280<S4_01LG5@0I6AL061PF01@D4P0C4a4051@B01PH5P0g=cD05aLE01TI5`0@40h05aPC01LH4P80
61TD03`05QLB01LG5@0[:bT07AdK01TI6@0H61P07alO014A4@0I6AX08B8T01PI6`0N7b406A/J01/P
700A5a404aXC01@K500I8AT05AlD01hX7`0N9Al061`K01DI600K7ah0720O01XN7@0N8R406QhM00`@
3`0F6QT08BDT01lS8P0O9B804Q/F01DN6`0M9RD04a/M01TP9P0U;3<09bhf020W;@0N9RX0<c/n01/S
9@0S:S008RT_020Y;@0O:B/08B//02<_;P0[=cL0:C@f02Tg>P0R;cL07b`d02Pf?`0V=ch0:CY102Pi
@00W>Cd202/m@@0P02Xl?P0^@480;T1202i0@00cADD0<TA302i1?`0X>cL0=TU803a>D00cADT0G6ee
03M8DP0cA4h0=4E?03I7C`18FF40>TaD03]>E013F5d0AU]P04EJG`17Ff40C61W041DF`12EUd0AEUP
04MKI01:GVL0BemV04UNH@15FUX204IKG00D04QMG`1AIVT0FFic051UJP1JKg@0GW9i05EYL01DJFh0
F6e^05]`K`1OLg80H7Ac069eM01RM7@0IWQh06MhN01^OWh0LX:207B3Q01kRHX207f;S00A07b:R`22
SHl0QY6C08RCU@2=UiT0SiNJ08jFV@2?UiX0U9bO09ZOX`2JWJ80VijS09fPY@2TYjh0[:bd0:n_]`2_
[kT00P2h]/406`2n^/P0a<3>0<C0cP3<`mH0d<OJ0=?:g@3Jc^80g]7U0>3AiP3Ve>X0jMK/0>[Gk@3^
f>l0lmgd0?SPn03khO`0o^Cm0?kVoP3niod0o^_n0?o`o`3olol0ooCo0?ogo`3on_l0ooco0?ono`0;
0?ooo`0Z0?oooP3no_`0oogn0?omo`3onol0oo[o0?oio`3om_l0oo;o0?oao`3okol0ongo0?gZo`3j
iod0nN?h0?OQm@3dgNl0l=WY0>[Eh@3RdM/0elSB0<o4c03?aLd0c<;90<Jm`02l/[<0]JbZ0:jWX@2S
Wi@0ZJJH09RIQ`1lOF/0L7=P07YnK@22QWD0Oh=d07UmK01]LF00LGET06ieI@1`MfL0LGMY0P1]MFP0
1P1/M6T0JG=Z06UcJP1YLf`0IG5]06EaK`80Ig=a00l0IW9^069^JP1TLFX0EfAM04AABP17E4/0<d0g
04]FCP0c?3L07bPS02@]:00X<B`082TT02@]:00R;BL00P0X<bd05P0`>cD0;3La030k=@0Z=Bl0:SHa
02<b;@0P<2d09cTf0395@`0gBTP0;chl02@c;P0[=S00>dHn01DO5`0L8a`0:C0Y010G400M91d0?4<l
02`c;00W;RL202H]9P0D028Y8P0Q:2409c4Y024[9`0_>SH0DEaH02Xc<00P:BH07bPU01dS8@0V:RT0
92PW028V9@0Q9B@07B8N01lU800Q9b<082HR01hT800N9282020V900M02<Y:@0P9RH08RPX02db=@1M
Hf<0Be5@024U900H71/06QhM024S8P0W:BP09BLV01XJ6P0K6a/07QhN01lO7`0Q8B408bDR01DG500M
7a`06A/H01HH5@0K7AX061XG01LI5P0I6aP05ALD01HH5@0I6AH00P0H5a<0700I61@061LC01LF4P0I
61@05QDA01XI5@0I61@04A0<01HE4@0K5aD071HF01hJ6@0@3`d061PF06U[J03Zk>T0D59?01LG5@0@
3Pd061@C00H0000E40h05A4>01@@3@0F4Pl061@A01HB3`0E4@h201`H5@0601@@3@0C3``05A4>010<
2@0A3@X04Ph;0P0?2`P0500A3@X05A4>01HB3`0B3P/05Q8?01dI5P0I5A803PX700l;200B3P/061@A
01XF4`0D40d040`9014=2P0F4Pl0510=00d91P0@30T04`h;0P0D3``01@0A30T040/8014<2@0?2PL0
4@`9008050l<00l04`h;014<2@0B3@X030L4010;200G4Pl050l<00P3000=20D030L400l:1`0@2`P0
3`X7018=2P0@2`P00`0A30T06P0@2`P03PT601PC400?2PL04@`901<>2`0A30T050l<01<=3@0P6QX0
8adM00d71`0:1@D06aDE010:2P0C3@d04P`<00/51@0:10@03@L7010:2P0/9RH0618B02XT900D3Ph0
5@l?0`0?2@T3010:2P0400h8200?2@T03`T900l92@<040X:00T04`d=00h8200>20P03`T900d71`0B
30`030H600X4100=1`L00P0@2PX03@0>20P04`d=018<300>20P03@L7018:2P0?1@H02P0100l51P0E
2``050X;01882@0E2``00P0?1@H04P0@1PL03`D601D;300A1`P040H701882@0C2@X04PP901T?400b
:2T05P`=0147200@1PL05P`=01<92P0A1`P03`D601882@8050X;0P0B20T02P0C2@X04@L801061`0B
20T05@`=00l92@1_JFT0RhF501<=3@0E3`l200l92@0>00h8200=1`L03@L700h8200A1`P05`d>0106
1`0C2@X050X;01L=3P0?1@H04PP90147200?1@H201D;300601L=3P0;0@803`D601X@4@0E2``04PP9
100@1PL02`0B20T04`T:00h40`0B20L04@L600h40`0B20L04`T800l5100B20L04@L600803`D40P0A
1`H01@0@1PD03`D400l5100@1PD04@L600H040H55?ooool001_ooooo02@04Q0A00l=3P0J61T07A/L
00h<3@0:20T00`42014?400<2P/02`T:014?400?3@h0<2`[01`H5`0>2PT040`;01<?3P0?2`X0:RHU
01PD4`0>2PT05Q8A01DA400?2`X05Q8A01DA400D40l04Ph=01@@3`0G4a8061@C010<2`0<20L04Ph=
01<?3P0H51<3014=30<04Ph=01P040`;01<?3P0C3`h081`K03<_;P0o?Ch05aTN014B5P0<30`03`l:
01DB2@0B40@03@`1014A1`0J71403Q0900T>1`0@40d040`;00d9200E4A0030P700l;2P0e<C0200L3
0P09014=300E4A001@40014=300F4Q404`l>01HB4@0E4A0040`;00<0510?01D040`;018>3@0E4A00
4@h=014@3P0C4Q004Q4?01<B400A40h030/901TH5P0A40h03`h=00l>300B4@l04@l<020L6@0D40d0
6ADB00`81@0=2@H01P0C3``0=P0A3@X05A4>01@@3@0D40d05Q8?014=2P060P006aLD01DA3P0N6QL0
6ADB010<2@0E4@h04Ph;01DA3P0>2PL0510=01DA3P0D40d04Ph;010<2@0B3P/04`l<01@@3@010000
5A@B01@C4@0R8Al02PT701PG5@0>3@/04a8@01TH5P0E518040l=01<B400J6AL0@T4o018A3`030P00
71/I00<2000A40h04Q4?01<B400D4a404a8@018A3`0N7A/05QDC010?3@0A40h04Q4?00l>30H051<A
0P0F4Q<03@0E4A80510A01<@4@0B414061LG010@400I6AT02PX:01DG5P0H6QT061LE01DD4P0D4a40
0`0B4@l01`0H5aD051<A01@C4@0C4Q0071/I02LV900D51800P0H61H03P0D51804A4?014A3`0C4a40
7AdK01LG5@0N7Q`0410>01LH4`0F5a404Q<>01`M600G61<08b<Q0P1>CT`0500E5AD05QHF00T92@0M
7Ad05QLF01LI600C5A@05aTH01<E500M8Qh06b4M018I4P0@5a0051`E00/E300:50`061lI01PL6`0G
6aX0720O0P0K7ah0FP0M8B007b<R01HJ6@0^<S40=CTh01hR8@0P9R<06B8M01PQ7P0R:RX0620R01@K
8@0O9Rd08RTa01XQ9`0h@4@06B4T024Y:`0S;3408R/`024Z;P0O:R`082`/02<_;`0J:2T06BLX02@b
=@0Z>D009cHm045?F00X>D00:S]202Lh?`0U=c/0:C/o02Xl@00Z?3h0;Cm102i0@P0^@400<TA40395
A00^@Cl0;T4m03U;BP0lCU00>D]?0393B`0dADl0AeQR059SK@0lCED0=TM?03i@E`0jCE@0@5AK04EI
H014F5l0AUYQ04YNI@12EUd0@5AK04AHG`19GF@0BemV04QLH`19GV40AEYL04EJG@16Feh0Bf1S05I[
KP1IKW40E6U/05ebM@1PMGX0EV]^05=XJ@1EJV/0FFi]05ibL@1QMG@0I7Mg06IhN01[OGd0JGYj06in
OP1aPH40MHB407f;S0<0OhZ<00@0PXf?08NAT`29TiD0SiNJ0P2@V9/02P2CV9`0V9fQ09^PY02LWj@0
WZ6V0:2SZ02XZ;00[Zjf0;6a^@2c/K`20;^h``0K0<2lbP36`]00a/;@0<c3eP3Ba]X0e/[N0=_>hP3O
d>D0h=7V0>GCj@3Ye^`0jmS^0>oIl03egOD0n>3h0?_Qo03ni?d0o^Kn0?kWo@3njoh0onoo0?oco`3o
m?l0ooOo0?oio`3onol0ooko00/0oooo00D0ooko0?omoP3ooOh0oocn0?ojoP020?oho`1V0?oco`3o
l?l0onoo0?o]o`3ojoh0o>Sm0?WVo03hh_L0mMkc0?7Jk03]e^H0i]7M0=o>eP3Ealh0c<790<c2bP36
_lD0aKbo0;Za/P2bZjL0[:FM0:>OU02WY9H0QhQf07EfI01eN6D0OX9a08B8M`1jPFl0M7]Y06U`GP1]
M6@0KWEU06mfIP1_MfT0LGU^06eeJP1VL6L0J79Z06afKP1[MVl0Ig=_06A`KP1RKVX0I71/069^JP1H
IEl0D5eF05MTG@18ED`0A558034n=@0[=Rh092dX020V8P0W;BT0:S<^02L`:`0R:bH08bhX02Ha:`0^
>C<0=T<l02hk=00gA3d0=D4m03A0?00Z>C@08S8_02Hh=P0bAD<0;Cdl02Lf=013DTd0>D@n02D`:00[
<RX0<cXc03Dl=@0P9b00>D0i05mVG`0f?CH082LP02<Z8`0X;bP09B`U024X8@0U;bL09Bl[02Lb;P0i
A4008R/X02D^:`0S;2T08BLU02T];00W:bX09BTX024U900N8al08BPR0P0T:RH04@0P9R807bDS01lU
8`0e>cT09bd]01dS8`0Q9bL06QlR02dc<`0P9RD06AdL02<W9P0W:bX07R0O01XL6`0O8B006QXJ0080
71`L00l07AdM028R8P0J71P05QPC01hP6`0H6QD05QPC01/M600H6QD05QPC01LI500E5a805aTD01TI
5@0G5Q801@0H5a<04P0@3`/05QDA01PG4`0<2`L04A0<01PE4`0I4a<07QXI01TH5P0D5180;S0]0863
P00W:BH03@d;018@3`0M6AP050h>01/F5@805Q8?00H040`900h:1`0G4a005A4>01XF4`0K5a@601@@
3@804Ph;01H05Q8?014=2P0C3``04Ph;014=2P0E4@h0510=01LC400D40d04@d:01<?300F4Pl061@A
00h:1`0=2@H05Q8?01DA3P0<20D04Ph;01D@3@0C3P/040/80P0B3@X200l:1`04018=2P0D3``050l<
01<>2`804@`900P040/8018=2P0F4@h04`h;00`7100?2PL06A@A01D@3@803PT60P0A30T2018=2P06
014<2@0@2`P03PT601D@3@0?2PL040/80P0B3@X01@0D3``02@<3010:2P0G4A407ALG00<04@/;00@0
30H600d71`0F41004P`<0P0<1PH01@0O6AT05Q0@01<=3@0;1@D04P`<00<03PP800@04@/;01@>3P0F
410040X:0`0?2@T200h8200C00/51@0A2`/030H600T4100F41003PP800d71`0G4A4040X:01<=3@0D
3Ph02@<300h8200<1PH02`D500`61P0>20P04PX:01<92P0201@:2`<04`T:00H060h?01882@0A1`P0
4PP900l51P0C2@X201882@080147200B20T050X;01H<3@0M4a@03@<401882@0@1PL201@:2`050147
200@1PL04@L801@:2`0C2@X00`0B20T0300A1`P040H701882@0B2@X0208205E?C`1/IVH0100000l9
2@0A2`/040X:00l92@<03@L700L0308301P>3`0>1@D03@<401061`0D2P/03`D600804@L800X05@/<
01hD5@0V71d0;bDV01/A4P0D2P/05P`=00`20`0A1`P04PP90P0A1`P02@0@1PL04@L801882@0@1PD0
3`D401471P0@1PD03`D401D;2P0201881`0301061@0=0`803P@300804@L600D040H500l5100?1@@0
40H501471P0601061ACooooo000Kooooo`07010>3`0B41403`d>00H51@0B4140518C00h<3@0200l=
3P0?01LE5P0A3a003@/<01`H5`0B3Pd04@d<01DA400B3Pd040`;02LS8P0J5QD04@d<018>3@0@30/0
30P700804Ph=00X040`;00l;2P0B3Pd05A4@010<2`0A3@`05Q8A00l;2P0:1PD04Ph=0P0?2`X0:00@
30/04@d<014=300A3@`04Ph=01<?3P0F4Q403PX901XF5@0>30d03@dB01PH6@0=30T05Q<<010=0@0J
60T0;R/J01lL3@0R8A@04a@:01LJ400?3`T06QHE01HB4@0=2@P071PG01/G5P0<20P05Q8A01hJ6@0=
2@P061@C01DA400K5aH04`l>00h:2@0C3`h0510?014=300H51<301@@3`0300h:2@0@30/04a4?0080
4a8@00@03`h<018A3`0C4Q004A0>0P0D4a40100E51802@P601HE4`0H5Q<2014=2P0301/G500G4a00
5Q8?00H04Ph;01h061@A01XF4`0F4Pl04Ph;01DA3P0C3``06aLD00<0000k=c@03@T601TE4P0C3`d0
5A4>014=2P0D40d03@T601@@3@0F4Pl04@d:018>2`0G4a007ATF01/G500A3@X05A@B00l>300H5aD0
4Q4?01@C4@0G5Q@2010?3@0:01`K6@0K6QP040l=01<B400I61H04A0?01LF500I61H03Pd;01LF5080
51<A00X04a8@01@C4@0C4Q004a8@020O7@0W9R@08b8P01PG5@0B4@l05QDC1P0D4a40400E4A805a8D
01TD5@0H51D05Q<D01@A4P0L6Q/0GUiN010@400E5AD02P/:018B4P0G5Q@05QDC01DD4P0D4a43018A
3`0Y01DD4P0I61H05A@B014@3P0D4a405QHD01/K6@0L71X06ATG01DE4`0D51805ADC010@3P0M7A/0
7alM018B400L7AP05aPC018C3P0H6A@051D@01XJ600i>CL0:2PV01HF5P0K6a/03`l?01dM7@0F5aH0
8bDQ01TK6@0F61D0418?01/P700F6aL04ALC01LM6@0I81`07RLQ00dF4P0J81h00P0E6AP09`0O8b80
6alN01XN7@0N8R408BDT02``;`0b=SD09RXY01lS8P0R:2D07RLR01XS800L9B@07BDW01lV;00S:S40
6B0X04mFG02@V9`0:30c024Y;00P:Bh082T`024[<00R;Bl092la02Hc<`0[>CX08Bl`02Le>@0eA4/0
:3Ho02/i@`0W>400:CY102Hg?P0V>3`0:ce102i0A00202i0@P0C0312A00a@d<0<dE503I8A`0_@T00
>4]703Q;BP0/?T00AEMK03]<E00gB580AeQR05Y[M@16Eel0?e1H04AFGP10DeX0@UIM04AHG`0204=G
GP1904AHG`1@I6/0BEeT04YNI01?HfT0C65W049GG019GV@0Bf1V04aQI@1=HVH0DFIZ05I[KP1JKg40
EV]/05Q^K@1IKfh0EFYY05AZJ01FK6X0F6e[05a`K`1OLg80HgIe06EgM`1aPh<0KGin06moO`1aPH40
LX6207V7R020Rhd0PHb>08:=S`25Si40R9:D08VCU@2>UYT0TIRK09:IW02EVYh0VIjR09^PY02PXjP0
XjFZ0:JX[@2][KD0/[:j0;Bd_02k^L@0`;g80;jkaP32_L/0b<?A0<W3d@3?aMP0e<SL0=O;g`3Lcn<0
gm3U0>3AiP3Ud^P0j]K/0>gHk`3`fO40mMge0?OOm`3khO`0o^Cm0?kVoP3niod0o^_n0?o_o`020?oc
o`040?ogo`3onOl0oo_o0?omo`D0o_kn1P3oool0J@3oo_l0oogn0?kloP3onol0ooSo0?ogo`3om?l0
oo7n0?o^oP3ok?h0onWm0?gUnP3liO/0n>Gk0?KPm@3bg>l0kMKV0>OBgP3Mb]<0eLK<0<g1a`38_/H0
al370<6l`P30^[/0_;Bb0;F^Z@2YYI`0W9R<08n=O`1fMfD0Kg9N07b0J`20QG80PXQe07QoK@1aN6L0
J6mN07=jJP1gOVl0N7m`07InL@1[M6T0Ig1U06A^I@1[MFd0KWUa06]fL01VLFd0IG5^06=^JP1LIf<0
EV5M04mKE@1;Ee00D5aE04IBB@11CT@0=40g034l=00/<Rh0;C<_02X`;00]=300<CTd02Tb;@0T;bT0
9S4[02hj<`0f@c`0;CXc03E3?00d@Sd0<d8n0392?`0b@T40:chl02@g=@0Z>ST0<d8o07f:P`0g@SX0
;cP_03]2>P0U;2D09bhW04Q?B00Z<BX0:C0Y01lV7`0P9b008RTR02L^9`0U;2D092/T02Tc:`0Z=340
92l[028]:@0L9B8092dZ020Y9P0S:BL08RHU024U9002020T8`05020U8@0R:B<09R`X02D[9`0R:2@0
0`0N9280500P9RH07B<S02@Z:P0L8B@06R0P01XP7`0O8b808BDT01dQ800O8B009RPW01/M700Q8B40
92@T01dM7@0H61P06a/I01XL600K7AP07AlJ0P0G6A@02@0K7AP05aTD01PJ5@0K7AP05aTD01HH4`0G
61<05QDA01LF4P0401PG4`0301@C3`0G5Q805QDA00806QTE01405A8@01D?3`0E4A0051<A01LG5@0<
3P/07R0M018D4@0N7Q`0518@01XF5@0C3@d04@`;01HB3`0I5A8061@A01@@3@02018>2`805Q8?00<0
4@d:018>2`0A3@X00P0D40d01@0C3``04@d:01<?300I5A804@d:0080510=00<040`900l;200C3``0
0P0A3@X0400D40d04`l<00h:1`0B3P/03`/8018>2`0?2`P03PX701<?300D40d03`X7014<2@0B3@X0
4@`9010;200C3P/2018=2P<04`h;00@04@`900h91P0@2`P04`h;0P0E40d02`0D3``04@`901XE4P0B
3@X040/801@?300=20D03`X7010;200B3@X04`h;00804Pd:02004@`9010;200@2`P04@`901<>2`0D
3``03`T9010:2P0K5AD0=S0`02<M7@0A2`/020<301@>3P0B30`030L700h8200?2@T04@/;00P20P0@
2PX03`T9010:2P0=1`L04@/;00l92@0>20P04@/;01@>3P0G4A404@/;010:2P803`T900d03PP800d7
1`0B30`03`T901D?3`0?2@T040X:00`61P0?2@T03PP800/51@0=1`L040X:00803PP801403@L700l9
2@0B30`04@/;00d51@0L4Q<0;28S024G600;0@80308301061`0E2``04`T:01882@0E2``04@L80188
2@0201<92P0:01061`0A1`P05P`=01`B4`0@1PL0308301882@0@1PL04PP901H<3@<04PP90P0C2@X2
01D;300:01@:2`0A1`P03@<400h41@0D2``02@<300l92@0=1`L06aDE018<30804@/;00`03`T900d7
1`0<1PH030H600h51@0M4a@05@/<01061`0A1`P03P@501D;300D2P/201<92P0L01D;300G3@h05@/<
01061`0E2``03@<400P0000e:b`05P`=01D;300B20T03`D600h41@0=0`@04@L600`20@0B20L05@/:
01881`0L4Q405P`;01881`0>10<03@<200l5100@1PD04@L601061@803`D400<040H501471P0@1PD0
1@0@1PDDooooo`006oooool0400=2``04Q0A00d;300A3a0040h?004000040P<06ALH01LE5P0?3@h0
2@L801DC500>2PT04@d<01hJ6@0M6AP2010<2`0600l;2P0B3Pd04Ph=00l;2P0A3@`0510?0P0C3`h0
2`0A3@`040`;018>3@0D40l040`;018>3@0>2PT05A4@01hJ6@0<20L04@d<00804Ph=0P0D40l0?00E
4A0030P7010<2`0L61L040`;01/G5P0L61T03@/@00l=3P0B3P/06aH=01<=000X8a00N7=O07mjIP0d
<Ah09RDG0041000I5a4040`;01TE500C3`h030P701DA400C3`h030P700d9200O6aX061@C00d9200C
3`h04Ph=01<?3P0R7Qd07ATH014=300C3`h04@d<018>3@0C3`h03`/:010<2`0J5aH07ahL01XI5`0@
3`d04A0>018A3`0A40h06QTG04e<BP0Y:2H04A0>01TH5P0>30T040`902/W900A3@X02@D200`81@H0
4Ph;01006ADB01hJ5`0K5a@040`9014=2P0E4@h03`/802@P7@0A3@X0<2`Y00l;200I5A805a<@01@@
3@0F4Pl03PX70P0C3``0100E4@h04`l<014=2P0C3``201DA3P0B014@3P0I61H0FeYH02@S8@0J6AL0
5QDC00l>300@3`d05A@B01@C4@0?3P`03Pd;0040000J6AL01PD301TH5P0l>cT05QDC0P0D4a402P0B
4@l04A0>018A3`0C4Q0020L501dL6P0R8Al05QDC00l>300G5Q@601@C4@0301D?4@0G4A<06Q@F0080
6ADF00P05a<D01PF5`1@D50010@402DU9@0L71`051@D01@C4@<05A@B0`0C4Q002@0A40h05A@B01HE
4`0H5aD071/I01@D4P0H61H06ATG01HF500201@D4P0T01DE4`0B4Q006QXH01HF500B4Q005aPC01XK
5P0I6QD05AHA01PI500A4@l05ADC01`L6P0O7al071`L01PH600W9bL06a`H01/N5`0D5Q406Q`G01TK
5P0M8Qh051TE01DK5`0O9B<04APF01HO700:4a00;C@b01PL6`0D61L07b<R01/O7P0H71/08bLV0P0G
6aX0900I7A`06alN02@X9`0J81d06B8M01`U8P0I8R406B4S01/R:00K8RT092/c01XQ9`0`>3`09blb
020X:`0O:2d082T`024/<00T;c409S4c02Hd=00O;Bh082h_02Dd>@0X=Sl09C<l030nB00U=Sh0:3U0
02Lh?`0Y>cl0;d550394B00a@dD0;d530353A@80=4I600h0>Da;03Y=B`0bAD40?U1?0312A00cADT0
?e1H03Q9D`0gB580AUMQ03i?E`15EUh0@59I045DF`80?e=J0140@5AK04AHG`16FV40CF5X04QLHP1:
Gf@0D6EZ04eRI`13Eeh0CV9[05EYLP1EJG00E6Q_05I[K`1DJF`0Efa]05AZJ002055XHP0B05=ZHP1F
KFL0Fg5^05aaL01NLW40H7Ac06AgMP1VN7P0JG]k06]lO01dQ8@0MhN707N6Q`1kRHX0P8^=08:=S`23
SY00Qi6C0P29TiD0402<U9L0TYNK09BIW@2EVYh0VIjR09^PY02SY:T0YZN/0:Z[/02_[kL0];>k0;Je
_@2n_<L0`[o:0;nla`33_L/20<W3d@0H0=75f@3Db=`0el_O0=c?h`3Od>D0hLoU0>CAi`3[eN`0k]S_
0?;JlP3egOD0mmog0?_Qo03ni?d0o^Kn0?kWo@3njoh0onoo0?kbo`3olol0ooKo0?oho`3on_l0o_co
1@3moOd00`3no_h0oooo0?ooo`030?ooo`0Z0?ono`3no?d0oO_n0?khoP3mm_d0oo?m0?obo@3okO/0
on_l0?oXo03niOX0n^7g0?OPn03ch?H0lM_b0>cFj03Ucm`0g/[E0=?1b03=_/<0b;g10<:k`P32_L<0
^KFl0;F_[`2`Z:H0Y9fI09RDR`2?SH00PH5`06iaG01aM5l0OhA^07^3KP20R7<0OXEc07ElK01[LV80
LgYZ07AlK@1cNf`0L7Q[0P1VL6D01@1YLfX0KGQ`06ehL01VLF/0GfYV0080HfiZ02P0F6=O055LF01?
FU@0Ae9:045<A00g@SX0;CT_024]8`0b?3<0;cDa02hc;`0X;RX0:Bl[02`d;`0X<B`0:SD_030l=@0^
>c@0=T<l03=1>P0fACh0?di90351?@0]?CX0<TE30354@P0V>CL0:SXi02`j=P0[>3407bTQ03<l<P0@
60d0;3<[02T`:@1;DT/08RTR02he;P0N9Ah09RdV0P0T:b@04`0Q:2408bXS02/e;@0Y<c0092l[01TT
800N9b@09Bh[02L`;@0N92806AdL01XN7@0M8B007b<R028W8`0P9b408bTU028X900O9B400P0N9280
7P0X;R`08RPX01`R8P0J82006AhQ01DK6`0i?ch082@S01/O7P0R9RD08B<R01XL6`0O8B009bLW02XZ
:P0R8R806ATI01/K6@0K7AP06Q`G01LI500E5a805aTD01PJ5@0F61<06A/F01hP6`0H6QD051HA01HF
4P<05aHB01/05QDA01DD400H5a<04a8>010?2`0=30P06QTE01hM6@0>2`T04P`<028N7@0D4a40410>
00L91P0E5a@030h;00P81P0F51<05A4@01D?3`0L5aD04`l<010<2@0C3``05a<@018>2`0C3``00P0F
4Pl00`0C3``05A4>018>2`0301<?30804@d:00X05A4>01<?300B3P/0510=014=2P0>2PL0510=04M3
@00Z9R<04@d:0P0I5A80300?2`P03PX701DA3P0E4@h04`l<01LC400?2`P050l<01TD4@0K5Q<04@`9
00h91P<04`h;0P0B3@X3014<2@<040/800`03`X700d81@0G4Pl040/800/60`0@2`P04Pd:00P3000>
2@H040/8018=2P0C3P/201@?300O00d81@0B3@X040/800l:1`0B3@X04@`900/51@0?2@T03PP800l9
2@0:10@050h>014;2`0@2PX03PP801dG5`0J51@02`D5010:2P0?2@T050h>00d71`0B30`05@l?018<
300@2PX03`T9010:2P0A2`/04P`<010:2P0300l92@803PP801<02`D500L10@0>20P05Q0@00L10@0A
2`/03PP800/51@0G4A407aTI018<300:10@04P`<00`61P090`<02`D5014;2`0D30`04`T:008050X;
0P0C2@X04`0O5AH0;bDV020F5`0?1@H04`T:01882@0D2P/04`T:0147200@1PL04@L801D;300N51D0
3`D601D;300A1`P04`T:01882@0D2P/00`0B20T01P0A1`P04`T:01P>3`0J41406@l@01@:2`8040H7
00T02`@400d71`0=1`L06aDE00@0000C3@d04@/;010:2P0?2@T00`0=1`L0200I3a006a4B00l51P0?
1@H03@<400l51P0@1PL03P@50P0B20T01`0=0`@02`4201P>3`0E2``05`d>01882@0900000P0B20T2
0147200A01061`0A1`P04PP901471P0?1@@040H500l5100=0`804PP701@:2@0A1`H03P@300l5100@
1PD03`D401471P0@1PD00P0?1@@00`0@1PD04@L601061@0501061ACooooo000Kooooo`0<01<A4P09
1`P02@L801/I6P0B41407Q`M01LE5P1>C4d05A<D00L51P0?3@h05aDF0P0B3Pd02@0N6QT07ATH010<
2`0A3@`05A4@01LC4P0D40l04@d<018>3@0301DA400>018>3@0@30/04Ph=01@@3`0@30/01`<201<?
3P0B3Pd06QHE00D1000A3@`04Ph=01<?3P0D40l201DA400C00l;2P0A3@`05A4@00/71P0>2PT03PX;
00l=400C3`h04a0;01PC1`0Q6PX0>S<P0=?@^`3lmn40NGMR02d]700;30005aD>00/71P02018>3@05
01DA400J5QD04@d<01XF5@0D40l00P0:1PD02P0B3Pd04@d<01<?3P0B3Pd08QhM01`H5`0@30/0510?
01HB4@0G4a8301@@3`0401TF5@0N7A/06APF014@3P804Q4?00`04A0>03Lf=02:RHL09RDS014@3P0E
518040d;01XF4`0o>cP081`I01dI5P0E4@h701HB3`0[01XF4`0G4a0040`9014=2P0C3``03`/801dI
5P0W8b80[ZZW02PT8@0@3@/04`l<018>2`0H51404`l<01PD4@0I5A805A4>01@@3@0B3P/040`9018>
2`0H514081lM00X91`0K6QP030/9018A3`0510803`h<014@3P0?3P`040l=01<B400?3P`06QTG010?
3@0E51806QTG010?3P0@3`d051<A01<B4002010?3@08014@3P0B4@l05QDC00l>300<2`T040l=01@C
4@0B4@l601@C4@0I01LA4`0H4Q@0618D01LC500F4Q<05A4B01LE5P0?3@h07Q`M00l?3`0000006QXJ
01@C4@0E51805QDC01DD4P0B4@l04A0>01DD4P0B4@l05QDC01DD4P0C4Q005A@B01<C4@0201HF5080
51@B0P0E5A<01@0G5aD04Q8@01@D4P0G5aD04A8=00805QLB03005aPC01dN6@0G5aD07QhL02PX9P0[
:b/0AdM701PH600M7Ad061TE02DX7`0G6Q<05QTB01@G400O91h05AXE00`B3P0P9R@06b8R02L`;`0o
B4L0KWEd02<W9P0D61L07B4P01TM700G6aX07R8Q01PL6`0E6AP07b<R028V9@0L81l061hK01dV8@0P
:BH07BDU01lW:@0O9R`08BP_02<Z<P0K8RP08RX^02Ta=00N9RT08R/`028]<`0T;c<202D`<P0I02<a
<P0/>S/0<Cm00350A@0[?4@0;d1802Tj@`0V=cl0:S]202/l@`0/?T80<4960353A`0bA4H0;Cm10312
A00dATH0<dE503Y<B`0lCdd0>Da8045CDP0hBT`0>4Y>03e>EP02041AF`0Q04YKI@0hBE40?4eE041B
F@15Ef40?e=L03]?F00lD5L0@EEL04AHG`18G6<0AU]Q04YOI01?I6T0CV=X04IJH@1FJWD0G71k05M[
M01EJG00F6ea05EZK@1CJ6T0E6YX059YH`1BJF40E6]Q05E/I01KLFh0G75_05ibL@1PM7<0I7Mg0080
J7Yj00T0KGin07Z:RP1nSXh0NhZ;07b:R`20Rhd0Phf?08F?T@28TY@00P2:TYD0402=UIP0U9VM09JK
W`2HWJ40VYnS09fRYP2SY:T0YjR]0:^//@2a/;P0]KBl0;Je_@2m^/D0`;g80;jkaP34_/`20<c6e00H
0=;6fP3FbMd0f<_O0=c?h`3Od>D0hLoU0>?@iP3[eN`0k]S_0?;JlP3egOD0mmog0?_Qo03ni?d0o^Kn
0?kWo@3njoh0onoo0?gao`3nl_h0ooKo0?oho`3on_l0o_co1@3moOd00`3no_h0oooo0?ooo`030?oo
o`0`0?ono`3no?l0oo[n0?khoP3lmO`0o_;l0?o`o03nk?X0on[k0?oWo03lhoP0n]ke0?GLm03afo80
k=K]0>K@hP3ObMH0f<C?0=2ma@3=_/40a[bo0;nh_`2m^;h0/[2f0:RRXP2VWY`0W9NB09NCRP2?SH00
Ogi^07MjI@1kOVT0PhQb07InJ@1jPVd0OXEc07QoK`1[LV80KGAT06]cI01]MFH0KWU[06egK01^N6l0
KWUa06ehLP1YM6h0I6mY0P1PJfL06@1LIf<0DUeG04]FD014CdT0<Sde03M2>P0e@3P0:3@Z028^900b
?3<0:2hZ02X_:`0`=C40<3Hb02`c;`0Y<Rd0;CPb03M3?@0]>S<0=4<l03]:@`0jBD80BeYE03]:A`0`
@3d00P0bAD<0>P0[?S`0?De:02lm>P0L:B80<cde02H_9@0[<BL0<cXb024X8@0a>340;3</03U0>@0L
8a`09bhW02D/9@0T:b@082LP01lV7`0W<BT0:38_024/:00B7AT0624N01hW900Y<Rl06R0N01LK6P0N
8R408RHU024U900S:2@082LQ028X900Q9b<07bDQ01lU8`0Q9bD08bTW01<I6@0H7Qh08BLW02<X:`0I
7al0Ife/030d<`0I7A`06alN01lQ800J71/07b4P020P800S8b<07alO01XJ6P0M7A/06ahH01XM5P0I
71D201XM5P0701TL5@0F6A8061/D01`O600G6Q<05APA01LH4`0201PG4`0701LF4P0E51004a8>01HE
4@0=30P05QDA024P700201HE4@0501XG5@0C3@d061@C00l>300L71X00P0K7AX06@0A4a003@d;01TG
5@070`80208201LB4@0B3P/03`/8014=2P0F4Pl0510=018>2`0E4@h0510=01<?300E4@h04Ph;01@@
3@0E4@h05Q8?01@@3@0C3``05A4>018>2`0?2`P00P0A3@X03`0>2PL04Ph;059>B`0`;2T03PX7014=
2P0D40d05A4>014=2P0?2`P05a<@01HB3`0@30T081`I01LB3`0201PC4006018=2P0@2`P04@`901@?
300C3P/04Pd:0`0A30T03P0F4@h04`h;018=2P0C3P/04Pd:00l:1`0U81d05Q4>014<2@0C3P/03`X7
00/60`0A30T04Pd:0P0C3P/05`0B3@X04@`900d81@0D3``040/800d81@0A30T03`X701LA4@0<1PH0
4@/;010:2P0F41005a4A01PB4P0910@02@<302dW9`0U7al02@<300d71`0D3Ph03`T9008030H600<0
3`T9010:2P0@2PX00P0?2@T2010:2P0400h8200?2@T03`T900l92@8040X:01d04`h>01PB4P070@40
5@l?00L10@0E3`l02`D5018<300P6QX0=Bl_020J6P04000040X:00l92@0<1PH02@<300h8200D30`0
3`D600X00@0?1@H05@/<01@:2`0P5QL0=2X[02DK700B20T04`T:00l51P0201882@0@00l51P0@1PL0
4PP901<92P0I3a002P0101T?400@1PL05`d>01<92P0A1`P04PP901<92P0A1`P040H701<92P<05`d>
00T050X;0147200B20T03PD601XD500=1`L04@/;00@0000J51@00P0?2@T02@0>20P03@L700d71`0>
20P05P`=01882@0?1@H06a4B01<92P0200h41@0;00`20`0D2P/060h?01D;300F30d02`4200X00@0=
0`@05@/<01P>3`0B20T0100@1PL01P0B20T04`T:00h40`0B20L040H500`20@803`D400<04PP700l5
100?1@@00P0A1`H00`0>10<04@L601061@0200l5100301061@0A1`H040H500D040H55?ooool001_o
oooo00`040d=014>3P0F4a<0514A018?3`1<BDT07a`L04E2@P0J5aL0514A01XG5`0B3`l201@@3`0J
014=300G4a805A4@01DA400@30/04@d<00l;2P0B3Pd05Q8A01HB400C40X04Pl901<@2P0?2`H040`8
01DB3P0V8Ql030P701TE500<20L04`l?010<300A3@`05A4@010<2`0B3Pd201<?3P0Z010<2`0B3Pd0
4@d<018>3@0D40l04Ph>01D@4`0D3`d05A0;01PD200a;A/0A40]0;FaW03=bKL0C4Pi024N4`0g<b`0
5Q8>01@@3`0@30/06aLF07McLP1LF5L04`l>010<2`0A3@`05a<B01@@3`0F4Q40510@01D@4`0@30h0
6A@F01XF5@0F4`h06AH=02<Q5@0N70h04@l601PD3`0C3`h03``;0P0E4a404@0D4A00518@01<A3`0E
4Q40=C8a06ERH@0G5A<040h<01<A3`0C410030L901PD500H5AD0@3`j01@@3P0@30T04`l<0080510<
01005A4=01@@300B3P/05a<A01<?3@0F4Q004`l=018>300A3@/0510>018?3@0/:2H02`L501HB400<
20H040`:0P0F4Q00100G4a407ATG018>300B3P`201LC4@0I01DA3`0G4a4040h;01@B3`0F4a4040d;
01@A3`0F4a4030X701PE4`0;2@H0514?01PE4`0A3P`05A0=01HB3@0E40d05A0>01@?3P0F51<05Q4A
01HD4`0A3`d05A8A01@A3`0200l>2`805aHC00L04a8?014?300A3`/040h;01DC3P0=2`P061@@0080
6A@A01/05Q8@01PE5@0D4A406ALF018@3`0B3`l05QDD01DC4`0G5QD04Q4@01LF5@0H61L051<A01PH
5P0H5aD04a<A018A3`0D4a405A@B018A3`0I61H071/I01PH5P0G5Q@05QHD01TI5`0H61H00P0E5A<2
01PH5P2Y01LG5@0@40h05QHD01XJ600B4Q0051DA01<D400G61@04aDA01<D4P0K71X07QlM01<D4P0O
81l06a`J01@E500K7AT07R8M01TM5`0H71D05ATB01TN600J7aT06AhJ01TN700I7Qh05A`N05IJGP1Y
Kg006R8P01hS8P0Q9bH07BDS01PM700G7Q`08BTW01PM7@0K8B007BDS01DJ6@0N92@07B@T01dT9@0K
8R@092/`02D/<P0P9bh06b<Y02hf?00P:2d08bha02H`<`0T;c<09C0d02Hc=@0U<C<08c8b02Dd=00V
=cL09CHf02hoA01FJ700X[>g04=FH@0/?TD0;T1702m1B@0Z>d@0>4UB049CG00bADX0;d970313A`0c
ATH0=4M603U<C011E5H0B5]N03e?D`0eB4d0@eEL04=EG@18FF<0@UAN041AF`0oD5X0AUQQ04AFH@1>
H6d0B5]X04AGH@13EUh0@eMM04=GG019GF00BEiQ04YNHP1<H6D0CF5V04QKHP1FJW@0Ffmi05AXL01B
IVd0Efa`05I[K01DJVP0E6YW05I]I`1EK6@0E6]Q05Q^I@1JKVX0G6m]065dL@1TMG@0IGIe06QjM`1/
OGd0LH6007R8QP1jRXX0NHV807V7R02;UiP0R9BE08F@T@27TI80RI:E08^DUP2AVId0UYbQ09BJW`2J
Wj@0WjB[09jRZP2TYZh0Z:Ra0:b/]@2b/KX0][C00;Ne`@2l^LD0`;c90<2mb@36`Ll0cLOE0<o9e`3B
amP0e<OI0=S;g03Lcn40h<kS0=k=h@3Sd>D0jmG/0>oIl03cfo<0m]kf0?SPn03kh_`0oNCl0?gUo@3n
j?d0o^_n0?o^o`3nl?l0o_7o0?oeo`020?ogo`090?ojo`3mo?l0ooco0?omo`3noOl0ooco0?omo`3o
o_l0oogo0080ooko0P3oo?l0O`3on_l0ooOn0?kdo`3nl_h0o_7o0?o^oP3njod0o^Sl0?gVnP3ihOH0
mMga0?7Jk03/fNP0hLkL0=c9d`3B`<P0dl780<no``3<`<40a;Rj0;bd]02j/k@0/:ZY09nKU02MVI00
VYV<09VHRP2ATh80P89^08F8L`24RG80Q8Yc06mgG`1dO6D0OXE`07MoK`1XKf80IVeQ065YG@1fOW80
OHQl07EoMP1gPGP0LWie06]gKP1XLfX0HViW069^IP1MJF40Ef=K04iIDP12CDH0<Sdg03<m=`0_>C80
;SPa02/e;P0b>cD07RPR02L_;00[<c40=3`j03Do?@0b>cT0<3/f02Td<@0e@C`0:SHa034n>@0iAd40
>TU403U8@`0_?c/0:SXf03I7@P0`@3`0;Cdi02Ph=00W=2h0<Che02Lb:P0V<2H08R/Q02T_:P0X;BP0
:S0[02P]:P0T:RH09bdX02<Z9`0U;BP092lX024[9P0M9b407bTU02@/:@0Y<2h092/Y024X9P0F6aT0
7B8Q01TN7@0K7ah082@S028V9@0P92<08RLS02@[8`0R:R8082PR01lU8@0P9R@08BLV02<X:@0V:bd0
:2d_01hQ8P0L7b407b8S02DX9P0N8Al082<Q020Q800O81h061TG01hO7@0K6aX00P0L71/04@0M7A`0
7alM01/L5`0P81/07AhI01XL5P0K6aH07QlJ01`N600H61<06AXD01TK5@0H61<05QHA01PG4`0I61@0
5aHB008051<?01l06APD00`;1`0X9b<0C4]7024P700E51006ALD01<@3P0K61H05A@A01<C400A40d0
4a@@01/K600C4a004Q4>01TF500H5Q<0510=01@?300F40d05a8?01HA3P0E40d050d;018>2`0D3``0
5@l<018>2`0A30T04@d:00804`l<00L04Ph;014=2P0@30T09b<P01HB3`0B3P/061@A00<05A4>01X0
40`9018>2`0B3P/03`/8018>2`0H51402`L4010<2P0F4Pl0510=02<O7@0A30T05@l:01L@3@0@2`P0
3PT5018=2P0>2PL050l=01HC4@0<20H04@d;00l:200D3``03PT6014<2@805A0=00L04Pd:01LB3`0B
3@X04Pd:01@?300C3P/050l<00<04Pd:03X04@`9010;200?2PL03`X7018=2P0?2PL040/8018=2P0;
1P<050h>00l92@0A2`/040X:00/51@0<1PH03@L7018<300@2PX04P`<014;2`0<1PH04P`;01D?3P0<
1PD04Pd<00l:200A2`X03`T8010:2@0A30X03`T8010;2@0=1`H03`/:00h9200B3@d03`X900h8200B
30`091`M02LP800B2@X05Pd>00d51@0B20T05@h>00/51@060@40?3Hf04Do?`0>20P03@L701D?3`0K
5AD05@l?00`61P0?1`P04@L80P0C2@X05P0B20T04@L800l51P0D2P/04`T:0147200E2``04PP901@:
300B1`X03P<601472@0=1@D05P/>01462@0<0`D05P/>01472@0G3@l050X<01482@0@20T201892P0@
01082@0>1@D04`/<018;2`0?1@H04@P900X30`0B20T040L800l82@0@2@T06a4B00h8200=1@H040L8
00l7208040L800L040P901882@0?1@H04PP901hD5@0X7Ql07A<D00804PP900h04`T:0148200g;Bh0
GeEF01882@0D2PT04`T800l5100?1P@04PT701481`0B2@P040T800l81`<03`L800`03PD301471P0C
2@P040H501H<2`0Q5aH05P`;01471P0?1@@04@L601881`0?1@@501061@0401471P0@1PD03`D40106
1@804@L600<040H5ooooooooool04_ooool001_ooooo00D061@C014=300E4A00510?00h:2@0201HB
4@0S01TE500M6AP03@T801<?3P0;1`H040`;00T51@0A3@`05a<B014=300400004@d<01<?3P0@30/0
4Ph=01@@3`0A3@X0514901DB2@0C40L04a0801HC300H5A003@X6018>3@0A3@`04Ph=01`H6@0B3Pl0
40`;00h:2@0G4a804@d<00X61@0I5A@01P0@30/0500D3Q004`h;01<>200@30806AH501hK200W91D0
?SX^03@`9@0;1PD081XL01PC4`0:1PD03PX901DA400[9bH05Q8A018>3@0A3@`04Ph=0P0C3`h03@0B
3Pd0510@01@@4@0B3A405A4C01XF4`0H5@`06AP603lo9@14A2P08B4<01/I3@0K5a@00P0E4A0201HB
4@0301DA400D40l0510?00<0510?01404`l>018>3@0A3@l050lE018=4@0W8b@0BTI701HB4@0C3``0
5a<@01HC3P0D4@`05Q<>01@A2`0L61D06aLF00T51002014=300>01<?3P0@30/040`;020L6`1ACD`0
5A4@014=300W8b80:2@S010<2`0E4A007a/J00h:2@0B3Pd201<?3P0401@@3`0E4A005A4@014=2P80
5Q8?02L04Ph;01<?300A3@X03`/801LC400;1`@0920M00h:2@0C40/040/501`E4@0I510081PF028L
7@0?2@/030H801hI6`0B3Pd03@T8010=2@0P7aX05aPC00l@2`0?3PX04A0<01@B3P0G50l07a`G01HB
3@0N6A<05a8<01PC3@0G4P`06aLD010?3@010000<2l]00h=2`0I61H01@0F5A<06@0E51805QHD02<S
8@0T92806QXH01@D4P0E5A<04a<A02/[:@0O7ad03`l=010@3P0=3@/06QXH01`L6P0I6AL051@B01<C
4@0E5A<04Q8@01<C4@0F5Q@06ATG01DE4`0A4@l00P0F61D0100C5A808B<P03Pj=`0];b`201@F4`07
01DG500F61D05QPE01LJ600H71/05a`H01HK5P0201LL5P0F01@I4`0M8Q`06QhM02/_<00A5AP0:B`c
01dR9P0H8B00=Sln02D^;@0H8B008b`[038k>P0>5aH08BXY01/T8`0U;Rd0>45001TP8`0N8bT07b@Z
01dS:@808RT_00T07BD[02@]<P0K92T07BL/02Xe>@0Q;30092lc02Ha=@0V=3D00P0S<c805@0U=SD0
7c4a024e=00Z?D80?E5H096U[P0dBE<0;d5;03A7CP0bA4h0:Sa803I8E016F6@0;d5;02m2B@0`@dP0
<TI703E9B00hC4X0CV5W04ULH`0203a?EP0R04EHG`16F680@59L045CG@0nD5X0@E=O04aNJP1FJ7D0
B5UY04AEI012E600A5IP04QKH019GEh0AUYK04]OG`19GEh0BeiT059UK01DIfh0BUiW05=WK`1CIfh0
DfQ]05=XJ`1=HV<0DVQV059XI@1GKVP0FG1X05I]I01EJV<0GW5]069bK`80J7Qe00l0IgMd06alN@1_
Og`0L81m0761OP1dQ840MhN407V9QP24T900Phn?08:>SP27TI80S9JH08jHVP2<TiT00P2CVZ009`2H
W:D0W:2Y09bPZ@2UYk<0ZZZf0:f]^@2b/[h0]kG20;Rf``2l^/L0_k_90<:nc037`m40cLOE0<k8eP3B
amD0e<SF0=K:f03JcMh0g<kO0=g<gP3TdND0jmG/0>kHk`3bf_80m]kf0?SPn03jh_X0nn?k0?cTo03m
io`0o>Wm0?k/o`3ok_l0o_3o0?obo`3om?l0ooGo0?oho`020?ojo`80oo_o0P3oo?l30?oko`80oo[o
02d0ooSo0?oeo`3nl_h0o_7n0?g_o`3nk?l0oN_o0?cYo`3kiOX0n>7f0?CMl@3`fN/0k]SU0>SGg@3D
`lT0d/;80<Zk_P3=_/40a;Jh0<Fj^02o];80^:j/0;N^Z@2`Z:00XIn@09BEP`20PFl0MGQU07MjI`1m
P6/0Q8Uc08V>M`1oQfl0JW9K071hH01iPFX0Mgmb06=ZHP1YL6P0HFQP071gK`1eOgH0LWac07=mM01Z
MV`00P1SKfD03`1PKF<0I75W05]XGP1DHEP0CUUA04=>AP0g@S`0@DY504=<A`1:De00;C<a038h=P0a
>ST0<S`m030k?002030l?01202di>00X=380=40n03a8A@0c?c/0>4A003Y6@P10C4P07bhY03Q9@`0Q
<R`0:3Lb02hm=`0a@3T0:3D^02Db:P0Y=2`0:3<[024]900Q:b<0;34]02`^;@0X:RT09BTX02H[:P0W
;B/09Rl/02Pb;`0X<bl09C4]02<_:`0T;b/09BXX02DY:00R9RD082@S01@H5`0B5QD06AdL01hR8@0P
92<08bLV02HZ:@0X;RX08R/P01hX7`0M9al07R@Q01hT900O9BD07B4T024R9P0R8bL08R<U02HW:@0X
:RT09RHT01dM6`0Q8Al07AdK028R800M7A/071`J01/K6@0J6QP06a/I0P0L71X201XI5@0F01TH500G
5Q805aHB020O6`0R8Ad06QTE01lN6P0Y:2@08R4M01DD400G5Q8061LC01HE4@0D4`l05A@@024P700=
30P030/701LF4`0<2`L05A@@01/J5P8061LC00L05aHB01HE4@0F5A404a8>01LF4P0H5a<04Q4=0080
61LC00@05A0=01P@3P0H40h05`l=0P0F3P`02@0N5Q@06A4?01P@3P0H40h050`:018<2@0C3P/04Ph;
01<?3002018>2`07014=2P0P71T04Ph;00P40`0300004Ph;01HB3`02018>2`<04@d:01H040`900<0
000R7Q/03PX700P40@0=2@H05A4=01D=2P0G40X0614;014<200?2PH04Pd901XF4`0>2`T051<A00h=
2`0C4Q005QDC02<N6`0F4@h04Pd:0P0D3``01`0F4@h040/801<>2`0?2PL03PT6014<2@0=20D01P0?
2PL400d81@0:010;200E40d0100001H@40090`<01@0001XD500?2@T03PP800l92@8040X:01D03`T9
00h8200<1`@04Pd:02<N6`0L5a@02PD200/60`0?2PL04@`901@?300@2`P05A0=00h:1`0<2PT01`H4
014@3P0710<01`4101D?3`0A20T00P0C2@X01@0D20X04`L901882@0>1`L05Q0@00803`T900X06aDE
00h8200;1@D03@L701LA4@0C3@d02`D5018:2P0B20T04@L80P0B20T00`0A1`P040H7014720040147
200600`4100?10P03`@800l5200@1@T05@X>1@0A1PX0200@1@T02`<501H@400D3Ph01P4101H@400=
1`L01`820P0B30`02@0P6QX040X:018<300B2P/05`d>00l51P0>10D040H704Y0@@0201061`804@L8
0P0B20T03@0A1`P0308300/10P0C2@X06@l@01P>3`0C2@X06a4B01@:2`1:@440OWAe01D;2`0@1P@0
0P0B2@@01P0?208030D000/30@0?2PL03PT600d91P803@T800`03@P8018:200?1@@04`T801061@0>
10<07aDD01D;2P0B20L040H501881`0A1`H200h40`0;00d30P0@1PD04`T801D;2P0B20L040H500h4
0`0A1`H04`T801881`0@1PD05?ooool001_ooooo00<04Ph=00l;2P0?2`X00P0B3Pd0900?2`X030P7
014=300<20L00`0000l;2P0<20L020@301DA400/:2L04@d<00T61@0J5QD04`l>01HB4@0A3@`040`;
014=300=2@H0514;01<@2@0>2`@040d701@A300A3@X06ADB01`H5`0F4Q403PX9010<2`0300004Ph=
014=300810<02`L601@@3`L040`;018050h@01dG5`0J5A405Q8901XG200L6@P07Q/<00H2000h=2/0
:B@R01<=3`0?2P/01`<2014=300>2PT040`;00d9200D40l2014=30804Ph=01004`l>01DA3`0C3``0
4@d<018>300E4P/05Q@7024P2@1eMUL0YJJ706m^EP0b<2408QlH01LC400F4Q405A4@0`0D40l0500C
3`h04Ph=01<?3P0C3`h04Ph=014=300B3A0061<G00d8300J5QL081`M00l;2P0I5A806aLD01PD4@0C
40/05A8=01@A300400004@d<0P0D40l01P0A3@`05Q8A01HB4@0@30/05a<B04A0?`80510?00@07QXI
03Te=00P71/020@30P0F4Q401P0E4A006QHE01LC4P0C3`h061@C01DA40804`l<03d061@A01LC400B
3P/04`l<014=2P0D40d030P501TE4P0=2@L05a<@01@A300C3`/03`/:01H@400L61T04`hB00d8300K
5aT06ADD01/G5P0=2PH00`8001XJ600<3P/04Q8@01HF500E5A006APD00`;1`0I5a808AhI01<@2`0H
5A002`P300X91@0O7Q`0;2/Y07elNP0S8R002PT701<B400G5Q@06QTG01TH5P0D4a404Q4?00h>300H
61H06ATG018B400>3P`03`l=01XJ600>3P`02PX801LG5@0N7Q`07AdK01/K6@0H61H05QHD008051@B
00d05ADC01LG5@0F5Q@05aLE01PH5P0D51804Q8@01LI5P0K7AX04Q@A02h`;@17BDH0:bdZ00805aTF
0P0H6QL06P0I6aP061/I01LK6P0H7AT061dH01PM5`0G71H0724K01/P6P0F6QT09RX[024U:00F6B00
5Q/O01TR8@0R:bX072DT01dV9@0Q:RT0:34`02</:`0H8B004a`K02</:`0M9RD082LZ0P0R9b/0300N
9BP082P[024Y;00M9RT0<C/m020Z;00M9bT0=D1202Td=P0T<SD09C<f02Dc=08093@c03X08SDc02<e
=@0W>CT0;3m402@h?`0mDEX0:Ce702doB@0gBU40<TA>02i0C00/?TX0=DMC0312C00bAD`0=DQ>03U=
CP0jCTd0?51?04IIG`10DeX0>4]B03mBF@17FV40@UAN04=EG`12E5h0?4iH03mAF`1;GFL0F6Yg05=T
M01;G6/0@UAP049DGP16FEh0B5aM04MKG01=HF80BemP04]NI01DIfh0FFac04iQJ01BIF`0DfI]05EX
KP1FJFd0CV9S05AXI`1FJVP0EV]V05U^I`1JKfP0DVMP061cK`1SLg00J7Qe0P1YNGH02`1_Og`0L81m
0761OP1bPWl0M8B107R8Q@1jRXL0P8b<08:>SP24T900R9:C0080R9:D0P2CVZ004@2EW:80UYZS09^O
Z02RYZl0YjVe0:^[]`2^[[X0];C00;Rf``2i]l@0^kW60;nkb@32_/`0al?A0<g7e@3>b=H0e<WG0080
eL[H00T0el[K0=c>g`3Qd>80i]?W0>gGkP3_fO00l][b0?CLm03fg_H00P3jh_X02P3li?`0oNOl0?cY
o@3mjoh0o^go0?g_o`3olOl0oo?o0?odo`3omol20?oho`80ooWo0P3on_l30?oio`0k0?oho`3nmol0
ooKo0?oco@3nl?d0onon0?k]o`3ljOl0o>On0?[Tn`3hh?H0mMgb0?3Ik@3/dnH0im7O0=k=e@39^/40
d<760<joa03?`lD0`KFf0;nd/P2f[:T0[jJQ0:nVW`2[YI`0UI>408R9M`1bMF80JfiK079eHP22Qg<0
KG9N07f2K01dO6H0IfmJ06YbF`1RJED0NX9g06M^I`1dNg@0KWE^06]bJ`1[MFd0KgYb06iiL@1SKVH0
FfQO05i[HP1OK6<0GfaR055NE012CdH0?TU103Q3>`0`>cD0=3dh03<l=`0oB4D00P0/<S001P0b>cX0
>TA503<o@00a?Cd0<clo02hj>@808bl]02@0;c/h02`h=00b?SX0<3`h034m>@0eA3l0:STd03a;AP1J
IV80Hg1Z02<`:@0X<bd08bhW02D_9`0T;RH08R`S02P_:00[<2`0:bd/02X/:`0X;2/0:Rl]02/a;`0Y
<Rl0:S@`02Pc;`0V<Bd09S8^02Td<00P9B<07b<R01XN7@0P92<07b<R01LK6P0L81l2020T8`0F01lS
8P0P92<082HR01hW7@0L9Qd072HN01lU8P0P9RH082DX020T9`0M7R8071dQ020Q8`0W:BP09RPW02<S
8@0L71X08B4O01dM6`0Q8Al06a/I01dM6`<071`J0P0M7A/0300Q81`05aHB01/J5P0P7a/07QdI01dL
600H5a<04a8>01hM6@0[:RH081lK01DD40806APD00X05aHB01DD400F5A408R4M01`K5`0D4`l040l;
01PG4`0Q81`06aXF0P0H5a<02P0G5Q805A@@01@C3`0A40`051<?01LF4P0D4`l06APD01PG4`0E40d2
01P@3P0:01L?3@0F3P`05Ph<024I5`0J4Q005`l=01TA3`0G3`d05@h<018=2PD04Ph;00H04@d:00h:
1`0N6QL04`l<01DA3P0B3P/2010<2@<04@d:01004Ph;02LS801NFUL0:RHS01DA3P0>2PL05a<?01P@
3@0D3@L04P/501@?2`0F4@d04@`800L3000?30X06APF0P0^;B/00`0B4@l0:RDR01XE4P02014<2@04
01@?300I51404@`901<>2`803PT600<04`h;014<2@0?2PL01@0?2PL02`0A30T040/8018=2P0=20D0
4@`902LR7`17@D4040X:01D?3`0P6QX0208200803PP800X03`T9010:2P0@2PX03`T900h8200E40d0
6A@A03Pc<00]:2D04@`90P0>2@H0300B3@X05Q4>01<>2`0I51404`l<010>300:2@L04A0>01@@3`0:
10@03@L7010720<04PP900l04PH80147200?1`P03`T901@>3P060@402P@4010:2P0<1PH02P@4010:
2P0>20P02`D501<;2`0C2@X00P0@1PL3014720<04PP90P0A1`P07P0E2Pd081DI02<H700A20X04PL;
00/0100@1@T04PL;01462P0@1@T03`@800h31`0@1`T05@l?010:2P0D3Ph05@l?01<=3@0@2PX030H6
00L10@0A2`/01P0000l92@0=1@H02@0001H<3@0>10D04@L801D=3@8040H70P0A1`P201882@0?00l5
1P0B20T05P`=01H<3@0C2@X03@<400L0000900003P@501H<3@0T6Q/03P@400l50`0E30L04PT40080
30@100d05`l=00l:1`0?2PL03PX700d9200<20L03@P701<;2@0?1@@04PP701471P0;0@004PP70080
40H500L04@L601<9200A1`H03@<201471P0?1@@040H5008050X90P0A1`H01@0@1PD04@L601<9200D
2PT040H501Cooooo000Kooooo`0D018>3@0K5aH04Ph=00l;2P0C3`h030P701DA400C3`h0<2`[04U5
A00F4Q4040`;01DA400D41003@T800h:2@0A3@`030P7010<2`0D40l3014=300900d9200B3Pd03@T8
01<?3P0@30X03PX801HB400L61H02@D40080510?0P0D40h01P0D40l03`/:01DA400@30/05Q8A01<?
3PD04@d<01@04@d>018<400J51H04`d<010;1@0A3@<03`/101HB2@0I5@h06QD@04i9B@0C3Q405Q4D
01@@3`0J5QD05A4@01PD4`0F4Q4040`;018>3@8040`;01404Ph=01@@3`0D40/04Q0601DB2`0D4@X0
4a0501dL2`1:BRl0alRW0?oohP2`/ID0<S4N01hL3`0F4`h05Q8A01@@3`0201<?3P80510?00<04`l>
01@@3`0D40l00P0C3`h0C@0D41002PH801@?4P0D41405A4B01LC4P0H51806QHD01HB3`0B3PX05A4=
01@A300H51<04Ph=010<2`0O6aX0:RHU01<?3P0=2@P06ADD00h:2P0K5aH03PX9018>3@0N6aX0>SHe
02XV9@0=2@P03PX901DA400G4a8081`K01XF5@0B3Pd06QHE01@@3`0G4a004Ph;01LC400J5Q<05Q8?
024M6P0H51404Ph<014=2P0J5Q<05a<@01XG5@0D4a80410@01@C5@0C4QH040hB01PE6@0=2Ph0510B
01<?3P0K5QD05a8>01LE4@0B4a405APH01LJ600D5aL04Q<B01DF4P0I61D0K6]X04E3?`0N71L04a4=
01DB3`0F5A<04A0>014@3`0S8R005QDC008051<A00L05QDC01PG5@0G5Q@051<A01<B400D51805QHD
008051@B00`071`J024Q7`0n?Sd04A4?01dM6`0L71X02`/901HF500H61H051@B01<C4@0F5Q@201PH
5P0<02@T8P0K6aT05ADC01<C4@0G5aD06ATG01LI5P0P8Ql06adJ02<U8P0X:RL03a4>1@0H6QL0>P0G
6QP05QXI01PM6@0J7aX06QlI01TN600J7aT051TC02HZ:@0A5AH09RX]01`O9P0I7R408BXY01LP7`0H
8B006B8Q00hG5P0M9RD041TH01XS8P0R:bX06R<R01lX9`0L8b<08BHX024V:@0O9RP082PY02<[;P0S
;2d0;3Hf02/e=`0S;Bh07b/Z028^;`0S<C@0938e02Dd=P0V=SH09cLf02Hi=`0[?Cd0:S`l02Hi?@0^
@DP09SU002m3C00]@4L0>DaC02m2B`0eAe<0;3i:0394D00^@4/0<49<03M:D00kCU8203a@D@0R03mB
F010DU/0?e9J04EGH01;GFH0AeUS045CG@12E5h0?U1J03mAF`19FfD0DF=_05AVM01>H6h0B5YV04UK
I@1:GF<0BUeQ04YNH01?HVD0BUeQ04MJH01=H6L0D6=Z05AWK@1CIVd0E6M]05MZL01HJfh0EVY[05EY
J01IKF/0E6UT05=XH`80FVmX03h0Gfm/069bK`1[NgP0K7ai06YjM`1]OGX0L81m0761OP1bPWl0Lh>0
07J6P`1hR8D0Oh^;082<S022SXh0Qi6B08ZDUP2<UYP0Yjjd09BKX@2EW:80VYjW0:2T[@2Z[[L0Z:^e
0:f]^02`/;/0]KG00;Vg``2k^LD0_;[60;nkb032_//0al?@0<c6d`3=am@0dLWF0=C9e`3BamD0e<OH
0=c>g`3Re>D0imGX0>cHkP3^fO00l=Wa0??Kl`3dg?@0nN7j0?WRnP3jho/0o>Kl0?_Xo03mj_h0oNcn
0?k]o`3okol0oo3o0?oao`3om?l0o_Ko0?ofo`80ooOo0P3on?l0;`3omol0ooKo0?kfo`3nmOl0oOGn
0?oco@3ol?/0onkl0?o^o`3ojoh0o>Ol0?[TnP3hhOH0m=cb0?7IkP3[dnH0i/kO0=k:eP3Gb=00b;W1
0<bna@36^[h0bko10<6f]@2i/:/0YinG0:6IT@2SVi40V9:608B4LP1lOV/0MGQU07UlJP1mP6h0NWm]
07UoKP1mPg80I6YJ05aSE01]M6D0KgIX07AkL`1aN740NH1i079kL`1aNG80JgE]0080J7=[02@0HFeT
05YWGP1LJF00FfQO069_I@1BGeD0@e1704A?A`12CDD0>TDo03e6@@0a>SD0>44n03m5@`0m@d40>dA3
03e7B00`?3d0;3Ph034m?@0b?Sd0;3Pf02hj>00hA440<clk03Q4@00b?SX0;CTe02Te<@0Z=c80;STe
05QTH00`?3L0:C<]028/9`0P:282020Y8@0402D/9@0`=Rl0;34]02`_;P80:Rh]00l0:Rl^02X`;P0Q
:RL092h[02H`;00T;b/08bhZ02@^:P0S:2L092PW01dQ800K7ah09RXY01/O7P0O8b800P0S9bH2024U
9005028X900P:B007bTP01hX800P9R<00P0P9BP03`0g>ch0:2T]024R9P0O82408R@S01`N7@0P81h0
6a/I024Q7`0M7A/08B4O01/K6@0L71X06a/I01XJ600201/K6@0F01`L6P0L6aL061LC01`K5`0N7AT0
7A`H01PG4`0E510051<?01LF4P0O7QX06QTE01LF4P0J6AD06APD01LF4P0F5A405A@@01HE4@0E5100
6QTE01PG4`8051<?00D04a8>01DD400E510051<?018A3@02014@308051<?00@04A0<01@C3`0D4`l0
5A0=0P0G4@h0100F40d05@l<01D?300I4a0201<=2P0601PB3`0F40d050h;01<?300B3P/04@d:0P0B
3P/02@0C3``05Q8?014=2P0/:2D08alL00h:1`0A3@X03`/8010<2@02014=2P0E018>2`0C3``04Ph;
01hJ5`0<20D04Ph;014=2P0D40d05Ph;01<<1P0B2`D050l;01D@300B3@T061@A00`91`0W9R@0Ti:@
0::QW`0>3@/061<@00804@`900T04Pd:014<2@0D3``040/8018=2P0?2PL040/801PC400I51401P0@
2`P03P0E40d03@P501@?300@2`P03PT602@O700`:RX05Q0@014<300A2`/050h>010:2P0>20P03`T9
0P0@2PX05P0?2@T03PP800h91P0?2PL04`h;014<2P0=20D03`X7010;200B3@X05Q4>018=2P0G4Pl0
4@`905UFE@0S8Al02`T701hI600G4A4040X:0107200A1`P201882@0:0187200@1PL04`/<010:2P0;
1@D04@`<01`F5P0<1PH03`T900d71`8040X:00P03`T901<;300B20T03`D60147200E2``05`d>01@:
2`804@L80`0C2@X01`0G30l02@0201L<400B20/0304501@93@0C20`01@0A1PX03@0B2@/0;BLW01lI
6@0=1`L03@P801D?3`0>20P05a4A018<300H4Q803PP801D?3`0?1`P00P0B20T00`0D2P/05P`=01<9
2P0201061`804@L80P0B20T04P0=0`@06a4B02DK700C2@X0308301`B4`0h;Rl03@<401@:2`0<0`@0
50X;01<92@0@1P@060l:01071@090@004`/8030X9P8040/800/03PX800d9200<20L03@P801081P0>
10<04`T801L=300C2@P04@L600l5100200h40`0?00l5100A1`H04@L601<9200G3@`05@/:01471P0?
1@@04@L600l5100A1`H03`D401471P0D2PT03`D401Cooooo000Kooooo`0401@@3`0O6aX05Q8A00l;
2P804Ph=00l03PX900T5100b;Rd0GUYI014=300<20L01`<203lk>P0R7Qd02`L600X61@0S7ah030P7
014=300@30/00P0B3Pd04`0?2``03PT>00d83P0F4AD04@`@018>3`0P71d0=30`00d9200H51<040`;
00P40@0<20D04Ph=01<?3P0W8b806aLF01TE500<20L01@0B3Pd0500B3Pl05Q0E014;3`0@2P`05a8>
01TD3P0D3`T040/601/F4P0;1P<04@`>00h73P0<20T08alN01<?3P0D40l030P7014=300G4a804Ph=
0P0@30/04@0B3Pd0510?01DB300D4PH05Q<:01LD2`0D4PH081l=03Lg7@1hNET0/;6?06QYC00@3`00
5aD801PD3`0E4A00510?00<04`l>00<04@d<010<2`0A3@`00P0B3Pd0D`0A3@`05Q8B00@00@0H51D0
3PX;01HB4`0@30/04@d<01@@3`0B3P/04@d:01@@3@0D40`01`<200d9200H51<0510?028N7@0G4a80
4@d<01@@3`0H51<06ADD00L30P0C3`h06ADD01HB4@0@30/07QXI01XF5@0>2PT04Ph=01LC4P0C3`h0
3PX9018>3@0?2`X04Ph;00l;200@30T04Ph;01LC400R7Q/0510=01TE501:AT<0PGej01lK600920H0
1@T<01@I7@082a0010L<01<D6P0=318071/Q01LD600D40l07aXG01XE400J5a803a4@01@H6@0=4A80
8bLX03`o@00F61L08R@S010A3`0G5aD061PF024P700=30P04a8@01HE4`0N7A/00@0001PG5@0@3`d0
5A@B01@C4@0C4Q0051<A00805A@B00@03@d;01<C4@0D51804Q8@0P0?3`d0100J6QP08b<Q020P7P0K
6aT201PH5P0501TI5`0F5Q@051@B01<C4@0D51800P0E5A<201TI5`0701LG5@0F5Q@05aLE01PJ5`0J
71T07AlL01@F4`0401TK608061XG00D05aTF01LJ600G6aX061dI01XO6P0201XO6@0I01PM5`0`=Bl0
HfMV02L[;00D61/06QdT01/P900_>3L09Bh]01XS8P0B6aX072DT01DN7@0Z<c806b@S03m8A`0a>ST0
1Pl>02D];00M8b<07bDU024X:00R:bX0:S<b03@m?00202@^;@0602hi>00/>3H0;3Pg02<a=00U=3T0
:CPl0P0V=SH04@0Y?3X08S@d02`n?P0[?T40:Ca202@g?P0/?dP0=4M>03U<D`0bAD`0>4YF03U;E`0l
CUX0;d5=0353C`0gBE80>diD0080>diB02/0>diE03mAF`11Ded0@E=M04EGH@17FF<0B5YT04]MI`1:
G6H0BE]U04eOJ@1<GVP0BE]W04QJIP18FV@0BEaS04QKHP15F5`0B5]O04]NHP19G600BeiT055TJ`1?
HVT0BEaR055TJP1ML7H0G6mc05AWJP1AIFH0CV9Q059VI01IKF/0F6eX05I[IP1LKfT0GFeZ065aKP1[
NgP0K7ai06YjM`1^OW/0Kgml0080L81m03L0LX9o07B4P@1fQX<0Oh^;07b8R01kQhL0PH^<08RBU02<
UYP0VJ2V09:IW`2HWjD0XZJ_0:2T[@2OXj`0Z:^d0:b/]P2_[kT0]KFo0;Vg`P2j^<<0_K_60;nla`31
_/T0a<7<0<W3c`3:a=00c<CA0<k3d@3?a=80dlKG0=c>g`3Pd^<0i=?V0>WFk03[f>h0k]S_0?7Il@3b
f_80mmoi0?OQn03hh_T0n^Ck0?WVnP3kj?`0o>Wm0?cYo03nkOl0onko0?o_o`3olOl0oO?n0?oco`3o
m?l0ooGo0080ooCo03P0o_Co0?kboP3ml_h0o?;m0?gao@3nl?d0o^cj0?kYnP3njO/0o>Oj0?[Tn@3h
hOH0mMgc0?7JkP3/e>H0i/kN0>38eP3C_l`0c;o90<:e_`37^/80_K:f0<Bj^`2j/:h0/:VQ0:FOU02Q
Vhl0VI>507ahJ01mOfX0N7]V07MjI`1oPW40PHEd07]oL01lPW@0MG]_07EkL01OIe`0IfiV06YaJ@1f
OGH0Nh9k07ElM@1_NG40LWad06QcJ`1OJV80HFaT05i[HP1HIE`0EfAK055NE@16DdT0?4To03M4>`80
?DQ000@0>D@n03Dn>@0f?cX0>44n0P0d>SP0;00mATD0>dE602lk?00X=3@0:cLg02lk>P0]>CL0F6AR
04eIEP0b?SX0<Cdi02lk=`0`?3P09c8^02Td<00N:BD0;cXf02lh=00Q:RD09bdY02@[9@0S:R<082DO
020U7P0Y;RP0;34]02/_;P0Y;B`09bd[02D[:@0T:RP07bPU02D^:`0Y<Rl09S4]028]:@0P:BH07R<R
028V9@0X;2/07R8Q02HZ:@0I7A`08RHU0P0U:BP202<W9P0D02<Y9@0S;2@08R`T024Z9@0Q9bH07R<V
01dR9@0]<C@08R<W01lP8P0P8R408B<R01`N7@0O7ad06ATG01lO7@0M7A/08b<Q01dM6`0K6aT301XJ
60806a/I00H05QDA01`K5`0K6QH05aHB01HE4@0H5a<201`K5`0401DD400F5A4061LC01LF4P8051<?
00/05A@@01@C3`0B4@d05aHB01DD400I61@061LC00/:1P0D4`l06QTE01DD400201@C3`804a8>0P0D
4`l01@0A40`03Pd900l>2P0@3`/0514=00805Q4>01D05A0=01@?300D3``05A0=018=2P0C3P/050l<
010;200B3@X05A4>01@@3@0B3P/040`9014=2P0C3``030P502DQ7P0@30X02`L401DA3P0B3P/00P0@
30T3014=2P0K018>2`0O6aP01@4001LC40070`002PH300`91@0C2`P050d701D>200A30P040/7018=
2@091@804a0>018A3`0J6AL06APF00/:200?2PL040/801HA3P0E40d03`X700h91P0@2`P04Pd:0080
3@P500<04Pd:010;200A30T01@0A30T03P0D3``03@P5018=2P0D3``03PT6014<2@0F410030H605I@
D00L5QH05Q0@01LA4@0>20P03`T90P0@2PX01P0?2@T03PP801<>2`0L5a@02`H300l:1`8061<@00d0
4@`901<>2`0D3``03`X7014<2@0;1P<03@T900/71P0810<03PT9014;2`0K5AD040L800804@P900/0
4PP90147200@1`P03`T900h8200B30`02@<300d71`0>20P030H600h82002010:2P0800h8200@20T0
40H700l51P0B20T05`d>01T?400E2``20147200<01<92P0D2P/050X;01@:300>0`L02`0401X?4`0;
00@06@hB00l4200@1@T04@H:0P0C20`04`0D2@d03@D702LQ8@0G4A404@/;00L10@0B30`020<301H@
400?2@T04@/;00P20P0>20P040T901D;300c:BX0BT1101T?400?1PL00P0@1PL2014720804PP900l0
308300d3100?1@H04`T:01L=3P0L4Q<081HG00L0000@1PL01`0001@:2`0<0P803`D301D<1`0B20H0
0P0<10400`0G3`d03PT600h91P0300d9200I00h92@0A20T04@L601881`0C2@P04@L600h40`0@1PD0
3`D400`20@0;0@003`D401D;2P0<0P4050X901D;2P0@1PD03`D401D;2P0=0`804PP700d30P0?1@@0
5@/:00d30P0Dooooo`006oooool04`0@30/0510?018>3@0A3@`05A4@01PD4`0B3Pd05A4A00d9200O
6aX03PX9018>3@0D40l07a/J010<2`0<20L03``;00T5100;1`H00P0A3@`2018>3@0C00h:2`0E41H0
71LN01<>500=20h050lC01HB4`0I5AH02PH5018>3@0D40d06ADB01HB3`0<2@P05Q8A07mkNP18A4<0
0`0001LC4P05018>3@0D018>3`0H4aP01@0500`62P0H4Q405A0=00`70`0E40d020<000d71`0C3A80
9b0W020K7`1=BDP07QXI00h:2@0J5QD040`;00/71`0B3Pd2014=300?018>3@0C3`h071PB01HD200A
3PD05a@=01DB2@0H5PT061L6024Q1@1;C2d0>3PO014?000K60l0510<00<0510?00H04`l>018>3@0@
30/040`;014=300C3`h2018>3@0N01DA400@30/0510?014=300I5A@05a<B010<2`0D40l04`l>018>
2`0D40d04Ph;02@P7`0>2PT0510?03di>01IEE@06QHE01LC4P0D40l040`;00h:2@091@@06QHE00@0
000:1PD03@T801LC4P0D40l05A4@0`0A3@`2010<2`0U00l;2P0?2`P04Ph;014=2P0?2`P05a<@01XF
4`0O6aP030P5010<2@0e<Bh030P701LG5`0:3a<03A@J01/R:00P9B/05QTQ014A6@2DTiT0BDI:00`8
1`0B3@X04`d8018?2P0?4a804AHI01`Q901WK6l0UY^K02/_<00I7Ah04A@C01`N7@082PT01`L601/K
6@0201HE4`0401LF50071P@051<A01DD4PH051<A00l05QHD01/K6@0M7A/06a/I01HF500D5180:b/Y
01XJ600<30X04a<A01DE4`061P@05QHD01TI5`0G5aD00P0C4a40100F5Q@04A4?01PH5P0J6QP301PH
5P0501LI5P0I6aP071hK01@F4`0K7AX00`0L7Q/0600K7AX06Q`I01XL6@0I71X05a/J01LL600I7QT0
6QlI01/P6P0G71H08bPR03a0?`0L82402`lB01DH7`0O92P092d/01DN7@0G81l07BHU02`e=00F7ah0
4a`K01`U9080;SLf03<092d/01dU8`0O9B<082HT02@[:@0U;R/0;cPe04YDD@1@FeL0?4M302hi=@0/
>3@09c<a02Dc=P0[>Sl0;Ci102@f=P0Q<c<0:C`j02Dg=`0]?cl0<dE802Hg?P0[?T@0<TE<03E8C`0d
Add0<TE<03=5D@0nD5`0>D]I03E7D`0gBED0>diF03iAE`0oDUH0?e9G03e?F@0mCe/0>TaH03a>F013
EEl0@UAN04]MI`1>H6X0BUeT04IIH018Ff80AUQQ04]MI`18FV@00P17FV406P14Eed0?e9H04EHGP17
FV00BEaR04mRJ@1EJ6l0CV5X04]LH`1CIFT0GFmc05U[K`1CIFP0FF]]06]mO@1GJVT0FVe[05e`KP1F
JFD0GG1/069bL@1SLg80JGUh06YjN@1/O7/0Lh>20`1aPH00301cPh80MHF407N7QP22SXh0Oh^;07f9
R@21Rh`0QHnA08RBU02AV9h0VZ6W09bSZ@80XjN`00/0Wj>/0:NZ/`2/[;H0[jni0;Bd_P2h]/40^[S3
0;jla`30_LP0`[o:0<C1c0020<O1c@0<0<W1cP37_l`0b/;?0=C9f@3Kc]l0g]3Q0>;Ai03We>X0jMK/
0>gGkP3_fO00lM_b0P3fgoT03P3hhO/0n^Ck0?_Uo03li_`0nnSl0?cYo@3njoh0onco0?o]o`3okol0
oO7o0?oao`3ol_l0oo?o0P3ol_l0Q03mlOl0o_3o0?g`o`3ll?h0oNon0?k/nP3mj?L0nnCf0?[SmP3i
h_H0n>3f0?KNm03bf_00kMKZ0>S@h@3QbML0g<CB0=:oc03<_//0`KBn0<Nl``31][X0aK^l0;:ZYP2[
Y9`0Y9jC09REQ02?S7T0NGMT07AfH@1fNF@0Nh1/07n3LP21QG@0Q8Uj07j4N01mPgT0Z[6X08B;Q01g
OWL0LgYc07R1O01eOWT0KGIa07=lM`1_N7<0IG1Z061[I@1QKVL0GV]T05ETG@1DHe`0CUeE04QEB`10
CD<0?DY1049=A@11C4@0@Da603M0>`0mAT40>D8o03Dk>@0l@T00@T]:03U3A00c?d00<3`l034m?@0b
?Sd0<Cdk04QDDP0oBdP0:3@`02Te<@0W<bl09S8^01DP700Q:RL0>T=001HO700c>CH0;38^02L/:00X
;BP09b`V02@V8@0O8Q`09BXT02T^:P0X;R`09R`Z02D[:@0S:BL08BLU02H/:P0Y<2h0:C8_02L`;@0T
;BX08b`Y02T^;@0H71/08bLV01hR8@0/<2l082@S02HZ:@0W:bX092PW01lS8P0L81l06b4M024Z8P0Q
:RD082TT020V9@0M8RD0724T01dQ900J6ad06a`N01hP7`0M7a`06adJ020P7P0I6AL07alM01dM6`0U
9B<0820N01lO7@<07AdK00D07QhL01lO7@0K6QH07A`H01/J5P0201PG4`0901XI5@0L6aL06aXF01DD
400G5Q8061LC01HE4@0E51005QDA00806QTE00P05QDA018A3@0=30P04Q4=01<B3P0=30P040l;014@
30804a8>100D4`l01P0C4Ph04Q4=018A3@0A40`04Q4=01DB3P805Q4>00H05A0=01@?300D3``050l<
01<>2`0D3``2018=2P0401lJ5`0G4a005A4>018>2`803`/800L04@d:03Pd<@1EDDh0510=00h:1`0L
61D030P500804Ph;0`0A3@X02`0@30T04`l<00H2000F4Pl02`L402/W900c<2`05@d:01D>200D3@L0
4@`8008040/700h05Q8?00`91`0E51804A0>01TH5P0R8Al050l<014<2@0D3``04`h;010;200C3P/0
3`X7014<2@803@P500<03`X700`7100A30T01@0A30T03P0B3@X04`h;01@?300D3``04Pd:010;200@
2PX04`d=03D_;`0G4A40@cdm00`61P0>20P03`T90P0@2PX04P0?2@T03PP800`7100?2PL02`H300`7
100=20D030L4014<2@0C3P/050l<00l:1`0A30T02`H300d8200N61P091hN010:2P80100000@03`T9
01892P0B2@X04PT:0P0A20T00`0?2@T01P0001D?3`0301<=3@0300d71`0>20P03@L700803`T900@0
40P801061`0?1@H04PP91@0D2P/02P0C2@X04PP901882@0<10@0<bP/00L0000;00@03P<701L<400D
2@d401462P0C01872`0A20X03PP800@0000f<3003PP8014;2`0H4Q807aTI018<300=1`L030H601XD
500E3@d01`0001lE5P0Y7b0050X;0147200201061`804@L80P0B20T03@0?1@H03P@50147200H3Pl0
5P`=00/20`0D2P/0;R@U01P>3`0700003`D601T?3`0@1P@00P0B20H00`0?1`D030@200/30P0200`6
1P0900d9200=2@X03PX;010;2`0B2@X04`T801471P0?1@@040H500803`D400P04@L600l5100=0`80
3`D401<9200?1@@040H501471P804PP700L04@L600h40`0D2PT03P@301061@0G3@`03@<201Cooooo
000Kooooo`0f01<?3P0A3@`05A4@01DA400@30/04@d<02/W9P0e<C004Ph=00T51@0E4A003PX901/G
5P0B3Pd04`l>00d9200@30/04Ph=00/71P0B3Pd040`;014=300B3Pd040`=04M2BP1oNX407APO014<
4`0F4AL02`H:00d92P0H51<03`/:01@@3@0?2`P02`L4018>3@0@30/071PG01PD4`0C3`h03@T801<?
3P0B3Pd03@T8014=300J5QD04Ph?02LP:00I4QT071DK01hH6P0G4A803`X80P0C3@h08P0F41<04P`B
01D>5P0B31009B4P00h:2@0?2`X05Q8A00/71P0D40l04Ph=014=300?2`X0510?02DQ800Y9R408QlH
00h:1`0E4A404`l?010<200H5@T04a8401`K200M6`/05A<:01PE4P0D40l02`P701DA400F4Q403`/:
01LC4P0@30/2018>3@0<01@@3`0E4A004`l>00l;2P0J5Q@03PX801dI601>BTT0CDU8018>3@0D40l0
4`l>0P0B3P`02@0A3@/040`;01`H5`0@30/061@C01`H5`0A3@`03PX901DA4002014=300601TE500H
51<0510?01PD4`0C3`h04@d<0`0C3`h0<@0A3@`04`l>01@@3`0B3Pd04`l>00l;200D40d05A4>01@@
3@0G4a00510=014=2P0H51405A4>010<2@0F4Pl04A4A00`A5@0I8RT0VJ:Y0:nc^`0O8R/05APO02TX
<00J5a`05A4@01XE4P0F40/06AHA00lC500B61/0:2d`08jCUP35b//0=CTj01LK700A51@03Q0?01/M
700E5Q@04A4?01TH5P0D4a402PT701hM6`0@3`d05aHD01TH5P0C4Q000P0D4a4201<B400A01@D4P0A
4@l0410>01LG5@0L71X06a/I024Q7`0G5aD06QXH01LG5@0F5Q@04a<A01@D4P0G5aD05ADC01<C4@0E
5A<00P0G5aD0300H61H05QHD01DE4`0I6AL07AdK01DG500N81d06A/H02T[:00F61D03a4>01XL6@80
6A/H0P0H6QL03P0J7A/051PG038g<`0E6QD07b@N01LL5P0M8Q`05a`F00X<2`0P92D07R8U01XM900L
8BD0624P0P0G81l0A`0M9RD0:C8a01DN7@0N9bH07BHU01lX9`0R:bX0:c@c028Z:00V;2X092XX02Xb
;`0V;b`0>D8o09ZTX@3Fgmd0[;Nc04eHE00hA400:SLe02ho@`0cA4/0>4Y?02Xl?P0Q<c<09cTi02/n
?@0Z?C`0;d5202Xl@00b@dT0=4E=03=6C00^@DL0=4M>02m1C@0gBED0=DME03I8E@0gBED0>deH03e@
F00nDEL0?U5H04EGHP10DUl0@E=O04AFHP0mCeX0AUQR04IIH@0jC5D0?e9I04AGGP15F5h0AeYP04AG
GP15F5l0@eIM04EHG`18Ff80AUUP04AGGP16FF00BeiT051SJP1CIVd0DFAZ05EWJ`1EIfX0EfU/0080
E6IY03`0GFma07B6QP1MKfl0DfIU05Q[J@1LKfd0GW5^06QhM`1WMgL0J7Qh06YjN@1]OGd0M8B30761
P@1cPh80Lh>307B4P`1fQXH0NHV907b8R01nRXX0P8b<08RBT`2>V9X0TI^M09NNY02TZk40WjJ/0:2T
[@2UZK80XjN`0:JY/@2/[;D0[jnh0;>c_02h]/00^KS10;fla@32_lT0`l3:0<:ob@32_<L0`kg80<Fn
bP37_l`0c<CA0=G:fP3JcMh0g<oP0=o?hP3UdnT0imG[0>_Gk@3]fNl0km[a0?GNn@3fgoX0mn3j0?[S
o@3li_d20?cVo0090?gWo03njOd0o^[n0?o[o`3okOl0o^ko0?o]o`3okol0oo3o0080onoo06H0o^ko
0?o]oP3nkOh0nncl0?cZn`3mjOT0nnCd0?OPlP3fgo80mMkb0?CLlP3`fNh0kMOZ0>WCi03QbmX0f/G@
0=K0b`3Ea<l0dlSC0<RmaP38_/H0_kJi0;J][P2WXI`0Xj2D09RFR02<RWP0QHIa07n1J`1eN6<0OH5/
08:7M01iOfh0Mga]07QnL@1lPgP0KgI/08jESP1hP7/0L7Qc07MoN`1cO7L0JG9]06A^J@1]Mg80IW5[
065]IP1RKfP0IG9[05aZH`1FIEh0E6=L055PF01:Edh0@Di403M4>`0kASh0=T4i03Q3?@0oB4<0<3Td
02lh=@11AdD0>3hl03@m?00jA4D0<cm003I2@P0hA4@0=D50038n?00_>cT0=40m02lk=`0`?3P0;3Pd
02Te<@0lAD807RLT02H_;00_=C<0<3Hc02`b;P0Q9R809R/V02<X8P0W:B@092LQ02@Y8`0U:bL09Rh[
02D]:P0S:RP08BPV024W9@0Y;bd0:S4^02Xb;`0W;R`08RTW02<Y9`0`=3<201`P7`0@01dQ800T:2L0
8BDT024U900S9bH09RXY02DY:00S9bH08bTW024Y900O:2@07RLT020V9P0R9bX07B8U01hR9@807b0R
00d0828P01dO700Z;2P07alM01TI5`0K6aT07AdK024Q7`0N7Q`0820N01lO7@0K6aT06ATG00806QXH
00X06aXF01TH500H5a<061LC01LF4P0I61@06aXF01XI5@0I61@06aXF0P0I61@0100K6QH061LC01hM
6@0M71P201HE4@805A@@00D051<?01PG4`0I61@04a8>014@3002018A3@8051<?0`0C4Ph0:P0F5A40
51<?018A3@0E4Pl05Q8?01<?300G4Pl040/801HA3P0D40d040/801@?300I5A805A0=02HQ7P0J5Q<0
4`l<01@@3@0=2@H04`l<01@@3@1>BTL0EU9?018>2`0A3@X04Ph;00`81@0B3P/04@d:010<2@0B3P/0
5Q8?01<?300I5A807QXG018>2`0D40d0;BTV03@`;00G3``05@h801@=1`804Pd900l03`X600h:1`0@
3P/06APF00h=2`0C4Q002`X801D@3@0@2`P03PT6010;200E40d07APE00h91P0A30T00P0@2`P0=P0B
3@X040/802/V8`0M61D02`H501@?300A30T050l<00`7100C3P/04@`900h91P0@2`P04@`902HP800A
2`/050h>018<300E3`l02`D500h8200@2PX04`d=014;2`0?2@T04@/;01<>2`0:1@804Pd:00l:200@
2`P03`X7010;200A30T04Pd:00l:1`0A30T03PT6014:2P0<10D03@D601092@0A2`/03PP802DO7`0P
61T08ATJ01@=3@0@2@T030D500`61P0?2@T040X:00d71`8040X:00X03`T9010:2P0=1`L03`T9010:
2P0@20T04@L801061`0B20T04`T:0P0D2P/201D;300;01882@0A1`P04`T:030U:028OH40:1dQ01D:
3P0>1@L04@H:01<8300B1`/00P0A1PX201052@0D01482P0=1`L0100002XT900?2PX03@L700h92@0?
2@T03@L7014;2`0<1PH040X:00`41@0E2``09Q`M00d51@0A1`P04PP900l51P0A1`P201882@0301@:
2`0B20T04PP9008050X;0P0>10D02P0D2P/0:AlP03T_<00?1PH040H701@:2`0B20T050X901471P0@
1PD201081P0@018:2@0J51@02`D500h:2P0@2`h04Ph@014<3P0A20T04`T801471P0?1@@04@L601<9
200;0P404PP700l510804@L600@040H501471P0=0`803P@30P0B20L01`0=10@03`D401@:2@0;0`80
5`d<02/Q800A1`H05?ooool001_ooooo01003@T801`H5`0U8B007ATH01TE500Y9B@05Q8A01`H5`0<
20L040`;014=300?2`X03PX900T5100?2`X04Ph=0P0@30/06@0<20L04`l>010<2`0?2`X04Ph=014=
3P13?TD0FEAK00T42P0B3A<03@P<024M7P0G4a@06aLF01@@3`070`406QHC01@@3@17@d801P8101<?
3P0<20L08QhM020L6`0@30/00P0?2`X01`0K5aH0:BDT01TE5P0C31<04P/B018<400C3A400P0D3Q00
1P0@2P`03`T=00l93@0B2a805PlF01LB5P802`L601L040`;024M700@30/04@d<01<?3P0D40l06ADD
02<O7P12?Sd09B4O010<2@0810D05A0F01<>5@0B3A<05Q<A01DB2@0F4`X05Q<<01DA400D3aD05Q8E
00d92003010<2`0401PD4`0C3`h04Ph=010<2`804@d<00P040`;01PD4P0?2`P04Ph;00d9200D40l0
9b<R01<?3P804Ph=0P0A3@`02`0B3Pd02`L6010<2`0B3Pd0510?00<0000D40l04`l>018>3@0A3@`0
4`l>00805A4@0`0C3`h00`0O6aX06ADD00l;2P0301DA400:01@@3`0C3`h04`l>01<?300E4@h061@A
01TE4P0G4a005A4>01<?30804Ph;02X0510=01DA3P0@41008RL[00lF701bNGl0OX>901`O9`082100
4Q4G010=4@0E4A005A0=01@>2@0H5A001@T801XO8P0=4QD08BHY0497A`0F6Q/04ADF010C4P0A4a80
4aDD01DE4`0B4Q004A0>018A3`0O7Q`0:RTW01<B400D4a407A`J01@C4@0E518051<A018A3`0A40h0
5QHD01TI5`0E5A<201HF50804Q8@00/05ADC01PH5P0C4a405QHD010@3P0D51804A4?01@D4P0K6aT0
5QHD00h>300201LG5@0=01DE4`0D51805aLE01/K6@0B51408B<P020R7`10@Sl071hK01/M6P0H6QL0
5aTF01HH5@0201LI5P0Z01/N700n@T40Y:VU02<X8`0@5@l0:2dW01DJ500M8Q`0;30_01hR8`0C5aX0
;2lf01`Q9@0P:BP0624P01dV9@0I8R405QlN024Z:@1kQ8<0[kRg07R1P00b>cX0;cPg02P_;P0/<S00
728P02T`;P0d?CX0C5EB0;6k]`3`noL0/;^g03U5@@0/>3@0:cPf01//<`0gBU40AEIM02m1A@0R=3H0
;Clo0P0[?S`01`0]?cl0;T1202m1A@0b@DP0=DI=02i1A`0gBU400P0cAE403@0iBeT0>TaJ03]=F`0n
D5d0?e5M03i@FP0kCEL0@UAR03]=F`13EF<0CV1/049DH019FfD00P0kCUD0200oDUP0BUeS045DFP0m
D5H0?e9H04AGG@13EU`0A5MN0P1;GVD01`17FV40EFQ_05EXK`1EJ6l0F6]b051SJ@1FJ6`00`1FJ6X0
3`1EIfT0E6IX055SH`1GJFT0EFMW05a_K@1XNgT0H7=a06QhN01YNGT0JWYj06alO01^OWh0Kgmo0761
P@0307>3P`0T07N7Q`1kRh/0PHf=08>?S`26TY80SINH096KW@2CWIl0Vj:X0:B[/@2QZ:h0XJF^0:>W
/02QYJh0YZV`0:f]]@2`/;P0/k>k0;Nf_P2j^L40^k[20<6na`32_lP0_kc50<2ja031^lD0`kg90<[2
c`3>a]<0dlSH0=S;g03Kc]l0gm3S0>?Ai`3UdnT0j]O]0P3[f>h01`3`fOD0lmch0?GNnP3gh?X0n>7k
0?WSnP3kiO`00P3ni_`01@3miO/0onOm0?oZoP3mj_d0o^_n00@0onco0P3njoh06`3mj_d0n^Oj0?WV
n@3jiOL0nN;b0?GNl03cg>l0lM[^0>oGk@3ZeNP0i]7R0>7<f`3Ia]80d/790<jm``3:_<D0akg60<Bj
``2n]K/0][2b0;6/Z@2VXid0Ti6508Z:N`2BTh40U9J108>5L00207n4L01[07b0K`1`MfL0Jg9R06Q^
H@1]MFX0JW9W07AkL`1WLFT0HfaW06YcKP1aNWD0JW=^069]I`1SKVP0IG1Z065^I`1PKFH0JGI_06=b
J`1OKVL0EFAM04mNE`0f@cX0?T]103m<@`0/=bl0:C@/03<n>00j@ch0:34/03M0?@1DFUP0>Clm03<l
>`0a>c`0;STj03A0@00hA4@0=40o02lk>@0hA480<3`i02lk=`0d@3`0<clk02Pd<00[=S80:C8_02df
<`0W<2d0;38_028X900V:bL09b`W01dR700W:B@0:2/U02@Y8`0Z<2`0:c@a02Pa;P0T;BX08RXW02@Z
:00Q9bD0:2h/02`b<00T:RP06R0N020V900Q9B@092PW01TM700H71/05QXI01lS8P0R9RD08BDT02DY
:00T:2L08BDT028X9P0T:bL06R<P02H_;00[<C40=3Tl01PM800R9RT08B8T01lQ800O8Ad0D59=09fO
VP0S8b407QhL01dM6`0O7ad07AdK01/K6@0O7ad0820N01XJ600H61H06QXH01TI5`0H5a<00P0I61@2
01LF4P805QDA00/061LC01TH500H5a<05QDA014@300C4Ph04A0<018A3@0D4`l040l;01DD400201@C
3`0401DD400F5A405QDA01@C3`804a8>00<04Q4=01HE4@0F5A400`0A40`2018A3@07014@300@3@X0
40`901XF4`0Y9B8071PE00`81@0201@@3@0B020L6@0T81d05A4>01<?300>2PL02`L401TE4P0A3@X0
:2@Q01DA3P0F4Pl03PX701TE4P0@30T03PX701HB3`0?2`P04Ph;0P0?2`P02@0E4@h0510=00P40@0I
5A803PX7018>2`0>2PL04`l;01D=2P0201@=1`804Pd900d04@`800P40@0B3`d03Pd;00`;2@0I61H0
30/901@?300A30T03`X7010;200E40d06A@A00H040/800D02`H3014<2@0[9R<04Pd:00T50`0200h9
1P0G01@?300C3P/03`X700l:1`0D3``04`d=00l92@0:10@02`D5010:2P0A2`/03`T900/51@0>20P0
40X:00l92@0A2`/0?cXg02@O7004000040/800l:1`0A30T01P0>2@H401482@803`T900X04`d=059<
C01;ADD02`H600L10@0Q6a/040X:00l92@0>20P03`T90P0@2PX03P0>20P040X:00h8200@2PX04@/;
01492P0B20T04@L801061`0A1`P04`T:01882@0A1`P04PP90P0@1PL01`0D2P/05@/=03P]<@0B1`/0
4@P:00h31`0C20`01P0A1PX03`0H3a406A<C00l92@0>20P0>38b018<30040000208205I@D01`JVX0
40X:00T30`0?1`L040H701882@0201<92P0601882@0A1`P05@/<01D;300B20T04`T:0P0@1PL01P0C
2@X05P`=01061`0>10D04@L801<92P804PP90`0@1PL201881`0;01471P0=1@<03PH401892P050000
6aDE03<_<00d;c<06aHJ00X51`0?1PL00P0@1PD02@0A1`H04`T801@:2@0F30/05@/:00l5100>10<0
40H500d30P0300l510<040H500H04PP700h40`07000040H501T?3P07000Dooooo`006oooool03P0B
3Pd04@d<018>3@0@30/03@T800l;2P0=2@P04@d<010<2`0F4Q403`/:01<?3P0D40l04`l>0P0E4A00
100A3@`03`/:00l;2P0D40l2010<2`0N018>3@0@30`0?STl01`H6`0B3Q004`h@00T51@0G4a<0K6QW
05IBD@0:1PH05Q8A014=2P0=2@H0AD5000/81`0I5A@0:2@S00l;2P0A3Pd04Ph=00l;2P0C3`h05Q8A
01@@3`0>2PX04P`?014;3`0A2`h04`d?0P0E3a408`0I4aD050h@010:300?2@`04@/?010;300?2`X0
8QhM00l;2P0E4A004`l>018>3@0=2@P03`/:018>3@0?2`X07ATH014=2`0B3P`0510B01<>5P0B31P0
4`dG01D@4`0D40`04a0;01@@3P0E41@05a4J01@?4`0J5QD04@d<01@@3`0K5aH04@d<00<04`l>00`0
3`/:00h:2@0A3@`03`/801XG4P0F4Pl03PX701DA3P0P71/04`l>018>3@0B3Pl201<?400C01DA4P0H
51<03`/:01TE500B3Pd04`l>018>3@0E4A004`l>014=300C3`h0510?01<?3P0<20L06QHE01@@3`0B
3Pd03PX:044m?002014=3004018>3@0C3`h04`l>01@@3`805Q8?00D05a<@01HB3`0D40d04Ph;01@@
3@02018>2`1701@@3@0E4@h04A0>00l?4@0?4QD03a4D01lP9@0E5AX04Q4F01DD6@0C41<0510?01H@
3`0G4Pd06AHA01<E500@51D03Q8B00lC500C5AH05aTG01LH5P0B4a40410=018A3P0D4`l04a8>01PG
5@0J6AL020L601@C4@0C4Q005aHD01HE4`0@3`d051<A01HE4`0E51804a8@01DE4`0I6AL05ADC014A
3`0D51805QHD01LG5@0L71X05aLE01TI5`0U9B<06ATG01DE4`0G5aD061PF01DE4`0F5Q@06QXH01TI
5`0H61H05QHD01DE4`0F5Q@061PF01XL6@0I6aP071hK02DW900B51407AlL01XL6@0I6aP00P0H6QL0
E`0I6aP071lM00hB4@0X;BT05Q/F028W8@0C6180724K01dR700G6aX08bLX014E600L7bH0>Sm3045:
B@0K92<0<3Th02Tb<@0=5QD08BXY06mhM`1IHV40:S<b01hW9P0I8R409Bd/020V9P0T:R/0:2l_02hg
=P0i@D80CEIF07=mO01PJVX0<Sdl02`h=P0Z=cL0@5=J0;;6cP2HZk80:Ca102@h>@0/?Sl0:chl02`o
?@0`@400<T5403=2A@0e@dT0=TQ<02m2A`0hBe80=4IA03A6DP0jC5X0>T]K03a=G00oDEl0@E=P041B
G@0nD5/0<D9A03Q9F@0nD5l0@59P03i@G@0nD5/0>4]B069eO014Eed0A5ML03iAE@12EEP0?U9D04QK
GP18Ff00AeYP04ePJ01@HV`0BUaW05AVL@1>H6X0CV1Y05IYL01@HfT0Ff]^05UYJ@0205IVIP0?05QX
J01IJFT0EFEU05a/K01NKVh0IGEe06]kN`1QLG40IgMg06QhN01[Ng/0KGem0720P01aPH40LX:200<0
Lh>300H0N8R807j>SP1nRXX0PXj>08NCT`2<UYL208jHVP0;09JMX`2LXjT0VZ6W09bPZ@2NXZ/0X:B]
0:JY/02^[[H0/K6i0;>c^`2h]kl00P2k^/830;fj``1<0<6ka@33_LL0a;k:0<W3c`3<a]80dLWH0=K;
f`3HcMd0gLoR0>7@iP3Td^P0imG[0>[Gk@3Ze^h0kMWd0??Ln03fgo/0n>7l0?SPnP3ggoP0n^;j0?cR
n`3lhoX0o>?i0?kUn`3oio`0oNOl0?kWo03niod0o^Sm0?oXo@3oj?h0onWn0?oXo@3mio`0n^Ci0?WR
m`3gh_D0m=o`0?;MkP3`fnd0k=S[0>WEj03SdN<0fl[H0=K5d@3Ca<`0cL330<Rj_P33^Kd0`;Vo0;bf
^`2e[k40[j^Y0;2/Z02TXi/0U9B808j?P029RgX0PhIb07UmJ@1oQG80M7]Y07MnKP1nQGD0Mgi^07R0
L@1eOG00MGea06miK`1JI5X0G6IM061/I01XLfd0IG1/065/J080H6aX01D0Gf]W05]ZI@1OKVT0E6=N
055RG01CI5h0HW=/0:NdZ`1BGeD0=44h03Q3>`0Y=2`0;STc03Ho>P0/=C00;SLd03a2@00b>3H0:S<b
02Pb<`0]>CX00P0[=cL0600b?Sd0=40n03<o?@0^>SL0;CTe02lk=`0c?c/0>4A003U4@00a?3P0<3/g
02Pc;`0Z=2l09RlZ02P`:`0U;2H072<L02P^9`0Z;bT0:2lX02La;00V<Bd08bhZ024Z9`807RLT00l0
7B<Q02D[:@0X;R`082@S01PL6`0O8b8061`K024U900L81l07b<R01/O7P0U:BP08bLV024U900R9RD0
0P0Q9B@03P0T:RP07RHS01hW900P:BL07R<U02<X:`0O92L07b<V01`M7`0K7A/092HQ028T7P0V:280
7AdJ0P0K6aT02@0M7A/07QhL01hN700J6QP071`J01PH5P0I6AL071`J01XJ600301PG4`0;01LF4P0F
5A405A@@01HE4@0H5a<06QTE01PG4`0F5A406APD02/Z9P0U92000P0F5A40100B4@d04a8>01@C3`0D
4`l301DD400401@C3`0C4Ph04a8>018A3@805QDA0P0C4Ph0:@0B4@d04A0<010?2`0A40`05QDA01PG
4`0C4Ph0;B`X09BCS`0j>CD05aHB01HE4@0@3`/020L4010?2`0A40`03``:01XF4`0B3``07a/H06aX
I@0/:2D04@h<010<2@0?2`P0=C4^018>2`0A3@/03PX7014=2P0C3``04Ph;01<?300B3P/05a<@02/W
900F4Pl04`l<014=2P0C3`/04`/800804``60P0B3@T02@0C3PX05Q8?00`:1`0A40h05aHD03ln?00>
3@`04Pd:014<2@0200l:1`P040/800L04Pd:01D@3@12?CX05A0>014=2P0?2PT03`X700804`h;0P0@
2`P00`0C3P/03PP801<=3@0200/51@0401<=3@0?2@T06Q@D014;2`8040X:00P03@L700h8200W8Ql0
3`X903Lb;`0P6aP040/8014<2@D03PT600@03`T601882@0B20T04PP90`0A20T02P0?2PX05@l?00h9
2@0C3`h02PH500h:2@0A2`/040X:00l92@0@2PX2014;2`0>00l92@0@2PX030H600h8200?2@T04PX:
01H<3@0C2@X04PP901061`0A1`P04PP901<92P0B20T201061`070147200B2@X040D901D:3P0B1`/0
5@X>00`11@0601462P0=01482P0<1`L04`d=00h82014?Sh05Q4A010;2`0<1PH0=c4a051:BP0H4Q80
3@L700h71`020147200A01882@0E2``05`d>01L=3P0I3a005@/<0147200B20T040H701882@0D2P/0
5P`=0147200>10D040H700l51P0@1PL00`0A1`P0100B20T04PP701881`0B20L200h51P0801892P0<
1PP03@L903@_<`2:QHT0:RDY00l9300@1`P201471P0:01881`0D2PT05@/:01P>3@0?1`H04@L600X0
000@1PD050X901881`@04@L600L040H500h40`0;0@404`T801471P0;0P405P`;01Cooooo000Koooo
o`0b018>3@0<20L03`/:01TE500K5aH040`;01HB4@0D40l03`/:01@@3`0<20L04`l>00X61@0?2`X0
4@d<018>3@0D40l04`l>00h:2@0A3@`03`/:018>3@0E4A004Ph=01DA3P0R7Q/0510=018>2`0H5140
2PH301dI5P0D40l04Ph=00`81`0L61L06QHE01@@3`0B3Pd01`<201dI600300003PX9010<2`0A3@`0
510?014=300>2PT05Q8A01@>3P0B30h5014;3@0>018<3P0C3@l050h?01D?4@0B3@d07ATH03`h=`0E
4A002`L601@@3`0H51<03@T801<?3P0G4a8201@@3`0>01<@2`0C40T04Ph=00d83P0D3aH061<J01@@
4@0B3`X04@h7018?2`0E4A805a8I01D@500B3Pd201<?3P0301DA400B3Pd03`/:00804`l>00T03`/:
00d9200A3@`05Q8?01PE400@3@P06QHC01HB3`0>2PL00P0B3Pd01`0B3Pl04`hB01@?4`0F4A@03PX9
01@@3`0>2PT00P0I5A@03@0A3@`0510?018>3@0@30/04Ph=01<?3P0B3Pd061@C01XF5@0@30/04Ph=
00L30P0K5aH00`0B3Pd301<?3P<0510=00H04Ph;010<2@0?2`P0510=01<?300B3P/201@@3@0S018>
2`0C4Q005A<C01HD5@071@P0QhF802<N8P0D3a<04`hA018>3@0E4A005a<?014@300;2`T04A<B01PJ
5`0D5QD04A4?01HG4P0H5a<04a8>018?2P0C40/05A8=01DA3P0G5Q@08R4O018A3`0g=S@05aHD00h=
2`0H5aD03Pd;014@3P0D4a400P0G5Q@04`0D51804Q8@01<C4@0D51804a<A01@D4P0E5A<06ATG014A
3`0E5A<092@R01LG5@0E5A<03@d;01HF500O7ad071`J01/K6@0J6QP00`0G5aD201HF500e01TK600D
5Q<06Q`I01TK600K7AX0:R`Y01lQ7P0L7Q/06Q`I01PJ5`0G6AH05aXH018F5@0Y;RX04aPC00@90`0G
71H04aPB02L/9P0J7Qd05ATJ01@H6`0J7B@06AhR01@M700I8R4072DT01XS8P0Q:RT06b@S01XS8P0O
:2L0:34`01`U900U;Rd08bX[02@Y;00X;C40728U02`d=P0nATT0;CHh03@n?`0b?3h0:C<e02Pd=00^
>cd093Ln04iRJ`14FEl0=TU?02Di>P0a@d@00P0`@d40:P0b@T40=49303A2@`0d@TD0=TQ<02i1A@0h
Be40=4I@03A6DP0jC5/0>daN03a=G@11DV40@eES049DH011Del0=dQH03m@H00nCel0>deK04EGI@0o
DE`0M8N>0:Bg_P1TMgd0B5]O03]>DP0lD540?U9A04QLG019G600BEaR04iQJ@1?HFd0DF=a04aNJP1H
JW@0EfUc04aOI`1GJW00FVU/05MWI`80Df=S00d0EfMW05YZJP1OKW40Gfia05i]L01RLG@0IWEh061_
LP1VMGP0J7Mj06]jO@1]O7l0L7n20080LX640P1dPhH01`1eQ8L0NXV<07n?S`21SHd0QI6A08ZFUP2?
VIX00P2@VY`03@2CVZ00V9nU09ZQY`2LX:T0XJF^0:JZ/`2VZJl0[Jjc0;2a]P2b/kP0][Fk0;Rg_@2i
^;h00P2h]K`05P2l^L00`Kc30<>ma`33`</0b/C@0<c6dP3?amH0e<WI0=K;f`3JcMl0g/oT0>3AiP3U
dnT0i]CZ0>OEk@3/f?<0lMgi0?CPo03hhOd0mmoi0?KMn03ggOP30?_On00?0?cPn@3mh_/0nn?k0?cR
n`3lho/0nn?k0?_QnP3lho/0o>Cl0?gSo03jhOX0m]kf0?KLm@3af^l0jmWY0080j]OZ01D0imKX0>CC
i@3Lc]h0cl??0<^ob@3=`/L0aKbm0<6i]`30^[T0^[Je0;B`[`2a[JX0[JZU0:BSWP2HV8l0TI>608f@
P022QG@0OH5`07n3LP24RgT00P1dNf/0A@1lQ7D0M7a]07=kK021S7`0O8Mg06mjK01FHU@0FFEG05EQ
E01KIV00GfYV06=_J`1RKVX0GVYV05QWHP1GIV40H6mZ05UZI01BHed0B5UC04AECP1HIE`0>DHl03E2
>@0b?CD0@di603i9@`0f?cX0<CXe02Tb;`0]<c40<SPf02`e=00/=SL0;c/l02`h>00[=cL0=40o03U5
@`0nBTP0<cll02Xf<P0W<bl0;3Pd03i:AP1JIV809S<_02Hb;P0X=3009C4/02/f<00T;bT08b`V01lY
8@0Y<b/09RhV02@^9P0Y=2h09C4]028]:@0P:bL07bTV01hW900Q9bD082DT02<W9P0S9B@07AlN01`N
7@0201@H5`0G01PL6`0U:BP06alN01lS8P0Q9B@082@S028V9@0Q9B@09BTX02/a;`0P9bD04Q/J00PA
4013B4/04aPK02T^<@0O8bD08R<U01HH5@0R91h0;c8[024T7@0L7AT00P0M7A/01P0O7ad08R8P02<S
8@0J6QP06a/I01LG5@806ATG00H05ADC01TH500J6AD06QTE01PG4`0G5Q8201PG4`0;01HE4@0E5100
5QDA01PG4`0I61@08b8N01/J5P0B4@d07A`H01PG4`0C4Ph01@0D4`l301<B3P0a018A3@0F5A405QDA
018A3@0D4`l05A@@01<B3P0B4@d05A@@01PG4`0A40`02`X605ACC`3hmo<0Cdi:010?2`0C4Ph04Q4=
01<B3P0O7QX03@`800l;20060P003`/900l;200L61D05Q8?01hJ5`0J5Q<04Ph;08R4P@1NFUL05Q8?
014=2P0?2`P04@d:01DA3P0B3P/02`L4014=2P0T81d040`900h:1`0@30T05Q8>01491P0A2P@04P/5
014<2002018=2@0600l;200C4@h030/900/:200;2PT02@P60P0>2@H300l:1`0300h91P0@2`P040/8
00@040/80P0B3@X01@04000040/801<>2`0H4a003PT6008040/80P0?2PL04P0@2`P0208201<=3@0?
2@T03PP8018<300>20P0618B01XD500K5AD03`T900/51@0@2PX03`/900T40@1QG5T0?CPe01HA3PH0
3PT600<040P601<82@0B20T00P0B20T201482@0:00l92@0G4a802`L600l=2`061@<04Ph=00l92@0>
20P03@L700h820803`T900H03PP800l92@0<1PH03`T9018<300B2P/201<92P0301882@0C2@X04`T:
008050X;00/04`T:01882@0B20T04@L801P=4007000060dA00h31`0G31003`@801H;3`0501462P0=
01<:300C3@d07QPH01dG5`090`<04`d=018<300M5aL04P`<010;2`0D3Ph04P`<01@<3@0201472007
01882@0E2``060h?01<92P0F30d04`T:01061`0201<92P0500l51P0@1PL04PP90147200@1PL00P0A
1`P02`0B20T04`T:01<92P0B20T04@L801061`0A1`P04PP900l61`0>1@H04@P;008050h@00L02`L:
05IAE`0M61h030L<01892P0B20L04@L600803`D400/040H501T?3P0F30/060h=01471P0?1PD04PP7
00l5100@1PD04@L601881`0201<9200301061@0B20L040H500803@<200<03P@3ooooooooool04_oo
ool001_ooooo00H02@D4018>3@0A3@`03@T800h:2@0?2`X201<?3P0[00X61@0?2`X03PX901<?3P0@
30/05A4@018>3@0A3@`0510?01<?3P0>2PT040`;00l;2P0D40l05Q8A018>2`081@804@h7010=1P0C
40X06QLB00l;200C3``040`;01TE500H51<06ADD01LC4P0@30/05a<B014=30060P805A4@01LC4P0A
3@`04`l>014=300@30/02`L6014=300D3Ph04P`<014;2`03010:300b018<3P0C3@l050h>01D?3`0D
3Ph04`h=01DA400V8R404Ph=01@@3`0A3@`04Ph=00T5100@30/03`/:01<?3P0<20L04Pl8014?0`0C
40/050lA01HA5`0C3Q804@d;018?200B3`H04a0901DA400F4AD061@F00X61@0@30/03PX900X61@0E
4A004@d<01<?3P0B3Pd040`;00l;2P0A3@`04Ph:00d:1@0D4@`06aLD01HB3`0K5a@04`l>018>3@0B
3Pl2018=4@0?01@?4`0E4A806QHE01@@3`0G4a801P81018>3@0C3`h04@d<010<2`0A3@`04`l>018>
3@0D40l05A4@00<06QHE00P05a<B01TE500I5A@05a<B01DA400C3`h04Ph=01HB3`805A4>00H04`l<
018>2`0A3@X05A4>01<?300B3P/201@@3@0P014=2P0U8Qd01000028N7@0=1`L0;b//00<00P0G4QH0
510B010<2`0B3Pd05A8>00d<200=3@/04A<@00l?3@0=3@/0410<00l>2P0F5A404a4<018?2P0D4@`0
5A8=01@A300J6AD04a8@024P7P1:BDL04Q4?01LF500P7ad301@C4@805QDC00P04a<A01@D4P0I6AL0
5QHD00d=2`0<30X051@B01HF50804Q8@00T07QhL01DE4`0D51804Q8@010@3P0E5A<0@D4o06EUH`0I
6AL00P0G5aD01P0I6AL05aLE01HF500F61D07AlL024S80806Q`I00@07R0M01dO700J71T061XG0P0F
61D07`0E61H051PG010E4@0V:bH07B8L020U7`0N8ad051TC01PL6`0V:R/04QHI024T:`0M8RD04a`K
01LP7`0E7Qd072DT01lX9`0@6AP05b0O02D^;@0H8B003QLF030i>00Q:2/07B8V01hS9`0T:Rh0@DU<
04Q@D`0]=ST00P0^>3X02@0Y<cD09C0b02`h?00Y>dD0;D5<02PlA00eB4h093Pi02`n?`020395@`0i
03A4@`0e@d@0=D=403E3AP0gBDd0<4=703U<D`0eAe40=DMC03]<G010DF<0@E9T04AEI@13E6@0@E=Q
03i@GP12Df<0?DiP03Q9F@14EV@0E6Id049DG`0lCUP0HGAk04MJG`11E5P0@5=G04IJFP0mDDl0A5QG
04QLG@1=H6H0E6I_055SK`1IJgT0DfEb06eoR`1ZO8H0Cf5Z05QYL01GIVT0E6AT059RHP1CHf<0F6QX
05][J`1QL7<0GFa_05i]L01SLWD0J7Mj06MfN@1XMgX0JWUl06akOP1^OH00L7n20080LH2301/0M8>6
07J5R01gQXT0NhZ=07n?S`21S8h0Q92@08NCT`2<UYL0SYRJ08nIV`2@Uid0UYfS09^RZ02LX:T0Wj>/
0:FZ/02WZ[00[Jjc0:n`]@2`/KH0/k:h0;Fd^P2g][`0][>j0;Nd^`2l^L000P31_<<04`34`L`0b/C@
0<c6dP3?amH0dlSH0=C9f@3Ic=h0gLkS0=o@i@3Td^P0iM?Y0>KDk03Xe?00k=Sd0>oKm`3cg?P0lm_e
0??Jm@3fg?L00`3igOH00`3lg_P0o>3i0?[Pn@020?[Pn@80nMoh0`3jh?T0>@3ggOH0m=[c0?;Hl@3]
e^/0i]CT0>GBi@3TdnD0h=;S0=g?h03EbML0bKo80<RnaP3:`LD0_KRe0;bg]02n^[H0][:_0;2/Z@2]
ZZD0Z:FN09^KT`2DUH`0RXb107eoLP1oPg@0Oh=b07=gIP27SWh0O8=c07V0L01nQWL0NX9c07V1LP1Y
M6@0K7MW071kJ`1KJ5L0F6EC05UUE@1FHET0GFQT06A`K01QKFT0GFUU05QWHP1PKfX0Hg9]05EVH01<
GEL0@U==03Y;A00gAcd0=D8h041=A00c?SH0=D0h034l=P0202lh<`0N02df<`0`=S@0;S@b02H_;P0_
>CX0:SHg030l?00c?cl0<Cdl034m>`1JIV@0=d=002/g<`0b?SX0<clk034m>@1PKfX0:cXe02Xi=00^
>SH0:SHa02/h<@0V<B/09C0Y02@^9P0Z=2`08B/R028]9@0W=2d08bhZ0P0O:RH09P0O:BH07RLT02<Y
9`0N8b408BDT02@V9@0N81l06adL02@X9`0D61L05ATH02DY:00P92<09b/Z024U900R9RD092PW02<W
9P0X;2/0;cDc01`S8@0b>cX0EEiM0;>h^`0Z;c803Q<F01<G6@0O8B00:bdZ01/M5`0D5`h04QD>01hN
6`0N7Q`07AdK01XJ600K6aT07AdK0P0K6aT0100H61H06QXH01PH5P0C4a4301XI5@0?01TH500H5a<0
6APD01PG4`0F5A4051<?01HE4@0H5a<05A@@01LF4P0@3`/03`h:01XI5@0D4`l04a8>00<051<?1@0C
4Ph01@0B4@d05QDA01HE4@0@3`/04Q4=00805A@@00P05QDA01XI5@0O7QX08B0L01XI5@0F5A40Cdi:
02<R7P805QDA0P0A40`0400I61@030/7010<2@050@0071PE01DA3P0300003PX700P40@0300005A4>
02@P7@0<20D040`901@@3@0A3@X2010<2@803PX700L01@4001HB3`0>2PL04`l<00`81@0>2`L04PX7
00804P/50`0A30P01P0T81d06aTF0040000U92801`H401hM6`803PT600@03`X7010;200A30T04@`9
1P0@2`P01P0400005a8?00@0000A30T03@P501D@3@H03PT6018030H600h8200<1PH02P@400h8200E
3`l03PP801H@400J51@03PP800`61P0D3Ph04`h;01D@3@0P6aP0>3<`01@?300?2PL500h91P030108
1P0C20T04PP900804PP90P0A20T01`0=1`L0100000<0000A40h02@P600D40P0?2@T00`0=1`L0200>
20P03`T900`61P0>20P03@L701@>3P0K5AD05@d=0P0?1@H20147200401882@0D2P/050X;01<92P80
50X;00P04PP901@93007000060dA01462P0I3Q803`@801@93@D04@H:01<02`@500@0000;1@D03PT9
00@0000M5aL02P@400d71`0:10@02@<300H0000400003@D601061`0A1`P04PP901@:2`0F30d03`D6
00804PP900D04@L801@:2`0C2@X03P@500l51P04014720806Q0A00L06@l@01H<3@0C2@X03`D60106
1`0A1`P04PP900803`H700X04@P;01D?4@0K5AL05A0D01hI7`0300@02`D:01<:2`0C2@P04@L60`0>
10<04P0800005P`;00l5100D2PT040H501@:2@0=0`803`D401061@0A1`H04`T801@:2@0>10<04PP7
00X0000;0@004@L600L001Cooooo000Kooooo`0E01`H5`0M6AP04Ph=00d9200A3@`03`/:00h:2@0G
4a802@D400l;2P0D40l04@d<01HB4@0J5QD04Ph=00h:2@0C3`h0510?018>3@0C3`h03`/:0080510?
01003`/801HC2`0:1`0071T@010=1`091P803P/6010<2@0?2`X03`/;018>3@0M6AX03PX;010<2`0E
4A004Ph=0P0D40l01`0>2PT04`l>01@@3`0A3@`081`K01@@3`0<20L00P0A30T0<`0@2`P04P`<018<
300C3@d05@l?018<300A2`/04`h<01HA3P0F4Q0040`;018>3@0A3@`061@C00X61@0D40l04Ph=01XF
5@0>2PT06aLF00`81`0E4`X04Q0201@A200E4@h03PX:00l;2@0C40/04@l401<A1@0E4`P0514<01@@
3P0D410020@301PD4`0S7ah03PX901<?3P0D40l04Ph=010<2`0B3Pd04`l>010<2`0C3``02PL301DB
3@0<20H03``801<?300201<?3P0>018>3`0A30l04@`@014<4@0B3Pl05A4@014=300:1PD0=S8a03Lc
<P0A3@`040`;00l;2P0A3@`201@@3`0601TE500=2@P05a<B01LC4P0c;bh05A4@0P0B3Pd301<?3P05
01@@3`0E4Pl0518>01<A3@0B3``00P0C3``06`0F4Pl04`l<018>2`0D40h04`l=014=2@0A2`H07AHA
00l:200L51805Q0@01H@4@0_:B/091hP018>3@0B3P`06ADA01<A300C4`l03`l;018A3@0F5A405Q<@
01<@2`0D4@d04a0;01@@2`0201LB3@0]01D@2`0J5Q@05QDC01LF500T8R007adL01HE4`0I5aD04Pl>
01@C4@0F51805A<A01@C4@0B4Q004a<A01HF500G5aD092@R03<c<@0I6AL061PF01XJ600E5A<06ATG
01HF500E5A<04a<A01HF500D5180:BTW0451?`0H61H05QHD01LG5@0K6aT06QXH01HG5@0E5a@08R@Q
01XL6@0G6AH07AlL01HH5@0J71T06A/H00806Q`I01d06adJ01hR7`12AT@082DQ01XO6P0C61806QlI
01/P6`0G71L0720O04Y>D00R9RT05QTO01LK7`0T;2/07bHV01`T8`0N9bD06B8P01lX9P0P:BL05b0N
028[:P0L9B@092d/01hU:00Q9R/092T^02H/<@0203<j@01602H^<`0U;S<0:c@j02/f>`0Y=3T0:SHl
02Dg@00P=3l0:Ca302m1AP0X>cd0=4I60353@@0c@d80=4A403I5A`0hATP0>DI;03]=DP0dB4`0?E1H
03Y<E`0iBeP0@55P041AHP11DV<0A5EV04EFIP13E6<0@59P03a=G@0oD640AUMW049DHP17FFH0@59M
041BG00oDUT0@UEJ04=FFP13EeT0AEUJ04EIF@17Fe/0BUiP059UJ`1GJG80CV1[05AVLP1BI700Gg5k
05e`N01AI6/0FF]^05EUI@1EHf<0EVAT05QVI`1LJV/0Gfe^06AbM@1QKg80I79e06UgNP1/NWd0JgUl
06YiO01/Ngh0KGao06imP080L7n203T0Kgj107F4Q`1jR8/0NhV<07f;SP1nSHh0PHb>08:>S`24Si00
RI>D08fGV@2>V9/0UYfS09bSZ@2RZJl0Wj>/09fQZP2SZ:h0YjZ`0:f^/`2^[k@0[Jjc0:n^]02`[kD0
];>i0;Ba^02f/kX0_[_20<2la02o^l<0a<7=0<S5d@3:am<0cLOE0=38e`3BbMP0f<cM0=_=h@3Ncn<0
h];V0>?Ci`3UdnX0i]?]0>SDk`3Ze_00k]Sb0?3Hl`3afO@0lm[e0?OKm`3gfoH0n=_d0?WLmP3kgoT0
n=oj0?SNn@3gg_T00P3fgOP20?ONn0220?KMm`3cf_@0l=O`0>gDk@3XdnL0hM3P0=o>g`3Lc=d0e/SH
0<o2dP39_//0`kW20<Bk``33_L00];2^0;Jb[`2i][40[jjW0:bYX`2RXIX0UYN?092AQ`2;SH80PXEj
07]oLP1nPGD0Nh1c071dIP1aMfT0L7IX06meI`1bNV/0N81a07R3LP23SWd0KGQW069_G@1LJEL0FFIC
05=QC`1GI5`0G6UU065^JP1LJFD0FFIR05a[IP1KJVD0FFQR04QHDP15Ee00@E=<03a>AP0jBT00>DHl
03Y7?`0lAd00<chg03E0>`0kAD00=T0k038k>@0^=S@0:S4`02/c=01IHf@0<cm0030l?00e@D40;3Pg
030l>P1DH5h0=D4n038n>P0jAT80=D4m034m>@0^?CP0<d<n03E5?`0^?CP0<D0j02<a:P0Q;RL0934Y
02@_:00X<b`09C0X03<n=P0X=2h08bhZ01l[9`0R;2T09Bh[02@[:P0N92<07R<R024U900P8R406Q`K
01hP7P0_<c407B8O01XN700N8b0051PG01hR8@0O8b808BDT02<W9P0O8b808BDT02T^;@0L8b807RDU
020W9`15Bd`08BHX02DZ;00K7b0071hL02@V8`0L7QP08bHM01/N5P0K71P07AdK01XJ600H61H06ATG
01`L6P806a/I00@06ATG01dM6`0J6QP051@B0`0I61@0100H5a<05aHB01LF4P0H5a<301LF4P0801PG
4`0E510061LC01DD400G5Q804a8>00h=2@0E510201@C3`0401<B3P0B4@d04Q4=018A3@804a8>00h0
4Q4=01HE4@0F5A404A0<01DD400I61@05QDA018A3@0C4Ph051<?01<B3P0?3PX051<?01HE4@8051<?
0P0H5a<01`0D4`l030/6010?2`0E4@h03PX701dI5P0C3``00P0D40d01@0D4@l061@A014=2P0@30X0
3`/800804@d:00`04Ph;01<?300>2PL04Ph;034]:P0@30T05a<@010<2@0H51402@D2018?2`0C30T2
01<<1P<040/700`04`l<00l;2@0G5Q<08QlN010>300=2`T04`h;018=2P0A30T040/8018=2P0C3P/6
010;2006018=2P0@2`T07QTF00X5100D3``05A0=0P0@2`P0100?2PL040/8014<2@0?2PL200l92@04
01/E5@0H4Q803PP801TC4`804P`<00X04`d=00h8200>20P050h>010;2@0E3P`03`X901@>300?20H0
40/80P0?2@H0100>2@H03`T600l91P0@20H301<82@0?01882@0A20T04@P9014;2`0@30/05A4@00T7
1P0D4Q006AHE014;2`0@2@T03`T901092@0A2@X04@/;00803`P800D02`D5014:2P0F3`l04`X;0147
200501882@0:0147200@1PL04`T:01@:2`0B20T040D801D:3P0F2`l04PL;01H;3`L04@H:00l0718D
00d8200I4Q8030H601<=3@0<1PH04``<01H@400@20T040X:018<300<1@D040L801061`0B20T00P0C
2@X0200B20T0308301061`0B20T04@L801<92P0@1PL04PP9100A1`P00`0>10D04`T:01@:2`0201H<
3@0@01@:2`0A1`P03`D60147200C2@X040L:00l62@0A20/040T<00P31@0C3A40100403`g?00P6al0
4PT:01881`804@L60P0B20L01P0@20L0:b4P00T0000I3`h03PD401471P<03`D40`0@1PD301471P03
01881`0C2@P04@L601Cooooo000Kooooo`0401D?3`0D3Ph04P`<014;2`8040X:00@06A<C014;2`0D
3Ph03@L70P0?2@T0700@2PX04@/;00T30`0@2PX04@/;01XD500A2`/040X:00l92@0A2`/04`d=01@>
3P0W8b0040`901DA3P0B3P/04`l<014=2P0>2PP04`l>010<2`0?2`X02PH501HB4@0;1`H04@d<01<?
3P0B3Pd2014=300401<?3P0A3@`04@d<00l;2P803@T800@03PX901@@3`0E4A004@d<0P0=2@P01P0B
3Pd04`l>01@@3`0D40l04Ph=014=30<040`;00<04@d<01<?3P0C3`h00P0C3`h01`0B3Pd040`;00l;
2P0@30P04@h9014=2P0A3@/00P0A3@`0300G4a0040`900d:1@0Y9R800`0001<?3P0J5aL03@/<00`:
2`0Q7b003`d>00H41@804@l@0P0;2@X01@0>30d030X;018@3P0@30T04@d:00804`l>010040`;01@@
3`0@30/03@T8010<2`0B3Pl04@d>00P71@0I61H030/:01/J600;2PP07A`J01@C4@0B4@l04A0>0P0C
4Q00100?3P`04`l>01TE500J5QD201DA400P01@@3`0@30/04Ph=01DA400D40l04Ph=018?3P0@4@`0
2`h701TJ5@0;30L03@`9018A3`0B3Pd04Pd<018<300B30h050h?01L>3`0=1@<05`l<01P@3P0E3@/0
:20N04Dm>`0J4A806Q4A01TD4@0H40h0FeEB024L6@0D4`h301<B3P0Q01DD400F5A40;bh/02HU8`0K
6QP06aLF01<?3P0E4A008alP00l:300E4A806A<E01TD5@0G4a@04@`=01H@4P0T82404Pd>01`F600B
3Pl04A0A01PH600J6QX051@D07IfMP3Jf]X071`L00/;2`0E5AD04a<C01DE5@0F5QH05aHD008061LE
04X05aHD01TI5`0K6aT061PF01<E4P0G6AH06A/H01LI5P0I6aP05aTD014C3P0K7AP06A/F01lQ700K
7AP05ALB01`N6@0M7aX06A/F01LI500G6QD061dG01TN600J7aX06b0L01`Q7@0L81h06alN01dQ8P0O
8bD07R8U01dP9@0K7b<08BDX02@X:@0_=3@0IfeY02D[9`0M8al08RPT01dV8@0J8b408BXY028Z;00O
:2P08BXY024Y:`0S:bd09Rha02L`=@0S;380:c@k02dg@00/=T00:SM002Da?00T<CT08Rlg02/h?P0a
@4<0;Shn0310@00dA4@0;Cdm0350A00a@4L0>dYA03Y:DP1BIVl0@eUT03U?FP0nDEl0?e9P041CH@80
@eIT00/0?e1O03i@GP14EV@0@U9Q04AFI00nD5h0?U1M04=EH@10DUh0@eEP04EGH@0204EHG`0C04=F
G014Eed0CF1V059SK@1AHV`0C5eW04UJI01HJG40CUmV04IGGP19Feh0@eEE055THP1HJfP0E6MS04mO
GP1CHf<0EfMW05YZJP0205][J`80I7Ad0P1UMGD206IfMP080720P01/O7`0KWin06moO`1`Oh00MXB5
07F3Q01jQhP207n:S00K086<SP24Si40QI2D08:=T@2BWJ40UIjS08jGW02AVZ40V9nW09jU[@2W[[H0
Yj^d09nS[02PYJ/0YJZ^0:b`/`2]/K@0ZZfb0:f]]@2_[kL0/;2h0;:a^@2e];`0/k:k0;Fc_P2l^L@0
`ko>0080a/;A0280bL;B0<g7e@3?amH0e<[J0=O<g03FbMX0g]7R0>;EiP3Md>40g<kO0>CCiP3Ue>L0
jMOZ0>cIk@3]f>d0kmW`0>oGk`3^e^h0kmO_0?3Hl03bf_80lmgd0?GMm@3dgOH0l]_e0?7JmP3ag?L0
l=cg0>kJl`3[f?00imKY0>?Bi@3Qd>00elWF0P3A`m005`3:_/X0ak_50<Bi`P37_LD0][2d0;bf^@2i
/kD0/Zb/0:j/YP2b]:T0ZZZP08R:O`2:SH80SI2508J9O`1cNFl0L7M]07b2N01]MFX0OhIk08F=P021
RGX0N81a0080LGU/0P1dOg408P1XLfD0GFUM05]WF`1FHUH0CU]@05IWH@1FIV<0G6aY05a]I`1GIV40
EFAM05QWH01BHUP0CUiD04QHCP0oCdD0?De2045>A`0gA3d0>TI103I2?P0d@3`0>4A202lk>`0oBd/0
<S`n02Tb=`0b>d0092h`03Y6AP0b?S`0<3`j03]7A@0/>3H203<o?@04038n?00[=cD0:cLe02`h=P80
9C4]03T0;C/d038o>00_?3D0:SHa02Xe<@0h@cl08bdY02lh=@0Z<c00:S8_05mUH@0k@S/08bPS02P/
:`0n@T406alQ038f>@0Z;S40:b`_03@f=@0J71/08B<O01PJ5@0K81X0724K01hS7@0Q9R008bPT02@Y
9@0O9200:BhZ01hS7`0W:bX0;S8a02@X9`0U:BL09BTX02<W9P0P92<08R@S02@V9@0N81h05aTF01`N
6`0L7QX061XE01TK5P0J6QP05aLE01PH5P0K6aT06ATG01LG5@0M7A/06a/I01TI5`0H61H00P0F5Q@2
01HE4`0A01@C4@0C4Q008R4O02HU8`0E51805QDC01LF500E51806aXH02h[:P0@30/081`K01DA400I
5A@05Q8A01@@3`0G4a800P0F4Q40100G4a806ADD01PD4P0D40d201<?300J01DA3P0H51405Q8?01DA
3P0G4a005Q8?01<?300B3P/0510>01<?3P0I5A@040`;01PD4`0E4@h04a0;018?2P0C40/0514<01DB
2`0C40/09b8O01PC400B3@X04`h;00d81@0C3P/3014<2@08010;200?2PL03PT600T50P070`004a0>
01DA3P0@30T2018>2`0700h:1`0A3@X05A4>014=2P0@30T03`X6010;1`02014<200;018=2@0C3PX0
3`X6014<200B3`X06A@A010<200E40`04`h:018=2@0A30P00P0?2PH01@0=20@030L3010;1`0A30P0
40/700803PT500l04Ph;00X60`0:1P<03`/8014=2P0<20D06QHC00`81@0B3P/0510=00`81@081040
5A0=018=2P0@2`P00P0A30T0500?2PL05Q4>00T40P0=20D040/8014<2@0I51404`/901@:2@0D30X0
50/:01@:2@0B2PP03@@301061@0@20H04PT801<9200B2PP03@@50P0B2@X01`0A2@X030H600P20P0<
1PH03@L700h8200>2@T00P0@2PX01P0Y82404PP900H0000P5QL09adN00L000804PP90P0@1`P01@0@
1PL04@L901H;3`0E2Ph040D900804`P<00<03`@801052@0A1PX00P0B1`/0700@1@T03@8601052@0I
3Q803`D800l4200H3A4040D901dB5P0A1PX04@P:01@93@0700004@H900/20`0@1PL04@P900X10P0<
0P<04@L801482@0C2@X040H700h51P0D2P/05P`=01<92P0A1`P301061`804@L80P0@1PL00`0A1`P0
4PP901881`0201881`0301471P0@1PD040H500H04@L602@03P@500l51P0A1`P04PP901<92P0D2P/0
3P@501@;300?1PT04@P;05]BE@0j<C<03@<400h41@0@1PL03`D60147200D2P/0DDM801lE5P0e:b`0
2`4200`4100?1@H03`D401@:2@0@1PD03`D401881`0@1PD03`D400T1000E2`X01`0001881`0<0P4D
ooooo`006oooool02@0E3`l050h>018<300A2`/040X:014;2`0=1`L050h>01H@400201PB4P0701D?
3`0=1`L04P`<01LA4@0R71`0618B00h82002018<3007014;2`0B30`050h>01D?3`0X92<05A4@01TE
5002014=300800l;2P0>2PT04`l>00d9200A3@`02`L6010<2`0>2PT2014=3004010<2`0?2`X040`;
00T510804@d<0`0?2`X0200B3Pd040`;014=300C3`h04@d<00h:2@0?2`X04@d<0P0B3Pd00`0?2`X0
40`;010<2`02010<2`03014=300B3Pd04`l>00804`l>00@04Ph=010<2`0?2`X040`;1@0A3@`03P0<
20L03`/:02@P7`1;AdH06aLF01<?3P0;20P03@/<01hL7@0B41402`T:01/I6P0=2``0518C0P0C4A80
0`0G5AH03@/<00d:2P02014=30804`l>00`040`;01@@3`0A3@`03`/:014=300C3`h04Ph=01/J600C
4Q004Q4?00D40P0A40h201<B4009014@3P0@3`d04Q4?018A3`0?3P`03`/:01DA400G4a804`l>0080
510?00h04Ph=01@@3`0E4A004Ph=010<2`0@3@/03@l:00`A2P0;3@P04Q<>01DE4@0?3P`04`l>01<>
3`804`d?00l05PhA01L>3`0I41406Q8@01D=2`0B2PP0610>02@L6P0A2@L05Ph<01/C4@0;0`40:b<Q
00/60`0E4Pd00`0B4@d07P0D4a005A@B01LF500J61P040h?01DC500B41405Q@E01<?400G4A<050h@
01LA4`0P6Q`030H801@>400f<380AT1201lI6`0L5QP05Q8C014@400G5aL06QXJ01HF5P0d=3@0EUIF
01TI6@0C4a<06ATI01<C4`805QHF00P06ADD01TH5P0H5aD05aHD01LG5@0H61H05aLE01DG50806Q`I
014051TE01HK5`0J71L061XE01DG4P0G6A@07AlJ01PJ5@0M7aX08B<N028T7`0N81/07AlJ01/N6@0I
7QL06AhH01XO6P0201/P701Z01`P7`0L82407B4R01hR900N8RD07R4V02d_=00J6al051PI024U900X
;BT00`X302@[900Q:2407RLR01`U8P0R:bX08RX/01lX:00Q:RL08R/Z02@/;@0V;S009c0e02Tb>00U
;SD09S0j02Td?`0U<Cd0;SY7030j@`0]>3h0<3/o03=1@P0b@440>4I603M7A`0b@T80=dI;02m0B00f
Adl0=DMA04QNJ`10EV<0?59O041FH`0nE640?U5O049EH`0oDV00AEMU049DHP17EfH0Be]Z049DH00m
Ce/0@59N04QJIP19FfL0CV1Z055SK@10DU`0?U5H04=FG@0oDUT0CV5X06EeQ01AHG00G6ai04iOJ@1;
G6@0C5iR04mQI@1HJVX0Cf9N059UH@1?He/0CV5K051PG`1CHf<0EfMW05UYJ@1LK6`0GFe]06=cL`1T
M7@0IGEe06IfMP1WMgL0J7Qh06alO01YNGT0KGem06inOP1^OGh0Lh6207J1P`1kQXP0OXV;07n9R`21
Rhd0Q8j@08JAU`28TiT0W:N]09jW[P80TY^R00L0V9nW09ZQZ@2PYjl0XJF^09jRZ`2QYZ`0YZ^^0080
ZJf`00D0Z:^`0:^[/`2/[;@0[Zjf0;6_^P020;Jd_`060;Rf`@2m^lP0`Kg=0<K2d@37`m80b/?C0P3;
aM<02@3AbMP0elcJ0=C9e`3Gc=X0fLkL0=G:f03Mcmh0j]c[0>WKjP020>SGj@030>WGjP3[f>`0kMO^
00<0kMO^07P0k]S^0>oIkP3_fO00kmWa0>kJl`3^f_D0k]_f0>_Il@3Yenl0i]GZ0>;Di@3Nd>40g<kK
0=C7d@3>`L/0cL3:0<Fj`P32]kl0_kJk0<6h_@2c[K40]k6c0;6[[@2YXjD0YZBN0:RZW@2TYYT0Rhj2
08J9OP21Qg/0M7Y_06meJ`1gOg@0N7mg075hL01cNg40OXIi07R0L@1bNV/0Lg]^07InL@1dOg40K7I[
06I`I@1QKF<0Gf]Q05aXGP1MJf40FVYW05EXIP1HJfL0FV]U05IWH@1JJF80CemE04UIC`18ED/0@e16
03Y7?@0gA3T0:CH_03<o>`0mBDD09S8`02/g=@0`?3`0>4=503I1@`0b?D4082/a03a7C@0g@TH0@dm?
03]7A@0/>3H0:cLe03E1?`0/>3H0<Cdk030l>P0[=cD0;3Pf02hj>00W<bl08BdY02Db:`0[>340;STc
02/f<@0W<Rh0<CXg02Pa;`0Y<S409bd]02<Y:@0a=cD0:R`W034c;`0K7AX0:2T[024R9@0720d08b@Y
01dN8@0U9bH07AlN02HX900M81T06b0I020U7P0S:24092TS02<X8P0R9b408BHR020U8@0B5a<05QXI
02L[:P0T:2L2020R7`0601lQ7P0N81d0828O028T8@0N81d061XG0P0K7AX0300L7Q/0828O01/K6@0H
61H06ATG01`L6P0K6aT06ATG01dM6`0J6QP06ATG01LG5@805QHD00L061LE01HE4`0G5Q@05A@B01`K
6@0Q81h05aHD00804a8@00X05QDC020O7@1^K6X0<Bd/00<0000F4Q406QHE010<2`0I5A@05a<B0P0F
4Q401@0H51<06ADD01HB400B3P/04`l<0080510=0P0C3``201@@3@09018>2`0A3@X04Ph;01@@3P09
1@@03PX901<?3P0Q7A`0>CDb00803``700@04@h901<@2@0D4@X0514:0P0A30T0100@2`P04`h;01LB
3`0E40d200l:1`804Pd:0P0C3P/0300I5A8030P500l;200C3``05A4>010<2@0D40d04@d:01<?300G
4a00510=018>2`8040/70`0A30P01`0B3@T050l;01<>2P0B3@T03`X600d8100910000P0C3PX2014<
2005010;1`0?2PH03@P4010;1`0A30P00P0?2PH03P0@2`L030P500d91P0?2`P040`9014=2P0?2`P0
0`0002PT8@0e<Bh07ATF01@@3P0C3``03PT60P0=20D02@0>2@H03`X700l:1`09104040/801HA3P0>
2@H02@@100h91P0201@:2@805@/:00<050X901<9200A1`H00`0B20L0200A1`H03`L501H>3`0A2`/0
3PP8010:2P0E3`l05Q0@1P0>20P01P0A1`P03P@501L=3P0S6AX0DTQ901lE5P804PP90P0A1`P01@0@
1PL04@H901D:3P0E2Ph04@H:00805@X>0P0B1`/01`0C20`050T=01@93@0D2@d05``@01D:3P0F2`l0
0P0C20`03`0D2@d0304501<8300A1PX05P/?00L0000:00<0=2X/01D;300C2@X05@/<01061`0>10D0
40H70147200201<92P050147200B20T04`T:01882@0A1`P00P0@1PL0100A1`P04PP901882@0A1`P2
01061`050147200B20L04PP701881`0A1`H00P0@1PD601471P803`D601`040H70147200B20T04PP9
01D;300B20T030<300/10P0M4a@05@/<00h41@0@1PL04@L801061`0B20T05@/<0;F[[00e:b`060h?
01D;300K4A801`0000h40`0A1`H03P@300l5100B20L03`D40P0C2@P0100F30/03P@301061@0I3`hD
ooooo`006oooool00`0E3`l050h>018<3003014;2`0600`61P0D3Ph030H601XD500=1`L05@l?0P0A
2`/0100E3`l09AlO01/E5@0:10@201<=3@08018<300C3@d050h>01@>3P0A3@`03PX901DA400@30/2
01DA4006018>3@0M6AP04@d<01HB4@0B3Pd03`/:0P0B3Pd05`0@30/03PX9014=300B3Pd0510?01TE
500B3Pd040`;018>3@0@30/05A4@00d9200>2PT05A4@01@@3`0A3@`04Ph=01HB4@0H51<05a<B01<?
3P0B3Pd04@d<008040`;00<04@d<018>3@0C3`h00`0B3Pd00`0A3@`040`;010<2`05014=300J018>
3@0?2`X04@d<01PD4`0;1`H0510?010=3@0>30d0518C018@4@0;2@X03`d>014?400E4a@03@/<014?
400F51D03P`=010=3@0A3@`04Ph=01<?3P0D40l04@d<01@@3`0C3`h2018>3@0301@@3`0C3`h040l=
008051<A00<04Q4?010?3@0@3`h00`0@3`d01`0A40h040l=00h=2`0=2@P04Ph=01<?3P0A3@`00P0D
40l201HB4@0A01@@3`0A3@`040`;018?3@0>3`X0;c8[00h@300B4`h03@d9010?3@0D40l04`l?014=
3P0B30h04`d?01<=3@0F3@h00P0C2`T01@0G3`d06A4?01H>300C2`T050`:00808ATG00@06Q8@01<>
2`0E4Pd04a8=0P0B4@d08@0D4a005A@B00h=2`0O7Qd040h?01LE5P0C4A805A<D01DB4`0F4a@061DF
01DA4P0F4Q<061DF01LD5@0G4a@07Q/L01@A4P0K5aP05A8C01DD5@0H61P04A4A01@D500H61P04Q8B
01DE5@0J6QX06a/K01@D500J6QX05ADE01PD4`0201XI5`0E01LF500D518051@B01DE4`0G6AH06adJ
01PJ5`0C61@05a`H01PJ5`0J71T06A/H01XL6@0D5Q<07AlL01/M6P0M7a`071hK01XL6@0K7AX071lJ
00806QlI02d06QlJ01XO6`0J7Qd0720O01dQ800L8240720R01dQ900O8bH07R8U02P/;`0n@T<07B4P
02ld<00T:b@07RDN020X8@0O:2<082TV028/:`0P:R/082TY02</:`0T;B`09Bl_02La<P0Y<SL09S0f
02hi?`0Y<c`09c8m030lB00a?TP0>49;03@oA@0a?400<3ho0390@@0jB4P0<T9202hn?P0eAd/0<dA<
03Y;D`0fB5800P0mD5h0:014EfD0AEQV041BH010DV00@55O03E6E@18EfH0?diM04=@H01:F6L0@U=O
03i@G010DUh0AeUU04YLJ01>H6X0A5IP03a>F018Ff80AEQO04ULH`2<WjD0enOc06AdPP1MKGT0FFYd
05AUK@1?HFD0CV1S05a^KP1EJ6@0DFAP04YMEP1AI5h0Df=R05ATI01FIVH0F6QX05e]K@1PL70206Ad
M080IGEe0P1VMWH0701[Ng/0JWYj0720P01bPX80L7n007>1PP1eP880NXF707f8RP1nR8X0P8Z<08:<
SP25T9D0Q8nE08jIW`2BVj80T9VP09>LX`2HWjL0UijV09VPZ02MXJX0Wj>/0::W[@2RYj/0X:BW0:6U
Z02XZk020:j_]0060:b/]02b/KT0^KS00;Zh``2k^L@0_kg90P31_L`01`32_/d0aKk>0<W3d@3>b=H0
c/KD0=O?g03Fc]/00`3Db]D0<03Kc]d0jM_Z0>OIj03Pd^<0hM3R0>CCi@3We^T0jMK/0>_HkP3Ye^`0
j]C[0>[Dj@3ZeNP0j=GX0>SEjP3Ye^`0jMK]0>OEk03RdNH0gm3T0=k?h03KcM/0f<[H0=C7d@3<`LP0
b;g40<Nl`@2o]KT0^k:f0;bc]@2aZj`0[:JW0:nZZ02`[:X0YZ:P09fNUP2=TH<0QXYl07]oLP1bMFX0
KG=W06abI`1cNFl0O8Ai07ElM01gOWH0LG]b06ifJP80K7AW01d0MGe`07V1M01dOW<0Kg]a06]gK@1W
LfT0HFiU05i[HP1RL6P0IgMa061`K@1JJVL0EfQR05=TGP1FIEh0Be]A04UIC`1:Edh0A55703e:@00h
A3/0=d@m03U5@@0e@Cl0>TI406McL@0hA4@0>dI802Td=P0203M2AP0^05QSJ00^>Cd0D5aL04UED`0a
?C/0:SHd04EAC`0^>SP0:cLe02Xf=00X=380:cLe02di=`0S;b`08bl[028_:00U<R/0:SDa02Pc;`0Q
;2P0:S<`02Tb;`0O:2D09B/[02hd=00S:BL0:B/X02PZ9P0V:2D07b0R01lP8`0S92P06Q/O028S9P0T
9RD08bDT01hP700R91l0724J020U7P0R9b008RLQ01lT7P0M8Q`082DQ02HZ:@807b<R00T08BDT01lS
8P0T9R<092HS028T8@0O8Ah07R0M020R7`0M7a`00P0K7AX0100J71T07R0M02@V8`0L71X201/K6@06
01dM6`0L71X06a/I01`L6P0J6QP061PF0`0G5aD01P0J6AL05aHD01TH5P0G5Q@05A@B01LF50805A@B
00/05aHD01@C4@0G5Q@07a`K01@@3`0N6QT0510?01TE500K5aH05A4@01LC4P0201HB4@805a<B00T0
5Q8@01DA3P0F4Pl05a<@01@@3@0B3P/0510=01LC400H51400P0F4Pl0200I5A806ADC00d9200D40l0
71PG00l;2P0C3``04@h90P0B3`X0200A3PL040d6018?200D3``06A@A01<>2`0>2@H05A0=0P0A30T0
4P0B3@X04`h;01<>2`0C3P/04Pd:01TE4P0<20D04@d:018>2`0E4@h03@T601<?300?2`P04Ph;01HB
3`0B3P/040`901<>2P804Pd90P0A30P2010;1`06018=2@0G4Ph030L302@O6`0H4`l04@`8100B3@T0
500A30P040/7014<200?2PH03PT500l:1P0B3@T02PH300l;200A3@X040`900h:1`0?2`P0;RXW0:NS
X00M6AH05a<@00h:200?30X03`X70P0@2`P00`0A30T050l<01HA3P02018=2P0500`71@0D3``061<@
018=2P0C2@P00`0D2PT201<9208040H500`04@L601<9200D2PT050`:01082@0>20P040X:014;2`0B
30`050h>010:2P0?2@T200h820803@L700L06a4B01D;300?1`L05@/<02HL7@0>1@D04PP900@04@L8
01004@L901<8300D2@d04`P<01D:3P0F2`l050T=01872`0@1@T03`@801052@0B1`/04`T<01062@0A
1PX050T=0P0?10P201<8300800l4200@1PT03@@602/Q9013>3/04`T:00h41@0A1`P201882@0301@:
2`0B20T04PP9008050X;0P0A1`P01@0B20T04@L801061`0@1PL04PP9008050X;00@04PP901061`0@
1PL040H70`0B20L00`0A1`H040H501061@0601471PL040H700H03`D601<:2`0L4Q<03`D600h41@0=
0`@200l51P0?00h41@0@1PL04`T:01T?400@1`P04`T:01061`0=10@04@L800l5100>10<030810106
1@0E2`X03P@3008040H500@03`D4034W9P0H3Pd03P@35?ooool001_ooooo00@050h>01<=3@0A2`/0
4@/;0P0B30`03@0E3`l04`d=024K6`0f<3006A<C03H`<00E3`l04P`<00X4100D3Ph04`d=01H@400A
2`/00`0B30`2014;2`0>01DA400H51<06aLF014=300B3Pd03`/:018>3@0W8b805A4@01@@3`0C3`h0
510?01<?3P0B3Pd2014=300501HB4@0I5A@03PX900h:2@0?2`X00P0B3Pd01@0>2PT03`/:014=300B
3Pd04@d<008040`;00P03PX9014=300C3`h04Ph=00h:2@0@30/04Ph=014=308040`;00<04@d<018>
3@0A3@`00P0B3Pd00`0A3@`040`;010<2`05014=3003010<2`0>2PT06ADD00805Q8A00h05A4@01DB
4P0@3Pl01@<401@B4`0B41402PP9010>3`0:20T04@l@03@b<`0Q7b002@L8014>3P804Ph=0P0D40l3
014=30804Ph=00/04@d<018>3@040`403@`:00L61@0<2`T03`h<01TH5P0=30X03Pd;010?3@0300l>
300701<?3P0E4A004Ph=014=300C3`h04Ph=01@@3`0201DA400;01<?3P0D40l05aDB0=GFd@2d]Jl0
5QLB0042000B4Pl06QTG018A3`0B40l00P0B3Pl03`0C3Q0050h>01PB4P0G4Pl05A0=01@?300F4@h0
5a8?01PC400K5Q<06A@A02<N6`0H4a005A0=01LD3`0301@C3`0401HE4P0G5Q@061LE02LU9@806QPI
00l0518C018@4@0:20T05QDE01XJ6P0=2``02@P801PH600A414081hO020P800A41005Q@E01`L700A
4A400P0M7Ad201<C4`0301TI6@0E5AD05QHF00805ADE00H071`L018B4P0I5A@06QTG01/J600G5Q@2
01<C4@0<01HF500D5Q<05QPE01@F4`0C61@061dI01dO700N81d04aDB01LI5P0I6aP061XG0P0M7a`0
1@0L7Q/06adJ01dO700M8A`06QlI00<06QlK05D06QhM01`P7`0M8B00720Q01/O800M8B807b<V028V
:@0N8RD0;C4b01TN700P9R809bhW01`U7@0N:2007bPS028]:@0R;2/07bTZ024[:`0T;B`092h_02H`
<P0Y<cD0:C@h02Pc>00[=S`0;CY202llA00U<S/0;CU4030mA@0`?D<0;S`o02hl?@0`?Sl0<D5003M7
A`0_?cl0=dU=041AF@1;G6@0@59L03Y<FP0kCE/0@UAR045CH@0nCUd0A5AS04EBHP0oC5`0BEIV04EA
H@1:EVH0B5EU049BG`0oDEd0?U1L03mAG@13EF40@eEO05QZM017FF<0?E1G04EHG`1DIfh0HGAj09:S
[@1JJWL0H75k05EVL01?H6P0BeeQ04eOH@1@HV40BUeI04iQG@1;GUP0EFQT05EUI01EIFD0EVIV05UY
J@1NKVh0HG5a0080KWin01X0K7al06YjNP1YNGT0J7Qh06YjNP1[Ng/0LH6107>3P`1bPH40M8:307F0
PP1iQ8H0NhJ807b6R01nR8X0P8Z<08NBUP24Si<0QI2D08ZCV02AVYl0Uj2U09ROY@2JXJL0Vj:X0:2U
Z`80XZN]00@0Y:V/09jRY@2OXjH0YZZ]0P2/[K80LP2^[k@0];>k0;Zi`@2i^<00^;K10;bja@2o_L/0
a/;A0<g9f03;amD0bL?A0<c6e03>b=@0eloL0=O?fP3?am80c/C?0=77dP3Hc=X0f/kL0=W=f`3Md>40
gm7R0=k?h@3Sd^D0iM?Y0>ODjP3VdnT0i=7W0>?Ah`3Udn<0imGU0>OEj03RdN@0g/gP0=c<g`3Jc=d0
f<[I0=K:e@3Cb=00d<G=0<Zoa033^[d0`[Vl0<:i^P2k/[<0^[6b0;fh]@2]Z:D0ZjNT09VFT@2RWiX0
TY6<096BR@25RG/0OX9d07b1M01dNVh0LWQ/06ieJP1RJUl0IfmT06egKP1RK6<0IW1W06A/H@1YLFH0
LWY_075kL01`NVl0LWac06ahKP1ULFL0HVmV06UfK@1ZMfh0JGM`06UhL`1QLV`0FfaV05QWHP1AH5/0
C5]D04EBB`16Dd`0AE99045<A00lAcl0=40g041;A@0oBTH0<3Xi03@n?@1ZM7<0<S`m09bVY`17DE80
:38d03e7B@0Y<cH0?DM9030l?00_>cT0930^02lk>@0[=cD08Rh/02lk>@0]>CL0;3Pf030l>P0_>cT0
8Bd[024]:@809C4]01H08RdY020[9`0Q;2P0<CXg02Pa;P0O:2D07bDS020V900Q9bD0;2h[020R7P0Q
8b008R<U028S9P0:2`l09bP/024R9@0J71/07R0O01/M6@0W:B@07B8L0`0L8A/0500M8Qh07R<O01lT
800P92<05a/J02X^;@0P92D092PW02LY9P0V:2D08bDR01hP7@0M7a`07R0M01XL6@0N81d071hK01PJ
5`0I6aP06Q`I0`0K6aT201XJ600301/K6@0J6QP061PF00@05aLE00h061LE01/J600F5A<04a8@01HE
4`0G5Q@051<A01HE4`0J6AL04a8@00l>300J61H06aLF01@@3`806QHE00<061@C014=300D40l0100D
40l0100F4Q0061@A01HB3`0D40d201<?30804@d:0P0D40d201<?300901HB400H51<04`l>01DA400K
5aH06ADB014>2@0B3`X04a0;00804@h700D05Q<<01<>2`0@2`P05Q4>01PC4002018=2P0C014<2@0B
3@X04Pd:014<2@0@2`P03PT600d91P0H5140;2PU020L6@0A3@X0510=014=2P0=2@H040`901@@3@0@
30T03PX701<>2P02018=2@09014<200@2`L040/7014<200@2`L04`h:00@0000K5Q802PD100@03`X6
0P0@2`L2014<200N00l:1P0>2@D040/701<>2P0K5Q<04`h;00l:1`0B3@X04`h;00l:1`0;1P<0;RTV
00l:1`0400003PT600`7100=20D040/800h91P0<1`@03@P5014<2@0910403PT600X50P0D3``05a8?
00h91P0B20L04`T80P0D2PT201881`803`D400X040H501<9200F30/05`l=01@=3@0:10@02`D500d7
1`0C3@d071HF0P0=1`L02P0>20P03`T900l92@0?2@T05Pd=01<92P08000050X;00l51P0G3@h50147
200401882P0B1`/04@H:01872`8040D900<05``@01/@500F2`l00P0B1`/0400D2@d05P/?01872`07
00004PP;01T>4P0<0@D02P4301<8300B1`/05@X>028G6`0F2`l03`H701<92P0B20T201<92P0701X@
4@0M4a@04`T:01061`0A1`P04`T:01882@020147208040H700H04@L801882@0D2P/050X;01882@0@
1PL200l51P<04PP700<04@L601061@0@1PD01P0A1`H2014720@040H700L06@l@00h41@0B2@X02`42
00d3100B20T03P@5008040H701D03P@500l51P0B20T02P0100/30`0700004@L801<92P0E2``04@L6
00l5100>10<04`T801P>3@0@1PD050X901061@0A1`H0@3He01`B4@0?1@@05?ooool001_ooooo0P0C
3@d2014;2`0?018<300C3@d04`d=014;2`0Z92@0>38b01H@400Y8b<04@/;01D?3`0?2@T050h>014;
2`0G4A404@/;00<04P`<00h040X:00l92@0B3Pd05Q8A01TE500A3@`04Ph=00d9200@30/08AdL01<?
3P0?2`X03PX901<?3P804Ph=00@04@d<018>3@0G4a806QHE0P0B3Pd01@0I5A@05A4@00d9200?2`X0
40`;00804`l>00D03`/:00h:2@0?2`X040`;014=3002018>3@04010<2`0A3@`04Ph=014=308040`;
100A3@`00`0B3Pd04@d<010<2`06014=300E01@@3`0:1PD03`/:00D10@0?2`X04Ph=01HC4`071@H0
3`d>00P61`0:20T06ALH00`:2`081PL03P`=02l];P0L6Q/02@L801@A4@0B3Pd04`l>0080510?01P0
4Ph=00l;2P0A3@`04`l>018>3@0@30/04Ph=01`K6@0:2@L05A@B014@3P1>CD/0FeYH00d<2P0?3P`0
4A0>010?3@0?3P`04A0>01HB4@0G4a804Ph=014=300D40l2014=300=01<?3P0D40l0510?01DA400I
5A<0MWEa06AUG`0@4@`04Q<>01PH5@0?3P`051<A01@B4@0201DA4P0?01LB500I4a<05@l?01LB3`0D
3``04@`901@?300J5A8030L401`G500E40d04@`900l:1`0I5A8061D@00<05A@@00D05aHC01PG5@0F
5A<06ALG01/I6P0201DC500801@B4`0I6AT07AdM010@400X:2P0@D51014A4@0@410201HF5P0@010@
400;2`/03@d=01DE5@0C4a<061PH01<C4`0B4Q806a/K01PH600E5AD061PH01HF5P0J6QX04a<C01TE
50806aXH01H061LE01HF500F5Q@06ATG01<E4P0G6AH061XG01DJ5P0G71P09RPU02DW900Q8b007AlL
028T8@0>40d07AlL01hP7@0L7Q/06adJ01`N6`0L81`06QlI0`0J7a/0100J7Qd0720O01`P7`0L8242
01dQ8P1?01hR9@0T:2/05QXM01XN7`0K81l06b4M028Y8P0N9al07RPP01dX8P0R;BT08B/Z020Z:`0S
;Bd09Rl^02D_<00W<C<0:S@f02/f>P0_>Sl08bhd04QEG@1WM7d0;S]402hjA@0^>d<0<Ci4034o@P0`
?Sl0<d520351@00hB4P0;Clo03E7B`0mCUH0AUMO03]=E`0lCU`0>deK03m@GP0oCeh0?DeL04QEI@14
DF40Cea/04]GI`16DV80CEUY04QDI011DEh0@59N03i@G010DUh0AEMS04EGH@1<GVP0AeUS04AGGP1;
GVD0DfI]04IIG`1NKgT0EVMa05e^MP1KK7@0F6U_04mQH`1EIfL0D69Q04QKF@1>HEd0BUeG059UH@1E
IF@0EVIV05QXJ01KJf/0Gfm_065aL@0206]kN`0P06QhN01WMgL0IGEe06AdM01YNGT0J7Qh06inOP1`
P800Kgio07B2P`1fPH<0NXF707b7R@1mQhT0OXR:082:S020Rhl0QI2D08ZEV@2=UY/0SiRM096JW`2G
WZ@0Vj:X09bSZ@2RYjd0XjR^0:2UZ@2X[K00XjNZ0:2TY`2RYZT20:JW[00:0;2a]P2d/k/0^KS00;Nf
_P2e/kh0^KO20;^iaP3<b=L0f]KU0=GAg`80a/3>00L0cLOC0=79e03AbM@0b/;=0<Jla`39_lX0f<cJ
0080eLWG05L0gm;S0>;Di@3Ncn40hM3S0>;@iP3SdNL0hm3V0>;?i@3Rcn40i=;P0>GCh`3Sd^<0g/gO
0=W8fP3Fb=T0e/[H0=?7d`3AaLh0cL;80<Zoa@33^[`0_[Jd0;je]P2n][@0]:n[0;>^Z`2e/:`0ZZNP
0;Re[P2CT8T0WYjD09>CR`2=T8@0QHUk08:6N026Rgh0OhEi07IlL01^MFT0IViS06ifJ`1hPWT0Ig5X
06I`I`1SJf00Jg=X07EmLP1_NFh0K7I[06iiL01bOW@0JWE]06IcJP1]NW40JgQa06AbJ`1QL6/0FV]U
05MXHP1IJ6<0DV5L04]JD`11CTL0@e19045>A@0lAcl0>TDm03<n=@1ZMG40DeiJ03U3@P19De80LWak
03<m?P0X<S<0:C<d02hh>P0a>cd072HX02li>`0^>SX0;c/i038n?00oBdT0;3Pf02di=`0/>3H00P0Z
=S@0100^>SP0;3Pf01/W9@0L:2@2024]:@0`01lZ9P0P:bL09C0/02/d<@0U;R/0:34^02H/:P0K8Al0
82HR02H[9`0L7QX09bTX02<U900S92L0D55E05AEF@0V9bT05ALF01`N7@0Q8b00828M01lT7P0M8Q`0
6b0J01`Q6`0P9B408BHR01XO6`0_<c80<SHe04I:B@0O8b@0720O01hP7P0N81d07AlL01/M6P0L7Q/0
7R0M01TK600N81d071hK01TK600G6AH051HC01XJ600L71X06a/I0P0J6QP01@0L71X06ATG01PH5P0G
5aD05QHD00805aLE00P05aHD01/J600D4a4051<A01PG5@0K6QP05QDC01<B40805QDC00T05aHD018?
3P0>2PT03`/:020L6`0<20L0510?01PD4`0D40l00P0E4A00200D40l04`l>01DA3`0F4Pl04`l<014=
2P0@30T04Ph;0P0A3@X06@0D40d05A4>018>2`0A3@X04Ph<01PD4`0@30/03@T800l;2P070`0030T4
00l<1`0B3`X04@h701@A2P0L6A8061<@01HA3P0V8Ah0:B@Q01PC400B3@X03@P500h91P0@2`P00`0A
30T0300;1`@06QHC02l[:00O6aP02`L4014=2P0C3``03`/8018>2`0E4@h04Ph;010<2@804Pd90`0A
30P01`0@2`L04@`8010;1`0@2`L01@00018=2@070P000P0?2PH400h91@0O010;1`0B3@T04@`800l:
1P0@2`L04Pd9028M6P0F4@h040/801@?300G4Pl04`h;01@?300?2`T04@`900d81@0F4@h02@@1010;
200C3P/04@`900d81@0<1`@040/800d81@0E40d03PT601<>2`0b;BX0@chk01881`0301<920804PP7
01005@/:01881`0A1`H04@L601881`0B2PP02@4200h8200I4a<05@l?00X4100;1@D030H600d71`0>
20P03`T90P0@2PX01`0<10@050X;01T?400<0`@081HG01<92P0@1PL00`0A1`P08@0B20T04`T;0146
2P0@1@T04PL;00h31`0=0PH05P/?01T>4P0E2Ph04@H:01052@0A1PX03P@7024F6P0P5AT05@X>00h3
1`0=0PH07a@H01<8300:00<01`0000/0100?10P04@L901882@0C2@X04PP900h41@0D2P/06Q0A01<9
2P0201061`0401882@0C2@X04PP90147208040H700D04@L801<92P0D2P/04`T:01882@0301061`<0
4PP700<04@L601061@0@1PD01P0A1`H50147200801882@0<0P<01`0001D;300F30d01`0001L=3P0B
20T201<92P090147200B20T05@/<00T0000P5QL07aDF01P>3`0:0P803@<400804PP700X040H501<9
200G3@`04@L600`20@0=0`802P0001L=300700006a4@5?ooool001_ooooo00@04`d=018<300A2`/0
4@/;0`0C3@d0300A2`/05a4A01D?3`0A2`/040X:014;2`0D3Ph03PP801@>3P0A2`/05@l?01<=3@<0
50h>00d04@/;010:2P0>2PT04@d<01@@3`0A3@`0510?00/71P0C3`h05A4@010<2`0C3`h02`L60080
4@d<01D04Ph=014=300?2`X04@d<01@@3`0C3`h02`L601<?3P0;20L071PG03hj>@0H51<040`;00l;
2P0A3@`040`;00h:2@0D40l04`l>018>3@0C3`h00P0D40l00`0C3`h04@d<010<2`02010<2`<04@d<
0P0B3Pd7014=300E01<?3P050P405a<B018>3@0H51<03PX9018?3`071@H06aTJ02h/;@0B41403P`=
00d;300B41403`d>018@4@0D4Q<03P`=01<@400B3Pd04`l>00805A4@01<04Ph=010<2`0D40l05Q8A
01@@3`0B3Pd0510?01@C4@0=30X03`h<00T81`0P7ad07A`J00d<2P0@3`d04a8@014@3P0@3`d04a8@
0080510?01P040`;014=300F4Q40510?00l;2P0A3@`0510?01<?3P0B3Pd04`l=01/J5P0F5A005A@@
00h=2@0A40d04Q4?00l>300?3Pd040h?01@@4@0G4a@061@C01H@400F4@h301D@3@0801@?300M61D0
50l<01`G500H4a004`h;01XF4`0F50l301@C3`0Q01HE4P0G5Q@092<Q014?3`0T8R<040h?018@4@0?
3Pl04A4A018D4`0D5QD0@TA305iPG`0A4a805aTH018D4`0>40l051HE014C4P0E5aH051@B01LG5@0F
5Q@051@B01PH5P0M7A/061PF01dM6`0W9bD061PF01HF500I6AL06aLF00806QTG01806APF01XJ600L
71X06a/I01LI5P0O8Ah09BLT01PM6@0C61@07B4P01hR8@21QH@0Ce=B01LK6P0K7ah05QXI01TM700H
71/201HJ6@0301PL6P0I7A/06AdL00806alN0`0L81l0:`0M8B007b<R01hR8@0N8R80720R01lT9`0N
92@0728P01`S7`0Q:b<07RPP01lY8@0M:2808RdY020/:P0P;2`09C0`02H`<@0V<380:38d02Xe=`0/
=c/0:cLl02hk@@0nBe<0C5YR0350A`0/>d<0<3e403=0AP0a?d80;Shn03A4A00cA4<0<TA40312@P0i
C500=4M>03]>E@0jC5H0?dmN03a<F`0nC5`00P11CUh02@18E6@0Ce][07^7U`1NIgP0BeAU04aEIP16
Cf00A5AQ04EGH`02041BGP0H04MII@15Ef40AUQR049DGP16FF00BUeT04ULH`1@HfT0CEiV05]/M01;
G6<0DF9Y04mPI@1SMGL0BUaL04YLF`1:GE/0DFAP04aOFP1GJVH0E6AS05MWI`1KJf/0GVi^0P1PL702
06EeM@@0IWIf03@0K7al06UiN@1^OWh0L8200760P@1gQHH0Mh:407^6R01mR8X0OXR:07n9R`20RX`0
PHb@08JAU@27TYH0RY>H096JW`2DWJ80U9^Q09NNY02EW:80WJ:X0:6V[02NXjL0XJJX0::VY`2PY:D0
WZ:U0:BUZ@2WZ:`0/K:g0;:a]`2e];X0];>k0;Je_@2k^L<0^KO30;nmbP3;bMH0alCA0<2mb035`/d0
a;k:0<:laP38`/`0bL;:0<O0b03;`ld0d/OE0=O<fP3FbmT0fLkN0P3Kc]l0<03Mcn80gLkS0=g>h`3N
c^<0glkT0>3@h03Mc]T0flcI0=O9e`3Eb=L0eLSF0=C8e@3Aa]00cL;;0<W0a@34^kd0`;Rg0;Zc/02f
/Jd0]k:^0;>^Z@2WXid0YZ:L0:FSV`2c/jP0f][?09>DR@2EUhX0SY2408^?P@24RW`0OXAf07b2M@1n
Q7P0Lg]^06]cI`1eOW<0M7ic06afK@1^N6l0JWI/06A^I@1WLFP0KWQ_06miL01/MVh0JWE]06ijLP80
JgQa01/0IgI`05i]J01IJ6<0GfiW05MVG`1CHU/0E6=L04mNE`1:Ee00?da5049?B00nBD<0=d8j03U4
?00d?SL0=d8n034k>P0e?ch0<3Xi03<m?00]=cH0;3Hg038l?@0W<C80:cDf030j>P0Z=3@00P0^>SP0
100d@3h0;SXh02Xf=00Z=S@202Te<`0=02/g=@0b?S`0<3`j01hZ:00V<S008Rh/020/:P0R;2/08bh[
028]:@0S;2T08R/W02</9`0202L]:@0=02@Z9P0V:bL07B8P02<W9P0[;bh07B4P05QLG014B4T08RHV
02@X9`0H71/08BDS020U8@0201/P6P0I01`Q6`0N8al07R<O01hS7`0R9RD07B4R01PL7@0Y;Bh05QXK
02DY:@0P8R00828O01lQ7P0L7Q/07AlL01lQ7P0K7AX06Q`I01LI5P0M7a`07R0M01PJ5`0L71X07alM
01hN700201`L6P0301hN700I6AL05aLE00805QHD0P0G5aD201PG5@0?01LF500M71X06QTG01LF500F
5A<051<A01TH5P0H5aD05QDC01HD4P0S7ah04@d<01PD4`0A3@`071PG00805a<B0P0H51<01`0F4Q40
5A4@01DA3`0E4@h05Q8?01DA3P0D40d00P0C3``201DA3P0E01<?300A3@X04Ph;014=2`0C3`h03`/:
01PD4`0D40l0;2PU00h;1P0A3PT04Pl:00h;100?30D05a@=014<2@0I514071LD01LB3`0F4@h04`h;
00804@`90`0B3@X0100A30T04Ph;00`81@0E4@h2010<2@804@d:00D03PX7014=2P0D40d04@d:00l;
2002010;1`804@`800/04Pd901<>2P0?2PH040/701<>2P0E40`04@`801@?2`0B3@T04@`8010;1`02
00l:1P0900d8100?2PH04Pd901<>2P0B3@T040/7014<200C3P/04@`9008040/800/04Pd:01<>2`0A
30T040/801@@3P0<1`@04`l<01<>2`0@2`P050l<018=2P0200h91P0701<>2`0L5a@040/8014<2@0H
4a008ahK02`W900201881`804`T800@04PP701471P0F30/04`T80P0A1`H0200C2@P04`/900l8200E
3`l08Q`L01`F5P0=1`L03PP80P0?2@T200h820803@L700H04`X;01D;300D2P/04@P900d51@0D2P/2
01061`040147200B20T04PP901<82`803`@801H050T=01052@0@1@T050T=01872`0@1@T03`@80105
2@0A1PX05``@03`a=@0b9b/060hA01D:3P0:0@<04PP;01052@0I3Q805P/?00l4200C20`04PL:0P0>
10D0200C2@X040H700h41@0?1@H04@L801@:2`0C2@X04@L80P0C2@X301061`080147200C2@X04PP9
01882@0A1`P040H70147200B20T301881`0301471P0@1PD040H500H04@L60P0A1`P02`0C2@X050X;
01@:2`0E2``0N6i_071VI`0@1`P060h?00/20`0M4a@040H700804@L800L03P@500l51P0A1`P05@/<
00d41@0?1`L03`D600804PP900`040H501@:2@0@1PD040H501<9200A1`H050X901061@0K4A002P40
01H<2`0h;RdDooooo`006oooool601<=3@0800/51@0D3Ph030H602@N7P0E3`l05Q0@01@>3P0B30`2
010:2P03018<300D3Ph04P`<00@04@/;014040X:01<?3P0J5QD00`00010<2`0>2PT03@T801@@3`04
00004Ph=014=300G4a802@D4010<2`0A3@`04Ph=01<?3P0201@@3`0@00/71P0E4A003PX901DA400U
8B00[JVX02DQ800>2PT04@d<018>3@0A3@`05Q8A00h:2@0A3@`04Ph=01<?3P<04Ph=00`040`;00l;
2P0@30/04Ph=01DA40050@008AdL048n?@0A3@`02PH501PD4`0C3`h2010<2`804Ph=00d04`l>01@@
3`0C3`h04Ph=00l;2P0>2PT04a0@00<10P0c<C80LFm`01XH6@030@805A<D00803@/<00X040h?01@B
4`0E4a@04a0@014=300B3Pd05A4@01PD4`0K5aH04Ph=0P0D40l0;P0A3@`040`;014=300D4a404Q4?
00l>300=30X03Pd;014@3P0@3`d03`h<00d<2P0<2`T03@`:00l>300>2PT03@T8018>3@0E4A004Ph=
01@@3`0A3@`05A4@018>3@0A3@`05a<B01PD4P0A3@X04a0;01HB3`0B4@d040l<010?3@0D4a403`h=
00P61`0<2P/0518C00d<2P0B3Pd04@d:010<2@0G4a007QXG018>2`0C3``301DA3P0?01PD4@0L61D0
5A@?01DD400N7AT04a8>00h=2P0O7Q`0:BPV014@3`0B41405Q@E00h<3@0@410051@D008051HE01T0
5ALF01LI600H6QT03a4@01HH5`0D5QD0418A01DG5P0L7Qd051@B01<C4@0E5A<06QXH01PH5P0E5A<0
5aLE01XJ600H61H05ADC01HF500H61H05a<B01HE4`0G5Q@06APF00806ATG00/05ADC01DG500E5a@0
5QPE00`A3@0D6AD041HD02T_;@0H7Q`08RPV01DK6@0201HL6P0;01PN700J81h06AlM01TO7@0H7A`0
61`K01LK6P0I7A`06alN01hR8@0M8B000P0K7ah201`P7`0?01dQ800O92@0724T024W9`0R:BL07bPS
01lY8@0K9Qh07RTQ01hY8`0S<2/08Bd[01l[:`0N:BX08B`^00809C0d03h092lc02Le>00X=SX0:cPn
02/j?`0Z>Ch0=DA902`mA00eA4T0=4=803=2A@0b@T80=4A403A7A@0nD500<4A303I9C@0gBe80<TI=
04=FH00nCUd0?4aK045>GP1<FFT0=T=C04]GI`1AGFd0UJ6a05aUMP1;E6D0@daM04aDIP15EF80A5IR
03U;E`0kCET0B5YV04MIH`15Ef40@UAN04EHG`1>HFP0DFA[04aOI@1:Ff80FV]b059TJ01:G600CEmR
04UKG@19Fe/0CF1O04iQG`19G5P0AeYE05EXI01AHF00EFEU05][J`1MKFd0GVi^05e]K@80I7Ad00h0
IWIf06UiN@1[Ng/0JGUi06YjNP1[Ng/0K7al06inOP1cPX80MH>407Z5Q`1kQXP0O8N907n9R`80PH^=
02/0Q8nA08F@TP24Si40QHnA08ZDUP2=UiT0TYZM09JNX@2KXjH0VYnS09VNXP2NXjH0WJ>R09JJV`2O
Xj@0WJ6R09fNXP2WZ:`0/;6e0:n^]02`[kD0];>i0;^j`02n_LD0^;S30;^ka`2l_<P0_K_60<6nb@34
`LX0`;g60;Vc_@30^l80`kk50<[5c036`LP0clSE0=;:e`3Fc]/0dLWH0=35e@3Fbm/0e/_L0080fLcP
00`0e/WM0=?6fP3EamP0e<SD0=G9e@3Hc=T0c/;@0<c0cP3?aM40bl7:0<Voa`2o^K/20:nZY`0a0;6^
Z@2]ZZ<0clc50:bYX02=SH<0YjNM09RHS02FV8/0T9:508Z<OP28S7d0RXio08Z?P01nQ7H0NX1b07Mn
L01XL6<0IViQ07=lL01jQ7T0NHAi07J2N01bOW@0JWI/06miL@1/MVh0JWE]06QcJ`1UL6X0J7A]061/
J01SKf/0GVeX05]ZI`1MK6T0FfYV05e/I@1=GE<0Df=I04MDC@1GI5d0EF9K041;A@0jACl0A4e803Dn
>@0f?cX0?dQ302lh=@0203Dn?@030419B00lAD@0;SLf00<0;cPg01d09Bh]03Q1?`0mAdH0;3Pf030l
>P0X=380930^02Xf=00^>SP0=D4o02Te<`0^>SP0@Ti<04EAC`0U<Bl07BTY02Pd=00^>SX09c4`01lZ
9`0X<bl08b`Y024Z9P0S;2L08bXS020W800T:RH06AlM024W9@0201lU8`0J02@Z:00T:RH0<SPf01`R
800M8b406R0N02<Y9`0F71X06QlK010E4@0[<2`07b@P024U900M8B007R8S028V9`0G6a`092P[01/O
8P0K7b00828P02<U8P0[;BX07R0M014C400L7Q/601/M6P1701TI5`0M7A/071`J01dM6`0W9bD07alM
01LG5@0T928051@B01<C4@0Q8Al06ATG01PG5@0D4a4040l=014@3P0L6aT06QTG0081000F5A<05A@B
018A3`0920H05A8A01@@3`0F4Q4061@C01LC4P0F4Q405a<B01XF5@0C3`h05a<B01TE500B3Pd04Ph<
018>2`0D40d05A4>01@@3@0B3P/05a<@01<?300:1P<05a<@02<O700j=S<02`L501@@3`0A3@`03@T8
01HB4@0A3@X02`P301XG4P071080514:018?200C40T05Q4>00L2000B3@X0?STf018=2P0D3``03PT6
010;200E40d0<2/X01HA3P0C3P/00`0C3``01P0B3P/04@d:014=2P0D40d04Ph;014=2P804Ph;00P0
40`900T4000D3`/05A0<018=2@0:1@404Pd901<>2P803`X60P0A30P00`0=20@040/7010;1`0200h9
1@803`X600d04`h:01D@300F4@d05Q4=01D@300C3PX04@T7018:200A2@L03`L501081P0B2PP04@T7
00804`/900D04@T700l71@0@20H03@P500l:1`02014<2@0300l:1`0=20D03@P5008040/801P03PT6
010;200B3@X04@L601<9200D2PT03P@301061@0H3Pd040H501D;2P0G3@`05@/:00l5100;0`403PH7
00/51@0?2@T03@L700/51@0>20P03`T9010:2P0A2`/3018<30H04@L800/04PP901061`0>10D05`d>
01P>3`0@1@P05@X>01T>4P0E2Ph03`@801052@0201462P0801<8300E2Ph04`P<01462P0?10P04PL;
01H;3`0E2Ph201462P0>01872`0F2`l0GE9F01052@0K41@0304501472@0>10D05P`=02<I6P0=0`@0
200001@:2`0A1`P201061`0D0147200B20T04PP901/A4P0=0`@05`d>01D;300D2P/01`0001hD5@0B
20T060h?01061`0?1@H0308101D;2P0?1PH040H501D;2P0?1PH601471P0<00h41@0A1`P04`T:0147
200@1PL04@L803/a<P0Z82404PP900h41@0B20T04@L8300@1PL301061@0901471P0B20L04`T80106
1@0B20L04`T801471P0B20L050X901Cooooo000Kooooo`H04P`<00P0618B00h8200F4100Ad5103<]
;@0<1PH04`d=018<30804@/;00<04P`<01<=3@0A2`/01@0A2`/0300;1`H05a<B00X61@0D40l05a<B
01@@3`0F4Q403@T8014=300@30/04Ph=00d920D04Ph=00T04@d<02PT8`0A3@`00`0001HB4@030000
;b/Z01TE500<20L00P0A3@`01P0=2@P04`l>010<2`0A3@`04Ph=01<?3P804@d<1@0B3Pd0200?2`X0
5Q8A04I2@@1NFUT06ADD00H20@0@30/04Ph=0P0D40l0100A3@`03`/:010<2`0A3@`2018>3@804@d<
01h04a0@00`:2`0A3a008b4R018@4@091`P0518C01HD5@0B414030X;00T7200;2@X03``<014=300B
3Pd04`l>01@@3`0G4a8040`;018>3@0C3`h040`;00l;2P0A3@`04Q4?014@3P0?3P`03@`:00h=2`0A
40h2010?3@803`h<00<040l=014@3P0E4A000P0?2`X0700E4A00510?01@@3`0B3Pd05A4@01<?3P0B
3Pd05a<B01PD4P0>2PL04@h901@@3@0A40`04A0=018A3`030P004Q4@01@B4`0H5QL03@/<01DD4P0B
3Pd04`l<014=2P0E4@h06ADB010<2@0A3@X301<?300?01HB3`0J5Q<03@`7010?2`0A40`030/703Pg
=00A40h02`X801<A4@0M6a`081hO01/I6P0C4A8051@D00<05ALF00/051HE018D4`0@4Q4051HE01<E
500A4a805QPG01XL6`0J6QP05ADC01@D4P0201LG5@805ADC0P0H61H01`0F5Q@061PF01XJ600M6AP0
6QTG01TH5P0H5aD00P0F5Q@01`0Q8Al04Q@A01lQ7P0J71T041DA01@I5@0K8Al00P0D6QP0100J81h0
5Q`J018H5P0I7ad201PN700301XP7P0K8Al06QlO00806AdN02406QhM01dQ800O8b807R8Q01/O7P0M
8B007b<R01lT800N8al07B8Q02ld=`19Cdl0=Sdk01HO6P0N:B409C0X01lZ8P0O;2D09C8]02@`;P0R
;Rh08bh_02@_<@0V<CD0:3<g02Td>00Y=cX0:SLl02/j?`0Z>Ch0;ci3041?E00eATd00P0a@4D0<P0b
@D@0<d=30394A00dAdD0;D5003iBD@0nDED0=DU@049FG@0jCUL0;d5?04YJJ@14Df80?daL05MTM00m
BET0E61`07J2TP1>EfP0Dea]04QAHP17DV80@U9O04AFHP12E600BeeY05a^NP1OLG/0AeUS04IHHP18
Ff80CV5X04mRJ@1<GfD0A5EL05=UJ@1;GF40A5IJ04MIF`14EUH0B5YJ04EHE`1<Ged0CV5M05IYI01B
IF40EFET05QXJ01LK6`0GVi^0P1OKfl00`1RLW80I7Ad06IfMP0206MgM`0P06QhN01[Ng/0K7al06em
O@1_Ogl0M8>307J4Q@1iQ8H0NXF707b7R@1nR8X0PH^=08:<SP24Si40QI2B08B?T@26T980RYBF08jH
VP2;TiH0RI6D096IW02KX:@0W:6U09jSYP2KXJ00VinP09ZNW`2LX:40XjBX0:FVZP2a/[H20;2_]@07
0;:a]`2e];X0]kJn0;Jf`@2i^LD0_Kg90<;0b`020<:ob0090;Re_P2j]K`0`Kc30<6l``39a</0b<?:
0<[4c`3;aM40dLWF0080c/KE01P0e/_K0=G:f`3Gb]h0f<_O0=G8g03Ca]X0cl?C0<c0c03AaM40el_I
0<g2d038_L/0bl3=0<O0b036_lH0`;Zk0:n[Z02YYZ40[JZT0::OV02QWYD0UYJ<09NGS@2NWY8208nA
Q00h092BQ02>TX<0R8am08F9N01oQGD0NX1b07QnL01_MVP0I6aO06M_HP1dOW80NH=h07F1M@1bOW@0
KWY`06YfK01ZM6`0J79Z06YeK@1ZMFl0IG1Z06EbJ`1NJVH0HFeY05i]J@1KJVL0G6]X05YYI@0nCDH0
C5aB04UIC`1<FE80SIZC07b9PP1BGEL0AU5;03e6@@0g@3/0>T<n02lh=00/=C@0=Chm03@m?00g@3l0
<c`k030i>013C4/0<c`k038k>@0a>SL0>D8o041;A`0Z=3<0:cLe02Da;`0T<2h202Te<`0?02hj>00/
>3H0;SXh03E1?`0`?3X062@R024];@0W<c<0<Cdm038l?@0V<2l082/W02H_;00R:bH08B/S00808RTR
0200:c4]03<i=`0Q9bL09R`Z02X`;P0S:BD09R`X024W8`0N92408RPV02le<`0N92<06R0P02/`;@0A
5Q805a`H01XO6`0T:2L07B4P01hR8`0S9bP05ATJ01XN8@0S9bX051PI01lQ7`0R92404A<@020R7`0U
9b@03a4>01`N6`<06adJ0P0J71T0600P81h07alM01/K6@0F5Q@071`J01<C4@0B4Q003Ph<00T91`0I
6AL06a/I018B400E51807QdK01/J600S8R005aHD00h=2`0C4Q008R4O01HE4`0M71X04Q4?01PE5080
6ADD00H061@C01HB4@0E4A004`l>01PD4`0D40l201DA4003018>3@0F4Q00510=00@0510=01P03`/8
01<?300P71T071PE00l;200C3``0<2`Z00`81`0A3@`06aLF020L6`0A3@X03P/601DB3@0@3@P071TB
00h;100e<R/08A`I01@?300J5A80;2LT01PC400B3@X2014<2@0400`71@0O6QL03`X7014<2@<04`l<
00D04Ph;014=2P0A3@X04Ph;010<2@0200l;200500h:1`0<20D05a8>01D@300F4@d00P0<1`<0100A
30P04`h:010;1`0?2PH2014<200500d8100A30P040/700l:1P0@2`L00`0A30P01P0B3@T04`h:01<>
2P0B3@T04@`801491`804`/90`0B2PP0200@20H04`/901<;2@0A2@L040P601491`0>2@H03`X70P0@
2`P03`0?2PL03PT600X50P0<1`@03`X7010;200A30T04Pd:01471P0<0P402`4000l5100Q5aH0<2HU
01H<2`0201L=300?01H<2`0D2PT04@T701092@0=1`L03`T900h8200=1`L04@/;01@>3P0?2@T030H6
00X4100;1@D030H600804@L80P0B20T20147200601882@0@1PL03`D601H<3@0G3@h04@H90P0A1PX0
3P0B1`/040D900l4200?10P04@H:01<8300E2Ph04`P<01462P0>0`L040D901<8300B1`/03P<70P0?
10P030070000=BX^00`21@0C20`0200101882P0H3Pl040H701892P0K4A804`T:00l51P<040H700T0
4@L801882@0A1`P06Q0A01882@0J41405@/<01061`0Q5aP00P0800002@0?1@H04`T:00l61`0B20L0
8QPG02HL6`0E2`X060h=00h40`0601471P0;01D;300H3Pl05@/<01882@0E2``04@L802LM7P0M4a@0
40H700l51P0B20T03@0@1PL0100B20L04@L600h40`0>10<200l5100600d30P0@1PD04@L601061@0B
20L050X95?ooool001_ooooo1P0B30`01@0?2@T04`d=00d71`0J51@04P`<00804`d=100B30`04`0C
3@d03`T9010:2P0A2`/04P`<01<=3@0D3Ph04Ph=01<?3P0D40l02`L601DA400B3Pd04`l>01PD4`0?
2`X05A4@00l;2P0D40l00P0C3`h02P0B3Pd04@d<010<2`0@30/03@T801XF5@0:1PH05A4@00d9200B
3Pd200l;2P0401@@3`0A3@`03PX901<?3P@04Ph=00l040`;00l;2P0A3@`04Ph=01<?3P0B3Pd04@d<
01<?3P0:1PD03@T901PD4`0?2`X040`;018>3@0E4A000P0L61L01P0B3Pd03`/:00h:2@0?2`X04@d<
01<?3P80510?00h03``<01HD5@0@3Pl03@/<01<A4P0>30d04@l@018@4@0E4a@04Q0A00h<3@0@3Pl0
4@h>010<2`<04Ph=00@04@d<00h:2@0@30/04@d<0P0@30/00`0B3Pd03`h<00l>300200h=2`0500l>
300A40h03Pd;010?3@0B4@l00P0D4a402@0C4Q0061@C014=300?2`X05A4@01@@3`0A3@`04Ph=01<?
3P02014=300E01@@3`0F4Q004@`901@?2`0F4Pl05A4>01DC400F5A<040l=01@C4P0;2`/051@D010@
400F5Q@03`h<01<B3P0B4@d040l;018A3@0@3`/03@`800<040l;02L04Q4=01DD400D4`h05QDA01/J
5P0@3`/0?chk01HE4`0E51804Q4@00l=3P0D4Q<06QPI01<A4P0F5AD06APH01XJ6P0J6AX05QDE014A
4@0D4a@04a8B01<C4`0G5QH061LH01LG5P0J6QL051D@01<D3`0E5Q4061TD01XK5P0E5Q405aPC01PI
500I6QD06Q/F01/L5`0K5aH00P0I61H0300J6AL06ATG01TI5`0S8b40:R`Y04a>B`0K7AX04QLC01dR
7P0F71/04aTI01TO7`8061hN0P0K8B4201TO7`0N01XP800K8B40724S01/O8@0K7b007B4R01hR8`0O
8b807R8Q01`P7`0N8al082DQ024V8P0Q9R4082HT01`T9P0T;B`09Bh[024[9P0R;BD07b/R01l/8`0O
;2D0938]028a;P0Q;bl0934b02Ha=@0X<cL0:SLj0P0[>C`02@0/>Sh0;3]002Ph?@0]?d<0?4iB03A6
BP0^?D80;ci30312A00203=5A@0_03=6A00nDU40;d=203U>D@1bQXd0CF5X03eAFP15EfD0?U1N04AF
I014EF@0@E5P04UGI`1:EfL0EV=c05UVMP1?Ff/0>TIF04eIJ@16EV<0B5YV04MII@1;GFT0E6Ib05=U
K`1:G6H0BeeW04ePI`1;GVD0BUeT04ULH@1:G5l0DfEW04eOH@18FU/0BeeM04YLG01?HF00B5]I05=V
I01DIf<0Kh9n05U/J01MKF`0GFe]05i^KP1OKfl00P1RLW800`1SLg<0JGUi06YjNP0206MgM`0>06]k
N`1/O7`0KGem06inOP1`P800MHB407N5QP1hPhD0NHB607^6R01oRH/0PXb>08>=S`24Si4208JAT`04
08RBU02<UYP0SiVK0:R`/`80UYjQ0380Vj2T09FJWP2AUYT0WjFT0:BXY`2IWI`0VinN0:NXZP2TYJL0
Zjb`0:j]/P2`[k@0/[6g0;>b^02c/[T0];Bn0;Rh`P2k^lD0^k_40;Zi`@2i^<00/:fd0;Ba^02m^/40
_[Vo0<S3b@38a</0blSB0<W6d@3;a]80blGC0<g7e@3AbMT0d<OH0=?7f`3Db=`0dlOK0=;6fP3DbMX0
e<WH0=35e03>`m@0b/7@0<[0d039`Lh0`kk50<6l`P2o_;`0/K2/0:JUX080WYjF0700UiN=09^LTP2C
UHX0RH]o08N:O@1mPG<0Nh1a079iJ@1ZLF40JW5O06mfIP1fOVl0Lg]/065YF`1PJ5/0I6mQ06mjK@1b
OW80K7Q/06IcJ@1ULVP0J7E[06IaJP1TKfT0JGA^06YfLP1VLVh0I71/05e/J@1QL6d0Gfe/05UYJ01J
JVT0EFES04mNE00kB3h0@Tm604=@A`17E4/0B5==04E>B@16CdX0=Sll03Dk>@0l@T00=3Xh03]4A014
C4h0?4A6038k>P0[=3<0<3Tg04I?C00]=S<0;CHa034j=@0_>3<0<C/g02dh=@0]>CL0:SHd02di=`0a
?C/0;3Pf02Da;`0]>CL0;c/i02`h=P0Y=C<09C4`06agN014Ce40:C@e02Pb<`0X<S409c8^02hg=00W
<B/09BlW02L^9P0[<RX0=chg069XJ00T:R/06R0N028X9P0M91l0<3L`020W800S:B@05A/H024W9P0I
7R008bTY01lT8@0O8b807B4P02L[:P0R9RL082@U01`P8@0Q9BP0H6AW03/o@P0Q9BP082@U01hP7P0R
9240@D=001hP7@0G6AH05QPE0`0K7AX301XL6@0L01TI5`0L71X07AdK01PH5P0K6aT04a<A01TI5`0D
51808R8P01DE4`0l?3X0VIVG02h]:`0F5A<05aHD02HU8`0>3@/06APF01@C4@0I61H04A0?014@3P0@
3`d071XH01dI600K5aH05a<B01DA4080510?00h06aLF01TE500G4a80510?014=300H5180510=018>
2`0A3@X04Ph;01<?300E4@h05a<@01@@3@804@d:018081`I09B@SP0R7Qd020@301LC4P0C3`h05A4>
01@A300K61<04Pl:01LD3@0A3PL07a`E01hI5P0F4@h07QTF010;200K5Q<2018=2P0501LB3`0@30T0
5A0=01<>2`0B3@X00`0B3P/3014=2P0B00l;200>2PL03PX7010<2@0A3@X040`900d8100B3@T03PT5
01HA3@1KEU807QTE018=2@0A30P040/7014<200@2`L03`X60`0@2`L01@0A30P04`h:01@?2`0A30P0
40/700803`X600@040/7014<200?1`D040P60P0C2`T01@0B2PP03`L500l71@0B2PP04`/900804PX8
00<04`/9014<2@0@2`P00P0>2@H0400@2`P04@`900l:1`0>2@H03`X7010;200;1P<02@@100l5100A
1`H050X901471P0C2@P06@l>01H<2`0E2`X201@:2@0E01D;2P0D30X040P900d71`0@2PX03`T900d7
1`0@2PX0;RPX028L700H4Q8040X:00h8200?2@T04@L801<92P0D2P/04`T:0147200@1PL04PP90080
40H70P0E2``02`0D2@`04@H:00h31`0A1PX050T=01462P0?10P04@H:01<8300E2Ph04`P<00804@H:
0P0B1`/01P0A1PX040D901462P0D2@d03@@600`31@804`P<00P03@8601H;3P0E2``03@<401H<3@0A
2@T050X;024G60<03`D601@040H70147200A1`P04@L800d3100B20T050X;01`B4`0I3a005P`=02TO
800b:2T03`H701@:2`0J4A402P4001471P0<0`80718A01@:2@H04@L600H03P@501@:2`0@1PL050X;
028H6@0N51D201882@040147200@1PL040H700l51P`040H700L04`T801471P0?1@@040H501@:2@0G
3@`03P@300804@L600<040H501471P0B20L05?ooool001_ooooo1`0A2`/201@>3P0301PB4P0C3@d0
4@/;00H04P`<01003PP8010:2P0@2PX04P`<01<=3@0D3Ph04@d<00/71P0I5A@03@T801DA400A3@`0
40`;01XF5@0B3Pd08alN0P0G4a82010<2`804@d<0P0B3Pd02@0D40l05a<B010<2`0=2@P03`/:00D1
000A3@`04`l>01@@3`0200l;2P0601DA400D40l04`l>014=300@30/03`/:0P0@30/03P0?2`X03PX9
00l;2P0@30/03@T8018>3@0L61L06ADD00l;2P0@30/04@d<01DA400J5QD05a<B0P0?2`X00`0A3@`0
4Ph=018>3@0201<?3P0@018>3@0A3Ph030X;00/92P0>30d02PP900h<3@0@3Pl02PP900P61`0<2P/0
8AlP03Tg>00/:BT03PX9014=3080510?00@04`l>00l;2P0A3@`04Ph=0P0A3@`02P0D40l03Pd;00h=
2`0>3@/03`h<010?3@0A40h030/900h=2`0A40h201<B4009018A3`0C3`h05A4@01`H5`0J5QD04`l>
018>3@0D40l04Ph=00804@d<03<04Ph=01@@3P0E40d05Q4=01LB3`0D40d0510>01HB4@0?3P`0410?
01hN7P11@d80CDm>014A3`0>3@/04a8>01DD400C4Ph04Q4=01LF4P0>3@T04A0<018A3@0A40`04Q4=
01@C3`0=30L051<?01<B3P0F5A403@`901HE4`0K6QP040l>01@B4`0>30d03@/<02/Y:P0D4Q<05a@E
01TG600K5aP05a@E01<A4P0G51D0510A01<A4P0J5aP06aLH01HE4`0C51000P0D5A00100E5Q4061TD
01XK5P0I6QD201PI500d01TJ5@0H6A@061TD01`H5`0L6aT07ahL02<R800U9B<09RHT01PH5P0];b`0
E5IC01HH5@0@5A407R<O01DL700O:2L04Q/J028[:P0?61L05b0O01DN7@0H8B006B8Q01LP7`0E7Qd0
5a`N01XN8@0K7b80720R01dQ8P0M8B007R8Q01dQ800K81`06b0K01hS7@0Q9R009R`Z028Z;00T;B`0
6R@P01HQ6`0P:b<0934X028_9P0N;BH08S4/01l^:`0N;2`08Bla02Db>0<09c@j00<0:STn02hm@@0a
@4<00P0`@T@0400eAdT0=DU:0394B00cADT0=DM903E7A`0cADD0<DE303Q>C00N=380?U=F092W[@18
GfD0=TeE04III`0lCed2041CH@0P04YLJP0nD5h0D61_04IFI@1AGfl0C5UY04YGI`17E6@0@e=P04EG
H`17FFD0BE]W04aNJP1:G6H0BeeW04aNJ01>HFP0BUeT04MJH@15F5d0BUaN04iPH019Fe/0AUQH04UL
F`1;GU`0C5mM051SH@1CIV@0@eIB069eL@1JKFT4061`L005069bLP1SLg<0I7Ad06]kN`1/O7`00P1X
N7P0501/O7`0JWYj06]kN`1/O7`0Kgmo07>2PP1ePh@0MX6307V4QP1lQhT0P8Z<08>=S`25Si40Phn?
08JBTP28U9@0RYBE08fGV02@VY/0WZJX0P2CVid0302EVYd0V9fP09bRXP2GWIX0V9bK09VMW02KWih0
YZNY0:j_/@2XZJ/0[Jba0;2_]080/[6f01H0/[6g0;6c^`2g^/<0]KS10;6a^@2i^<00`L360;Bc^@2^
[;40];:g0;Vg_034`/L0`[o60<_8dP37a<l0a<7<0<K2d03<a]@0c<KE0<_4e03=a=L0c/GH0P3=a=L0
8@3Cb]`0d/WJ0<W0d@32^L/0a;_<0<JmcP36`<d0`[c60;^h_`2j^;X0]kJb0:f^Z02TYIh0VIZB09nP
V02c]:`0XZFJ08R;P01_LfH0IVaN069XFP1LHe@0GfQG06QaH01]MFD0Jg=T06A/G@1GHE80GfYL069]
G`1VLF@0K7Q/06EcIP0205i[H@0/06EbJ@1[MW00IG1/06EaK@1YMG<0Ig=a06EdL@1RL700IG=c05m_
KP1HJ6P0EfMW051PG`0lBD00>dPn04MDBP18Dd/0AE1804MBBP0kA3l0@DY503]1?`0c>CT0>T1003Lm
?@0_=3L0=3Tl02db=@0`=SH0;C<c02`b<00a=cD0;cDa03@j=P0]=2d0<CPa02L`:`0/=c<0:cLe02Te
<`0/>3H0<3`j02Xf=00/>3H302/g=@13030l>P0iADD0<3/m02@_<P0T;c40:S@e02Tc<`0X<bl08R/X
01lY8P0Q:b<08RTQ028Z800Z<BX09c0_01TQ8P0R:bP0:c@a02@^9`0O:B405R0H01lY8P0N9b8031DD
03@m?@0Y;bl07b<R01DI600U:BP0B4a;028V9`0Y;Bh08bLZ010D5`0c=cX07B0U01/N8`0B5QT07b4O
02`^:`1YJfP08B<P010B3`0U9b@05aTF01PJ5`0I6aP06adJ01`N6`0M7a`06a/I024Q7`0V9R@071`J
01LG5@0>3P`06a/I00D50`0C4a402@T701lO7@1eMG<09bHT01/J600P7ad0<S4_00d<2P0201@C4@0B
01dL6P0L6aT051<A01TH5P0D4Q006ADD01LC4P0E4A00510?01DA400G4a806QHE01@@3`0G4a806ADD
01<?3P0F4Q00510=0P0E4@h08@0D40d04Ph;014=2P0E4@h02PH3020L6@0810402`L401hJ600B3Pd0
71PG00X61P0@30/040`9010=200D4@`03P/601LD3@0M6Q<02`P4010;20080`006QDB010;200B3@X0
4`h;00l:1`0E40d05Q4>010;200I514050l<010<2@05014=2P0<010<2@0?2`P03`/8014=2P0B3P/0
4@d:00h91@0H4`l04@`802DP7025P7`0;2LS0P0A30P2010;1`803`X60P0=20@01P0>2@D03`X6014<
200C3PX04Pd9014<20803`X600L04@`8018=2@0?1`D04@L601@:2@0G3@`05@/:008040H500L04`T8
01D;2P0D2PT050X901@<2P0A30T03`X700803@P500D03`X7014<2@080`002PD200h91P03018=2P08
01H<2`0>10<03P@301061@0J40l091XI01061@0B20L201<9200601061@0>1P@03@H6014;2`0F4100
50h>0P0<1PH01`0>20P030H600/51@0<1PH03@L700h8200C2@X00P0D2P/02@0C2@X04@L800l51P0B
20T040H701882@0C2@X04PP901872P0601872`0501462P0C20`04`P<01<8300A1PX00P0B1`/20146
2P0@01872`0C20`040D901T>4P0700004`P<01@93@0@1@T02`4301X@4@0=0`@050X;05E;C019?d00
6@l@01061`803`D601@040H70147200?1@H0200001<92P0F30d03`D600X10@0;0@803`D605U?D021
MgP04PP901@:2`1?AD@07A<B01P>3@0E2`X06@l>01<920H04@L600`04`T:01L=3P0@1PL040H701X@
4@0A1`P040H701882@0D2P/04PP901<92P0G3@h<01061`0<01471P0@1PD040H501881`0G3@`06Q0?
01@:2@0E2`X04`T801061@0?1@@040H55?ooool001_ooooo1P0B30`0200H4Q805a4A014;2`0:10@0
30H601<=3@0A2`/04P`<0P0C3@d01@0B30`04@/;00l92@0@2PX04@/;00804P`<00d04`d=01<?3P07
0`80510?00l;2P0:1PD00`0000`81`0B3Pd03@T801XF5@0E4A003@T800803`/:00H040`;018>3@0B
3Pd04`l>00T51@0:1PD201@@3`0P01<?3P0?2`X040`;018>3@0@30/03@T800h:2@0B3Pd0510?018>
3@0A3@`040`;00l;2P0A3@`040`;00h:2@0=2@P03PX9010<2`0C3`h04@d<00l;2P0:1PD03@T8018>
3@0@30/04@d<018>3@0@30/030P700h:2@0B3Pd301@@3`0A018>3@0A3@`040d=00/92P091`P030X;
01XH6@0D4Q<03@`<01TG600F51D040h?00l=3P0D4Q<0514A00l;2P0B3Pd00P0D40l0200E4A0040`;
018>3@0C3`h04Ph=014=300C3`h03`h<0`0@3`d2014@3P0300d<2P0>3@/040l=00<040l=00@04@d<
01LC4P0S7ah07QXI0P0E4A006`0G4a80510?01@@3`0D40l04`l>01HB400D3``05A0<01@?300@30T0
4@d;01<?3P0P7ad03Ph=01LG5`1?DE00F5YI00/=2P0>3P`04Q4=01HE4@0D4`l04Q4=01PG4`0?3PX0
4a8>01@C3`0201<B3P0=01@C3`0?3PT06aXF00`;1`0Q81`05A@A01LF500D4a403`h=01XH6@0E4a@0
=cDf092>S`0501DA4P0401HB4`0I5AH05A4B01HB4`806QHG00P06ADD01HF4@0F5a805QLB01DF4@0G
61<06AXE01XK5P8061TD02006AXE01PI500F5a806aLF01XI5`0K6QP07QdK01hN700O7ad06ATG01DG
500^<2d05QPE01@I5@0F71X05AdL00PA400<5A@08b`[014J6@0C71/051dL01PQ800J8b805b0O01<L
6`0E71d06QhQ01/O8P0M8B<0720Q01`P7`807R8Q01`0724M01XO6P0M8Q`07b@N01lW900O9bT09c0_
01hX9@0G8Q`082dT02Ld:`0U<RT08C0Y02@c;P0R<Bh08Bl_02Le=`0Y=S`0:3Dk02Hc>@0X=C/0:STn
02`k?`0^?D00;T1202m1@`0a@dD0=TY;0P0eAd/0700eAdT0=4I603=5A@0aAD<0<dU703E;B@0Z?d80
=4]A0358CP0jDET0@EMT051SL@1ZOH/0@UES04]NK012E680@E=Q03i@GP19FFP0?DeL04ICH`17EFD0
A5IR04IHI019FfL0BUaX04]MJ@1:G6H204aNJ00;04ePI`1<GfH0BUeT04MJG`1<GV00C5iN04QJFP16
F5P0BEaK04ePGP1>HEl00P1FJFL01P13EU80EfYV05]^JP1NKVh0Gfm_061`L080HG5a0P1RLW80101W
MgL0J7Qh06IfMP1VMWH206UiN@0f06YjNP1/O7`0KWin07:1PP1ePh@0Mh:407V4QP1mR8X0PH^=08F?
T@28TY@0Phn?08NCT`29UID0RiFF08jHV@2@VY/0SiNI08fEU`2?UiT0TYNJ09fRY@2W[Jd0W::O09JJ
V@2GViX0V9bK09jOX@2TYJL0[:f_0:j]/P2_[[<0/:nd0:j]/P2/[K80[[2h0;Bg`02c][l0/k>k0;nn
a038ald0^;Nm0:bZ[`2a[k@0][Bi0<2n``2l^L00_Kc50;bia02j]l80`[k<0<_5d`3:a=<0b/?C1P3;
`]D05039`=<0b;oB0<_2e@36_m40`[c;0;nla@2j]kh0][Bf0;Je/@2_/:/0XjBM09BES@2TYId0Z:ZQ
09BGSP2;SX<0LgQ/071fJ01]LfD0JW5R0P1WL5l02@1UKEd0GVIG05YRD`1JHeD0HfiP06A_H@1WLVD0
K7Q/06MeJ00205m/HP0:06IcJP1^NG<0Ig9^06A`K01XM780Ig=a06EdL@1RL700I79b05e]K080EFEU
05<0D61P04ADBP16DdT0@4e304A?A`13CTH0;cXb03Ho>P0Z<bh0;C<a034g=`0k@D40;S@d04=8B`12
AdX0<cPk03<i>@0/<S808BLU02H/:00]<bl0=C`f02T`:@0`=c009c0[02lj=P0_>cT0:cLe02di=`0a
?C/0;CTg03A0?P0[=cD0:3@b02Te<`0[=cD0;c/k02hi>`0`>ch0=3m1038l?@0T;Rh07RTU020Y9P0O
:B808R`T024X800N9A`08RTR01<L6`0L92D08BXW02</:@0P:R<05AlG01XT700G8AX07bPS018K6P1]
MWH0Mgn101lS8`0N8R407b<R02<W9P052@X0<CDf01dQ900F6Qd09RX]020S:00H6b0061`O01LI5`0W
:BH0<38_01hP7@0O8Ah05ALD01LI5P0H6QL06A/H01/M6P0201`N6`0J01LG5@0N7Q`09bLU01lO7@0K
6aT051@B010@3P0O7ad08R8P02<S8@0A4@l05aLE00d<2P0K6QP061LE03ln?00X9bD05QDC01/J600E
518020L600h=2`0Q81h04Pl>01LC4P0F4Q4201DA400[01HB4@0E4A005Q8A00l;2P0F4Q406aLF01DA
400G4a405a<@01TE4P0J5Q<05a<@01@@3@0F4Pl06aLD00T50P0C3``030P502/W900U8Al04`l>01@@
3`0P71/06QHE018>2`0D4@`030T401<@2`0E4P/03@X301DB2`0@2`P02`H301LB3`0I51403PT6018=
2P0A30T040/8018=2P0400004Pd:01@?3003010<2@<04@d:00<04`l<014=2P0?2`P00P0?2`P02P0<
20D04`h:00h91@0;1P803PT503`g<`0E40`040/7018=2@0A30P200l:1P03010;1`0>2@D03PT50080
3PT500@040/7014<200B3@T04@`80P0@2`L01@0A30P04Pd901D;2P0C2@P05P`;00806@l>00@050X9
01471P0D2PT05@/:0P0D2PT00`0D30X04PX800l:1`0200h91P0500l:1`0@2`P04Pd:01<>2`0B3@X0
0P0?2PL02@0A30T04`T800l5100A1`H04PP701H<2`0L4Q4040H501<9200201D;2P0801881`0@20H0
40P901<=3@0J51@05a4A00l92@0>20P200l92@8040X:0P0>20P0100E2``050X;01<92P0B20T20147
200901882@0@1PL04`T:01882@0@1PL04@H901052@0B1`/04`P<00<04@H:0P0B1`/0600C20`04PL;
01872`0A1PX040D900l4200@1@T04@H:01052@0;0P@060dA00d21P0A1PX05``@01<8300>0`H05P`=
01882@0D2P/0?cDf03D[;00?1@H04@L801061`804@L801<04PP901hD5@0D2P/04PP90147200C2@X0
5`d>020F5`0700003PH601T?400C2@X05@/<02LM700:00004@L600`20@0700003PD500H04@L600H0
4@L801882@0@1PL04@L801@:2`0>10D20147200401882@0C2@X05P`=01dC50`040H70P0A1`H30106
1@0701471P0E2`X05P`;01@:2@0A1`H03`D401061@0Dooooo`006oooool00`0D30h04`d>01<=3@03
01<=3@0802@N7P0E3`l04Pd<018=300G4Q803PT8014;2`0B30`201@>3P03018<300A2`/04P`<00@0
4@`:00d04@/:03lk>P0A3@d02@D401@@3`0B3Pd04`l>01dI600J5QD05A4@00`81`0G4a803@T80080
4@d<0P0@30/0100?2`X040`;018>3@0=2@P201@@3`03014=300C3`h03PX900804@d<00D04Ph=014=
300?2`X0510?014=3002010<2`03014=300B3Pd04Ph=00<04`l>00D04Ph=01<?3P0<20L030P701<?
3P0201@@3`8040`;00<03`/:010<2`0B3Pd00`0C3`h301@@3`0701<?3P0@3@d04@l@00d;300A3a00
4a4B00`:2`0200h<3@0A00l=3P0B41404@l@00l=3P0A3Ph04Ph=014=300@30/04@d<01<?3P0A3@`0
4Ph=01<?3P0@30/03`/:010<2`0B4@l00`0C4Q00100B4@l04A0>014@3P0@3`d300l>3008014@3P0A
3@`04Ph=01TE500J5QD0510?018>3@0F4Q42014=300A018>3@0?2`X04`l=01D@3@0G4@d05Q4>01@@
3@0F4Q006QHD00X91`0F5A<02`/:03Hg=@0D5QD06Q`I01<C4@0A40`00P0E51001@0?3PX04Q4=00l>
2P0C4Ph05A@@00<04a8>01404A0;014@300G5Q8051<?00d<2P0@3`d051<A01HE500P7Ql06QPI014?
400M6a`081`M01/F5`0C3Q004Pd?01HA4`0201XE5`0D01TD5@0H4a@06QDF01/F5P0K5aH05aPB01HG
4P0E5Q005aPB020Q6`0V9b4061TD01HG4@0H6A<071dG01/L5`0I6QD061HD01LG5@0H61H201TI5`0;
01TJ5`0J6aP05ALD01<E4P0H6QL061dI01HL6@19DE008RX[05mXJ00N9RP00P0E7Al0:@0H82806B4S
01XR8`0G82005QlO01TN800L82<07b4T01lS900O8b<07R8R01hR8@0P9B008BHR028W8P0P9Al07R<L
01lW8`0I8b@06bDT01lY9P0S;RT09C8Z028_9`0Q;bP07RdW02@b;`0T<c4093@c03I4B00fA4/0:3Dk
02Xh?@0b@4D0;Ca102dm@@0_@D<0;Cm102m2A00aADH0<DE50080<dE801T0<TA60355A00aAD@0<dM5
03I;B@0fBd/0>De@03U?E00mDUT0?59J03U?F`0hCUX0IGZ604QMJP11EF<0>TeK04MJJ00oDV00AEMU
03i@GP10DF00BeaZ04=EHP14EV80BE]W0080BeeY00@0CV1Z051RK01=H6P0CF1W0P1BIF`01P1<Gf@0
DF=S04ePGP1;GU`0BUeK04ePGP80DfIT00P0E6MU05Q[J@1FJFH0EFQU05MZI`1JJVT0GFe]061`L080
HG5a00D0H71`06=cL`1TM7@0IWIf06QhN00206UiN@0Q06]kO01/O7d0KWeo0720P01dPh<0MhF507R4
Q@1kQXL0OhZ<08B>T029TiD0RiFG08>?T027Ti@0RiJG08fGV@2?VI/0TI^L092HVP2<U9H0SIFG092E
U`2GW9h0WjFU09JLV@2FViL0TIJB0:N[ZP2i^kX0/;:b0:RYZ`2ZZZh0ZZZ_0080[:^`01L0[:fb0:ja
^02/[kH0[[6h0;Bd_02f]k`0]KJk0;:a]`2^[K80/[:e0;2^/P2h][T0^;Jj0;Bc^`2c/K/0/K2i0;^i
a@32_//0a<3>0<W4d`39`]<0b<7B0<Nod@020<NodP0h0<S0dP35_M00`kc>0<O1dP32_Ld0^[G40;^i
`P2h][d0/;2a0:j^Z`2WZ:@0WYnJ09NHTP2MX9X0T9>;08R;P@27SH80MWa_07=iK01]MFL0KGEV06]c
I01SKUl0H6UK05mWF@1PJe`0JWEV06QcI@1YMFL0KWY/06mkK`1_OG00J7E[06EbJ01[N6h0JGM`06=`
K01TLFl0JGId06EcL01OKFd0FfUY05aZJP1EIFD0Cf1P05=TI01DI6@0BUU?04QEB@13CdD0A4m603E0
=`0d?CH0?4E002H_:P0nA48202hd=01402L/;`0X;Bl0:Bh`024V:00Z<300:c4`02X`;P0^=3009B/W
030g<@0Z<BX0:2lX02dg<00b?CT0=D4o02hj>00[=cD0<3`j038n?00^>SP0:cLf038n?@0c?ch0:cLf
02/g=`0X<cD09S4e02Lb=00W<C409S0^02`g<P0X<R`09BlW02D^9P0R:B407B@K020W800M9R@07BDU
01/T8@0J8al072DN01hX7`0K9Ad06b<M02H]:P0I81l08BPY01hT9`0P92<08bLV01TM700]<C40;30a
06IZJ`0o@dD0A4Q:01@H6P0L7b<04QDI024U9`0K7A/05QPE01/M6P0M7a`05aTF01TK600K7AX201XL
6@0801TK600H6QL061XG01PH5P0G5aD07QhL01LG5@0J6QP301TI5`804Q8@00<061PF01LG5@0I61H0
0P0G5Q@201HE4`804a8@00H051<A04E4@P0E51803Pd;01LE4`0H51<201TE500<01LC4P0F4Q406ADD
028N7@0M6AP06aLF01PD4`0D3`h06ADC01LC400F4Pl0510=0P0C3``0200D40d05Q8?01PD4@0@30T0
6QHC010<2@0d<2h07QXI0P0@30/0500@30`0510>01<@2`0C40/061D@00d:100>2`L05A8<00h91P0E
40d03PT601LB3`0D3``04`h;01D@3@0?2PL07QTF00d81P0D3``04@`90P0?2`P2010<2@<04@d:0P0@
30T00`0C3``05A4>01@@3@0201<>2P0501<=2@0C3PX04Pd901@?2`0?2PH00P0B3@T00`0?2PH03PT5
014<2002014<208040/70P0A30P09@0?2PH04@`8018=2@0B3@T04@`800l:1P0D2`X040L501071P0F
30/060h=01<:200D2PT05P`;01H=2`0D2PT04`T801<;2@0@20H040X8014<2@0B2`T040X800h91P0F
3`d06aDB01HA3P0>2@H050d;01/D4P0G3@`04PP701@:2@0B20L03P@401071P0C2@P00P0A1`H02@0B
20L050X901@<2P0@20P03PP8018<300@2PX03@L7010:2P0200l92@0600h8200=1`L030H600/61P0G
3@h04`T:0P0A1`P0200B20T050X;0147200@1PL050X;0147200?1@H04`T<0P0@1PT0100H3Q406a4D
01@:3@0@1@T601872`0D01062@0@1@T050T=01D:3P0A1PX03`@800h41`0D2@d040D901D:3P0=0`H0
5@/=00/10P0J41404`T:00d3100J414040H701<92P0B20T201<92P0501@:2`0Y7b006a4B01<:2`0@
1`L00P0B20T02`0=10@05`d>01D<300R61T09A/L01<:2P0D2PT05`d<0188200A1`H060h=00L04@L6
00`04PP900l51P0F30d060h?01061`0?1@H04PP901061`0?1@H040H701882@0C2@X<01061`0500l5
100A1`H04PP701881`0A1`H00P0?1@@01@0B20L04@L601061@0A1`H04PP701Cooooo000Kooooo`0K
01<83P0D2`l05@`?01@;3P0B2Pd03`T;014=30091@D07A`H01DD400@3`/01@@000d71`0E30d04`X;
01<;2@0H40h050`:01TA3`0C2`P0610=01491P0D30T06A@@024M6`0L61L04`l>008040`;01D02`L6
01DA400F4Q403@T800X61@0D40l06ADD010:2P0C3@d04@/;00h8200B30`05Q0@018<300C3@d04P`<
014;2`0C3@d05@l?00l;2P0A3@`00P0B3Pd05`0?2`X03PX900h:2@0=2@P03`/:01<?3P0B3Pd05A4@
00/71P0E4A007a/J00T5100?2`X05A4@010<2`0J5QD04@d<00`81`0C3`h030P700h:2@0@30/04Ph=
00804`l>01@04@d<00l;2P0A3@`04`l>010<2`0>2PT03`/:01<?3P0F4Q404Ph=00h:2@0A3@`05a<B
00P40`0P71/02@D4020L6`0?2`X0510?01<?3P803`/:00L040`;014=300O6aX020@3014=300:1PD0
5a<B008040`;00D04`l>014=300>2PT04Ph=01DA400200d9200400l;2P0@30/04@d<01<?3PD04`l@
0P0C3`h02P0M6AP0510=01@@3@060P003PX7014@300C4Ph051<?00l>2@0A3PT201<@2`0I014@2`0?
40/0414<01<D400E5A<04A0>02<O7P0O6aX05a<B01DA400C3`h04Ph=01@@3`0F4Q405a<B01PD4`0F
5A405A@?010A2@0W:2003a0:018C3@0K71L05AHA01<D3`02010@3P0L01LG5@0M7A/0[J^/024O800C
4A805A<D01<B4@0E51804a8@01HE4`0J6AD05QDB01DD400I6QD061TD01TK600C5A004Q@@02d_;01V
J6<06Q`H018D4@0G6A@05aTE014C400C5A0071hI01PJ5@805aTD01`06A/F01TN600Q9Al04aPB018G
4@0I7QP06b0J01TN600I7a/06AlM020V900I7al0724T01XO8P0H7B0061hN01LM700F71X06AlK01`P
700L7QT07QlJ01lQ700Q8ah082DO01dR700E6Q<08BPQ0P0P9al0600U;2@05alK02<];P0Q:b`072LV
02di=`1aOGd0934a02<a<P0M:b`0;3/m01TX:`0O;S40?diD03A5C00S<ST09cLm02Li?@0U=c/0:S`o
02i0@P0`@T@0<49302m1@@80<D=30100=DM703a?CP0aA480=4M50394A00cADL0@UIG04AFF@0lCe<0
>4]A03mBF00eB4l0<TA>03Y<EP11Del0?DmK0`0nD5`09@11E680AUUW04YMJ`1>HG00AeYY04MJJ015
F6L0BUe[055UL01HJW@0DVE/04ePI`1CI6/0FFYa059TJ01=Gf<0CEmO04]MG@1=Gel0DVAT05IXJ01E
IfL0CEmO05=UI@19Fe/0DfEU05U/J`1JKF/0Hg=b05m_KP1[NgX0GFe/05a/J`1XN7L0Hg=b06IfM@1Y
NGP00P1XN7L0>@1YNGT0IgIm06imQ01cPXL0Lh:507>2PP1dPh00NhN5075mN`20S8`0SiVK08>=T02B
Vj80R9>I08B>U`29U9X0RiBJ096JW`2KYJL0U9bN08VBT@2:Ti80UYbK09BJV02?UI<0TiNF09FIV02J
WYd0a/[;0?_oo`35bL`0X:BW0:BW[02WZZl0Zjfb0:b]/P2Z[K80ZZfe0:ja^P2a];d0/[Fl0;6b]`2_
/;D0/:nd0:f][`2][Jd0ZZRZ0:ZXZ@2_[Jh0/K2d0;2_]@2/Zk40/k:h0;bk``2l^l@0_K_60;nkb@02
0<2lbP060<6mc031_/X0^k[20;Vg`P2l^l@0]kJn0P2e];`01@2a/[L0/;6e0:n`/`2WZ:X0WIjP0080
U9BF01l0Ti>A096CS024R7X0MWe]075hIP1UK5X0I6eJ06E^GP1WKf80J71U06A/I01NJ600IFmV07Eo
M@1]N6X0JGEW06ikJP1ULF<0GfeP06MgK01]OG<0JWUb06QiL`1VMg40HgA^065aKP1NKV/0FFUV05IV
H`1IJFH0DV1P0080D5iN0240CU]J04E@BP1;EDd0?TQ003Dn>@0Y<Rd0=3di02H_;00b>cP0;CHe01hW
9P0_>3L09Bh^02D^:`0T;BP0:34^02df<`0/=C809Bh[02Xc<00V;b`09c0]02`e<P0^=cD0=Cln03Q4
@P0/>cP0BEQE030o?00V=C<0<3hn02Xh>00^?3`00P0b@440800_?Ch0;CPj01hY;@0Z=3D082XY02Xc
;P0I8aT0>D@f0459>P0f?S00:2hT024V7`0N8ah082HR01LP6`0J91l06B8M01LQ6@0K91`08RTR01LM
6@0Q9R807B4P01`N7@0O8B407R0O028T8P0S9B8092HS028T8@0N81l071hM0P0O8B001@0M7ah06adL
01`N7@0N81l06a/I008061PF02L07QhL01dM6`0I6AL05QHD02@T8P0F5Q@07QhL01@D4P0J6QP07A`J
01`K6@0:2@L07QdK01<B400I61H071/I00d<2P0@3`d06aXH01XI5`0F5A<061LC01DD400D4`l05A@@
01LF4P0E51003`h:01HE4@0d<bl08b8N00l>2P0E51406APF00/:200J6AL05A@B01LC4P0H4a800`0I
4a<01`0G4A4060l@01@?3P0B3P/0JFER024M6P0L61D00P0F4Pl2018>2`0K01LC400H5140510=018>
2`0D40d04@d:00`81@0>2PL04@d:018>2`0C3``04@d:00l;200@3@P040`901<>2`080P804`d=01TC
4`0B30`05A0=01<>2P0D3`/05A0<01@?2`0C3PP04@`800<04`h:00d04Pd9014<200A30P040/701<>
2P0?2PH040/701@?2`0=20@04`/901H>300D2`X07aLE00804PX800`03@P5018>2`0U8Ah08QhK00d9
200<20D06A@@00L2000@2`L050l;00`70`0C3PX6010;1`0F010;200A2`P040/8018:200A2`P040/8
01L?3@0F3`d04Pd:018:200@2@L050`:01H>300C2PP04@T701@:2@0C2PP03PH401D;2P0D2`X04PX8
01<:208050X900h06Q0?01@:2@0@1PD040H501@:2@0F30/050X901881`0>10<04@L601D;2P0B2PP0
4`d:014<2@8040/800D03`T900h8200?2@T03PP:00d72@0200h82P0R00l92`0B1`/04@H:01462P0B
1`/04`P<01@93@0?10P04@H:02HK7`0H3A40304500l72P0E4A8020@5081kO@28PX@06aDG01482`0>
1@P03`@801@8300A1@T040@800d41P0I4a<03PD601D<3@0V7Ah01P000107200B20T040H701051P80
40@601<04@H801<9200A1`H04PP701`B4@0I3`h04PP701<9200D2PT04`T801061@0=0`803P@300l5
100E2`X050X900d30P0>10<04PP700804`T80P0@1PD01`0C2@P04PP600d40009000040H401H<2P0A
1`D00P0A1`H02P0A1`P050X;01T?400A20P01`0001T?3P0]8b807A<B00l5100@1PD200l510050147
1P0@1PD03`D400d30P0A1`H00P0@1PD05@0?1@@040H501471P07000060h=00/1001;@D0040H601<9
200H3Pd030<201L=300A1`H030@300X0000F30/01`0001T?3P0A1`H06a4@00L0000Dooooo`006ooo
ool0800C20h050X@01D<3`0D2`h04P/=010:2P0;1`H06QPD00d<20041@002@X7020O6`0<1PH050/<
01482@0B2PP05Ph<01491`0E3@X040T401<<1P0G40X03`P200@0000G4Q005A4@00l;2P0@30/04Ph=
00l;2P0A3@`05A4@0`0C3`h0100@30/050h>014;2`0@2PX3014;2`8030H600@03@L700l92@0?2@T0
3`T90P0@30/2014=300C010<2`0?2`X04Ph=01<?3P0D40l04`l>010<2`0=2@P061@C01@@3`0e<C00
;2PW00L30P0B3Pd030P7010<2`0B3Pd01`<200`81`04018>3@0I014=300@30/04@d<010<2`0?2`X0
510?01DA400B3Pd040`;018>3@0D40l04Ph=00l;2P0A3@`030P802<O7P1RGUd0:bLV00/71P0810<0
8alN01`H5`0C3`h03`/:010<2`02014=300<00D1000E4A004Ph=01XF5@0>2PT040`;01@@3`0C3`h0
40`;01<?3P0E4A003`/:0P0@30/2014=3003018>3@0B3Pl04Ph?00<04Ph?01H04Ph=010<2`0A3@`0
4@d:00D1000L61D061D@00l>2P0@4@`04Q<>010?2P0A3`T05A8;01<@2@0B40X040l:014@300C50l0
5QDA00l;2P0G4a805Q8A0P0E4A00:`0=2@P04`l>01DA400E4A005Q8A01DA400C4Ph051<>01<D300T
9Ad051D=01<D3@0C50h03a0;01/L5`0H6A@05ADC01LG5@0B4Q00=3@d010@400Q8B407AdM01DE500?
3`d05aLE01LH4`0I6QD05QLB01HG4@0L7AL0418?00X<2@0A4a006Q`I014C400S9B804aDB01HH5@0E
5a@07AlL01hP7@0E5a@00P0D6A<0:`0E6Q@061dG01`Q6`0M8Q`05a`F01HK5@0D6A<04aPB01DJ500F
6aD05ahG00<91@0H7QX06AlO01TN8@0G71l061dP01PN7P0G7A/05adI01TP6@0M8A/07b0J020Q6`0Q
8ad08bHO028W800W;2D06AhG01/R6P0O9Qh06b8J02<Z8P0M9b<06bDV014K700W<S808bl_03Y5A`0O
;2h09S@g02Th>`0V=CT00P0d@dP0J@0iBDl0<T=:02Df?@0[?480;3i202/m@@0]?d80;Cm102m1@`0^
@440;Clo0312@P0kCT`0=DQ602m2@00bAD<0<4=103Y<C00a@dD0@UAF03mAD`0jC500?DmC03mAE@13
E5`0A5EM03e>F00kC5H0A5EO04MII@13EF40@UAP041CH@12EF<0AEQV04MMJ`12F6H0@EMU04QKJP1?
HW00DFE`05EWLP1CIVd0Cf9Y05=TJ`1HJVh0DVAX04eOHP19Fed0B5YJ04YLG01>H600DVAT055SH`1I
Jf/0G6i^059TI01HJVX0EfUY05U[J`1JJVT0IgMf08BDT`1gQhH0IGEd05i^K@1UMG@0Hg=b069bL@1Y
NGP0LH6006alO01XMgh0KGb40760Q@1aPH40LH5o07>2O`1dP7`0NXJ407N3P`21Rhd0PhbB08N@V@28
TY/0QY2J08^EWP2;U9X0SIJK09BNX02@VIT0RiBC08jGU02FW9T0TINC08bBSP2HW9/0TiNF09FIV02`
];D0dMGH0:Z^/@2RYZT0Y:N/0:NZ[`020:V//@0F0:V//`2XZk@0[:nh0:nb^`2`/kX0[k2e0:f^/`2W
YjX0YZJX0:RXZ02VY:D0Z:NU0:f/ZP2_[k40[jjc0:^Z[`2a/;D0^KRn0;Vh_`2j^L40^kW40;bjaP80
_;[700D0_[g70;Vj_`2e][/0]kRm0;>d^@020;:c^00N0:n`]@2][[80ZZ^_0::SY`2KW:00Ti>H0:2O
Y027QhL0Rhf608N;O@24RgT0JW9L06M_F01TKEX0JG5Q06mgK01_MVh0JG5[061YI01UKVT0LWac06Uc
J01ULF<0IG9Q05aXFP1MJeh0IWI/06]kL@1XN7<0GVmY0P1KKVP205a_J`1505][J01FIV<0EVIS059P
H01AGel0C5YJ049>C@0mAT40<cde03Y3?P0g@3/0;3D`02H_;00nAd@0@4U601PQ800V;bh0>T=202lg
>00[=2l0;3H^02hg<P0`>C@0;cPc02/d<@0b>cP0;SLd030i>00b>cX0<SXk03Do@00[=cD0;chk04YI
EP0eA440;3/i02<a<@0Z>3T0;3Xk02dk?00/>Sd0:SPk02Pf>@0_>3d0:38c020[9`0b?3<0:3<T04MB
@@2LYI80NH5a03m5>@0a=Rl07b<Q01HL6P0J91`06bHM01/U7@0J91`07BDO020V8P0N8al09BPV024S
8P0P82008R8R01hN7P0P8Ql07b4N00807R0M0P0M7a`00`0O8Ah0828O01lQ7P0201dO700W01hP7@0M
7A/06QXH01`L6P0P81h07QhL01XJ600R8R00I6AR05MGE@0G5aD07alM00T91`0N7A/081lM02<R800J
6AL081lM010?3@0J6AL05aHD04m>C00l>cT06APF018A3`0H5a<05A@@01@C3`0E51005aHB01PG4`0B
4@d040l;020O6`0H5a<040l;04i=BP1PGed08B0N008040l=02H05Q8A01<>3@0D3Ph05@l?01L@400G
3Pl05Pd>01<=300n>SL0W9RE01hK6@060P005A4>01XF4`0C3``05Q8?01LC400D40d04`l<010<2@0=
2@H03`/801LC400L61D05a<@01/G500G4a0040`900`81@0A3@X061@A00l92@0i<c<0A3hn010:2P0;
1@D03`X701<>2P8050l;00<04`h8018=1`0B3@L00P0B3@T2014<208040/701@04@`8018=2@0@2`L0
40/701@?2`0>2@D08aTH00L0000E2`X0>30^00H0000B2PP06A@A018>3@2FTXl0THf:00d:200U8Ah0
9b8N01D@30804`h:00<03@P4010;1`0@2`L01@0@2`L6010;200700X50P0A30T03@P501<>2`0H4a00
5a8?01D;2P0201881`8050X900@04@L601881`0B20L04PP70`0C2@P00`0G3@`050X901<920030188
1`0701`B4@0I3`h04`T801881`0C2@P03`L500l91@0300h91P803PP800<03`T900h82P0=1`T00P0>
20X02P0?2@/04PL;01462P0A1PX04PL;01<8300D2@d05@X>00/0100E2Ph201052@0:01D?4@0=2``0
2PP904E2@`10?3d04@/=018;3@0@1`X04@H:01@8308040@800H06a4C00@0000B30`03@H600H0000F
3@h201@:2`0=01<92P0C20T04`L901@82P0D2@T04`T801471P0B20L06Q0?01L=300@1PD04@L60188
1`0301<9200401471P0@1PD04@L601<9208050X901X03@<200h40`0?1@@03@<200h40`0A1`H03`D3
01<:1@0E30L03`D300d30@0?1@<06@l>01881`0A20T02@0000L0000o=CH03`D401H<2`0K4A004PP7
00d30P0B20L040H501471P804`T800<04@L600h40`0A1`H00P0@1PD02@0?1@@040H501471P0R61L0
3PD501471P0j<2l060h=01@:2@0201881`0:01471P0=0`806Q0?01061@0B20L0DTQ700`20@0@1PD0
1`0001/A41Cooooo000Kooooo`0K01@93@0D2Ph050/=01@;3@0C30`04P`;018>300>2`P07QdH01@E
3`0<3@L04A0;014;2`0D2``04`X;01@<2P0E3@/04PX801@<2@0H40d04PX701<<1P0G40X06QDA01<>
300C3`h04@d<00804Ph=00P040`;018>3@0B3Pd040`;01<?3P0B3Pd030P701LA4@804@/;01<050h>
018<300?2@T04@/;010:2P0C3@d06A<C01H@400B30`04Ph=010<2`0?2`X040`;014=300B3Pd05A4@
01XF5@0I5A@04Ph=00803`/:00`05a<B00d9200I5AD081`K00l;2P0C3`h05A4@01PD4`0T81l05A4@
00`81`0E4A03014=30<04Ph=00P040`;00d9200@30/0510?01<?3P0A3@`04Ph=014=30<04Ph=00l0
4`l>00`81`0P71/03`/:01TE500?2`X061@C01XF5@0A3@`03PX9010<2`0B3Pd0510?014=300C3`h0
0`0D40l0100?2`X0510?01HB4@0C3`h201DA40804Ph=0`0C3`h00`0D40l04@d>014=3P03014=3P0=
014=300G4a8040`;01@@3@0T81d03`/801@A3@0@3@X040l;018@300C40/0514<01HC3P0201<@2`07
018@2`0C40d0518?01HC400E4A00510?01LC4P0201dI6003018>3@0D40l05A4@00805A4@00`0510?
014@300@3`X07QlG010A2@0A4P`06Q/E01`M5`0E5Q405QLB01<D3`0A4@l201<C4@0<00X:2P0J6QX0
4A4A014A4@0I6AP051@B01DE4`0D5A005aPC01HG4P0F5a406a`F0P0D5Q<03P0I6aP05QPE010B3`0K
7AX04Q@A01XL6@0F61D08B<P02@V8`0E5a@05AXD01HK5@0G71H06AhH0P0J7aT00`0H7AL08RLQ024V
800201PM5`0=01dR700J8AX05adI01`R7P0F71`07B8U01@I700I7R406R0P01TO7@0I7a/06R4J01lS
7@02024S7P0:02<U800T9R408bPR02H[9@0I7QP06B0I028Y8P0K8Q/07RPP01hX9@809Bl`00d08Rd^
02Pd=00O:R`0@4a?01/Y;00Y>3/08S4e02Lf>`0N;C80:SY002Lh?`0U=Sd0;3e30080:Sa000H0;d54
0312A00a@dD0<49302m1@@0a@d<203=6A00803iAC`1WNWP0@eID03I8B00eAdT0@59D03a>D00kCE42
03i@E00W045BFP1;G6@0A5EO03e>F018FF<0A5IR04YLJ017FFD0AEQV04MJJ018FfT0@eUW041FI00n
E680CF1_05IYM`1@I6l0E6Ia05AWKP1AI6/0DfA[05=UJ@1?HFD0BUaO04QJG019Fe/0BeeM04mQH@1A
Hf<0D69R059TI01DIVH0EFMW05]]K@1DIVH0Ffe]05e]K01LK6/0JGUh0080GVi]02T0HW9a05m_KP1W
MgH0Gfm^06MgMP1kRhX0M8B406akO`1_OX<0Kgj006inO@1`P7h0M8>007R4PP23Shl0QI2C092IW`2;
U9`0QHjG08RBV`29U9/0S9NL08^DV@2;U9P0SYRI08bEU02?V9H0TY^G09>JU@2?UI00S9:>09BHV02>
TY<0UYZK09jRX`2VZZd0X:BW0:BXZ`2UZ:d0YZV^0:NZ[`020:JY/0080:JY/P2Y[;D0Zjjg0:b_]P2/
[K80Zjba0::SYP2SXjD20:JVYP0:0:VXYP2_[Zd0/[:d0;6`]@2_[[<0/[6f0;Je^`2f]K`0][Fm0;Jd
_`80]kG002P0]kG20;Nf`02a/[L0[Jjc0:j_]02[[;40ZZ^`0:b]/P2/[K40Z:V]09jOX`2EUYX0TiBH
0:2QY@3?d=80ZJ^Z0863O01^LV@0OHAb06A/E`1QJE<0HfaI06]cI01aNFh0LG]b07EoN@1aNWH0KWMb
06]fK@1NJUh0FVII05]XFP1KJE/0H6eQ065aI`1QLFP0H71Z05e^J01JKFL0FVeY0P1KKVX00`1JJVL0
FFUV05=SH002051NGP0P04aJFP11CD`0<CXe03Do=`0kA3l0?TM20419A00V;b`08R/X02Tb;`0c?3/0
8BXY02Xc<P0f?cl0<S/f03<m=@0c?3L0;SLb02df<@0`>CH0;CHc02`e<P0b>cX0=Sln03<l?00d?Sl0
=40n02ln>`0a@3d09SDb030n?@0Z>3P202hl?@0M02dk?00/>Sd0:3Hi02Lc=`0[=3T0:cDf02Pc;`0Z
=2`0<ch`07f8M`3cn^/0]Kb]03Pn=00[<2T07R8O01lU8@0M9al06bHM01dW7`0O:B407bLQ01`R7P0S
:2@08bLT024S8P0S8b<08R8R01`L700T9R<00`0R92400`0S9B8092HS01lQ7P02024S800O01hP7@0M
7a`07R0M01`L6P0I6AL07AdK01hN700I6AL05ADC028R8027QhD0LG5_01/K6@0C4a406QXH024P7P0V
9B<09B@R04U8AP1gMW@05aHD020O7@0D4a40?C`j02TX9P0N7A/061LE01PG4`0E510051<?01DD4002
01LF4P0K01TH500D4`l04a8>01<B3P0A40`0=3<`040o?@0H5aD05A@B014@3P0E4A004Pd<01<=3@0E
3`l06A8B01T@4@0G3Pl05a8@00H20@0X9240510=01PD4@0B3P/04`l<01DA3P0H51405Q8?00804Ph;
00D05A4>01@@3@0D40d03`/800X71@02014=2P0;010<2@0B3P/04`l<018>2`0C3``071HF02TS8`0S
7Ad02P@401LA4@0F4@h00P0D3`/0100C3PX04@`6018=1`0C3PP3014<208040/701T03`X6018=2@0B
3@T04@`8010;1`0B3@T040/701L=300:0@409ahM04e5@`0H40l04@T800h91P0C3P`09b<P028N6`0B
3P`08QhK01/F4P0E40`030L300d8100D3`/04Pd900H040/71P0@2`P01`0<1`@04`h;00d81@0C3P/0
40/800d81P0C2@P00P0B20L01@0D2PT05@/:01@:2@0A1`H050X900805`d<00<05P`;01D;2P0C2@P0
0P0E2`X01@0D2PT040H500h40`0J40l060h=00804PP700H04`T800l71@0>20@03PT600l:1`0A30T2
018<300300l92@0>20X03@L900803PP:00H03`T;01872`0A1PX04@H:01872`0C20`201@93@0G01<8
300D2@d04@H:01872`0I4Q@02@L800h<3@0?3@d02`L801H@4P0D30l04`X=01872`0C20`040D90145
2@0@1PP05a4A00h92@0B2``040L800l7200C2@X00P0?1@H02@0@1@L04PH80186200C20T04`T80106
1@0A1`H05@/:01<9200401061@0901471P0B20L04PP701P>3@0C2@P03@<201@:2@0B20L03`D40080
40H500H03`D400h40`0B20H04`T701480`0@1`<200l50`0801881P0C2@P03@@401882@0E30d05`d>
0557B00C2@P201881`804`T80P0@1PD01P0B20L05P`;01H<2`0D2PT040H501471P8040H501D03`D4
01061@0A1`H01`0001T?3P0C2@P040H501D;2P0K4A002P4101H<2`0?1@@04@L602hT8`0M4a8081HE
08b2P@0F30/02@000188200;0@405?ooool001_ooooo0P0C2P/06P0D2``04P`<01<>2`0D3`/03``7
030^:@2n_[H0EeM?01@D300C4Pd03`T900h82@0>20P03@L700h91`0B3@X050l<00X6100G4Ph081/G
00h90`0D3`/0510>01<?3P0D40l04Ph=0P0>2PT0100G4a806aLF01DA400?2`X2010<2`0E018<300E
3`l05@l?018<300C3@d05@l?010:2P0>20P04P`<01TC4`0D3Ph03`T9018>3@0?2`X03PX900l;2P0A
3@`04Ph=014=300H51<05a<B008040`;00L03`/:00T5100K5aH04Ph=00h:2@0J5QD02`L600807QXI
00@06QHE01PD4`0<20L03PX90P0?2`X0100@30/04Ph=01@@3`0D40l201LC4P08014=300C3`h0510?
018>3@0A3@`03`/:014=300B3Pd2014=300;010<2`0O6aX04`l>01<?3P0D40l04Ph=00h:2@0?2`X0
4@d<018>3@0A3@`00P0C3`h02P0:1`H061@C00L30P0@30/03`/:01@@3`0F4Q40510?01HB4@0E4A02
010<2`04018>3@0D40l05A4@01LC4PD04`l@00T04`l>00<0000k=cH020@202hZ9`0300003@X501DA
3P0D40d00`0D3``00`0B3@X050l<01D@3@0201D@3@0;01DA3P0D40d04`l>01@@3`0G4a8061@C01HB
4@0D40l04`l>01@@3`0F4Q400P0G4a808`0E51004A0;00/<1@0L7AL08b@N01lP702l_KP0@44l01XJ
5`0I6AL06QXH00`<2`0F5QH051@D01PH600>3Ph061PH01/K6P0?3`d051@B01DF4@0K71L071dH01TJ
500K71H061XG00P:1`0F61D05aTF01/M6P0L7Q/061XG01@F4`0H6QL071hK00806A/H00L06QlI01TN
600I7QP05Q/E01<H4P0B5a405a`F00806QlI0P0G71H03@0I7QP06R4J01HL600G7AT082HV020U:00G
71l06AhQ01/Q8@0K8Al06R0L01/R6`0N8ad00P0P8Qd0<`0Q91l082DO024V800L8Q`092/T02L^9`0N
9Ql07bTQ024[8`0R:bP08B//06afM`1_NW/06BDU024/;P2GY:H0=D=601d/;`0X=c/0<3m401/Z;`0Y
>Cl0:3U002dnA@0a@TP0;3i202do@`0`@TD0<D=50394AP0a@d@0;d510353@`0jCD/0<dI40395@`1O
LW00>Da:03A6AP0kCDl0=TQ:03a>D00kCE40=TQ<03U;C`0lCED0?e1H04QIH`19FV@0A5EO045CG`02
03mAG@0:04EHIP1>HFl0CV5_04=II`15FfT0@eUW04mRL@1DIgD0Cf=^05EWLP80DFA[00P0D65X04]M
H@19Fel0AeUL04]MG`1>H600DF=S059TI080DfEU00H0D69R05IXJ01GJFT0G6i^05AVIP1KKFd205a/
J`0X06MgMP1NKVd0HW9a06=cLP1XN7L0PI6@0720O`1PL6l0IgMf06IfM@1`P800LH6106moOP1^OWd0
LX9o07N6P`20S8`0P8^<0;k9c@3FgnH0W:B^08bDW`28TiT0RIBH08NBU02:U9D0T9ZK09>MW02>UiD0
T9VF08nHT`2?UI00T9N@09:ITP2AUID0Si>D09^OX02KWj80W:2S0:>WZP<0XjJ[0140XjJ]0:BW[P2T
Yjh0YJVb0:N[]02X[;D0ZJbc0:R[/02WZZl0Z:V/0:RXZP2YZJT0YjNW0:VYY`2_[jl0/K2d0;2_]002
0;:a]P030;:a]`2d/kT0/k:h00<0/k:j00L0/k6l0;2_^@2ZZ[80Zjba0:n`]@2YZZl0Y:FY0080XZ>W
0240XZ>U09jOX@2LWIl0XJ:T0:^/[P2NWj40Si6@075eKP1mPgD0IFaL05iVE01SK5T0LW]X07EoL01b
O740MGmf07Z3OP1`NGH0Ig9/061[H`1MJEl0H6eS06=`I@1PKF<0GFeS05QXGP1GIUl0F6QR061`K@1L
Kf/0FVeY05U/J01GJVH00P1EIF80@`1AHEh0CeiK04aKF016EE80?d]803i7@P17DDT0=Chi051IE00V
;bX0<c`i02Xc<00a>SL0CeQG03M0?`0c?3/0:c<d03Dn>@0e?cL0<S/f02/d;`0Z<bh0<3Tf02df<`0/
=C80<c`k03Q1@00f?cl0>493030l>P0Y=C<0=T90034m>`0Y=C@0:SHf030k?@0c?T00=3m1038m@@0Z
=CT092lc02Pb=00P:R/0<C`h03M1>@0V<B@0=d8b06]cI01TJed082HL02P]9P0O8b007B<O01hX800K
9Ad072HN020W800N9Al061hJ028W8`0O8b008B<R02@V9@0R92<07R0O01`N6`0P8Ql00P0R92400`0N
81d071hK01`N6`0201hP7@806adJ00D071hK01hN700H61H071`J01/K6@0201DE4`0b02<S8@0I6AL0
3Ph<01TI5`0F5Q@09bLU01`K6@0M71X06QTG01/J600Y:2H05QDC01LF500S8R004a8@01PG5@0B4@l0
4a8@01PG4`0E510051<?01DD400G5Q8051<?01`K5`0J6AD051<?01HE4@0B4@d03`h;01LF500?3P`0
5A@B00L6100@30/05a8A01PB4P0I4a<06a@D01XA4P0H3a004`d<01dI5P0V8Ql04Ph;01TE4P0J5Q<0
4`l<01DA3P0C3``201DA3P0I01<?300F4Pl03`/800X60`0I5A8071PE00/71@0;1`@02PH3014=2P0E
4@h03`/800d91P0<1PH01@0001LA4@0E3`l04@/;010;2@0C3PX04Pd9014<200@2`D04@`601@?2@02
01<>2P05018=2@0A30P04@`8014<200B3@T00P0A30P2010;1`0C01<>2P0:0000718A01H<2`0E3@/0
6a<A01@<2P0B3@X03@P501`H5@0M6AH03`/801HB3`0<1`<04`h:00h91@0B3@T07APD01LB3P06010;
1`H040/800L04Pd:00h91P0D3``03@P500/71@080`004@L600<04`T800X050X901D;2P0A1`H05@/:
01P>3@0I3`h05`d<01H<2`0C2@P04PP70`0A1`H02`0B20L04@L601881`0?1@@04@L601@:2@0@20H0
40T6010;200A30T04`h;008050h>00<03`T900h82P0=1`T00P0>20X07`0?2@/04PL;01462P0A1PX0
4PL;01<8300D2@d04PL;01D:3P0=0PH03`@801T>4P0F3a403@T:00`82@0?2P/05@lA018<3P0@20/0
40L:00l62@0B20/04@H:01@93@0@1`T071HF020J6P0N5aL040L801L>3`0<10D00P0B20T01P0C20T0
50P:01D92`0D2@X04@L601061@804@L602`040H501881`0C2@P04@L601061@0A1`H04PP701@:2@0T
6QT08QPG01881`0D2PT04`T801D;2P0F30/05@/:01471P0@1PD04PP601H<2P0A20<04PT401D;2@0A
1`D04`T700d30P0;0@0040H701L=3P0T6Q/05Ph>00d30P0?1@@05@/:01L=300E2`X040H500h40`0@
1PD050X901D;2P0C2@P040H501471P8040H500T03`D401061@0A1`H04@L600L0000_9B@0L6IU018:
2@0K4A000P0B20L02P0C2@P03@<201061@0700002`4000h61@0K4A005@/:01L=300K4A0Dooooo`00
6oooool0<`0D2``04`X;01<;2@0B3@X050l<01D@300>2`H0AdDo0?3`j01jNW806QXB00l<1`0D3Ph0
5@l@01<=3@0?2@T04Pd;020K600N6AH04`h;01D@300O6QH04@`601`G4`0@30X03`/:014=300@30/0
3`/:014=300F4Q408QhM01hJ6@0D40l03`/:00h:2@0@2PX05Q0@01D?3`0A2`/04P`<01H@400A2`/0
3`T9014;2`0E3`l04P`<00l92@0A3@`040`;00l;2P02010<2`05014=300@30/0510?01<?3P0@30/0
0P0A3@`00`0?2`X05A4@01DA400201HB4@0400l;2P0O6aX06aLF00T61@804Ph=00h04@d<018>3@0A
3@`03`/:010<2`0A3@`040`;01@@3`0E4A003`/:018>3@0C3`h03`/:010<2`804@d<0P0@30/05P0C
3`h02@D400X61@0A3@`05Q8A018>3@0;1`H040`;018>3@0E4A00510?00l;2P0E4A00510?00d9200]
:BP02`L601LC4P0?2`X0510?01DA400B3Pd201@@3`8040`;00@04Ph=01@@3`0E4A005Q8A1@0C3a00
2@0C3`h09R8Q085mO00S7a`07ATF01lK600C40/05a8?01HA3P0201@?300401<>2`0A30T050h>01D@
3@805Q4>01X05A0=01@?300B3Pd05A4@01PD4`0E4A004@d<01DA400B3Pd0510?01HB4@0H51<06ADD
01LF4P0K6QD0414:01lP6P19BT@0824K06m`J`0d=C004a<@01`L6P0R8R004A4@01PH60804a<C0P0H
61P02`0G5aH05ADC018B400A4Pd05QLB01LH4`0D5@l05AH@01hP7@0M7a`0<C<`00805aTF00/07b4N
01LI5P0@4Pl05aTF01XL6@0G6AH06adJ01TN600H7AL05a`F01HK5@0201DJ500301LL5P0E6Q@05AXD
00<061dG00l07B@M01dS7`0N92006R0P00`A500S:2/06AhQ01`R8P0M8b406b4M01/R6`0M8ad07b4L
020R7@0P8ah00P0O91h05P0Q9b40=Sdf030g<00J8a/08B/S02<]9@0]=S<02aDF03<m?P1=F5T09S8b
01TT9P15DU@07R`_01l^<@0S<SH0:3Ll01d/<@0U=C/0:CY102hoAP0_@DH202`n@P0H02m1A00a@dD0
<TA60312@`0^@400<49203a?C@0dAdD0;D0n04MJF00aA480=4I603]=C`0bA4H0>de?03Y<D00mCe<0
=TQ<04AEG@11DUX0AeQR04QIH`12Ded0BUaX0P11Del03@19G6X0EFQf05IYM`1:H6h0Aee[04]QK`1B
IG@0DFAb055UL01GJG@0Cf9Y059UK01?H6L00P18FUh06P18FUd0BUaN04mQH@1BI6@0DF=S059TI01C
IFD0CEmO05Y/K01EIfL0F6YZ05MYJ@1KKFd0FVYY05][JP1VMWD0Gfm^06AdL`1QLG00K7ak08RHU`1m
SH`0JWYi06emO01dQ8<0L81m0P1aPGh0701`P7d0Lh>007R6QP26TY80QY6D0=ORj03eo_l0Z[:n08nG
XP25T9@0R9>D08B@T029Ti<0TYbK09BOV`2?V9@0SIJA08^ES@2=U8d0T9N?09>JT`2GVi/0UIVJ09^O
X02FVYd0W:2S09>GVP2QY:T20:2SZ0030:6TZ`2RYJ`0XjJ]0080YJVb0140YZZc0:NZ/@2VZJh0YZV^
0:RY[02WYjT0Z:RX0:FUY@2VYZ@0Zj^[0:b[[`2/Zk00/:nd0:n^/`2][;80/K2f0;:a]`020;:a^@80
/K2h00X0[jng0:b/]02^[k@0];Fj0:b]/P2UYZX0XjBX0::SY@2OX:80VIZL0P2DUYD06@2=Shh0LG=b
08:4P@1dN700OhEi05MNCP1PJ5L0IVmN07EnK@1gP7<0LG]b07AnMP1jQ7h0Lgai06MbK01KIV00F6=K
05]XG`1NJf80GFYQ05][H@1HIf00EfIO05UYI01HJfL00P1FJFD0601GJVH0EVUU05EUHP1?Ge`0DF5N
051OG017EU<0@E1=04A@C@14CDP0OHMo04I?BP18DD`0<c`g03a5@P0f?c`05QlL09fVY@14CD`0B55@
04]CE00h@C`0=T0h038k=P80;CHa00h0<CXg030i=P0]=S<0;cPg038k>P0a>CX0<cdn03Q2@@0/>3H0
<Cdk02lk>@0V<S40<Cdm02dh>P80<3/m01T0;CPl02Lb=P0P:bl0;3Hh02@^;`0/=c<0:S@/02<]8`0_
>R`09BdP03Dl<00J7aP09BXT01hS7`0P9B4082LP01dW7P0L9Qh07RDN01`S7@0I7a/092TU024U8P0V
:2L09bTX008092HU00H07AlL028T8@0U9b@08bDR01dO700J71T201dO700P01/M6P0I6aP06Q`I01`N
6`0V9R@06QXH01dM6`0L71X05aLE01/K6@0D51803`l=024Q7`0K6aT08B4O00`<2P0F5A<061LE014@
3P0G5Q@06aXH02<R800D4a408b8P01HE4`0K6QP01`H401TH5P0H5a<05A@@01@C3`0E510201LF4P0<
01/J5P0D4`l04A0<01@C3`0A40`05QDB01hM6`0A40h071/I01@C4@0I5A@06A@D0P0H4Q803P0H4140
5`h?01H=3P0A2`X05A4>00T50P0D40d06QHC01TE4P0D40d05A4>014=2P0D40d05a<@0P0C3``04@0D
40d04`l<00`81@070`0081`I01DA3P0?2`P04`l<01HB3`0@30T04`l<00l92@0A2`/0618B00X4100F
41004@`900<04@`800<04@`6018=1`0C3PP00`0C3PX2018=2@03014<200C3PX04@`800804@`80100
3`X601@?2`0=0`806Q0?01<9200<10804`/9018:200<1`@050l<00D1000810405a<@00T50P0?2PH0
5A0<0P0@2`L00`0E40`03PT5010;1`05010;1`H040/800L061<@00h91P0G4Pl02@@1024L6@060@00
4@L6008050X900D04PP701<9200E2`X040H501881`0201D;2P8050X900H05@/:01881`0@1PD04@L6
01<9200E2`X201@:2@0501471P0B20L04`T800l71@0@2PH00P0?2PL01P0@2`P040X:010:2P0?2@T0
3PP:00d72@803PP:01<03`T;01872`0A1PX04@H:01872`0C20`050T=00d21P0D2@d05@X>01X?4`0F
2`l03@D801@@4@0A3@h040/=010:300;1@L04PX=00803PD800X04PP<01872`0D2@d05@d?018<300<
1PH09b0P01T@4@0Q61T030@50P0A1`P0100A1PP04PH801<72@0C20T200l5100301881`0@1PD040H5
00<04`T800H05@/:01H<2`0G3@`04PP701X@3`0M4a8301881`0601@:2@0E2`X04`T801061@0>10<0
40H50P0700002`0C2PD04`T700/1000E2`T03P@300`20@0A1`P03`D600d3100;0P<03`D4008040H5
0P0?1@@0200A1`H03P@300l5100A1`H04PP701471P0@1PD04@L60P0@1PD04@0?1@@040H501471P0F
30/05@/:04Pn?@2RV9L09adL01471P0@1PD02`4101dC4P0L4Q406Q0?01P>3@0<0P405`d<00801`00
00<03PD500L00?ooool04oooool001_ooooo0P0B3@X06@0A30T04Pd:01DA300F4`h06QLA01XG400h
=Bh0:BHM00h;0`0@3@H05Q0@01TC5@0F41803PP901@>3P0_:BT0;RTV01LB3`0V8Ah0Pgij05mJEP0V
8Ad0510>00l;2P0B3Pd00P0A3@`00`0F4Q404@d<01@@3`02014=3003010<2`0=2@P04`d=00804P`<
00<04`d=00l92@0=1`L00P0D3Ph01P0C3@d04P`<018<300B30`040`;014=30804Ph=00/040`;00l;
2P0D40l04@d<010<2`0A3@`04Ph=01@@3`0=2@P03`/:01@@3`02014=308040`;00T05a<B010<2`0=
2@P05A4@018>3@0A3@`040`;00l;2P0A3@`00P0C3`h03@0B3Pd03`/:01@@3`0T81l07ATH00d9200A
3@`0510?014=300=2@P040`;018>3@0A3@`00P0D40l00`0;1`H05Q8A01<?3P02014=30804`l>00`0
4@d<018?3P0B3Pd06QHE051<B`0A3@`03PX9010<2`0D40l04Ph=00l;2P0C3`h201DA4080510?00<0
4Ph=014=300A3@`01@0B3Pl05@0B3Pd05a<B01hJ6P0@30X04`l=01HB3`0@30L05`l<01H=2P0E3@/0
5Q0@01DA4@0A3Ph04`lA01DA4@0G4A406A4?01L?300E3@/05Q0@01@@3`0201TE500401@@3`0I5A@0
510?01DA40805Q8A00`05A4@018A3P0F5A407QlI08R9P`3`l>`0HF9M01`M600H61H05QHD01<C4@0C
4a<201HF5P0802DU9@0C4a<05QHF00X:2P0H61L04a<A01lO7@0D5A0201<D3`07018C3@0D5@l05ALD
028T8@19BdP06adJ00d?300201PJ5`0=01TK600F61D071hK01XL6@0?4@h06b0J01PM5`0F6aD05AXD
01LL5P0H7AL06AhH01/P6P0401`Q6`0=01HM5P0M8al05adI06=YJ@0f>ch041DH01XO8P0N92@07R@R
01`R7P0L8a`07R@N01hS7`0301lT800O01hT800U:bL0<CTd02D^:@0V;bX0:34/01/V800R;BX08bd^
01lY:P0R;Bh0:cLg02@_<@0P;2l09cDh02Lf>@0V=CT09cHk02Xi?P0Y>Cl0:S]202`mA00]?T@0;T14
0312AP0dATT0=dU;03Q:C00eAdP0<dE503E7A`0203A7A@0U03M:B00dAdD0=4M503M9B@0mCe40>Ta>
03]=C`0mCe<0I7Ij03mAE@0kC5@0A5EM045BG00jBeD0@55K04EGH`19FfL0AUQT04MJJ01@Hg40DfId
04UOK@17GF/0EF]i05Q[NP1@Hg40Ef]f05EWLP1@HfX0EFQ_055RJ@18FUh0BeeQ04eOHP1;GEl0DF=S
05EWI`0205=UI@0b05AVIP1NL700L8:205Y/K01GJFT0FF][05=UI@1KJfX0G6a[06AdL`1NKVd0IgMf
06=cLP1RLW40IgMf06IfM@1TM7<0JGUh06moO01/OGL0Kh1i0761O@1`P7d0M8>107R6QP1lQhX0OXV?
09:LY@2[/kd0VJ6]07n8T@1oRX`0QY:@08>?S@27TXl0SIRD08bGT`2;U900R96;08NAR@2;TX/0S9>;
08bCS02CVIX0V9fP09bQY02PYJP0^[o309NLX02MXZH209bQY`0309jSZ@2PY:d0XJF^00<0XZJ_00l0
XZN]0:>VZ`2RYJX0XZJX0::SY@2TYZD0XZBS0:BTXP2ZZZX0Z:V/0:VZ[P2_/;@0[Znc0:^//02_/;@0
0P2_/;D0:02^[k@0[Jjc0:f^/`2][[D0ZZfd0:^^]@2_/[P0ZJba0:>WZP2TZ:X0XZJV09bPX02DVIH0
RXn;0866PP1dNGD0M7Ud07j3OP1jOgL0M7Y_06=[G@1YLV80JgAV06mjJ`1dOW<0MGmf07=nMP1eP7X0
Lgij06agL`1RKVT0GfaU05m/IP1OKFH0GfiW069aJ`1TMFl0HW=]05i^J@1GJVL205MZJ080FFaZ00d0
F6QU051PG@1EIF80BEQD041?BP1BHE`0QY:>04E?B026T8P0DU]F03Y3?P0`>C@0:S<`00809Rl/00H0
>D9103a5A00f?ch0<c/l03M0>`0d?SH202lh<`0B030i=00a>SL0<CXg02`e<P0Z<c80;3Dd030i>@0h
@D<0=d5003Y6A00/>3H0:CDc02di>00b?Sh0<3/m02`g>@0W<S@09C0d0P0T;c<0:P0W<C<0:38c02Td
<00Q:RD0;3H]03Q2=`0U;B80:C0V02DZ8`0W;2H08bPT028W8`0S:R<092/S020W800M91d07B<M020U
8@0U:RH08bPU02L[:P0T:2L07B4P028V9@0P8Ql08B<P028T8@0P8Ql071hK01/M6P0P8Ql07AlL01XL
6@0I6aP07AlL020R7`0[:bT061PF01TI5`0H61H06ATG024Q7`806QXH00@06a/I01HF500L71X06QXH
0P0F5A<03P0K6QP04a8@01dL6P0B4@l061LE01HE4`0E518061LE01@C4@0I61H061LC01DD400D4`l0
5A@@0P0G5Q80<`0F5A404A0<01XI5@0I61@040l;018A3P0J6AL03`h<01/J600D4a407ATH01dH600F
41005@l?01D>3P0G3Pl06A0A01/E500g<c007ATF01/G500;1`H04`l<01DA3P0G4a005Q8?01@@3@0A
3@X04Ph;01<?300B3P/05Q8?01@@3@0?2`P0<BdZ03<_;00Q7AX03`/800d91P0@30T0:2@Q01@>3P0A
2`/04P`<00X51@0N61P04Pd:00l:1P0@2`L04Pd901<>2002018=1`<04Pd901/04@`8010;1`0@2`L0
4`h:010;1`0B3@T04@`800h91@0F4@d04PP701L=300D2PX06Q8@01<;2@0@20H05A0=00d81@0B3P/0
40`900`81@0K5a@04`h:018=2@0@2`L03`X6014<200D3`/01P0@2`L6010;2009014<2@0>2@H050l<
00h9201XHf005Q4@01<9200F30/05@/:00804PP70`0D2PT201<9208050X900T05@/:01@:2@0C2@P0
50X901D;2P0F30/050X901D;2P0B20L00P0C2@P01@0>1P@05Pl<01<>2`0B3@X040/800803PP800<0
3`T900h82P0=1`T00P0>20X05P0?2@/04PL;01462P0A1PX04PL;01<8300D2@d0=b``01462P0>1@L0
6@hB01<8300B2@`030H8010:300?2@/02`D7014;3@0@2P`030H800l62@0B2@`200l62@0:018:300A
30`02@<305UADP0Q61T04@T:01<:2`0B20T04@L801461`804@D700P04@H700h40`0?1@@050X90106
1@0B20L05@/:01<9208050X900D04`T801471P0B20L03`D401061@0201@:2@0I01<9200?1@@04@L6
01881`0@1PD04@L601D;2@1<@T00;2<N00l60P0C2@L04PP601071@0B20L0308101882@0?1@H03P@5
01<:2P0C2@P040H500h40`0A1`H04PP700l5100401061@0301471P0C2@P04@L6008040H501D03`D4
01061@0A1`H02P8101<9200@20L08ALF00l5100B20L050X900h40`0E2`X040H501071P0<0`<05P`;
01481`0A1`H040P701071P0H3Pd05?ooool001_ooooo01/040`;01@@3`0F4Pl020@1018>2`030000
3P/6014=1`0D3`T05A0:01<>200A30P0510A00l:3P0C3a003`/<018>3P0=2@P03PX901XF501<B4D0
l>gZ0:6MVP0^:RL0510?00l;2P0@30/00P0C3`h01@0A3@`03PX900l;2P0@30/04@d<00804Ph=00L0
4@/;00d71`0@2PX0618B01H@400B30`04@/;008040X:01h04P`<01@>3P0E3`l030P701<?3P0:1PD0
5A4@00L30P0H51<0B4A301DA400D40l04Ph=00L30P0@30/04Ph=010<2`0<20L04Ph=01DA400>2PT0
4@d<018>3@0C3`h02`L600T5100B3Pd05Q8A01PD4`0C3`h201@@3`07014=300B3Pd040`;00l;2P0@
30/04Ph=01<?3P03018>3@07010<2`0?2`X05A4@01DA400A3@`04`l>018>3@0201@@3`0C01DA400?
2`X030P700L30P0K61L04Ph=00l;2P0@30/04Ph=010<2`0C3`h03`/:00d9200B3Pd040`;00d9200B
3Pd04`l>010<2`0201<?3P0;00d9200A3@`05a<D00h:2`0G4a@08alP01/G600F4Q404@d<018>3@0C
3``00P0D40d03P0E4@`06A4>00l50`0K4a40>C<c01/H6P0@41804@lD010=3`0B30`0610>01D<2P0:
0P0050h>0`0E4A00;`0D40l04Ph=01dI600>2PT07QXI00l;2P0E4A004a8@01`K5`0E5Q40>c`g05mP
F`0d=C405QHD01/K6@0@40l07QhN00H6200H61X03Ph@01TI6@0E5AD04A4A01`L700<30/08R8P01/K
6@0E5Q404a@?01@E400I6Q@06a`F010B3`0F61D06Q`I014C400G6AH0:R`Y01PJ5`0F61D061XG01XL
6@0F61D04Q@A01LL5P0H7AL06QlI00806AhH02P02Pl901XO6@0M8Q`08bPR01dR700G71H06QlI01PO
600G7AT0:Bl[03Y0@00d>C`041DH01/P8`0O9BD0728P028X900Q:240728L02ld<00D6AD06AhJ01hT
800V;2P082PS02</9`0R:bH08B`V01lZ900N:B<08R`Z02@^;`0S;Bh08bh_02@`<00V<C<09C8d02Hd
=`0Y>3/0:cXn0P0[>Sl03P0_?dD0;Sm602hoAP0bA4T0<49603A6BP0iBdh0?U1B03e?D@0_@D80=4I6
03I8B00dAdD0>4]90P0fBDL06P0lCdd0?4i>03i@DP12E5H0?DmA03mAE@0jC500?4iB04]LI00mCUH0
AUMQ049CG@0oD5X0DF=_04iPK01CIG40@UES04aOK@1:GF/0Bf5_04UOK@1=Hg40DfIe055TLP1AIG00
EVQc0P1AI6/02`19FV40AeUM051RIP1DIVT0Cf5S04mQH@1@HV80DF=S05=UI@1EIfL0EVQX0080EFMW
00<0EVQX05U[J`1KKFd00P1MKF`04`1NKVd0H71_06AdL`1VMWD0H71_06MgMP1^OWd0M8B306UiN01_
Og`0KWmg06amM01cQ7h0LX9o06mnO01kRHX0PhjB07b7SP1oRI800P24S9L01`26SiH0PXj>07n;Q`22
SXX0R9>?09:MU`2KYZ000P21RXD07`1mQgl0S9><08R?R026S8P0TIZJ09:JW029TI<0Xj^^0:jf^@2G
Wj80UijT09JMY@2KXZX0VZ6Y09fT[02TZk<0WZF]0::Y/@2X[kL0WjBZ09fRYP2Z[k<0WJ6S09nSY02V
ZZT0XJ>R0::TX@2^/:l0Y:FX0:RY[@2[[;000P2^[k<07`2g^;`0/;6e0:BUZ@2ZZjl0Z:V[0:Z[[`2[
[K80Y:V_0:FZ/02W[;40YZ^_0::WZP2OY:H0WJ>Q09NMV`2;THd0QXf608>:P`1mPgd0MGYd07QmM`1m
PgX0LGU^07=kKP1mQWT0OhUn06miKP2:UX`0SIR@06ehLP1_NWD00P1`O7P04@1YMG40IG5]06QgM01Z
NGD0I7=^065bK@1RLfd0H75[05IYI01GJVP0E6IV05U[J`1GJVP0Cf9P05EUI01BHUl0B5QE0080AUE@
05/0BeYC04=@B@0f@3P0>D<k03a5@00nAd80;cPc02Pa;P0[=340:S<`02`e=00U;Rd0:34`02/c=00/
=C00;3H^02Xc;P0`>C@0=Slj02`e<P0Z<c00;CHc02`e=00[=3<0<S/k038j?00T;Rd0<3Xi03M1@00b
?3/0:cDe02Tc=00V<380;SPj02/e=`0Z<cP082T^02/d>@0P:R`08R`/02@_:`0V;bX092hV024[8P0U
;2@09R`U020U7`0N8ad092TT02P]:@0O91h08RLQ02<X8P0G71H07B8M024V8P0R9b<09BXW024W9@0J
81h0728P01HJ6@0H6QL0:2XW01LI5P0P8Ql0Gf5N01@F4`0K7AX09RPU01<E4P0N81d04aDB02PZ9`0L
71X07AdK01PH5P0C4a405aLE01dM6`0J6QP05QHD01LG5@0J6QP061PF01DE4`0G5Q@061LE01LF500F
5A<05aHD008061LE03d051<A01DD4P0J6AL061LE01DD4P0F5A4061LC01DD400F5A405A@@01HE4@0J
6AD06APD01HE4@0C4Ph04Q4=01<B3`0V9B<040l=01PG5@0S8R00L6a[01D@3`0D3Ph04`d=01/C500G
3Pl05@`=01LA400:1P<05Q8?01TE4P0>2PL061@A014=2P0M6AH04Ph;01@@3@0>2PL0510=01<?300B
3P/04`l<01TE4P0D40d040`901DA3P0<20D05A4>01@@3@0A3@X03`/801H@400E3`l02PD501PB4P0@
2PX05Q4>01<>2P0B3@T04`h:00805A0:00T04Pd7018=2@0C3PX04@`800h91@0@2`L03PT500l:1P0@
2`L00P0B3@T05P0@2`L03@P401dC4P0U6aX05P`;01491`0D30X05Ph<014<2@0@2`P01`<001<?300L
61D0al?0055<B00C3PX05A0<00d8100<1`@050l;014<200>2@H200d81008014<200E40`04`h;00`7
1P0N6AH0100001<>2`0k=S<600l:1`0601471P0B20L04`T801<9200B20L04@L60P0C2@P201881`80
4@L600H04`T801881`0A1`H04`T801D;2P0F30/201<920804PP701H04@L601081P0G4@d03PT600d8
1@0A30T03PP800X4100>20P03PP:00T31@0=20T06aDG00`6200=0PH03`@801872`0G310060dA01L<
400C20`04@H:0`0@1@T04`0?1@T050/>01<:3@0?1PT06Q4D01LA4`0A2`d03@L900`6200D3Q004@/=
00d72@0<1PL05@l?01@>3P0C2``040L800T00@0A20T00P0B20T0100A1PP050P:00/00@0E2PX20106
1@0901471P0B20L04PP700l5100@1PD04PP701061@0A1`H04PP700H040H500`06a4@00L0000C2@P0
5P`;01061@0W7A`0e/c:06]RG@0;0`4050X800l50`0;0P4201471P@04@L801@06a4@01@:2@0<0P40
4@L601D;2P0B20L040H500l5100>10<03`D401881`0F30/03@<201H<2`0C2@P05P`;00l5100A1`H0
4`T801881`804@L600@04PP701<9200>10<040H50P0B20L0100@1PD03P@300l5100A1`H201<92003
01471P0?1@Cooooo01?ooooo000Kooooo`0P018>3@0A3@`04Ph=00/71P0D40d06QHC00l;200C3`X0
5A0:01HA3@0D3`T04Pd9010<3@0F4AD03`X>00h:2`0A3@h04@d<00T5100J5Q@08QhK08=oO01KEe@0
3@T6014=300@30/04@d<01@@3`0A3@`03PX9018>3@0A3@`2010<2`803PX900@04`d=014;2`0A2`/0
4`d=0P0D3Ph301LA4@0N01H@400C3@d04P`<01<?3P0H51<03PX901<?3P060P404`l>01HB4@030000
2@D401DA400B3Pd061@C01<?3P0B3Pd03@T8018>3@0D40l04Ph=01<?3P0A3@`09R8Q02LS8P0C3`h0
3@T8018>3@0C3`h040`;0P0C3`h00`0A3@`04Ph=010<2`02010<2`03018>3@0C3`h04`l>0080510?
00L04`l>018>3@0D40l03`/:00`81`0?2`X03PX9008040`;03403`/:014=300K5aH081`K03lk>P0B
3Pd03`/:010<2`0B3Pd040`;01<?3P0D40l03@T801LC4P0D40l04@d<018>3@0E4A003`/:010<2`0D
40l04@d<01<?3P0H51D040`=01HB4`0O6a`061@E01<?3P0D40l04`l>018>2`0A3@X04`l<01HB3P0A
2@H04`T7014:2@0J5QL04a8F01TJ7P0?41@04a8F01dI6P0E3`l040L502<K600F4@h05A4@00804`l>
04`0510?01DA400B3Pd0510?01/G5P0:1PD061@C01<B400I61@03@h901hO6P0`<B`071`I010@3P0?
3`d0410?01@D500@41805aLI02@T9P1@D5004a<C020P800G5aL09bLV0041000I6AL05QLB01DF4@0F
5a8061TC01TJ500I6aP05QPE01TK600J71T0;Bl/04=5@P0H6QL05QPE01LI5P0I6aP05QPE01<E4P0H
7AL07b@N02DZ900Y;RP0:c0Z01dR700K81X07R<M02<X8P0P9Al07B8L024V800mA3d01`d902@Z9P0K
8B4041DH028W:P0D6A`051XJ01hT8P0E6aL07bHO07=iL`13B4@07R<O01hT800I7a/0BU1<01dV8@0P
:B@07bXT0P0N:B<03P0M:2808R`Z02H`<@0U;c009C0a02Hb<P0X<cD09S8e02Dc=P0W=ST0:CPl02Xi
?P0[>Sl0;Si40P0/?D@01`0`@TL0;T140394B00dATT0=TQ:03M9B`0a@d@00P0iBd/02@0aA480=TU7
03A7A@0aA480=4M503=5A@0eAdT0?DmA03U;C@0203i@E003049DF01WN800C5eU0080@55K00h0AeQR
059TL00oDEd0C5iZ04MJJ01;GV`0DVEc04AJJ019Gfd0Bf5_051SLP1@Hg40D6A_05=UL080D6=Z0140
B5UP04IHG01>H6@0D69U051RI01@HV80DF=S059TI01EIfL0EVQX05AVIP1EIfL0EfUY05U[J`1LKVh0
GW1`065aL003069bL@1f061`K`1NKVd0I7Ac06UiN01[NgX0L81o06QhM`1`P7d0KWmg06n0M`1bPgd0
LH5n07:1P@1iQhX0OXV?07b7SP23SIH0Qi2I086:T`1mQXd0Oh^;07n;Q`22SXX0Q8n;08RCS@2>VI<0
SIJA08><Q`20RH@0PhZ408:8Q02AUi<0SYNG09RPXP2CVid0Ti^N09FMX02@V9/0UIbR09FLY02IX:P0
V9nW09ZQZ@2QZ;00WjJ^09jU[@2RZK40WjBZ0:N//02g_<00_<3209jRX`2OXj80YjVX0:BVX`2VZ:L0
YZNZ0:NX[02YZZh0[:fa0:j_/`2h^Kd0/K:f0:BUZ@2RXjD0VibN09bMW`2TZJ`0YZ^a0:N//P2W[;40
XjR/0:2UZ02FW9/0SiFA08bBSP24Rh@0QHb408J=Q@1jP7P0L7E^092ESP2MXiX0LGU^06ifJ`1dOW<0
K7I]07V5N`3CgmH0]/6i07AoN@1^NWD0L7ah075mN@1]NGH0JGEc06UhM@1YMgH0Hg=`061`K@1MKFX0
FV]U05=VH@1GJVP0DfEU05EWI`1DIVH0CF1N059RH@1>GU/0CemL049AC00a@3T0<3lh03M4?@12C4@0
=T0h030i=080=d0k01T09c0]01lX9@0Y<Rl0>dA303M0?`0`>CP09Rh_02hg<P0^>300;CHa03@m>00k
A3l0=3dj02Xc<00]=S<0;3Dd02/d<`0a>CX0;cLi02@^;@0Z=3<0;SPg02dg=P0Z=3@0:S@e0080:38d
03H092h`02Pa=P0Q:Rl0:38d01lY:`0T;Rh09S0_02@]:P0P:B@07bTQ02D/9@0X;RP09b`V02DZ900R
9b807R<M02H[900T:B<0724K018G4@0N8ah06QlK01`Q7@0F6aP08bTW014G5@0P9R@06b4O02HZ9P0G
6AH05ALD01hP7@12A4409RPU01TK600W:BH05ALD01hP7@0E5a@051HC01HF500J6QP06a/I01PH5P0G
5aD061PF01HF500B4Q004a<A01DE4`0C4a404A4?01PG5@0G5Q@201DD4P0>01PG5@0K6QP05aHD01DD
4P0F5A<05aHD01HE4`0E51805A@@01LF4P0D4`l05QDA01DD400D4`l501DD400702@S801/JfT04a8@
00h=2`0A40h09R8Q018=300201H@400T01PA4@0F3@h060l@01H@3`0@30T04Ph;00h:1`0D40d061@A
01DA3P0;1`@08alL00/7100Q7AX01@4001`H5@0C3``040`9018>2`0C3``05a<@01dI5P0?2`P02@D2
00/7100B3P/05a<@00@0000V82007QPH010:2P0400004@`900/60P0=20@040/70P0A30H01P0@2`D0
3@P400h91@0B3@T04@`800l:1P804Pd900<04@`8010;1`0?2PH00P0?2PH00`0>10<06Q0?01H<2`02
01H>300=018:200E40d03`X801TE4P0D40d0920M0:fYYP0l=c<040/701D@300?2PH03@P4010;1`02
01@?2`8040/70P0C3PX01P0@2`P04@`900`7100g<Rl0Ddi;06eXI@H040/800H04@L601881`0C2@P0
4`T801881`0A1`H201<920804PP70P0A1`H301881`0401<9200D2PT05@/:01<920804PP70P0A1`H0
4P0@20H050d:00h91P0>2@H040/800l92@0>20P040X:00`6200:10H03PP:01XD5P0@2P`04@H:0105
2@0B1`/05P/?01D:3P804`P<00D04@H:01052@0@1@T040D901062@0201482`0@01P?4P0/8bH0:R@V
01LA4`0?2@/030H800/51`0>20X03@L9014;300=1`L0100002DN7P0i<3407aHG00h51P804PP900@0
5@X;01451`0A1@L03P<40P0@1PD0100A1`H04PP701881`0@1PD201471P0400h40`0@1PD03`D400l5
10D04PP700X0308101@:2@0F30/0308100l5100>10<081HD0189100F3@P07Q@B0P0A1`D201471P@0
4@L800H05`d<01881`0=0`8040H501881`0@1PD200h40`0:01061@0C2@P05P`;01X@3`0C2@P060h=
01H<2`0H3Pd050X901D;2P804@L60P0@1PD201471PL040H500D04@L601881`0B20L04@L601061@0D
ooooo`006oooool07P0A3a403P`>00P61`0C4A<040d=01HB4@0>20T04@/:018=2P0D30/050`9014<
2@0<20T09R@W00`:3@0?3A003P`>01LE5P0=30X04A0>00X91`0J6AH05QDC01DD400>2PT040`;018>
3@0C3`h03`/:00`81`H040`;00<04@/;01<=3@0B30`00P0@2PX04`0A2`/050h>01LA4@0I4a<0618B
01D?3`0C3@d0510?01HB4@0A3@`04Ph=014=300B3Pd07a/J02/W9P0I5A@03`/:00d9200?2`X00P0B
3Pd00`0A3@`04Ph=014=300200h:2@0400d9200M6AP07QXI014=3080510?00@03`/:010<2`0E4A00
510?1`0A3@`00`0@30/04Ph=01<?3P02018>3@8061@C00D04`l>01@@3`0A3@`04@d<01@@3`03018>
3@0A00T5100G4a804`l>010<2`0A3@`04Ph=010<2`0C3`h07ATH00`81`0D40l02`L600h:2@0C3`h0
5A4@014=300@30/00P0C3`h02@0E4A005a<D010<3@0B3Pl05a<D018>3`0@30/05A4@01@@3`02014=
2P0@01<?300G4`h05Pl901`D400D3Pd05A@E00lB5@0>51P02@dB00d?4P0>3@d04@`<01H>300F3P/0
5Q4>01@@3`804Ph=01`05A4@01LC4P091@@06aLF01HB4@0O6aX06aLF01@C4@0F5A404A8=01LH4`0>
3P`05aLE01HF500G5aL04a<D014A4`0];Bl06ATK01LG6@0E5AD061PH01LG5`0A4A404a<B018B400F
5Q@05aPC0P0H6A@02`0H6A<05aPB018D4@0D5Q<06Q`I01HH5@0C5A806A/H01XL6@0G6AH05QPE00<0
61XG00H051TC01XO6@0P9Al08bPR02P]9`0L8A/301dR700E01XO6@0K81X07R<M01`S700U:bL07R@P
01XP800I7R406QlR01/P8`0I7al08BLU020V8P0O9Ql0>D0k020V900Z<2h07bDS02D[:@1BFeP08R`Y
00807bXV0P0P;2P0500Q;BT08bh/02@^;`0T;Rl09C0`02Hb<P0W<S@09S8e02Dc=P0V=CP0:3Lk02Xi
?P0]?440;Si402/l@`0/?D@0;T1502i0A00a@dL0<dE80P0dATP0100dATL0?4i>03M9B@0fBDL203Y=
B`0K03E8AP0fBDL0>de=04=EE`1?HF<0@UAF03e?D`0nD5@0>deA04=DG00oD5P0AeQR04IGH@1;G6H0
B5YV055SK`17FFD0Bei/04AGI@18FfT0CfEc04aRL01;HFl0CF1_051SL@1AIG00Cf5/0080B5]R00D0
AeQO04UKG`1=Gf<0CV1S055SI@02059TI00705=UI@1FJ6P0F6YZ05=UI@1FJ6P0FVa/05a^KP0205i`
L00705i^K@1QLG00Hg=b06=cLP1PL6l0GFe/065aL00206EeM02206]kNP1YNGP0LX9o06enN01cQ7h0
Kh1k06moO@1gQXH0MH>7082:TP24SYL0SYRP08jGW`20RHl0Mh2307V5P`1nRXH0R9B@08JAS@22S8X0
Q8n;08ZCT02AVYP0VZ>Q096GU@1mPh80S9:A08fEU`2?UiX0TYZM08nGVP2>UI/0U9^Q09NNYP2HWjL0
VJ2X09NNZ02IX:X0WJB^09ZSZP2LXj/0X:N_09^RZ02QYZX0ZZnc0:Z`/@2FVY/0UYZI09^OWP2NXil0
XjNV0:6UZ@2OXZL0XJBY0:FY[02VZZd0YZZ[09fQXP2EVIX0TYJF08jBT@2DV9L0X:FX0:>W/02SZ:h0
WZ>X09JKW`2BUiX0T9JD08jDT028SXT0O8=j07Z2M`1kPgP0NH5f06eeJP2:TXL0WZFL07V0N01cOG@0
M7ie06mjLP1hPg/0ZKF]08fJT`1WM6d0KGUd06ijMP1]NGL0K7Ui06YhN@1YMgL0IgIg06EeM@1OLG00
EfYW05AWH`1EJ6<0G6i^05QZK01CIFL0DVAT055SH`1@H5l0BEUF04]KE`0oCTP0BUUB03m?AP1EHUT0
GFMO041:@P0lAD00;CHa02/d;`0V;b`0;cPe02`e<P0Z<c809c0_02Tb<@0^=cL0;SLb02`f;P0X<B`0
;3D`030i=00]=S<0:S<`02df<`80;CHe00<0<CTj02hf>00Y<c800P0V<2l09P0Z=3<0;3Hf02Xd=@0Q
:bd09S0b02Xd=P0a>Sl08b`a020Z;00L9RP08B/[02@^;@0T;B`08BXX01lX900Z<2d092TU024V8P0P
9B407b@O01hS7@0Z;BH07R4K01hP6`0M7aX082<O014F4P0N9200728O01TO7@1AFUL0<3Tf02hd<P0M
81d04A<@01lQ7P0K7AX07b4N0P0H6QL0200U9b@06A/H01`N6`0S9B805QPE028R800J6QP061PF0P0K
6aT201TI5`<05aLE00T05QHD01DE4`0I61H05aHD01DD4P0D4a4061LE01`K6@0E51800P0H5aD201DD
4P0401HE4`0C4Ph05QDA01@C3`805aHB0P0D4`l05`0C4Ph051<?01@C3`0E51009bHS06e/JP0J6AL0
6APF01DD4P0C3`h061<B01PB4P0I4a<05@h>01P?400I414061<A01dI5P0E4@h061@A01<?300=2@H0
5a<@008030T700`06ADB00P40P0X92403P/800h:1`0?2`P05Q8?01@@3@0B3P/03@T601<?300D40d2
014=2P0801@@3@0C3@d0<B/[01PB4P0B30`050h>014<2@0A30P201<>2P0B00d80P0<1`404Pd701@?
2`0>2@D04Pd901@?2`0=20@04Pd901<>2P0B3@T040/700h91@0?2PH04@`800`30`0F30/04PP70`0E
3@/0600C3P/03@P500l;200=2@L04`l<01@@3`0H4`l03`X601<>2P0@2`L04Pd900`70`0B3@T05A0<
00d8100<1`<04`h:00h91@0@2`P04@d:00l:200?2`T0D4]801LB3`H04@`900H04@L601881`0C2@P0
4`T801881`0A1`H201<920804PP70P0A1`H01@0B20L04`T801@:2@0D2PT04`T800<04PP70P0A1`H0
5P0@1PD03`L500l81@0@2`P03`X700`7100>20P04@/;010:2P0;1@L03`T;010:300K5AL081XL01@9
3@0B1`/04`P<01@93@0B1`/040D901<8300A1PX201052@0J01462P0D2@d050T=01052@0C2@d081LJ
01/B5@0B2`d08A/M01XD5P0?2``0510A010<3@0A30d04@/;00h8200F3Pl040L800/20`0C2@X05P`=
00d3100D2@X04@D7034U9`0A1PH201061@0301471P0B20L04PP700804PP700@040H501<9200I3`h0
5P`;1@0A1`H03@0B20L040L701@:2@0B2@P05Ph=018:2@0B20H050X801H=200>1@803@@30189200?
1P@00P0A1`H40147200:00l5100A1`H04PP701061@0?1@@040H500h40`0?1@@04@L601<9208050X9
00L04`T801061@0@1PD03P@301<9200B20L040H500@04@L600<040H501881`0@1PD00P0?1@@0100@
1PD04PP701471P0A1`H201881`804@L65?ooool001_ooooo01P04a8G02<R9`0<30h040hC010<400I
5AH03@L;00l72P0A20T04@P;01882@0A20T07aXN03/i?P0G5AX05A<F00X82P0@3Pl02`T:018@400C
4Q0020L6014@3P0C4Q0200l;2P803PX900H03`/:010<2`0>2PT03`/:010<2`0A3@`2018>3@0600l9
2@0A2`/05Q0@01/E5@0D3Ph03PP80`0A2`/0300C3@d050h>01@>3P0E4A004`l>014=300:1PD0510?
00P40`0@30/05a<B00d920803`/:00@04Ph=00h:2@0?2`X04@d<0P0@30/0200?2`X04`l>010<2`0=
2@P02`L6018>3@0S7ah061@C0P0@30/00`0B3Pd04@d<010<2`05014=300300l;2P0>2PT03`/:00<0
4@d<00D0510?018>3@0?2`X04@d<00h:2@0200d9200>00`81`0C3`h05Q8A014=300E4A00510?010<
2`0A3@`04Ph=00l;2P0B3Pd06aLF00l;2P0G4a82014=300401@@3`0B3Pd0510?01@@3`803PX900d0
4`l>010<3@0=2@X03`/<018>3`0A3@h04`l>010<2`0A3@`0510=01DA3P0D40d04a0;00803PT302T0
40h;018C5@052`l07bP]0499D@0O9BX05AHH01LF500E4@`061<?010<2@0C3`h05Q8A01LC4P0E4A00
4`l>01DA400G4a80510?04M3@P0J5QD05A@B00l>300B4Q006QXH00l?3@0M7A`05ADE01PH600L71d0
5QHH09nNX`1?CU<0410B01/K6`0@41004Q8B0000000G5aH051@B01PH5P0201DF4@0;01HG4P0I6Q@0
6Q/E01XL6@0C5A8051HC01HH5@0K7AX07b4N01TK600H6QL00P0G6AH0GP0I6aP06adJ01PM5`0H7AL0
5a`F01DJ500K81X04QLA01PM5`0K81X0724K028W8@0[<2X0;c@^01lV7`0F71P04QPD01XP800@5AP0
6b0S01DJ7@0R:2P06R0N01XP700M91d07bHQ028X9P0I7ad09Rd[01lX9@0<5A8082XV01lZ9P0O:bL0
8RhZ02@`;00U<Bd092l]028/;@0S;Bh09C0a02Hb<P0W<S@09c@f02Pf>@0Y>3/0:STm02`k@00`?d@0
;cm502dnA@0_@4L0;d560353A`0cADT0>4Y=03U;C@0eAdT0=4I703U;B`0gBDT0>di<03U<BP0eB4H0
<DA203A7A@0oDE40=TQ:045CE@0gBD/0=TQ<03]=D@0lCU80>4UA03]<E017F680@U=M04YKI@1AHfl0
Cf5]04QJIP1EJ7H0A5MU04EHIP1>I780D6Id04eSL@1>HG00D6=a051TK`1<GVT0BeiU04ULH`1=GVD2
059TJ00k059TI`1@HV@0D69R055SH`1BI6@0EFMW05IXJ01EIfL0EfUY05Y/K01KKFd0FVa/05QZJP1K
JfX0G6a[05e]K01NKVd0HG5`06=cLP1UMG@0KWim06alN`1bPX40Kgmn07:2P@1/O7T0LX9o06emO01_
Ogl0NHN<07B1R@1nR940P8ZB08F@UP22Ri00MX22079lN`1iQH<0P8b:08^GU@29Ti80PH^<086;RP2>
UYL0SYJH08VAT`2>TiH0RHjA08fBU@2;U9H0T9ZL08jHVP2=UY/0SYNL08bEVP2AVZ40TibU09:KY02A
VZ<00P2BVj@0H02FWjH0VZ>Z09^TZ`2FWJ<0TYZM09FMX02IWj00W::R09VOW@2@U9<0U9VE09jRX@2M
X:@0W9nT0:2SZ02UZJ`0X:BU09^OX02FVYT0T9BC08^?SP27S8P0Ri2<09ZNXP2QZ;00XJR^09ZQYP2@
V9X0S9BF08VBS`25SXT0OXR0079lLP1bOFl0Lgi`07AnL01eOG00MGeb071iK`1_NG00LG]c06UcK01d
OgT0MhAm06QeK`1WLfl0JGEa06]hM01VMG00I7=`06AbLP1ULgH0IGAg069aM@1QL7<0Ffe^05AWI@1C
IV80EfaV05MYJ`1GJFd0D69T04eOG`1@HV80Be]J04IFD`1:FeD0AEA=03i>A00b@SP0/l2g0>_ek@1o
RH40=Slj02hg<P0a>SD0<c`i02lh=@0Z<c00:34`03@m?00f?ch0;CDf038k=P0]=bl0:S<^02`e<00]
=S40;3Db02Tb;`0/=C80;CHe02hg=P0d?3d0<SXl02df=@809c0_03<0;3Dd02/c=00R:R`07RHY02Ta
=00]=CP0;SDk020W;@0T;2l08bd^01hX9`0O:BP09Bh]02</:`0J8b00:S0^024V900Q9B@08bPT02L/
9`0`=Bl0FEaE02HW8@0P8A`071hI01TL600S:2@07B<O02<Z9`16Cd`0bmCA06]eLP0E7Q/07R8N02@V
8`0l?S/05ALD02X/:@0M7a`0<C<`02T[:00N81d07AlL01/M6P0N81d0:BTW01TI5`0E5A<06QXH01`L
6P0J6QP00`0G5aD0100F5Q@05ADC01DE4`0F5A<201TH5P0401LF500F5A<05aHD01HE4`806aXH0P0G
5Q@01P0H5aD04Q4=01DD400C4Ph05aHB01HE4@H04a8>00h04A0=014@3P0>3@/06aXH01HE4`0^:RT0
71LG01H@400D3Ph05Ph?01XA4P0F3@h02@@401<?30804Ph;01/03`/800`81@0I5A805a<@01TE4P0@
3@/04Ph;00<0000A3@X04`l<01TE4P0S7a`06aLD00l;200H51405Q8?00L30@0C3``04Ph;00`81@04
00002@<301<=3@0I4a<03`T900h91`0>2@D00P0@2`L02`0?2P@05A0:02HQ6`0Q71P04`h:00`70`0B
3@T04@`8018=2@0>2@D03`X600<04@`801L040/701D;2P0I3`h04@L6018:200@20H050`:010;200D
40d06QHC01hJ5`060P40;2PU00T4000C3PX03PT5010;1`0B3@T03PT5010;1`0A30P03PT500l:1P02
01<>2P0601XE4P0;1P<07QTF01D@3@0<20H01P401P0A30T01P0A1`H04PP701<9200C2@P04PP70147
1P804`T80P0B20L301471P0501<9200D2PT04`T801471P0@1PD00P0B20L201471P0E01061@0?1`D0
4P/801HA3P0D3``03@P500h8200B30`03PP800l92`0B30h02P@600d72@0M5aT04PL;01462P0B1`/0
50T=01872`0@1@T04PL;008040D901/04@H:01872`0B1PX04`L;01872`0A1PX050T=01<:3@0>1PT0
71HH01<?400?2``02`T:00H41@0H4a@0208200D0000U7Ah07QDF00l61`0C2P/060h?00X00@0B1`P0
4@D703``<P0C20T00P0@1PD02`0A1`H04PP701881`0B20L04@L601061@0D2PT07A<B01X@3`0A1`H0
3`D4008040H50P0A1`H0300D2PT03P@301061@0E2`X03@<201L=2`07000030<00189100B20H04@L5
01881P804@L6100A1`P02@0=0`804@L601H<2`0B20L03`D401881`0?1@@040H501471P0201061@09
00l5100C2@P0308101<:2@0800004PP700l5100A1`H04PP700804`T800@04PP701471P0?1@@040H5
0P0A1`H00`0@1PD03`D401471P0501471QCooooo000Kooooo`0800001@0O7R@07QdR01<A5P0810X0
3PT=010:3P0A2Ph201<:3@0>01D;3P0D2`h040/?02@R9`0@3Q<040hA00`:300@3Pl03`d>00`:2P0P
7ad051<A02@S8@0F5A<2010<2`0300h:2@0=2@P03`/:00804Ph=00<04@d<010<2`0@30/00P0>2PT0
300B30`04`d=01TC4`0P6QX0618B010:2P0F41004`d=014;2`0@2PX04@/;018<30802`L600X04@d<
00/71P0T81l040`;01@@3`050@002@D401@@3`0:1PD04`l>0P0?2`X02`0A3@`03`/:00l;2P0B3Pd0
4`l>00`81`0A3@`04`l>014=300L61L05A4@00803`/:00<03PX900d9200?2`X00P0A3@`01@0B3Pd0
4@d<014=300@30/04@d<00@04Ph=00<040`;00X61@0:1PD00`0@30/201<?3P0500h:2@0810<030P7
00l;2P0D40l00P0A3@`02P0B3Pd03`/:014=300<20L03`/:01HB4@0I5A@04Ph=014=300@30/201DA
4003010<2`0A3@`04Ph=00803PX;03/040`=018>3`0C3a00510?00l;2P0A3@`05A4>01LC400E4@h0
4Pl:01<>200E4P/05QHC00X>3`0>5QX0D5]Q0>7Zl@18D5@03a<D01TI5`0<2PD07aXF00h:1`0C3`h0
61@C01TE500F4Q404Ph=01/G5P0C3`h05a<B04Q4@`0H51<05A@B01<B400A4@l04Q8@00h>300F5QD0
4Q8B00410@0H61T08R8T030_=00T8bP03Ph@00/;3@0F5QH03@d=02DU9@0E5A@06QXH01LG5@0E5Q40
51D@01HG4P0J6aD06a`F014C4002018D4@0901<E4P0D5Q<05QPE01PJ5`0I6aP061XG01LI5P0I6aP0
6adJ00806AhH00@05a`F01@I4`0L8A/051TC0P0N8ad0=P0K81X07B8L02@Y8`0V:bD04aXC02<Y9@0O
9B407bDU02`a=01CF5/0;C8e00dC4`0N928082HR01/R6`0M91l06b4O01hT8P0@61D08R/X01lX9@0N
:2D07BPT01hZ9P0P;2P08bl[02@`;00T;bh09Bl`02La<P0Z=CD0:SHf02/f>00Z=cT0:cTl02/j?@0/
>cl0;Ca1030oA00^?T@0;d170352B@0`@TL0<dE903E7B`0gBD`0=dU;03A6B00dATL0>D];03e?C`12
EE<0>di<03A7A@80<TE302H0>Ta<03A6B00jC4h0=DM903U;C`0kCE40@E=G03m@F00jBe<0BU]U05=T
KP1BHfd0?U1L04]MJ@1EIg<0DFAb045DHP1@Hg40DFMe051VM01>I780Cf9a04mRL01>HVd0BeeX04aO
IP19G6<0C5eT051RIP1?HFD0CV1S051RI01@HV80DF=S059TI01EIfL0EVQX05QZJP@0FF][00/0F6YZ
05m_KP1NKVd0G6a[05e]K01OKfh0HG5`06IfM@1`P7l0JWYi06inO@0206UiN00P06inN`1_Ogd0Kgmo
07>2Q@1jR8l0NHJ>086;U01nRI00OXV=07^5Q`1eOgl0N8:107j:R021SH/0R9BB08>=SP1lQXL0OXR9
08ZBU02<U9H0Ph^>08^@U027S900Q8b?08><S`2BW9h0SiVK08^DV@2?V9d0T9VN09BMY02HXJX209FN
Y`1<09JOZ02EWZL0VJ:Y09JOYP2DWJ@0U9^Q09NOXP2JXZD0VInP096GU`2?UI<0U9RG09ZOV`2MXJ00
WJ2T09fPY@2RYJX0Yj^^09jRX`2EVIT0Si>B08fAT02<THd0SI:>08nDT02CVY/0VJ2X09ZQY`2CVil0
RI6C08J>T025SXX0PXb407^5O01/MVX0J7=U06IaH@1QJe`0MGe`07b4N@1WL6H0H6YQ06=]I@1XLf`0
JWE_06]hL@1]NG@0J7A`06A`K01RKf/0HW5/069`L01QKg40HFmb065`M@1NKG80FVU^05EWJ01AHf<0
D6=O05=XH`1EIfT0G6ib05EWJ@1?HF<0EFMW04iNG012DTl0?Di804=BB`13DdT0?De30;W6_03Dg]H0
Lgee02df<@80:c@_00@0<c`i02Pa;P0U;R/0:34`0P0j@d802@0/=3D0;CHa02Tc:`0[=2l0<3Td02lh
<`0a>SL0:S<`02df<`0202`e=00k03<k?00c>cd0:C8a02H_;P0W<2l0:S<b02H_;`0M9BL092`_02L_
<P0Q:B`082L]01XQ9`0Z<SD0:C<d024[:P0N:2L08b`[028[:P0J8b807B<S01`Q800V:RT09R/W02DZ
9@0_=2h0@T<m01dN6@0Y:RD09RPS01XM6@0P9B40>Clk01@K600@6AH0<S/h02Xd<00H8Ah051LD02la
;P1OHEh08bDR01dO700B51407AlL018D4@0=3``0=CLd01HH5@0D5Q<06a/I01LG5@0I6AL07QhL01XJ
600E5A<06ATG01XJ600I6AL00P0G5aD01@0H61H05A@B01TH5P0J6AL061LE00805QDC03/05aHD01/J
600L6aT06QTG01PG5@0G5Q@04Q4=01DD400C4Ph05QDA01DD400A40`040l;014@300C4Ph05A@@01HE
4@0F5A806aXH01@C4@0A40h02@P600T5100E410050h>018<300H41406A0A01P?400O6AP0<Rh[02PT
8@0>2PL06ADB01PD4@0D40d00`0001TE4P0F4Pl06ADB051<B@0L61D04Ph;01<?300H51404`l<00l;
20091@8061@A01<?300F4Pl06ADB05=?C00o>CT05a4A018<300H4Q804@/;014<2@0201@?2`08010;
1`0=20804Pd701lJ500N6AD05Q4=00`70`0@2`L201D@300E00d8100>2@D04Pd901<>2P0A30P03`X6
01471P0F30/050X901H>300@20H03`L500@0000I51401`<001HB3`0=2@L040`900/60P0E40`02`H2
00<04@`80P0;1P802P0E40`05Q4=00h91@0@2`L020<001PC400400003`X701@?30091046010;2006
01471P0B20L04`T801<9200B20L04@L60P0C2@P201881`804@L6100B20L201061@804`T80P0B20L0
4`0A1`H040P601H?300J5A8061<@014<2@0A2`/050h>00l92@0A2`d040X<00/51`0400003PP:0105
2@0?10P04@H:01@93@0C20`00P0A1PX201052@0K01462P0B1`/04PL;01@8300E2Ph04`P<01462P0B
2@`03@H8018<3P0:1PL03@X;00H41@0H5QL0FEEE03H`<00D3Ph081TI01<:2`0800004PP901@:2`0?
1@H05@X<01041P0U6A/03P<3008040H500<04@L601881`0B20L00P0B20L01P0@1PD04@L601D;2P0B
20L03P@301471P804PP700h04`T801@:2@0@1PD02`4001L=300F30/04@L600X10@0H3P`04PT400d4
000800001`0000l510804@L6100A1`P0500>10<04@L601D;2P0C2@P04@L601<9200?1@@040H50147
1P0B20L04`T801@:2@0@1PD02P0001X@3`07000040H500`20@0A1`H04`T80P0D2PT0100C2@P04@L6
00h40`0@1PD201881`0401061@0>10<04PP701471P8040H500<04@L601881oooool04oooool001_o
oooo00P0MWAm02<Q:@0E4aT05Q<I018>5@0D3a@04@X@014:3`804PT>00l050/@01D<4@0A31803``A
00d;3`0;20/03``?00d;3P0<2@X0518C00X82@1=BdX04@h=00`:200?2`X00P0C3`h00`0@30/03`/:
010<2`06010<2`0701<=3@0D3Ph050h>01D?3`0C3@d04P`<010:2P02018<300D01<=3@0@2PX03`T9
014<2`0@2`/06A@D014=300c;Rh05Q8A02@P7`1<B4L04`l>00l;2P0L61L0510?01LC4P0D40l04`l>
00d9200>2PT2014=300@00d9200A3@`03PX900P40`0C3`h04Ph=014=300C3`h03PX900l;2P0C3`h0
40`;018>3@0C3`h04Ph=010<2`@04@d<010040`;00l;2P0A3@`040`;00l;2P0D40l04Ph=014=300@
30/05a<A018>3@0:1PD06QHD01@@3`0E4A004@d;0P0A3@`02@0>2PP04@d<01HB4@0T81l03`/:01PD
4`0D40l09b<R01<?3P02018>3@0;01`H5`0S7ah05Q8A010<3@0C3a005A4B01@@4@0C3a004`l>014=
300B3Pd00`0D40d0=00D4@`04a0:01dJ500I6AH041@D010H6`0Z=SX0OXN<02P`<`0730/04Q<A010>
2@0C40/040`:01<?3P0E4A005Q8A01LB4@0F4A0050l?01<?3P0N6QT06aLF01HC4`0F51@04Q4?01@D
4P0A4@l05aLG00h>3P0H61P071`M01@D5@0E5AL03`hB03Dd>00=3@l04a<D01hN7P0F5QH0OGem030`
;`0D51805ADC01LH4`0H6A@06AXE01TJ500H6A@05aTF01`N6`0J71T301DG500301LI5P0K7AX06adJ
00806A/H00L06adJ01HJ500L8A/07B8L01PM5`0K81X04QLA00807b@N0P0H7AL08`0L8A/06b0J02he
;P0O9B00;C<_01XP7`0L8B<0HFIX03<h>P0H7Qh06AlM01lU8@0O9B008RPT03@j>@1EGU`06b@R02H_
;@0`>SP07bTW01l[:00P;2T08bl/02@`;@0U<Bh09C0_02H`<@0X<S<0:cHg02`g>00/=cT0:SLj02/i
?00]?3l0;Ca00080;3]00340;3a102m1AP0b@dX0;d5603A6BP0fB4`0<dE803=5A`0fB4X0>4Y;03M9
B@0kCDd0@eIE03U<B`0gBDP0?E1>03]>C00jC4/0@59C03a>C`0iBdd0@E=G03U;C`13EEX0BeaT03a=
EP13Del0@eAO041@G014EV80BeeZ04QJI`1XNhT0Sj:`06j1S`1:Gfd0CF9`04mTLP1@Hg80Bei[04QK
IP19FfD0Cf9Y04]NI@1CI6/0G6ic05a^LP1PLWH0DVAV0080DfEU00<0E6IV05MYJ@1IJf/00`1IJf/0
1@1JK6`0G6i^05iaL01OKfh0HG5`0080Hg=b05L0HW9a061`K`1TM7<0KGem06AdM01YNGT0KGel0720
O`1cPh<0KWen07J5Q`1lRXl0OX^B08B?V021Ri@0OHN>07^5R01gPH80Mh5o07n:QP22SH/0PHb<08>>
SP21Rh`0P8Z<08F?T@26SY40R92C08ZAUP2:Si@0Ri2F09fUZ@2f_/80Q8fB08F>T`2?V9d0S9FL096J
X@2CW:<0VJ:[09FNY`2GX:T0V:6Z09FNY`2FWjH0V:2X09JOY@2FWj<0UYjQ09FMX02:Ti<0Ri6@08^A
SP2BUi@0VYnK09bQWP2JWj80UIZN09VNX@2OY:L0V9jN096GUP2=Ti40Ri6>08fCS`2AV980SiF@08N>
S`29T9L0S9BH08R?T`1oQhT0OhN80829Q@1nR800Mh5h06QbIP1QK5h0GVUJ069/G`1YLVH0KWU_06Yd
J`1UKfL0KWUb06iiM01VLFd00P1VLVh0:`1SKf/0HFeZ05IUH@1NKFT0IWAd06IdM@1OKG00G6]`05a/
LP1GJFd0DfEV055TH`1@I640CF5N04]MG`1JK700EfU/04eMH01DI6H0CE]K04]IE`0mBdH0>DI003E3
>`0b@3L0AE5805=LEP0nAd40:C8^02lh=00^=c<0:c@a02</:P0X<Bl0;CHe03U2@@0g@3l0=Sho02/d
<00W<BX0;3Da034j=P0]=S800`0_>3H01@0Y<S409Bh^02`d=@0]=CL0:C8a00809c0_03H0:34`02Pa
<@0U;Bl0:C4c02L_<@0Q:B`092``01/S9`0R:Rd082XZ028/:`0P:RT07bLX02@/;@0]=C@09B/[02<X
9`0X;2/08bPT024V8@0f>CD08b<O01lP700U9B80824M028U8@0J7Q`05a`I01hU8P0W<2d05b0M01dV
8`0I8Qh06QhJ01lQ7P0U9b@06adJ01dO700S9B8071hK020R7`0Y:bP0[:j[055CD00Q8b006QXH01LG
5@0H61H06ATG01PH5P0G5aD06ATG01/K6@0J6QP201LG5@0C01TI5`0G5Q@06APF01PG5@0F5A<05aHD
01TH5P0F5A<05aHD01XI5`0L6aT05aHD01<B400D4`l05QDA01<B3P0E510051<?018A3@0501@C3`1R
01<B3P0E514040h<01<A3`0R81d03@T801`G5P0C3P`04`d=01PA4@0B2@T08QTJ069LFP16@Sl06ADB
01HB3`0E4@h0510=018>2`0B3P`05A4?00l;2@0K5a@0M71]02TV8P0>2`P030T7010=2`0?3@T04Ph;
00`81@0F4Pl03PT6018>2`0G4Pl0OWUf05mIF@0F41004P/<00d51P0E3`l04@`9018<200A30P04P`9
01<=200C3PP04`d801D?2`0O6QH06A<?00d60`0B3@T04@/7014:1`0@2`L040X6014:1`0A30P050d:
01D;2P0F30/04@L601L?3@0D30X07ADC05I?C@0F4@h03@T801D@3@0Q7AX03@T700d8100E3`/02PD1
01L@3@0?2@D050l;01@>2P0D3P/0<bhZ03@]:P0C3@T04Pd900l91P0B3@/050l<01/D4P0I4a405a8?
014:200A2`P040/8014:200A2`P04@X801471P0B20L201<9200401881`0A1`H04`T801<920804PP7
0P0A1`H00`0D2PT04PP701471P0201061@0301471P0E2`X05@/:008050X900L04`T80189200?20H0
4`d:01<>2`0A2`X04@X:00804@/;00`040T;018<3P0T7R005@d@00d5200A1`/040D901462P0C20`0
4@H:00l5200A1PX201062@0E01472P0B20`04`T<0104200?10L04@H:01472P0?1PT03`P:01D?4@0;
1`P0514B010>3`1HEEH0j>KV09>=S@0_9bP07A@E01L>3`0:0`<050X;00804PP900@04`P:01<72@0>
0`@04PL80P0@1PD01`0A1`H04PP701881`0@1PD04@L601881`0?1@@00P0A1`H200l5100@01471P0B
20L04PP701<9200E2`X0>2h]0516A@0@20L04`T901@;2P0?1@<04PP601891@0D2PP05`d;01471@80
4@P6100A1`P00`0?1@@040H501471P0201471P0?01881`0C2@P04PP700l5100>10<03`D401881`0D
2PT04@L602`R8@0>1@@05@/;01061P0?1@@04@L600804`T800@04@L600l5100A1`H04@L60P0?1@@2
01471P0601<9200A1`H040H501061@0A1`H04`T85?ooool001_ooooo01L0BdI=01`G7@0A3100510A
014;300P6aP03@P5018<300<1PP06A<G018<4@0@2A0040X>014<3`0C3a005@lA018=3`0=2@X05a4C
03<^<00P71d04@`=01H@4P02010:300;00l92`0;1@L03`T;01@>400C3@l03PP:018<3P0A2`d040X<
01@>400H4Q@00P0?2@/05P0@2P`04@/=014;3@0A2`d05@lA018<3P0C3@l050h@01<=3`0A2`d050/>
0189300C2Pd04``>0189300>20X04`d?02LS900>2P/05A4B00<0000B3@h2010:2P05014;2`0B30`0
4P`<014;2`0B30`00P0D3Ph0100A2`/040X:010:2`0A2`d301<=3`03014;3@0@2P`04P`>008050h@
01h04P`>010:300@2P`050h@00l92`0D3Q003@L9024K7@0l=SP04P`>00d72@0D3Q007QPJ03La<`0I
518040d800h:1P0B3P/05Q<>01DA3@0@30T04a0;01HC3`0E4@h04Pl:014=2P0E4A004Ph=010<2`0A
3@`201<?3P0<02HR8@060P403@T802DQ800^:RT04Ph=01H@400C3@d0618B00@0000?2@T06A<C0P0F
41009@0E3`l050h>01<=3@0B3@/040/801@?300B3P/04@d<01HD500A4A404a4B010>3P0@3`d05A4>
01LC400E40d040`;014<3@0B30`050l<01TA3`0J4Q005@d;01PC4@0E4A006ALH01DE600>3Q005A<D
01TH5P0A40h03`h<01@C4@0A40h05aHD01DC4`0I5aP00P0O7Ah04`0G5AH05aHD01/J600M71X06aXH
01LG5@0F5Q@0820N03do?00B51405ALD02T[:00I6aP0ATM500d=2`0D51806QXH014A3`0J6QP00P0M
7A/301`L6P0301XL6@0H6QL05QPE00806adJ00h06Q`I020R7`0F61D08bDR01lQ7P0K7AX07b4N02hc
;@2j_kP0=c`e02T^:00K81/07R<O01DJ5P80720O01808bLV01lS8P0N8R408BLW01PP8P0M9BL0<3Tj
02La<P0K9BH072LW02Da<@0H92@0938b01l];@0S<C409S<e02Pc=`0Y=3P202Tg>P0A02Xh>`0/>d00
<3m403A3B00fB4`0;d5502do@`0`@TH0<dE703E7B`0bA4H0<49403A6B00gBD/0<dE70394AP0eAdT0
0P0iBdd0;01KJVl0AEAI03Y9C@11DE40AUIE03M7AP11DE00=TI503]:C00jBDh0?4]B03m?EP1>GV/0
A5IT04IHIP17FFL0?U1N04IHIP1EIWH0AUMW07N8V03Nkol0T:6a04MHI`1=Gf/0C5iX04QJI017F680
B5US04iOI`1AHVX0DfA/05Y[L`1;G6@0BeaS05Y[LP1JJF`0FFQ[05YYK01LJfh0Ff]/05MWI`1MKFd0
GVi]0P1OKfh2065aL00V06=cLP1TM7@0Jg]k06EeM@1WMgP0Hg9e05a[KP1[NWd0IgIi07j=TP1TLgP0
NHR=06]hOP1lR8h0PhjD07j9S`1oRY00R96F07n8S@1nQhX0OhN906aeM01jPX00NH9o0829R026Si00
QHf?07n7R@22RX`0R92B08fEU`25SHl0QXj@08>;SP2j`/D0];bo0:je_01nQHd208fDW080TIRP06H0
TYVQ09>JXP2@Uil0UIbT09NNYP2AV:00UIbT09NLXP2AV9h0TYNL09>HW02DVI`0QXb;08B:QP2<Th`0
OhIn09>JTP2KXY/0U9RH08b@T`2IWIh0U9RI09>GV02OXj@0Rhn@08>7R02<T8l0Si>B08b@S`29T940
Q8b>0869R`1oR8L0O8F207V2O`1hPG/0Lgee071jL@1[MFX0IFmT06YdJ@1/N6d0IG9Y06IcJP1YMVh0
KGYc071lN01]NgL0IGAa06=bK`1SLW00HW5^05e[J`1LJVX0IGEd06QhN01LK6`0FFUY05i]L01OKW40
EfIY059RHP1HJ6P0FF][05MXI`1?HF<0BUaP04YKG@1CHF@0EUmT04aBE@11ATT0?D=303<g=`0/<2l0
;c@`03Tn>`0a>ST0<3Xi02li>00[=C@0:S@c02`f=@0X<S<0;SPi03Q2@`0i@d@0=T1103<m?P0^>3T0
;cTj02@^;`0_>CX09Bl`02La<P0[=CH0;cTj02hh>@0Y<cD09S0b01hV:00T;B`201dS8`0R01XP800W
;Bd0;cDe03i4A00/<C<082DX02<X:`0U:Rd08BLW01lU9@0W;B/08bTW028X9P0U:RT08BDT02DY:00T
:2L07b<R01/O7P0N8R409bTX01PF6`0L6Ql081lT024P9@0O82<06alP028V9`0P9R@06R0L01LM6@0C
71L06R<N01PM6@806QlK01805Q/G01dR7P0H7AT05Q/G01hS7`14BDD0>Chj02hc;`0A4a006a/K01@D
500E5AD061PH01hN7P0O7al04Q8B01TI6@0K6a/201@D500?01/K6`0L6aT071/I01@C4@0A40h05QDC
01LF500F5A<05A@B01<B400@3`d05A@B00/:200C3`h0510?00<05Q8A01@03@T803<_;P0B3Pd0510?
01PD4`0U8B004`l<01@A300G4Pl061@@01TD400H4a005A0=01D@300F4@h061<@01LB3P0F4@h07APE
01/E5@804P`<05005Q0@01@>3P0B30`040X:018<300G4A404`d=010:2P0D4Q000P@101`N7@0<3@`0
410>01HD4P0B3Pd05Q0@01PB3`0D30X04PX801L=2`0G3@`04`/901@;2P0F30/04PX801D<2`0B20L0
4`/901071P0@1PD05@d:01D<2P0F30/04PX801H=2`0F30/03`L50189200F30/05@d;01<:2@0C2@P0
4PX801<9200I3`h05P`;01@:2@0C2@P04@L601H<2`0]8b804@T701D=2`0K4a404`/901L?3@0E3@/0
4PT8024I5`0?1@@04PT700X2000D2PT03PD301D=2`0C2@P04`X900`40P0900005`h<01<;2@0I3`h0
5Pd<01L?3@0?1@@05Pd;018:200G3@`04@P601D;2PL04PP700X03@@401T?3P0@1PD06@l>00`20@0?
1@H0710B01T=3`0?1@H06`lA0P0C1`T0;P0I3@l08QHH01`@4P0@10H03`D600l71`0G3@h04PT:0108
2@0Q5QX03`H901H<400A1PX04@P;01H<3`0@1@T02@0300h51P0E30d06A0A01892P0E30l03`T;01<;
3P0?2@d030H:01H@500300803@L:01/B5@0A20/04`X=014;3@0?2@/03PP:010:300=1`T05@lA00h:
2`0f<380WYNI06AKGP0I3Q805P/?01P=4@0?10P201462P0@01872`0C20`04@H:01052@0B1`P03002
01T=3`0C1`T03@4301T=3`0C1`T06`lA00P0000@1@H05PX<0186208040@601h05@T;01@8200B1PH0
4PL500T0000A1P@05@T90104100?0`<04PH801X<300C0`@04@@401<9200A1`H04``9014<200D3`/0
40/800h8200B30`030D601@:2@0A1`H02@4000/1000G3@`081HE01D;2P0D2PT201881`0>01D;2P0D
2PT05`/=01<72@0A1@L04`L90186200=0@<03P840186200C1`T04@D701041P0A1@L<018621Cooooo
000Kooooo`0=020I8@0C318081XL02DO8@0D3Pd03@P401XE4@0D3`d0618B01PB5P0910P04@XA01<=
4@03018<3P0=01<=3`0A2`d02`D701hH6P0F41804P`>01H@4P0@2P`05@lA01@>400?2@/04@/=01@>
4002018<3P8040X<0P0B30h0100A2`d03`T;00l92`0@2P`3014;3@0:01@>400B30h04P`>01<=3`0B
30h040X<01@93@0E2Ph050T=01<:3@8050/>00`0618D014=3P0810D040`=01/G600D3`l040X:00h8
200L5QH05Q0@014;2`0C3@d2010:2P804@/;00H04P`<014;300A2`d04P`>01<=3`0B30h2014;3@04
018<3P0C3@l04`d?01<=3`8050h@02/05Q0B00h82P0A2`d02P@601<=3`0X8R@03PP:00/51`0D3Q00
6aDG02lY:`0B3@/03``7014>2@0?30L030T400T60@0@3@P04a0;01HC3P0E4Pd0514<01DA3@0C3`h0
4@d<018>3@0C3`h0510?018>3@1EDE00;BTX01HB4@0D40l071PG010<2`0?2@T050h>014;2`0@2PX0
30H6018<300E3`l050h>00804`d=00T050h>01D?3`0D3``05a8?01@?300@2`P05A0=018=2P0F4@h0
0P0C3P/04`0E40d05a8?01D@3@0D40l050l?01<=3@0E3@/05`h<01P>300O5aD05a8@00T81P0B41<0
3@hA01DF6P0?3@h05aHD01<B400@3`d00P0D4a405`0B4@l04A0>01@C4@0H5aD06APF01DD4P0G4a80
6ALE01TH5P0G5Q@05A@B01@D4P1:BTP0OX1m02/]:P0=3``05a`H00H;1`0L71X04A4?02HV900Z:RP0
61PF00806ATG00L06QXH01/K6@0M7A/07AdK01hN700I6aP05aTF00806adJ00h06Q`I01lQ7P0L7Q/0
7b4N01/M6P0L7Q/06adJ02DW8P1PIEh05a`E020U7P0K81X07b@N01XO6@80724M01808BHS01dQ800M
8B008BHX01XR9@0M9BP0;3Dh02La<`0P:R`07BLY028];`0M:b`082h_01HT9@0S<C80934d02Td>P0W
=3X202Pe>`0:02Lf>`0Y>3d0:CPm02Xl@00_@DD0;3i202i0A00cADP0<TA60353A@<0<TA600<0>D]=
03e?D@0kCDl00P0jC4h0;00iBdh0>dYA03i=E00mC540?4]>03e=C@13De80A5AC03i>C@15EEH0AEAK
04ABF`14Ded0AEET04AEI@16EfL0B5UY04]LK019FVX0C5e]05=TM01AHW80M8FE05a]O@1:FfX0C5eW
04aMI@19FV80A5EM04MHH01@HFT0BU]S04]LI01>GfL0EVM_05QYL@1EIVh0G6]`05a[KP1JJF`0F6MZ
05MWJ01GIfL0GFe]0P1NKVd05P1OKfh0HG5_065aL01RLW80Gfm_065aL@1NKG00I7=f06IeN01^OH80
JWUn08JEVP35e=/0VZV`06QgOP1^N840NhF>08B>U`25SYD0QHjD08J?U01mQHP207b4QP0L07EkN`2A
UiH0WjFS08^CU@28T980P8R:07^3Q@1oQhT0Q8b>0828RP24S8h0S9BF08::S02JXZ@0RY:E08J=U02A
V:00QXfE08N>UP2CVZ80QXfE096HX02?UYh0SIBL09JMY@2HWjL0TYVQ09RLY@80VIjT04H0UibP092E
V02;TI40R8j=08B:QP1oQWl0PXV108ZAR@20Qgl0T9BD09:FU`2?Ti@0T9BE096EUP2:SXl0OX:30824
Q@2?Ti@0TIFF08b@T@28SXh0Q8f<08:;RP21RXP0P8V607j7PP1hPW/0L7Yb06ihK`1ZM6X0I6iS06Qb
I`1ZMfd0IGA]06AcK01VMFl0IgIa06UhL`1WMW80IGAa06YhN01^O7`0JGMg065_K`1MK6`0HG5a05m_
K`1HJ6P0FFUY05YZJP1IJFT0F6QX05MWI`1FIVH0EFEU059RHP1@HVH0BeeQ04aJG@1BGF40DEQN04A8
C015ATX0?d1403Lg>@0b=3<0=CLf03`o?P0T;2h09Bl`0P0Y<c@0>@0[=CH0;SPi02Pb<`0[=CH0=3ho
03Y4A@0h@T<0;SPi02dg>@0c?Cl0:C<e02hh>P0kADL0<C/m02li>`0b?3h0;cTk02Tc=@0U;c407BLX
02T_;`0T:RX0:S0`02le=@0T:RX07R@T02D[:`0R:2P07bDU020V9P0U:b/09bd]01lS8P0V:RT08bLV
028V9@0T:2L08BDT02P/:`0U:BP07b<R01`P7`0O8b809BHX02DR:@0U8BT08b0W024P9P0Q8BD0824U
02<W:0093Ph0:c4]01LM6@0P9b<06R0L01PM6@0202<X900O01HK5`0H7AT05Q/G020U8@0M8Qh0Ada8
02@Y9@0G71P07b4N01TI6@0K6a/07AdM03lo?`0c<c<04a<C01XJ6P0D51@05QHF01LG5`0I6AT07AdM
01PG5@0=30X04A0>02@S8@0N7A/03Pd;01PG5@0M71X05aHD00l>300201TH5P0=01@@3`0E4A005a<B
01LC4P0F4Q40=C4`08=oOP0^:RT03PX900X61@0810<071LE01LB3P0201PC3`0501LB3P0F4@d04`h:
018=2@0C3PX00`0D3`/0700<1`H07ALG03D_;`0V8200208200d71`0G4A4050h>01H@400E3`l04P`<
01XD500O7Qd061`K00L;2P0F6AP00`<3010?3P0S7Ad05@l?01D=2`0J40l04`T801P=2`0G3@`05@/:
01P>3@0J40l201H<2`0?01471P0E2`X050X901881`0D2PT03`D401D;2P0C2@P05@/:01P>3@0F30/0
7Q@C01H<2`0E2`X050X900804`T801L050X901<9200B20L05`d<01P>3@0A1`H03P@301dC4P0A1`H0
5P`;01P>3@0C2@P05P`;00l5100C2@P060h=00l5100K4A005P`;01@:2@0B20L05`d<01061@0201D;
2P0<01@:2@0K4A0040H501881`0>10<040H501881`0@1PD02P0001881`0A1`H04`T81P0B20L04P0I
3`h03`D401D;2P0B20L07Q@C01H<2`0B1`P050P:01<72@0=0@<06Ph@01@82P0B1PP05@T;01/?4@0H
30h04PH801@82P8040D902X05P/?01482P0@1@T03`@801052@0>0`L03`@801@93@0G310060h?01H=
3@0;0P<01`0001@;300D3Q0030H801<=3`0300802@@800H21@0I5a`04@/?00H00P0B30h04`d?00h8
2P0<1PP03PT:00l92`0G4A<0618D00T31@0B30h0=bha02LL800B1`/04`P<01462P0<0@D03`@80105
2@0A1PX201872`0@01462P0D2@`04`L900P0000E2@/05`/=00P0000A1@L02@0001/?4@0L41802000
01dA4`0B1PT04@D901<72@805`/;0P0B1`D05`0E2PP05@T90104100@10@050L901T9300I2@X060/;
01@:2@0@20H040/701DB3@1?C4L0?3Pe00<0000@2PX040X;00P0000L4Q406Q0?01`B4@0900003`L6
00<04PP700D04`T801@:2@0A1`H05PX<01@82P0201<72@080186200?0`D04PH801<72@0B1PP040@6
01451`0D20X60186200601<72@0B1PP04@D701451`0B1PP04`L95?ooool001_ooooo00h04@XA010:
3`0B30h05@lA01D?3P0B3@X04@`9010;2@0=1`L06Q@H03H`=@0G4AH04`dA01<=3`8040X<00l04P`>
01D?4@0<1PP03PP:010:300D3Q004`d?014;3@0G4A<05@lA010:300A2`d04P`>00l92`0E3a400P0@
2P`00`0B30h040X<00d72@06014;3@0O01<=3`0@2P`040X<018<3P0@2P`03`T;01D:3P0G31005@X>
0189300G3Q4071<F01D?4@0?2``040`=01PD5@1mNGX0B4=300l92@0=1`L07aTI01D?3`0=1`L06Q@D
01/E5@0C3@d04@/;01<=3@0B30`04@/<018<3P0301<=3`04018<3P0C3@l04`d?018<3P<04@/=0180
4P`>01H@4P0A2`d040X<014;3@0>20X05Q0B01<=3`0?2@/04`d?010:300M5aT02PD4010<2@0C3``0
510=01TE4P0U8Ah201@@3@0401<?300@30T040`901<?30804Ph=00L04`l>01DA400D40l040`;01PD
4`0<20L03`/:0080510?00T040`;018<300L5QH04P`<01dG5`0?2@T04`d=01D?3`0D3Ph00P0B30`0
1P0D3Ph0618B01<>2`0D3``04Pd:014<2@805A0=01@05Q4>01@?300C3P/05A0=01HA3P0E40d05a<B
01LB4@0E3`h05@d;01H=2P0F30X050`901LB400A40h06QPK01XJ7P0J6al0518C01HE4`804a8@0P0G
5Q@02`0C4Q005A@B01DD4P0E51805aHD01TH5P0I5A@06ALE01LF500E518051@B00805QHD00/06adJ
00d?300L7Q/03Q<?01TN6P0I6AL06a/I01`L6P0J6QP06ATG01dM6`0201/K6@@06QXH00D071hK01XL
6@0K7AX06adJ01XL6@0201`N6`0R01LI5P0F61D07b4N01XL6@0N81`07b@N01LL5@0S:2406b0J01XO
6@0N8ad07B8N01dQ800O8b807R8Q01dQ800N8bD06R8U01`T9`0S;2h07bT[024[;@0T;S007BPZ01d[
;00Y=cP0=TA504ABD`0U<SH0:3<i02Hc>@0W=3X0:3Dk02Lf>`80:STn00`0:C/o02`n@P0[?D40;T14
03A6B@0a@dD0<49403A6B00fB4X0<dE703I8BP0kCDl203U;C@0@03Y<CP0iBdh0?DaB04iMI013DUL0
AeII03m>D00oCe00?4]=03m>DP16EE`0BEMR049@G00oCUd0?dmN04MII`80AUQV00T0Cf5_04QJJ015
EfD0Cf5_04]MJ`16F6H0BE]Y04YLJ@1:FfD00`19FV802@1<GFD0DV=[059SJ`1GJ700CUmW06enQP1/
OHD0DfA/05IUJ`0205a[L00305UXJ`1JJF`0Gfm_0080GFe]02l0GVi]05m_KP1PL6l0HG5`05i^KP1O
Kfl0H71`06AcMP1UM7L0IgIi05m^L`1/Nh00RiZO0;O6c@2DXjX0LH2707R2R`1jQ8d0OXRA08:;TP23
S980PX^@07n7RP1iPH@0MGeo07IlO02;TI00TINE07b4QP1mQHL0NH6307j6R02=UIL0UYjP08fEU`25
SHl0R92B08::S02:TY@0Ph^>092GWP2=U9`0PXVA08ZAV@28SiL0S9>K08jEW@02092GW`0H096HX02B
VJ40T9NO092DW@2>TiT0TIJL09>HW02AUYT0TINH08fCTP25RhP0QXb708>:P`29T8P0Z[6Z09ZNWP29
SHh0SI6B08nCU02:SXl0Q8R907f1PP21QHH0RHf>0P2:SXl05P2:T900Qi2?08B=S022RhT0OXN407Z3
OP1cO7H0JgE]06YdK01ZM6/0IFmV06E_I@1YMF`0IgI_06IeL01UM6l0I7=^06AcL01UM740J7Md06Ug
M`1VM7@2065_K`0L069aL@1NKVh0EfMW05IVIP1LK6`0FFUY05EUI@1IJFT0FVYZ05ATI01?Gel0Be]K
04eOHP1=GV80D5iQ059LH01<DeT0?T9703Hg>`0`<CD0:R/]02`^;@0`<S40;S<b02L_<@0Y<c@0;3Hg
02Xd=@80:38c00<0;cTj02hh>@0d?Sl00P0mAdP03@0a>c`0:cDf028/;@0`>S/09S0a038l?@0e?d00
;cTj034k?00]=cP0:C<d02/e=P0W<3400P0V;2`01@0P9RH0;C<c02hd=01HGUh082HV0080:2h^00H0
8bTY028X:00W;Bd092PW02L[:P0R9RD201lS8P0F01hR8@0Y;B`08bLV01lS8P0P92<08RHU02@U9P0X
9b/09B<X020N8P0O7R<08R8V02DV:00J7Ql0JVi^02T];02?UI@09R`Z01/Q7P0O8Ah061XG01TK6080
7R0M01407b4N024S800M7a`07b4N01LI5P0O8Ah04Q@A01PH600F5QH05ADE03dm?@12@T80ATI6030`
<00I6AT05QHF01PH600201@D5006020O7@0g=S@0;Rd[01HE4`0C4Q006APF0P0E51801P0D4a407QdK
02HU8`0V9B<05Q8A01LC4P8061@C00P05a<B01@@3`0R7Qd04`l>01PD4`0@30/06QHE01@@3P<061<@
00@05Q4>01D@3@0F4@h05Q4>0P0E40d00`0G4Pl061<@01TC4P0201/E5@0N01D?3`0@2PX04`d=01D?
3`0D3Ph05a4A018<300?2@T07QPH05eLF`2e^KP0>S`k00d>3@0`<3004a4@03D_;`0K5AD04`/901/A
400B20L04`P601D;2P0C2@P060h=01X@3`0E2`X050X900h40`0C2@P060h=0P0I3`h201H<2`0801D;
2P0F30/05P`;01H<2`0M4a805P`;01D;2P0D2PT201<9200801D;2P0?1@@05`d<02@J6@0M4a804@L6
01061@0<0P4301<9200J01D;2P0A1`H04`T801L=300?1@@04PP701H<2`0G3@`04PP701<9200F30/0
40H501X@3`0L4Q407A<B01lE500@1PD04PP701471P0E2`X0@CLf02XP7`0=10<040H501@:2@0K4A06
01881`0f01471P0?1@@050X901<9200G3@`050X901D92`0B1PP06@d?0187200E2@/040@60186200A
1@L04PH801<72@0D20X05`/=01872`0D2@d03@@601@:3@0D2@d05@X>01`A5@0F2`l04@H:00`11@0?
10P04PP901<92@0A1`P060h?0107200b:bd0Qh6303La<`0@2`l061<G00l:3P0D3aD040X>00`7200<
1PP0618D02LQ8`0@2P`03PP:00l92`0C3@l02`H7018<3P0I4aD03PH80P0G3100100;0@@040D901H;
3`0B1`/201052@0@01462P0B1`/050T=01<72P0>0P@05@T;01051`0>0`@060`>01L;3@0:00405`/=
00h41@0V6Q`04`T:01L<3P804PH800H060`<01T=3@0C1`L050T70146100@1@<20146100L01@81`0D
1`L05`X901461@0:0@003PH3010;1`0?2`T04@d<01D@3@0A2PX03P@50107200B20L05@/:01071`0Q
5aH05`h=01@;2P0@1PD03`D401471P0D2PT04PP700l5100C1`T05@T;01H:30804PH800L04`L90186
200B1PP040@600h2100@10H050P:00H04PH800H050P:0186200@10H040@60186200D20XDooooo`00
6oooool04@0@2A005PlE018<3P0@2P`04Pd;00`7100A30T061<A00T30`0C3A40?CHl00d72`0?2@d0
4P`>01<=3`0A2`d04P`>00805@lA00D050h@01LA4`0B30h03`T;01D?4@02018<3P0;00l92`0A2`d0
4P`>010:300A2`d04`d?014;3@0?2@/04@/=01<=3`0B30h01P0A2`d200l92`0?010:300?2@/03@L9
01D:3P0H3A405@X>01482`0H3a807QDH014;3@0?2``01`<400d92P0c;c0040/<008050h>0`0?2@T0
1`0J51@07aTI01D?3`0B30`050h>018<300B30d01@0D3Q000`0B30h040X<018<3P0201H@4P0:018<
3P0@2P`050h@01LA4`0B30h05Q0B01TC5@0A2`d04`d?00d72@804`d?00l08A/M01PC4P0D40d03@T6
010<2@0G4a007QXG01@@3@0C3``04@d:00l;200@30T05Q8?01HB4@0C3`h00P0A3@`2018>3@0H01DA
400G4a805a<B01<?3P0=2@P04`l>014;2`0>20P04P`<00X4100F41007QPH01TC4`0F41004P`<010:
2P0B30`05@l?014<2@0@2`P04Pd:01@?300E40d05a8?0P0D3``201<>2`0F01@?300E40d05A4@01DA
3`0D3``05Ph;01P?2`0I40/05`l<01<>300:2@L071XM07enP@2HVI/0:bTZ01PG5@0@3`d05A@B01LF
500C4Q0040l=018A3`804A0>01P04a8@01HE4`0J5QD06QLF01LF500E51805ADC01LG5@0E5A<05ALD
01PJ5`0Q8b006b0L01TN6P0F5Q@07AdK01PH5P0I6AL06a/I01LG5@0L71X06a/I01XJ600I6AL201PH
5P8071hK03@06Q`I01/M6P0L7Q/06adJ01XL6@0I6aP05aTF01dO700J71T0828O01XO6@0Q9R007R<M
01`Q6`0M8Qh09BXV020U8@0P92<07b<R024U900Q9BH07R<U01/R:00O9R`07RH/01TR9`0L9BX09S0d
01lZ;P0M:bh0;ce004ABE@1?GF00930e02D`=P0T<CL09c@j02Xg?@0Z>Ch0;3]002dl@@0^@4@0<TA8
02i0A00_@DD0<D=70394B00fB4`0=dU=03I8C00gBDd0>D]?0P0gBDd0;P0kCE40?e5E041BEP0lBe00
BEQM03Y9CP1=G640AeIK03a;D010CeH0AeEN04ECG`1=FV/0AeAU04ECI`17EfL0AeUW04YLJP18FVP0
AeUW04iPKP1<GV`0?U1N04EGI@14EV@0AUQV04YLJ@1:FfD0AUMO04UJHP1FIfl0FFYb051QJ@1>GfL0
GFif051QJ@1RLg/0FV]c051QJ01AH6L0G6]`069aMP1PKg@0GVe`065`L`1LK6`205e]K@0905i^K@1P
L6l0H71_06inOP1/O7`0HW9b06YiO01TLgH0IWEh0080J7Ml0140IGAi07B3RP1`OhH0MHB;07AnQ`1h
PX/0O8J?08><T`2FWjD0Z;6f08^CUP1mQHP0KgMi07UoO`1kPH00KWAb07=kO@020828RP0F07Z2Q025
SHl0TIVK08ZBU024S8h0PXZ<0828RP1lQ8H0QhnB0:bc^@39d=H0W:>Y09:IW`2@Uid0R8nE09FLXP2S
Z[00XJR^096HWP2>UI/0U9^Q09JKX@80UIZP0140SI:F08bAU02BUiX0Ri6@08>9Q`2:T8`0QH^608jE
SP35blL0VinO07j2P`2<T940TIFF08F9RP27Rh`0R8b=08Z>S`0208R<S@0>08V=SP2;TI40R96@08F>
R`21RXL0NX>007AmN01^Mg80JG=[06QbJP1[MFd0Ig5Y06I`J01XM6`306IeL00<06EdK`1TLg00I79a
06=aL@1PKVh0GVa]06IdM@1bP840K7]k05e]K@1KJf/0EVIV0P1IJFT00`1GIfL0EFEU055QH@0205=S
H`0@04aLG018EeX0BUUL04mLG`1;EEL0@TY=03Hj?P0a<SH0;2da02PY:`0];S00;S8c02/`<00S:bd0
9bla02hf>080<3Pj00D0<SXl02/c=@0]=CL0<3Pj034i>`02030h>P0C02/c=@0^=SP0:C4c04Q@DP2^
][P0MWj002de=`0^=SP0:c<e02P`<P0]=CL0;3@f01HL700S:BT08RPX02le=@0R:2P0A4Y:020V9P02
024W9`06028X:00U:b/0:2h^02DY:00S9bH082@S0P0M8B008@0Q9B@092PW01lS8P0N8R408RHU02DY
:00V:2L08B4Q024Q8P0O7al07alQ020Q8`0Q8R@09BHX05aOH00k?d00:Rha02`a<`0T:RX07AlM01/M
6P0G6AH051HC00`>2`0K7AX06Q`I014C400L7Q/06Q`I01LI5P0I6aP051@D01DE5@0201lO7`0E01HF
5P0K6a/06QXJ010@400A4A404a<C01@D500G5aL04a8@024P7P0L6aT04Q4?014@3P0B4@l06aXH01@C
4@061@<03@`:01PG5@0X9bD05a<B008061@C0P0G4a801`0F4Q40:2@S014=300G4a806ADD01XF5@0S
7Q`00P0E40d201HA3P0301LB3`0F4@h04`h;00804Pd:00L04`h;01D@3@0E3`h05Q0@01TC4`0H4Q80
50h>00<04`d=01H05@l?01H@400@2PX04`d=02@R8P1BE5<051@D00X92P0>30d06aLF01@>3P0C3@d0
40P601H<2`0M4a807A8@01L=300C2@P04PP701<9200A1`H05@/:0P0G3@`0300E2`X040H500d30P0@
1PD04`T801H<2`0H3Pd050X901<9200B20L05@/:01@:2@804`T802H050X901D;2P0;0@004@L601@:
2@080000308103<Y:00D2PT05`d<00h40`0A1`H06@l>00h40`0H3Pd040H501D;2P0M4a804`T801X@
3`0G3@`04`T801881`0?1@@05@/:00L0000>10<050X900/1000B20L04`T801@:2@0E2`X07A<B01X@
3`0L4Q403`D500`20@H04PP700h0308101D;2P0E2`X04PP701061@0E2`X04PH801451`0I3@l04PH8
00d10`0C1`T05@T;01@82P<04`L900D04PH801<:300K41@02P0301@93@0201052@0N01H;3`0A1PX0
4PL;01L<400F2`l04`T:01@:2P0?1@H06Q0A00l61`1EC4l0gMCG04m9B`0G4AD04@/?00P41`0Q7280
4@/?01`C5P0<0`H06A0C01H=400O5QT050/>00T00`0C2Pd050/>01072P0E30l03@<70P0?10P0100D
2@d05@X>01052@0>0`L200l4200B01052@0B1`/050T=01H;3P0M4A<04@D701T=3`0B1PP020000146
1`0N4Q@060`>01/?4@3IcLl0>2`^00d3100B1PP04`L90P0B1PP03@0B1PH05P/90146100E2PP06@h:
01D:1P0D2@D05@X801<:1@0?1P4040P5018=2@0>2@D00P0@2`P04`0B20T050P:01D92`0C10L04`L7
01471P0g;B`0Q7Yi0<[0_`0Z81l04`T800h40`0?1@@04`T800l5100@1PD04@D701@82P0F2P`00P0A
1@L01`0E2@/03P8401<72@0E2@/050P:01451`0@10H01P0A1@L01P0C1`T04PH801451`0A1@L04PH8
01<72ACooooo000Kooooo`0?0109400B31003`T;00l92`0A2`/03PT600/60`0>20L03PP:00T31@0?
20h02`D900d72@0C3@l050h@00804P`>01<05@lA014;3@0E3a405Q0B010:300A2`d05a4C010:300B
30h040X<01<=3`0E3a404`d?00l92`0C3@l04P`>00h82P0B30h05Q0B00<04P`>0`0A2`d05P0B30h0
3`T;00l92`0A2`d03`T;00h82P0D2@d05P/?01D:3P0B2@`05Pd@01XA500=20T061@E00d92P0C3a00
71PI00`71`0H4Q806Q@D00`61P0@2PX201@>3P0301D?3`0@2PX040X:00804`d=00<050h?01@>400C
3@l00P0C3@l03`0D3Q004@/=00h82P0B30h06aDG01hH6P0I4aD050h@014;3@0G4A<04P`>014;3@0H
4Q@050h@01hH6P0201<=3`0300l92`0K5AL050l?00803PX70P0C3``00`0<20D04@d:018>2`0201<?
300401HB3`0M6AH061@C01@@3`8040`;01d04@d<018>3@091@@04@d<00h:2@0@30/02`L601HB4@0I
4a<04P`<01dG5`0@2PX09b4Q034[:`0H4Q805a4A01<=3@0A2`/04P`<01@>3P0D3``04`h;01HA3P0G
4Pl04Pd:01<>2`0D3``05A0=01@?3002018=2P0D01D@3@0D40l0510>01@?300G3``06A4=01/B3@0G
3``050l<01DD4P0Z:2T0YZJY0<c=c`0_;Bh06APF014@3P0F5A<05aHD018A3`0C4Q0201@C4@0K01DD
4P0F5A<05QDC01LC4P0H5Q@05aHD01DD4P0C4a4051@B01LG5@0B5140:R`Y01HH5@0K81`03a4>01PH
5P0I6AL05QHD01`L6P0N7Q`06ATG01PH5P0I6AL06QXH01`L6P0M7A/07QhL008071hK00@06A/H01`N
6`0N81d071hK0P0O8Ah0800K7AX071hK01PJ5`0P8Ql05Q/E02<X8P0I7QP082DO01dR7P0Q9R8082DQ
020T8`0O8b808bLV02@X:@0P9BT07bH/024X;P0P:2h07BH[01hW;00R;3009C0d02Dc=P0W=CP09C<f
03=1A00Q;S809S4g02Db>00X=C/0:cPn0P0[>Sl03`0Z>Ch0;3i20394B00_@DD0<D=70394B00dATX0
>4Y>03M9C@0eAd/0>D]?03]=D@0gBDd0=TQ<03Q:CP0203]=D@0?03U8C@18Ee`0@e9G04QGG012DEH0
@e9I03a:D`14DUd0>dQI04]HJ`15DFL0@e1W04aLK019FfT0C5i/0080CV1^01d0EfUg04IHIP18FVP0
B5YX03]=F`13EF<0BE]X04YKI@16Eel0BEYR05QYL@1KK7@0Cf1X04QIH@1GJ700DF9Z05AUK@1?H6P0
E6E]05MVK@1OKW<0Hg9g061_M01MK700G6]^05][J`1LK6`0GFe]05i^K@0205m_KP1D08FEU@1kRh/0
Hg=c06imP01WMWT0Kgj106QgO01_OX<0K7^006mnQ@1]O8<0MhB<07J0R@1jQ8d0O8J?0829T02@VIl0
XZ^`0:2XZ`2?UiX0MGeo07f3P`1gOG`0KG=a06mgN@20R8X0Q8b>07^3Q@21RH/0RY:D08F=S`20R8X0
NX:408F=S`2DW9h0^l?50:2W[@2RZJl0RY6G08>:T024Ri40PhZ@08nFW02MY:X0W:>Y08ZAU`29T9H0
U9^Q08fBV02@UI/0UIZP08nDV029SY40SiBG08N=S@1oQHD0OH>108N=RP2<TXh0U9ZF08Z>SP24R8T0
QXZ;08jBT`26RX/0Oh>408Z>S`2?Ti@0T9BE08jBT`2:SXl0QXf=08F>S@23S8T0PHZ707^4P@1eOWT0
KgQc06QaK01WL6/0JgE]06UcJ`1XLVX0J7=^0P1UM6l0101VMG00IGA_06EdL@1SLW02069`L00N065_
L01SLG80IgEf061_L01KJf/0GFe]05EUI@1BHV80DF5Q059RHP1?Gel0C5aL059RHP1CHf<0C5aL04iM
H01AH6<0E65T04]EE`0oAdX0=3Ll02l`=00/;C40:BX/02X^;`0/<340:c0`02L_<@0Z<S@0;SHh0P0]
=CL0500^=SP0:c<e02hf>00a>C/0;cLi02hf>00a>C/0;cLi02/c=@0U;Bl0@4Q:09NOX@1TK6h0;SHh
02lg>@0Z<S@09Rh`02Ta<`0V;S00;C<c0P0[<C402P0m@d<0;cDe02`b<P0/<S809R`/028X:00T:RX0
9R`/02@Z:P0Q9BH301lS8P06028V9@0Z;Rd08BDT01lS8P0N8R4082@S0P0T:2L0400R92<08b<S02<S
8`0R8R807b0Q01dN800D5AL07b8T01LK7P0T:2/05QXN01/O8P0Q8b402`d:01HH5@0c=C8201TK6003
01hP7@0];b`07b4N00805QPE00L05aTF024Q8@0M7Ad06ATI014A4@0R8R805aLG00805ADE00@061PH
01HF5P0E5AD06QXJ0P0I61H02P0H5aD07A`J01`K6@0G5Q@04a8@00/:200E5180>CPf01XI5`0<2`T3
01LC4P0901HB4@0E4A005a<B01/G5P0N6QT061@C00l;2P0>2PT03`X8008050l<00@05A0=01HA3P0H
4a005Q4>0`0D3``0100E40d05Q4>014<2P0B30`201LA4@0F014;2`0@2PX050h>01@>3P0E3`l06Q@D
01@>3P0?2@T04Q0?01TI6@0:2PX061LG00<10P0B3Pd03@L701D?3`0D30X04@L601X@3`0G30X06Q0?
01D;2P8050X900<04`T801P>3@0F30/00P0D2PT201<9200401lE500@1PD05P`;01X@3`805`d<0`0D
2PT201<9200@01@:2@0F30/0718A01T?3P0@1PD03P@302LM701]Hf806a4@01P>3@0?1@@04PP701T?
3P0@1PD06@l>00d30P805@/:00d03`H600T0000C2@P04@L601H<2`0J40l09A/J01881`0>10<050X9
00d30P0E2`X04`T800804@L600D04PP700T0000>10<04@L601hD4`0601881`0>00h40`0A1`H02`40
01471P0>10<05P`;01<72@0;004040@60186200;004060`>01H:300G2`d201@82P0N01<72@0@10H0
40H900l4200F2`l060dA00T00P0I3Q804@H:00h31`0C20`0714E01P=4@0C2@X04@L701882@0E2``0
4PP901482`0d:bh06A<E00H0100C3A40:RDY0:nZ/01?Ad`05Pd@01D<3`0?1PT01P000P0A20/0300;
0PD040L:01D<3`0:0@@030<601062@0<0@D040D901H;3`0=0PH03`@801@93@8040D903404@H:0187
2`0C20`05``?00X0000f:R`0FTi@01L;3@0<00805`/=00T0000<00804@D7024E5`0G2`d06`lA01<7
2@0D20X040@600l31@0B1PH05@T901050`0E2PL05P/700h3000=0P004@P100h5000B2P@04`h800d8
10060@00100000h6100@1@H03`0301X:3@0I2@`05@T900`20@0M51<0OWAc0?kdl`0i;bh05@/:00h4
0`0B20L05P`;00804@L600<04@D70186200C1`T00P0A1@L01`0C1`T040@601H:300J3Q0060`>01@8
2P0B1PP01P0@10H6018621Cooooo000Kooooo`0:01LA5@0?2@`040X<01<=3`0C3@h05Q0@01H@4@0B
30h04@/=01/E5`8040X=01D040X<01<=3`0A2`d03PP:018<3P0K5AL03PP:01<=3`0?2@/040X<01<=
3`0B30h03@L9010:300>20X04@/=018<3P0?2@/04P`>010:300?2@/00`0B30h201<=3`804P`>0P0A
2`d01`0C3@l040X<014;3@0B30h040X<00l92`0E2Ph00P0D2@d0100D2`h04`X=0189300C3@l2010<
3@0I00h:2`0@30d04Pd>014;2`0C3@d05a4A01@>3P0A2`/040X:00l92@0A2`/04P`<01<=3@0D3Ph0
4`d>014;3@0@2P`03`T;010:300A2`d04`d?014;3@0@2P`05a4C01TC5@0201D?4@0I00X41P0B30h0
5Q0B014;3@0H4Q@04@/=024K7@0E3a404`d?00`6200D3Q0040/;00h:2@0C3`h04Ph=010<2`0>2PT0
4@d<018>3@0C3`h04@d<018>3@0F4Q405A4@01@@3`0301<?3P0=00l;2P0C3`h071PG018>3@0E4A00
30P7010<2`0A2`/050h>00l92@0I4a<05Q0@01TC4`0501@>3P0:01H@400B3@X04@`901XE4P0M61D0
5A0=01@?300C3P/05Q4>01@?30804@`900l050l<01HB3`0F4@h05A0=01L@2`0I4@`06a8=01dF400G
4Ph06QTF01@B4`0c<cD0?Sm101`J6`0E51800P0G5Q@0600E51806QTG01PG5@0F5A<061LE01`K6@0K
6QP051<A01PD4`0K61L06aXH01TH5P0F5Q@05ADC01PH5P0N81d02`d:02HX9@2;T8`09BLT01dM6`0I
61H05aHD01XI5`806aXH02/06QTG01/J600M71X07ahL020O7@0O7ad06adJ01`N6`0I6aP071hK024S
800M7a`0828O01hP7@0L7Q/08R@Q01hP7@0T9R<061dG02T^:00C618082DQ01`Q7@0N8al07B4P01lS
900L824092PY02HZ:`0Q9RX07RD[01dT:P0L92X07bP]02</<@0S;C40:C@h01l]<00V=3L07R`_02Hd
=`0Y=CX0;3Lm00<0:SLm00T0:CPm02hm@P0`?d@0;T1402m1A@0]?d<0<D=703Q:CP0gBDd00P0eAd/2
03I8C080=dU=01H0=TQ<03Q:CP0kCE40>Ta@049AE013DUD0AUEJ04=BF@14DUX0AeEP04=AG`1<FFT0
?daQ05YVO`1EHG/0BeUb04eMK@1@HVh0BUaX051RKP1NL7`0D69^0P18FVH02P15Ef<0CEm[04aNJP12
E600AeQR04MHH019FV80CEiV051QJ@1AHVX2051QJ@0>05=TK01?H6P0DF9Z05MXL01KJW40FVU`05UX
K`1JJFh0GFa`05e/K`1KJVd0G6]]05e]K@1NKVh205m_K`0L06QfM`1[NGX0G6Y[071nP@1TLWD0JGMj
06UfO01cP8H0M867075nQP1cP8P0N8F=07f7T01nR940P8ZC086:T@1kQ8X0LGYo07b4Q`28T9<0N822
07f3P`1aMgH0LWQf06eeM`1fOX00P8R:08B<SP80QHf?0P29TI<0;01kPhD0Q8b>09RPXP3EgMl0VZ:W
08B;T@2:TIL0QHbB08^BV02<TiT0QHbB08J=T`29T9H0QhjD092GW@2MY:X0Yjbb08^@UP2<TIL0SY>G
08^@T`2?U9L0R8f?07n5Q@23RHP0QH^9096GUP2;TI00PXR808N=S@2:T900P8J608N=S@2BV9P0SiFE
08fCT`28SXh0S9:B08V?S`22RXP0OhR507f6P`1iPWl0LGYg0P1YLVl01`1WL6`0I6eY06UbK@1YLVd0
JG9^06McKP1TLfh00P1UM7401@1RLFh0HFm_065_K`1QKfl0Gfe^0080H6i_01X0GVa]05]ZJP1NKVh0
Gfm_05IVIP1>GUh0AeMG04ADE019FET0CEeM04iNGP1<G5`0B5QH04YHF@1>G5d0DEaN04E>D@0k@DD0
<SHi02//<00Z:bl09bT/02<W:P0T:2/09b`_02hf>080;cLi0P0/=3H0:00^=SP0;CDg02hf>00c>cd0
>41203Lo@@0^=SP0<CXi020Y:00X<C0082TX02Tb<@0Z<c80:34`02/d<`0X<C0092d/02L`;`0S;2/0
8bP[02T^<@0U:Rd092T/02`a=00W;2l0;34d02T^<@0V:bh09BX]02@Y;00R9bT09b//024U9P0P92D0
7b<T020T9@0[;c0082@U028V9`0P92D201dQ8P0I024U900O8Ah07b4N01lQ7P0P8Ql08B8R024R900X
:Bd071dQ01LH7@0U:2h07R4W02LZ;P0J6aX06ATG02/[:@12@T006ATG01/K6@0P81h0;Rh/010@3P0H
61H07AdK01HF500201PF5`0?01`J6`0Z:2T06ALH01HD5@0I5aP05aDF01/I6P0J61T05aDF01PF5`0E
51807QdK01PG5@0B4@l05A@B00805aHD00H04A0>01XI5`11@3h07A`J014@3P0F4Q4201LC4P0;01DA
400D40l05a<B00h:2@0O6aX040`;01<?3P0P71/04`h>01H@400E3`l00P0D3Ph201D?3`0401@>3P0F
41005a4A01LA4@805Q0@00<04P`<00l92@0A2`/00P0D3Ph0100E3`l04`d=018<300E3`l2018<300D
00l;2`0H5QL04@h?00l<3@0K5aP04`d=01LA4@0B30`04`/901H<2`0E2`X04`T701L=300C2@P050X9
01D;2P0C2@P05@/:01@:2@0B20L201D;2P0301@:2@0R61L04PP7008060h=00@050X901P>3@0H3Pd0
50X90`0C2@P0200D2PT05P`;01071`0@1PD05@/:01@:2@0A1`H060h=0P0E2`X0700D2PT04@L60147
1P0E2`X040H501881`0E2`X03`D4034X9`0D30/04`T801D;2P0D2PT04`T8028H5`0F30/050X901L=
300>10<05P`;01D;2P0B20L04`T801H<2`0D2PT0718A01@:2@0?1@@601881`0<01471P0B20L05`d<
034W9P0G3@`040H50186200?0`D06@d?02`P8P0?0`D04`L90P0E2@/02P0@10H04`L901L;3@0D20X0
CD=6028G6`0<0PD050T=01072@0A1PX201872`804`P<01H04PL;0147200D20T04PH801882@0D2P/0
5P`@01072P0C2Pd05@hB00`62P0[9BT0`[_205A=D@0F3A003`H901L?4@2GSY40>C0c01482`0F3A00
3`H90P0A20/01P0=10L050X=01<8300D2@d04`P<01462P804PL;02/04@H:01872`0C20`04PL;0146
2P0@1@P04`T:02dQ8`0j;S004PH80147200E2@/0308302PL7P0P5AH060d>01/A4P0f:R/05@T90186
200D20X05@T;0186200C1`L040D301L<200G3@D04@L101/A2@0L4`P04@/201<<0`0>2@8020<002@O
700C2`/04`T:01D92`0H20/060D801H41P0>0`<04`T8008050X901@0;R@T01@;2P0B20L03P@301T?
3P0P5QD05P`;00l5100B1PP040@600l31@0A1@L04PH800l31@0@10H050P:01D92`0C1`T04PH801<7
2@L040@600D04PH801D92`0E2@/04PH801041P0Dooooo`006oooool0300K5AL01P0202LQ8`0;1@L0
4@/=00l92`0C3A4030H8010:300D3Q0040X<00d72@H04P`>01l03`T;018<3P0E3a4050h@014;3@0?
2@/05a4C00h82P0600806Q@F00`6200F41804P`>00d72@0F418040X<01D?4@0X8R@0Ad5301D?4@0>
20X04@/=00P2100D3Q003`T;010:300A2`d050h@01D?4@0F418060dA00803P<700`050/>0189300>
1@P050h@00l;301DD5405Q8C00<0000H4a<03PP800l92@0C3@d2010:2P0>01<=3@0B30`04P`<01<=
3@0D3Ph05@l?01@>3`0;1@L05a4C00/51`0M5aT03@L9010:300A2`d3010:300B00l92`0I4aD01000
00`6200=1`T07ALI02TS9@0C3@l04@/=00P2100?2@/05@lA01@>400C3Pl03@T800`81`0K5aH02@D4
0P0E4A000`0D40l03`/:00h:2@02014=300601TE500?2`X05Q8A01@@3`0A3@`040`;0P0B3Pd0400J
5QD01`<200h:2@0F4Q404`d=00h8200B30`06aDE01TC4`0C3@d040X:01@>3P0G4A404P`<010:2P0C
3@d200l:1`05018=2P0E40d050l<010;200D3``00P0C3P/05`0E40d05Q4>01@?300H51405a8?01D@
300I4P`07aL@02<J4`0M5Q004Pd8018A3@0M6a`07b0Q01@E5`0C4A806aXH01@C4@0Q81h04A0>01DD
4P0D4a405A@B00805QDC02L05aHD01PG5@0G4a806ALE01/J600J6AL061LE01HF500H61H05ALD00h@
3@0M7a`0OhB00<C6``0S8b406QTG01LF500H5aD071/I01dL6P0L6aT06aXH01`K6@0N7A/081lM01lO
7@0L7AX04Q@A020R7`0I6aP05aTF01XL6@0T9R<05aTF03@f<`10@Sl08bDR01XL6@0O92000P0L8Ad0
4@0M8Qh0720O01/O7P0M8B807b<T01dQ8`0N8RD08RHY024V:P0M92`07RD]01dU;00N9bh082T`028/
<`0N:Bl0:3Dk0080;3To01408c0f02`h?P0/=cd0:SLm02`i?`0_?480<3m403A3B00fADX0;3i20353
A`0dATX0<4960394B@0lCE@0?e1G03U:D@0203Q9D00U03U:D@0cA4/0=TM>03a=E00gB4l0?U1E041?
DP11D5<0@4mD03e<D`0mBe@0@U1N04UFI`14DF@0BUI]059NN01=FG<0AU=/04EEI@10DUh0AeUU04QJ
IP0nD5`0AUQT04UKI`12E600@E=O04EGH`14EV80A5IQ04AEG`1>GfL0CEiV041AF@1<GFD0Cf1X059S
J`02055RJP0305=TK01EIVh0EVM_0080F6M^03@0GVed061_MP1MK740Gfic05IUJP1VMGP0IgIi05a/
K01OKfl0HW9b071nO`1^NG/0KgYl07=nPP1_NWh0IW5e07=nQ01dOhD0SIRN08B>U`1gPHX0NhF>07b6
S`27TIX0R9:K07j7SP1`NGl0JgAi06M_LP1iPH@0NX:407^1P@1mPh80LGMe071hNP1iPH<0P8R:08::
S024S8h0QhnA08F=S`22RX`0P8R:0869R`24S8h0QXj@08::S@27Si80R92C0869S027Si80Q8b?0P1o
QhX01P27Si80PHV<09VQY02maLP0bm3F08V>TP80SI:F01@0T9FI08N<T024RH`0PXN:07n4Q`29SY00
YJZ]0;Fk^`24SH`0QXn>08F>S@21RXT0OXN608><R`27T8l0QXn>08><R`1nQhH0NhB307b5P`80Mh1m
0100JgAa069[J01WL6d0J75^06M`K@1TKFX0IVm]06=/J@1QJVT0HFaZ06EdL@1XMg@0I79a06EcL`1T
LW80H6i^0P1NK6d02P1RL780HW1c05i/K`1LJfd0GVi^05e]K@1DI6@0B5QH049BDP13De<204QHF00?
04IFEP19FET0AUIF04aJFP18E5@0@D]<03i6B00k@4<0<CDh02h_<`0Z:bl0:2/`03Lj?`0_=3P0<3Hj
0080;c@g00X0:Rlb02H[;P0]<SD0>Sm203Dj?@0oA4L0@4E803@i?00a=ST0;S<f0`0Z<3003P0Y;bl0
:2h^02P^;P0`=SH0:S0`02@Z:P0V;2`09bd]02<Y:@0O92L0<SLk02T^<P0I7R80:Bhb0P0X;C401`0T
:Bd0<cPl02@Y;@0T:Bd07B8U02L[;00T:2T00P0P92D0800S9bP09RX[01`P8@0P92D09b//01hR8`0R
9RL08bLV01hS7`0O91l08RLS02PZ9`0N7al0:2T[02<T:00L7B807QlT020P:00N7RH07QlT01dM700K
6aT061PF01dM6`0L71X05aLE01<C4@0D51808b<Q01HF500M7A/030`:0`0E4a@0100L6Q/0:2HW02l]
;P0F51D201PF5`0601DC500D4Q<05A<D01PG5@0M71X061LE0P0F5A<0800B4@l05A@B01<B400E5180
4a8@01HE4`0L6aT06aLF01LC4P0@30/05a<B01HB4@0D40l061@C01LC4P0F4Q405a<B01PD4`0F4A40
6Q@D01dG5`0E3`l03PP801<=3@0B30`09R0P00X4100G4A403@L7020J6P0A2`/04`d=0P0D3Ph200h8
20804P`<0140618B01XD500<1PH05@l?024K700D41404`d?01LA4`0I4aD04P`<01P?400C2P/09AdK
01D;2P0L4Q404@L501D;2P0201@:2@0301<9200D2PT05@/:00H050X900H0308102HL6`10=SD02@00
02lU900C2@P201D;2P0501@:2@0@1PD04@L601L=300A1`H00P0D2PT02@0A1`H04`T801471P0F30/0
4`T801D;2P0>10<04@L600`20@0201H<2`8050X900@04`T801881`0B20L05P`;0P0I3`h0100E2`X0
4@L601471P0C2@P301@:2@804`T8020040H500l5100A1`H04PP701471P0;0@0050X901`B4@0B20L0
4`T900l5100K4A0030@3028H5`0<0P406Q0?01dC4P0D20X05PX<01T=3`0D20X04@D701D92`0I3@l0
50P:01451`0@10H04@D70186200O51P06a0D01H;3`804@H:1P0C20`0500C2@X04@D601451`0F2P`0
4`P901872`0G310060hA01893P0C2Pl050hB01@=500@2@d04`P<01@93@0I3Q80:AhR02DJ7P0E2Ph0
40D90P0>0`L00`0?10P04PL;01<8300201872`0H01462P0@1@T040D900`31@0K41@050T=01062@0G
31003`@801@9300F2P`03P8401D:2`0C1`T06Ph@0186200@10H060`>0147200B1PP0710B01451P0@
1@<04PH60P0C1`T07@0C1`X040@401`A3`0A1P807aD;0106000P5`P06141018;000D3P@01@4001D@
2P0=20@040L801462P0C1PP05@D601L41P0H1@H04`L701<9200<0`<05@/:00l5100K4A005@/:0106
1@0A1`H050X900804@L601P05@T;00X0000I3@l06Ph@00`20`0B1PP05@T;00h2100G2`d03P8401<7
2@0T61X05PX<01D92`0C1`T04@D700l31@0>0P@06@d?00h3100=0@<04@D70147200I3@lDooooo`00
6oooool0300E3`l0:bDV05UCE@0P6Q`03@L:06mYK@0E3a<05Q0D01LA4`0A2`d03`T901TC4`8040X<
0P0A2`d2018<3P0:00h82P0B30h050h@01@>400@2P`03PP:01TD5@0<1PP0;bT[01D?4@803@L902D0
4@/=00`6200?2@/03PP:01LA4`0V82809AlQ01<=3`0:10H071HH014;3@0B30h03`T;010:300A2`d0
4`d?01@>400E3a408QLK01T>4P0G31005`hA01@;3P0A20/02`H7010<3@0`;2d06QHG01<?400B3@d0
4@/;010:2P0C3@d040X:014;2`0D3Ph04`d=00804P`<00X04`d=01@>3P0E3a0030H801PB500J51H0
;2HX01/E5`0H4Q@04P`>0`0?2@/05`0>20X020<401/E5`0O6A/06A<E01`F600<1PP081XL01dG6@0D
3Q005@lA01@>400A2`d040/;010<2`0E4A004@d<00`81`0C3`h06ADD01LC4P0C3`h040`;00804@d<
01<05A4@00`81`0=2@P03`/:01HB4@0L61L02`L600l;2P0>2PT07QXI01lK6P0F4Q4071HF01D?3`0D
3Ph05a4A01@>3P0@2PX05Q0@00805@l?00<05Q0@01D?3`0C3@d00P0B3@X01@0D3``05a8?01HA3P0B
3@X050l<00804`h;01H05A0=01HA3P0D3``0510=01<?2P0B3@L05@h801XB300O5Pl0614;01<>2@0A
40`05A@B01DF5`0A4a801`H401PG5@0L6aT061LE01hM6`0>3@/05A@B100F5A<03P0G5Q@06QHE01DC
4@0D4a406APF01`K6@0I6AL05aLE01LI5P0C5A805QPE04U>BP1]Kf`06aXH0P0G5Q@00`0J6AL06aXH
01/J600301`K6@0;01hM6`0P7ad08B0N01TJ5`0Z;2T06A/H01/M6P0M7a`07b4N02DW900F61D00P0M
7a`0100I6aP08B<P01lT800O920201hS7`807B4P00d07b<T024U9P0O8bD0720S01dQ900Q9R/092/c
02D/=00U;C@08b`c020Y<00X<ST0=T5700807BX`03T07R/a02`i?`0U<CL0:cHl02Xg?@0/>Cl0;CY0
02`k@00Y>3d0;3]002/m@@0hBTh0>Ta@02m1A@0iBU00VJZa0:6b^@0jBe80?4eD045BF@0b@dX0=TM>
03U:D@0mCUD0>DYA03m@E`10Ce@0AEAG04MFG013DEX0AUAO05ERL@1DHG@0AeAW04eIL01ULHT0HVj8
04ABJ@1IJGP0F6Yf04IHI00mCe/0B5YV04EGH`12E600?e5M04=EH@17FFD0AEMS04EGHP1<GFD0D65Y
04aMI@16Eel0DV=[04iOI`1CI6`00P1BHf/0:@1EIVh0F6Ua05QYL@1JJG00FFQ_05i]M01OKWD0GFab
061_M01QL7D0G6]_05UXJ`1RLW80F6QX05m_K`1XLgD0IW5c06MbM01[MWX0KWUm06agN`1_NX00LGb2
086<TP1hPX/0LWb507J0R@1nR940P8ZC086;U01nQhh0LW^106M`M@1`N7/0Nh>507R0PP1jP800OH>2
075gM@1hP880OhN90080Q8b>02`0QHf?08J>T025SHl0PXZ<0869R`22RX`0Q8b>08F=S`25SI00QXjA
08B<S`2@V9/0Vj>V08ZBU@1nQXT0PHV<08ZBU@24S8l0R92C09VQY02OY:X0OX>708R=T@2:Si<0SiBH
08R=T@27S8l0RXnB08R=T026Rhh0SI:E09BIW023S8/0Q8f<08><R`1oR8L0OHJ5086:R@24SH`0Phb;
0829R01mQXD0NhB307^4PP80MGik00d0JgAa06E^J`1ZLg00JW=`06M`K@1SK6/0HV]Z05iWIP1LIF@0
GfYY06EdL@1VMG80H6m]0080H6i^00L0GF]/061^K`1QKg00H6i`05]YK01JJ6/0EVEW0080DV9R02@0
CemO04YJFP16EUH0@e=C04EEE@13De<0@E5A04ADE013DU80AE5A041<C00j@dD0>Sm203Hk?P0]<C@0
8b@X024R9P0U:Bh0<cPl02`d=`0^=ST0?454038g>P0R9bX08bP[030e>00oA4L0?4540456B@0k@4<0
;34d02X_<P0[<3<0:c4a02X`<00Y;bl202P^;P0>02T_;`0W;Bd09bd]02D[:`0R:2P092XZ02P^;P0c
>3/092T]02<X;00P9BT0:c0d02ld>00c>3`201hS9`0P02P]<@0W;3007B8V02da=00Y;Bh08RHW01hR
8`0L82406QhO028V9`0K7b00720Q02L[;00U:BX04QHG01dR7P0Q9R806AhJ01HH5@0J71`09BHX01`M
8@0K72407QlT01`M8P0I6B007QlS01dM700K6aT061PF01/K6@0J6QP201DE4`807QhL00@04a<A01hN
700E5A<05Q@E0`0G5AH02P0K6AX07Q`M01LE5P0I5aP061HG01HD5@0E4a@05Q@E01DD4P0K6QP201LF
500?01PG5@0E51805A@B01DD4P0G5Q@04a8@010?3@0D4a403@T801hJ6@0K5aH02PH501DA400J5QD0
5a<B00<05Q8A00l05a<B01D@400G4A406Q@D01H@400A2`/05Q0@01`F5P080P805@l?018<300Y8b<0
1@0001D?3`0G4A400`0F4100500C3@d0;bTY01dG5`070@406Q@D00X4100Z92@0@3Xk01D?4@0A2`d0
4`d?01LA4`0D3Ph03PD600X10P0I4@l05@/:01T?3P0E2`T05P`;0P0E2`X00`0D2PT05@/:01H<2`06
01@:2@0:02@J6@0;0@004PP802HL6`1AAdH05`d<01H<2`0D2PT04PP701@:2@805@/:00X04@L601D;
2P0D2PT04PP701@:2@0B20L03P@301881`0E2`X060h=0P0G3@`01P0A1`H04PP701881`0C2@P050X9
01D;2P804@L60P0@1PD01@0?1@@03P@301@:2@0D2PT04`T800<04PP700H04`T801471P0@1PD04@L6
01881`0@1PD201H<2`0J04To?P0n=3<04@L601881`0;0@0050X901P>3@0A1`H06a4@00/1000@10H0
3P840186200D20X05@T;01T=3`0A1@L040@601451`0C1`T05`/=01P<3P0B1`/03`@800d21P0>0`L2
01052@D04@H:01H04@L801861`0A1@L05@T;01<72@0A1PX05P/?01D:3P0C2Pl050/@01D?4`0B2a80
40H<01<8300A1PX03`@801T>4P0G31005@X>01/@500H3A4050T=0`0C20`201872`0W01462P0@1@T0
40D901052@0A1PX03P<701@93@0C20`03`@801051`0F2P`02P0000l51P0C1`T0200001@82P0<0080
710B01X>400:00004PH801861P0@1@<04`L701@82P0C1`T04@D801451`0W71X05@X501T?0`0R6@X0
6a<601TA000R6`T0>C8S01H?1@0=20803PL400804@H:00h04`H801D51P0G10H060D501hB4P070000
4PP701lE502l/[407A<B00d30P0>10<04@L601881`804`T80P0B1PP0200;0@80200002DI6`0<0080
4@D700l31@0A1@L030020P0G2`d201@82P804PH800P04@D701041P0C1`T03`@50186200M4A<05@T;
00`00QCooooo000Kooooo`0<028M6P0C3P`04@/<00X41`0H4QL04@XA024J8@0C3A803`T;01<=3`0H
4Q4071LE100@2P`2014;3@0:00h82P0A2`d04`d?01<=3`0?2@/03PP:028L7P0?2@/05Q0B00`72080
50h@00`04`d?01D?4@0@2P`03`T;01@>400E3a4050h@03Xd=P0F41803@L9010:300Q6ad3014;3@<0
4P`>01@06@hB01L<400E2Ph04PT<01<:3@0D2`h06A@E01<?400=2@X04a0@014=3P0E41404`d=014;
2`0C3@d04P`<01D?3`0G4A405@l?01<=3@<04P`<00T08A/L01LA4`0=1`T04P`>01XD5P0@2P`05@lA
01LA4`0C3@l00`0A2`d02P0D3Q003`T;014;3@0H4Q@02PD6010:300F41804P`>010:300B30h2010:
300901@?4@0=2@X05A4B018>3`0c;c00510A00l;300>2P/040`=00804@d>02005A4B00h:2@0A3@`0
40`;01@@3`0F4Q404@d=01<?3P0@30/03@T801PD4`0;1`H0<2`[01hH600H4Q805@l?01H@400C3@d0
4P`<01@>3P0A2`/040X:01<=3@0D3Ph03`T901<>2`0B3@X04`h;01HA3P0E40d04@`901@?30804`h;
01D05A0=01HA3P0D3``04a0;01<?2P0B3@L05@h701TA2P0M50d05@h601TD3P0D4`l040l=00d>3@0B
51<08b8P01HE4`0B4@l04a8@018A3`0?3P`00P0G5Q@05P0F5A<05A@B01DD4P0E5180<2`[02<P7`0H
5aD06APF01TI5`0F5Q@05aLE01@F4`0F61D05ALD01`Q7@0H6QL06aTG01`H5`0O6aX081`K01`H5`0H
51<301hJ6@0D01lK6P0P71/07ahL01TJ5`0O8Ah071hK030b;`0O8Ah0828O01LI5P0M7a`092HS02LY
9P0M7a`05QPE01XO6`0Q9B@082@S01/O7P0J7Ql201`P8@0j01lS9P0P92L07R8U01hR9@0Y;S@0:S4i
020W;`0O9bh092dd02L`=`0`>T00AU5G024^=00W=3X0:SLm049?E@0Y=C/0:SDk02Tf?00Z=cd0:cPn
02/j?`0c@TL0>dY?02i0A00]?d<0=DM;03A6BP0lCU<0RY^S09FV[P0oD5P0=TM?041AF@0jBe<0=dQ@
03U:DP0kC5@0>4UA03Y;D`0kBTl0?Da?03a;D@0mBe@0C5YU06ejR@1IIWP0EF9e055NLP1AGG80DEib
05ARM01PL7d0BeeW049DGP1;GFL0AUQR04AFH080@UAN0P18FV@02@14EV00AeUS04mPJ01<GFD0BEYR
04iOI`1FIfl0D65Y05AUK@0205=TK00^05QYL@1KK7@0G6ee05i/M@1KJG80GF]d05e/L`1LJg80H6mf
05QWK01SLWH0EfIY06UhN`1QL7<0GVa_06MbM01[MWP0KgYl06ehO01XLgL0I6mc06A_M@1_NX00Mh:8
071jP`1jQ8d0O8J?0;:la@2FX:T0OXRA07n8S`23S980PX^@0828R`1mQHL0M7an07UoO`1oQH@0Mgek
07MoP@1mQHL0PXZ<08F=S`26SY00QhnA08>;S@<0Q8b>0P23Rhd05@25SI00Q8b?08::S@2BVYd0Vj>V
08>;SP22RXd0Ph^>08F=T026SY40PXZ=0828R`2:Si<0QHZ>08B9S@22Qh/0RXnC08R=T@25RXh0R8fA
08N<T00208B9S@0V08F:SP22RXX0PX^:0829R01mQXD0O8F407n8Q`1nQhH0OHJ507^4P`1hPH00MGim
07=lN@1WL6/0IVm/06=/J@1TKFX0J75`06I_KP1TKF`0HFU[06=[K@1QJF/0H6QZ069]K@1RL700HFm_
05]YJ@1JJ6P0FfUZ05m]KP1TLW<0HW1c05]YK01DHVD0E65W05ETIP1AHF4204eMG@0B04]KF`14E5@0
A5AD04]KF`17EeL0A5AD04MGE`17EUH0?d]:03e7AP0h@D00=cdm03@i>@0^<3@0?d1503<e>P0_<cL0
;cDk0P0Z<SL02@0^<cL0;C4d02``<`0/<3<0;S8e03Pl?`0b=ST0=SXm03<g>P0202T]<00G030d=P0]
<C80:bl^02T];00X;2/0:Rh]02hb<@0U:BP0:Rh]02/_;P0S9bH09RXY034e=P1IGV409R/_02P]<@0[
<3@0:Bhb02`a=@0P9BT0<3Di01/P900d>Cd00P0W;300200Q9BP08RHY028V:@0R9RT08BDX020T9`0L
82<0;S8e0P0U:B`04@0N8RD0720R028X9`0M8R407b<R01PL700P8b@07b0R01/L7P0M7B008B4T01lN
8`0K6Qh081lS01lM7@0N7A/06aXH00807A`J00P061LE01/J600I61H04a8@01XI5`0L6aT061LE01PD
5@8071PI00/06QHG01LC500G4a@06QHG01/G600J5QL061@E01TE5P0J5QL051<A01PG5@0201LF5080
6APF00`05QDC01XI5`0N7A/06QTG01HE4`0H5aD0Ddm>01<?3P0Q7A`040`;01PD4`0D40l201DA4005
01@@3`0E4A005A4@01D@4@0D3Q000P0E3a408P0F4180618D01TC5@0>20X05@lA01HA4P0500406A<E
01<=3P0C3@d04@/;01D?3`0R71`071HF01TC4`0G4A404@/;01D?3`0>20P040X:01XB500F3A004@P;
0189300F3A005Pd>01L>3`0E30d05@d;01L?3@0=1@<04@T601L=300F30/301D;2P0301L=300D2PT0
50X900@050X900T04`T801061@0E2`X04`T801<:2@0C2@P05@/:01<9200D2PT00P0G3@`03P0C2@P0
4@L601@:2@0C2@P04PP701D;2P0D2PT03@<201H<2`0<0P406@l>01071P0J40l04@L61@0B20L03@0D
2PT04PP701471P0B20L05`d<01/A400G3@`05@/:01471P0@1PD04@L601881`0C2@P00P0A1`H201<9
200701061@0H3Pd03`D402/Q800R61L03P@301H<2`0201881`0:01061P0K4A005@/:01<9200I3@l0
4PH801H:300J3Q0050P:018620<050P:00@04`L90186200B1PP05P/?0P0@1@T00`0D2@d04`P<0105
2@0501872`0=01882@0G2@X05@H901P9300F2P`05@T=01H:3P0B1`/04`T?01@;400E31404@L?0147
3@0201P=4@0701052@0C20`050T=01@93@0F2`l050T=01872`0201052@0301462P0B1`/04@H:00<0
4@H:02@04`P<00l5200D2@d05P/?00/1100>0`L05`/>01@:2`0?1@H050T:01L;3@0L41803`@50186
200D20X040@601@82P0H30h04PP701<81P0D20P04`L:01862P0@10L050P:01<81`0F2`D040H002@L
2`28P6T0MVaG04U0:P0d:QX07aH=01P@2P0A2@L201462P0;01<62@0E1@L05PD601L51@0D20P04@L6
01481`0H3Pd0;B@T01<9200<0P800P0H3Pd02P0A1`H05P`;01D;2P0B20T04@D70147200K3a4040H7
01@82P0A1@L201D92`0301451`0K3a403@4300L04PH800D07a<E01@:2`0H30h03`<501041P0Doooo
o`006oooool04@0I5140100001@>3P0@2Ph0@C]00109400j<cX07QPM018<3P0F41804Pd;00X50P0E
3a4050h@018<3P0A2`d040X<00803`T;00<040X<014;3@0A2`d00P0?2@/04`21Ngd0E4i@00D00@0L
5QP0100000X41P0<1PP03@L900`6200`:R`0GeUK06YTIP0=1`T06A<E00@0000?2@/030H800l92`0B
30h00`0A2`d2010:300E01052@0E2Ph05@X>01<:3@0G3Q406a8E06aVJ00J5QL00`00018>3`0:1PL0
50l?014;2`0?2@T04P`<01<=3@0G4A406Q@D01D?3`0C3@d04@/;008040X:00<0:B<T02TS9@0@2P`0
0`0C3@l00`0E3a405Q0B01<=3`03014;3@0400X51P0S7Al02@<5014<3@805a4C02<03`T;01<=3`0D
3Q005@lA00d72@0>20X05A0A00X61`0@30d04Ph?03lk?00C3a00510A014=3P0B3Pl03`/<00X61`0?
2``020@3018>3@0A3@`05a<B00h:2@091@@06QHE01@@3`0C3`h00`0002LS8P0K5aH050h>018<300F
41006A<C01H@400201@>3P0601H@400H4Q805@l?01<=3@0E3`l04`h;0P0B3@X201<>2`0I010;200D
3``04`h;01<>2`0E40d05Q4>01@?300E4Pd05A4;01D@2P0G40P06Q8:01`C2P0G40P05a8<01@C3P0C
4Q004Q<B01<E500C4Q0051<A01LF500I61H05A@B01@C4@0201HE4`0901DD4P0D4a4051<A01<B400I
5A@06QLF01HE4`0C4Q005A@B00806QXH00H04aDB01LI5P0F61D06b0L01<E4P0N6aX201dI600401hJ
6@0L61L06QHE01`H5`806aLF010071PG01dI600L6aT071dK01PJ5`0P8Ql0=CLd01/M6P0L7Q/09BLT
024S800M7a`07b4N01XL6@0?4@h07B4P0P0U:BP0@00O8b807R8S024U9P0M8B@06alR01dP900P8bP0
8B@Y03Pm@`0l@dd0:S4k028Z<`0P:C808R/d02D_>00S;CH09S<k02dj@P0^>d<0:SLo02`h?`0[=S`0
9c@j02Pe>`0]>T00<D1502hm@P0`?d@0;3i203=5B@0nD5@0>D]?03e?E@0]?TH0<dA<041AF@0cA4`0
>T]C03m@F00nCeL0?4eE03Y;D`0kC5@0>T]B0350A@0hAdX0AUEK04aJH`19Ef80@TmO04eJJ`19EVL0
BeQY05ISL`1EHW80@4mL03a=E`1EIg40BE]U049DGP1NL7X0BUaV04MIH`16F68204QJI00704MIH`1@
HV`0CUmW04iOI`1AHVX0DV=[04mPJ002059SJ`07055RJP1BHf/0EfQ`05Y[L`1KK7@0Gfef05]YLP02
05aZL`0T05]ZLP1PKgH0FVU`06imPP1bPHH0Gfia05UXJ`1cPH@0G6MY06=]K`1XLW@0JG9g06QaMP1Y
LWL0G6E/079kPP1jPhX0Lgb5086:T`1nQi00QY2I08F?V026T9T0R96H08F>U01nQh`0PXZ=07MoPP1]
MGL0LgUi07b2P@1kPGl0Lg]m07R0PP1oQhT0Q8b>0P25SHl08@23Rhd0QHf?08J>T026SY00Ph^=08::
S01oQhT0R92B08nGV@22RX`0PHV;07j6R01oQhT0Q8b>0869R`23Rhd0R92B08J>T023R8`0PHJ:07Yo
P`22Qh/0RXnC08bAU@2<TIL0QHZ@0866S020QH/0OhB:07n4R01nQhP0OhV807j8Q`0307^5Q01I07V3
PP1hPX40M7im06miN01/MWD0Ig5^05YSGP1IHUd0FV=O05iWI01RJfX0H6QY061XJP1QJF`0J71c06I^
L@1SJfh0HVe^05e[J`1LJVX0FFMX05QVI`1KJFX0I79d069`L`1KJF`0FFI[05MTJP1BGfD0CE]N04UI
F@16EUH0C5aL051PH01=GEd0BEUI04]KF`18F5P0A5AD04IFEP14De<0=d=103I1?@0b>cP0;cDe02``
<@0X:Bd0<SDj028U:P0Z;cD0<CPn03M0A@0f?dD0<SLk02HZ;@0R9RT0;C4d02lc=P0[;c80<3@g03Di
?00i?D00;c<f02@X:`0P92H0;C4b02/_;P0Y;B`0:2`[02/_;P0_<c80;30_02/_;P0X;2/09RXY02P/
:`0[;c00=CXn02<X;P0W;3809BX`02T^=00W;380<SLm02<X;P1MHVP0T9FK02hc>@0P9BT00P0X;2l0
9@0V:Rd08bLZ01hR9@0I7B007b<V02@X:`0Q9BP04aLJ02@X:`0e>C`061dP01XP8@0V;2`07b<V03<g
>01ZKVl07b0R01LH6P0K6a/081hQ01`J700H5QL06QTG01`K6@0J6AL071/I01hM6`0L6aT061LE01DD
4P0J6AL08R4O01/J600R8Al061@E01/G600L61T00P0K5aP0200M6AX06ADF01XF5`0I5AH05a<D01TE
5P0L61T05QDC0P0G5Q@201DD4P0>01PG5@0A40h04a8@01HE4`0D4a404a8@01PG5@1SGeh07a/J02DQ
800B3Pd0<Rh]02/W9P0D40l301<?3P0501@@3`0F4A405@lA01<=3`0D3Q000`0F41804P0E3a406A<E
01<>3`0`:R`0100001`F5`0E3`l04`d=01PB4P0U7al081XJ01D?3`0>20P03@L701@>3P0@2PX05Q0@
01/D5@8050T=0P0F2`l00`0E2``04`T:01L=3P0201@<2P0300h6100E3@X050X900804`T800<04PP7
01<9200D2PT01P0D2PT0400F30/060h=00h4100K4A006Q0?01<92@0>10<050X901T?3P0E2`X04@L6
01<9200A1`H04`T801471P0?1@@301<9200500d5100J40l0CdE403H/:`0700000P0D2PT0300C2@P0
4PP701471P0A1`H03`D401061@0A1`H04`T801D;2P0F30/050X901881`803`D400d04PP701@:2@0B
20L04@L601<9200D2PT04`T801061@0?1@@060h=01<9200=0`806a4@00803P@300l04PP702DK6P0/
8R4040H501471P0>0P@040@601T=3`0M4A<050P:01451`0>0P@040@601<72@0F2P`00P0G2`d01P0H
3A4040D901052@0C20`03`@800X00`D04`P<01<04`T:01831@0@0@@0404401<41`0A1@T03P8601<7
2`0B1`d04@H<0107300A1`l03P@:01<72`0G2`l050P<01862P0C1`/04PH:00804@D900@04`L;01@8
300E2@d050P<1@0A1PX02@0>0`L06@hB00`11@0;00@06PlC00`11@0f;2d0/JFW02`P8P0201/?4@05
00P0000B1PP03@4300d10`0E2@/00P0D20X07@0J3`h060d;01<71`0@10P04@D901@73@0=0@<05PX:
01/A2@0]91D0Lf]F0>gXcP3oo^H0YYN003d_7@0C1P003@8001<92@0A1PX04@H<01862@0D1@P05@D6
01D51@0=0@404@L601@:2@0:00009Q`K00803`D400/07A<B01`B4@0@1PD05P`;01D;2P0900003`<5
024E5`080000710B00P0000201@82P03020D5P0F2P`04@D700<050P:0P0B1PP0200A1@L040@60186
200O4aD03P8401T=3`0=0P<050P:5?ooool001_ooooo00h03`/9018=2`0E3`l03PP<02hX;@0>1`l0
4``D01@=4`0D3Q003`T;00d81P0F4@h04`d=01<=3`804P`>00<04@/=010:300A2`d00`0B30h2014;
3@0B01D?4@0D3Q003PP:018<3P0:10H04@/=01PB500D3Q003PT:00l:2`0B30h04@/=00d72@0G4A<0
3PP:01<=3`0L5QP030H80P0A2`d2010:30804@/=00<04`P<01D:3P0E2Ph00P0C2Pd0400D2`h04@/=
01DA4P0@30d03@T:01DA4P0B3@d03`T900h8200B30`04@/;01<=3@0F410050h>018<300A2`/2010:
2P06014;300D3Q001`83014;3@0?2@/05a4C0`0?2@/2014;3@803PP:01004P`>010:300n>3X04P`>
01@>400?2@/030H800d72@0B30h04@/=01<=3`0D3a003`/<01DA4P0=2@X0510A0P0?2``0800;1`P0
4@d>01@@4@0B3Pl081`M01XF5@0K5aH03@T801HB4@0=2@P0;b`[04a8A`0F4a8071PG014=300E4A00
5Q8A01<=3@0B30`05Q0@01LA4@0B30`04@/;018<300D3Ph05Q0@018<300A2`/04`d=01LB3`0E40d0
4`h;0P0E40d06P0B3@X050l<01<>2`0C3P/05A0=01HA3P0D3``04Pl:01<?2@0C3PP05@h601L?1P0H
3`H05Pl701@@200B4@`04a8>018C4@0A4a804A0>01LF500920H06APF01HE4`0E518051<A0P0E5180
5P0D4a405A@B01DD4P0I5A@07A/I01XI5`0E518051<A01PH5P0V9R@0828O02`^:`0I6aP05AXF01HH
5@0H5A@061<B01TD500M61P07QTH01dH600N6AP201dH5`0601dH600N6AP07AXI01/L6@0b=34061XG
0P0M7a`0100K7AX071hK02DW900S9B8201XL6@0D01hP7@0I7A`0720O01dQ800L8200720Q01dQ8P0S
9bX07R8U01lR9P0Q92T082<X02<X;`0O9S0082La02Ta>`0S;3D08BXc02Pa>P0V<3T202Hc>`1002Db
>P0Q;SH0:3@k02/f?00Y=S`0;3To034nA00c@TL0>4M<045@E@0eAd/0<D=703mAE@0nD5@0>TaB03I7
C`10DET0=TM?04AEG@1@HFT0?DiF041AF@0iBU80<dA<03M8D00fAdh0=dI;03]:C@15E5`0CUaW04mM
JP1;F6P0AeAT04eJJP1<FVP0@e5L04=BF`14E5`0AUMP04UKI011E5`0?U1I04AGG`14EUl0B5YS04AG
G`15Ef00BUaU04]NIP1DIVl0DV=[05AUK@1IJW80EVM_04UJHP1CI6`0DV=[055RJP1BHf/0EFI^05QY
L@1IJW80G6Yd05UWL@80GVae01@0GF]c061_MP1TLgX0GVec07Z9SP1]O800Gfib09^Y[01`Ngd0JG=e
069/KP1SK740JgAi071iOP1[M7/0OXN>08RAV01mQXl0PHZC0829TP<0P8ZC00l0P8V@08:;T@24SI80
Ph^>07R0P`1`N7X0LgUi07QnO@1lPX00NX:407b4QP21RH/0QXj@08F=S`22RX`00P25SHl208J>T005
08F=S`24S8h0P8R:08VAT`2BVY`00P23Rhd03P26SY00Nh>508J>T028T980Q8b>0869R`22RX`0Qhb@
08F:SP23R8`0Ri2D0825RP26Ri00Q8V?0P1oQ8X01020QH`0NWn607=jO`1hPH8207f7QP0Y07Z4P`1g
PH00MX1o07AnO@1cOG`0LG]j06egMP1[MG@0J79_061YI01QJVD0GfQT061YIP1WL6l0IFe^069ZK01Q
JF`0IVib06A/L01RJFl0HFa^05]YJ@1JJ6P0FfUZ05MUIP1IIfT0Gfe`05UWJP1DHFH0EVAY05QUJ`1B
GfD0C5]N04YJFP18F5P0AUIF04EEE@12DU80A5AD04YJFP18F5P00P14E5@0M00oCTh0=D0o03I0?00g
?C/0=3Pi034e=P0`<CD0=STn02X]<P0g?D<0:C0f02hg?00d?T<0OhB805IJG@0W:bh0:2`_02``<`0Y
;C00:2`_02da=00f>Sd0<CDh02HZ;@0R9RP0;C4b02da<00[;bh0:Rh]02/_;P0^<S40;30_02HZ:@0Q
9B@09BTX02P/:`0T:2T09BX^02T^=00/<CL092T_02T^=00S:2h092T_02H[<@0U:S00<SLm02P]<`0P
9B/09RT^02DY;@0U:2`08bL[024T:00N8RH061`P03/o@`1lP8@0;C4e020S9`0I7B408BHY01dS9`0I
7R80<SHj02DZ;@0R9RP0;Bh`01lP8@0O7ah09B<S028P800N71X06ALE01dJ6@0I5aD06AHE01/I5`0J
5aH07Q`J02LU8`0O7A/05Q@B01lL6`0F4a806QDG01/F5`0J5AL061<E01TD5P0J5AL061<E01PC500G
4Q<05Q4C01TD5P0L61T05A@B01@C4@0G5Q@051<A01DD4P0J6AL05A@B01HE4`0I61H051<A014@3P0D
4a405A4@00h:2@0H51<03`/:028N7@0P71/05A4@0`0D40l03P0E4A005A0A01@>400C3@l050h@01D?
4@0F41806A<E018=3P0^:2X0EU1B01lI6`1@BT`0618C0P0A2`/01`0E3`l04P`<01<=3@0C3@d05Q0@
01D?3`0?2@T00P0H4Q803@0B2@/05@X>01H:3P0G2`l05P/?01H<3@0G3@h050X;01<;2@0>1P@08ATG
00d50P0D2PT00P0C2@P00`0B20L04`T801@:2@0601@:2@0@01071`0F30/05@/:01@:2@0H3Pd050X9
00h40`0D2PT06Q0?01<9200@1PD05@/:01H<2`0G3@`04`T800l510804`T800X04PP701@:2@0B20L0
7A@D01P?3P0E2`X040H501471P0B20L04`T80`0D2PT201D;2P0301@:2@0B20L03`D400804PP70P0A
1`H05@0B20L04`T801881`0B20L050X901H<2`0D2PT040H501`B4@0A1`L04PP700/20P0@1PD04PP7
01L=300B20P04PP701071`0D2PT03`D401451`0201<72@0601041P0G2`d08QHH01H:300D20X04`L9
0P0B1PP01`0C1`T04`P<01462P0B1`/04`P<01872`0@1@T01@0A1PX03P0B1PP05`P901D62@0D1@P0
70d@01/?4`0E2@d04`L;01<83P0B1`d040H;01473`0B1Pd04`L;0P0F2Ph00`0B1PX04@D901<72`03
01<72`804PH:00@04@D901052@0A1PX04@H:0P0B1`/0900I3Q809Q/O01472P0H3Q40=2T]01hC5`0?
1PL0@SHh00`20`0@1@L07A4C01@82P0C20T03P8401hB500m<C<04`P900/10P0R5QD05P/701861P0@
10P04@D901<6300C1`/060`<01lE3@0b:AP0DTXd0<S3Y`3XglD0PW5I02PH2@0L3PD070l900l41080
4@H<01/04@L90186200C1`D04`L401@9200?1@@04@P701@;2`0L4Q404PP801061@0C2@P04PP700l5
100B20L050X901061`0K3a4050T;08=gN@0O5AH05PX<01<72@0@1@H06`lA01041P0=0P@00`0C1`T3
0186200701451`0A1PL05PX<01/A4P0n<S@06`lA00h3100Dooooo`006oooool0;P0A2@L06Q<B00@0
000L4aH02P8801H?5P0B21003PH<01LA4`0N5AH06A8A018=2P0=1`T03PP;00l92`0A2`l04`d@01<=
3`0B31004P`?018<3P0B30l04P`@018<3P0@2P`04`X=02@N800=1PP07A@G01<=3`0[8bH06A0C00h8
2P0<1@L04PT<01H@4P0B2`d04PT<00P2100P61/0@cXm01D?4@0@2@/04@P;010:300B2Pd201<:3@0<
01@93@0E2Ph05P/?01D<3`0D2`h04`X=01L?4P0400004@/=00h82P0I4aD03`P80P0A20T01P0C2P/0
3PD600d41@0A2`/04P`>014;3@8040X<0P0A2`d0200P6Q`04@/=00d72@0600805Q0B00`6200@2P`0
4@/=0P0E3a40;P0B30h03@L901XD5P0800805@h@01LA4`0e;2l05`lB014;3@0?1PT04@T<00h82P0?
1PT04`d?010:300>20X06aDG00T31@0C3@l0618D018<3P0C3@l040X<00/51`0L5QP040`=01DA4P0C
3`l07ATJ00<0000T81l0>cLf02`X9`0G4a803PX901PD4`0?2`X04P`<00l92@0A2`/04P`<010:2P0E
3`l05Q0@01<=3@0B30`201H@4004014;2`0E3`l04`h;014<2@804Pd:00T040/801@?300C3P/04`h;
01D@3@0F4@h050l<014=2P0B3PX00P0C3PP201H?1`0>01L@2P0H50h05a@?018A3@0@40h051@D01XI
5`0C4Q4071/I08Z9Q`0G5Q@06aXH018A3`0C4Q0201@C4@0701DD4P0F5A<06aLF01LE4`0E51805QDC
01TH5P0201XJ600>014A3`0U9b@04Q<@018D4@0L71X06aPG01`H5`0M6AP07a/J01/G5P0H51<081`K
01lK6P0N6QT201lK6P0>020L6`0L71X07QhL01lQ7P0H6AH07AlL01`N6`0O8Ah05aTF01lQ7P0S9B80
6Q`I01LI5P0O8b8201dQ8003020T9@0Q9BH08BDV00807R8U00L08bL[02DZ;P0S9R/082H]01`S:`0Q
:300;3@l00809Bhe00<0:C<j03]6C00O;3@00P0^>d<01P11CUH08c0g02Tf?00/>Cl0<3e3034nA080
;Se20300>TU>03A6BP0bA4P0?DmC03I8C00bA4T0<D9:03Y;D`0fAdl0<45903a=E@16Eel0BU]U045B
G00gB580?TmI03e>F00jB540?deF04MEH@17EF80B5EU04iKJ`16E640BUQU04UGH@17EUd0BEQO03e<
DP0nCeH0?4mF03e?EP14EEd0B5YT04IGH@1>GfT0AeUS04MIH@1<GFD0BEaS04QIH018FF40B5UP055R
JP1FIfl0B5UP05=TK01DIFd205=TJ`0305EVKP1GJ6l0F6Ua0080F6I_02L0GVed061^M`1MK7<0Gfie
05]ZL@1UM7X0FfY_06akP01NKG80Gfe`06IaM@1SKFl0IW1b06efN`1_N7d0JW=h06UbN@1eOXD0PhbC
07IoR01gP8T0OXN@0869U01oR980PHZC08B=UP28TIP0R96F08bCV@26SY40OXJ807b2PP1lPX40PhV9
07InP01hP880OhN908R@TP27Si401`25SHl07P21RX/0OhN:07f7R024SHl0Ri>F07Z4Q@1oR8X0OhN:
08B>S`25SY00Q8b?08VAU025S980OXF;07f4RP24Ri40NX6708bCV@2DW:00PXZ=07Z2Q@1eOH00K7Ag
06I^L@1aO7T0N8=o07Z5P@1gPWh0LWei06mjMP80KWUe01<0KgUh06ihM`1]MgH0K7Md06IaJ`1YM700
HfiZ065/J01YLg80J79b069/K@1OJFX0Hfe_06MaL`1[MGL0J7Ae05]YJP1JJ6T0FfUZ0080Df5T02h0
E69U051NH@1AGV@0Df1V059OI@1?G680BeUL04QHF018EUL0AEAC04=AD@14DU80@Dm?041>CP11Cdl0
?D];03]9BP0d@D80;cXf034j=`0d>SP0<cTi03<g>P0d=c`0=3Ln02`a=`0m@T/09bhd03i7C01cO880
=c`o030d=@0/<3<092P[01dR9@0`=CP0;34d02/`<`0_=3L0:B`a01lR9`0T9b/0;S8c02`b<00]<C00
;30_0P0[;bh0500W:bX092PW028V9@0U:BP0:Bh]02T_;`0W;2l0724U02L/<00X;C40;34e02T^<P0c
>3`0724U030e>@0T:Bd08bP/02T^<P0P8bP082@W0P0Q9BP2028V:@0P03<d>00S92P0MGIj01<D600X
:Bd08b@X02d`=@1:CU<03a8G01`P8`0F61/071dO02TZ;00P81l06a/I01XI5`0J5aD07QXG024N7@0U
8B007A`J01XG5P0K5aH061LE01TG5@0O6aX05A@B03/i=`1RGUd0;BTX01LB500L5QP201dG6@0401`F
600M5aT05a4C01H@4P805@lA01806A<E01/G600C41404@l@01HE4`0E4a<05aHD01hM6`0=30X051<A
01XI5@0F5A4040l;018A3@0@30/06ADD00l;2P0B3Pd201PD4`805Q0@00D05@l?01H@400F41004`d>
014;3@0201<=3`0601@>400H4Q@05@lA01LA4`0Q6ad0H5YL0P0?2@/06@0H4Q<03`T901@>3P0L5QH0
3`T901PB4P0b;2`04Ph=00D1000K5aH02PH500D1000F3Q005`/?01H:3P0D20`05PX>01X@4@0N51D0
40H701D=2`0I4@l0Aclm01P@3P0E2`X00P0D2PT00`0C2@P050X901D;2P0601@:2@0901X?3@0B1`D0
6@l=01<9200D2PT050`:018:200C2`T050`900<04`/800@06a4@01`B4@0F30/04@L60P0D2PT01P0E
2`X04@L601H<2`0B20L04`T800/100804PP70P0@1PD0200?1@@03P@301061@0A1`H04PP701<9200F
30/05`d<0P0C2@P08`0B20L04@L600l5100=0`804PP701<9200E2`X05P`;01@:2@0?1@@04@L601<:
2@0E2`X04@L601P>3@0=0`80:R0O01P>3@0l<S405`d<00l5100C2@P04@D701<72@0?0`D050P:03da
<`1LD58050P:01451`0@10H04PH801D92`0F2P`040D900804PL;0P0?10P00`0@1@T04`P<01<83003
01<8300801@8300D1@P04P<601831P0L3A00710D01D93@0@10P201H;4@0301<83P0@1@/04@H;0080
3`<700H04PH:01<72`0D20`05@T=01862P0C1`/201@8300501<72`0B1PX040D901052@0A1PX00P0B
1`/0900@1@T04`P<01X?4`0D2@d02`0401872`0G30l0200001lC5@0?1@H04`L900P0000J3Q006@d?
00d10`0C1`T0710B01041P0@10<040D301861`0B1PP040@800h21P0;00408QHF01@:0`0K4@D05a00
03D/601KC3T09aH401L7000A0P003@0001H:2`804@H:00`04@L801861P0B1`D04PL400T0000B20L0
5P`;01881`0700004@L601/A400D2PT201061@0800h40`0A1`H07A4C01T=3`0>0P@0<RHX0186200I
3@l201@82P0600h2100:000060`>00`00P0@10H04@D70P0B1PP201@82P804PH800@0300202@H6P08
00007A4C5?ooool001_ooooo0P0C2@X01`0B2@X04`T:01<9300B2@`04`P<01<9300B2@X00P0C2@X0
8`0B2@X03`T=014<4@0>2@d03`X@018=4P0;1PX05A0F00`7300D3a<05A0E01<>500C3A403`H901@9
3@0F3A005`dA01D:3P0C2Pd040H901462P0@1`X05`d@01462P0E30l04PP901@:2`0G3Pl071<D01X@
4@0E30d050X;01D;300D2``05@`=00805P`=1P0C2@X0600H3Pl05@`=00X10P0D2``05Pd>0187200E
2@T050P801871`0D2PT05@/<00d51P0F3A803`T=01H@500?2Ph06QDK03dh>`0C3@d03@L701@>3P0B
30`050h>014;2`<040X:00l04@/;01<=3@0C2`d04`X=01<8300?1@T05@`?01T>4P0P5QT02`8501<8
300G3A005@`?01lD600?1PT0100D2`h0100C2Pd04PT<01<:3@0D2`h20189300E01@;3P0C3A404`dA
01@>4@0D3Q804`d?018<3P0@2P`050h@01LA4@0C3@d04@/;018<2`0;1@D05Q0B00l:2`0M5aT04P`>
014;3@0B30h04`d?00<05@lA00<04`d>01@>3P0D3Ph00`0D3Ph0800E3`l04@/;01D?3`0H4Q806A<C
01H@400C3@d05a<B00`81P0O6aP09b<P01hI5P0V8Ah07APE01TF500:1P<06aLF010?3@0A40h05Q8A
01DA400L61L07ATH01LC4P0D40l061@C01TE500F4Q404Ph=01<?3P0I5A@040l=0P0C4Q008`0M71X0
5QDC018A3`0K6QP06APF01PH5P0K6aT06ATG01PH5P0J6AL061LE01hM6`0O7Q`06APF01LF500J6AL0
5aHD014@3P0K6QP08R4O01/J600M71X0:BPV00T91`0M71X07alM01PH5P0T92803@l<028T8@0f>3D0
9BXV014F4P0O82406a`N00807b0R02007b<V02HZ;@0_=3P07R<W01`Q9P0K8RP09BX`01dT:@0Q:B`0
8RX]02@];`0V<380:34f02La=P16DED0>DI<02Ld>P0^>d408c0f02/h?P0Y>3d0:cXo02`k@00T<cP0
9cHk030oA01>GF80EVEZ03=2A`0eA4T0>dY?03E6BP80<dA;02d0>4U@03Q9D@0nCeT0AEIP03e=FP0j
BUL0A5AR03A4D`14E6<0=d=I04QDJP1BGW<0CEY]05ISM00oC5/0AeEP04aJH`1JJG00BeYO04ACF013
DUT0AUEL04=DF`15EEd0BUQS04YJI`1<FVX0CEYZ04MGIP15EF00BEMP04YKH`1=G680BeYQ04IEFP16
EE/0EfI]059QIP1IJ6h0Hg9i05QWK01GIV`0Gfie05YYKP1HIfh00P1]NX809P1IIV`0FfQ`05]XKP1L
JFl0GV]a05QUJ`1SL7H0GFY`05m/LP1RL7<0Ig9f06=^L@1LIf/0JGAh06UdN@1[MW`0JGAj07F0Q`1h
PX/0NhF>082:T`1lQ8l0MWj;08fDXP24RYP0PHNC0827T@2AV:00P8N=08N?TP21RH/0MWmn07f6Q@2B
ViX0MWj007b4QP23Rhd0QhnA0P26SY005P23Rhd0QXj@08B<SP1oQhT0P8R:08::S021S8h0PhbA08RC
U@20RXd0PX^@082;S@1oRH`0PX^@086<SP27TID0R96F08><T@23S9@0PX^B086:T@20RHl2086:S`0T
07b6R01hPX40N8:107R3P01XLfl0KWUe06ikM@1bOgP0Kgae079oMP1gQ7X0Hg1V06ikLP1OK6D0JWIc
06QdLP1ULG40I71^06IbKP1QKF/0GVYX06=_K@1ULFl0IW9`069^K01MJFL0GVYZ05m[J`1RKVh0HFma
065`L`1JJF`0EfIY05QWK01DHfP0EFAY0P1@Gf@0A@1CHVL0DV5V04]JG`17EEP0AE=D04eIF@17E580
@4a:04=?B`11CDT0@Ti:03e7AP0jA4<0>TA503Q0@`0c?3T0;CHa02Xc<@0lA4H0>d1603m3C00[;cX0
B4mI02/b?00j@DT0@dYB07^3Q`0_<c@0;C4`02X_;`0/<S80;SLf02/c=@1iPH@0CeMJ01dT9`0O92X0
:Rdd02`_=@0]<SD0:C8a02L];@0V:R/09b//02//;P0Q8R@08R<U024U9P0O9BD08RTY02@];00V;b`0
8b`Y028[:00Y<S40:c@c01/T8`0X<C009Rh_01/S9@0L92H09Rh`02H/;00R9RL07R0R02h_<@0b<cD0
92DW01lP8P04024Q8`05028Q900S8B@08R8R020P800M7Ad00P0L71`0=00M7Ad07alO01dL6P0G5Q@0
6APF01`K6@0E5180<2l_02/Y:P0A4A407ahN01hL7@0E5AD06QTI01`J6`0A4A40;2/[03dk?00M6a`0
5Q8A04I2@@1@C4/0920O051<B`1?BdX07a/J00X61@0N6QT06QHE01DA400?2``05a8F01TD600I5AH0
5a8E01HB4@0G4a804@d:01TE4P0H5A004Pl:01HC3P0L6A@051<@014@3P0C4@l05Q8A01LA4@0U7al0
;RDV020G600F3@h201`B4`0=01L>3`0E3`l06A<C01D?3`0A2`/050h>014;2`0I4a<071HF01TC4`0A
2`/02`D501@=3@0201H=3P0F01@=3@0B30`04@d<00l;2P0H5aD05A@B010?3@0E51807AdK00/61P0R
61T03P@501D<3@0O5AH060h?01D;300D2P/05@/<01P>3`0G3@h03`D501@:2@804`T800T05P`;01P>
3@0G3@`05@/:01`B4@0B20L06@l>01471P0E2`T00P0F20D02`0H3@`01`0000h60`0B3@X06AHA00d:
1@15@SX0:BDL01`H3@0F4PP04`T700804`L700L04PH601<71`0D20P03`<301H:2P0I3@d05`/;0080
5@T901404PH60104100=0@404`L701L;2`0900005@T901H:2P0D20P04PH601<71`0F2PX05@T;0104
1P0C1`T05@T;01<72@0201@82P804`L90P0D20X03@0B1PP04@D701H:300@10H03`<501L;3@0I3@l0
200001hB501<@480710B00T0000L41800`0A1@T00`0C1`/050P<01@8300601862P804@D900h04PH:
01@8300F2Ph05PX>01L=3`0A1@T05PX>00`2100R5QX03P8601862P0@10P07Q8F01882P803@4500`0
50P<01452@0@10P04@D901<72`0N4QH08aLK01`@500C1`/040@801862P0D20`20104200:01@8300@
10P040@801<72P0Q5AL04@D701061`0D20X02`0101H:308040@600@060d>02/O8@08000050P:1@0A
1@L00`0@10H04@D701lC5@0201<72@0300X0000A10D04`D500<04`@702D04@D700l51P0@1PL04PP7
01<91`0E3PP071<=01T<1P0H2`D05@L501<5100A1@D04PH601@8200B1PH050P701@91`0@1@4040D2
01<71`0B1PP04`L901@82P0C1`T040@60555A`1ODeD05P/<00T0000I3@l03@4301041P0E2@/03P<4
06eQH`0Z7R003@4300H03`<500D0:1`N01lC5@0B1PP05`/=01lC5@0301451`804PH80P0C1`TDoooo
o`006oooool;01<92P060189300>20`040/@00h93P0?2Pl04PdB0`0@2a001@0D3a@08alS01lJ7`0?
2Pd050X=00<050T=0P0C20`0300M4QH05``@01462P0E2Ph03`@801D:3P0D2P/05@/<01P>3`0K4A80
5`d>01D;30804PP90P0C2@X201@:2`H04`T:01L050X;00`20`0Q5aP040L801X@4@0E2@X050H70185
1P0D20T05PX;01D:3@0B2@/05@`@014;401?BDh071LL00d93@15@4<03PP800d71`0C3@d03`T9018<
3002014;2`8040X:00<04@/;018<300C2P`00P0D2@d02`0B1`/05``@01P=4@0E2Ph060dA01D:3P0a
9bX08AHJ00T00P0H3A405@X>00805P/?0P0G31000`0C20`050T=01D:3P0201<8300E01@:3P0J41P0
5PlF01@>4P0A2`l040X>010:300B30h050h@01H@400C3@d04@/;018=2P0M5aT0>C<e01<=3`0I4aD0
40X<014;3@0D3Q005@lA00805Q0B0P0E3a40200J51@05a4A01<=3@0@2PX04`d=01D?3`0B30`04`d=
0P0E3`l201@>3P80510?0P0?2`X0900G4a806QHE04M3@P0`;2/06ADD01<?3P0E4A0061@C01/G5P0E
4A005Q8A01PD4`0G4a806ADD01hJ6@0A3@`07QXI02@P7`0I5A@061@C01HE4`0G5Q@04A0>01PG5@0E
51805aHD01PG5@0F5A<05aHD01TH5P0H5aD05QDC01TI5`0H61H07AdK01hN70<061PF00l05QHD024Q
7`0K6aT06a/I02/[:@0O6aX05QDC01TH5P0O7Q`06QXH020P7P0J6QP071hK02DW900R92400P0M8Qh0
CP0S92H07AhP024R900T9BL08RHY02DY;010ADT06b0T02@Z;`0L8bT082L]024Y;00Q:B/08b/]02D^
<00W<C809c4c02<]<01OJVh0H6ia02@b=P0[>3h0;CY002`j?`0Y>3d0;3]002dl@@0X=c`0;3]00391
AP0hAd`0>dY?03M6B`0hAd`0>dY?03M8C00eAd/0>D]@03i?EP0hBE00=TM@03a<F00jBUL0=DED03i>
GP0iBET0FFUj05AON`18Dfl0CEUc082<X@1RKh00B5IR04ABF`12DEP0BUUN041?E011D5D0AEAK04ED
F@17EU/0BeUQ04iLI`1@GV/0D5e/051MKP1=FVT0BUQT04]IHP1<Ff80C5]O04]JG`1>GF80BeYO055P
I@1;FUl0EFAY05MVJ`80EVEZ0300FVU^05a[L01LJg00EV=Y05m/LP1HIF/0GV]a05aYK`1JIfd0IW=i
05m/LP1VLgT0H6ec06AaM`1VM7L0JWEi06E`LP27TYD0GVU]06]fNP1XLgP0KGQn07=mQ@1fP8T0NhF>
08>=UP21RiD0Vj6_0;[0c`23RIL0NX2<08jEX021R900PhZ@08:9SP1mQHL0Nh>507b5Q01oR8L0NX:4
07j6R023Rhd0QXj@08F=S`24S8h0QHf?08R@TP27Si4208::S00>08>=SP1oRHh0P8^?07j9S@2AW:00
P8^?07N2QP1mR8`0O8N;07f8S01kQXX0O8N;08:=T`1oRI<207n9TP0E07n:T01oRXh0OhZ<086=S02M
ZJL0QI6=06YgL01RKfL0KW]c06MdK@1/NG00L7ed06QeJ`1ULfH0GFYO05aYG`1LJF80GVYV05m[J@1`
O7`0FFMU00<0GVeZ00D0I7=`06=bK`1OKV/0FFQU05MVH`0205YYIP0^05]ZI`1LJf`0Gfic05YYKP1F
IFX0DV5V04aKH01BHFH0Df9W059QIP1:FEh0AeIK04aKH01MJVd0BeIH04A@D01>FUL0AU9>04YEC`15
CdX0>dE003Y3@00k@T80>3m103Dj?@0`>CD0=Chi02lh=P0`>3/0;C@j02he?P1<DUh0<CM303@kAP0`
=cl0>D16030f>`0^<S<0:bl^02P];00Y<S40:S<b02H`<@1NJ6X0AU1B02dd>P80;c@j0240:R/d02hd
=`0[=3<0:S0`02P/;@0W:b`0:R/]02DV:00W:2X09BTZ01lU9@0Q:BP09S0_024Z:00W<2d0:C8`028[
:@0N9bD09c0^02</:P0V;bl08b//028[:`0S;2`07RLV02DY:00P8b80;2h]02la<00U9RH08R8R020P
800Q82000P0Q7b00100R7b008alP024P7P0O7Q`201hM6`0>020O7@0Q81h07ahL01`K6@0N7A/07A`J
01PG5@0G5Q@071`L01LG5`0N7Qh061PH02DU9@0L71`301PH600I018B4P0K6a/061PH01PD4`0N6QT0
8alN01HB4@0Q7A`0510?018>3@0N6QT0510?01<?3`0N6QT0920P01XF600K5aT06ADG01DA4`0C3`h0
510?01HB3`0E4@h05Q8>01PD3`0201LD400A01@C4@0A40h04a4?01HB4@0F41006Q8C01/B4`0G3@h0
5P`=01dB500M4A<05@`=01PB4P0K5AD091hN01LA4@0>20P00P0D3Ph01@0B30`0618B01TC4`0@2PX0
50d=00805Pd>00h050d=01<=3@0B3@`05A4@00l>300<2`T07A`J06=SH@1kO7T09R4Q01P>3`0_9BH0
91XK00h41@805@/<0P0F30d01@0E2``050X;01882@0I3`h05`d<00<05@/:01@04`T801P>3@0H3Pd0
4`T801471P0E2`X050T801d?300:00005P/801TA3P0B3@X040`:014@301?CTT0f]SA04=0=P0A3P<0
4Pd301<91`804`L701404PH601<71`0D20P05@T901H:2P0C1`L04PH601D92@0J3Ph05@T901L;2`0B
1PH04@D501@8200B1PH05@T901<71`0201451@0801@8200E2@T050P:01H:300H30h050P:01041P0F
2P`201<72@060186200A1@L04PH80186200?0`D050P:0P0A1@L0300C1`T03P8404<g>@0L4A80710B
01D92`0@1@H040@601<72`0B1PX04@D901862P804`L;1P0B1PX04P0C1`/050P<01D93@0E2@d04PH:
01452@0G30l05P`>0104200?10L06`lC01452@1jKW808ADI00l51`0<0P@05`/?01@:30T04PH:00<0
4@D90104200B1PX00P0@10P0400C1`/040@80104200C20/04@D700/00@0E2@/02P0102`P8P1:?T00
4`L901041P0^8bD0B3`n01P<3P0A1PP501451`0701041P0P51H0;R8T00l51P0H30h04`L901851`04
01<41`0401451`0B20T04`T:01<92P8040L800@050/<01H:300E2@/04`L90P0A1@L02@0B1PH04PL5
00l40P0A1P@050T501870`0D2@H060`<01D92`0201041P804PH800`05@/<01@82P0C1`T06@d?00h4
1@0C20T02`4201H<3@0G30h0LFEW03<X:@0=0P<601451`0501L;3@0A1@L03P840186200D20X00`0A
1@L2018620804`L95?ooool001_ooooo2`0C2@X03P0B2@X07ALK018=4@0P6al07aXN014<400M61`0
50lC00h93@0?2Ph061<G01@?4`090`L04`T<0`0E2Ph03@0C20`04PL;01/@500F2`l04@H:01H;3`0B
1`/060dA01D;300F30d05`d>01P>3`0D2P/00P0C2@X201@:2`<05@/<1P0C2@X06@0A1`P03083028H
6@0K4A806@l@01H;3@0F1`X04PH:01L;3P0G2`l05@X>01/A5@0800805@lA01hH6`0F41806aHJ00/7
1`0:10@03`T9018<300<1PH04@/;018<300A2`/00P0@2PX05`0A2`/04P`<01882`0D2@d05@X>01@9
3@0G31005P/?01P=4@0=0PH040D9028G6`0E2Ph03`@801<8300D2@d05P/?01L<400H3A406@hB01<8
300D2@d05@X>00804`P<00L050X>01H<500C31<04@/?010:3P0A2`l05@lA00804`d?00X04`d=018<
300A2`/04@`905==C`1FD58050h@00P210090`D06Q@F0P0E3a4201H@4P805@lA00P0618B01H@400C
3@d04@/;01<=3@0E3`l050h>01<=3@804P`<00l050h>01H@400>2PT05A4@010<2`0>2PT061@C01dI
6024P7l0G5QG02LS8P0F4Q4061@C02@P7`0L61L00P0D40l02@0E4A005Q8A01XF5@0e<C00920O096=
S02FTY4081`K01DA4002028Q7`0S01PG5@0K6QP05A@B01TH5P0J6AL05aHD01PG5@0J6AL06APF01PG
5@0J6QP061PF01`L6P0K6aT061PF01XJ600L71X04Q8@01TI5`0F5Q@0;Rh/05=CD@0T81l0:BPV010?
3@0Q81h05QHD020P7P0N7Q`06adJ01lQ7P0S9B8082DQ01dR7P0U9RP00P0N7b401P0Q8R@0720S01XN
8@0C61`0:2da02<Y;P807bH/00l07BDX028Z;00U;Bl0:34c02Pb<`0W<C<09c8e01hY;@0F92L0;3Tn
028_=@0L:Bl0;3Y002Pg?00[>Sl00P0/>d008P0_?T<0=DA902hm@P0gAT/0DF1U03i=DP0c@TL0=TI;
03E7B`0fB4`0>4U?03Q9D00jBe<0?4eF03Y:E`0gAeH0?TiN03e=G@1PL840JWJ@04aGL`18E6d0IW>6
04UFIP0iAe80DEmX04IEG011D5D0>4M<03e<D@13DUP0AUEH04UHF`1=G68204iLI@0A04iLI`1=FfH0
C5YU04UGH@17EUd0AUEJ04IEF011D5D0CUeR04]JG`1?GV<0D5mT06MfN`1@Gf@0FFQ]05YYKP1GIV/0
0P1OKW<0FP1DHFL0GFY`05aYK`1RKgD0FVM]05QUJ`1SL7H0G6U_065^M01NJg40IG9h06AbM@1ZMGL0
JGAf096LWP1^NGd0JWEi06mjOP1^NGl0LWb407N1RP1lQXl0PXbE08:<UP1eNhT0QXbJ0826TP24RYH0
QHbE08N>UP29T9H0PhZ?0828R`21RH/0PHZ907b5Q01nQXP0PHV;08>;S@24S8h0PXZ<0869R`22RX`0
QXj@08F=S`20R8X0OhN9082:S025Si80SiZN07AoP`25T9@0Mh:608:=T@1kQXX0NXF908>>TP21S900
RYFI09bWZ`1kQXd0O8J?07b7S@1mR8d0OHR:07b7R@1mRHP0OHV506ijMP1ZMg00H6eV065^I`1SL6T0
FfQQ06IcJP1PKF<0GF]N05]XG@1@GE<0C5UB05]XH`1AGE/0Hfm_05aZJ01IJ6D0G6]X05m^J`1RLFh0
GVeZ05MVH`80Df9O00T0FFQU05QWI01FIF80FVUZ05e/L@1EI6T0DF1U04aKH01:FEh00P1CHVL0B01A
H6D0AeIK049AEP1:FEh0G6U/04]FF011CDd0AE5@03i:AP0oBT@0@D]503]4?`0]=S@0;34d03<h>`0n
@dL0>44n02Pa;P0T;B`0>d=603<j@00c>T<0<SU303DlAP0e?4D0SiJL0;c3b@0i@4<0:bl`02HZ:@0W
;2/0:c@c02Xc<P0W<C8072HX02H`<P0_=S`09R/a020U:`0];cL0:Rlb02Pa<00W;Bd09BTZ02DV:00T
92H0820R02@T9P0T9RP0728R01hV9@0W<2l0>T=2028[:`0U;Rd0:c<e02</;00U;Bl09Rh`02<[;@0M
9BL07bLY02Ta<`0e>Sd08BDV01dP7`0S9B@09BLV020Q800P82007alO01lN7`807adN00@081dN020L
7@0N7A/07A`J0P0K6QP04@0M71X07QdK03Th=P0O7Q`06QTG01/J600G5Q@08b8P01<C4`0?3`l06QXJ
01LG5`0N7Qh0820P01/K6`0D51@07AdM00806a/K02X05QHF01/G5P0K5aH06ADD01XF5@0K5aH081`K
01XF5@0A3@`08AdL028N7@0C3`h06aLF01DA400H51D061@C01LC4`0G4a8061@C01LC4P0D40l05A4>
01LC4@0E4A004`l>01<B400@3`d04a0?01DA400F41005Ph?01P?400H3Pl05`d>01/A4P0J3Q006Q4B
014;2`090`<040X:00H0000<1PH2020J6P0501D?3`0D3Ph05a4A018<300F3Pl00P0E30d0400D3@d0
4`d=01<=3@0@2`X06QHE00d<2P0Y:2H0i^KT0?Kfm00j=CD05P`=03X`<@0X7Ql02`4201D;300D2P/2
01H<3@0L0147200@1PL05@/<01T?3P0G3@`05@/:01@:2@0C2@P040H501X@3`0F30/07A<B01X@3`0_
9B@0;28Q01050`0H3@/060l=00d81@0810<03P/:00P71@0S8Qh0?cXg00d80P0F3`L04`/701@91`80
4`L701H04PH601<71`0D20P05`/;01D92@0A1@D040@401@8200I3@d03@4101451@0@10@03`<30145
1@0D20P05`/;01D92@0D20P05PX:01D92@0A1@D03P840P0B1PP00`0?0`D0710B03DY:`0201<72@08
0186200@10H04@D70186200G2`d04@D700d10`0@10H201H:300902TM7`0>0P@0200000/10P0D20X0
4PH801@8300C1`/04PH:00<04@D91P0B1PX601<72`0>01D;3@080000300401P<400<00@04`L;01`@
500900404`L;01H:3P0N4QH06`lC01452@0C1`/201@8300601452@0B1PX05@T=01H:3P0G2`l050P<
0P0B1PX201<72`0@01@8300C1`/04`L;01862@0B1PP0300201D92`0B1PP02@000186200K3a4060`>
01451`0@10H0300201H:30D04@D700L050P:00`00P0F2P`05PX<01D92`0:000050H900@04`@700P0
4@D70147200B20T04PP900h51P0=10D03`H701@82P804`L900d04PH801451`0A1@D05``:01<81P0B
1`D04PL300l4000A1P<05@T901<72@0@10H04@D700804`L900<09QXL028F600>10D00P0>0P@01`0F
2P`060`>01P<3P13=cT0300200`20`0Q5AL01P0A1@L01P0E2@/040@601P<3P0H30h04PH801T=3`80
4@D70P0B1PP201<72ACooooo000Kooooo`/04`T:00l04PT:00@00P0D3a80DD]?04m9C@0C3Q402`D9
04Y4B00I4aL02P@800P21P0600@03@L;00h41`0B1`/00P0E2Ph02@0A1PX03`@801@93@0C20`04PL;
01L<400A1PX05P/?01D;300201H<3@0301D;300C2@X04`T:00804`T:0P0D2P/201D;30L04`T:01H0
3`D602/Q8P0^92D03@<401T>400A1@T03`8901862`0>0`L03`@801D;3P0<0`H01P00014:2`0F4100
3@L901H?3`0=10D04`X;01@;300?1PL05@`=0P0D2``01@0C2P/04PT:01892P0C2P/04`T;00805@X>
018050T=01H;3`0F2`l060dA00d21P0C20`040L901052@0I3Q803`@801@93@0E2Ph05P/?01L<400I
3Q804`P<01@93@0E2Ph201<8300901@:3P0E2a<04P/B010:3P0?2@d04@/?01D?4@0D3Q004`d?00<0
4P`<00D04@`9030Z;00W8B<050h@01H@4P0201<=3`H05@lA0P0B30`401D?3`0A01H@400D3Ph04P`<
01<=3@0E3`l0618B01<?3P0D40l06QHE01LC4P0>2PT04@d<01TE500H51<01000014=300<20L00P0I
5A@00`0D40l05Q8A01PD4`0201HB4@0=01@@3`0J5QD0=S8a03Xf=@0O6aX03`/:01HE4`0I61H05A@B
01XI5`0C4Q004Q4?01XI5`0201PG5@0:01/J600I61H061LE01/K6@0I6AL06a/I01XJ600I6AL07AdK
01PH5P808R8P05T05aLE01`L6P0Y:BL07ATH02HU8`0H5aD081lM020P7P0T92806ATG02<U8P0N81d0
61XG01`Q7@0U:RH07QlQ01dN800P8B<0:BX/02X^<@0X;2l0:2da01DJ7P0[<CH08BP^01lV;00Y<C@0
9Bd_02L_<@0Z<cD0:S@e02Pb=00W<C@0<ci203A2A@0[>Cd0:3Dk02/h?P0/>T00:CPm02Xi?P0[>Sl0
;Se20350A@0eA4T0;Ca103Q7C01CHVL0>DQ=02hm@P0fAd/0=TQ<03Q:CP0gBDh0>DYA03]<E00gB540
=DI@03M7E013Df40A5AS05m_P01ULHT0Q92Z03a8G`1?G6l0AeAT04QFH@1DHV/0AeIM03m>D`0gATd0
?TeD04EDFP17EUT0BUUL04eLH01;FUl0BEQO04YHH@1?GFH0CUeT04eLHP1:FEh0BEQK04YIG01;FUl0
EfI[04eLH@0204]JG`0_065`M@1@Gf@0FFQ]05UXK@1FIFX0G6]`05YYKP1IIfX0GVa_05]YK01PKW40
F6IY05YXJ`1NK6l0FFMZ05i/K`1MJfh0IgEh069`L`1QK6h0I6ma06mjO01lQhT0HVe`079mP@1^NGl0
M7n507b7S@1nR940P8ZC08:<U@23RID0PHNC08bBWP2AUj<0Nh:;0868T024Ri40PHV=07j6R@1nQXP0
P8R908:;RP21RH/0Ph^>08B<S`23Rhh00P21RH`0:`22RXd0QhnB08J>T@21RH`0OhN:07n9R`26TI<0
TijP07N2Q027TY@0N8>508>>T01nRH/0NXF707n:S01hPhD0O8N908fHW01iQ8X0NXF;07^6S01kQX/0
NXF707V4QP1hQ8<0P8b807R4P01VLf`0JWM`08^HT@1iQX00GfaU06IcJP1PKF<0GFYP05aYG`1dPGL0
FfQQ05QUH01FHV00EV9R05]XI`1FIF800P1GIV<02`1JJFH0EVER059QGP1AH5d0Df9O05UXI@1GIV<0
E6=P05QWI`1DHfH0BEQK0080E6=V02P0AEAG04aKGP1BHF@0CeiQ04]JG@17EUT0AUEH04ICEP12CDl0
AE5A049=C013CTX0A4m903Y4?P0a>SD09R`[02P]<00e>Sd0AT]?03Hl?00g?C/0:S0`030e>@0d>Cd0
=SY203LkA00c=d00;c<l07b1Q`2Y[[@0;C8e02X^;`0T:2T0:2d^02hg=P0]=SD0:cDf02dg>@0Z=3H0
9Rha0P0[<3H07P0U9bd0:c0c02Tb<@0[<C40:2`]02LX:P0U9BL0820R02@T9P0V:BX08RPX02D];00/
=C@0GF9U02db=P0N8bH092T]02H[;P0]<SH07R<W02@Y;@0X;C409R/_024V:P0P9BP082@U01hQ800P
8R408B<R01hO7`807alO02`07ahO01lM7P0N71d07a`M01lK700Q81h07ahL01`K6@0K6QP071/I01dL
6P0j>CL06QTG01LF500M71X071/I02<R800L71`06QXJ00`<300M7Ad04A4A01lO7`0J6QX0;2`/02DU
9@0A4A405aLG01@D500J5QD06ADD018>3@0D40l03`/:01XF5@0H51<07a/J00`81`0E4A005a<B01HB
4@0E4@l061@C01PD4@805a<B00H06ADD01DA400F4Q405A4@01<?3`0D414201DA4008018>3@0D3`h0
5Q0@01D?3`0F3`l06Q4B01P?400E30d201T?400901@:2`0=1`L0:28R04@n?P0U7al04P`<00l92@0J
51@05@l?008050h>00D040X:01D>3P0E30d05@`=01@=3@0201<=3@0?018=3@0G4a804Ph=02<R801/
JfT0NGQf02<L700E2``07aDF01T?400>10D04@L801@:2`0F30d05@/<008040H700@05P`=01H<2`0E
2`X04`T80P0D2PT0500B20L04@L600`20@0?1@@01`0001P>3@0B2PT05`d<030X9P0T7A`0>cDg00l;
300A3Pl03`/<01<?3P0Q71X0610=01/B3@0?1P<050T70P0C1`L01`0B1PH04`L701@8200F2PX050P8
01861P0C1`L00P0D20P201861P0601D92@0G2`/050P801451@0D20P05@T90P0F2PX02@0B1PH03@41
01@82P0F2P`05@T;01041P0E2@/0:AdO01041P0200l31@0B01451`0@10H03P8401H:300B1PP04@D7
0186200D20X05@T;01X>400G2`d06@d?01P<3P0Q5AL07Q8D01@8300C1`/04PH:0`0A1@T601862P0D
01<72`0@10P03`<701862P0F2Ph060`@01/?4`0H31005@T=01<72`0=0@D05`/?00d31@0?0`L05@T=
00/10`0<00@03@4501452@0C1`/201@8300801452@0B1PX050P<01@8300C1`/040@800l31`0B1PX5
01D93@0400l51`0F2P`060`>00d10`8050P:00L03P<400d10`08000050P:01D92`0>0P@03@<400D0
4@D700L03`<502TM7`10=3H05@X;01<72@0A1@L04`H800@04`@700L04@D700h41@0?1@H04@L800h5
1P0=10D03`H700@04PH800<04@D701451@0F2`T00P0B1`D05@0C20@03`@001460`0?0`<03`<50104
1P0D20X05@T;01@82P090000710B01041P0d:2X07A4C00/10P080000710B02dQ8`0K3a4040H701T=
3`0601451`0601<72@0@10H060`>01D92`0=0@<05@T;0P0A1@L2018620804`L95?ooool001_ooooo
2`0C2@X03@0B2@X07A@G00/5200D3Q404P`?00d72P0Y8bH0M6ia020K7@080PD050hA00h82`0B30l0
0`0D2@d0300C20`040D900l4200D2@d04`P<01462P0E2Ph03`@801<8300C2@X05P`=01D;30804`T:
00@05@/<01061`0A1`P04@L80`0B20T601<92P805P`=018081HG01@;2`0J41404`L=01863P0C1`l0
5@T@00l42P0H3A<07Q@G01L?3`0F3@h04@X9018;2P0D3@`04`/;00l61`0C2P/201892P0401L>3`0D
2``050/<01<:2`804PT:00D04`X;01<9300F2`l05@X>01872`0201H;3`0301<8300L4AD06@hB0080
5@X>00<04PP;01H;3`0C20`00`0E2Ph0100F2`l04`P<01@93@0E2Ph201<8300401@:3P0F31@050dD
018<408040X>01H04@/=01D?4@0B30h040X:014;2`0B30`04@`901@>400>20X04@/=01@>400A2`d0
4P`>01D?4@0D3Q004`d?018<3P0C3@l05@lA010:2P0A2`/05@l?0P0F410301D?3`0S01<=3@0D3Ph0
5Q0@01LA4@0G4a404@d;01/G5@0T81h08AdK01PD4P0E4@l06QHD00h:200K5aD05a<A028N700G4a80
4`l>01PD4`0I5A@05A4@01@@3`0@30/061@C01`H5`0M6AP06QHE010<2`0G5Q@06APF01/J600X9bD0
8B0N01`K6@0J6AL00P0H5aD0300J6AL06APF01PG5@0K6aT06ATG01XJ600H61H06ATG01lO7@0M7A/0
92@R01hN70806a/I02D05aLE01hJ6@0B4@l08R4O038a;`2k^kT0;bl]02<S8@0J71T05ALD02@V8`0T
:BD07b@P028S9@0V9bT08R<U024R900Q9BP082@W024V:P0W;3007bDZ020W;@0S:S00:c<f02H^<00W
;c40:34c02Pb<`0X<S@0:C@g02Xe>@0Z>3/09cDi02Tf?00[>3h0:CLl0080;Ca10300;3]003=2A`0d
@dP0=4=802ln@`0b@DH0?TeB03A3B00b@DH0=dI;03Y;CP0oCe<0?TiC03e=D`0lC5<0?4]E049AG00o
CU/0AeIT04EDH`1BH740?DUP05]WO`17E6P0>TMH04eKJ@18EV00CUeT04EDF`16EEX0@e9I04YIH01D
HVT0AUIG04UIF@1:FU/0AUIG04IEF@1;FUh0AUEI04QGF`1:FE`0B5QI04QHF01:FUX0BeYM05=RI`1<
Ff0204mNH`0405MVJ`1FIFX0EVEZ05QWK080FVU^02D0EVEZ05YXJ`1IIfX0EVAW05aZK@1FI6L0GF]^
05i/K`1KJF`0H6ia05m]L01XMWT0GF]^065/KP1SKVl0GVUZ07R3Q@1WLWD0MH23071kP01iQ8X0PHbB
07n9T@23SYD0TijU08N=V022RI@0P8N@08ZAVP26SID0PXV?08B;T@26SY80QXjA08F=S`26SXl0RY:D
00<0Q8b?00@0Ph^>08::S@22RXd0Ph^>0P29TI@02023Rhh0PHV<086;S@1nRH/0QI2B08>>T02?VY`0
O8N90P1fPH<08`1eP880N8>507F0PP1gPX@0OHR:07R3R01iQ8T0NXF807R3QP1eP880M82006ijN01d
P7`0LWij06=`JP1ULV/0Q96:06ahM01KJ640H6eV05i[H@1PKF<0GFYQ09:OUP1dPGX0F6AQ06=_K`1N
JF/0GFUZ05]YJ01FIF<0Df5P05UWIP1KJVP0EfIT0080DV1O08<0F6IU05ARH@1AGeh0CEaL05=RI@1D
HVD0BEMJ045?DP1JJF`0LH2305UWJP1@GV40BeYM04QGFP13DUD0@DiA04MAD`1>FE/0A4m>041:B@11
BdL0=Slk03@k>@0`=SH0;c<f02hb=P0]<CD0<CLh05=IF00n@dH092T]03<h?00b=c`0=CXo030e>P1]
LWP0>d1502L/<@0_=3P0;c0d02DY:`0[<340<S/k02hf=`0/=SL09S0b02dg>@0^=ST092T^02DZ;`0/
;C<092T/02D/;00X;2d0:2T[02DV:00Q8B<071/N01hN800S92H09RX[02L];@0U;2h09R/`02DZ<00X
;C809R/b028W;00V:c0092T^028W;00S:2d08RL[02H[;`0c>3/08BDV028U900R92<08B<R020Q8@0P
82008B4Q024P8@0P7Ql07adN01lL7@0O6a`092<Q024P7P0N7A/07A`J01hM6`0O7Q`08B0N01HE4`0H
5aD07ahL01hM6`0K6QP09B@U02h];P0@3`l071/L00h=3@0M71`061LH024P800J6AX07QdM02HU9@0C
4A806ADD014=300B3Pd071PG01TE500G4a805A4@01/G5P0O6aX0?CTh01DA400G4a4061D@01XG4`0I
5Q805Q<?01DA3`0F4Q005A4@01HB4`0201HB500501LC5@0H4aH05A0@018=3@0D3Ph00P0E3`l02`0D
3@d05Pl?01L>3`0C2P/05`h?01P?400H4A403`T901D?3`0N6AT04P`<008050h>00T0618B01@>3P0E
3`l05@l?00l92@0D30d050/<01D<3@0D3@d00P0D3Ph0300A30/05a8A010;2P0J5AD05A<A01dH600D
3@h05P`=0147200D2P/060h?01H<3@805@/<00D050X;01<92P0D2P/05@/<01@:2@0201<9200501@:
2@0E2`X050X901<9200D2PT00P0C2@P03`0G3@`050X901@=300K5QL071PI07QcM`0D4AD03`dA01D@
5@03004091`N00h51@0<0P406`d;01@9200201<71`0401861P0C1`L050P801D92@8050P802/05@T9
01@8200@10@05@T901451@0C1`L050P801451@0D20P040@401@8200C1`L040@401861P0I3@d05@T;
01<72@0F2P`05`/=01<72@0D20X05PX<01<72@0H30h081@F01lC5@0B1PP03`<501<72@0H30h05@T;
01041P0F2P`08ADG01451`0>0`@04`P901H:300=0`@04`L;01862P0A1@T04PH:00804`L;1`0B1PX2
01452@0;01<72`0F2Ph05`/?01D;3@14>3`0Qg]o04Hj?P0900406`lC01D93@0=0PD00P0D20`00`0I
3A404PL:01862P0401862P804`L;00<04PH:01<72`0C1`/00P0D20`201L;3`0401<72`0G2`l05`/?
01@82`8040H700X04@D700h3100@10H050P:01P<3P0>10D050P:00h3100H30h04PL81@0A1@L01`0B
1`P040H701X?400D2@X04@D700T0000C1PP0100C10L01`0A1@L0308300l51P0B20T03`H700h51P0@
1`P00P0A1@L0700B1PP04`L90186200A1@D040D300h30@0C20H05P/701<8100C20D04@D501041P0A
1@L050P:01D92`0D20X04PH80147200F2``0:1`N00X00@0F2`d06@d?00X00@0E2P`02`0101P<3P0;
0@8601451`0301<72@0D20X04`L900804PH80`0A1@L2018620804`L95?ooool001_ooooo300C2@X0
7`0C2Pd06aDG00/51`0500404@/=00h82P0E3a403@P9010:300B30h040X<01L>4@0U6Qh07A8F01L<
400D2@d05P/?01P=4@0D2@d040D900d21P0C20`04PL;01X?4`0A1`P05@/<01@:2`0B20T04`T:01H<
3@0B20T00P0C2@X301@:2`H04`T:01X040L8024G602HSXl08ALH00l51P0B1`d03P8<01873`0D2A40
3P<;01lD6P0R61/05Pd>00T1000D3@`06A4?00d50P0F3@`03PD60107200?1PL04PT:01L>3`0B2@X0
5@`=01<:2`<04PT:00X050X<01L<400E2Ph040D901@93@0F2`l060dA01@93@0@1@T05``@0P0>0`L0
100H3A404`P<01<8300C20`201872`0301<8300D2@d05@X>00804`P<01l050X>01063P0?20l04@/?
018<400C3A404`d?01H@4P0B30h03`T9014;2`0B30`040/800@0000I4aD04@`=00/51`0:10H05@lA
01<=3`0B30h04@/=010:300A2`d04`d?01H@400E3`l050h>01<=3@0D3Ph05@l?00804P`<0P0C3@d2
01@>3P0U01dI5P0E4@h02@D201XF4`0/:2D04@d:00h:1`0A3@X06QHC01HB3`0H51404`l<01PD4`0C
3`h05A4@01LC4P0E4A005Q8A02PT8`0A3@`06aLF01hJ6@0D40l08AdL01LF500B4@l04A0>020O7@0J
6AL03`h<01dL6P0K6QP071/I01hM6`0M71X06aXH01`L6P0201XJ600I01HF500I6AL08B4O01dM6`0G
5aD05QHD01TI5`0G5aD051@B01lK6P0T8b4071/I024P7P0E5A<0:RXX01hN700O8Ah051HC01XL6@0P
9B4092TU02HW:@0_<3809bPZ01lP8P0201lS9P06028W:`0I7R808bT^01/R:00D6b409blb0P0T;2h0
1`0T;Bh092h_02H`<P0Z=CP09C0d02<a=00Y=c/00P0b?dD01`0[>Ch0<T560391AP0_?T<0=dI;03Q7
C00fADX00P0iB4d0:00mC540?TeB03M6B`0c@TH0?4]>03]:C@0gATX0@4mD04IEG013DUX0?TaG03M5
DP14DV00Cea/065^OP1<F6h0Ae=Y04AAH`19EVH0EF=^04]JHP0mC5<0>DQ?045@E@0oCUD0AEAK04iL
I014E5@0AeMF04QHF014E5@0AeMG055QH@13De<0AUIF04]KF`1:FUX0Be]K04mOGP1<Feh2059QIP0I
05YYKP1FIFX0C5]P05i]LP1EI6T0FVU^06EdN@1OKW<0G6]`05m]L01KJF`0F6IY05aZK@1CHF@0FfU/
05i/K`1MJfh0H6ia05i/K`1TLWD0Df5R069^KP1NJVX0KGUi05UTIP0206ehNP0B07=nPP1lQh`0PXfC
07f8SP29U9X0Z;>i08^BVP1mQ8`0Q8^C08nFWP22RHl0P8N=0869S023Rhh0QhnB08R@TP25SHl0OhN9
0P24S8l208>;SP80PXZ=00T0PHV<08N?TP27Si80PHV<07j6R@1nR8X0N8:4086<SP26TI<00P1dOh40
101fPH<0LWeo07F0PP1dOh4207V4QP0U07AoP@1hPhD0NHB607V4QP1fPX<0LGem06mkN`1`O7X0O8R4
079nNP1WLfl0FfQQ069_J01JIV80HViZ06EbJ`1HIEd0F6EL05MTFP1RKfP0G6QT06EaK`1JIVH0K7Mi
06QeMP1DHV80C5YJ04IDE01BH600FVQX05UWI`1AGel0D5iN05ARHP1@GUh0C5YJ04eKG00204mMH00c
055OHP14DUD0@e5D065_LP1RL7<0DV1S04ABE@11Ce80@e5D04MAEP0lADX0@4Y<049<C@0g@D00>dA3
03U0?P0d>SP0=3Xk03@g?00a=3T0:bhe02db=@0Z;c809b`_03Pm@@0d>Cd0;S<f03Hk?`0_=3L0;S<g
03Dj?P0`=CT0A4Q<03<d>00X;2l0;C4d038j?00Z<S@09c4b02D_<00Z=3D0:S8e02P]<@0Z;c<09BP/
02@X:@0U:b/0:Bd^02//;P0X:2X0928U00808AlR00H09RHX02``<@0Z;bl082DX02X_=@0Y;CH2028V
;`0F02T]=@0X;C<08RL]02DZ<00[<3@09b``024V:P0X;C007B4R024T8`0P8R407R0O01hO7`0M7Ad0
8R8R024P8@0Q7b0081hO020M7P0P71d071/I01/J60806APF01D071/I01dL6P0O7Q`08B0N01LF500B
4@l06APF01`K6@0T8R<0=S@e02@R8`0E4a@06ALH01dK700I5aP07adN01TG600A3a007A/L01PF5`0G
4a800P0L61L0600C3`h061@C01HB4@0D40l06ADD00L30P0S7ah05A4@01LC400D4@/05a@=01PE3P0G
50l061@A01XF4`0I5A@04PdA01HA5@0O6Qh07APN01LB5P0E3a004P`<01<=3@805@l?00T050h>01PB
4P0L4a@060l@01L>3`0F3@h04P/;01TC4`0E3`l00P0D3Ph0200A2`/0<R`/03`f=P0O6AT04@/;01D?
3`0C3@d05Ph?0P0D2``01P0D3@d050h>01@>3P0D3Ph06Q@D00T30`804`d=00H05a4A01@;300>10D0
6@l@01P>3`0C2@X201H<3@0N01<92P0B20T05P`=01L=3P0D2P/05@/:01@:2@0B20L04`T801@:2@0A
1`H03P@301L=300A1`H06Q0?01881`0A20P04@/=01DA4P0S7R80K6Y_02@R9`0V8bX020<901D@5P0@
1`/07a<E00l10@0C10@05PP80P0C1`L02@0B1PH04`L701@8200H30`04`L701451@0C1`L050P80145
1@0201861P0G01D92@0B1PH060`<02hR8P0C1`L05PX:01861P0>0P806`l?030T900]8B<05`/=00l3
1@0C1`T05@T;01<72@0D20X03@4301L;3@0U6A/08ADG00d10`0A1@L00P0@10H02@0=0@<06@d?03@X
:P0W6ad05@T;01451`0?0`D05@T;00l31@0301452@0301<72`0D20`050P<00H04PH:01H04@D901D9
3@0G2`l05PX>01452@0>0PH04`T;00X00P0H31004@H9028F6P0?0`L05`/?0104200D20`04PH:01P<
400@10P050P<01452@0@10P04@D90P0C1`/0100B1PX04`L;01@8300B1PX20104208050P<010040@8
01@8300D20`04PH901<72@0G2`d040@601451`0E2@/03@430186200:000050P:00h2100V6Q`05`/=
1P0A1@L01P0D20X06`lA00P0000E2@/04@D701851`@04`@700D04@D700h41@0@1PL04`T:01072002
00h51P0A00l31@0@10H04PH801<72@0B1PP04@D50146100@1@<05P/901L<200A1P803@8001P<300E
2@/040@600l31@0A1@L00P0B1PP02`0C1`T0Ed]=01X>400G2`d04`L900d10`0K3a403@8301L;3@0@
10H06Ph@00H04`L900H03@4301451`0:0000300201@82P0<008201451`804PH80P0C1`TDooooo`00
6oooool201<92P804PP90P0A1`P01P0B20T050X;01@:2`0B20T04`T:01@:2`H04`X=02/071<F00h5
200>1@P06A0C01<:3@0E30l0IeaP01/@500F2`l050T=01`A5@0@1@T03`@801D:3P0A1PX03@8601@9
3@0I3Q804PP900h41@0I3a0040H701D;300<0P<050X;0147200>10D03@<401882@0F30d04PP90147
200E2``050X;01882@0E2``06@l@01@:2`0F30d05@/<0147200A1`d04@L@00804PP@00d040H>0148
3@0A1`X04@L801<9200F30/05@/:01<91`0D2PT05@/<01@:2`0C2@X04PP900804@L801005@/<01H<
3@0D2P/06a4B01`B4`0G3@l05@X>01<8300B1`/04`P<01D:3P0D2@d04PL;01<8300D2@d05@X>0P0F
2`l01@0D2@d05P/?01L<400C20`040D900804`P<0P0D2@d03P0E2Ph05@/>01<94@0B2a804`dA018<
400A2`l03`T;01@>400E3a404@/;010:2P0B30`03PT60P0E3a40:`0A2`d05@lA01/E5`0=1`T05@lA
01@>400B30h04@/=018<3P0E3a407aTI07QbLP0N61P04P`<00/51@090`<05a4A00l92@0E3`l04P`<
01D?3`0?2@T04Ph;01LD3`0H5A005a@?01HC3P0G50l03``701<@2`0E4Pd0514<01<@2`0C3``0510?
01DA400L61L020@301XF5@0K5aH05a<B01HB4@0I5A@00P0M6AP0AP0H51<04A0>01@C4@0I61H05QDC
01LF500Q81h071/I01TH5P0H5aD06APF01XI5`0K6QP061PF01hN700P81h05aLE02d]:`0J6QP07QhL
01XJ600D51806a/I028R800J6QP0<Bd/02XY9`0P7ad071/I01hN700M7A/07alM01hP7@0L7Q/06adJ
01/P700M8Qh08B8T02@U9`0Q8R@09BHX02DY;00P92L092T]028W:`0S:Bh08BP^01dT:P0O9bX09Bd_
02@/;P0T;Bh09S0a02/e=`0]=cX0:SDi03=1A00W=3T0=D98038oA@0/>Sl0<T5603=2A`0b@DH0<d97
03Q7C00iB4d0<3m403A3B00mC54203I5BP0J03]:CP0kBd/0?Te@03U8C00iB4d0@e9I04ACF`19Ef00
AE=N04=AG@0nC5T0[K[;04QEJ00lBE`0Cea^03Q6D`16E5l0@U5I04IEG013DUL0@4mD04IEG01<Ff80
BeUQ04QGFP17EeL304EEE00Q04=CDP15EE@0AEED04MGEP1<G5/0CUiM04mOG`1<Feh0CEaQ051OI01C
HVL0EFAY05QWK01BHFH0Df9W05ASJ01JJFh0GVeb05IUJP1LJVd0E69S05ESI01FI6D0Df5R05MUIP1L
JV/0F6IW05UWJ01MJf`0Gfe^05e[K01QKFd0Hfm_0080J7Ad00/0JWIg07AoP@1fPH<0NHB707b7R`1o
RXh0PhjC08JAU`2<Ti/0QHbB08:9S`0208>:T0090828R`21RH`0PHV<09FMW`2SZjd0Ri>E08B<SP27
Si80PhZ@0080P8N=00T0OhJ<07f4RP24Ri40PhZ@0827S@22RHl0P8N=07Z4QP1lQhP00P1kQhL0;P1`
O7`0K7Qh07=oO`1dP800LGem07N3P`1cOgl0N8B4079nOP1iQHD0LGem07^7Q`1[MgH0Kg]i07B0OP1^
NWP0JgMc06YfLP1YMG40H6aX05UUH@1OJfP0Gf]W05YWH01IIUh0EfAK051ME@1GI5d0FVIR05]WI@1Z
MWH0KWUk05m[K@1=Fe`0AeEF04aJF`1FI6D0F6IW05UWJ01HIVL0EF=T059PH@1<FU/0AeEF04A@DP1;
EUP2059MG`80C5MI00@0CEQJ03e8BP0lAdT0BeIH0P11C4h0>018DUH0@DY?0459C00k@dH0<CXi03Dk
>`0i?cl0;S@d038f>@0]<3D0<SDj02X]=019C5409BP]02`_=00[;c806QhQ03Lk?@0m@D@0:bl`02lc
=P0W:bh0<3@g03m3AP0a<SL0;C0e02X^<P0V;S409blb02Tc=00/=SL0;SPi03Q0@P0X;C008RLZ02LZ
;@0W:b`0:2h^02P/;@0Y:R`0:BT[01lM800L6Qd07A/N02DU9`0V:R/092TZ02P]<00o@T/0;2hj02h`
?00]<3T07B0Y020S;00O8RT07b8X0P0S9R/02P0Q9BP09BT/01`P8@0M81l06A/J024S8P0O81l08B4Q
01XJ6P0L6a`201lM7P0:024N7`0Q7Ah05QDC01XI5`0K6QP06APF01XI5`0N7A/04a8@01lN70803@`:
00T07A`J014@3P0K6AX05Q@E01<A4P0N71d01083028P8@0H5QL00P0F51D00`0I5aP07Q`M020N7`02
01/G5P0W01PD4`0J5QD071PG01DA400H51<06aLF018>3@0I5A@05A4@01DA3P0B3`T061D>01lL5@0J
5a806QHC014=2P0=2@P04`hB00l:3P0E41@050lE01<>4P0G3a405Pd>01L>3`0H3a005@l?010:2P0N
61P06Q@D014;2`0B30`081XJ010:2P0H4Q8050h>018<300N61P06Q@D00<050h>00X04`d=014;2`0@
2PX04P`<01<=3@0B30`07ALG02/U9@0S6Q/05@`=1@0F3@h00`0D2``04PP901<92P0201<92P0801@:
2`0E2``04PP901L=3P0F30d04@L801P>3`0C2@P201@:2@804@L602L050X900h40`0=0`805@/:01X@
3`0G3@`050X:00l92`0I51P0K6M]0?olo`1PGF@0514H00T42`0A31804@L<020D5P0D1PH05PL801L9
2@0I3@d04PH601L;2`0E2@T04@D504<g=`0j;Rh04`L701T=3@0E2`/04`L701T=3@0E2@T07A4A01/?
3`0E2@T07a<C01@8200C1`L00P0B1PH01@0C1`L050P80186200@10H04@D700805@T;01P040@60186
200I3@l08ADG01X>400?0`D05@T;00h2100G2`d04@D700d10`0B1PP04`L901@82P0>0P@04@D700l3
1@0>0P@050P:01862P0A1@T02`030104200L41@201<72`0?01D93@0@10P04@D901@8300C1`/04@H9
00h21P0O4aL03@8500d11@0E2@d04PH:01<72`0E2@d05PX>00805@T=1P0B1PX01`0D20`04`L;01X>
4P0B1PX03P8601@8300K3a<00P0D20`01P0A1@T03@4501H:3P0F2Ph04`L;0104208050P<00<04@D8
01451`0C1`T00P0E2@/05@0D20X040@600`00P0N4Q@04PH804a0@P1PE5H06@d?01D92`0A1@L040H7
01hB500H30h03@<401D92`0A1@L04`L901@82P0>0P@04P@701831P0201@5200F01D62@0D20X03`D6
01T?400?1@H07A@E01@;300B2@X040@601D92`0L41803P8401041P0@10@03@8002<H5P0H3Pd0Q7Ue
01/@300>0`406Ph>00P0008050P:00T06Ph@01061`0=0@<05PX<01/?4@0H30h05PX<00`20`0B1PP0
0P0A1@L00`0@10H04@D70186200601451`0<00d10`0C1`T02`0101`@4P0?1@H0300201@82P0E2@/0
200001L;3@0@1PL0710B5?ooool001_ooooo0P0E2``301@:2`0701<92P0B20T050X;01@:2`0B20T0
4`T:01@:2`0601<:300;018;2`0E30h040L902lV:02BRH/0DTU;01P=4@0E2Ph02@0201P=4@0=0PH0
0`0D2@d02@0B1`/04@H:01<8300D2@d05@/<01`B4`0J414050/;01482@020147208050X;00P04PP9
0147200B20T04PP90147200E2``050X;01882@805@/<00d04PP901D;300E2``04`T:01H<4@0F3Q@0
610F01H=4`0A20d040L<01472P0B20T04`T:00805@X:00<050T:01<92P0B20T00P0C2@X201@:2`0<
01882@0D2P/05@/<01@:2`0H3Pl06@l@01H;3P0C20`04PL;01462P0B1`/04`P<100D2@d401D:3P80
5P/?00@05@X>01@93@0C20`04`P<0P0D2@d0500E2Ph05@/>01D;4`0A2Q403`T=00h8300?2@d04P`>
010:300A2`d04@/;01<=3@0G4A405Q4>01D?4@0O6A/03@P901TC5@0=1`T04`d?0P0D3Q004@0C3@l0
4P`>01<=3`0D3Q004P`<03`f=P0D3Ph05a4A01PB4P0`:RX0618B01<=3@0Z92@0:B<S01H@400D3``0
5A4>008061D@01805A8=01<@2`0B3`X04Pl:01DB3@0G50l05Q<>01DB3@0F4`h05A4@018>3@0H51<0
71PG01hJ6@0P71/05a<B01HB4@0H51<201/G5P0601PD4`0G5Q@07A`J02<R800P7ad061LE0`0K6QP0
4P0J6AL06aXH01XI5`0K6QP06a/I01TI5`0L71X06ATG01`L6P0D51805QHD01`L6P0J6QP07alM01hN
700L71X07a/J024P7P807QdK02407QhL01`L6P0P81h08B<P020R7`0O8Ah07B8N01lT800Q8R@0824S
01`M7`0P8B<08bLZ028V:@0V:bl082DY024W;00T:c409bhd02H^<@0V;S00:30b02Pa<P0Y<c@0;CLi
02H`<`0e@4@072X]02`j?P0/>Cl0:CHl03I4B@0a@4D00P0b@DH00`0c@TL0=dI;03U8C@0203Y9CP0Q
03I5BP0mC540?4]@03E4A`0eA4D0>4I803Y9C00kBDd0?4YA03m<E00lBU<0EF9]03a9EP0f@e40E65`
041=GP17E6D0>dUH03m=F013DEX0?diE04]JG`17EU/0AEAI04UHG`1;FV40AeEM04QGF`19F5X0B5QH
04ADD`13De80A5AB0080B5QF01X0BEUH04]KF`1<G5d0CEaO04eLH@1>GF80D5mT05=RI`1DHfP0EFAY
05MVJ`1IJ6d0FVU^05m^L`1TLgP0GVea05ITI`1BH640Df5R05ESI01KJFX0J7Ig05aZJ`1JJ6T0G6Y[
061^K`80I79c01T0HFe]06IbL@1_NgX0L7al06ahN@1`O7d0N8>507^6R01oRXd0PHb@08:=TP22SI40
QXfC08F=T@24S900Ph^?08>:SP22RXd0Q8b>08::S029TI<0Ti^M08B<SP25SHl0P8N=0080PhZ@0100
Q8^A08jEV`2EW:80P8N=0868SP1oQX`0PXV?0868SP1kQHL0M7mo07B0O`1cOgh0JgMf06QdL`1]NGP0
N8B30P1ePH00PP1dP7l0OHV807=oOP1bOW`0OHV809^WY01gPh00HFeZ06]gM01/N7D0J7A`06EaK@1P
K6P0GFUU05aXI01HI680FFEQ05MSG`1HIEh0F6EM05=PF@1IIUl0G6QT05UUI01RKFl0HVea05YVJ@1C
HF80CeeN05=QHP1HIVL0EfEV05ARH`1EHf@0EfEV059PH@19EeP0AE=D04EBD`19E5H0BeIH04IAD`10
Bdd0@Da>05UTIP1FHF<0A4mA04E@DP12CDl0AE1B04UCF011BE00?dI<03a4AP0d>Sd0<cTi03Dj>`0Y
;Rh0;30c034c>00h>T40:b`f02h`>00X:S00<38g038d>00^<3@0:B//02d`<00R9BD0:bh^02T[;P0]
<380=cTm02d^<`0/;cD0<3@i030h>`0a>C`0<S`m030j>`0[=CH0<CTj02T_<00Y;S00:b`_024U9P0X
;Bh0:bd_02@T9P0S8RD09B8U02LS9`0S8B@0:bX/03Df>00^<S<09b`_02HX<@0/;CT0:R/g02HX<@0W
:C809RP_02@V;00R92T09BLZ02@V:@0O8R<08B@T02X^;@0g>ST071hM01PJ6@0M7Qd06QXJ01lO7`0P
7al081hO01lM7P0O71d07QXK01`K6@0N7A/07A`J01/J600J6AL071/I01/J600L6aT202HU8`0901XI
5`0I61H06aPI03Pe=P0O71d061DF02<P8@0E4Q<06AHG00805a@E02/06AHG01`I6P0M6Q/05Q8A01`H
5`0N6QT05A4@02<O7P0C3`h061@C01hJ6@0I5A@05A4@01PD4`0F4Q005Q<>01/H500K5a<05Q<?01`H
5P0C3`d07ATH02XV9`0=2@/04`hA020K7P0C3A006@lA01L>3`0I41406a8C01TA4P0E3Pl05a4A01PB
4P0S7Qh04Pd=01/F5P0E40l0618B014;2`0G4A406aDE008040X:00D04P`<01<=3@0C3@d04`d=018<
300201@>3P05014;2`0C3@d06Q@D01H=3P0B2@X00P0F3@h01@0F30d05@/<01D:300F30d05@/<0080
50X;00T04`T:01882@0D2P/08aTJ04<i>P0C2@X060h?01892P0C2@P00P0D2PT201881`0L01@:2@0H
3Pd050X901<9200@1PD03@<201892@0;0`H06aHI02/U:P1NFEl07a/R00X73P0G4QP04PdC00l72`0J
3a004@@401P:2P0B1PH05`/;01861P0I3@d060`<01H:2P0;0@406@d=00d20P8050P800T04PH601H:
2P0B1PH06@d=01P<300B1PH06Ph>01@8200C1`L00P0B1PH00`0C1`L050P801D92`0201<72@0801D9
2`0F2P`050P:01041P0C1`T06@d?01L;3@0A1@L201@82P0301<72@0B1PP04PH800804@D700l05PX<
01<72@0E2@/04`L901041P0C1`T0710D04Tm@@0K3a<050P<00`2100F2Ph04PH:01<72`0B1PX00P0F
2Ph00`0@10P04`L;00X00P0201D93@030105200?0`L050P<008050P<00<04`L;01862P0A1@T01`0B
1PX0500F2Ph04`L;00/00`0U6Ad0;R8V00P0000O4aL03P<6020D600A1PT03P<601<72`0E2@d04@D9
01<72`0D20`04@D801451`0B1PP050P:0P0C1`T04`0H30h02@0001041P0D20X04@L801T=3`0A1@L0
5PX<01451`0E2@/05@/<00l51P0H30h04@D701L;3@0B20T03`<501H:300F20/00P0G20/08@0F1`X0
5@H901<72@0C2`/050X;0107200`:2P0J5mP06UPH@1DB4X081@F00d3100D20X0308301@92@0?10<0
2@0001T>300<0`404@P601L<2@1oLg<0;R8T01@92P0C2@X050P:03hc=@0E2@/0200002@H6P0d:2X0
4`P900l51P0201<72@0301451`0@10H04@D700L04@D700`0;B4S01882@0>10D050P:01@92P0E2@/0
4@H701872@0E2@/04`L901061`0C1`TDooooo`006oooool201D;300501@:2`0C2@X04`T:01<92P0B
20T00P0D2P/00`0B20T04`T:01@:2`0601892P0=0107200?1PL050/<00h61`11>3T03PD601482P0T
6Ad02`0401@93@0:00<05``@01<8300301052@0G01P=4@0O51P0>S0a00l51P0;0@806a4B00h41@0U
6a`04@L801H<3@0G3@h050X;01882@0A1`P04PP90147200E2``050X;01882@0E2``040H70147200E
2``00P0D2P/0100B2P`03PP:014;3`0B2Ph201482`070188300B1`/04PL;01<82P0D20X05@T=01D9
2`0201882@0501<92P0D2P/050X;01<92P0B20T00P0C2@X00`0D2P/05@/<01@9300501872`H050T=
00H04@H:01052@0?10P03`@801<8300D2@d201<8308050T=00@05@X>01D;3P0D2Q804@XA0P0@2Ph0
100A2`l05@lA01<=3`0D3Q02018<300801D?3`0B3@X0100003@^<00>20X0100001H@4P0J51H601<=
3`0>010:2P0>20P04P`<010:2P0B30`0:B<S00l92@0E3`l09AlO02TS8`0G4A4050l<00X70P0?30L2
018?2P0501<@2`0D4@`040d801<@2`0D4@`00P0C40/01`0E4Pd071PE01LC4P0?2`X061@C01dI600:
1PD00P0F4Q402@0G4a8061@C01PD4`0G4a804a8@01TH5P0Q81h081lM01PG5@0201TH5P0M01/J600L
6aT07A`J01/J600J6AL061PF01LG5@0J6QP06a/I018B400L71X07AdK01HF500G5aD07AdK01@D4P0U
9B<07QXI028Q7`0O7Q`07QdK01`L6P0I6AL07AdK01lQ7P0P8Ql07R0M01/P700L8Ad00P0O82805P0M
7R00824S024U:00Q9BP0724U01lT:00R:2d08bX`028Y;`0T;2l0:C4c02/c=@0[=3D0:38c02Pb=00Z
=CP0LGb002`j?@0/>Sh0=dA:02`i?`0`?T@202ln@`030350A@0c@TL0=TE:0080>DQ=0P0eA4T06`10
Ce@0?diC03E4AP0fA4D0>4I703Y8BP0iAdX0>4E;03a9D00hADd0C5UR03e9EP16DV00?TYH041=G@18
EFD0@DmK03=1BP0fAD`0AUEJ04UHG@16EEX0B5ML04]JH@18Eeh0@e5J04IEFP0204QGFP0903m?C`0m
CD`0@e=A04MGE018F5D0Be]J04]JG@1<Feh0CUeQ0080CUeR0100D5mT055PI@1BHFH0Df9W05]ZK`1L
Jg00FVU^05QWK01JJFh0E6=W051NG`1AGf00CUaM04]IFP1BH640Gfe^0P1NK6d0201PKVl0HW1a06Id
M@1WMGD0IG5_06UeL`1bOW`0M8200P1`O7`0@`1iQ8H0OHR:086<SP22SI40P8^?07f8S01oQhX0QHf?
08J>T@22RXd0PHV<08>;SP24S8h0QHf?0869R`26SY00OhN908>;SP1oQX`0PXV?0827S@1oQX`0QhjD
08fDVP20Qhd0OhJ<07f4RP1oQX`0OXF;07R2Q01dOgl0M81n07=oO@1^NWP0K7Qf06ijN01gPh40JgMe
07=oO@1`O7X0MX:007B0OP1`O7P0M81l08bHU01/N7@0GFUU06McK`1ZMW80JGEa06McK`1NJVH0G6QT
061/J01NJVP0H6aZ05eYI@1OJfH0GfaU05QUGP1JIV80GFUW05aXJ01QK6h0H6]_05YVJP1EHf@00P1C
HF80301EHf@0EVAU059PH@1DHV<0FFMX05=QHP18EUL0AE=D04QDEP1;EUP0BUEG04E@DP80?dY<00@0
Ae9D04=>D00mB4X0@4]=0P0oBT`0?P19DEH0@TUA03U0AP0g?D80<3Dh02X_<P0^<c@0:Rh_02X]<@0Y
:C40;Bde01lO:@0X:380;bli02X[<@0[;300;Bh`02h`;P0Y:bP092HS02T[:P0Y:R`0:2T[02`]<@0^
;SH0;c8i03<g?P0b>Sd0;cLj02Xd=P0/=SL09S0a02`e=00[<C40;cDe03Hg>@0^<S<09RX[020Q8`0/
:Rd0<c4d02LR9P0U82@08QdQ02DT9`0^;S00:2//02<W:P0Y:C<0<30l02h^>00Z:S@0:2P`02DV:`0S
92P07b0R02@V9@0U9bH08bDS02<U900N8R40;2l^0P0I6aX02`0P8B008B4Q01TI6@0K6Q/07A/L01hL
7@0O71d081`M01`K6@0M71X071/I00<06aXH00h071/I01LF500X9bD0:2LU01DD4P0J6AL07ATJ03Da
<P0O6a`040`=01`H6@0<20T06ADF01PD5@805a<D00/061@E01TE5P0F4Q40510?01DA400J5QD05A4@
01/G5P0H51<06aLF01hJ6@0201DA400@010<2`0E4@l06QHE01LC400D40l071PG018>3@0H51<07QXI
01XF5@0E4A404Ph?018<300G3Pl05P`=01T?40806Q4B00L05@h>020J6P0?2@T03`/;00X61@0A3@`0
5a8A0080618B00@0=Bl_034[:`0K5AD05a4A0`0B30`01@0C3@d050h>01<=3@0B30`04`d=00804P`<
00D050/<01@:2`0D2P/050X;01D:2`0201D92`0?01<82P0A1`P04PP901@:2`0E2``05`d>00L00008
0000:R0Q00d3100I3a005`d>01<9200D2PT05@/:00804PP702L05@/:01X@3`0D2PT050X901P>3@0E
2`X040H501@:2`0E30l030D900d63@0G4QP03PX@0<Boa@1KEUX03PT:01lG5@0O5A<04`P601@8200H
30`04@D501H:2P0D20P040@401H:2P0G2`/03@4100l30`0F2PX060`<01<71`0B1PH05@T901@8200@
10@05PX:01@8200C1`L00P0B1PH01P0C1`L050P801D92`0D20X04PH801<72@805@T;00h04`L90104
1P0A1@L04`L90186200@10H04PH800l31@0E2@/05PX<01<72@0H30h040@601451`805@T;01404`L9
01@82P0E2@d05PX>07Y^LP1REUX03@4501D93@0C1`/050P<01452@0C1`/050P<0104200B1PX0710D
01D93@0200l31`0301P<400B1PX04PH:00804PH:00<040@800l31`0B1PX01@0B1PX03`0D20`04@D9
01L;3`0E2@d03@4501@83008000050P<01D93@0I3A404@D901P<400K3a<07Q8F01H:3P0201452@03
0145200@10H04@D700<04@D701<03`<501<72@0B1PP04@D701@82P0E2@/04PH800P0000G2`d0=b/]
01@82P0=0@<050P:01041P0Z7R009ATK0186200I3@l03`<4008050D802@04`@701831P0@10H01`00
01L=3P0@1PL0ETe>0<Bk_00M51D05`/=0186200G2`d050P:01H:300A1@D02000020E4`0=10<05``8
00`1000A1P<0<bLW01D92`0C1`T04@D70186200F2P`04PH801451`0E2@/05`/=01D92`0C1`T050P:
01<72@0B1PP301041PH04@D700D03@4301P<3P0E2@/05`/=01H:300200P0000501L;3@0800002000
01<92P0H30h05?ooool001_ooooo0`0C2@X201882@070147200B20T050X;01@:2`0B20T04`T:01@:
2`0601<92P0K01H<3@0B20T05P`=01892P0D2P/07A<D01482P0H3A40304500d31P0F2`l05``@01D:
3P0G310060dA01052@0A1PX06@hB0148200T6Q/06@l@03T_<00L4Q<01`0001<92P0E2``050X;0080
4`T:01T050X;01882@0A1`P05@/<01@:2`0B20T05@/<00l51P0B20T05P`=01@:2`0C2@X04@X:00`8
1`0>20X03`T:00h82P0B2@`04`T=01872`0C1`/04`L<01@8300G20l05PX=00805@T;00@050P:01<7
2@0C1`T050P:0P0C1`T0100D20X04`L901@82P0D2@`;01@93@0601H;3`0L4AD060dA01@93@0G3100
5@X>0P0C20`201@93@0501D:3P0E2`h04`TA014:4@0C3A400P0D3Q8201@>400;01D?4@0B30`040X:
018<300>2@H0;RPZ08b6R00Y8bD05a4C01lI6`0500401P0C3@l04@0A2`/02`D501D?3`0>20P040X:
01D?3`0400005@l?00h8200G4A40618B01@?300F4`h06AH?01PE3P0E4P/04Pl800804@h70P0C40T0
2P0B3`P04a0901DB3@0F4Pl061@C01<?3P0D40l0=C4`018>3@0F4Q4201LC4P0301HB4@0H51<061@C
00805QDC00H071/I01/J600G5Q@06QTG01TH5P0K6QP201dL6P0301`K6@0K6QP061PF00807QhL05`0
6a/I01HF500R8R006a/I024Q7`0F5Q@08R8P01`L6P0H61H08QhM028Q7`0M71X071/I01dM6`0K6aT0
7AdK01lQ7P0P8Ql07b4N01`Q7@0M8Qh07b0R024R900S92H092DW020T9`0Q9BP08bP/02L/<00X;S<0
9bhd02H]<`0U;C009Rh`02Xb=00Z<cD0:38c02Pb=00e@4<0OHR<03I4A`0b?d@0=T=902Xg?@0]>d00
;Se202ln@`0a@4D0=4=803I5BP11D5D0@4mD03U8C@0mC540>4M<03A3B00eA4H0>dU903e;C00iAdT0
=D=603]8CP11CUD0@e1H03]8D@0nBUD0@TiJ03e9E`0nC5T0BUQU082>VP1DHV/0AEAK03m>D`14DeH0
@E1C04IEFP1;FV40AUAM04ABG014DeX0AUEJ04EDF00mCDd0>d]:049BD@14E5<0AeMF04]KF`1;FUd0
C5]P055PI@80CeiS0140DF1U059QIP1CHVL0E6=X05]ZK`1LJg00FFQ]05ETJ@1FIFX0DV5U04aJF`1A
Gel0CE]K04QFEP1<FUX0Df5Q065_K`03069`L00L06AbLP1VM7@0JWId06UeL`1`O7X0Lgmm079nO@1e
PH40NXJ607j9RP21S8h0PXf?07n:S@1lQhT0OXJ808B<S@25SHl0PXZ<0828RP22RX`0PHV;08N?T@21
RH/0QXjA0869S020R8/0PHR>0827S`80OhJ>00/0OXF=07f4S021R900P8N?07f4S01nQHd0O8>;07Io
Q01fPH40MX:007B0OP03079nO00;07=oO@1[MgD0QY:@07^7Q@1^NWP0LGek06eiM01TLFX0KGYc05m/
I@1QKFT00P1PK6P01`1SKf/0IG5]05aXI01GHf40G6QV05m[JP1PK6X00P1LJ6@07@1KJ640EfAN05]W
H`1LJ6H0GFQX05mZK01NJFd0GFY]05aZK@1GIFP0DV1S055OHP1DHVD0Df5T05ARI@1JJ6/0EF=V04YH
F`17EEP0B5AF04]EEP1<EUL0BUAE04I@D@14CTl0?DM803]5AP11Bd`0@Ta=0080?DM80380ATiC03i5
C@0e>T00<CHk02`a=00Y;C00:blb02P/;`0`<CH0:RXb030`>00];CP0=cM302TY<`0U9B`0=3Di02l`
<P0/;R`0:bdZ02T[9P0W:BH0:bd/02X/:`0_<3<0<C4i034d?@0d>3h0<3Lm02`c>@0V<380:C<d02H`
<@0/=C@09R`Z02P^;00d=SD0;C4b02@X:@0M7R00:RP[038`<`0U82@0:2<W02HQ9@0W9RT0:BT[02HY
:P0[;c80;blg02DU;`80;2`f01L07QlU01lP900S92P07b0Q02<U8P0U9b@08R@P024S800G6aX06A`K
01XL6`0S9B@07QlO02DU9@0G5aL06API01/I6P0L6Q/07AXK01hJ6`0J6AL06APF01XI5`0301/J600>
01XI5`0I61H06QTG01TH5P0G5Q@061LE03@`<@0[9bP0:RHW02@P8@0I5AH09B4R01TE5P0H51D401LC
500603Te=019AD@06ADD01`H5`0;1`H07ATH0P0G4a802@0M6AP061@C018>3@0C3`h05A4@01HB4`0G
4a805A4A01XF5@02018>3@0>00d9200F4Pl05a<A014=300D3Ph05``>01D;300G3@h06@l@01L>3`0E
3Ph06Q@D020L6`0`;2/200`;2@0>00`71`0=1`L05Q0@03hh>00f<3006Q@D01D?3`0D3Ph04`d=018<
300C3@d050h>014<300A3@`201H@400;014;2`0C2P/04`T:0147200C1`T05PP;01P9300I2Pd05@X;
01882@0C2@X00P0E2``0200F30d0F4i?02hT9@0>10D04`T:01L=3P0?1PL050X90P0E2`X0:@0C2@P0
4PP701D;2P0m<c80:1hM01061@0A1`H050X901D;2P0O4aD04PH801D;3P0;1@T04@`@01HA5`1XIV/0
6QPK01HA4@0I51401P0001@<2`0F2PX06Ph>01<71`0H30`05PX:01861P0C1`L04PP801D92@0J3Ph0
710@00h20P0C1`L050P801D92@0C1`L04PH601D92@0D20P04`L700804PH601H04`L701@8200C1`T0
4`L90186200A1@L04PH801<72@0G2`d04`L901041P0C1`T050P:00d10`0A1@L050P:01P<3P0F2P`0
50P:01T=3`0>0P@04@D70P0B1PP0600A1@L03`<501X@4P0>0PH060`@020E600K3a<0200001D93@0G
2`l040@800d11@0A1@T04PH:00d31@0B1PX0200001X>4P0E2@d04PH:00l31`0@10P04@D901862P80
4@D91P0B1PX02@0J3Q802P0200d11@0G2`l050P<00d21@0X7200300400d31@0200P0000401<72`0K
3a<07Q8F01H:3P804@D900<04@D801451`0A1@L00`0A1@L04`0?0`D06@d?0186200=0`@060`>0186
200C1`T04@D7038V:01<@4805PX<00P0000D20X03@4301dA4`0D2P/02@0001T=3`0A0`H00P0B0`H2
01<41`0R0186200700004@L801@:2`060000;RDV01<:2`0L41805PX<00`20`0800006@d?01H:2P0A
1P@05``:0146100I3PX0714=01L<2@0B1PH03P8400h3100A1@L06Ph@00/10P0A1@L060`>00d31008
000050P:0186200C1`T04PH801451`8040@61`0A1@L0300=0@<03P840186200W6ad05P`=0186200m
<C<0HeMI02@H6P0R5QP04PP900P001Cooooo000Kooooo`8050X;0P0C2@X301882@8050X;00<04PP9
01<92P0D2P/01P0B20P0200>1@H05`d=01492@0H3Ph02@4101P?3`0@1@T04@H:0`0E2Ph03@0?10P0
4`T<00h31`0E2Ph04PL;00`11@0A1PX040L701<92P0C2P/04PX:01L=3P0N51D00P0C2@X0600A1`P0
40H701<92P0E2``04PP90147200E2``050X;01882@0E2``04PP901L=3P0I3a0050X;0147200D3@`0
4@d;014<2P0?2PT04@/:01L>400F31004PL<01@73`805PP@00@05`L@01H83`0E2@/05@T;0P0D20X0
1@0C1`T05@T;01@82P0C1`T05PX<00804PH800<050T<01@93@0E2Ph00P0E2Ph00`0D2@d04`P<01@9
3@0201@93@805@X>00H06@hB024F6P0L4AD050T=01L<400@1PT201<8308050T=00D05@X>01D;3P0C
2A404@XA01<=4@02018<400?018<3P0A2`d04P`>010:2P0A2`/05@l?018=2P060@8081XL00h82P0>
2@X050h@01H@4P0B30h04`d?00<050h@00l04`d?00h8200A2`/04P`<01TC4`0D3Ph05@l?01`F5P0/
9RH030H601@>3P0B30`040/800h;1P0C40T00`0E4P/0600F4``0514:01HC300E4P/0514:01DB2`0I
5Q40510=01TE500G4a804`l>02hZ:@0D40l061@C01TE500H51<05Q8A01LC4P0K5aH07A`J01PG5@0J
6AL06APF01LF50806QTG00<06aXH01`K6@0M71X00P0N7A/0400L71X092@R020P7P0M7A/09bLU01hN
700K6aT08R8P02DU8`0F5Q@09BDS01XJ600N6QT07QdK01TH5P0J6AL201lO7@0N020P7P0Q8b008R@Q
024S800Q9R808RLS020Q8`0R8bD0:2T[02LX:P0Q9BP08bLZ02P]<@0W;3008bT^02@[<@0X;cD0:30c
02D];`0X<380:S<d02Xd=@0/=SP0;3Hi034l@00W=CP0>DI;02Tf?00^>d40=4970P0_?T<09P0d@dP0
=dI;03M6B`0iB4d0=DA903=2A`0hAd`0<d970350A@0gATP0?DY:03i:C00hA4H0=T=603i:D012CED0
@DaE03U5CP16DU`0CEQT04IBG`0hAU<0@DmL07^9T`1JJ740AeIM04mNHP13DUD0?diA04IEFP1:F640
A59K04IDG`15Ded0AEAL049AE`0oCU40@51@0P14E5<02P18F5L0CEaN04]JG`1<Ff80DV1X04mNI01?
GV<0DV5V05ASJ01EI6T205MVJ`0I05YYKP1HIf`0E6=X05MVJ`1EI6P0BUQI04mMG@1<FUX0CE]K05IT
I01IIfL0H6i^06=aL@1RL700H6i^065_K`1ULg<0KGUg06QdL@1]NGH0Lgmm07J2P@1kQhL0O8R807f9
RP02082;S@0>07n:S@1mR8X0Ph^=08><R`21RXT0PHV:0828R@1oQhT0OHF708N?T@20R8X0RY:E08VA
U01nQXT20827S`040868T022RI40PHR@07n6SP80P8N?00X0OHB<0827S`1oQXh0N86607AoO`1ePGl0
LGek07B0OP1ePGl0LWil0P1cOgd0:P2>VYP0Q92>071lNP1YMG40KGYc06AaJP1[N740HVmX06IcK@1R
KVT0H6aX05m[I`1VLVh0Hfm[05eYI`1QKF/0I71`06A`KP1OJfT0GVYV05]XH@1JIf40G6QT05]WI@1J
IVL0FVEY05]VK01KIf`0FFMZ05ESIP1:F5/0@e5D04MEF01?GF00Df5T05ITI`1DHVD0CE]N04YHF`18
E5H0Ae5B04QBD`80BE=D05@0Ae5B04E?D01:E5D0CEMH049<C@0mAdP0@4Y;04=;D00j@4X0<SHo034f
>`0/<CD0:Rha02/_<P0V:Rd0;Bhc02TX<00b<C/0=SE2051@G00];CL0?3a402d^<P0X:RT092HR02HX
8`0Y;2H09BLS034c<P0`<S40=cPk03@d?00b=Ch0<cLm02lf?00^=C/0;3Hh02Xd=@0U;c00:C8a024W
9@0R:2H0:B/Z024U9P0T:2T09BDW028P8`0U8bH09R4U02TT:00V8BD09B<V02DU9`0S9BL0:Bd`02/[
<P0P82T0:BTa02/[<`0R8bL09RLY02TZ:`0Q8b408bDP02DW8P0O8Q`071hH01`Q7@0K7Qd07AlN02@V
9@0I6QT0820P01`L700M71`07A/L01`J6`0L6AX06aLH01/J600I61H06QTG01`K6@0M71X201XI5`0<
01dL6P0D4a4051<A01/J600H5aD08ahP00l:2`0G4Q@06aHG01TD5P0Q71d06A@E100I51H0100I51D0
>3Dd05aHE`0K5aH201HB4@1201dI600G4a805Q8A01DA400H51<0510?03Te=@0S7b4040`>01XE600G
4aD05Q8A01DA400E4@h03`/801TF4P0M6QD06QLC01TD400I3Pl05``=01L<3P0G3@h05@`=01H>3`0>
20P0<Bd/05QFE00F5A<04Q4?020M700U7al040X:01D?3`0F41003PP801<=3@0B30`04@/;01<=3@0E
3`l0618B01HA400A3@`05@l?01LA4@0@2PX04@P901D;300D2P/05@T;01L9300H2@`06@T<01X<3`0H
3Pl05`d>01D;300C2@X04PP902@J6`0C2PX05@/<01@:2`0A20T060h?0P0E2`X01`0F30/04`T801<9
200F30/08ALF01D;2P0?1@@00P0F30/06P0A1PD05PL901H82@0G2`h040L;00X41`0^:Bd0UiFH02h/
;@0C4@l05A4=01<?2@0>2@@050X801X>3P0E2@T0710@01/?3`0I3@d09a/K01461P0@10@03P@401X>
3P0A1@D04`L70P0E2@T01@0C1`L04PH601<71`0D20P04`L700804PH600H04`L701@8200@10H05@T;
01H:300C1`T201451`0H01D92`0F2P`04PH801<72@0D20X03P8400d10`0B1PP03`<50186200H30h0
3@430186200E2@/04PH801@82P0E2@/04@D701882P0I3A402`4301L<3`09004060`@0P0E2@d03P0B
1PX050P<01@8300?0`L05@T=03HZ;P0E2@d04`L;00/00`0F2Ph040@801452@0B1PX04`L;200B1PX0
0`0A1PT050P<01@8300201452@0?01@9301?@dL09QXN01<82`0A1@T05PX>00h31P0C1`/05@T=0145
2@0C1`/050P<01<72P0D20X04`L900804@D701@04PH801H:300@10H02P0001@82P0A1@L03@830145
1`0C1`T04PH801<72@0;0@807Q8D02hR900?10D050P:01H:300D20X05PX<01441P8050D80P0E1PT0
2@0D20X04@P900`20`0@1PL04`X;00P10@0@1`P04@D700T0000202PL7P0D01451`0C1`L03@8100l4
0`0F2`T0XIJB0>;He00]8Ql04`L700l31@0B1`P05@T;00h2100@10H050P:01451`0A1`P050P:01D9
2`0@1@L401451`030186200C1`T04@D700D04@D700`050P:00l51P0m<C<0FdmA01`@4P0>0P@03@83
02`Q8P0D20X03P@501@92`0F2P`Dooooo`006oooool201D;308050X;0P0C2@X04`0B20T050X;01@:
2`0B20T04`T:01@:2`0B20T04PP801881`0B20T04PP801881`0K4A804PX:00d30P0D2P/060h?00`2
0`0B1`/00P0D2@d0400Q5QX04@H:01/@5017?40060dA01462P0C20`040D901<8300F30d040H701T?
400A1`P060h?00l51P0@1PL201882@8040H70P0B20T0100A1`P05@/<01@:2`0B20T201D;300601X@
4@0L4Q<04`P<00l4200A2PT03PT60P0=20D06@0F3P`07aHG01X@4`0A1P`050L>01L:4@0F2A005PH@
01<6300B1PP04`L901@82P0E2@/05PX<01P<3P0D20X050P<01P<400B1PX04@D901<82P0A1`P04`T:
01@:300C20`00P0A1PX09@0B1`/04`P<01@93@0E2Ph05P/?01872`0D2`h05@/>01<8300I41<050X=
01<8300B2@`04`T=01@93`0D2a005@/@01<<4`0A2Q403PP<00`62P0=1`/040X<01<=3`0D3Q004P`=
018<3P0F410050`=01D?4@0<1PP05a4C018<3P0C3@l04P`>014;3@0B30h00P0E3a40:`0D3Q004P`>
01@>3P0G4A402P@4024K6`0<1`L06A<C00`61P0K5AD030H601/E5@0@2PX071LD018?2P0F4`d05a@=
01DB3@0C40X04a09018?2P0C40X04Pl8014>2@0C40X05a@?018>2`0D40h06ADB01dI600F4Q406ADB
01TE500K5aD06ADB01HB4@0H518071PG01@C4@0B4@l05aHD01XI5`0I61H00P0K6QP201XI5`0c01`K
6@0O7Q`081lM01PH5P0M7A/06a/I028R800l?3X06a/I01XJ600[:bT0Rh^902l_;@0<30X07alM01dL
6P0P7ad071/I01/J6`0N7Qh071`L01hO7`0N81l07AlN01dP7`0O8b808RHU020T9@0P8B<08RHW028V
:00Q9BP09BX^01lU:`0W;3809bhd02@]<P0V;C<0:S8e02de=`0^=SP0:c@e02La<`0X<S@0;STl02Xe
>@1KIVX0AU=H02Xg?@0gA4X0;3Xo0080<3m400/0=DA903U8C@0hAd`0=DA903i=DP10Ce@0=TE:03Y9
CP0hAd`0=T=503Q4A00203M2A01003]6BP0nBDl0@diE03M1BP16D5T0@D]E05QRK01<F640?daE04=A
FP0nC5D0A5=J02hmA015E5T0AeIK045@E@17EU/0BUUP049AF017EEh0BEMP04ECG012DEL0@e9E04IE
F018F5P0AUIF04]KF`1>GF00BUUN04YIH01@GVH0CUeT04mNH`1BHFH0EFAY05MVJ`1JJFh0DV5V05ET
I`1@Gf80BUUL04]JG@1:FE`0CE]L04eKF`18EUH0CUaL05m]K@1QKfl0FfUY05m]K@1PKVh0GVa/065_
K`1VM7@0J7Md06EbKP1/NgP0MH5o07R4Q01jQHL0O8N907f8R`80OXV=00D0P8^?086;S@28T9<0PHV;
07f5Q`0207n7R@80O8B602T0Q8b>07^3Q@29TI@0SYJI07n7RP1nQH/0Ph^B0829T01lQ8/0PXVA08N@
U`1kPh/0OHB<07b5S022RY40Q8^C07j7S01cOgh0M81n071lNP1ePGl0Mh>1075mN`1fPX00JgMe06Yf
M01_NgT0Mh>106McK`1WLV/0GFQR06ehLP1HHed0FFAN06AaJP1NJVH0EV9N05m[I`1QKFT0Gf]Y06Ea
K`0206A`L00O061/JP1OJfT0GVYV05]WI01KIfD0FFEU05aWJ@1OJVh0Hfib05aYK01EHfH0EfEX051N
H@1:F5/0CUaO05=QI01AGf80D5iQ051NH01=Fe`0BUQK04UEE`19De@0AU1B04I@D@18E5@0BUAE04A?
C`14D500AE5A03a8B00203m;B`0K03m8C00mA4`0>cm803Ll@@0Z;c<08bH[02@W:`0P8BH09bL^034a
>`13@dd0BTYE03<c?@16ATh0YJJ[051AD`0c=C@07R0M02<U800[;BP092HS03<e=00_<380<S<f03Lg
?`0c=Sd0;S<i0080:S4g02L0:c@g02`d=P0R:R`09Rh_02P^;P0]<c<0:bd_02d^<00Y:R`092@V02/Y
;00_;C008R0S02TW:P0R82D08B0U02TZ;P0U:2/082@W01PK800S8b/07QlT01`M8P0S92L09BHX02DW
9P0N81d08B<N02DW8P0Q91h07R0K01LI5P0T9RD05QPG01LI600J6a/0820P01XJ6P0L6a`00P0O7Ah0
1`0Q7Ql08AdN020O7@0L6aT06aXH01dL6P0L6aT00P0H5aD03@0I61H071/I01`K6@0H5aD05QDC01LB
4`0P6Q`06A<E01`F6017@D<08A/M01TC5@0J51H00`0K5AL06P0J51H07ATH018>3@0O6aX061@C01DA
400@30/05A4@01TE500?2`X0510?01/G5P1VHV<0=C0d00d8300K5QX05Q8D01<?400J5QD04Ph<014=
2P0o>cP09b@O00H3000L5a<06a4B0P0H3Pl03P0G3Pl05@`=01082@0N61P040`;00d9200@3`d06QHE
01LB4@0C3@d02`D501D?3`0J51@040X:0`0=1`L0700B30`06A<C01dG5`0J51@03`T9010:2P0G4100
60l@01`C500N5AH060h?01P<3P0F2P`05PL:01D62@0G2@`05`d>01H<3@0E2``050X;01<92P0I3a00
1`0001P>3`0700007A<D01882@0E2`X201H<2`804`T800<05P`;01D;2P0B20L00P0A1`H07P0?1@@0
50X900h0000U5aL04P@701P=4@0@1`X03PP:02LS900300004@d;00D0000E40`03`T401@:2@0I3@d0
4PH601L;2`0E2@T04@D501H:2P0=0P806Ph>01451@0H30`03`<301861P0E2@T04PH6010410804@D5
00h050P801<71`0B1PH04PH601<71`0D20P03`<501L;3@0J3Q005`/=0186200@10H03@4301@82P80
4PH801T05@T;00l31@0D20X05`/=01451`0S5aT0=RX/01L;3@0?0`D050P:0186200K3a408aLI024E
5`0@10P060`@01862P0>10H05`/?01452@0B1PX03`<701D93@0T61`06PhB00802P0200D0;R8V00/0
0`0D20`02@010104200301<72`0301862P0@10P03`<700H04PH:00/04@D90104200?0`L04`L;01H:
3P0C1`/03P860104200E2@d040@800`0100201H:3P0301<72`0@10P050P<008050P<00l05@T=01<7
2`0B1PP04PH801<72@0E2@/04PH801@82P0@10D03`<301<71`0B1PL040@600d10`0B20T00P0E2@/0
1`0M4A<08QHH00l31@0=0`@05@T;0186200D1`T00P0C10L201421@0E00h2100C2@X060h?00h41@0G
3@h0200004@j>`13=cT05`/=0147200M4A<04PH801861P0C20H05``:01881`0e:RP0KF9N01/@3P0C
1`L05`/=00<03`<500L04`L900l31@0D20X050P:01P<3P0P51H05@T;00803`<500@040@601451`0C
1`T05@T;1P0A1@L0300;00405PX<01H:300>0P@03`@50186200F2P`050P:03da<`0?0`D04`L90186
21Cooooo000Kooooo`0F01P=4@0A1PX04`P<01<8300A1PX060dA01T>4P0D2@d02@0201872`0C2P`0
6PlC01872`0>1@L081HG01872`0A1`T04`T:01D:3P0D2@`04PP901882P804`P<00T050T=01052@0C
20`06a0D01X?4`0G3100>Rlc01D:3P0?10P00`0D2@d200h41@0400l51P0G3@h05@/<00d310804`T:
0P0D2P/06P0C2@X04PP901<9200E2``04`T:00l51P0A1PX04`P<01882`0F2`l06@hB01@93`0=0PP0
50X=01hE5P1gKVl05@`=01H<3@0H3Pl050X;00`11@0Q5QX030<500l4200G2`l05P/>0P0D2P/02P0C
2@/04PL;01872`0C20`03`@807mdNP12=cd050T?00T0100D2@`200l5100301471`0B20T04`T:0080
4@L801406@hB01@93@0I3Q804PL;01<93@0K5AL030@7038Y;00M5aT0;2DY05mFF`0=1`/03`P<01H<
500F3aH03@@<014:4@02010;3`<04@/?00/05@`A01T@5@0I41@0200401482`0F31001@0101`F600K
5AL06Q@F00H00P02014;3@03018<3P0C3@l04`d?00804P`>03D04`d?01XD5P0=1`T040X<01@>3`0<
1PH05@l?01LB400D3``040/800l:1`0B3@T07APE01@?2`0@2`L050l<01LB3P0C3PX061<@01HA3P0D
3`/050l<01HA3P0H4`l07a/H010<200O71L06aLD01@A3@0H5A0061@A01PD400G50l05a<@01PE4@0I
5A805A@B01@C4@0F5A<06QTG01/J600G5Q@061LE01dL6P0Q81h08R4O020O7@0O7Q`071`J01XJ600L
71X07alM01dM6`0201/K6@0_02LW9@0e=C<05aLE01LG5@0Q8Al061PH01/K6`0L71`06a/M01`L7P0M
7R007QlQ01`M8@0M8B@08RHY020S:00L8B@07bDT024U9P0R:2P092T]02H[<@0F7B<082P`02T`>00T
;C808bhb02Tc=@0Z<cD0<3Pk02de>00Z<SD0:C0f02Tb=`0/=C/0;3Lm04=>E00^>T40=T=;02llA00b
?dH0<Ci4038oA@0iAT`0?DY@03Q5B`0gA4X00P0jAdd0;P11CU@0A55G045>E00lBD/0=T9002`h>00g
@T@0BEAH049=D`0mAe00BE=L04]EGP1AG680DeiT04MDE`16E5L0@e9G045@E@11D5L0@U5H04ACFP0i
B4l0@E1G04]JH018Ee`0AEAI04]JG@1:G600@E=G03U;CP12E5H0AeUK04EGF00nD580AeUK04YLGP1<
GV00C5iR04QJGP1>GF80DV5V05IUJP1DHfH0Df9U05MVJ@1FIFP2051PH00L04QHF00oCdl0CUiN05MU
I@1>G5`0EVAT05UWI`1DHV80FfUY069`L01JJ6P0GVa/06=aL@1ULg<0IgEe06MfL`1TLg00J7Qg075o
O`1fQ8D0Lh6408>>TP1kQX/0NHB:07n8S`24SID0PhbC08N>UP80PXV?01L0O8B708::S@1mQHP0PHV<
0828R`1oQhT0P8R:08::S024S8l0OXN<09bV[02e`<H0PXbB08><T`1lQhd0NhF<07Z3RP1aO880OXR?
08RAV01nRHd0Mh>407N3P`0207J2PP80MX:004/0LWil075mN@1aOGT0L7ah06mkM`1`NgL0J79[06E_
I`1RK6@0GVMR05URG@1GHU`0GFMT05aWH`1QK6P0HF]Z061/JP1TL6h0I6i`069/KP1NJ6T0HVa]05MQ
HP1TKVl0GfUZ05USI@1MIfT0EEmQ04iHFP1=FUd0CEaQ04mNH`1=G600D5mR055PH`1=GEh0CUiN051P
H01<G5/0A5AC049BDP14DE80CeYL04mJGP13CU40AeEF04mJG015DU<0CE]L07F3P`18EUH0=D=303I4
A00mBDX0<3Tn04mFG00b=c/09bX_030a=P0Q8RP0;Rhf02XZ<P0h>480<cHo03m2BP0d=CT0;c0b03Xk
?@0o@D00;c4`024S8P0[;B`06adL02TZ;00a<S@00P0e=SX0800^<CH0<CHj03Hk?`0i?T80:c0d02hd
>00W;300;S<g024V:P0U:Rd06AhQ02HZ;@0L71h0:2HW02XX:@0S8bD07alQ02TX;@0O82@0;Bhc020S
:00V:Bh08BH[01lT:P0U:Rh082<X02``<`0I7B00;Blb024R900J6ad07QlO0P0R8R00400N7Q`061PF
00l?3`0R8R806ATI02h^;P0I61T09bDV01`J6`0K61T06aLH01dI6P0O6Q/07ATJ01XH6@0L6Q/201dK
700N01XH6@0H5QL05Q@E01XH6@0I5aP061HG01TG600D4Q<06QHG01LC500E4A805a<D01`H6@0N6Q/0
5a<D01PD5@0L61T061@E01HB4`0L61T06ADD01/G5P0M6AP06aLF01LC4P0D40l06ADD01/G5P0I5A@0
5A4@0P0D40l601LA4`0;01D?400I4a<0?SPh02DO7`0I4a<03`T901H=3P0B2@X04@P9010:2P0C3@d0
100E3`l02@0C3`h04`d=018<300O6AT071HF00`61P0L5QH08Q`L01D?3`02010:2P0M018<300C3@d0
5@l?01L@4@0F3A0030<601P>4@0A1PX0714E01052@0H3A405P/?01052@0C1`/04PH:01D:3@0B20T0
40H70147200C2@X05`d>01/A4P0E2``040H701@:2`0E2``03`D601H=3P0?1PL00P0A20T00`0:0@80
4`X;01482@0401482@0B01882@0@10H04PH801@82P0B1PP04@L801@:2`0C2@X040H701@:2`0I3`h0
5@/:01061@0>0P807A4A01<71`0=0@404PH60P0H30`06P0?10@04`L701861P0E2@T02`0000P0000M
4A<02`0101T=3`0B1PP03@4301@82P0=0P<03@430186200C1`T0300201041P0L4180=RX/01451`0H
3Pl0200001@82P0B1PP050P:0P0G2`d01P0B1PP02P0001/?4@0800009QXL05E9B`805PX<00L04@D7
01hB501MDE<06@d?00l31@0?0`L03@4500804`L;00@03@4500/00`0B1PX04PH:0P0C1`/03`0B1PX0
4@D901<72`0C1`/04PH:0104200B1PX050P<01X>4P08000050P<01472@0D20`06@dA00l52@0200h3
1`0:00l4200B1`/050T=01H:3P0>0PH03`<701`=4P0E1P/03@44010420804`L;0P0@10P601452@07
01L:400]82L07Q4H00d31@0G2`l040@601861`0201861P0S01461@0@1@<040D301461@0C1`T02`01
01D92`0A1@L06Ph@00l31@0=0@<04`L900d3100?0`D05@T;00l3100C1`L05PX:01@8200B1PH03`<3
00h20P0K3`l03`@400P0000?1@@08aLG01T=3@0F2PX040@400d10@0?0`<04`L700l30`0@10@00P0C
1`L04@0B1`D040@401T=3`08000050X;01451`0F2P`04PH801451`0@10H03`<501451`0B1PP040@6
01@82P0B1PP040@600804@D700<040@60186200B1PP0100B1PP0300D20X04PH801041P0@10H04PH8
01@82P0B1PP05@T;01/?4@0H30h040@601@82QCooooo000Kooooo`0C01D:3P0B1`/050T=01@93@0B
1`/05@X>02<H700O5AP06a0D01H;3`1:?d<040D900`21@11=SX0?34e01hC5`0A1PX040D901462P02
01872`0801D:3P0G310060dA01<8300?10P04@H:01L<400E2Ph201<8300601052@0C20`04`P<0146
2P0C20`05P`=0P0E2``0100K4A806@l@01882@0B20T301<92P804PP901P050X901@:2`0C2@X040H7
01462P0C20`05@X>01X?5@0:0@D06a4F02@I8@0F2a003@<402HL7@0A1`P0718C00h41@0B20T060h?
00X20P0J41404PP901061`0B20T201@:2`0;01<92`0C20/04PL;01P=4@080080<BH/01dB6@0J3aL0
50TA01472@0A1`D00P0A1`H0100B20L04`T:01@:2`0B20T201<830804PL;01h050/>01TC5@0?2@/0
5Q0B00`6200T7R80A3i201XD600D3A@03`T?0109400A2a403@H=00h8300A2Ph04``@01@=4@0E3a<0
6a<H01493P0@2@d07ADJ00d52P0F3A804Pd>01LA4`0D3Q009AlQ01H@4P0B30h2014;3@@04`d?01@0
40X<00h82P0E3a404`d?018<3@0D3Ph04@/;01@>3@0C3P/04Pd:01@?2`0H4`l04Pd:01XE4P0K5Q<0
5a8?01@?300F4@h061<@01HA3P8050l<00/05Q4>01PC400H51006ADA01XG4`0B3`/061@@018>2P0K
5a<06QLC01TF4P0201TE4@0401PD4@0I61H061LE01TH5P806aXH00D061LE01XI5`0K6QP071/I01dL
6P0201/J60<06QXH0P0K6aT201`L6P0701PH5P0K6aT06a/I01lO7@0J6QP06ATH01lO7P02024Q8P80
7b0S02007QlR01`O8`0L82@07R4U01lT9`0O92P08BLV02<Y:@0P9RH06b<V01XQ:@0Y<3P07bPa02</
<`0O:Bh07bX^02hi>`0V<3809blb02Xb=@0_=c/0<3Pn02lh?@0[=3X0?TQ>02Ha=`0e@DP0OX^C04QE
G@0_?4<0<Ci403A1A`80>4E;00@0=T=903M4BP0kB4h0?T]A0P0mBU00:00oC580@4e?03M4A00a?Sh0
>dM;03]7CP0g@T/0?TUB04MCG016DU/0Ae=J04MDE`0kB4/0?Ti>03m?C`10Ce<0@4mF03m>E@0oCEH0
@e5J04IDG@19F5l0A5=H045@D`13De<0?4i@03]=D016F5/0AEMJ04=EF018FUd0BE]N03mAE01:G5l0
AUQK051RI@1>H6<0D5mT055PI@1CHVL305ASIP0`059RHP19FET0BEUH04aLF`18F5L0D61O086?S`1L
JVX0CUaL05ARHP1HIVH0FVQX05QVIP1MJf/0IG=c06AbLP1RL700IWAd06EeM01ZNWT0KWin06moP01d
PhD0NHN;086<TP1lQXh0NhF>0869T`24S9H0P8VB07j5S`21R900QHbD0868SP22RHl0P8N=08::S@21
RH/0OhN90828RP21RH/0PH^=08F>T`2U/;H0[KRn07f8SP1hPhT0PXfC0P23SY@06P1oRY00O8N=07^6
S01gPXH0N8>607J2PP1dP800LGem06ijN01]NGL0KWYh06mkM`1^NWH0JgMc06QdL01WLV`0Hf]U065X
H@1OIUl0GVAP05aUH@1MIV80G6IR065/J@1NJ6H0GVUW0P1SKfd0<01QJfd0HVe_065[K@1ZMGL0H6]]
05eXJP1OJF/0F69T06=^L01JI6H0Ae5C045=D@16EEX0DF1U05=RIP1DHfH0DV5T04iNG`1>GUh0CUiM
04YJF@14E5<0@U9A049@D019E5L0B5=F03]7BP0lBT`0@4i?03i<C@0lBT/0A5=C03U8B013De<0=DE4
0390@@0_>S`0<3Pk02DZ;P0U:2d0<C4h04a;D`0c<SX0<30h03Hi@@0i?4@0?45702d^<08092HU02d0
:2XY028T8`0T9BL0:BX/02<T9P0/;C40>3Tm02h_<`0g>3d0<3@h03@i?00k@4<0@TI:03<h>`0]<SD0
<cLk03Pl@00Q9RT082@X02DY;@0m@4@0:BPZ024N7`0V92D0<30b02PX:P0U9RX0<cHk03e0A@0X;380
9b`b02<X<00S:Bl092T_01dR9@0^<SD06AdP028T9`0W:2X07QlQ02DV9`0W9bL08R8R01hN7P0L71`0
0P0Q8B400`0^;Rh06ATI020O800201lM7P0601dJ6`0M6AX07QXK01lJ6`0M6AX071PI0P0J61T02P0I
5aP061HG01PF5`0K6AX05Q@E01`J6`0P7Ql07A/L01XH6@0I5AH201PD5@0F01TE5P0J5QL06aLH01hJ
6`0K5aP030P903`h>@17@d@061@E01TE500G4a805A4@01LC4P0I5A@06QHE01@@3`0G4a805Q8A01DA
400F4Q405a<B01D?4@<05Q0B00d05@lA01@>400X8R@081XL01D?4@0B30h0;2HX01D?4@0E3`l04`d=
018<300C3@d050h>00@05@l?010050h>01<=3@0D3Ph04P`<01PB4P0X8R808A/K01H@400C3@d04P`<
014;2`0B30`04`d=01@>3P0C2P`06PlC0P0B1`/02`0M4QH04PL;01H;3`0F2`l06@hB01D:3P0A1PX0
5P/?01@:300F30d05@/<00805P`=00d060h?01D;300E2``05@/<01H<3@0E2``04PP901D;300@1PL0
6a4B02DK700K4Q<040L800H04PP90P0J3Q001@0I3@l04`L901451`0A1@L050P:00804PH801H040@6
00l31@0H30h081@D00l30`0F2`/06@d=01L;2`0B1`L04@D501<71`0G2`/03`D501D:2P0H3Ph04`L9
01451`0C20T06`lA01H:300P51H04@D70P0B1PP201451`060186200A1PL04`T:01D92`0D20X05P`=
0P0C1`T0100B1PP04`L901D92`0E2@/20186200A01<72@0D20X04`L901882@0A1@L03`<501D92`0;
0@807A4C00h2100D20X0:1`P01<72`0?0`L04PH:01<72`0D20`00P0B1PX201<72`0>01862P0A1@T0
4@D901862P0A1@T040@801452@0B1PX0>2``02PL800<0P@060`@01462@0=0@D201<8308050T=00h0
50P<01<8300B1`X04PL;01462P0B1PX03`@601H:3P0C1`/04PH:01@8300C1`/04@D9010420D04@D9
02@040@901T<500B1@`040@901@8300?0`D04`L801861P0B1`H04@H501050`0@1@804@D401<72@0I
3@l04@H8038V:01?@dD05@X<00d3100?0`D04`P90147200C2@X04@D601<71`0@10@03`<30104100D
20P05`/;0104100C1`L04PP800h20P0A1@D201<71`0401@8200B1PH04@D5010410H04@D501803P84
01X>400/82803`<50186200<0P<03`<501<72@0E2@/040@600h2100C1`T04PH801@82P0E2@/04PH8
01041P0A1@L60186200601@82P0B1PP040@601041P0B1PP050P:0P0A1@L201H:30804@D75?ooool0
01_ooooo0P0C20`201@93@804`P<00`081DI01`A5@0=0PH02`0401H;3`0J3a<0714E03DZ;P0B1`/0
40D901H;3`0H3A4201@93@0501D:3P0H3A406a0D01`A5@0B1`/00P0@1@T02@0C20`04PL;01052@0F
2`l05``@01D:3P0@1@T04@H:01D:3P0201882@0401061`0C2@X04@L800/10P804@L80P0B20T00`0A
1`P040H701<9200201882@0E0147200B1`/04`P<01lD600B1`d05@X@02/P9P0X7BD060dB01P>3`0C
2@X08aTJ01@:2`0=0`@050X;01X@4@0O5AH060h?00L0000E2``05P`=00@04`T:00T04`P<01462P0B
1`/04PL=01@9400B1`l060dE01872P0B20H00P0B20L05`0A1`H04@L801882@0H3Pl04@H:01@93@0B
1`/05``@01072P0<1PP03`T;018<3P0D3Q003`T=00X4200A2`l04P/B01D>5@0F3aH05a0G01<94@0C
2Pl050X?00804`X?01004P/?018<400H4QH05Q0D00@00P0400<09b4U02DO8@0@2P`05a4C00d72@0I
4aD030H800l92`0@2P`04P`>0`0C3@l0200K5AL04P`>01H@4P0=1`T04`d>00h8200D3Ph050l=0P0C
3P/01`0D3`/05A0<00d81@0J5A807APE01HA3P0B3@X00P0G4Pl02`0F4@h05A0=01D@3@0F4@h05a8?
01HB3`0C3``05a<@01DA3P0M6AH05A4>008071PE00@06aLD01XF4`0I5A8061@A100J6AL01@0I61H0
5aHD01`K6@0I61H061LE00805aHD00h061LE01PH5P0I6AL061PF01LG5@0J6QP071`J01/K6@0M7A/0
ADE301dM6`0D518092@R01hN70808B4O02P0820O01lQ800P8R408b@V028V9`0P92L07R8U028W:P0V
;2`07bDS01HL700U:b/0>d=601XQ:@0U;3@0:34j061YL00S;C<09C0d02/f>00X<C@0;SHi02/c=P0Y
<SH0;SLl03@m@P11Be4082/a030k@@1RKWD0EF9Z03m<E00^>d80=45703Y7C@0iAT`0=T=903Q5B`0j
Add0?4U?0P0oC5804@0nBe40@4eC03i<D00oCE00>dQ>03Y7CP0kB540?DUE04=?F`17Del0AE5M04MD
G01<FEl0AUAH03i=D010Ce80@U5F0080@E1G00@0@U1I04QFG`17EEh0AE=K0P13DUL01`14DeH0D69V
04=EF@11DeL0A5IJ04EGF`1<GV800P16F5`01`1>H6@0GFmc065cM`1AHfL0Df9W055PI@1@Gf@00P1E
I6L0101AH6<0CEeM04IFEP18F5L204iNG@0J059RH@1@GUh0E69R05e[J`1KJFT0EVAT05]YJ@1MJf/0
GVa/06=aL@1RL700Hg5a06]iN@1VMWH0K7am071oPP1_OX40Lh6507Z7S@1mR8h0O8N>07j8T@22RYD0
PHVD07j6T@1oQY0207b3R`0508>:T01nQH/0O8>90869S021RH/00P1oQhT08`1nQXP0OHN907f6R`1n
RHl0MX6707j9S`1oRY00TIbR08>>U01oRY00PhjD086<TP1kQX`0OHR<07N2Q01cOgl0LGem06ahN01X
M780Ig=a06ijN01_NgL0KWYf06UeL@1RKVX0H6]W05eUG`1KHU/0FF1I05YPG01LIF80GVMT05aWH`1_
NGP0Ig5`0080HFe[01d0F6AT05i[K01VLG<0G6Y[06=_L@1TKg40F6EV04aJF`2>VI/0Y[:d04mMGP12
CDl0;Se003Q7C018Ee`0CUeQ051OHP1AH6<0CUiO04]KF`1:FUT0AeMF04=CDP12DU40@4m>04A@D013
CU00>DI703U7B00203]9BP1?04ABD`0nC4d0?4Y=049AE00c@D@0<cm202Xe=`0/=3L0:c4e024T:@0V
9b`0BTYA02@S:`0[:c<0:Rdd038e?00j?d@09RLY028T8`0V:2L09bTX024S8P0O82808b@V02`];`0Y
:Rh0<34e028S9`10@DH0:Bd`02hb=@0b=ST0?413038f>@0X;2l0;S8e03Lk?P0X;2l07b<V02L[;P0a
<cL092@V01dK700W9BH09RHX03Xj?01aLWH0=3Ll03i1AP0V:C008RL]01hR:P0M8RP08bP/02DY;@0L
82<08BDX04E7BP0R8bD06AXL01/L7@0O7al08B4Q020P800M7Ad06ATI01hN7P0B4Q808B4Q01dL7@0X
9RL08AlP01lL7@0M6AX07QXK01hI6`0K5aP07ATJ01TG600201LE5P0:01PF5`0I5aP061HG014?400K
6AX07A/L01HD5@0J61T05a<D01TE5P806QHG00T061@E01LC500D4140510A00`82@0P71d0920Q00l;
300J5QD00P0H51<00`0M6AP0920O02LS8P0201PD4`0601HB4@0C3`h04`l>01DA400D3Q005Q0B0P0G
4A<0300D3Q004`d?010:300@2P`06Q@F01@>400I4aD04@/=01@>3P0E3`l05Q0@01D?3`8050h>0`0E
3`l02`0D3Ph04`d=01D?3`0<1PH03@L701lI6@0E3`l03`T901@>3P0C3@d04P`<00804@/;00P04P`<
01H>400M4QH04@H:00h41`0O51P02@0201dB5P801`0000@0714E028G6`0/8BD060d@0`0C2@X20188
2@0302<I6P0P5QL05`d>008040H70P0F30d01@0@1PL050X;01/A4P0G3@h04`T:00H04PP901404PH8
01@82P0E2@/04PH801451`0C1`T05@T;01<72@0G2`d05PX<01451`0B1PP050P802LK6`0_8b<02000
01lC4`0200l30`0=00d20P0A1@D05@T904<g=`1ZGUh0300200h3100M4A<060`>01<72@0L41804PH8
01@82P0401<72@0600P0000B1PP05PX<01dA4`1LD580D4A60P0A1@L0500B1PP04`L901<72@0B1PP0
3@4301041P0=0@<040@601P<3P0D20X04@D701<72@0M4A<05PX<01<72@0A1@L0RWj202`P90090040
3@<50P0E2@d201862P804`L;00D04PH:01452@0@10P04`L;01862P0201452@0901862P0>0`H02P02
01<72`0=0PD07A4E01D93@0C1`/04`@9008040@800h03`<70104200C1`/05``@01@93@0K4A@03`@8
01D93@0?0`L03@4501@8300I3A405`/?01862PD04@D900L04PD;01032P0A10/060`A0104200;0040
4PH700804PH600@04@H501050`0@1@<04PH60P0800009P0<0P<040@602@H6P0>10D03P8400X0000D
20X04PH801@82P0J3Pl040@401@8200F2PX04PH600d10@0@10@05@T901H:2P0K3`l05PX:01<8200@
10@04@D501@8200C1`L04@D500l30`0C1`L04PH60104100?0`<040@401<71`0I3@l060`>01T=3`0=
0@<06@d?0P0?0`D02`0B1PP05@T;01041P0>0P@04`L901041P0E2@/06Ph@01<72@0?0`D04@D700P0
4PH80P0@10H20186200601<72@0@10H050P:01P<3P0F2P`04@D75?ooool001_ooooo01804PL;01@9
3@0C20`04`P<01@93@0B1`/040D900`31@0<0@D08aPL00`21@0A1PX0714E01lD600>0`L06PlC0146
2P0<0@D201462P0501052@0B1`/04`P<01<8300D2@d00P0B1`/0300C20`04PL;01462P0A1PX03`@8
00h31`0B1`/05``@01P=4@0D2P/05@/<01882@804`T:00<03P@50147200A1`P00P0B20T00`0A1`P0
40H701<920020147200E01882@0C20`04`P<01`A5@0@1@/03@8801H;4@0R5al06Q0D01061`0>10D0
6Q0A00/10P0E2``040H701X@4@0m<c@050X;01`B4`0<0P<05P`<00804`T800`04`T901<92P0C2@X0
40D801dB5P0F2a405@X@00/01P0B1`d03`D601<91`0C2@P201881`804PP901D0718C00h31`0A1PX0
4@H:01dB5P0:0P@02`D701XD5P090`D02084018<400F41@07QPL00X42P0700L03`P?01XA6@0D2A40
50T?01D93`0D2@l00P0C2Pl02P0E3a<0100201/F6P0=20`05Q@G08f8S02ESi406A<E018<3P0@2P`2
018<3P03010:300A2`d04`d?00<04`d?00T02`D701LA4`0L5QP030H801@>3`0E3`l05Q0@01D?3P0C
3P/00P0D3``01`0D3`/04@`901D@3@0F4@h050l<01<>2`0E40d01P0F4@h03@0[9b@05A4>01hJ5`0N
6QL06aLD01LC400J5Q<06aLD01`H5@0K5a@06QHC01PD4@0I61H00P0J6AL02@0I61H05aHD01HE4`0M
71X06APF01PG5@0G5Q@061LE01TH5P0401dM6`1<01hN700O7ad06a/I02<S8@1;BdT07AdK014A3`0R
8R008R<N020Q700N7aX06a`H01dO700O8Ah092HU02<W9P0P92D07R8S028X:00V;2`092XX01TO7`0/
<S80ATiA01lV;P0T:c<0<CY30;o8c`0d?T<06bHZ02D`<P0`>C`0;3@g02H`<P0T;S40:34f02dh?00X
<cP0;3Lm02`i?`16DeX0@e1H030mA@0a?TH0>dQ@045>EP0oC5@0>dQ@03m<E00nBe<0>DI>03Y7C`0o
C5@0@4eE03e:DP0d@DP0@TmE04EBFP0oC5H0@4aH03U5D`0mBEL0BEES04A@GP13CeX0AeAL04=@E`0m
C4l0?4]>03a;D00oCUD0@DmH049@F`18EV40AUAM04=BFP80@E1E00X0@e9E03e?D`11DUT0@U=J04MH
G`0mCUD0AUMN04QIH01=GVD0CUmV0P2M[[D01`1@HFP0E6=X059QIP1AH6D0E6=V05ETI`1AH6<00P1:
FUX08P1=GE`0CUiM04eMG01DI6<0F6IV05UWI`1GIFD0DV1P05=QH@1OKFd0H6i^05i/K01VM7@0JgUi
06QfMP1WMGH0JGQk06]jOP1]O840L7n407B2R01ePXX0O8J?07f7T01oRI<0PHVD0828U01mQI00OHB>
07b3R`23RY80UYfS08J=T`1lPhT20828R`80OhN905d0OXJ807b6R020RHh0PXfA07j9S@25T9@0Lgj2
07Z5R@1nRHd0MX6507^6RP20Rhl0OHR<07b7R`1eP880LWin071lO01]NGT0JWId06UeL`1/N7H0KGUe
06ahM01VLVh0GVYV05aWH`1NIV40Ff5M05QNFP1GH5/0FV=P05aUHP1`NWT0NhN506ahMP1PK6`0G6QX
05APH01FIFH0GVa]059RHP1HIfL0EfEV05m^KP1=GEd0Df5R06YiNP1FIVH0BUQI049BE01;FUl0Df9W
051OH`1>GF00CEaO04aKG@19FET0AUIE04=CDP11DE00@51?03i=C@0nCDX0?Ta<03U7A`0kBDT0?4Y;
03e:C01;EUX0@TeA04A?E@0oC580=T57034l@@0_>S`0=Si1020U:@0f>Ch0<34f02/[<@0Y:2h0>3Tn
03Dh?@0m@4D0CeAH024R900R92<0:2XY02T[:P0S9B@07b0R028S9@0a<S@00P0W:2`00`0U9RX0BT]@
02@X:`0202P/;`0Y038f>@0/<3<09b/^02P/;`0^<SD0:Bd`01dQ900R9RT08bHY02LW:@0M7Al08R8T
01/K7@0];Bl0HF9V020Q9P0^;c@07R4V02<V;@0R9R`08BH/01dR9P0U:Bd061`O028V:@14AdT08R<U
02PY:`0Q8B80820P02<S8`0O7al05QHF02PX:00J6QX0:BTY038b<P0E51D0928S024O800N6a`00P0M
6AX0100M61X06aLH01hJ6`0J61T201PF5`0D01TG600J61T06ALH01LE5P0N71d071XK01DC500K6AX0
5a<D01TE5P0J5QL06ADF01LC500E4A807QXK024M7P0O6a`061@E01LC500I5AH201DA400401HB4@0H
51<06aLF01`H5`806ADD00H05a<B01@@3`0F4Q405a<B01H@4P0G4A<201PB500<01H@4P0E3a4071HH
010:300K5AL04P`>014;3@0J51H04`d=01D?3`0F41005@l?0P0C3@d301D?3`0401@>3P0C3@d04P`<
010:2P<03`T900@04@/;01@>3P0C3@d04P`<0P0A2`/03`0B30`05@`>01@93@0>0`L060dA01T>4P0=
0PH060dA02dR9P0Z7b<040L907Q]L@1gK7003`@70147200201882@090147200@1PL081HG01hD5@0H
3Pl04@L801061`0D2P/04`L900@04@D700<05@T;01<72@0C1`T0100C1`T00`0?0`D04@D701<72@02
01<72@0T01H:300E2@/03P8400l31@0F2P`05@T;0186200P51@0?C4a044e=@0@10@0=RXZ020D500G
2`/04PH601451@08000040H601451@0:00004`L901H:300<00803`D601<72@0F2P`04PH801451`0E
2@/05PX<01041P0J3Q0060h?01451`080000:1`N0P0A1@L20186200A01451`0C1`T050P:01041P0F
2P`02@0000d10`0I3@l02P0001041P0O4aD0?C4c01@82P0800004@D700h21P0?0`L00P0E2@d0100@
10P04@D901862P0B1PX201<72`0301862P0A1@T04@H:008050T=00/04PL;01462P0B1`/06Q4C01D:
3P0700006@hB00L0000@10P06@X?01H52`0201<42@0>01<72`0D20`04PL;01@93@0600006a@F0189
300A1`X03`<700d11@0C1`/06@dA01L;3`0C1`/501452@0T01@8300>0PH04PH:01X>4P0>0PH03002
01041P0B1PP04PH601451@0@10@040D301D92@0K3a40300201X>400800002@0000l31@0K3a404@D7
00d3100L41803P8400X0000800003@<301D92@0B1PH040@401H:2P08000050T9075UI@0Q5AD040@4
0P0B1PH04@0A1@D040@40104100A1@D04`L701861P0@10@03`<30104100C1`L0710B00h2100<0080
3`<501L;3@0B1PP04@D7008040@60P0A1@L01P0@10H03`<501D92`0I3@l04`L900l31@L04PH80P0A
1@L201041P804@D700H04PH801451`0B1PP05PX<01L;3@0@10HDooooo`006oooool03P0C20`05@X>
01462P0A1PX05@X>01<8300A20X060dA01872`0@1`T04PL;01L<400D2@d040D90P0E2Ph01P0G3100
9a`P01D:3P0D2@d04PL;01462P804PL;00<050T=01<8300C20`00P0C20`301@93@0401<8300G3100
5@X>00l4208050X;00D040H70147200C2@X040H701882@0301<92P804PP901`04PP701061`0@1PL0
50X;01@93@0C20`04@L:01X?5@0D2@l04`T>01873`0P5QX06Q0A00l51P0B20T050X;01L=3P0E2``0
3`D600l71`0O5AH0KF=T01hD5@0@1PH04PP701<9200C2@T050X:0P0D2P/0500C20/04@H;01D:400T
6Al09a`R01H;3@0B20H04PP701<9200D2PT050X;01H<3@0G3@h0308503@Y;@0E2Ph0714E01L>4@0=
1`T03@P90P0@2P`06P0C3A4040X>01LA5@0B2a8040T@01@=500J4aX04@@=01<5300D1`h05PT@01H;
4@0G3Q<04`dA00l;3P0F4aH06aTL01XI6`1/Jfh0GEUJ01dG6@0G4A<02P@600`6200D3Q004P`>0`0C
3@l04P0B30h04@/=01@>400I4aD02@@501`F600B30d07QPH01D?3`0C3@`04`h;01D@3@0G4Pl05Q4=
01@?300C3P/04Pd:01@?30805A0=0P0F4@h201LB3`805Q4>00P0;2PV01@@3P0I5A<05Q8@01LC4@0K
5aD05a<A01TE4`806aLE00<06QHD01PD4P0H5aD00P0K6QP0100I61H061LE01TH5P0I61H201PG5@09
01XI5`0K6QP071/I01/K6@0I6AL071`J020P7P0L71X061PF008071`J00/07alM01/K6@0K6aT05ADB
020Q6`0P8A`07b0J01`M600L7QX07R0L028T800201hS801;01hS8@0N92<07bDT02<Y9`0S:BT092XZ
02<[;P0L8b/09B`d030i@P2KY:/0<C]102<^<P0V<C<09c4c02Tb=00[=CL0<3Xm030j?`0_>Sh0;cXo
03I2B00[>3h0=45802Le?@0a?dL0<T1803E2BP0iATh0>4E=03I3B`0iATh0>dQ@03Q5C@0f@d/0>TM?
03a9D@0jAdl0>TM@041>F00lBED0AU=Q059NK`1AGFl0EF5c059OK`18E6D0@DiL04AAF`11CeL0@4mD
03a;CP0oCU@0CE]T055OJ01:F6<0A59M04IDG`15De`0?TeD03a;D010Ce<0GVmf06n0Q`14EEd0BeaU
04AEG01fQhl0DfA]05=TK01<GFD0KGj70721R01=GVH0DF1V0080DF1U01L0D5mR04mNH@1>GF00BEUI
04]KF`1>GUd0D61O059RH@1CHf80FfUY05ITI01CHF40EVAT05QVIP1EHf<0G6YZ061^KP1^O7`0LX20
06YhN01SLG80JgYn06imP`02071oQ@0507>1R01fPh`0O8J@07j8TP1oRI<00P1oQi802@1nQY40NX6;
08:9T@2=U9`0YZfc08fDVP27SY@0OHF807j6R00207n7R@0;07j6R01lQXL0NH:707b7R`1mR8`0NXF9
08B?T`2CWZ80OHR<07b7R`1gPXH00P1fPHD01P1bOH40Lgj0075mO@1_Ng/0K7Qh06YfM080JGEc0200
J7A`06IbKP1QKFT0FfMS05YUH@1NIV40G6=O05YRG@1IHUh0FV=Q05YTHP1SKF`0HVi]05]WIP1HIFD0
GV][05m]K@1IJFT0G6e]06=dM025UYH0EVMW05AUI@1[O7`0DV=S05Y[J`1_P800BU]K04YJG01?GF<0
CeeR04aKG`80D5iQ00@0BeYK04EDE010Cdh0?Da<0P0oCTd0800lBdT0>TU503Y9A@0kBDP0?4Y:03e:
B`0nBT`0@DaB03DoA`11BU@0>T=>03]4D00^>400>DA70459C00X;S80<cHk02//<@0/;380<C0e038c
=`0T:2`0720T02P]<@0X:B/0:R`[02`^;@0Z;2/0:bd/02h_<@0U9RP0;Rla0P0W:2`0=013A4P0@T=8
02@W:P0/;S40:2/]02/]<00X:Rd0:2/]02T/;P0T9RT0:B`^01lQ900P8bD08bDX02<T9`0I6Qd07AhQ
02LX:`0R8RD08B8V024R9`0_<3D08B<X02<V;00M82H061`R01XO8`0T:B`092P[01hR9@0N8B<09BHX
02<T9P0O82407alO020P800O7al06a/K01PH601KFe/0FEUI01@D500f=CD08b4R01hL7@0K61T06aLH
01dI6P0M61X06aLH01`H6@0J61T301TG600801PF5`0G5AH061HG01HD5@0I5aP06aTJ018@4@0H51D3
01TE5P0501HB4`0E4A806ADF01TE5P0E4A800P0K5aP01`0B3Pl06QHE01TE500H51<05Q8A01<?3P0B
3Pd00P0F4Q401@0E4A005Q8A01XF5@0M6AP0618C00<05Q0A00T05a4B01PB4`0B30d0618C018<3@0H
4Q<06Q@E01@>3`0C3@d00`0D3Ph201<=3@<05@l?00H050h>01<=3@0@2PX050h>01H@400A2`/201@>
3P07010:2P0B30`04@/;018<300C3@d050h>01D<3P0201@93@0:01P=4@070000:b0T01<8300B2@/0
5@`>01@93@0D2`d06@hB01@930<050X;01L05@/<01L=3P0E2``050X;01D;300G3@h05@/<01882@0A
10H04`H801L82`0H20/05PP;01P9300F1PT050L901D72@0F1PT050L901D72@0E2@/05PX<01L;3@02
01@82P0301H:300`92H08ADG00804PH801804`L90186200F2PX04PH601H;2`0C2@T06`l?00l51@0@
10@03`<301L;2`0C1`L05P/;0104100E2@/050P:01451`0I3@l201@82P0T01H:300A1@L04@D701D9
2`0F2P`040@600l51P0H3@h0308301T=3`0@1@H060`>0186200D20X04`L901451`0C1`T05`/=0104
1P0C1`T05`/=01<72@0>0P@05@T;01P<3P0E2@/0:AdO028F600E2@/050P:01@9300?10L050P<01H:
3P0@10P03P@60P0B1PX201<72`0301862P0A1@T04@H;00805@X?01L04`P=0187300B1``05@/?0105
2P0I3Q<04@H;01062P0D1`d05`D;01H42P0E10X05@D:01D62`0C1`/04@H:01<:3@0R71h0ZJFV089m
OP0N5AP050P<01452@0201862PL04@D901X04`L:00X00@0@10L04`L:00h21@0C1`T040@60186200B
1PL04@D60104100@1@@03P<401hB500>10D04`P900l31@0=0@<04@H701041P0>10D060`>00P0000I
3a00ACTj01/?3`804@D500h03P8201861P0B1PH03P@401<71`0k;bl05@T901451@0C1`L04PH600l3
0`0>0P803`<301861PH04@D500<04@D70186200E2@/00P0@10H0100@1@H04@D701041P0@10H30145
1`0301041P0B1PP050P:00T04PH80P0@10H201451`8040@600H03`<50186200?0`D040@60186200>
0P@Dooooo`006oooool04@0C20`05@X>00h31`0>0`L05@X>01<8300B1`/050T=01P=4@0T6Ad04`P<
00h31`0B1`/03@<601D:3P0:00<05@X>00804PL;00<04@H:01052@0@1@T00`0A1PX301872`0601<8
300D2@d05@X>01@93@0=0PH03P<70P0E2Ph01@0C2@X05@/<0147200B20T05@/<00<04`T:0P0D2P/0
400C2@X04PP901881`0>10D040H701@:2`0D2@d04PL;04@i?@0700804PL=02DJ800B1`l07a@I00d3
100;0@8201D;300800L0000C2@X04@L80147200?1@H08QPI01882@0B20P201881`0b01<9200D2PT0
50X;01L=3P0>10D07a@H01462`0M4QP05``B00d3100A1`D04PP701@:2@0E2`X05@/<01H<3@0;0@80
60dA07M/L00T6Ad050T=0189300?2@/05@lA01PB50090`D03PP<018<400?2@d04``C00P1200<1@`0
7QHN01L74@0H1`l05`P?01D83`0D2@l04`X?00h8300E41@0>cTl09NGV@0n?T006QXL01HB4`0I4aD0
2PD601hH6P090`D401@>400G018<3P0A2`d03`T;00P2100O6A/05a4C01TC5@0D3`l0ShV901/E5@0F
4@l050l<01D@3@0D3``040/7014<2@0E40d05a8?01HA3P0E40d05a8?01D@3@0F4@h00P0G4Pl03`0F
4@h05A0=014=300E4A005Q8A01<?3P0_:bX0>cLf018>3@0F4Q406QHE01/G5P0J5QD061@C01PG5@02
01dL6P0701/J600J6AL071/I01@C4@0F5A<05aHD01XI5`0201`K6@05024Q7`0M7A/08b<Q02/[:@0S
8b400P0J6QP0<@0E5A<09RHT01XJ600J6QP06a`G01TJ4`0Q8Q`092DO028S7@0N81/07AlJ02<U800N
8al07b@P02<X900O9B<06b4O02@Z:00Y;bl09B/[01lW:P0Y<3P092/c02@]=P0d?D@092hd01hY;@0a
?3h0;CLi02/e=`0Z=3H0:SDh02dh?00_>Sh0=415030m@`0S<3H0=TA;02`k@P0jBE00;Sa403A1B@0e
@TX0=T=;03M4C00hADd0?4UA03i;D`0mBU800P0gA4`0=`0nBe<0@e5L03Q5E@0oC5d0K7V;05MSN@0n
BV00Ae=Y04QEJ010CEh0?T]K04UGI01=Ff@0>dY?03M6B`10CeH0EfE^05]YLP17EF00?deH04ECGP1:
F680A5=J049AF01:FEh0/<790;31b`16Ef40DF9/03m@FP1EIW00CEiX03Y;E@1JJgD0A5EO051QJ`1C
I6d0BeYQ04iMHP1@Gf@0BUUL04QGFP19F5/0B5QH04EEE@17EeH0DV9Q05QXI`1BHV40EfEU05m]K@1G
IFD0CUaL05ESH`1VM7@00P1RL7003@1TLW80Hg5a06IdM01aOh00JGQm07B3RP1eQ8/0Kgj5075oQ`1l
RI80OHNA07j8TP1mQi400P1mQI009P1oR940PXVA08>:TP1iP8P0RY6G07V0QP2?UY`0NX:507b4Q`1n
QXP0OhN907j6R01lQXL0OhV;07AoP`1oRXh0OXV=08F@U01oRXh0OXV=08nJWP21S900MX6507N2QP1c
OX80Lgj0071lO01]NGT0JWIf06IbL01ULFl0JgMe06QdL01ULFd0HFeY05iZIP1MJFD0FfAO0P1LIF00
8@1MIf<0G6IU05aVI@1HI680FfMW065]K@1LJVX0EF=S05EUI01IJVX0EfUY07^=S@31dm<0FVa/05]]
K@0lCTh0BE]K055SH`17FET0Ffe]051NH@1@GF<0BUMM04UFF`1>G5l0BeUL04IDEP12D540?4Y:03Y8
B00lBTX0?D];03i=BP0203a;AP1O03i=B`0nC4`0?dY<03i9CP12C5D0?dMB03e5D@0V;S/0?TEE03Do
B02nbLd0b];E03Pm@@0f>Ch0<34f03<c>00j>Ch0<S<g02lc=P0Q9BH09R/]02DW9P0Z;2/0;S0_02T[
:P0W:BP092DW028S9@0S92H08b@X02d^<P1NGf<0:BX_02DV:P0`<C<0;2d_02PY:`0S92H092DW02LX
:P0L7Al0<34c02X[;@0P8B<071dO01/L800S92P08R<W01XK7`0G61`09BHZ01dN8P0[;3007b0U02<V
:`0Q92T07b8W024V:P0b=cX08RHY02<W:P0W:R`06Q/M02PY:`0];Rl0:2PX01hN7P0K6a/08R8R01XJ
6P0Q8B407AdM02<S8`0^;Bd06aTJ01XH6@0I5QL06ADF01/G600M61T06aLH01PD5@0H5QL06ALH01PF
5`0F51D0518C01`J6`0J61T04Q0A01lM7P0[:BX03`d>01TE5P0H51D00P0G4a@201HB4`0801PD5@0D
414071PI01TE5P0D41406QHG01TE500G4a8201HB4@<05a<B01405Q8A01<?3P0B3Pd05A4@01PD4`0G
4A4050h>018<300C3@d05Q0@01PB4P0G4A405Q0@00h8200C3@d050h>01H@4005018<300<01<=3@0E
3`l05@l?01D?3`0D3Ph04`d=01D?3`0B30`03PP801@>3P0G4A404`d=0`0@2PX02`0B30`04`d=01D?
3`0F3Q007Q<G01`A5@0G31007a@H08EjOP0[82@060dA008040D900@06a0D01@93@0C20/050X;0P0C
2@X03P0F30d06@l@02HL7@0M4a@03`D601061`0F30d06@h@01`=400G1`X04@4401H62@0M3A0070`?
1P0F1PT00`0C10L04`L901@82P020186200J01@82P0G2`d04@D701041P0A1@L040@601<72@0A1@D0
4PH601<71`0F2PX02P0001<71`0@10@04PH601X>3P0B1PH05@T901<71`0J3Q003@<4028F6014>3X0
7a<E01<72@0@10H201<72@804@D700d04`L901@82P1@A4H02P0001lC5@0H30h02@0001<72@0E2@/0
50P:01451`0D20X06@d?008040@600<03P8401@82P0F2P`00P0800002`0H30h03@4301041P0@10H0
3`<50104200D20`05@T=00l31`0D20`07A4E00804PH:0P0C1`/01P0B1PX04@D900l42P0C20h050T?
01873@8040D;0P0U6R005P0700805``B0146300?0PT060@:01h;4@0Q3Q@07`hD01T:3`0D20`04@L:
01/B5@0D3Q00[j^/08>1PP0@20/04PH:01452@0@10P03`<701452@0C1`/501452@0701D9300>0P@0
50P:00l51P0?0`D060`>00l31@020186200K01451P0@10@040@401<7200;0040200001<72@0<0080
6Ph@00/10P0K3a4040@601061`0C1`T02@0001dA4P0A1@D03P<301@8200?0`<04@D501H:2P080000
5@T900/0000B1PH05`d=00D040@400<04@D500l30`0@10@00P0C1`L03`0B1PH040@401451`0J3Q00
3@<400P0000J3Q0040@600h2100C1`T05PX<01041P0>0P@050P:01451`0200l31@0301451`0C1`T0
4`L900H04PH800D03`<501041P0A1@L04@D701041P0200l31@0501L;3@0B1PP03P840186200A1@L0
5?ooool001_ooooo0P0C20`201872`0401@93@0E2Ph05P/?01@93@804`P<00@04PL;01<8300A1PX0
4@H:0P0B1`/201<8300B01462P0F2`l04PL;01D:3P0G31004`P<01472P0E2Ph0304501@93@0?10P0
2P0301872`0H3A407Q<G01872`0O51P04@H:300C2@X0100B20L04PP901882@0B20T201872`0U01P?
4@0H3A<03P<902hS:@0O51`04PL<01T?400:00403P@501882@0K4A8040H701P>3`0B20T05`d>00L0
000Y7b003`H601881P0>10803P@301881`0D2PT04`T900d3100Y7b002P8201/@500800405@/;0188
1P0C2@P04PP701061@0B20T05@/<01H<3@0201D:3P804`P<01X040L:00l92`0C3@l04P`>014;3@0C
3A405@lC010:3P0C31<05a0G01@=502>QXh06PXD01T8400G20l05`XA01H;4@0@1``04@/?01<>4P0F
51L05ADG01<C5@0?41803PX;010:30<04P`>03@040X<01PB500B30h05Q0B00l92`0I4aD04P`>01/E
5`0?2@/06A<E00D00@0B30d05@l?01LA4@0I4a804`h;01D@3@0A30T07APD01@?300I51404Pd:01@?
300@2`P06QDB00h91P0H4a004`h;010;200F4@h05A0=014=300M6AP061@C014=300Q7A`05A4@00d9
200H51<05a<B01/G5P0F4Q407ATH01dL6P1MG5X051<A01TH5P0D4a408R4O01TH5P0E51805QDC0P0K
6QP0F@0I61H06QXH01/K6@0J6QP07QhL01dM6`0G5aD07alM01hN700I6AL08B4O020P7P0C50l08R<L
020Q6`0Q8Q`09BHP02DW8P0T9R407b4L02DZ9P0K81`08bPT024W9@0E6aT08RPV02T_;`0Z<30092`_
02@[<`0V;CD08BXc02@]=00V<3H0:SDi02lj?00R;Bl0<ci003e8BP0^>C`09S4e03M5B012Ce@0<d16
02He>P0eA4X0;ci502<d>`0c@DT0>4E>03a9DP0f@d`0=dA=03U6C`0kB540>TM@03Q5CP0jAe00@4eF
03i;E00nBUP0?DYK049?HP1GHgT0F6Al04YFKP14D6H0?T]N045>G`10CEd0?TaI05YXLP0nCE@0?TeB
03i=E010CUL0@DmJ04iLJ@19Ef@0A59M04=AF`12DEP0?diE045@EP1KK7@0BU]U04aMI`1:FfD0AUMQ
0080BEYT01H0BeaV04YKI@1=GVP0D65[04YKI017EUd0EfI[069aMP1HIfX0E6=V04iMH01?Gel0Be]K
04eMG01?Geh0C5aK05ATH`1KJFT0F6IV05ESH`1GIFD0G6YZ0P1QKfl0<P1VM7@0J7If06IdM01TLW80
IWAe06]jP@1/NX<0KWb5071oQP1ePh/0N8F=07f7T01kQHh0N8:;07Z3S01mQXl0P8VB08:9T@1oQXh0
O8>;0827S@24Ri40NX6707n7RP1jPXD0OHF707n7R@1mQHL0OXR907V3Q@1cOX00MH2207n:S024Si40
PXf?07R3Q@2?VY`0TYfO079mO`1fPH<0LWeo06iiN`1]NGT0KWYj06ahN01WLg40Hfm]06QdLP1QKFT0
GVYV0P1MJFD0201LJ6@0G6ER051KE`1QK6P0GFMV05QRH@1MJFL0E61P0P1JJ6P0601EHf@0EfEV05UY
J@1FIfL0DfEU05QZJP1PLW80HWAd05AVIP1>H600BUaL04eOG`1CIFD0DVAT059QI01@Ff40F6=Y09:M
XP19E5P0D5]O041;CP0mB4X0>dM703i:BP80@De=02T0?D]803i=B018Ee@0CU]J045=C@0nBD/0?TQ=
03HoB00oAE40@dUF03m5E@0m@e<0=Ce709RSY`2//kT0>Sm502@W;00e=SX0<c<h030_=00Z:bd08bLX
028V9@0R:2L092HU038d<`0a<c80:bd/038d<`0Y:R`08R<U02TZ;00[;300:2T]02//<00X:Bd0>CXn
04E6B00];S009RLY02DV:00202X[;@0C024R901QHV@0=cPj02l`<P0O82808bLZ01LJ7`0Z;C80<34f
02HW;00Z:bl0824U02<T:00M7R807QlS02//<00P92L08bP/02L[;`0201DI700I02<U:00J6ad061TK
028S900P82008B4Q02TY:@0R8R805aLG01/K6`0V9RH06a/K01`K6`0U8b@07Q`M01`I6P0M6AX07a/L
02@O800U8B8061@E01dK700>30d05Q@E01TG600201LE5P0B01HD5@0G5AH06ALH01PF5`0E4a@06ADF
01/G600O6a`05A4B01XF5`0Z9RL06ADF01DA4P0F4Q<04`l@01TE5P0D414061@C0P0I5A@0100J5QD0
Ee=B01DA400H51<201<?3P805a<B00d05A4@01LA4@0F41004`d=01PB4P0J51@05a4A01TC4`0<1PH0
3`T901LA4@0@2PX0618B00804`d=00@050h>01D?3`0E3`l05@l?0P0D3Ph02`0C3@d04P`<01D?3`0E
3`l01P0000h8201lMWH0618B010:2P0B30`06aDE00805@l?00@03@L7018<300E3@l05@X>0P0F2`l0
0`0G31006@hB01L<400200l4200401H;3`0C20`03P<701882PD05@/<02406Q0A01@:2`0B20T05P`=
01D;300C20X0404401D5200N3Q406PX=024A500H20/05@D801H62@0K2`h0400301D5200I2@`05PL:
00l31@0A1@L050P:01041P0D20X06Ph@02DI6`0G2`d07a<E01/?4@0=0@<05@T901861P0E2@T00P0N
4Q806@0C1`L05PX:0104100>0P804@D501861P0?0`<040@60186200G2`d06Ph@01L;3@0@10H04`L9
01L;3@0=0@<0300201H:300B1PP04`L901T=3`0J3Q0050P:0186200D20X01`0B1PP01`0E2@/04@D7
01hB500D2P/03P8401451`0C1`T00P0E2@/02`0B1PP04@D701<72`0B1PX091PL01D93@0?0`L050P<
01<72`0B1PX04@D900804PH:02804`L;01883P0C2Pl07QDJ00h52P0700<07A@I05M>D`0a:2d01P02
04PoA00B2@h06@`C01P42`0J1`d070T?01T83P0E1P/04PH:01872`0D2`h03PP:02@P8@0W9BH050`?
00/00`0?0`L03`@704Hj?P0H31003@4501452@0B1PX040@80P0C1`/01`0@10L03`<301@8200?0`@0
4`L901P<3P0?0`D00P0A1@L0400B1PP04@D701451`0?0`D06Ph@01D92`0>10D06Ph@00T0000>10D0
:alQ00l31@0>0P@040@600P0000G2``501451@0601L;2`0B1PH0304100l30`0H30`04PL71P0@10@6
01451@0>01P<3P0?0`D04PH800d10`0J3Q0040H701041P0A1@L040H701hB5009000050T:01<72@0B
1PP201041P0301<72@0F2P`03`<500804PH80P0@10H01`0C1`T06Ph@01451`0=0@<03P8401D92`0F
2P`00P0C1`T201451`0301041P0?0`Gooooo01?ooooo000Kooooo`0301H;3`0D2@d04PL;00<04@H:
00<05@X>01@93@0B1`/00P0B1`/00`0C20`04@H:01462P0201872`804`P<01804@H:01@93@0@1@T0
4PL;01H;3`0C20`050T=00h41`0A1PX040D901X?4`0i;S80F4eA02@I7@0>1@L050T=01P=4@0?1@P6
014720H04`T:02P04PP701<92P0D2P/050X;01872`0A1PX050X=01<:3P0@1@/05@X@00h32`0C2@d0
4@L801@:2`0e:b`06Q0A01<92P0>10D05P`=01L=3P0U6a`06@l@03H/;@0I3`h060h;01T?3@0G3@/0
4PP701471P0D2PT05@/;01061`0C20X05@`>01L<400D2PX050X801H<2`0D2PT04`T80P0D2P/00`0B
20T04PL;01@93@0201D:3P0301@;3P0C3@l04P`>00803PP:00<040X>01<=4@0A2`l00P0G41L0400;
10/0;bL_01D84@0F20l05`T@01X=500I3Q@050/@05A>DP0n>Cd061DH00X82`0=30h03@`?00h:2`0@
2P`2018<3P0H014;3@0@2P`0:28T0:ZTYP0S7Al06aDG00`7200@2``04@`=01hH6P0>20X06aDG01LA
4P0>20P03`T901LA400@2`P05Q4>01D@3@0D3`/06aHC020K600A30T050l<0P0G4Pl02P0D3``05Q4>
01@?300C3P/06aHC02HQ7P0K5aH05a<C01hJ6P0F4Q8301LC4`0A01TE5@0L61P0:2@T024M7@0I5AD0
61LE01dL6P0?3Pd06APF01`K6@0G5Q@07QdK01/J600L6aT07ahL01hM6`0L6aT00P0P81h00`0M7A/0
7alM01dM6`0201PH5P0901XJ600I6AL09BDS02PX9P0O81`07b0K01/L5`0L7AL07b0J00807b4M05<0
828N020U8P0M8Al09b`Z01/Q800Q9bH08RPV028X:00T:RX09blb02L^=P0U;3@092df02H_=P0W<CL0
9c8f02/f>00X<cD0;CPj02`g>@0]>3/0;CXm02dk?P0`?T80;Se2030oA00`@4H0;Ce402m0A`0eA4`0
=T==03E2C00e@D`0?T]E04EAG010CEL0B5AO04aIH`11CUP0?d]F03m<EP0mBET0?TaP04YHK@1ULhT0
IWB;05QUO@1:F6h0B5IY055OLP1:FFL0?dmI045@FP1:FF00B5MM04ABF`11CeX0?deH04]HIP15DV40
@e5N04ECGP16E5d0A5=J04IEG01cQ8`0EfQ_04MHH013E5d0AEIN04aMIP19FV<0BeaS04]LI01=GVL0
DV=Z04iOI`1AH6H0BeYO05QWK01QL7<0Df9U04UHF`0204eMG@0I051PG`1>GUd0Be]J05=SHP1KJFT0
FFMW05ITI01GIFD0G6YZ061^KP1SLG40IG=c06IdM01TLW80IG=c06QfM`1[NX00JWV106akPP1`OhH0
M8:807B1R01gPXT0NH>:07Z5RP0307^4RP0I07f4S021R900Q8^C07n6S01kPXP0PhZ@07Z2Q@1fOX00
NH6307b4QP1jPX@0NhF607j8RP1mR8X0NhJ807Z5Q`1lQhT0OXV;07J1P`1iQ8H0NXF706mjO01gPX@0
LGan06ehNP0306ahN00606McL@1TL6h0Hfm]05]WH`1HI600FVIR0P1LJ6@0>`1MJ6@0GfUW06=^J`1O
JVP0GFUX05aXI`1OK6`0GVa/05QVIP1LJf/0Gfi`05YYJ`1EIFD0DF9R05AUI@1CI6@0CUmO05=TI01=
GUh0BeaL04mPH01BHf<0Cf1P051OHP1=F5h0EV5W059MHP14Ce<0Ae9F03]6B@0oBT`0@De=03a8B00g
@d<0>TI603a9B@0jBDL0?Da:045>C`0lAdX0?4I;03m8D@0h@4T0?45=03i3D00l?dl0>Ca<02T`>P15
D5@0?dI<02L/<P0a=3T0;c0d038b=P0_;c40:R//02DY:00V:RP09bdZ0080:bd/00L0<38a034c<P0/
;Rd0:BX/02PY:`0^;c40;Rlc00809RL[03P09bP/024R900X:BX0:b//02HW:00Y:R/0;2`]02@T9@0S
92D0:b//01hO800/;Bh092DV01hQ9P0M8BL09BP^01/M8P0L7R<07QlS01XK7`0R8bL08R8U01dN8@0V
9RT092DY02@W;00M8RD07R8U020T9`0Q8bH092DW01lP8P0P8240820P01hN7P0K6a/06ATI020P800O
7al0:BTY01lO7`0J6AT05Q@E01XH6@0L6AX07QXK01dI6P0M61T06ADF01hJ6`0G5AH04a4B01PF5`0L
6Q/05A<D01PF5`805aDF02X06ALH01PF5`0E4a@06QHG01@@4@0G4a@05A4B01dI6P0[9bP06ADF01LC
500J5QL05a<D01`H6@0F4Q<05A4@01HB4@0I5A@05Q8A03Lc<P0?2`X05Q8A01@@3`0F4Q406ADD01HB
4@0B3Pd05Q4?01PB4@0F4@l06QDC01TD4P0D3Pd04`d<01D?3P0D3`d06A<B010;2@0E3`h04`d=01@>
3P0F410301D?3`0901LA4@0F410050h>018<300D3Ph04P`<01HA4@0G4A40;2HV00808A/K00T04@/;
00`61P0[9BD0PWal014;2`0G4A404`/=01@93@0C20`00P0E2Ph0200B1`/04`P<01H;3`0A1PX040D9
01<8300B1`/05@/=1@0D2P/0500B20T04@L801882@0D2P/05P`=01H;3@0L3a405`X<01`>4@0H20/0
408501L82`0O41<04@@601D72@0E1@P050H901<51`0E2@/050P:0P0C1`T02`0D20X05`/=01<72@0H
30h03`<5020D5P0T61X05PX<01<71`0B1PH04`L700805PX:00<04PH601@8200D20P00P0C1`L20186
1P080186200A1@L04`L901D92`0C1`T03`<50186200E2@/201P<3P0801L;3@0D20X04PH801D92`0D
20X040@600l31@0C1`T60186200501<72@0B1PP05`/=01@82P0]8B<00P0A1@L02P0C1`T05@T;01D9
2`0B1PP04@D704@h?00?1@L06PhB01/?4`0A1@T201<72`0901862P0A1@T04PH:01862P0B1`/050X@
01493P0D2a404PT?00804@P>02<081LM01D<4P0M4aX0>30e020G7@0C2@h05PD;01L52`0G1P`05PH<
01D62`0B1PX04@H:00d41`0<1PP04@`>00l:2`0>1PT03P<601P<400C2@/0<BDY01872P0?0`L04@D9
01<72`0B1PX04`L;01452@0@10D040D401861P0B1PL04@D601<72@0201451`0A0145200B1PT04@D8
0145200B1PP02`010147200g:bd06Q0A0187200D2@/0200001451`0E2@/04PP901051P0>0`@01@0A
1@D01P0C1`L04@D504Lk>`0H3Ph06@d=00l51@H040@41P0A1@D0300:000050P:01@82P0=0@<04@D7
0146200B1PP04@D70186200=0`@050P:00h41@804@D700L04PH801H:300L418081@F01<72@0@10H0
4@D700805@T;00P04PH801H:300@1@L05@T;00/10P0D20X04@H701041P<04@D70P0B1PPDooooo`00
6oooool00`0E2Ph050T=01462P0401052@0501872`0@1@T04@H:01D:3P0D2@d00P0A1PX201872`<0
4`P<01404PL;01052@0A1PX050T=01D:3P0P5AT050T=01X?4`0A1`X05``@03hc=`0F3@l06PlC028G
6`0<0`D05P/?00T00P0601<92PH04PP903804@L601<92P0D2P/050X;01462P0@1@T0Bd1401<83P0F
2a406PlE01873`0E2Pl03`D601H<3@0m<c@06Q0A00l51P0A1`P05P`=01061`0B20T02P01020F5`0C
2@P06A0;01hD4P0I3`d04@L501061@0D2PT0718A01L=3P0B20T05`d>01D:3P0=10<04PP601<9200B
20L040H501882@0D2P/04`T:01<8300B1`/04@H:01052@0?1PT03PP:010:30803`T;01<04P`@00l9
3@0>20`03`P?01<<4`0F3aH02`<;01463P0C20h05`/A01P=4`0F3A804`X?02LQ9@0H4QH01`8600h9
3@0E4aH05a8F00804@/=0`0B30h06P0A2`d03PP:08^5Q`1ECe408A/M010:300G4A<09b4S071ZK017
@D<05a4C018<3@0K5AD0:bDU02LR800=20D04@`901HA3@0B3@T02`H301lJ5`0=20D03PT601LB3`0C
3P/04@`90P0L5a@05P0C3P/09b8O05E@C@0V8R<04@d>01<?400E4A807ATJ01HB4`0H51D05A4B01LC
500V8R<081`M01@@4@0H5aD040l=01TH5P0G5Q@06aXH01dL6P0L6aT301/J600801TH5P0H5aD071`J
01/K6@0H61H06a/I01XJ600E5A<201hN700801/K6@0O7ad07alM01TI5`0R8ah07AhI01`M600O7a`2
020R7`07024S8P0D61L0;30a01`P8@0/<S80:2h^02P^;00202<Y:@0M02@/;`0R:C4082L_02Pa>P0X
<CP0:C<i02D`=00V<C<0:3<e02dh>P0`>cd0;S/m02/i?00]>ch0;Ca002Th?@0a@dL0;3i303A5C011
DUT0=TE>03I2CP0g@dl0?DUE049>FP0nBUH0>DEA04aHI01CGf/00P11CET07P15DEd0A59R04=BI`15
E6T0E6=i05QWOP1EI7/0CEab04QGJP19FFT0>daH03m@F014EE`0AUEL04EDF`16E5d0BEMR04]IIP1J
IgL0C5UY04QEI@16E600AE=L04=AFP17EUd0?DiE03=4B`13E5/0Cf1W051QJ080BU]R01L0CEiU04aM
I01:Ff80CEiU04]LH`1FIFX0BeYO055PI@1LJfh0E6=V04eLG`1>GUh0Df=S05MWIP1CHf80D61O05IV
I@1KJFT0F6IV05ITI01GIFD0FVQX05e[J`0206AbLP0Q069`L01SLG40IG=c06QfM`1[NWl0J7Mn06Yi
OP1_OX<0LX2506ilO`1dOh<0MH2207J1P`1gPH<0Mh6207N1P`2d^l40QHbD07MnQP1mQ8X0NX6707b3
R@1mQHP0NH6407j6R021RH/0OhN907n9RP2nb<X0SiZL075lOP1kQXP0NXF70080LGan00H0M7n107F0
PP1eP880LWeo06YeM`1[MWP206UeM@2706YfMP1VLW00I71^05eYI`1GHel0EF5M05UUH@1MJFD0GVYV
05aWH`1NJ6L0HF]Z05m[J@1NJVX0Gf][05aZJP1KJFX0Gfe^05a/K01EI6L0EVEX05MWI`1CHF80D61P
05QWJ01@GUl0D5mO04UIF@1<FU/0DF1P04mOG`1<FU/0Ae=G04mJH01:EE/0CeYO04E@E02Z]KT0DEaO
049=C`13Cdl0?TY:03Q4A00kAdL0@4e=03e<C`0lBTd0?da?041;D@10BE00?dM?034h@P0a=D40<CA0
034c@00`<T40:2lh030k?`0Q:2h0;S<i03<f>`0W:2`0<S8e02PX:00U9bD08bPT02DZ900W;RL0=3Hc
038d<`0e=cH0=SPg034c<P0];S007QlQ02TZ;00e=SX0<34e02LX;00P8BH0;Bd_028R8P0V9RH05aLG
01`L700V9RH08B4Q01`L700O7al0@D5103@d=00S92D0:B`a028W;@0U:2l082<X02DX;@0V9b`06AXN
020Q9@0R8R@07QhP028R900P8B<08BDX01dR9@0O8bH082@W01dO8P0L7Al09RLY01lP8@0S8b<08B4Q
01PH600M7Ad06a/K0451@@17AdL07alO01/J6`0j>3T071XK020M7P0P71d07QXK01`G600J5QL07ATJ
01/I6P0H5QL040h?01HD5@0K6AX061HG00805aDF00P061HG01LE5P0D4Q<06ADF01PD5@0M6AX06ADF
01<?4080510A02<05A4B01TE5P0G4a@06aLH01<?400K5aH04`l>01HB4@0B3Pd06QHE01TE500D40l0
5Q8A01/G5P0N6QT05Q8A014=300D3``05A0=01<>2`0G4Pl05Q4>014<2@0F4@h050l<00d81@0D3``0
4Pd:01@?300C3@d05@l?01H@400E3`l04`d=01D?3`0201PB4P0@01D?3`0B30`04`d=01XD500H4Q80
BD=301@>3P090`<08A/K00h8200O6AT05@l?02XT90090`<06aDE01072@804@H:00D06PlC020E6@0L
4AD04`P<01L<400301P=4@0301872`0C20/04`T:00@04`T:00@040H701@:2`0E2``05@/<0P0H3Pl0
6@0F2P`09a/M01P<3P0A1@L07A4C00l51P0;004050P:01/?4@0=0@<05PX<01D92`0<008050P:01L;
3@0F2P`060`>01451`0H30h06@d?0186200E2@/05PX<00/10P0B1PH00P0C1`L02`0?0`<03P820145
1@0?0`<05@T901H:2P0C1`L04@D501<71`0G2`d05@T;008050P:0`0C1`T02P0A1@L07A4C01hB500E
2@/060`>0186200C1`T040@600d10`0?0`D70186200801dA4`0:00006Ph@01`@4P0o<cD04`L90186
200C1`T201@82P0;01<72@0B1PP02@0101L;3`0B1PX02`4301L;3`0A1@T04`L;01862P0A1@T00P0B
1PX01@0B1`/02`<900H0100600@040H>00806@lG01L03@<;01L=5@0600@06@lG0516CP07008050D;
01@32@0B0`P04`@901452@0B1PX03`@801872`0?1PT03PH90189300B20`03P8601X>4P0D20`06`lC
00d11@0201862P0>01<72`0B1PX05@T=01D93@0B1PL040D300h20P0C1`L03`<300d10`0C1`T04@D7
01452@0B1PX201452@0=00l31P1SEeT06Ph@01@:2`0M4A<040@601L;3@0S5aT040@601@82P080000
7a<E01<7200501451@0600h20P0800007a<C00P0000900003082300A1@D0300C1`T05`/=00h2100D
20X0300200l51P0E2@/04PH801T=3`0A1@L02@0001H:30@03P8400D04@D70186200D20X04PH80145
1`020186200700l31@0@10H04PH801041P0H30h05@T;01@82P0201041P804@D70P0B1PPDooooo`00
6oooool0100C20`04PL;01462P0A1PX201<8300601872`0D2@d03@8600`11@0?10P02P030P0A1PX2
01872`804`P<018050T=01<8300C20`04`P<01D:3P0G31006PlC01@93@0E2Ph04@H:00X00`0K41@0
5@X>01dB5P0700004PP;00L0000A1PX601<92PH04PP900@04@L601<92P0C2@X04`T:0P0A1PX0:`1H
CE406PlE01T>500J3aD03@8:01@93P0D2P/02@0001H<3@0;0@805@/<01@:2`0A1`P0308300l51P0=
0`@06a4B01D;2P0F3@P06A0;01D;200@1P@04`T700l71P0P5QD0AS`k01<;2P0G3@h040H701P>3P0B
20H04`T801881`0@1PD04PP901@:2`0C2@X04`P<01872`0A1PX040D900h5200>20X00P0B30h03`0A
2`d04@/?00h8300?2@d03PL>0109400H4AP04``D01473`0B2@h05@/A01@;400B2@h03`L<01PB5P02
01H@500301LA5@0D3a<030H:00L04`d?01P0JVAV048m?P0I4aD03`T;014<3@0L5QP0@S`n02XT9P0C
3@l04@/<010:2P0/9RH09R0O00d81@0A30T05Q4=01@?2`0C3P/0;RTV01TD4@0B3@X04`h;00h91P0M
61D201@?300901TD4@0P6aP0:2<P00l;300I5AH05A4B00X61`0C3a002@D600805Q8C00/04`l@01dI
6P0J5QL061@E01TH5P0M71X05A@B01HE4`0G5Q@061LE01XI5`0201/J600:01TH5P0G5Q@05aHD01dM
6`0L71X06ATG01dM6`0N7Q`06QXH01LG5@806ATG00@0820N02<S8@0Q8Al08R8P0P0N7Q`0CP0Q8B00
8R@S024S8P0V9bT0:Rh_02da=00R9RT0;c@g02X`<00W;B/0:2h^02H/;00Q:B`08RTa02@[<`0Y<S/0
:34h02hh?@0Y=3P09C0b02Te=`0Z>3T0;3Xk02dk?@0_?D00<D1303=2AP0/>d00<TA80353B011DUT0
BUeS03Y9DP0f@Th0=D5=03i:EP0oBeL0>DEA03A0C00oBeL0@DeI03E1C@0lB5@0@DeI049@H010Cf@0
?TeR04ACJ@18Efh0BeYa04YIK`16EFP0BEUX041@G014EEd0@U=J04IEG017EUd0BUQQ04iLI`1@GV/0
Gfal04iKJ`18EFD0@e5M04=AFP14DU/0CEaS04QJGP11DeL0C5iR04eOH`1@HVH0EFM[04MIG@1;GF40
BUaP04UKG`80C5iR03d0BeYO04aKH01:FEh0BUUL04eLG`1<Feh0CemO05ATI01HJ6L0E6AS05=SHP1G
IfH0FFMW05QVIP1FI6@0EfEU05YXJ01MJf/0I79b069`L01QKfl0Hg5a06IdM01WMGH0JWUl06QgO01[
NWd0KWf0071nP@1/NW/0M7n1079nOP1`O7X0LWak07AnO@1gPH80bM3F08fDW01fOHD0OXF;07Z1Q`1d
Nh40OhN:07b4QP21RH/0Ph^=0869R`20RX/0cmWJ09ZVYP1cOgl0Mh>307B0P01/N7P0Lgmo07R4Q01c
Ogl0LWin06eiN@1[MgL0JGAf0080IW9b00L0Ig=c06A`KP1QKF/0G6QV05QTH01GHel0G6QT0080Gf]W
0200H6YY05YVI01PK6X0HFe]05i/K01ULg<0FfUZ061`L01bPX80HW5d051OHP1NKG00EVAU05]VJ01I
IfP0J7Af05eXJP1:EeP0BEMH04iIF`1AGEl0CUaM04]FF019E5P0BE9I049;DP1;E5X0>T=808ZCV012
Bdl0>dE703Y4A@<0>dE601T0?4Q;03e<D@0lBe00?d]A03m9DP0mATl0>d==034h@P0a=D00<34m038b
?P0c<T008BL`02<^=00O9R`0:c0e02ha=P0W:2`0;c0c02XZ:P0X:RP09b`X02X_:@0]=2d0:R`Y0080
<S@c02T0<cDd03do?P0f=cT092DW02DV:00V9b/08B8V020Q9@0W:2d08B4S01/K6`0_;bl0:2PX02LW
9`0U9BD07alO020P800S8b<0A4A403Ph>00S92D0@4=:02P/=@0V:c40:B`c02@W;P0Q92T07QlS01lP
900O7b408R0Q02<Q8P0L71h06alR02<W:`0L82<07B4T02@V:@0H6A/08R<U01`L7@02028R8P0o01`L
700S8b<04A4A01dM7@0P82003`l?01<B4`0K6AX07A/L01lL7@0N6Q/071PI01hI6`0Q7Ah04@d>01XH
6@0K6AX071XK01PF5`0;2@X06ALH01PF5`0G5AH061HG01LE5P0D4Q<04Ph?01@@4@0K5aP07ATJ01TE
5P0G4a@0510A01DA4P0I5AH05a<D01/G600C3a006aLF01HB4@0N6QT06ADD018>3@0N6QT05A4@01PD
4`0L61L081`K01TE500C3`h071LD01TD4@0E40d06A@A01`G500I514061<@01<>2`0?2PL06QDB01LB
3`0H4a0050h>00805@l?00H050h>01<=3@0D3Ph05a4A01PB4P0F4102018<300I01H@400k=CD0NWAd
01D?3`070@407QPH01D?3`0C3@d03`T9018=3@0B30`02@<301H=3`0E2Ph05P/?020E6@0X7B409AXN
01`A5@0G31004@H:00h31`0@1@T050T=01T?4@0501D;300C0147200E2``05@/<01@:2`0H3Pl05@/<
01H<3@0`9RL07Q@E00d3100D2P/060h?01lE5P0@1PL04PP90147200C2@X06@l@01041P0201<72@07
0186200D20X04@D701451`0D20X05PX<01041P0201<72@0A01861P0E2@T05@T900l30`0>0P804`L7
00d10@0C1`L05@T901861P0@10@04PH601L;3@0F2P`04`L90186200C1`T00P0D20X01@0?0`D060`>
01T=3`0C1`T06@d?00804`L900@040@600l31@0@10H04`L91P0B1PP0100:000040@601`@4P0?0`D2
01T=3`H04`L900T06@dA01/?4`0@10P040D801/?4`0;00<04`L;01862P0A1@T00P0B1PX03`0B1`/0
4`/B01PA600C31<03PL>01<<4`0X8BP0C4E<00@0100;10/03PL>00X32P0D2a004PD;018320020104
200:01452@0B1PX07a@H02@I7@0D2@d03P@801<8300A1PX02@0100d11@802P020140300401H:3P0B
1PX04PH:0104200H31006`lC01@82@0C20H03P<101871P0A1@D0300001<7200A1@L04@D901862`02
01442`0=0145200h;2h0200001H:300<00803@4300/10P0I3@l0200000h41@0e:B/02P0000d30`05
01451@0301T=3@0J3Ph03`D5008050P800<060`<01451@0A1@D02P0A1@D301451`0=01<72@0@10H0
6@d?00/00@0E2@/04PH8020D5P0>0P@05@T;01<72@0B1PP04@D701041P0200l31@0<01P<3P0L4180
6Ph@01@82P0B1PP05PX<00d10`0=0`@06@d?06EIF`10=3H02`010P0B1PP201451`8040@65?ooool0
01_ooooo00`05@X>01@93@0C20`04`P<01@93@0E2Ph03@8601D:3P0@1@T04`P<01hC5`0K41@20146
2P804PL;0`0C20`04@0B1`/05P/?01H;3`0C20`05@X>01<9300B1`/04`P<01P=4@0?10P04PL;01P=
4@0800406@hB01D;3P0D2@d04`T<00`04@L800@04`T801882@0A1`P04PP90P0C20`04P0F2`l05@X@
0146300B1`d03P<;0188300H3Pl04@L801H<3@0A1`P060h?01482@0C2@X050X;01L=3P0C2@X03@@4
01881`804`X50P0B2@D0300E2`T05P`;00l5100R61L040L702dS900C2@X04@P701@:200F30/050X9
01<9208050X;00<04PP901872`0D2@d00P0E2Ph0200E30l050h@01@>400@2P`03`T;014;3`0@2Ph0
4@/?0P0D3A@02P0:0`X05a0G0109400A2`l04`/@00l8300>1`/040X>00h72`0A2@h301@=4@0301H=
4P0C3@l04P`>00<04@/=02004`d?010;300F4A80618D00L20`0I4aD05A0A01<=3`0?2@/05@lA01XD
5P0L5aL03@L7018<300B30/04@`901PC400C3P/06aHB014<2@0R7AX061<@01HA3P0E40d05Q4>00l:
1`0T7a`09B0M01hI5P0L5a@050l<014=3P80=C4b0P0J5QL0900K5aP061@E01XF5`0F4Q<07ATJ01XF
5`0M6AX081lM028Q7`0F5A<08B0N01hM6`0E51806QTG01hM6`0O7Q`071/I01XI5`0K6QP071`J01XJ
600G5aD06a/I01dM6`0I6AL07AdK01`L6P0M7A/07alM020P7P0R8R007QhM01dM700O7b008R8S028S
9P80824T0200O824051DF00S9RX09b`_01TN8P0S:BP09bd]02P^;P0U;C00:2lg02Xa>@0X<CX09Bhe
03I0AP0d?d<0:3<e02lk?@0[>CX0:SPi030n@00d@TD0<3m202`l@00]?T80:ce102i0A@0iBe40>TeC
03U9DP0d@4`0<Ce903U5D@80>dMC0P0oBeL01`0mBED0>dMC03]7D`0mBED0?TaK03Y9G@0lBf000P12
DFL06P15E6X0EFAh04mOK`15EF@0>T]D03a=E015Ee/0AeIM04UHG`1:F680B5IS04ABG`1;F6P0AE9R
041=G@11Ce`0AUAO04UGH01DHfX0AeUM04EGFP1=Gf80B5YM04YLG`1=Gf80AeUL0P1<GV403`19Feh0
CEmR055SIP1<Ff00CeiS04eLH@1:FE`0CEaO05=RI@1?Gel0DV9R055QH01BHV40EfMV05QXI`0305IT
I00W05QVIP1LJVX0GVa/069`L01QKfl0HW1`06EcL`1WMGD0IG=d06MfN@1/Ngh0Kgj006elOP1]O7/0
KGaj071lN`1_NgP0K7Uc06iiM01aO7L0Lgik08>;S`1hOhL0MWf507V0QP1lPhT0OXF;07b4Q`1iPH<0
OXJ807n7R@1kPhD0N8:3082:R`1hQ8@0Kg]k06eiN@1bOWh0MX:20080OXZ:00T0Kg]k07=oO`1`O7`0
MX:206QcM@1SKfl0HVi^065]K@1NJVP00P1LJ6H0601KIf<0GFUU065]J@1PK6P0Gf]W05mZJ@1YMG<0
GVYX05aXJ01LJVX0FfUY05QVI`1MK6h0JWYk05]/KP1?H680G6]^05IPHP1RKFl0JWEg05IQH`1HHfD0
BeEG04eHFP80CUUK05H0C5MI04aFF01>F5`0?TM>04M@E`13C580FF9W03e6B`10BDd0?4I803]5AP0l
ATL0?dU:041:B`0oBdl0@e9J04ECF`10C5D0?TQA03a5CP0i@D/0<cM203<f@00/;SP0:BPd02l]>@0W
;3D092le02Xa=`0_=3T0<3<h02d^<P0V9bT0:2PX02LY9@0W;2H0:RlX02he;@0_<Bh0=CLf02h`;`0/
;Rd0<cDd02PY:`0S92H092DW02l`=00e=SX0;c0d02X[;`0[:bd09BDU02<S8`0R8R807alO028R8P0Q
8B40;2`/01dM7@0P8200;Bd]02@T9@0a=C`06b4Y020U:`0U:C008RH/02@W;00S92P0824U01lO8@0R
82408b0Q01lN800H71l08RHZ01dQ900Q9BP0:Rd_01lP8P0K71h06a`M01/K6`0L71`07QhN01lO7`80
7AdM00T07QhN01PH600Q82006aTJ01PF5`0L6AX071PI01TE5P0L5aP00P0R7Ql0:P0d<S<04@l@01TG
600K6AX05aDF01XH6@0H5QL05aDF01PF5`0G5AH04a4B01/G600H51D05Q8C01LC500I5AH06QHG01TE
5P0G4a@06QHG01LC500L61T05Q8C01DA400I5A@09b<R01hJ6@0?2`X05Q8A01LC4P0F4Q4061@C01dI
600J5QD05a<B01/F4`0F4@h04@`901HA3@0I51405a8>01XE4P805A0<00D04`h:00h91P0N6AH05Q0@
01@>3P0201<=3@0501@>3P0C3@d050h>01H@400E3`l00P0B30`00`0F410040X:01TD500201<=3@08
00T4100D3Ph030H601/E5@0?2@T07aTI018<300?1`T201<8300:01D:3P0G31005P/?01H;3`0A1PX0
6a0D02dR9P0J3a<04@H:01L<3`D05@/<02D04PP901D;300B20T05`d>01hD5@0D2P/030<301/A4P0G
3@h050X;00P0000d:b`0FDm@01lE5P0A2@X07A@E00`3100A1`P060`>01<72@0H30h06`lA01<72@0D
20X05PX<01D92`0L41803@4301451`0G2`d04PH601@8200E2@T04PH601451@0D20P040@400804@D5
0P0B1PH0100C1`L04@D701@82P0C1`T201451`0301@82P0B1PP04PH800804PH800<050P:01D92`0C
1`T00`0B1PP00`0C1`T04PH8018620050186200701<72@0B1PP04PH801451`0A1`P02`4201@82P04
01<72@0:01@82P0?1@L03@<501P<400@1@P03`@701452@0C1`/04PH:01452@804PH:00l04PL=00l8
3P0?21003PL?04Y4B`0U7bD04P/B02`U;028PHT050dD00l940080`T040L?01062P0A1PX00P0B1PX0
;00A1@T040D901/@4`0S5a/050T=01462P0F2@d03`@701472@0[7b<0@CDi01/A4`0A1PT04@D90186
2P0C1`/04PH:01L;3`0I3A4050P902<H5@0H3@/04PH601L<2`0<00004@D601451`0A1@T04PH;0144
2`0A10`050P=01P<3P0:00404`L901061`0H3Pl04@D700l51P0D20X0:AdO08]oP@0F2P`04PH71@0A
1@D01P0A1`L060`<00l4100J3Ph04`L701461PH04PH61P0A1@D03P0@10H04@D701D92`080000;20R
01051`0C1`T05PX<02<H6@0=0P<03P8401D92`0?0`D040@6100A1@L01P0C1`T06Ph@01L;3@0@10H0
3`<501D92`804@D700@04@L804@h>P0/8B804@D70P0B1PP301451`0301041_oooooooooo01;ooooo
000Kooooo`0401T>4P0G31005@X>01@93@804`P<00H040D901L<400>0`L03P<701L<400@1@T20146
2P804PL;0P0C20`04P0@1@T03`@801L<400E2Ph03`@801872`0@1@T02P0300h31`0D2@d04`P<02<H
700K4A@0;b@X00L0000B1`/06PlC01462PH04`T:1P0A1`P04`0D2PT04@L800l51P0@1PL04`P<01D:
3P0@1`T07Q<G00X00`0C20h03`@:01882@0G3@/0308001471P0:00005P`;01T?3P0G3@h00P0E2``0
5P0F30d03P@501P>3@0C2PD04`T701@;1`0E2`T050X801D;2P0D2PT03@<201L=3@0900004@L801@:
2@0B20L04`T80188200@1PL04PP901D;300F30d201D:3P804`P<08/05@/?01@>400@2@/03`H9010:
300K4aP04PT>00`62P0B2`l07aDM00P1200/8b/040X>014;3`0@2Ph03PP<00l93@0G3Q<06a8G01P?
500D2a0050T?01L<4P0K41H04PT<00l92`0?1`X03`H900h82P0A2@`07A@G00h82P0?20X07QDH01TC
5@0I4Q@030H801dG6@090`D06Q@F05aFE`0U7al071HF018=2`0C3P/05a8?00l:1`0X8b0071LD01HA
3P0>2@H05Q4>01<>2`0D3``04`h;024L6@0A30T03PT601TD4@090`<081`K01<?400H51D04`l@01PD
5@0L61T061@E01XF5`0I5AH08alP01`H6@0H51<06QHE01hM6P0U92006aXH01@C400L6aL05aHC01dL
6P0N7AT06aXG01/J600L6aT092@S020P800L71`07QhN01lO7`0K6a/08R8R020P800Q8B40820P024Q
8@0U9BD071`L01hN800R8R@09bLY02@U9`0R8bD0:b``03<g>P0V:Rd092P[08F:SP0U:Rd09R`[02D[
:`0Y;bl0:c<f02L^=00S:S009c0g024Z<@0lADX0?DQ<02`f>00^>C/0=dE604A?D@0gADL09S@g02Pf
>@0_?T80>D]?0394B00cA4X0<4=902dnA@0iBE80<Si:03I2CP10C5P0>dMC03M3C`12CUX0AE5M0080
AU9N0P0e@Dd05@10CE`0?DeM03a<G00mC5h0?4aL049AI01<G6/0?DeL03a<F@13E5d0?TmF03i@E01;
FV40CUeT059PJ@1BH6/0CE]V055OK010CU/0?TaI04ABG@0204YHH@0504mNI01EIf/0BeeO04MIF`14
EUP00P1;GEl00`1CIFL0EfU[05=UI`0204YLGP0704aNH01@Gf80AUEH04iMH@1EI6L0BeYM055PH`02
059RHP0=04iNG@1DI6<0GVi]05][JP1CHF40E69R05ITI01HIVH0GF][05m]K@1PKVh0Gfe^06=aLP02
06MeMP0S06=aLP1VM7L0L7j007:0P@1]Ng/0JWQh075mN`1ZMW@0K7Qe06ijMP1_NWH0KgYe06egMP1j
Q8H0Nh>907N0Q@1jPHL0O8B9079kP01iPH@0MWn107V3Q01kPhD0MGio079lO@1gPh<0L7am06ijNP1b
OWh0LGem06eiN@1_Ng/0Lgmo06UeM@1cOgl00P1TL700<`1WLg<0HVa]05iZJP1MJ6T0FVAS05MSH@1J
IF@0GVUU061/J01TKf/0HFaX05eYI`1XM7<0Si^K06QdM01PJfd0IgEf05ARH`1KJF`0EVEX04iMH01C
I6H0FVU/05=RI@1JI6L0Yk2e0=SRi022S8h0F69T04]EE`1?FE/0CUQJ04]EE`1:E5H0CEMI04aEF@1@
FEh0BE9G03a5BP0mAdT0<S]003Q2A00kADL0?TQ903Y4A@0g@D80>dE603i:C@11D5D0@U5H03I3C002
03<mA`0`03Q0B`0h?TX0>cm:02la>`0V9S00;2`d02/`=P0T;C80>41303<h>`0O8bH0:blb02T[:`0Z
;2/0:B`X02X_:@0]<R`0<SPa02`^:`0T9RD09bTX034c<P0^<2l0;2d_02LX:P0R8bD0:R/]03Df>P0_
<3@09bP/02LW9`0];Bd09bLW038b<P0W9bL08B4Q02XZ:P0U9BD0:RXZ02h^<00T92@0820R02@W;00S
:2h09RT_01XM900O8RL08bDZ0P0S92P04@0R8R@07Q`O01hL7P0V92L0824U01TM8@0P92L092DY01hO
8P0P8B<071dO024R8`0H61P05aLG01dM7@0G5aL07AdM00807QhN010061PH01dL7@0?3@h05A<D01hK
700P71d071PI01XF5`0M6AX0518C06m]KP10?Sl0:BLX00h<3@0M6a`06QPI0`0H5QL04@0F51D04a4B
018>3P0J5QL06aLF01`H600L61T071PG01TE5@0E4A805Q8A01<?3`0I5AH0510?01TE500A3@`06ADD
008040`;01X05A4@01HB4@0A3@`04Ph=01PD4`0I5A@061@C01XE4@0H4a005A0<01PC3`0H4a004`h:
014<2@0;1P<040/701<>2`0a;2T0HEaI01PB4`0C3@l04@/<018<300D3Ph04P`<014;2`8050h>0P0A
2`/03@0D3Ph03PP801lF5`0E3Ph02@<301dD5@0D3@d040X:00H0000H41402P@401P?400G3@l00P0G
31002P0D2@d04`P<01@93@0F2`l01`0001H;3`0d:Bd05@X>00T00P0C2@/501<92P0N01H<3@0G3@h0
50X;01lE5P0Z82406a4B0107200I41401`0001XA4P0D2``04@P901892P0<0`@040L800/20`0@1`P0
4PT:01451`0>0P@0;20R03P/;P0M4A<03@4301<72@0<00805@T;00X0000B1PP05PX<0P0@10@03@0B
1PH04`L701@8200C1`L05PX:01451@0?0`<04`L701H:2P0D20P040@601D92`0F2P`00P0D20X00`0G
2`d03`<501L;3@0201451`0801H:300>0P@040@601451`0B1PP04`L90186200?0`D60186200900d1
0`0F2P`040@600d10`0V6Q`05PX<01@82P0C1`T04PH800804`L900X050P:01862P0;00<0200000l5
1`0J3Q803P8601<72`0B1PX04@D90P0B1PX0800B1`/040L>044g?`0^92`0N6if03/a>@0B21004`/A
00d32`0D2Q803`H=01hD700600@03`H:01872`0D2@d04`P<01052@0?10P04@D901D93@0G2`l05@H;
0183200C1PX04`L;038V:P19?D403P8600`0100>0`H040@80`0D20`02`0A1@T04PH703DZ:00U6AT0
4`L701`@400<00003`<501451`0A1@T04PH;00804@@;01P04`L<00P0000A1@L03P@501<72@0D20X0
4@D701P<3P0;00404@L801P<3P0T61X04`L80146100A1PD04@D50146100A1PD05PX:00T0000C20L0
5@T901H;2@0E2@T601861PH04@D500d06Ph@01041P0=0P<05`/=08=gN@0N4Q@03`<500X0002CQhT0
?c<e01<72@0A1@L04PH800<04`L900<04PH801451`0A1@L00`0C1`T02P0D20X05@T;01L;3@0?1@H0
4`L900/00@0D20X040@600l31@0@10H201451`804`L95?ooool001_ooooo01<050T?01D:400C20h0
4@H<01873@0C20h02`0601H;4@0@1@/03@8801@93`0F2`l04@H:01061`0A1`P040H70147200E2``0
60h?00803@<400/03`D601<92P0J41404@L801882@0>10D06@l@01`B4`0@1PL04`T:01D;300201H<
3@0801<92P0B20T04`L901<72@0I3@l07Q8D01T=3`0C1`T201@82P804`L90P0B1PP201882@0501<9
2P0D2P/050X;01D;300C2@X00P0B20T0300C20`050T=01<91@0K4@P04PP001T>200D2@<04`P401<8
1@0E2@T05@T;01D930805@T=00@04`L801871@0C1`L050T80`0D20P201D92@0801@8200C1`L04`L7
01D:2`0@1PL05@/<01@9300A1PX201<8300b01/@500;00@040D901P=4@0900804@H:01482`0G3A00
60dA01<:3@0E2`h05P/?01D<3`0E2`l05@X@01@;400D2Pl03PD:00l62`0A20d04`X?01@;400E2Q00
6PlE01@93`0A1P`04`P>0146300k<3H04PL;0189300C2@d050T=01@;3P0E2`h03`@802TP8`0?1@P0
81DI01<:3@0F31003`T901H@400=1`L04@/;01PB4P0D3Ph0618B00h8200@2PX201<=3@0901TC4`0C
3@d05Q0@01TC4`0J51@0618B01H@400D3Ph05Q0@00<05a4A01805Q0@02XV9@0I5A@07QXI040l>`0T
81l040`;020L6`0I5A@081`K01LC4P0I5A@07a/J01HB3`0L6AD081dH01lK600K6AD201TH4`1702<T
7`0U9R0071dH010A300N7AT06aTK01PF6@0I5aX071XM01`L7P0K6ad07QhP028S9@0M7R009RLY02<T
9P0D5AL07AdM02PX:00Q8B4061PH024S8P0T9RD0824S020T9@0Y;Bh08RHW04aBDP0X;Rh08R/Z01dV
9@0a>ST0=3dm02@/;P0U;C00:c8h02`c>@0]=3X0;3Dj02dd>P0c?Cl0<Cdm02`f=`0a?3d0<Sdo02dh
?00/>Sh0;3]00350A`0^?DD0<T=;03Y8D@0gA4l0<cm=02hjB00iAE<0@DeK03i:F00mBEL0@dmM04QD
HP12CU`0@4aJ04UEH`1<FFD0B5IQ03e;EP17EF40;C]604=AGP13DE`00P12D5/01@13DEX0A59K04IE
G018Eeh0DV5V0080CUeT0380>dYA04IEG00jBE00?DaC05]ZL@1_OXD0BeYQ06]jO`1EI6T0C5]P04ED
F@1?GV<0EVEZ04iMHP1?GV<0C5]P04]JG`1?GV<0DV5V055PI01;FUd0C5aL051PH@1=GEd0AeMG04iN
GP1GIfL0Df=S059RHP1EIFD0EfMW05EUI01AHF00E6AQ05QXI@1KJfX0Gfm^061`L01NKVh0H6mb065`
L`1_OX<0I7=h06IcN@1kQXX0JWEg06mjO01fPH<0LGan07AnO`80JgEf0180L7Yk07J0P@1iPh@0MGn0
07Z4QP1fP8<0[[Vk07^5Q`1gPH<0KWUk07N1P`1gPX@0MX6307N1P`1dOh40Lgj007b7R@1cOX4206]f
N080KWUk05<0LWin06YfM01TL6h0JgMe065]J`1OJfT0Hfe/065ZJ@1QJfX0FF9Q05=LF`1FH5l0FF=R
05mXI`1SKF`0HV]Z05iWIP1MIfH0IG9b082>S`1^O7d0F6IY05YWK@1IIV`0EF9X05MTJP1FHfT0FfY]
05QVI`1@GV40I6mc0:bg_@3gool0P8^?04UDF01@Feh0CUUK04mKF`1>FUX0BUIF04IBDP1;EeP0B5=E
04MBE00e@480@Ti>034l?P0oBd/0>4A403]7A`0iADD0=T9203Y6AP0iADD0>TQ803A2@`0`?D@0>TIB
03a8EP0lB5P0?4ED03LoC00`=T40:Bhd02`_=00^<cH09Bh]02X`<00d>SX0:Bl_02L];@0/<2l0:Rh]
02hc<@0a=c<0<SPd03<h=00Q8b80:BTY034a<@0T92@09bLW02d];@0302XZ:P0902TY:`0W9bT09RHW
02h`;`0H6QL08bDR024S8P0R92<08B<R00807AhP02L09RLY01XK7`0L7Al09bP/02PY;@0W:2d092DY
02<T:@0U9RX0:RX^02HU:P0U92T081lT01TH7@0L71l09B@Y01XI7`0Q8RH092DY028Q9P0O7R807alQ
028R900P82407QhN01dM7@0O7al0820P01/I700P7R4071XM01XH6`0O7B009B<V01`J7@0P7R406QPK
01PF6@0K6A`00P0E4aH0@00P7R404@lB01/I700Q7b80518E01XH6`0M6ah0518E01<A500I5aX030X;
01XF500>2PT04@d:01PD4P0G4a805Q8?01DA3`0G4a8061@A01PD4P0E4A00510?01PD4`0J5QD05a<B
01`H5`0M6AP05Q8A01`H5`0K5aH05Q8A018>3@0F4Q4061@C01`F5@0G4A405A0=01@?3@0C3@d04`h;
01HA3`0I4a<08ahK014;2P15?cl0T8Z:01HA5@0H4aL03PT<01DA4P0C3a005a<D00<0000N6QT061@C
00T5100O6aP05a0?01T@4@0E2``04`T:01<:2`0D2P/201@;30805@/<00H050/<01D;300F30d05@/<
01882@0@1PL201L=3P0401D;300D2P/04`T:01@:2`804`T:00`050X;01D;300E2``03`D601882@0E
2``05`d>01`B4`0I3a004`T:01L=3P0F30d2014720804`T:00h050X;01D;300E2``04`T:00h41@0H
3Pl08aTJ01P>3`0G2`d04`L901041P0E2@/06@d?01@82PH04PH801@02`4001`B400B20H05@/900d3
0@0A1`D060h<00X20@0E2`T06Q0>01P>300I3`h05PX<00h2100D20X040@60186200@10H05@T;01<7
2@804PH800T04`L901D92`0E2@d060`@00X00P0800005@T=01H:3P0A1@T00P0C1`/0400A1@T04PH:
01<72`0:00804`L;01862P0G2`l07a<G01<72`0G2`l03`<70104200<0@@04`L;00d11@0A1@L20186
200301451`0C1`T05@T;00804`L901H03`<501<72@0L41803`<701D:3`2XWJ<0PWMm01P=4`0;00H0
714G01883@0700807Q<I00/11P0D2@l05``B01462P0>0PH05`/?01H:3P0>0PH04@D90P0B1PX02`0@
10P04`L;00l31`0H30l03@4301P<3P0A1@L040@601T=3`0>10D04`L9008050P:00T04@D700l31@0;
0@808QHH00h2100F2P`0300200h2100L41@00P0@10P0100A1@T04PH:01862P0B1PT201041P040145
1`0B1PP04PH8018620D04@D701P04@H501460P0A1P<04@H401460P0A1P<05P/900l4000?10807Q<A
028G4`0H3@/04@D500h20P0?1@D050P800h20P0B1PH02`0001L;2`0=0`<0300001861P0C1`L20104
1P803`<501@040@601451`0@10H060`>02DI6`0I3@l050P:00l51P0>0P@04@D701P<3P0@10H02`42
0186200<00805@T;01041P0800004PP901H:30H04@D700H050P:0186200=0@<050P:01H:300:000D
ooooo`006oooool0200A1P`04`P>01L<4P0I3Q@05@X@00h32@0B1`d04`P>0P0D2@l0100B1`d040D9
01872`0B20T201061`080147200C2@X03`D601H<3@0J414050X;01L=3P0P5QL201D;300401882@0J
41406a4B01882@H050X;00H04PH801041P0C1`T060`>01@82P0@10H201@82P804`L90P0B1PP00`0A
1`P04PP901882@0301<92P<04PP900`050X;01D;300Z81X091X?03dc:P0_9A/05@/301@90`0D2@L0
5@X801D92`0E2@`201D93@0301<72@0B1PH04`L700@050P80P0E2@T201@8200D01<71`0A1@L050T=
01D:3P0M4QH05P/?02XO8`0N4aL03@@601<8300P5AT06a0D01X?4`0F2`l04`P<01@93@0G31005P/?
01L<400F2`l201D:3P<050T=00d050T?01D:400F2a405P/A01D:400D2@l03`@:01P=4`0I3Q@060dC
01/@5P0C2@h050T=00805@X>0`0F2`l0300Z7b<0<bP/01/@500H3A404PL;01P>4@0U71d09R0P01D?
3`0B30`05@l?014;2`804P`<00H05@l?01@>3P0C3@d071HF01H@400G4A4201H@400301D?3`0D3Ph0
5a4A00806A<C0P0J51@0500I4a<06ADD01XF5@0L61L0510?01TE500f<S406aLF01HB4@0N6QT06QHE
02@P7`0]:BP06QDB01dI5@0N6aL07ATE01`I5@0K6QH07A`H0P0A4P`0200M7QT06Q/F01lO700P6al0
7adQ01dK7`0K6Ad06a/N0P0M72004P0I6Qd08b@W02//;`0Q9BL07b<T051@D00K6a/0:2PX01lO7`0c
=C@08bDT030b<@0T:2L07R8Q02@X9`0[<Bl082HT02D^;@8092d/00H0:c@c02/c=@0V;S00:c<f02`d
=`0]=CT202dd>P0B030i>`0_>CP0<3Xk03<m?`0`>cd0<Se103<oA00kB4h0<3m603I5C@0e@d`0?D]F
03E2CP10C5L0?TYG03m;F00nBUL0>DEC0P10C5X07@12CUd0A51O04A@G`15D640AE9O04]IHP18EUl0
?deF04=AFP15De`0@DmH03i<E@0oCEH0@e5J04IDG@19Eel0B5MN04eLH@15E5T0@e9G03M6B`10Ce@0
AEAI061_M01:FEh0CeiS04eLH@17EU/0C5]P0080CUeR00X0B5ML04MFF`1<Ff00CeiS051OI01?GV<0
BEQM04MFF`17EUX0BUUL0P1@H6000`1;Fe/0CUiN05=SH`02059RHP80Df=S02<0E6AT05EUI01EIF@0
EVIS05MWI01IJFP0GFe/05m_K`1OKW40G6]_061_M01RLGL0I7=i06]hOP2KYZX0Mh6306]eM`1bO7h0
L7Yl06egN@1YLgD0K7Ih06miN`1`NW`0KgUk06egN@1gPX@0LGan08>>T01`Ngd0N8>508:=S`1aO7h0
LWeo07=nP00207AoP@0907=nP01[MWX0KgYn075lP01_NW`0KGQj06agN@1ZMWH0JGEc0080I71^0240
HVi/065]J`1TKF`0I6e/06I_KP1PJFP0G6ET05iWIP1LIF@0HFYY061YJ01QJVT0HV]Z05eWIP1IIFL0
FFMZ05MUJ01JIfd0FfQ`05MTK01OK7@0FFI/05QUJ`1DHVD0D5iO05=QHP1DGfD0Hfid08jIW`1II6P0
AU5E04YEF018DeD00P19EED00`17De<0AE5A04MCD`02045=C@0W03]7A`0nBTX0;c/k03]7A`0d@400
?DU903m;B`0lB4P0>dM7038m?00e@Cl0>4A403Q7C00oCEP0@DiM03e:FP0lB5P0?DIE03<lAP0W;S@0
;34e03]0@00c>3L0:Rl^02db<@0V:bX08bPV02P];00]<S40<CHd02ld<`0/<C009b`[01lQ800/;2`0
;Rh^03dm?@13@d<0:RXZ00<09bLW01D09RHV02DU9@0U9BD05QPE02PZ9`0O8Al092HU01lQ800^;c00
:R/]020Q8`0S92P092DY02TZ;P0U9RX0:bX_02TX;@0U92T08B0U028Q9P0T8bP00P0Q82D201lN8`0:
024P9@0R8BH07A`R020O9@0R8BH08b8W020P8`0M7Al07alQ01hN7`807AdM010071`L01/K6`0H5QT0
6QPK01/I700I5aX061HI01LE600L6Qd07A/N01LE600F51L06ALJ01HD5`0E4aH06QPK0P0M6ah01@0D
4QD0;B/^06QVJ@0Q7b8071XM008061HI00H06aTJ01/G5@0J5Q@05A4?01TE4`0L61H201HB40<05a<A
00D05Q8@01DA3`0E4A006QHE01LC4P0201HB4@0401@@3`0B3Pd05a<B01PD4`805Q8A00<05a<B01TC
4`0F4100100E3`l04`0B30`03`T901@>3P0F41005@l?01PB500L5a`06QDI01<>4P0B3A404Ph?01XF
5`1:ATL04@d<01@@3`0=2@P06QHC014:2@0E2``00P0H3Pl301H<3@L05@/<0P0D2P/04P0L4Q<07A<D
01P>3`0E2``050X;01<92P0B20T04`T:01882@0E2``05`d>01@:2`0E2``050X;01H<3@0H3Pl050X;
01061`804`T:0`0D2P/201<92P0=01882@0=0`@06Q0A01<92P0?1@H081HG01P>3`0G2`d04@D701P<
3P0B1PP06Q0A01`@4P060186200@00/20P0I3`h03`D401<9200=0`804`T701881`0F30X040H401X@
3P0D2PP03`D401451`0@10H06@d?01451`8040@600P04PH801451`0@10H040@601451`0B1PP05PX>
01462@806`lC00<040D801862P0A1@T00P0C1`/00`0A1@T04PH:01<72`0201`@500:0104200?0`L0
5@T=00`0100@10P04@D901P<400A1@T050P<010620<050P:01804`L901D92`0G2`d08aLI00h41@0H
30h04@H701451`0D20X04@H901dB5@0D2P`04`P;01862P0@10P04@D901472@0@10P201D93@0D0104
200B1`X03`<701P<400T61`06PhB00l31`0C20/04PP:01D93@0D2@`02@0101862@0=0P<05@T;01<8
2@0:00403`<50186200C1`T201@82P0901451`0@10H04@D801452@0?1@L03P@602<G6`0l<3@050P<
008040@80P0A1@T01@0B1PX04@D801041P0@10H04@D700<04PH81@0A1@L00`0A1PD04@H201460P03
01460P0Z00l40@0A1P804PL301<8100D2@D05P/701@8200T61P081@D00d10@0=0P804`L700l4100D
20P040@401L;2`0E2@T04PH601041P0=0@<08aLI02dQ8`0I3@l03`D601<72@0A1@L060`>01D92`0<
0@804@H70186200G2`d07A4C01@82P0A1`P050P:01/?4@18?3h06Ph@01L=3P0A1`P03`D61P0A1@L0
1P0C1`T04PL801H:300;0@804`P901@82QCooooo000Kooooo`8050T?00H06@hD01lD6P0K41H040D;
0146300>0`T201<83P0>00l42P0D2@d04PL;01<92P0?1@H040H701882@0?1@H05`d>00l51P0B20T0
6@l@01472009000201<92P0;01061`0D2P/050X;00h41@0E2``04`T:01882@0C2@X050X;01D;300G
2`d00P0C1`T00`0F2P`050P:0186200601<72@P04@L800d04PP901@:2`0F30d060d:06]QE`3ooO<0
V8j501X?2@0K40`06@h;01@91`0D20X050P;008050P<00<04`L901861P0C1`L02@0D20P04P0C20X0
7a@H01D:3P0L4AD05``@03`a=@0Z7b<01`0000`11@0F3@l02P0301<8300E2Ph04@H:01/@500U6Qh0
7a@H01872`8050T=0P0C20`201872`0<01873@0C20h04`P>01<83P0B1`d04@H<01X?5@0@1@/03`D:
01X?5@0F2a40=R/a1P0F2`l0200@1@T04`P<01H;3`0<0@D03`@801L=4@0M51D081XJ0P0B30`0400E
3`l040X:014;2`0C3@d05@l?01<=3@0@2PX04@/;01LA4@0F41005@l?01@>3P0E3`l05Q0@01@>3P0E
3`l401H@401K01HB4@0H51<06QHE01HB4@0J5QD0;BTX01lK6P0I5A@06aLF01@@3`0I5A@061@C01`G
500M61D06aLD01XF4`0K6AD07QdI020O6`0S91l08B8M01<D3`0/;BP051@B01`G6P0P7R407adP01dK
7P0Q8B<09bLY02HV:00L7Al06AXL01dN800K7b008BDV01dM7@0B4Q80;Rh^020P800[;B`0;2h]02T[
:P0N8R40:Rh]02T];00J81h082HT02@];00V;bh082TX02@];00Z<S@0:C4c02`d=`0]=CP0;SDj02he
>`0]=3X0<CXl038l>`0b?3d0<cdo02hi>`0`>cl0=D5604iKH@0fAD`0>4I>02Xh@@0kBE@0=49<04=@
F00lBE80>4E>03m;E`10C5X0BeMU04A@GP16DV80BEAV04YEI`19E6P0C5UV04]IHP1CHFX0AUAM05IT
K@0oCEH0@e5J045?F003049@F@0N049AF@1:FF00B5ML041?E00oCU<0?DaA04=BE`19F5d0GVeb0;c;
d01QL7D0?diC04aKH019F5d0A5=H04MFF`1AH6D0Df9W04mNH`1;FUl0CEaQ04iMHP1;FUl0BEQM04UH
G01AH6<0GFe]05UYJ@1@H600EfMW0P1BHV80601EIFD0F6QX05IVIP1EIFD0FFUY05UYJ01GIf@0EFER
05IVI@1JJVT0GFe]06akOP1UM7P0JWUn05a[L01PKgD0IG9h061[K`1ZM7H0M7j0071jO01VL780JG=e
06YdMP80KgUk00/0JWAf06I`LP1VL780JgIh07J1P`1[MWP0N8>507=nP01hPhD0KgYl075lOP03079m
O`0/075lOP1eP8@0L7]o06ehO01_NW`0KWUk06ehNP1YMGD0JgMe06McL@1NJVP0Hfm]069^K01QJVT0
IFi]06I_KP1RJfX0GVMV05mXI`1KI6<0JgAc06=/J`1NIfH0HV]Z05mYJ01JIVP0JGMj06]iO01HIF/0
Gfad07>0R01FHf/0FVM]06EbN01HIVT0BeUJ05=QHP1?FV00?dY@04UDFP1CGV80C5MK04UDE`1:EEL2
04YFEP0/04MCD`16DU80A51@03e9B@0jATH0?TY:03A0@00Y=CD0>4A403U5A@12CTh0@dm?03]7A`0h
A4@0<Sdm03Q2@`0h@dD0=d=903]9E013DEh0?T]K034mB`0d?TX0<SU402X_=@0/;c@0>3`m03<g=P0Z
;Rd0:Bd/02L[:P0X;2/0;30_02hb<@0c=cH0<SHe02hb<@0V:RT0=CDe02@T900f=SH0clo?0>SXj013
@d<202LW9`<09RHV00X09bLW02la;P0K7AX0;c4`02HX9`0[;B`09bPZ030a<`0[;2h0:b``0P0J6al0
100R8bL0:RT^02TX;@0V9BX202@S:00L02HU:P0S8RL081lT01hM8P0Q82D08R4V01hM8P0P7bD07QdR
020O900S8RL08B4T01/K7@0P82808B4R024Q8@0O7al071`L01XJ6P0M6ah06ALJ01XH6`0L6Qd07Q`O
028P8`0K6A`071XM01XH6`806ALJ01005Q@G01LE600E4aH06aTL01`J7@0O7B00De5D0;Vg^P0V92L0
40hA00d;3P0L6Qd07Q`M018>3P0C3`h05Q8A0P0J5QD00`0G4a805Q8A01HB4@0401HB4@0301@@3`0G
4a8061@C00806ADD01l061@C01LC4P0D40l05A4@01@@3`0E4A0061@C01H@400G4A405Q0@01D?3`0F
41005a4A01XD500H4Q804P`<01LA4@0N61P06aDG09:=TP0X8bL06aHJ00T4200C3a006QHG06EQHP0B
3Pd05Q8A01@@3`0I5A805Pl>00806@l@00@050X;01L=3P0Q5aP081HG1@0E2``02P0D2P/05P`=01H<
3@0E2``0718C01hD5@0H3Pl05@/<01@:2`0A1`P201<92P050147200F30d060h?01@:2`0E2``00`0D
2P/201<92P0301@:2`0A1`P050X;008050X;00l04`T:01882@0B20T05P`=00d3100A1`P03`D600L0
000G3@h05`/=01041P0J3Q00200001041P0E2@/01P0B1PP01@0A1`H081HE01<9200G3@`040H500@0
4@L600H05P`;01@:2@0B20L05`/=0186200J3Q0201@82PL04`L900L04PH:020D602>PXH0TXJ:02<G
6`0900404@D900804`L;01T04@D901862P0C1`/07A4E01`@500A1@T03`<701D93@0B1PX07Q8F00h2
1P0;00<040D801hB5P0J3Q804`L901@82P0C1`T04@D701<72@0E2@/0Ge=E01@82P0@10H030830080
200000@060h@01@8300B1PX04@L90P0=0@D0600D20`0=b/_01862P0A1@T03`<701@8300A1@T060`@
0104200B1PX07Q8F01lC5`0H3100300400P0000L41@08ADI01H:3@0B1PP06@d?02LK7@0F2P`03002
01@82P<04`L90P0A1@L01`0C1`X02P0200l31`0C1`/0<bL[04m3A`0D20`00P0?0`L3010420040104
1`0@10H040@601451`<04PH81@0A1@L00`0A1PD04@H201460P0301460P0300l4000B1`<04`P40080
304000P04`P501861P0L41007Q8B00l30`0B1PH05PX:01@820804@D500d081@D01L;2`0@10@06Ph@
01<72@0L418081@F01<72@0A1@L050P:00h2100J3Q009ATK00804`L900P02`0101<72@0J3Q005@T;
01H:300H30h02P0005Q<CP804PH800<05P/<01041P0A1@L01@0A1@L01P0800008ADG00/00@0G2`d0
3P<400`00QCooooo000Kooooo`0601873@0>0`T040D;01H;4@0E2Q003P<90`0D2@l20146300=01T>
4P0>0`L040H700`20`0>10D04@L800X00@0?1@H05`d>01D;300?1@H040H701<92P0201882@0=0147
200C2@X04PP900h41@0D2P/04PP90147200B20T04`T:01@:2`0I3@l05@T;01@82P0201D92`0301@8
2P0C1`T04`L900@04`L9200A1`P02`0B20T050X;01D;300P5Q80IUaC0>gSfP20MVh06Pl901L<200B
1`@050T700<050P:00@050P<01<72@0B1PH04`L72@0D20P04P0E2P`05P/?00L0000?10P04@H:024F
6P0:0@<08QLK02TN8P1:?d<0;R<W00L0000G31003`@801T>4P0S61`07A8F01052@8050T=0P0C20`2
01872`0301@93`0E2Q005P/A00805``B00L05P/A01D:400A1P`091TO01`A5`0A1P`09AXP00H05P/?
00l09AXN01P=4@0E2Ph05P/?01lD600B20/040L801H@400?2@T04`d=01D?3`0>20P04`d=014;2`0C
3@d00P0H4Q802@0?2@T05@l?01D?3`0E3`l05Q0@01TC4`0J51@04P`<01@>3P0301D?3`0=01@>3P0E
4A0061@C014=300O6aX04`l>01LC4P0H51<05a<B01`H5`0H51<07QXI01XF5@0201dH5@0R01/G500I
5A806aPE01hM6@0Q81`0D55<02@U800O81/0824L01dM6`0M61/08AlR020N8@0N71l08R8T02LW:@0J
6Q`03a0B01DF600P8B<05ATJ024U9P0S8b<0<c<c03Lg=`0X:2P06A/J02`^;@1]Kfh05QXI02@X9`0X
;2/08RPV01DK6@808b`[00L09Rl^02</:`0T;2h0:c<e02`d=`0]=CP0;SHj0080;SDk03H0<S/m034k
>P0_>CX0<Sdn030k?@0`>cl0=415045>E00[>T40;3]302Xh@@0iAe80=D=;045>E00jAdl0>4E=049?
F011CET0A51N049>GP16DF<0Ae9U04MBIP1<Efd0C5UW03i<E@1GIFh0H6ig069`N@14DU/0@DmH03]9
DP0nC5D0A59K04MEGP19Eel0A5=J03i=DP0jBDh0?4]@049AEP13DUL0BeYO05i]LP3=g>40J7Ml03M6
B`1;FUl0CEaQ04MFF`19F5d0CUeR04]JG`19F5d204]JG`0504aKH01=G640CUeR04aKG`1?GV400P1L
K6`04P1EIFD0FVYZ04mOG`1>GUh0DV9R05IVIP1DI6@0Df=S05IVIP1IJFP0EfMV05EUI01EIFD0FFUY
05][J`1[NWd0IgIi06mnP@80Gfic01@0H6ec06UdN01/MgT0JgIh06A_L@1RKFl0KWUk06]fN01^NG/0
K7Mi06MbM01SKW00IG1b06IaL`1fPH<0JWEg07f8RP1aO7h0KgYl075lOP<0LWeo01P0LGan06mjO01f
PHD0KGQl06agN`1cOX00KWUk06MbM01YMGD0GVYX06mkN@1GHf40DemM061/JP1NJ6L0HVa[065[JP1M
IfH0FfET05YTH`1VL6l0NH>206ihM`1LIVD205YTH`0Q05IRI01AGf80BEMJ055NI02MZ[80fNK^061]
M@1QKW@0JGIl05QVJ@18EUL0CeeN05=NI015D5H0@diD05IQI@1>FEd0BUEH04eHFP1<F5P0BEEE04EA
D@13Cdl0@Da<049<C@0lATL0@D]<03Do@00`>S/0>D=403Do@00jA4D0>D=40080=3ho0300<cdn03U3
A00g@T@0<cm603<oB`0hAU<0?T]I03I2D00d?TX0=cm703@i?`0`<cP0<3@e02lc<P0]<C00:bl^02L[
:P0/<2l0<3@c02hb<@0a=C@0;c<b02X^;@0T:2L0@41002`/;00j>SX0clo?0>OWi`0o?cl092@T02<S
8`0R8R80820P024Q8@0R8R80828Q00d?3P0S9B@09BLV02h`;`0/;Bl0:b``02DV:P0X:Bd08b@Y02d^
<`0o@4D302@S:00G02DT:@0W9R/0:RT^02LV:`0S8RL07A`Q01hM8P0P7b@07QdR020O9@0N7B807ahS
028Q9P0Q82@06a/M01lO8@0P8240820P01lO7`0L71`06QXJ01HD5`0G5AP00P0N71l05P0I5aX06aTL
01XH6`0L6Qd07adP01hL7`0I5aX05Q@G01/I700J61/04a4D01DC5P0I5aX0=C<f04e;CP0?3A006QPK
00X82`0J61/07adN01XF5P0B3Pd201/G5P03014=300C3`h05Q8A00D05Q8A00H05a<B01<?3P0F4Q40
6QHE01LC4P0E4A0201<?3P0G01PD4`0F4Q404@d<01<?3P0E3`l0618B01LA4@0E3`l05Q0@01PB4P0C
3@d06aDE01lI6@0D3Ph03PP801@>400/9B/06Q@H00l93@0S7B405@lA00`6200S7Al00P0@2PX00`0B
30`061<@01H?3P0201T?400401@:2`0G3@h08ALH020F5`H05@/<0P0H3Pl00`0E2``060h?01T?4003
01D;300?01061`0E2``05@/<01D;300L4Q<06a4B01D;300G3@h06@l@01@:2`0C2@X05`d>01/A4P0H
3Pl04@L800804PP90P0C2@X201@:2`0<01H<3@0<0P<05@/<01T?400E2``0<RPY02TM7`0:000050T:
01dA4`0C1`T05@T;1P0B1PP04P0/8R40<BLV01881`0>10<02`4001H<2`0D2PT05P`;01dC4P0;0@00
2P4101dC4P0K3a4040@601D92`0C1`T05PX<018620H04`L900L07Q8F00d31@17>cl0Bcm30104200E
2@d04@D900804`L;00D04@D901862P0C1`/03`<701452@0200h21P804@D900H02`0301862P0I3A40
4PH:01hB5P0O4aL20186200601451`0?0`D04@D701<72@0B1PP03@430P0C1`T06P0N4Q@07a<E01<7
2`0>0PH02`0300h31P0C1`/03`<701@8300g:bl04PH:0104200?0`L04`L;01T=4@0?0`L02P0201X>
4P0P51P05@T=00h31P0C1`/05PX>01<72`08000050P;0P0?0`D01@0P51H05PX<00/00@0B1PP04`L9
00804PH800T04@D70186200A1@P040@800P0000?0`L05PX>01lC5`0<0P@01@0@10P0100@10L040@6
01041P0A1@L3018620D04@D700<04@H50146100A1P@00`0A1P@201<81P0J0146100?10803`@20187
1@0@10@020000188200B1PH03`<300h20P0<000040@401dA4@0_8b<07a<C00`0000A1@L040@600X0
0@0800003`<501H:300@10H02P0001<72@0O4aD201041P0<00P0000I3@l02`4200T0000P51H02000
01D92`0;0@802000020D5P0=0P<04`L91`0A1@L01@0F2P`06@d?00/00@0B20T03`<501Cooooo000K
ooooo`0G01D:400B1`d04@H<01<83P0D2@l04PL=01052`0C20h03P<90146300H3A<03@<601872`0F
30d04PP901H<3@0L4Q<04@L801P>3`0A1`P03`D601hD5@0M4a@00P0B20T201@:2`0501<92P0B20T0
4PP901<92P0B20T00`0C2@X01@0B20T050P:01@82P0C1`T04PH800804`L900<04PH801<72@0C1`T0
0`0D20X301<92P0@01882@0A1`P04@L801@:2`0C2@X04PP901<92P0D2P/05``90146000e:b<09Q/F
01<8100G30T050T701<71`<04`L900@04`L;0186200B1PH04`L70`0D20P201<71`8050P80P0E2@T0
4`0C20T07aDG03hc=P0N4aH03P@600`2100H3Q0030<500d31@0G3Pl040D801H;3P0E2Ph040D90146
2P0D2@d04`P<01@93@0F2`l00P0E2Ph301@93@0301873@0C20h050T?008050T?00L04`P>01L<4P0D
2@l0:b0V0146300K41H050T?00<05P/?0`0E2Ph02@0<0`D04@H:01H<3`0B1`/05``@01882`0@1`P0
5a4A018<300201D?3`0?00`61P0C3@d04P`<018<300J51@07aTI01D?3`0C3@d05@l?01LA4@0H4Q80
6Q@D01TC4`0F41005a4A00@0618B02h06ADD028N7@0D40l06aLF018>3@0N6QT06QHE01LC4P0I5A@0
5Q8A020L6`0I5A@071HE01dI5`0L61H06aLE01/I5P0N7AX05QDB01`L6@0O81`08B4N03/l>00T9280
8alP024O8@0P7R007Q`N01hN7`0P8240>3Pi07AfMP0];bl0828R02HZ:P0J7Qh08B4Q02<S8`0J6QX0
9RHV02<U900c=C@0GV1O02T];00X;2/092PW0P0Z<2h0;00U;Rd092d/02H_;P0U;Rd09Rh`02Ta<`0]
=CP0;SHi02lf>`0_=S`0;SDk030i>`0^>3L0;CLh034l?@0_>S`0<3/o02lk@011CU@0NHR?05UWK`0c
@DX0=49=03]9D00jB4`0?Ta@03e:D@19EUl0DEeY04]GI@1DH700Dei`04aGK015CfL0A4iV041=G00d
@d/0CUaT05m^MP1>GFD0AUEM03Q7C`11D5P0@e9J0P16EEd05015E5/0A5=H03a;D00oCU<0@e9G051O
I015E5T0?DaA04mNH`1IJ6d0CUeR04QGG017EU/0AEAI04YIGP1EI6T0D5mT04UHG@1LJg00D5mT0P1C
HVL0301=G640C5]P05=RIP1:FE`0D61P05ATI01EIFD0EVIV051PH01BHV80E6AT05QXJ080FVYZ01X0
FFUY05MWI`1GIfH0EfMV05MWI`1IJFT0FVYZ05i^K`1PKg40IgIi06UhO01SLWH0Hg9e06agN@1WLW@0
J7=e06agN@1]N7X0IW5c06agN@1ZMGL0IW5c06E`LP1WLW@0J7=e06YeM`80K7Mi00@0LGan079mO`1d
Oh40L7]m0P1aO7h04@1`Ngd0KgYl06ehNP1]N7`0LGb007V4R01lQhT0L7]m06MbM01VLW80KGUg05aX
IP1/N7H0R9BB05eYI`1LIVH0GfUY0080FfEU02L0GFMW05aVIP1JI6@0HF][06=]K@1KIFD0F69R05iZ
JP1JIfP0FVQ[05]YK01FHfT0GV]c06UfOP1DHFT0CeaR051MH`1>G5l0C5YK04mMGP1>FEl0B5=I04A?
E@1<Ee/0BUEI04QCEP18DeD0AU9B04=?C`0oBd/0?DU903a7A`19De@0>dE603Y4A@0b?3d0>49303Do
@00`>S/00P0b?3d06`0c?Ch0>D=403Y4A@0kADL0>dA903a8C`0e@T/0<d1;03a8E@0jA4l0<ca603Ln
A@0e>Sh0;c<f02`_;`0a=3<0<cHe02lb<@0Z;B`0;2l^02lb<@0]<2l0:B`[02@W9P0R9B@08B@S024Q
8@0202TY:@0603lo?`1:BTX0<C4a02PX:00V9RH08b<S0P0P82003@0R8R8061XI02la<00Q8R<0:b`]
02l`<@16AdX0@dA8030a=@0U9RX09BH[02`]<P0Y:Rl00P0R8BH202<R9`0902@S:00U92T092<X02<R
9`0P7b@07QdR01lN8`0P7b@07QdS00<07ahS00@07ahR01hN800K6ad071`M0`0K6a/02@0L71`07A/N
02LU:00f=3L0;bd`01/I700J61/071XM01/I700201hL7`0?01TG6P0J61/05Q@G01/I700F51L07A/N
01XH6`0I5aX07adP018@4`0L6Qd05Q@G01`J7@0=2`h05a<C00806ADE0P0G4a<01@0F4Q805a<C01HB
4P0E4A405Q8B00805a<C00l06ADD01DA400E4A004`l>01DA400J5QD05A4@01TE500U8B008alN01LC
4P0H51<05@l?01XD500I4a<00P0E3`l00`0H4Q805a4A00l92@0201PB4P0?018<300H4Q@0:bDZ02lY
;@0T7R8040/>01<=3`0H4Q@03@P902LQ8@0G4A405@l?018=2P0C2`X05@/<008060h?0`0F30d601D;
300601T?400J41405@/<01@:2`0E2``04PP90P0F30d0100A1`P06Q0A01/A4P0E2``201H<3@080106
1`0A1`P04PP901H<3@0A1`P05@/<01`B4`0H3Pl301882@804`T:0P0D2P/0300>10D05P`=00l61`0<
0`<06@l@024G600A1@L0BSi003DY:`0800005PX<01P=3`H04PH800T040H601dC4`0@1PH060h>0188
200A1`L05@/;01D<300:0P400P0D2PX0100A1`L050P:01451`0I3@l30186200801041P0A1@L04PH8
0186200A1@L040@601<72`0D2@`201862P0301<72`0>0PH04@D900804`L;01@04@D901862P0C1`/0
3`<701<72`0D20`04PH:01452@0C1`/03`D701@8300C2@/050T<04@h?01MDED04PH801<72@0A1@L0
3`<501041P804PH8018050P:01<72@0D20X05`/=00/10P0>10D06PhA01H:3@0@1@L03`D700l41P0C
1`X04PP:01041`0E2@`050P;00h21@0=0PD201H:3P0>00l41`0A1@T05PX>01452@0?0`L06`lC00l6
1`0V71h0@3@g0186200?0`D04@D701<72@0G2`d201<72@0;0186200A1@L04PH801<72@0A1PP05`/?
00`1100G2`l03P8601452@0B1PX00P0C1`/201862P0501452@0A1@P040@601041P0A1@L00`0B1PP5
01451`0301451@0A1P@04@H400<04@H401004`P601871@0B1`D04@H401871@0A1P@05`/;00l51@0R
5aL06Ph>0104100>0`<04@D501@8200=0P804PP80P0B1PH0600M4A<07a<E01D92`0=0`@04@D70146
1`0E2@/04`L900l41@0>0`@04@D701@82P0@10H03@<402@H6P0M4A<04@H7040d=P0K3a404PP900X0
000E2@/03`D6018620L04@D700D03P<501451`0<0P<0N6a^01lC5@0Dooooo`006oooool0800A1P`0
4`P>01873@0@1@/03`@:01052`0<0@L04`P>0146300S61h0<RL]00l4200=0PH04PP900h41@0D2P/0
718C00h41@0=0`@04@L801061`0E2``050X;00d3100>10D040H701882@0@1PL03`D601882@0A1`P0
4`T:0P0D2P/01@0A1`P040H70186200D20X05@T;00<04`L90P0B1PP01P0C1`T050P:01@82P0D20X0
5@/<01@:2`804`T:0P0B20T00`0F30d050X;01<92P0201882@0800d4100K40`05@X601870`0E2PH0
5``:0105100C1`L301<72@0401<72`0B1PL04PH601<71`<050P80`0C1`L0300D20P05@T901D92@0E
2P/01`0002PN7`0;0P<08QPI00P0000=0`@06a4B01@:2`805P`=00L0308301D;3@0B1`/05``@01P=
4@0D2@d05@X>00<05P/?0P0E2Ph03@0D2@d060dC01P=4`0G31805@X@01@93`0B1`d06PlE00L00P0D
2`l07A8H01873@0F2a400`0E2Ph07@0D2@d04`P<01<8300E2Ph04@H:01L<401?A4P0Fe1D01X@500D
2``06A<C010:2P0C3@d050h>00h8200C3@d05Q0@010:2P0A2`/05@l?00h8200B30`05@l?01LA4@0H
4Q805@l?01<=3@0F4100618B00<06A<C00T0618B01PD4`0I5A@06aLF01PD4`0L61L06ADD024M700K
5aH00P0I5A@06P0]:BP0:RHU01/E5@0M61L07ATH01`H5`0K6AL071/I024P7P0F5Q@0=SHd01HF500N
7Q`06QXH024M7P0L6Q/07A/L020N7`0P82007alO01hN7P0j?3/051HE01lQ800H71/09RXY0P0L71`0
2P0T92@07alO02PZ:@0S9B@09RPW02``;`0E6AP0:2`[01dS8@0Y;bd202Tb<@0701/T8`0V;bh0;cLi
02<[;@0]=CP0;SHi02lg>`0202lf?00R02lh>P0b?3/0=3ho02lj>`0U<380:C@h03A0A@0H9B/0EFA[
03I4C00mBe@0>4IA03Y8CP0/>S/0>4I903E3B01BGfL0MX:>05EQK`12CUh0A4mS04iHK`1BG7D0C5Ia
03m;G00c@TT0>TU@041?EP14DeX0KWf4049AF00oCUD0@U5H04QGGP80BUUP02H0@E1E03Q7C00oCU<0
@e9G05=RI`0nCE80CEaQ03]:C`19F5d0AeIK04IEFP18Ee`0CEaQ04IEFP1;FUl0CUeR04YIGP1DHfP0
DV5V05i]LP1RLGH0D5mT04eLH@1TLgL0E6=V04mOG`1@H600DV9R051PH01AHF40DV9R055QH@1DI6@0
Ff][05a/K01GIfL0E6AT05IVIP@0F6QX00L0GFe]05m^L01QL7<0LH2306UhN`1/Ngh0Gfe^0080JWEg
0180Ig9d06YeM`1_NW`0JgIh06=^L01OJV`0Hfi`06UdMP1ZMGL0K7Mi06A_L@1gPX@0JGAf06mjO01]
N7X0JWEg06agN@1]N7X306iiN`0I06MbMP1`Ngl0LGb006MbM01RKFl0Hfi`06=_K`1EHEl0FVIT061/
JP1^NWP0CEUG05aVI`1NJ6T0FF=T05eWJ01TKVl0Hfe^06E_L01BG5d0G6IW05eWJ01EGf00FVIV05=Q
HP0205=QI00B05ISJ@1BGfL0CEYR051MI@1?G680CEYP051NH@1:F5T0@Dm@04QCF@19E5X0DEaR04eH
G01<Ee/0Ae9E04A?D@13Cdl0@4a<0P0nBTX07015D500Hfe^04]EEP0mAdP0=Cm003i8B@0c?Ch0;CLh
02li>P0]=cP0;SPi03@n?`0g@480=3]102df?@0`>T80;S]3030mAP0f@T/0<Sa5030i@00d>Sl0=3Pk
03Df>00d=SH0<C<b030b<@0^<2l202la<00702d_;P0Z;2/092HU028T8`0T9RD0:R`[02HV9P0202DU
9@0601dM7@0S8b<09RHV02LW9`0U9BD0820P0P0L71`06P0M7Ad08R@S01dO7P0Y:R`06a`N03Lh>P1D
EET0:BX^02<T:00U9R/071dR020Q9P0W:2d0:bX_02XY;P0X9b`092<X028Q9P0P7b@06aXO01lN8`0S
8RL08B0U01lN8`0Q82D071/Q0P0P7b@03P0L6b0071`O020P8P0M7Al071`M01/K6`0L71`07alO024Q
8@0J61/07adP02LU:00M6ah04@lB0P0P7R40100G5AP061HI01LE600G5AP201hL7`0901LE600C4A@0
6aTL01HD5`0N71l05aDH01hL7`0L6Qd0518E008040hA00d0<Rh_04A0@@0S7b005Q8C01lK700B3Pl0
61@E01DA4P0D41405A4B01LC500H51D04`l>00806QHE00`04@d<01hJ6@0a;B`07QXI014=300F4Q40
5A4@018>3@0I5A@05@l?01/E5@0J51@201@>3P0301H@400C3@d05@l?00805a4A014050h>018<3P0F
41D07aTM01H@500E3a<08adO01dG6@0L5QP07ALG00l92@0E3`l030L401/B4P0J41405@/<01<92P02
01@:2`H05@/<00L050X;01T?400K4A805@/<01@:2`0E2``04@L800805P`=00l04PP901dC500O5AH0
5P`=01P>3`0J41405P`=01D;300B20T05`d>00h41@0=0`@050X;01882@0A1`P00P0E2``0400D2P/0
4`T:01882@0A1`P05`d>01061`0A1`P05P`=01<92P0@1PL04PH803L[;@0J3Q0060`>01D92`0?1@H6
0186200D038X:@0e:b`04`T:01061`0=0`@05P`=01061`1FC4d05P`=01T?400<10@06Q0A00`00P0J
3Q00:1`N01L;3@0A1@L060`>0186200C1`T201D92`0901<72@0B1PP060`@01862P0K3a<06@dA00l3
1`0H31004@D900804`L;00l04@D901862P0C1`/03`<70104200A1@T03`<70104200G2`l05@T=00P0
000@10P06PhB01`@500>0PH00P0D20X01@0B1PP040@601451`0C1`T03@4300805@T;02d02`0101@8
2P0D20X06@d?00P0000900005`/=01041P0C1`T05@T;00P0000O4aD02P010186200F2P`04`L;00/0
0`0A1@T04PH:01@8300L41@05PX>01@8300;00<04`L;01452@0C1`X03@4301T=3`0B1PP03`<501P<
3P0>10D04PH801451`0@10H04PH801<72@0D20/04`L;0104200B1PX03@4501dA5@0@1@P00P0D20`0
100C1`/04PH:01862P0A1@P201041P0401451`0B1PP04PH8018620D04@D700<04@D60146100A1P@0
0`0A1P@03`0<0@0040D301@91`0@1@<03P<101050`0;0000710@03HZ:P0A1@D02`0001451@080000
5@T901H:2P0201P<300I00h20P0F2P`03`<501451`0D20X03P840186200<00805PX<01D92`0;0040
5PX<00h2100C1`T05@T;01451`0:00004`L901H:300A1@L060`>00T0000E2@/03@4301D92`060145
1`0600P0000K3a4040@601H:300E2@/03P845?ooool001_ooooo100A1P`06`0C20h050T?01<83P0I
3Q@03P<902DJ800o=3X04`P<01H;3`0@1PL05P`=01<92P0>10D0718C01T?400@1PL06Q0A00l51P0A
1`P05@/<01061`0B20T04`T:01@:2`0B20T04@L801D;300201@:2`0A01D;300F30d05`d>00h2100A
1@L04`L901@82P0E2@/05PX<00h2100C1`T05`/=0186200@10H05@T;00h41@0A1`P00P0B20T00`0C
2@X050X;01061`020147200?01<92P0B20T040H401050`0?10804@H401D:200M4A407a<C01H:2P0D
20X05@T;01@82P0A1@L04PH7008050P800d04`L701@8200D20P060`<01T=3@0?0`<04@D501H:2P0B
1PH050T901H<3@0C2@X03P@500806a4B00/04`T:01`B4`0H3Pl05Ph>07meMP1hKVl04`P;00d21P0A
1PX060dA01462P0300l4200=01872`0@1@T0714E01T>4P0@1@/03047024F700D2@l01`0201/@5P0F
2a405@X@01@93`0201H;4@0>01D:400H3A405@X>01872`0D2@d05@X>01872`0F2`l06a0D00l6201i
KW80Uhb@03/a=00C2P/201<=3@03018<300E3`l050h>00804`d=0P0D3Ph201D?3`08018<300C3@d0
50h>01H@400J51@071HF014;2`0G4A4201/E5@806A<C0P0K5aH301XF5@0401TE500B3Pd07ATH01lK
6P808QhM02006QHE01/E5@0O6QT06ADD01XF5@0P7Q`071/I01dL6P0T92808R8P01/K6@0L71X051@B
020L7@0S8B807A/L01`J6`0N7Qh071`L02<S8`0O8B0071hM024S8P0J7Qd082@S01lO7`0T92@08b<S
01lO7`0S9B@0:2XY028T8`809BTX00D09b/Z02H/:P0Q9bD08R/Z02D^;@0202L`;`0_02P`<P0Z<S@0
:c<f02`d=`0a>Cd0<cY002lf?00Z<cD0=3hm02hh>@0S;Rl0<Sdo02`g>`0c?d@0;ca203m>E@0jB500
>DM@02lmB00gAD/0>DM803Q6B@0d@DL0?4UA041<F012CU`0?4QH049=H@1BGG<0EEmh059LM`1]NHX0
@4mD03a;D00mC540@U5F04=BE`12DEH0@e9G045@E@17EU/0?diC04QGG011D5D0?TeB03e<D@11D5D0
0P15E5T01P0oCU<0CUeR04QGG017EU/0AUEJ04]JG`80AeIK00/0C5]P04eLH@19F5d0BeYO05ETJ@2N
[K80]<?7051OI01<Ff00EFAX04mNH@0204mOG`06055QH@1DI6@0F6QX05EUI@1DI6@0EFEU0P1GIfL0
2`1DI6@0DV5T05MVJ@1CHVD0DV5T05QXJ@1JJVX0G6a/05e]K@1NKVh0H71`0080HW9b00@0IG=d06Qf
M`1ULg@0IWAe0P1/NW/03`1SLG80IWAe06AbL`1TLW<0J7Ig06IdM@1_NW`0Ig9d06ehNP1_NW`0JGAf
06iiN`1[MWP0JWEg06agN@0206mjO01?06YeM`1WLWH0JgIj06ehO01YM7H0IG1b06A_L@1MJFT0GFUW
05aXIP1KIfD0FFES05QTHP1KIVL0GVU[05YUI`1KIVP0HVe_06=^L01TKg40GFQZ05MRI01DGf40DeiP
05AOH@1FI6D0D5iQ05ESIP1>Ff40C5UQ05ISJ`1BGfL0CU]Q051MH`1>G5l0BUQI04]IFP1;EU`0CeYP
04aGG@1<Ee/0DUeQ04IAE012CDl0AU9B03i:BP0f@T80?DU904IAD@1BFU`0CEEG03e5A`0e?Cl0=3`n
03Dm?`0_=cT0:C4c02/c=@0]=CL0;cLi03Hm@P0k@TX0=d17038lA00i@d`0?4I?03]5CP0e@4H0<CY1
038h?@0/<3<0;c0b03Lh>@0e=cH0<38a02X/:`0Y:bX0:R`[02LY:00202HX9`0C01lQ800M7ah092HU
02PX:00S8b<09BDU02XZ:P0V9RH08R8R02HV9P0P82008B4Q01dM7@0V9RH0:2PX01dN800[;2h0824S
01/L8002038c=`08051AEP0T9BX0>CXo02HV;P0K6b<092@[02XY;P0X9b`202HU:P0F02DT:@0R8BH0
92<X02@S:00I61d08R4V024P9@0O7R<0:bX`01@C6@0N7B804A0E01HF6@0P828071`N01/K700J6QX0
6a/K01XJ6P0F5QH07A/N01`J7@806QPK0P0K6A`01P0J61/071XM01dK7P0M6ah071XM01XH6`805aDH
00@071XM01HD5`0K6A`02@L:0P0H5QT0400D4QD04@lB01HD5`0N71l07QXK01dI6P0E4A806QHG024M
7P0A3@h061@E01<?400O6a`0:bLX010<3@0/:2T201LC4P0501DA400F4Q4071PG020L6`0J5QD00P0G
4a802@0I5A@061@C01LC4P0V82005a4A01TC4`0G4A407ALG01@>3P0201LA4@0F01H@400D3Ph04`d=
01@>400J4AL0>2ld034X;@0O5Q/0;2<V0558B`0D2`h04`X;01@;300G3Pl06A4?01`C4`0J414050X;
01X@4@0=0`@060h?01D;30804PP901d05P`=00l51P0?1@H060h?01L=3P0D2P/03`D601061`0E2``0
5P`=01882@0@1PL04`T:01`B4`0H3Pl040H702dS9017?Ch07Q@E00`20`0J41406@l@01061`0I3a00
4@L801061`0K4A807A<D01T?400201@:2`0801<92P0?1@H03`D601882@0E2``04@L801061`0B20T2
01451`804`L901@050P:01D92`0?0`D04`L901D92`0A1@L04PH801D92`0F30d01`0001882@0=0`@0
2`420147200C2@X0DdU:024G600D2P/040H701@:2`H04PH80P0?0`D0200G2`d06@d?0186200>0P@0
5PX>01@8300B1PX04@D90P0@10P05P0F2Ph04`L;0104200D20`05PX>00X00P0<00@0GE5E01lC5`0D
20`040H801452@0G2`l040@800`0100E2@d03P8601@8300L41802000028F600?1@H201451`0701P<
3P0<00804`L900X00@0O4aD03`<501041P030186200401041P0?0`D04@D700h2108050P:00<04@D7
01<72@0C1`/01@0C1`/08`0?0`L03@4501@8300N4QH05`/?00l31P0C1`T040@600d20`0I3@l05PX<
00d10`0C1`T0300201P<3P0:00004`L90145200<00@03`<701T=4@0=0@D05PX>00h31P0D20`05PX>
01D93@0B1PX04@D901hB5@0H30h03@4301H:300D20X03P8400H040@600h03@8303@X:01<@4003000
00d10@0H30`04`L700P0000@10@04@D500l30`0>0P803`<3010410804@D50P0@10@04P0<00004`L7
00l30`0D20P0300000l51@0E2@/03P840186200C1`T0300201<72@0D20X04PH800l31@0@10H04@D7
018620804`L900L04PH801041P0A1@L050P:01041P0C1`T04PH800803`<500<04PH801451`0A1@L0
0P0B1PP201<72@0601H:300?0`D02`01024E5`0@10H06Ph@5?ooool001_ooooo0P0C20h01@0B1`d0
4`P>01D:400E2Q0050T?008040D;02T05@X@01@:3`0<0PD0714E01@:2`0G3@h05P`=0147200H3Pl0
?C<d01492@0<0`<050X;01L=3P0?1`L04@L801882@0C2@X050X;01<92P0B20T07aDF01/A4P0G3@h0
4`T:01061`0?1@H07Q8D02PL7P0H30h04PH801L;3@0?0`D04`L900l31@0C1`T050P:01451`0B1PP0
4PP901<92P0501@:2`0A01882@0A1`P04PP901<92P0C20T05`/:01451P0F2`/05@/<01T=3P0S5aP0
50P90186200C1`T05@T;01@82P0E2@X00P0E2@T0100D20P05@T901D92@0C1`L201L;2`0T020D500O
4a<04`L701@92@0@1PH03`D501H<300B20P040H601<92@0<0P<05P`<01@:2P0P5QL0:1hN01472@0J
3a<050T=01D:3P0S61`05P`?01@93@0B1`/04`P<01462P0O51P08AHJ01T>500L4AL04@H<01`A5`0I
3Q@0IeaR01H;4@0E2Q0050T?0P0F2a40400E2Q0060dA01H;3`0D2@d05@X>01H;3`0D2@d03@@601`A
5@0E2Ph0714E028G6`0F30l04`X;018<300C3@d201@>3P<04`d=0P0D3Ph201D?3`0:01<=3@0D3Ph0
50h>01H@400I4a<06aDE01TC4`0F410050h>01H@4080618B034061@C01XF5@0J5QD06aLF01XF5@0I
5A@0510?01PD4`0Q7A`06QHE01dI600K5aH06Q@E01hI6P0M6AT07QXJ020M7@0K6AT0:RPX01dM700G
5aH08B4P02h^;@1IFEP08AdM02<Q8@0O7Ad07QdL020P7`0N7Qd0820O01dO7@0K7A/08R@R01`P7P0R
9b@0;bl_02<S8`0P820092@T02<U900Q8b8092HU02DY:00S9bH09RXY02H/:P0S:BL09Rl^0080:C8a
00H0:34`02Xb=00[<cD0;CDh02/c=P0]=CT2030g?@0M03<l?P0oBDP0;cTj02hh>P0jADL0>4=7049>
D`0lBDl0B5MN03I4C00jB540<d5<03I3B`0fA4P0>4E:03]8C`10CEH0?DUE03]7E@1;EfL0EF1b04QC
J01JI7`0BUE/04ICH@0lBe00=dI;03Q7C00nCE800P0oCU<04010Ce@0?DaA04ACF013DUL0DV5V049A
EP10Ce@0@E1E04ACF015E5T0A5=H049AEP1=G640B5ML04IEFP18Ee`204]JG`0>04UHG@1:FEh0BEQM
04EDF@19F5d0E6=X065`M@1_OX<0DF1U05YYKP1@Gf<0E6=V05=SH`1BHV82055QH@0405ATI01AHF40
E6AT05IVIP80DF5Q01X0EfMW055PH`1GIVX0EfIZ05QWJP1HJ6X0DV5S05a/K01MKFd0GVi^05m_K`1Q
LG40HW9a061_K`1TLg@0HW5b06AcL`1YN7P0IWEf06]jN`1/Ng/0IWEe06EdM01YN7P0IgEf06]fN080
KGQj0P1[MWP03P1/MgT0JWEg06UdMP1ZMGL0K7Mi06]fN01WLW@0J7=g06UdN01XLgL0I6ma05mZK01N
JF/0Gf][0P1NJVP06@1MJFL0FfMU05YVI01OJV`0FFAV05YUI`1VLG<0I6ma05]VJ01OJV`0GFQZ05]V
J01FHF<0D5]M04iIF`1?GEh0CE]N04ABE@1JIfd0HVmg04eJHP1<FF40BUMM04eJH01<FUd00P16E5D0
3P16DEL0BUEK04YEF`16DED0B5=G03m:C@0mB4X0?TY:03U5A@12CTh0BeMG045;C00nATP0?DE70P0f
?T00700h@480=Cdo02/c=@0V;S00:30b02Ta<`0Z<S@0<CPm03U0B@0l@d`0<S]3030j@P0b?D@0=Cm5
038l?`0a>3d0<CHi02X];P0Y:B/0;2`/030a<00d=C@0<c@d02h_;P0[;2`0:BXZ02X[:P0Y:RX202<T
900602TZ:P0b<S80;Bd]02LW9`0Z:RX0:BTY0P0P82004P0M7Ad08B4Q01HF5P0L71`0;2`/02TZ;00Y
:Rd0;2d`024R9P0L7B40<S<g06AUJP0_<3D0:2P_020P:00X:3008b</02@S:@808b8W0P0T8bP00`0Q
82D071/P02HU:P02028Q9P0@02<R9`0P7b@07ahT02DT:P0H5a`05QDJ01`L7`0K6ad071`N01XJ6`0I
6AT06QXJ01/K6`0J6QX07Q`O01dK7P@06QPK00<05aDH01TG6P0I5aX00P0I5aX06@0G5AP06ALJ01/I
700P7R406ALJ01<A500F51L05aDH01HD5`0D4QD05A<F01LE600I5aX05a<E01HB500K5aT05a8E01DA
4`0E41<06aHI01D@4`0G4aD0920R01LC5@0[9bP00P0H51<01P0G4a805A4@01LC4P0I5A@05A4@01HB
4@8061@C02@0510?010<2`0F410071HF02PR8P0G4A4050h>01H@400G4A404P`<01D?3`0J51@06A<C
01D?4@0J41L05`hC01/B5`0G3Q<04PT<01L>4@0L4aH08QTJ01lF5`0F3@h04`/901D<2`0T6Q/05`d>
01X@4@0F30d06@l@01H<3@0K4A807Q@E01T?400D2P/201T?400<01@:2`0G3@h06@l@01D;300B20T0
40H701L=3P0M4a@060h?01@:2`0B20T03`H60P0D2P/05@0@1PL060h?01H<3@0D2P/03P@501882@0J
4140:b4R01X@4@0F30d050X;01882@0C2@X050X;01<92P0@1PL04PP901@:2`0B20T04@L801882@03
01@82P804`L901004PH801451`0C1`T050P:01451`0B1PP05@T;0106200@1@P04PT:01@:300>10H0
6@hA01/@4`0K4A<030840P0D2P`00`0B1`X04PH8018620040186200601T=3`0C1`T04`L901@82P0A
1@L04`L90P0C1`/08`0A1@T040@801452@0A1@T04`L;028F6P0J3Q80300400d21@0G2`l050T<04Pl
@00Q5aT03`<700h41P0F30h04@D901@8300J3Q807a<G00h21P0?0`L06@h?00h41@0E2@/06Ph@00h4
1@0L41806Pl@0147200I3@l050X;00d3100@10H04@D600<04`L80P0A1@H01P0@10D03`<401@82@0E
2@X040@501451`H04`L;0P0B1PX07@0E2@d06PhB01H:3P0C1`X05`/=01@82P0B1PP0710B01X>400H
30h05PX<01451`0?0`D03`D601041P0F2Pd04PH:00l51`0>0`H06`lC01<72`0B1PX050P<01D93@0C
1`/04@D901862P0Q5AP07Q8D00804PH80P0>0`@60186200901041P0S5aP0<bPY00h20`0>0`<04`P9
02DI6P0F2P/050P900803P<400<04`L80104100@10@00`0A1@D03@0@10@050P800T0000B1PH03@<3
01451@0E2PX03P@500h2100O4aD08aLI01H;300?10D00`0A1@L00`0B1PP04@D701451`0201041P80
4@D700T04`L901@82P0>0P@050P:01H:300D20X040@600l31@0@10H00P0A1@L30186200600h2100E
2@/0710B02hR900E2@/04PH85?ooool001_ooooo00@05@X@01@93`0C20h04`P>0P0E2Q004`0H3A<0
50T?01T>500E2Q003P<901`A5@0J3a<040H701882@0D2P/040H70147200900004`T:020F5`0=10@0
3`D601<92P0A1`P00P0B20T301<92P8040H700`04@L801@:2`0F30d05`d>01T=3`0Q5AL05@T;0186
200F2P`040@601H:300C1`T201L;3@0F0186200A1@L050X;01<92P0D2P/05@/<01<92P0A1`P04`T:
01882@0D2P/04@L801061`0B1`T07A4C01X>400K3a402P0000`00P0W6ad06@d?01D92`<04PH800d0
4PH701<71`0B1PH04@D501861P0C1`L060`<024E5@0K3`l0710@01/?3`0C1`L05P/:00804@L601h0
5P`;01881`0B20L05@/:00h40`0E2`X04@L601<9200I3`h03`D601D:3P0=0PH081DI03db=P0]8RH0
50T=01462P0D2@d04@H:01`A5@0Q5QX03P<901P=4`0G31806PlE00L00P0O51X05P/A01D:400D2@l2
01H;4@0301D:400H3A405``@00@05P/?00`0714E00l4200H3A4060dA01hC5`0I3a805@`=014;2`0D
3Ph05@l?018<300D3Ph201<=3@8050h>0P0E3`l201@>3P0A01D?3`0F4100618B01TC4`0L5QH06Q@D
01/E5@0N61P06A<C00h8200E4A0061@C01XF5@0K5aH06QHE01PD4`0Y9B@00P0O6aX02P0?2`X071PG
02LS8P0O6A/081/M020L7@0Q7Ah08QlP020N7`0W9BH201dM7@0401/K6`0N7Qh0:b/[024M708081lM
00X08B0N024Q7`0Q8Al0820N01dO700K7AX08R@Q01`Q7@0S:2@0:b/[0P0O7al02`0W9bL09RPW024S
8P0S9B@08RHU01lS8P0R9RD092XX024W9@0T;B`09Rl^00809c0_02/0:C4c02/c=@0/=3L0;3@g02de
>@0_=S`0<3Lm02hg>@0g@D009c4b03I0@P0_>S`0;CPl03A0A@0a?T@0>dYA02Xi@@0mBe@0=TA?038o
B00a?T@0;ca4030mA@0jAe00@dmK05UUL`1NJWX0GfYl05EPL`1AG700F6=i055MJ`0nCE80>DQ=03Y9
CP10Ce@0@E1E03m>D`0nCE80>dY?049AEP11D5D0D5mT0080AEAI01T0AeIK04UHG@18Ee`0AUEJ04MF
F`1>GF80B5ML04=BE`17EU/0AUEJ04eLH@1:FEh0B5ML04MFF`15E5T0BeYO051OI018Ee`0DV5V04]J
G`1GIV/0DV5U05IUJ01EIFD0DV9R0080D61P01@0DF5Q04mOG`1CHf<0EFEU051PH01?Gel0E6AU05IU
JP1GIV/0E6=X05MVJ@1LJfh0F6MZ05YZJP1LK6`0GFe/05i^K@1PL6l0HG5`05i^KP80I7Ad0100IWIf
06UiN@1UMGD0IgMg06YjNP1VMWH0IGEe06IfMP1QLG40KGQj07R3Q@1^NG/0Ig9d06]fN01XLgD0JWEg
101YM7H02@1WLW@0JWEi06MbMP1SKW80H6]]05]VJ01II6H0Gf][05eYI`0305aXIP0605aXJ01MJ6X0
HVe_05aWJ@1FHF<0FFAV0`1KIVP02`1JIFL0EF1R04iIF`1;EUP0AeEF05ESIP1RL7<0D5eS04]HH01N
Jg<0DEiV0080BUMM02L0AUAG045?D012D540@diD04A?E@15D5H0?4M;03m:CP0nBD`0?TU;041<C00h
A4@0?4Q8049>CP0kA4D0?DE703a4AP0g?d40>D5303Y2A00c>cd0:30b02H^<00W;c409Bd_02L_<@0`
=S`0>Ce803Y1B`0d?4D0;CHm02Xe>`0]=cX0;CLh02/c=@0Y;Rh09BHX02@T900Z:RX00P0b<S805`0/
;2`09RHV02LW9`0Z:RX0:BTY02PX:00T92@09BDU02/[:`0a<C40;Rh^02HV9P0S8b<09RHV02@T900L
71`06a/K02h^;P0X:2P07alO01hN7P0^;c<0;c0d0080:2T]02@0<S<g03dn@`0H6Ah06Q/P038b>P0K
6b<07alW02HV;`0S8RP08R4V024P9@0P7b@07ahS01XI7P0N7B807A`Q01hM8P0F5AX06aXO02LV:`0Q
82H07A`R02<R9`0/:c0051<G028R900L71h061PI01HF5P0I6AT071`L01dM7@0N71l07A/N01XH6`0I
5aX201PF6@0301HD5`0G5AP05aDH00805aDH00X05Q@G01<A500E4aH030X=01/I700G5AP04@lB01DC
5P0B41<04a4D0P0G5AP03P0B41<05A0D01lJ7P0?2Ph061<G014<400H4aL06aHJ01LB5P0>2@d04`hB
00d8300D4140510@0P0G4a800`0E4A00510?01DA400201LC4P0O01PD4`0I5A@05A4@01<?3P0J51@0
4@/;01D?3`0F410081XJ01XD500G4A404`d=01D?3`0I4a<0618B01H@4P0K4QP03PD:01dD6@0W7R<0
7A@G01P?4P0K4QD08aXK02HM7P0N5AH06Q8@01081`0S6AX0308300d51@0201@:2`0501`B4`0Y7b00
:AlP01L=3P0C2@X00P0D2P/05P0F30d05@/<01H<3@0F30d05@/<01882@0K4A808ALH01P>3`0A1`P0
4PP901L=3P0N51D050X;01D;300C2@X05@/<01T?400@1PL04PP901/A4P0Z824201882@070147200@
1PL04PP901<92P0D2P/04@L801882@0201<92P804PP90`0D20X0100C1`T04PH80186200C1`T20186
200?01<72@0A1@L050P:01L<400=0PH09a`P00h31`0@1@T081DI00d21P0?1PP08aPL01P=4@0@1@T0
4PL;00H04PH800<07A4C01@82P0B1PP00P0B1PP00`0F2P`04@D901452@020104200P01452@0B1PX0
3P8600/10`0:00804`L;01L;3`0:00804@D901H:3P0A1@T05@T=01/?4`0B1PX050P<01862P0A1@T0
5`/?00h21P0D20`03@<400d10`0A1@L02000030T9P3Fb/`0FdmA00d10`0K3a403P@501dA4`080006
0104100601<71`0D20P060`<01T=3@0E2@T04`L71P0B1PX00`0@10P04@D90104200200l31`0D00l3
1P0@10H03`<500h2100D20X04`L900`10P0:00006Ph@00l41@0<0080200001<72P0I3A403@4501dA
5@0800006@dA01862P0A1@T301862P0801@8300A1PP02P0000h2100G2`d050P:0186200C1`T50186
200301@82P0C1`T06@h?008050P:00L03`<501041P0<00805PX<01<72@0@10H03083008040@40P0B
1PH05@0A1@D040@400T0000C1`L07Q8B00h20P0K3`l040@401@82P0@10H03`<500h2100;00404`L9
00l31@0@10H04`L90186200A1@L040@60186200401451`0700h2100C1`T05PX<01T=3`0H30h050P:
01451`0401@82P805@T;00H05`/=00l41@0800004`L901041P0J3Q0Dooooo`006oooool201D:4080
4`P>00@050T?01D:400A1P`04`P>0P0A1P`02@0E2Q006@hB01D:3P0?1@H04@L801@:2`0B20T04@L8
02@J6`0201@:2`030147200E2``03`D600<04@L800@04PP901<92P0C2@X05`d>1@0E2``04@0B1PP0
40@601@82P0E2@/04PH801@82P0H30h07A4C028F600L41805@T;01L;3@0C2@X04@L801882@0D2P/0
4PP9008040H700h04PP901L=3P0A1`P03P@501<82`0E2@d04PH:01H:3@0800005PX<02lS9@0J3Q00
5PX<01<720@050P80`0C1`L03P0D20P05PX:01X>3P0B1PH04@D50104100;00005@X901dC4P0J40l0
4@L601D;2P0G3@`04PP70P0?1@@0600@1PD06a4@01`B4@0@1@L05``@01<8300:00<06@hB03`a=@0B
1`/03`@801H;3`0A1PX05``@01T>4P0B1`d03@8801H;4@0C20h04@H<01@93`0F2a405@X@01@93`80
5P/A01805@X@01H;3`0F2`l05P/?01D:3P0F2`l060dA01872`0700006PlC01052@0B1`/04PP;01D<
3@0?2@T040X:018<300>20P301<=3@8050h>1P0E3`l201PB4P0403`f=P0W8B405Q0@01D?3`806A<C
00<05A4@01LC4P0J5QD00P0K5aH01@0J5QD04Ph=01/G5P0Q7A`06ADD00806aLF05D08A/M01hI6`0N
6Q/07a/L020M7P0R82406aTJ01DE5@0N7Qh06QXJ034a<@071`L081`K01hM6`0P7ad08R4O024Q7`0R
8R0092@R020R7`0M7a`08R@Q01/P700Q9R808B4Q01lO7`0Q8B409BDU02@V9@0R92<09RPW02DY:00Q
9B@092PW02D[:@0S:BL0:34`02Tb<@0Z<c80:c@c02lg>@0b>S`0:c<f02lg>P0a>3d0<3Lm02lf?00[
=3H0=d50034k?012CDh0:C@f02Pc=`0/>3d0<d1603a;DP0c@DT0C5YS041>F@0gADl0>DI>03M4C@0d
@DX0>TIB04QDHP2DX:h0RiNU04]GI`1;EVP0Ef9d04aGJ`0lBED0@4mB03a;CP0nCE00@U5D04=BE@0o
CU40@4mB03e<C`12DE@0?4]>04IEF013DUL0AEAI0080B5ML00<0AeIK04IEFP16EEX00P1>GF801016
EEX0C5]P04YIGP1<Ff0204UHG@80B5ML00d0DF1U04aKH01?GV<0E6=X04QGG01GIV/0DF1T05ASIP1C
Hf<0DF5Q051PH01AHF40Df=S0080EFEU0140EfMW05QXJ01GIfL0E6AU059QIP1HIfd0FVU^05e/L@1P
Kg<0FVU/05UYJ@1KJfX0G6a[05e]K01OKf`0H71_05][J`02061`L004069bLP1UMGD0HG5a06EeM@80
KGem00/0K7al06]kN`1SLg<0Hfi`06mjO01WLW@0HFa^06E`LP1TKg40JGAf06YeM`0306UdMP0906Ye
M`1[MWX0IW5e069]L@1QK6h0GFQZ05YUI`1MJFT0FfMU0080FVIT02P0FfMU05aXJ01NK6h0HW1c05YX
J`1DHVD0FVQ[05i/K`1IIfX0EVAW05ARI@1@GV40C5YM04]IG016E5D0>4I904IDE`19EU`0OHZB0;g:
dP1?G6@0AE9H04=@EP11Ce80@Dm@04ABD`13CU@0BUEK059MH`14Ce<0?DQ<03]6B@0kATP0@De=03Y6
AP0d@400=d=303Ho@@0m@TD0>d130P0e>Sd0500c>3/0;S<f02X_<P0Z;c80;34d02T^<@0Z;c80=SY2
03/oB`0h?TX0>T9:03DnA@0^=c`0;cTk034k?00]=CL0:2d^02T[:P0/;2`0;Rh^0P0a<C403@0/;2`0
9bLW02PX:00Y:BT09RHV02<S8`0R8R8092@T02/[:`0V9RH0:2PX02`/;00[:b/00P0W9bL0;@0f=SH0
7AdM01PH600I6AT071`L02TY:@0[;3006Q/O02@U:@0Y:Rl08b@Y065RI`0`<3P0:2P`02LW;`0M7BL0
:b/e02HV;`0H5ad06APM01dL8@0R8BH092<X028Q9P0U92T06APM024P9@0H5a`06APM02<R9`0G5Q`0
6aXO00l>4`0C4QL06QXM01LG6@0L71h061PI01HF5P0I6AT071`L01dM7@0M6ah071XM01TG6P0401PF
6@@05aDH00X061HI01HD5`0I5aX0518E02HT9`0@3Q408R0S01XH6`0H5QT06QPK0P0M6ah04P0H5QT0
4`hB01TD600L5a/04PdA020K7`0H4aL05Q4E01/F6P0E41@061<G01LB5P0H51D04@d=01HB4@0G4a80
5Q8A01DA40805Q8A00<04Ph=014=300C3`h00P0C3`h0900Z92@09b4Q01`F5P0G4A407QPH00d71`0F
41006A<C01LA4@0C3@d050h>01H@4P0F31808AHL01`A5`1LDEL0;R<W01462P0D2@d05P`=01`B4`0M
4a@060h=02TO7`1DBT/0<RPY01dC500E2``03`D601@:2`0M4a@06a4B01@:2`0K4A806Q0A01<92P80
4@L800H04`T:01D;300C2@X04PP901T?400J414201D;300:01H<3@0B20T05P`=0147200F30d04PP9
01L=3P0H3Pl02`4201882@804`T:00@03P@501<92P0C2@X04PP90P0A1`P00`0C2@X04PP901882@03
01<92P0301882@0B1PP04PH800804`L90P0D20X04P0E2@/04@D701@82P0F2P`04PH801<72@0;00@0
6PlC08=hO00U6Qh02`0401D:3P07000060dA02/P900D2@d04@H:01052@H04PH800H060`>0186200C
1`T05@T;01@82P0F2P`201452@8040@80P0B1PX07P0A1@T09ATM028F6P0D20`040@801L;3`080000
5@T=01T=4@0;00<02`430104200D20`04@D900`0100B1PX03P8601L;3`0C1`T08ADG02dQ8`0U6A/0
200006MKG@0o<cD02@000186200M4A<04@D701@82P804PH600X04@D501861P0B1PH04PH601451@0B
1PH04`L701H:2P0C1`L040@41P0B1PX00`0C1`/050P<01<72`0201452@0401862@0B1PP04PH80186
20805@T;01T04`L90186200F2P`04@D701@82P0B1PP04@D801T=4@0B1PX0304401L;3`0;00<05PX>
01@8300B1PX03@8500/00`0<00@05@T<01D92`0A1@L040@600l31@0D20X05@T;00D040@600L04PH8
00X0000=0`@04@D70186200;0@80710B00805@T;00D0300201041P0D20X040@401451@0301861P0D
01451@0D20P040@400P0000Q5AD040@401471`0=0@<040@601P<3P0I3@l04`L901041P0>0P@04@D7
01@82P0B1PP040@601451`0B1PP201041P040186200C1`T040@601D92`@050P:00<04PH801D92`0E
2@/0100D20X01P0?0`D04`L901H:300K3a404`L9018621Cooooo000Kooooo`805@X@00/04`P>0187
3@0C20h04`P>0146300C20h03P<900l42P0F2a4040D901<8300501@:2`0701H<3@0B20T05P`=01<9
2P0G3@h040H701882@020147200701882@0C2@X050X;01<92P0B20T04@L801882@0201<92P0B01D9
2`0?0`D05PX<01L;3@0A1@L050P:01451`0E2@/06Ph@01D92`0@10H050P:01<92P0@1PL04PP901L=
3P0D2P/04@L80P0B20T03@0H3Pl04PP901882@0T6A/040@801H:3P0X71l04`T:0147200F2P`04`L9
0186200D20T0100G2`/301H:2P0401L;2`0B1PH05@T901861P8050P800L03`<301L<300Q5aD081HD
01D;2@0D2PT050X800804`T801T04PP601H<2P0>10803P@201L=3@0A1PX05``@01T>4P0B1`/05P`?
01<8300?10P05``@01462P0D2@d06@hB01P=4`0@1@/05P/A01D:400K41H04@L<01H;4@0E2Q0050T?
00805P/A00@05@X@01<8300E2Ph05P/?0P0D2@d00`0G31006@hB00l4200201H;3`08020E6@0K4AD0
8QTJ01LA4@0F41005a4A01@>3P0N61P201<=3@8050h>0P0E3`l201LA4@805@l?0P0G4A401P0M5aL0
6Q@D01LA4@0I4a<06Q@D01TC4`8061@C00L06ADD01/G5P0N6QT081`K051<B`1ACD`07a/J008081`K
01808AdL01lI6`0L5aT081`M024M7P0N6a`081hO028P8@0F5QH08R8R02DU9@1JFUX09RHV01hJ6@0J
6AH07ahK028Q7P0Q8Ah2028S7`0701lQ7@0L7QX08B<O01XO6P0P9B408B4Q02<S8`0202@T90808bDT
00H0:R`[02X^;@0X;2/0:Rh]02T_;@0U:bT202Tb<@0702Pa<00Y<S40;3@f030h>P0]=CP0<SXm03<k
?`02034h?P0V038k?@0c?C`0;CLh03M1@`0lAdT0NHB805MSJ00f@dT0?TeD03Q6CP16E5d0?4YE03U6
DP0jAU40?4QE03m;F00lB5D0?TYH041<FP1NJWP0EF5`049>G@0lB5L0B5=T04=@FP0oCU40?Da?045@
D`14DeH0@E1C03m>D@11D5<0?Da?045@D`0hAdX0@E1C041?E012DEH204ACF00604=BE`16EEX0?4]@
04QGG01CHVL0AEAI0`1;FUl03@19F5d0BUUN04YIGP1:FEh0DV5V04aKH01@Gf@0C5]P04eLH@1HIf`0
CEaP05ASIP1CHf<00P1AHF40701BHV80E6AT04iNGP1>GUh0D61P05=SH`1FIVH0EfMX04]JG`1LJg40
HW5g061_M01MK700EfIY05UYJ@1JJVT0Ff]Z05a/J@1NKV/0Gfm/061`L01TM7@0HW9b06=cL`1XN7P0
IWIf06=cL`1YNGT206QhN00906MgM`1PL700HVe_06A_L@1UL780I6ma06IaL`1XLgD0IW5c0080J7=e
0180Ig9d06UdMP1]N7X0JWEi069]L@1OJVh0HVe_061[K@1NJF/0GFUY05]WI@1JIV@0FfMU05aXIP1M
JFT0FfU[05QVJ@1EHfH205]YK00505ARI@1GIFP0Df5T051NH@1=Feh00P1<FUd0A`1?GEh0CUaO051N
H@1;F5h0AU=K04UFGP11CUH0>dQ>03e:D010CU40@U1A04IDE@12CE<0D5]Q061[L@1<Ee/0?TU=04QC
EP0lAdT0=d=303U5A@0`?3`0=41003M0@@0h?D00=CXm03<h>`0e>Sd0<SLj02/`<`0Z;c80;C8e030e
>00]<SD0;S<f03PlA00e>4L0<cQ403U1BP0d?D80;CHk02Tc=@0Y<c80:2h^02<W9P0Y:bX0;Rh^02`[
;00Y:BT0:b/[02l_;`0^;Rh0:RXZ02LW9`0V9RH08R8R02<S8`0W9bL0;Bd]02`/;00O7al09bLW02h^
;P0Q8B409RHV071`L011@D408b<S024Q8@0P820092@T00<08b@X0P0T9BX07`0R8bT08b<[020P:00P
82T0820Z02TY<`0L72D081lU01lN8`0Q82D08b8W028Q9P0L6b007QdR01HE6P0Q82D061LL03He>P0L
6b0071/Q01/J801QH6D0>STn01dL800J6Q`071`N01XJ6`0I6AT06QXJ01/K6`0J6QX00P0J61/0100I
5aX061HI01XH6`0J61/201TG6P805aDH0P0I5aX01`0H5QT0EE=F01HD5`0M6ah06QPK018@4`0E4aH0
0`0F51L201LE600b04@oA00S7R<061<H01hI7P0>2Ph06A@I01PC600N6Ah07APM01D@5@0D3a@04`hB
018>3P0F4Q405a<B01HB4@0G4a8061@C01/G5P0E4A00510?01HB4@0H51<05a<B01/E5@0M5aL06aDE
01D?3`0L5QH050h>01H@400J51@0618B018<300D3Ph0618D01H;4P0L4AL04`P>02LL8P0?1PP07a@H
01T>4P0E2``060h?01/A4P0H3Pd04`T901lE5P0?1@H201<92P0:01X@4@0I3a005P`=01882@0D2P/0
5`d>01H<3@0C2@X050X;01L=3P807Q@E00D05`d>01<92P0G3@h05@/<01<92P0201L=3P0=01H<3@0C
2@X040H701@:2`0F30d04@L801T?400?1@H05P`=01<92P0E2``05P`=01@:2`0201D;30804@L80P0C
2@X01@0A1`P04PP901@:2`0D2P/04@L800804PH80P0C1`T201@82P0B01P<3P0A1@L060`>01hB500E
2@/04PH800l5200=10H0I5UM02PM8@0G31003`@800d31P0@1`T05@X>00h31`0D2@d03`@81P0B1PP0
200F2P`04@D701<72@0E2@/04`L901@82P0E2@d050P<0`0B1PX0;00C1`/040@8020D600M4AD04PH:
01452@0F2Ph05@T=0105200D20`06`lC01D:3@0>0PH040@801<72`0D20`05PX>00d11@0D20`04`P:
01D;300?1@H0<bLY01P<3P0C1`T03`@601dA4`0<0080BCdo08YnP00P51H05PX:01D9200D20L05@T8
01D:2@0F2`X05@T801@9200B1PD05P/:01P<2`0D20P04@D81@0A1@T5010420030145200A1@L04PH8
00804PH800h04`L901051P0M4A<02@0001<72@0?1@H07a<E01872P0B1PX03`<7028F6P2FRXh0710D
01<72`<04PH:00D05`/?01dA5@0H30l03P8401041P0201<72@8040@61@0A1@L03P0B1PP04`L90188
2@0C1`T050P:01<82@0=0@<03@8301<72@0;004040@60186200A1@D04PH60P0C1`L201861P0701L;
2`0<0@4060d=069FEP0U6AT04`P801041P020186200@01061`0@1@H04PH800l31@0B1PP050P:00l3
1@0>0P@04`L901H:300B1PP03P8401<72@0G2`d05PX<01<72@8040@60P0A1@L0100>0P@04PH80186
200B1PP201451`0701041P0?1@H04PH801<72@0A1@L04PL90187200Dooooo`006oooool05`0D2A40
4`P?0146300A1Ph04@H=0146300A1Ph03P<:0146300B1`l040D<01873@0@1@T05@/<01<92P0?1@H0
3P@500l51P0>10D04`T:01P>3`0A1`P060h?00804`T:00d04@L801061`0B20T050X;01D;300H3Pl0
5@/<01<92P0A1`P040H700l51P0D20X06Ph@00804`L901X05PX<01451`0E2@/03P8401451`0F2P`0
5@T;01L;3@0D2P/040H701<92P0J414060h?01@:2`0G3@h04PP901H<3@0A1`P06@l@04<h>`0F2Ph0
200001X>4P0D20`0710D01041`804@D700<04`L901@8200B1PP00`0B1PH05`0A1@D04PH601861P0D
20P06Ph>01@8200A1@D04PH60104100E2PX040H401L=300P5Q@04PP601061@0C2@P05@/900h40`0=
10@060h<01@:2@0F30`05@X>008040D901404PL;01H;3`0G31004@H:01L<400B1`/05P/?028G700?
10X06@hD00`31`0I3Q@04`P>01P=4`0F2a405@X@01@93`0201H;4@0401D:400A1PX04`P<01D:3P80
4PL;01D05``@00/0100D2@d060dA01872`0I3Q805@X>02<J7@0E3`l04PX<01@;3P0B2P`07QPH01D<
3`0D3@h050h>01H=400F3a005@l?01PB4P0G4A400P0E3`l201H@400<01/E5@0J51@05Q0@01@>3P0G
4A406aDE01`F600I51@061@A01XF4`0P7AP0924L0P1iMW40C00P7AP0:BDR024M6P0L61L07ATJ020K
7`0[9bP0;2PY028O800O7Ah07ahM01LG5@0S8b406QXH02h^;00L6aT06QTF01HE4`0N7AT08R4O01lO
7@0R8R0071`J01TK600G6AH07R0M01/M6P0Q8b808b@V020Q8`0Q8R@09bPZ02X[;@0X;2d09RPZ02T]
;P0W:b`0:2`]02D[:`0Q9bL0<3Th02hg=P0[=3<0:C8a02/c=@0]=CL0<3Pk03<k?P0a>Cd0<3Lm03@k
@@0e?T00<Shn03Q2@`0`>cd09C0b06YeN@0oBe00;ca203Y9CP0`?dH0=4=:0390B@12CeP0>TA>03M1
C@14CUX0Ae5M04==F@10BUP0IW:004mKJ@19EF<0@dmM04A@GP10CUL2041?DP0L04IEF017EUT0@U5D
03m>D@10Ce80>TU<03i=D00jBD`0B5MJ04=BE@15E5L0AeIJ04EDF@16EEP0CEaP04MFF`1FIFP0I7=g
04aKH01>GF00C5]O04]JG@19F5/0BUUL04UHF`17EUT0C5]O051OI080DF1U01T0Df9W04aKH01CHVH0
EFAW05ATI01BHV80D61P051PG`1BHV40CEeL051PH01BHV80DF5Q05MVJ@1YN7/0EFAY05i]M01GIVd0
D5mT05ETJ@1MK6l0F6MZ05UYJ@1JJVT0G6a[0080GVi]00h0H71`06=bM01OKfl0HFmb06MfM`1VMWH0
KG]l06elO@1UMGD0I79c06IeM@1SLG80J7Ad05m[J`80I71`00<0G6QX05m[J`1QKFd00P1UL7804`1T
Kg40J7=e06iiN`1VLGD0GVU]05]VJP1QK6l0HVea061[K@1OJV`0G6QX05]WI`1LJ6P0GVYZ061/K01P
KVl0KG]n06MeMP1HIVT00P1CHF@08`1DHVD0DV1S051NH@1=Feh0BUQK04UGFP1:FE`0BeUL04aIG`16
DeT0@4]A03m:D010Be40?TU=04A?D`13DE@0@4i?045?DP15D5D0@diD04iIG@0mB4`0?TU=06IaL`1?
Fe/0<S`m03I0@@0[=CH0;cTj03Dm?@0c>CL0<SHe030e=@0b>3P0;c<f0080:2d`03@0;S8e038g>P0^
<cH0<CDh030c>P0W:CD0:R`h02hb>P0T;2l08BT[028[:`0U:bT092XX02<V9P0];Bl0;bla02l^;`0X
:2H0820P024Q800V9R@092@T02LW9P0Y:BL09BDT02LW9`0[:bT0<C4a05iNGP0`<C<06Q/M02LW:@0P
8B<0>3Tk07MfN`12@dD08R<U02<S9@0N7b408R8T020O900I6Qh0820T024P9@0H6Ad09RH[01hM8`0K
72408B4Y02`[<`0`<3P09bH^0P0Q82D05P0S8RL09B@Y02<R9`0M72407ahS028Q9P0O7R<05QDJ075`
M@0n?D8061LL028P9@1gMgT0928W01/J700E5AL07A/N01/J700J6QX071XK01/J6P0G5AH301PF6@05
01TG6P0K6A`071XM01TG6P0G5AP00P0E4aH07@0G5AP06ALJ014?4P0M6Qd03@/>03<^<P091PT07A/N
01<>4P0E4QD04a4D01<>4P0C41<06A@H01@?4`0]:2h06aHJ00h93P23OX805a8F018=4@0G4QH07QTM
01<>4P0H4aL071PI01LC4P0H51<05a<B00805A4@0P0G4a803P0E4A805Q8C01LC500E4A804`l@06eW
I`0K5AD0618B01LA4@0F41005@l?01H@400E3`l05Q0@0P0I4a<0=`0H4Q@05PdB0146300K4AL081LL
01`A5@0E2`h05`hA01P>3`0F3@h050/<01H<3@0G3@h05P`=01@:2`0N51D04@L801X@4@0D2P/04`T:
01@:2`0H3Pl040H701882@0I3a004PP900l51P0C2@X060h?01H<3@0B20T05P`=01T?400E2``050X;
01<92P0A1`P04PP901`B4`0?1@H03P@501P>3`0E2``04@L800l51P0@1PL081HG00h41@0B20T04`X;
01D<3@0B20T04@P901H=3P0C2@X00P0@1`P00`0D2P/050/<0147200201D92`0F01@82P0C1`T04PH8
01451`0H30h04PH801/?4@0S5aT060`>01451`0F2`l02`0401<8300G31004@H:01872`0A1PX03P<7
01L<400F2`l03P<701D:3PH04PH800X06Ph@0186200@10H04@D700l31@0B1PP060`@01H:3P0D20`0
4`L;0P0B1PX01@0I3A405PX>00l31`0B1PX060`@00805@T=00<040@800h21P0K3a<00P0D20`20186
2P060104200C1`/03@4501L;3@0a9BL020000P0F2P`0300800006@d?01H:3009000060`>01L;3@0Y
7Al05@T901871P0@1@<03`@201050`804PL500L04`P60146100<0@004@L501H;2@0A1`H04@H70080
4@D71@0A1@T08@0C1`/05@T=01<72`0@10L040@601451`0B1PP040@601451`0@10H0>2`^01H:300H
30h07Q8D08]oP@1LD5<07a<G00P0000D2P`040@800X00P0C1`/05PX>01<72`0>0PH03`<701@8300I
3A005@T;00h2100=0@<04`L901@82P060186200800l31@0I3@l05PX<00l31@0@10H04`L901041P0>
0P@200l31@0402HJ7010=3H04@D501861P804`L70P0B1PH03`0<00005@T901L;2`0A1@D03P8200l3
0`0A1@L04PH800h2100:00003@430186200@10H04PH801<72@0200d10`0301@82P0S5aT06`lA0080
40@600P04PH800l31@0B1PP04`L901H:300H30h050P:00`00P804`L90P0B1PP201451`0600d10`0@
1PL04@D700/00@0A1PL04@D75?ooool001_ooooo00d04`H@01L:5014=d005@PB01L:4`0B1@l04@H>
01L:500C1Q005@PB01853`0B1@h04PH:00<04`L900<050P:01D92`0C1`T01@0C1`T201862P0F0188
2P0m<SD0=2T/01T=4@0C1`/060`@01@8300A1@T04`L;01452@0G2`d04PH800d10`0O4aD05P`=03X^
<00g:bd04PH803HZ;00H30h04PH801P<3PL050P:00H04PH801D92`0C1`T040@601<72P0B1PX401<7
2`080105200C1`/05@T=01H;3P0B1PT04`L;01D:2`0D20X30186200301@82P0F2P`05@T;00<050P:
0P0E2@/01@0B1PL04`L901H:2`0B1PL04PH8008050P900X03`D601<7200@10D04@H702TM7P0D20T0
50T:01451`0A1`P05`/?0P0B1PX201<63@0501@73P0D1`l04PH<01D93@0G2`l00P0E2@d0200J3Q80
50P<01@8300B1PX0710D01lC5`0T61`06@dA0P0D20`00`0F2Ph050P<01X>4P0401H:3P0?01L;3`0H
3A406PlD00l52P0I3a@050T?01P=4P0G3A805@X@02<I7P0P5QX060dC01P>4`0L4aL050`?0080618D
00H05@lA01H@4P0L5QP05a4C01H@4P0I4aD201/E5`1e01D?4@0S6b40;2@V01/D4@0T81P09B4D03dj
:@2UXi80gmo?05aMC`0d=2T08b<K01hM6@0L6Qd071XO028P900Y9bX06aTK02<R8@0K6QL06QTD01/K
500O7aL08B4H020O6@0Q81l07alO01lO7P0R8R807QhO01XJ6`0Q8B809BDX024Q900S8RH09bH[02@U
:@0R9B/08bL]024U:P0Q9B/0:2`b02P]<P0T:2d092T^02DZ;`0a=S/0:2db02`a=@0W<2h092dZ02Pa
;P0[=3<0;SHh038j?00^=SP0;SHi03@l?`0e?D00<SXm034k?P0d@T@0@4a?03U7BP0`?T40=dE803I4
A`0d@TD0>DM:03Q6BP0kBDd0=dE903Y5BP0f?d<0=cm403e5B`0lA4d0>45:03m7D`12BeL0DEYY04eG
I`1:EVH0@4aM04aHI00oC580CEYP04EBF01:Eed0@DiD03e:D00nBe40@4eC049?E@13D5H0AE=G04ME
F013DE80AE=E03m=C`10CTl0MXB604QFF01=Fe`0JGMi06]iN`1AGf00B5IH04UGE`1;FET0AeEF04AB
D`1;FET0DEmQ059PH`1AGf80DV1S0080Df1V04d0DEiS05ARI@1IIfP0G6YZ05=QH@1DHf00BUUE04UH
E@1@GUh0EVAU051NHP1=FV00DEiU05=PJ01GI6`0F6E]05MTK01GI6/0FVM]05QUJ`1MJfl0HFma069`
LP1NK6h0FVQY05m[L01QKG80IG5f06=^M01TL7@0LWj2092KW`1^NWd0GVY/06=_K`1QKFd0GVYY065]
JP1QKVP0HVmY06A`K@1SKf`0Gf]X06=_K@1ULG00HVi^06=_K`1TL700GVU[05YXJ`1KJ6h0FFI/05MU
JP1MJW00FVQ/05e[K`1JIf`0FfQ]05UVJ`1GIFT0FfU/05ITI@1JJ6P0FFMW05]YJP1FI6D0CE]L055O
HP1?GF00C5YM04]HGP19EU`0AeIK05Y[LP11D5L0A59G04QDF00204=<CP1>04A=C`17D580ATmA045<
CP0oBTh0@4]?04QCE`19E5P0?dY>045:C@12C4h0?DI803U2@`0i@D80=Cdm03U1@00k@d80=3Td030d
:`0_<RX0;c8]02X];00Z:bd0:bda02LY;P0/;3<0=SPm030b=`0`<CH0=SLl02`/<@0X:2d0:R/^02XZ
:`0_<2h0:R/Y02PY:00W:2L0:RX]02HU:P0V9B`0:RT/02DV8@0S92009RLS02h_:P0W:2@0:b/W02<T
7`0Q8Qd08B4N04E6@@1=CD/07b0R02@X:`0V:2d08B<Y02@W;`0U9S00<c@o02DX<00N8BP092H[028V
:@0Q8bH081lT02DS:P0T8RL07adP020O800N7A`0:2LV028Q800N71l09R@Y02TW;@0S82L08R0U0P0R
82<00`0T8RD08b4T01lM800201lM800G01dK7P0P7R408R0S01lM800k>3X0920S01`I6P0M6A/061DF
01hK700K5aP06AHG01`I6P0Q7Ah081`M01PD5@0J5QL07ATJ01LC500L61T06QHG01`H6@0J5QL00`0K
5aP08@0J5QL06ADF01`G6@0J51H061<D01TC5@0I51H05a8D01`F600G4A<061<E01TC5@0H4Q@07ALI
02LQ8`0M5aX0618D01TC5@0J51D06aDF01LA4P0F40l061<A01`G5@0H4`l04`h:01PB4P0F41006Q@D
01TC5@0F41806A<E01`F6@0201TC5`0501XC6@0C3A8050hB028L7P0K5AL00P0H4Q@05`0G4A<06A<E
01TC5@0E3a405a4C01/E5`0F41804P`>01H@4P0G4180614C01PB500I4Q@05a0B02hX:P0@20/05a0B
018=3P0I4Q@04`T=02DJ7P0G31006PlC00<050T=00`05P/?01@93@0E2Ph05P/?01D:3P0G2`h04PH8
01P<3P0C20X040H701P<3P0F2P`201L;3@0O01H:300D20X050P:01<72@0D20X05`/=01H:300B1PP0
50P:01L;3@0D20X04`L901H:300G2`d050T:01<:2`0C3@d03`P800l7200C3@d04``=06QPH@2c[Jd0
>c@d02PQ8@0J51@040P901882@0B1PP04@D70186200401@82P0:01<72@0B1PP04@D701041P0B1PP0
3`<501@82P0H30h05PX<01D92`@04@D70P0C1`T03P0>0`H05@T=01D93@0J3Q804PH:01452@0B1PX0
50P<01452@0B1PX05PX>01452@0F1`X05@H90P0D1@P201H72P8050D8100C10L601451`0401@82P0C
1`T04PH8018620804@D701l08QHG01P<300C1`L04`L701@8200E2@T05P/;01<92@0C1`L04@H601/?
3`0`92@0?Bl_00l10@0L3Ph04`D501P<300A1@D05`d<02DK6P0K4A004@T70189200?1`D04PX800`3
0@0A20H0>2h^02PN7`0D2P/04@D700<050D:00<04`@901<4200C10L0100C10L0200G20/07PlB01h?
4P0D1PP06@X=02dN8@0Z6ah050D80P0E1PT0200C10L04P<601831P0E1`T03@0101P:300H2@`03001
0`0C10L0100D1@P04`@701<41`0C10L201831P0_01421@0B0`H04P<601441@0>10<04`L701871`0B
20P05`d>01D:2`0@10H04PH:00d31@0J3Q80;b<V01H72@0E1`L04`D50184100C1@D04PD501@61P0@
0P805@P801861P0?0`<0;b4Q01@82P0C1`T04@D700l31@0@10H04PH801061`0H3@h0@CDg01D;300B
1PP05`/=01l@4`0J2`h04`@701421@0D1@P05@H901@5200C10L00P0B0`H0100C10L050D801<41`0D
1@P201D62@0301@5200C10L04`@700D04`@75?ooool001_ooooo00h070lH00h12P0C1Pl0200401H9
4P0A10d040<<00h22P0A10d03@0901hA6P0K3QD050P<01@82P<04`L900<04PH801@82P0D20X0100D
20X02@0C1`/07A4E01@8300^8RH0:alS00h21P0E2@d08ADI01`@500201<72`0:01@8300C1`T07Q8D
00l31@0E2@/04@D702lS9@0/828040@601D92`80710B00<02P0001@82P0D20X0100D20X201862004
01<72@0@10H04PH801D930804`L;00X050P<01<72`0B1PX040@802XN8P0:00804`T;00P0000A1@T0
60`?0P0C1`T00`0B1PP04`L901<72@0301D92`8050P:0P0E2@/0500B1PP04@D701H:300C1`T04PH8
01L;3@0E2@/04PH801T=3`0C1`T09ATK08j2P`18?3`05@T;01<72@0A1@L04PP:01862P0C1`/04`H=
0P0D1`h01P0D1`l04PD<01@8300F2Ph050P<01<72`8050P<00/040@801T=4@0J3Q804PH:01`@500H
310050P<01L;3`0L41@06@dA01H:3P0401L;3`0801P<400I3A4050T?01L<4P0E2Q006@hD01D:400O
51X201L<4P0_01D:400G3180714G01H=4P0I41<04`d?01/E5`0V828091hP01H@4P0B30h06Q@F01/E
5`0G4A<05Q0B01`F600J41P07QDI01dE4`0N6A<0;b/N04=0;`2[ZYP0dm?204a=?`0R8QP07QdG01XI
5`0G5AX08AlU01TG700G5AP06aTK034`;P0O7Q/07ahI024Q6@0T91`08B4G01lO5`0L71/07QhN024Q
8@0R8R807QhP01/K7@0P82800P0X9b`01P0V9BX08b8X01hO900W:c4092T_02<X;P8092T_00`0<SLm
04U>E00Q9R`0:c0f02DZ<00R9bd0:Rlc03@m?@0U;Rd0:C8a03<l>`0a>C/202hf>00Q030h>`0e?D00
=cm203Hm@`0a>cl0;C/n05ARI@1PKW40;ce0030n@@0hATT0=dE803U7BP0mBdh0=TA70390@`0e?d80
:c<f0499C`0lA4X0@T]B03Y3C015CUT0?dUE075jR@1DGfh0@4aL04iIJ`12CeX0>dQ>04UFG014DEL0
AeAJ00<0@DiD0140A55G04UFG01=FV00CeaQ055OHP1:F5T0B5IG04aJF`17EEH0@Dm@04=ADP14DU<0
BeUJ04eKG018EUL0BEMH04ECD`0204UGE`0304MEE@1=Fe/0DEmP0080E69U01T0DEmR04iKH@1?G680
DUmU04mMH01^O7d0NXR904eKF`1;FUL0CeiK04mMG@1BH600EfEW05MTJP1EHVX0EF9[05ERJP1FHf/0
F6E]05]XL01JIfh0EfAZ06=aM01QKg80GF]^00<0FfUZ01T0GFQ^065/LP1YM7X0JWEi06E`M01TKg<0
Q8nA06ehNP1NJF/0GVYZ061/K01SKfd0GFUU06IbK@1XM700Hfm[05eYIP1MJFL0Gf]Y05iZJ@1JIVH0
G6QX065]K@1NJF/0G6Y]0080F6E[00@0EF9X06=`MP1BGfD0F6E[0P1MJW0205AQI`0I05aZK@1AGf00
E69R055OG`1@GUh0DV1Q051NG`1:F5/0CUaO04mMH01=FV00AeAJ04ACF01QLWX0A5=J045@E@14Ce<0
?4A703Y2A00kA4<0>D5303a4AP12C4h0@TeA045<D00204=>DP0@03]6BP0lATP0?TQ:03Q1@`0f?T00
>T=2038i>@0^=3@0<SPh030e;`0c=R/0<cH]038d;`0W:BP08b@V02//<080:RXb03@0<S8i02`]<P0[
;340<c<h01lN8`0k>Sl0;Bd_03Ti>@0c<c40<C4_02TY9`0V9RH0;2`_02/Z;`0V9B/08b8U020P7P0X
:2H0;bl]02/[:@0X:2H08b<Q02HV900Y:BL08B4O01TI5`0S8b40824S02DV:00V9b/08b<[02DU;@0U
9Bl09bLa02<S;@0T92d09bP]02DV:P0S92P071/Q02@Q:00P7R807A/N028P8@0/:bT08R4O020O7@0P
7Ql08R0U02@R9`0T8BL08b4V0P0Q7b803P0S8B@08R0S01/I700T8RD08AlR01TG6P0C4A@06aTL02HT
9`0_:b`081`M01dI6P0N6Q/06QHG0P0N6Q/201/G600301<?400G4a@08QhO00806QHG00H05A4B01`H
6@0N6Q/040`=01DA4P0G4a@201TE5P0:01XF5`0I5AH06Q@F01LA4`0F41805a4C01PB500F4180618D
01XD5P805Q0B00L06A<E01LA4`0F41805@lA01LA4`0J51H06A<C0080618B01d081/H01hI5P0F4@h0
5Q4=01XE4@0G4A409AlO040j>P0[9BD05@lA02PR900?2@/04`dA01`F6P0C31<0;2D/014;3`0K5AP0
4@/=020J701MEeT050h@01dG6@0E3a405Q0B01XD5P0M5aT05a4C018<3P0201TC5@80618D01X05a4C
04U3A@3CcLl0@cdo01/E5`0=1`T07QPJ0189300H3A406@hB01H;3`0B1`/0:b0T024F6P0F2`l050T=
01D:3P0F2`l05@X>01462@0K3a408ADG020D5P0K3a404PH801041P804PH800`05`/=01X>400H30h0
4PH801<72@0I3@l0710B01L;3@0B1PP04`L901@82P0H30h201/?4@0A01D:300J4A801@0000h8200D
3Ph03`T901LA4@1IDe<0ViFE03Pb<P0600002`D5018:2`0B20T04PH801451`0C1`T0100D20X02@0C
1`T04PH801451`0@10H04PH800`00P0H30h08ADG01H:30030186200@01451`0B1PP050P:01@82P0E
2@d03`<700P0000900404PH:01hB5P0@10P05@T=01452@0@10P04`L;01452@804`@700@050D801D6
2@0G20/06@X=0P0E1PT0100D1@P04`@701<41`0B0`H701451`<04PH80P0C1`T0900@10@05PX:01D9
2@0@10@04PH601H:2P0A1@D0Ac/k01dA4@0J3Ph03`<300P0000L3Ph04`D501/=3@0C1@D06`l?01<7
1`0E2`X06a4@01@:2@0A2@L04`/901081P0A2@H03PH401@<2P0I3`h03@<4020F5`0C1`T04P<80142
1`0B0`P050D:01@52@D04`@700P0408400l00`0C10L05PL:01@5200?00<03`8301831P804`@700L0
4P<601421@0F1`X03`0301/<3`0b8bH070d@00@04`@700<050D801<41`0C10L00P0C10L301831P0?
01<41`0C1PH06a0>00P0000L41003`<309N;S@1MDE<09a/M00l41`0I3A404PH:00l31P0B0`H04082
00805PP800P03@000184100=00005@L702XL700P4Q803@0001D71`<04`L901404PH801451`0A1@L0
60`>00h2100F2P`0200001H:300<0P<04`@701831P0C10L050D801<41`0>008050D801<41`020183
1P0401<41`0D1@P04`@701@520805@H900<050D801<41`0C10L01@0C10LDooooo`006oooool03P0G
2Q<04PD>00`0200A10d06PdF00d02@0F2A804@@=01<63`0800@05`XC00/01@0E2@d050P:0P0C1`T0
0`0B1PP04@D701@82P0501@82P0501H;3P0;00<06PhB0105200800000P0D20`00`0L41@05`/?0145
2@0201452@0<01P<3P0^8R@07A4C01L;3@0800003P8400h41@0D20X02@0001451`0=0@<04PH81P0E
2@/01`0B1PP050P:01@82P0@10H050P:01T=400D20`00P0C1`/02@0E2@d05PX>01L;3`0T61`03P86
024E6@0:00804PH:01<72P0601<72@804PH800X04`L901@82P0F2P`06@d?01@82P0A1@L050P:0145
1`0?0`D04@D70P0D20X02@0F2P`02`010186200b9RL02@0000l51P0<00803P8401X>4P0201<72`<0
50L>00H05@P@01P;4P0I3A406@dA01H:3P0C1`/201862P0502<G6`0_8bL0710D01/?4`0<00@00P0G
2`l01@0I3A406PhB01T=4@0H31006@dA008060`@03@05`/?01P<400I3A404PL=01X?5@0B1`d0714G
01T>500/8BL07a@J01`A5`0E2Q005``B01X?5@0B2@h06A0C018<3P0L5QP0:B<U02XT9P0K5AL04`d?
01TC5@0J51H05a4C01PB500M5a/050XB01XA5@0S6aT071LA02HR5`0Z9aP0?cd^05iNC`0S8aL08B4I
02@S7P0D4Q<05A<H01lM8P0L6Ql0928U028P8P0N7A/07QdI01lN6@0Q81/08R8J01hN500K6a<0820O
0P0K6a/05P0M7Ad0820R02@T9P0O7b409B@Y02LV:`0T8bP07ahT01`M8P0L82L092T_01LL8P0/<CL0
UIZP08R=T`16Be407b@Z02T^=00S:2h0;c@j03Dj?P10B4T202hg=P05038k>P0/=3H0:C4c038j?00b
>Sd00P0d?3l0:P0b>Cl0=Cm302hl?`0oCE00D5iQ03=1A00]>ch0<Cm203U7BP0hATT0>TQ;03M5B00i
AdX0=d5502`d=`14Be40=3a3049;DP0oB540A4iG06UcO`2RZkX0Hfem045=G@1<EfT0C5QS03Y7C@17
E5X0AU=I04MDFP10CE<0@e1F049?E@15DUP0BeQN051MH`1AGf<0?D]>049@D@15De@0A59C04MEEP80
BEMH00L0BUQI04MEEP15De@0B5IG04IDE@16E5@0BeUI0080C5YJ00`0D5iN05=QHP1GIFP0EfEX05=Q
I01>Ff40CeaR05ERJ01>Ff40MXB708BBU016E5D2059PH00705=QH@1DHV<0EV=X05ERJP1CH6T0D5eV
05aYL@0205QUK@0X05]XL01KJ6l0EfAZ05m]L01MJfh0FfU/05aZJ`1NK6d0H6i_069]L`1TKgD0JgIl
06iiO@1XLgL0H6]_06=^L01OJV`0GVU[05m[J`1QKFd0HVi/05eYI@1RKVT0Hfm[061/J01MJFH0G6QV
05m[J@1PK6/0G6QX05eYJ@1QKFd0FfIX05m]L01DHFL0HVme05ERJ01PKG<0EfAZ05YWK@80FFI/00X0
DUmU05AQI`1KJF`0CeeN055OG`1=Fe/0BeUI04mMGP1BH640CE]N0P1>G5l0@P1:Eed0A55G041?E00m
C5D0AeIM04UFG00kATT0=Cdo03a4AP10BDP0>41203Y2A011Bdd0@4]?03]6BP0iA4P0>dI:03Q3A`0m
AdT0@D]=03]4AP0d?3h0=d0o038j>@0d>SX0>Clo03Hk=P0a=2/0:RdV02T[9`0V9bT09BHZ02TZ<00X
:300:RXb02d]=00S92T09RL/030`=`0b<CL0<C0f02XY;P0];Bl092@T02DU8`0T92809RHV02XZ:`0W
9R/092<X01lO800Y:BL0<c<a030`;P0X:2H0<C4_028R800W9bD0:RXX02PX9P0I6AL08B4O02DU9@0U
9RP09bP[02LV;0809RH^00`0:2Ha02LW;`0Y:Bl09bH[02<T9P0T92H06QPM02<P9`0Q7b<08AlR02XX
:@0l>cT2020O7@0:020N7`0N72407Q`Q024N900U8bP09B<V028P8`0L6Qd06aTL01dK7P806aTL00L0
81hQ024O8P0J61/061HI01lK700H51D071PI008081`M00l08alP024M7P0L61T07ATJ01<?400Y9BH0
7QXK01TE5P0N6Q/07ATJ01TE5P0N6Q/04Ph?01DA4P0G4a@00`0H51D03@0G4a@06Q@F01LA4`0F4180
5a4C01PB500G4A<050h@01/E5`0J51H06A<E01/E5`0B30h00P0E3a409@0F4180618D01H@400D3Ph0
6A<C01lJ5`0M61D05A0=01D@300I5100618A028L700g<C409AlO01D?4@0U7b405a4C01PB5P0E3a<0
4P/B01TB6@0F41@07ALI01`F600c;Bl0CDM9010:300J51H05@lA01H@4P0I4aD071HH01PB500E3a40
6Q@F01TC5@0H4Q@00P0F41803P0Q6ad0N79d01dG6@0>20X040X<01LA4`0L4aH06PlC01D:3P0?10P0
=R/_08QmP@1QEUX05``@0P0E2Ph201H;3`0E01P<3`0D20X03P8401D:2`0D20X040@601@82P0B1PP0
40@601H:300I3@l050P:01451`0F2P`06`lA01dA4`0J3Q005@T;00l31@0A1@L050P:00805`/=00D0
50T;00l61`06000040X:00X41002014;2`0700L10@0R71`030H601<=3@0=1`L03@H601061`020104
1P0301<72@0F2P`05PX<00<04`L900T04PH801451`0A1@L04`L900/00@0G2`d081@F01<72@0A1@L0
0P0C1`T06@0B1PP04`L901@82P0E2@/050P<01862P0H31005`/?01D93@0:00803`<701D93@0A1@T0
3`<701862P0A1@T050D801<41`0D1@P05@H901L82`0H2@`05PL:01D62@0D1@P00P0C10L00`0B0`H0
4PH8018620040186200301041P0A1@L04PH800804`L901X050P:01H:2P0I3@d05`/;01<71`0@10@0
4@D502LK6`3Fb/X0G51@01dA4@0I3@d0:1`L01430`0D1PH05`T901@61P0K3`l04@D501061@0C2@P0
3`D4018:200E3@/04`/900h71P804@T700@02`4100L0000L4Q<04PH80`0B0`P00`0D1@X050D901@5
200501@520804P<600D060T<01`=400J2`h05@H901831P0201<41`804P<600L050D800h00P0@0@@0
7@hA01<41`0=00404P<600804`@700D050D801<41`0C10L04`@701@5200301D62@0I01@5200>0`<0
6@h<01<71`0T61P03`<308b0PP1NDU@09QXL00X00P0?0`L03@4501@82`0H2@`040820184100C1@D0
3`4102@F5P0K3@d0300000l30`0L3Ph05PP800`0000201041P804@D700P040@600l31@0D20X02000
01D92`0900006Ph@01L;3@804@8500H04P<601D62@0D1@P03`0301@5200C10L201831P0401<41`0D
1@P04`@701@520805@H900<050D801<41`0C10L01@0C10LDooooo`006oooool03P0C1Pl06PdF00d1
2@0I31D06PdF01D84@0=0PT05PXB01T<5@0>0`X070lH01452`0E2@d050P:0`0C1`T70186200H01@8
300H31006`lC00l51`0A1@T04`L;01L;3`0B1PX03P8601<72`0E2@d040@801@82P0J3Q0030830187
200A1@L050P:01<82P0A1@L06Pl@01@82P0L41803P<41P0E2@/0300C1`T05@T;01H:300B1PP05PX<
01X>4@0E2@d04PH:01<72`0G2`l06`lC02HJ7P80D4A800@0>Rlb01@8300@1@P05PX=0P0C1`T00`0D
20X04`L901<72@0201@82P0901<72@0B1PP04@D70186200D20X04PH801451`0D20X04`L9008050P:
00/06`lA01T=3`0C1`T05PX<01461`0A1@H06Ph>01D;300M4A<05PX<01<72`0201@8300A01@73P0E
20l05@P?01H94@0G2Q405PX>01D93@0F2Ph05`/?01H:3P0G2`l04@L901X>4P0>0PH05`/?01P<400B
1PX00P0F2Ph00`0B1PX04`L;01P<400201T=4@0E01P<400G2`l060`@01P<400E2Q006a0F01D:400I
3Q@05P/A02PM8`0N4aT08AHL01X?5@0H3A<06a0F01P?500I41<05@lA01PB500L5QP07ALI00806A<E
02l05a4C01XD5P0N61X07aTK01TC5`0M4a/07Q@K01hE5`0G4Pl06aL?01hJ400N6a009bDK02<S6P0V
9B009R@S028P8P0M6al07adQ01LE600O7B007Q`M01lN700N7AT07QdH01lN6@0Q81T07AdE01XI500O
7ah07alO02@T900Q8B407QhP02<S9@0T92H09B@Y02LV:`0T8bP08b8X02@U:P0T:2`082DY02<X;00e
>Sh0@TM;02L/<00202T^<P0A02/`=00V:bl0;S<g02DZ;P0`>CT0;CHe02hg=P0]=CL0;SHh038j?00_
=cX0<CTl038j?P0b>Cl0<cY003DoA@0nBe400P0d@DL09@0gA4X0;ca203I3B@0oC580;ca2034nA00^
>d40?T]A03DoA00j@DL0?dQ=03M0AP0mATd0>TA=049<EP1FH6X0BEEQ04QDH@1<F6H0@4aL07J3SP16
DeT0?daB03a9C`12CeD0@4eC04QEF`15DUP0@e1F04EBF016DeT0@TmD04=AE016E5D0AE=D04IDE@1:
F5T00P17EEH304YHF@0S04]IFP14DU<0AUAD04]IF@1<FUX0BeUI04iLG01@GUl0EF=V05=QI01AGf80
DEiT059OI@1CH6H0EV=Z04YGGP1HIF/0CU]P05YXJP1<FU/0Df5S05=PI@1CH6H0Df1X05APJ`1GHg00
IFmi05iXL@1IHf`0FVE[05aWK@1KIV/0FfIZ05eXJ`1OJV`00P1PJfd0;P1OJV`0GfY_05mZK`1NJFd0
HFa`069]L01JIFL0H6]]061[K01LJ6P0FfMW061/K01RKV`0I71/05iZIP1LJ6@0H6aX069^J`1PK6X0
G6QX065]K@1OJf/0GfY/05aWJ@1BGEl0FfQ]05ERJ01jQhd0L7f305ISJ@1EHVP0JGIl05aYK`1HIF/0
E65W059OI@1DHVD0Df5R059PH01AGel0CE]K04mMGP1DHV<0C5YM04UGFP17EEP204ICF@0>04MEFP1;
Ff80>dY@03a9CP13CU00?dM903U2@@1<DU80?TM603e5AP0oBD/0>D=7038m@@0kATX203a7B`0n041:
C013CDl0?dQ:03<k?@0`>CP0;cLf03Lm?@0j@400<3Da02HY8@0Q8ad0:B/X02`];`0X:Bd0:2T_02h^
=P0c<c/0<C4h02<T:@0Z:bl0ATI>07MeP@0^;CH0<2lf02<S9P0W9bP0:BTX038b<00j>SP0<C4`02LW
:00Y:BX0;2`[020P7P0U9B<0MWId04i>C00f=S@0:BTW02XZ:00U9B<08b<Q02DU8`0Q8Al0:RTW02LW
9P0Y9bX0:bT]02TW;@0X9B`0:2D]02XY;P0Z:2d09R@X02LV:00Z:2P08R0U02HS:P0R82@07Q`O01hL
7@0/:bT202@S8@0A02<Q8P0O7B807Q`Q020N900L6Ql08AlR028P8`0L6Qd07adP038`<`0Z:2/07Q`O
01`J7@0V92L08R0S01`J7@0O6a`00P0N6Q/00`0M6AX06QHG01TE5P0201TE5P807a/L01H0B4A501dI
6P0M6AX06aLH028N7`0C3a006QHG01hJ6`0H51D06ADF01PD5@0G4a@05Q8C01DA4P0J51H0618D01LA
4`0I4aD06Q@F01TC5@0L5QP06A<E0P0D3Q002@0F41806A<E01LA4`0D3Q004`d?01LA4`0I4a<0618B
01XD500301PC400A01HA3@0D3`/071LD01HA3P0A30T05@l?01PB4P0E3`l050h@01XD600B31007QPL
00P21P0K5AT06aDG01H@4P0b;2h00P0L5QP0300E3a406A<E01LA4`0F4180618D01XD5P0K5AL06A<E
01PB500G4A<05@lA01@>40805a4C01l071HH01LA4`0F4A804Pd>01P@4`0F2`l04`X<01/@500P5AT0
<BHZ01hC5`0H3A405@X>01H;3`0G31005P/?01@9300B20T09Q`M03lf=P0Q5aP05@/<01T?400D2P/0
4PP901P>3`0L4Q<06@l@01H;300E2@/050P:00805PX<00<05@T;01451`0B1PP00P0B1PP0400C1`T0
5P/<00l51P0K4Q<04@P900L0000G3Pl050/<01L>3`0D2``040L801<:2`0=10D04@P901L<3P0F2P`3
01<72@030186200C1`T04`L900@04PH800@050P:00h2100B1PP05`/=0P0A1@L201<72@0B0186200C
1`T050P:01D92`0h;30060d@0105200B20X081@H01P<400A1@T050P<01452@0B1PX05@T=01452@0G
20/05PL:0P0D1@P00`0E1PT05PL:01D62@0301D62@8050D81P0C1`T00`0A1@L04PH80186200201<7
2@0F01@82P0B1PH03@4100h20P0D20P05@T901<71`0D20P0?S8b020D500B1`L060`<01T=3@0F20P0
5@L701430`0G2@T060`<00l30`0I3`h05`d<01@:2@8050`:00T04`/9018:1`0H40h040P601061@0?
1@H04PP901041P0D1@X00P0E1P/00`0B0`P04`@801@5200401@5200301<41`0A0PD04@8500804044
00@04@8501<41`0C10L050D80`0E1PT01`0A0`D07PlB01<41`0@0`@06@X=0102100E1PT00P0C10L0
0`0D1@P04`@701<41`0201831P0L01<41`0D1@P04`@701831P0D1`L05P/901861P0G2`/04@D501P<
3P0H3@h040@601L;3`0C1`/04@D901D9300G20/040820184100C1@D04@<302@F5P0H2PX04`D501<7
1`0C1PH0408201D820@04PH801004@D701041P0f:R`040H701051`0=0`@040H70187200F1`X050D8
01831P0D1@P05PL:01D62@0D1@P04`@70P0B0`H0100C10L050D801<41`0D1@P201D62@0301@5200C
10L04`@700D04`@75?ooool001_ooooo00d05PT@01L:4@0<00H05@P?01@73P0J3A@07A0G03<V;@0P
4aX05PT@01442`0=00L04PH:00<04`L90P0D20X601<72@0H01@82P0<00806`lA01X>400H30h040@6
01@82P0A1@L03P8401<72@0F2P`04`L901451`0K3a4060`>01T=3`0B1PP040@601P<3P0=0@<02P00
01@:2`0800008aLI1P0D20X00`0B1PP04@D701@82P0201<72@0>01D92`0D20X050P:01@82P0E2@/0
5PX<01/?4@0`92H0THF701lC5@080000;b<U00d3100B1PP301@82P030186200C1`T050P:00<050P:
00D05@T;0186200D20X0710B01lC5@0201H:300<01@82P0C1`T03P8400h3100D20X04@D700l41@0H
30`07Q8D01dA4`0=0@<040H80P0D20`301D83`0401H94@0V6B008ADI01T=4@805PX>00`050P<02dQ
9@0C1`/081@H01/?4`0P51P05PX>01<72`0D20`04`L;01T=4@0O4aL201T=4@0301P<400G2`l05@T=
00805PX>0P0D2@l01P0Q5Q`060dC01<83P0E2Q0050T?01X?5@806@hD04D07A8H01XA5P0L4aH07ALI
01`F600I4aD0618D01TC5@0M5aT06aDG024K7@0Y8bD09b4S01/E6@0O5Ad08ALN01@;3P0L5QH06QDB
02LR700N6a@07Q`F01XI5@0C4Q0081hO01XH6`0P7R406ALJ01hL7`0/:R/081hN01dL6P0O7QX07A`H
01hM600P7aX07ahI01hM6@0N7Qd092@T02h^;P0U9BD06a/M020P8P0U9BL09RDZ02XY;P0W9R/09RD[
02//<@0Q9BX09b``02`a=@0W;3006b0T02`a=@0Z;c<09b``01dR9P0X;C40<SLk03Ll@00_=cT0<CTk
03@l?P0_=cT0;cLj03@l?`0_=cX00P0b>Cl0;00c>T00=Se503DoAP11CU@0=dA:03E2B00mBU00<d16
03M4BP0e@TP0;CY005UVK00^>d40>4E;038l@`1@FF00=Ci504A>EP0oBE80@D]D04A@F@12CeP0?DUE
04EBGP0nC5T0B5IS096NZ01=FV00=D9803i;D@1;F5h0?T]A041=D`12CeD0@DiD04QEF`1=FV00BEMK
049@D`0mBd`0@4i?04YHF@19EeP0@Dm@0P13DE805018EUL0BEMH04MEEP17EEH0BUQH04iLG01=Fe/0
BUQH04eKF`1@GUl0Df5T051NH@1BH6<0FVM]05]XKP1BGfD0BeQP05]XL01FHfX0@e1F0P1DHVD03@1@
GF<0DUmU059OI`1?FfL0Dem]065]N`1IHf`0FfI/05YUJ`1II6X0F6=X05UTJ01MJ6`00P1MJ6X02@1L
J6P0FfMW05YUI`1MJ6`0GVU]05UTJ01KIVP0H6]]05aWJ@0205YVIP0905=OG`1EHEl0H6aZ06A`KP1P
K6P0GFUV05aXIP1MJFL0GFUX0080GFUY00h0HFa]05mZK01OJV`0GFQZ05=NH01KJ6h0CEYP05i[L@2;
V9h0H6ec05=PIP1EHVP0Df1V05AQI`80Df1V05d0EfEX051NGP1<FUX0CeeM04aJFP17EEH0B5IG04QF
F@15DeH0A59E04EBF017E5X0BEIL03i=E00oC580?D]>03a7B@0k@dD0>d5103Y0?P0h?Sh0>T=2045:
C010BT`0?4I803a7B`0iA4P0>4=703I0@P0e?d40=Sm1038j?00f?ch0>40o03m5A@12B4P0;S8^028T
7`0T9R40;Bh^02`]<@0Z:c00;Bdd02/[<`0^;SH0;Rle024R9`0T9BT0>3M005]II`0[:CH0;2Xc02<R
9`0`<3808b<R02`]:00d=C00:R/V02<S8@0W9bD0;Rh]03Ti>@1@D500j^[Z09bLW013@d<0:b/[020P
800W9bL092@T02h^;P0Z:RT0:bXX02LS8P0Y9BD0;2L[02TT:00W8RP09B0V02TT:P0Z9BX0:BDV02`X
9`0X92<07adR01hK8P0R82@09B<V024O800X9bD07QdK01dL6P0L6Q/00P0M6b00100N72808R0U028P
8`0O7B0201TG6P0:024O8P0D4QD05aDH03Hd=`19AdX0:2HY00`:3@0I5AH071PI01dI6P<071PI00d0
5Q8C01`H6@0I5AH06aLH02LS900H51D0;b//00d92P0U8B807ATJ01`H6@0D41405a<D00@061@E00l0
5Q8C01PB500F41805Q0B01PB500I4aD0618D020J700I4aD09AlQ02@N800G4A<071HH01dG6@0G4A<0
0P0E3a400`0C3@d04P`<01TC4`0201HA3P0K01TD4@0H4`l05Q4=014<2@0N6AH081/H02`W900X8R80
5Q0@024K6`0A2`d0618D01<=4@0m=c/03@L;01H@4P0H4Q@05Q0B01@>400C3@l07aTK01XD5P0I4aD0
618D01LA4`0I4aD06Q@F0080618D01405a4C01H@4P0E3a4040X<02DO8@0E3a4081XL01@>400T7R00
40L:01lD600A1PX09AXN02XO8`0P5AT04`P<01P=4@0201H;3`805``@02L06@lA01X@4@0>10D08ALH
02/Q8P0H3Pl05P`=01D;300D2P/05@/<01T?400K4A806Pl@01<72@0A1@L04PH801D92`0C1`T04PH8
01@82P0F2P`04`L90186200E2P/04@L801892P0=10D0<BPY01482@0?1`P01P0001D<3@0G3Pl030<4
01<:2`0@1`P06@d?01L;3@0D20X00P0C1`T00`0A1@L04PH8018620050186200501@82P0A1@L04@D7
01D92`0B1PP0100A1@L201<72@0<01D93@0;0@<06@dA01452@0Q5AT04`L;01@8300A1@T040@801H:
3P0K3a<04PH:0P0E1PT201@520805PL:00H04`@701@5200E1PT05@H901H72P0G20/801<72@804PH8
0P0A1@L04P0I3@d05@T901<71`0C1`L04PH601451@0C1`L0300000l30`0J3Ph07A4A00P0000I2`/0
5PP801430`0F20P04`L701H:2P805`d<00D05P`;01081P0>1P@040P601L?300201@<2P0401<9200E
2``03P@501451`@04`@900<04`@801<41`0C10L00`0C10L02@0B0`H04@8501<41`0F1`X060T<01H7
2P0C10L04P<601<41`0301@5200700l3100D1@P0404400l00`0A0PD02`0001421@0201<41`0G01@5
200C10L04`@701421@0B0`H04`@701D62@0C10L04P<600`10@0B1`D060`<01861P0=0@404PH801H:
300=0@<03P8600P0000:00804@D801421@0B10@00P0D1PH01P0B10@04@<301@61P0=0000300001D7
1`8060X:01405@T;01@82P0B1PP040@601451`0C1`T0<bLY01041P0H30h04@D700d10`0@10H05`P;
01D62@0C10L05@H901H72P0201@5200701<41`0B0`H04P<601<41`0D1@P04`@701@5200201D62@03
01@5200C10L04`@700D04`@75?ooool001_ooooo00D05@P?01@73P0@0`X06@`C01<63@0201L:4@07
03DX;`0M41L06@`C01@73P0H31004@D90186200201<72@0301@82P0E2@/050P:00D050P:00P06@d?
01H:300>0P@040@6020D5P0=0@<03P<401<72@804@D700T04`L90186200@1@H05PX<01@82P0A1@L0
4PH801D92`0@10H00`0E2@/00`0H30h02P0001<72@0501<72@0:01041P0>0P@04PH801<72@0@10H0
4PH801@82P0E2@/05PX<01<72@8040@600/05PX<02dQ8`0D20X07Q8D00P0000G2`d04PH801@82P0E
2@/050P:0186200201041P0F01451`0F2P`06Ph@01dA4`0H30h06Ph@02LK7@0X71h05PX<01451`0E
2@/05PX<01@82P0K3a4050P:01041P0L414050P80186200<00806`lA01H:3P8050P<0P0E20l05`0F
2A005PTA01hA600H31004PH:01<72`0F2Ph05`/?01`@500=0@D04@D900d11@0_8bL08aLK01T=4@0G
2`l05PX>02@H700]8BD06`lC01P<400G2`l05PX>00<05@T=00l06PlE01P=4`0b9bd09Q/Q024F700J
3aD04`P>01L<4P0F2a4060dC01/@5P0C2Pl04`X=01H@4P0I4aD00`0H4Q@06`0E3a405a4C01hH6P0S
7Al081XL01H@4P0F3A808QTN01H=400U7al06A<B02<N6P0G4a006aTE01hM6`0U8b@0>cTk01@B5@0V
92L06aTL03Xh>@1HEUL0=SDd00l>300M71P06QTE01/J5P0201hM600N01hM6@0S8b8092@T02XZ:P0R
8R807AdO02HV:00R8R@09B@Y02/Z;`0X9b`09B@Z02TZ;`0S9b/0:2da01/P900V:bl0:c0d02L/<00X
;C409BX^028W:`0/<CD08RL[02/`=00W;c40:S8d030h>P0a>C/0<CTl0P0d?3l07P0f?D<0=3]1034h
?P0d>d<0>D=:03Q5B`0[>3h0=dA:049?E@0e@TP0<d16034nA00kB4h0SIZP04AAE`0nBe40@TiD075j
P@0j@dX0B55I03Q2B`0oBE80Ae9K045>E`1>FVH0B5EQ04MEHP14DUl0BEMP03A1A`80@TmE0100=T=9
03a9C`1?G680A55G045>E015DUP0BEIL04=@E@16E5L0A59C04UGF018EUL0@U1A04YHF@18EUL0A59C
0P17EEH07P12D540B5IG04MEE@1:F5P0B5IF04ABDP17EED0BUQI05ITI`1BH6<0EVAW069_M@1SL7H0
EV=Y05AQJP17E5d0AE9J05ERJ01;F5h0EVAW059OI@1DHFL0DUmX04YFI01>FVP0Gf]j04mIHP1GHVP0
G6M]05UTJP80Ef9V03@0G6MY05]VJ01JIFL0FVIV05]WI`1LJ6P0F6=U05eXK01HHfL0F6=U05iYJ`1J
IFL0FfMW05m[J`1KIfL0FfMU061/JP1IIF<0Ef=O05eYIP1LJ6H0F6AR05EQH01GHf<0HFe]06=^K`1O
JV`0H6]]069]K`1KIVX0C5UO05i[L@17E5X0H6ec04eJH01IIV`0EF9X05]XKP1LJFl0DUmU04mLHP1E
HfH0DV1Q04eKF`1BH600DEmO04MEEP16E5D0BUQK04MEF015DeH0A55G0P13D5H0EP18Eed0?daB03Y5
B@0lADL0@TQ80457A`0k@Cl0>Clo03]1@@0lA4H0=d5303@n@00oBTh0>dI:03Y5B@0h@T@0=Cm103Q1
@`0j@T@0@T]:03a3@`0f?3`0=C/k02T]:`0W:BH0:2XW02PY:`0U9RX0;Rld03Hf?@0/;3@0:RXb02h_
=@0T9BX08B8V02<R;00Z:3H0<Blm03<b>`0c<SL0>c/m01dM6`0Q8Qd0:2TT02<T7`0U9R40:BTW02TY
:011@D40?3`l0:j^[P1aLG40<C4a02h^;P0M7Ad0;2`/024Q8@0T92@0820O02`X9`0U8Ah09R8Q02/V
:P0V8BD091lU02DP9P0Z9B/0:bLY02XV9`0[9bH07a/I020N8`0L6B008b4U02HT9`0O7Ah081lM01lN
700M71X07A/L024O900S8BH0924W02PV:`0T8RD081hQ0P0O7B006`0L6Qd09bDX01`J7@0N71l09B<V
020N8@0V92L07ATJ020L7@0M6AX06aLH01XF5`0H51D04`l@01lK700K5aP081`M01PD5@0]:BX0NWIg
024M7P0J5QL04`l@01/G600I5AH05A4B01LC500401TE5P0<01H@4P0D3Q0050h@01H@4P0H4Q@05a4C
01`F600O6A/0?3Hh03/e=`0K5AL05a4C0P0B30h00`0E3a406A<E01XD500201TC4`0H01TD4@0H4a00
6A@A01XE4@0K5Q806QDB01LB3`0A30T05a8?01/E5@0E3`l06Q@D00@0000T7R00:28V0:^UZ@1=Ad/0
6aDG01lI6`05004091hP00@0000O6A/06A<E0P0K5AL00`0I4aD05a4C01LA4`0201TC5@80618D00T0
5a4C01dG6@0400008adO01LA4`2BS8h081XL01H>4@0U6Qh00P0C20`01@0B1`/06@hB01dB5P0H3A40
5P/?00<05``@00T040H802HL7@0G3@h04PT:020F5`0B20T060h?01H<3@0D2P/00P0A1`P02`0D2P/0
60d>01D92`0D20X05`/=01T=3`0E2@/03P8401<72@0G2`d050P:00804@D700d04PP900L0000F3@h0
HeYK01D<3@0=1PH03`H701892P0?1PL04PT:01L>3`0?1@H050P:00804PH800<050P:01H:300G2`d0
1P0B1PP01@0?0`D05`/=01<72@0A1@L06@d?00804@D70`0@10H03P0B1PP04`L901H:3P0?1@L07Q8F
00`0100G2`l03@4501D93@0@10P03`<701P<400M4AD04PH:0P0C10L0200D1@P05@H901L82`0I2Pd0
4P<601<41`0D1@P05PL:0P0H2@`601<72@0K01@82P0C1`T04PH80186200A1@L040@601861P0F2PX0
5@T901451@0B1PH05@T901871`0Y7Ad03@4101P<3008000060`<01D71`0G2@T050H601D71`0B1PH0
7A4A01@:2@0I3`h06Q0?00805Ph<00d06Q8@01L?300<108050`:00d40`0?1@H03P@501<72@0B0`P0
4@870183200D1@X050D900D04P<600T05`P;01H72P0A0PD04P<601@5200B0`H03`430101100A0PD0
0`0C10L01`0F1`X0404401831P0F2@X03@0101421@0E1PT00P0C10L05`0D1@P04`@701<41`0C10L0
5@H901L82`0I2Pd05`P;01D62@0D1`L05``:00P0000F2PX03`<302DI6`0]8B<05@T;01452@0E2@d0
50P<01041`0B0`H050H600804@<301`050H601430`0@0P804`D501L92@0D1PH03`410184100C1`T0
4PH800l31@0=0@<03P8401451`0D20X0200001@82P0?0`D05@T;01X>400E1PT050D801D62@0F1`X0
50D801421@0D1@P04`@70P0B0`H0100C10L050D801<41`0D1@P201D62@0301@5200C10L04`@700D0
4`@75?ooool001_ooooo00H04`H=01H9400@0`X040<:01H9400C1Pd201D83`0F01X=500I31<050L>
01P<400A1@P050P:01<72@0A1@L04PH801@82P0@1PL04`L901X>400E2@/02@00028F600D2@X05@T;
00l51P0I3@l03P8401D92`8050P:0P0C1`T20186200501L;3@0D20X04@D701P<3P0I3@l00P0A1@L0
2P0G2`d05PX<0186200E2@/06@d?01<72@0B1PP050P:01D92`0D20X201D92`804`L90P0B1PP00`0C
1`T050P:01@82P0201<72@030186200C1`T04`L900@04`L900P05PX<01061`0M4A<05PX<01P<3P0C
20T04PH800d3108060`>00T03`<501P<3P0F2P`05PX<01L;3@0F2P`04`L901D92`0F2P`01@0D20X0
4P0D20T060`<01P<3P0@10H03`@501P<400E2@d05`/?01D83`0D1`h06PdD01H94@0G2Q405@T=01@8
300F2Ph05`/?01@830805`/?00<05PX>01D93@0F2Ph00P0G2`l0100H31005@T=01L;3`0N4QH201P<
40805`/?0`0F2Ph201X?5@0?01T>500H3A<05``B01L<4P0J3aD06@hD01/@5P0J3aD060dC01`C600H
3a805Q0B01D?4@0F41806A<E00L06aDG01X08QTM01hE6@0O5QP06A<C01/E5@0K5A@07QXI01`J6@0O
7Ah0928T028P900I5aX08R0R02h/;@0k>CX08R4P024P7P0N7A/081lM02<R7P0U92007QdI01XI5@0P
7a`08B4Q02<S8`807alO01808R8T020P8P0T92H09B@Y02@S:00R8BH092<Y02DV:`0T:B`08BHY02DZ
;@0X;C008RLZ02`a=00V:bh09BX]02H[;P0/<C@202ld=`0g02de=`0^=SP0;cLi03@l?`0]=CP08b/^
030g?@0c>T80=3]3038i@@0f?DD0?4E=03U6CP0hADd0?4UA03Y7C`0iATh0?daD04EBFP0a?TH0?DYB
03M4C01nRi<0?d]C049<E@11Be@0>dE>03m9DP10CEH0@e1I03m<E@0nC5D0@U1J03m=F00kC5H0>dYB
03e:D014DEL0D5eS03M4BP12CeD0@DiD049?E@14DEL0AU=I04AAE`14DUH0B5II03e;C015De@0?4Y;
04ECE017EEH0@e5B04ECE00204ABD`0<04UGF01;FEX0AE=C04ABDP19EeL0AUAD04YHF01AGf00E69U
05MUJ01BH6<0CU]Q0P1BGfD0901CH6P0DUmW04mLI01=FV00CUaP05=QI01CH6H0DUmU04iKH`1EHFh0
HVil06YfQ01BFf@0EEiT05MPI@1JHfP0GVM[05eWJ@1QJfd0GFMX061ZJ`1SKFh0GFMX07f7R01cOX00
FVEW05AOH@1II6H0FFEV05YVIP1PK6`0G6QV05YVI01LJ6H0GFUV05]WH`80G6QV00D0FFES05aXJ01O
Jf/0Ef=S05mZK00205iYJ`0:05mZKP1MJ6`0FVEY04mLHP1QKW@0EV=Y05ERJ01DHFL0FVM]05ERJ0@0
Df1V00X0Df5T055OH01;FET0BeUI04iLG01:F5T0AE=D04UGFP13DE@0A59E0P13D5H03P16DeT0@E1E
03m;D00f@D@0@T]<04U?CP0k@Cl0?D5002lc<P0f>cX0FF5P03a5A`0kADL0>dI:0P0jADT01P0kADL0
=T1203<l?P0f?T00>D9103@l>`80:c4a03H0:Rh]02PZ:@0Y:b/0:BX^02d^<`0`<3P0<30i02l_>@0f
=Sh0:BX`030a=P0J6al0;B`e02d[>@0`;S/0=SDn03Lf>`0b<S@09RHU024R7@0U9R40:BXU02TY9P0/
;2X0<30_02TY:@0[:b/0>CTi03Ph>00`<300;bl_02/[:`0R8R809bLW02<S8`0S8b807Q/J028N700P
71`08ahR024L800P6b408ahT028M8`0T82<09b<T02DQ800N6QT08b4V02@Q:00R82@08b4T02HT9@0Q
81h201hM6`0801lM7P0P7R<08AlT02@Q9`0K6Ah09R@W01/I700T8RD201`J7@0=01hL7`0V92L07Q`O
01lM800K6A`071XM024M7P0K5aP07QXK01`H6@0M6AX0<Bd^02dY:P0201`H6@0C01hJ6`0J5QL071PI
02PT9@0O6a`061@E01`H6@0E4A80920Q01DA4P0S7b005a<D02<O800G4a@06aLH01H@4P0[9BL05a4C
028L7P0401H@4P0601PB500J51H06A<E01H@4P0I4aD050h@0P0E3a400`0G4A4071HF01PB4P0301PC
408061<?01L05Q4=01LB3P0H4`l05a8?01D@3@0D3``0618B01`F5P0A2`/091hP081jO00/9RP071HH
01@>400J51H05a4C04@n@00`:R`0=S0b04a6B00L5QP07QPJ014;3@0201LA4`0401D?4@0K5AL07ALI
01TC5@805a4C00`0618D01TC5@0L5QP07ALI01/B5@0I3Q806a0D01T>4P0F2`l05``@01X?4`0K41@2
01X?4`0901L<400F2`l05@/>01T@4@0K4Q<05Pd>01482@0H3a004@T9008050/<0P0C2P/0100B2@X0
50T;01D92`0F2P`201L;3@0501P<3P0F2P`05PX<01H:300E2@/00P0D20X0100>10D04PP901<92P0@
1PL201<92P0601@:2`0=0`@0>2h_05I<C@0E2``04@L80`0D20X201451`0J01D92`0D20X04`L901<7
2@0B1PP04`L901@82P0B1PP05@T;00l41@0D20X0@CDg02TM7`0E2@/04PH801@82P0C1`T040@601@8
2P0C20/04PL:01@8300E2@d04@D90105200B1PX301452@0401<72`0D20`05PL:01D62@804`@701/0
5@H901H72P0?0@<060T<01D62@0o<3<091DH01<41`0B1PP040@601H:300G2`d04`L901H:300?0`D0
4`L901D:2`0@1@L040H701H:300E2@T09QXJ028F5P0C1`L050P800d10@0E2@T00`0D20P0200C1`L0
4PH601L92@0I2`/05PP801L92@0H30`05PX:0P0B20L03@0C2PX05@d;01<;2@0B2PP04`/801D=2`0F
3P`05P`;01882@0A1`P04@D701@52P0C10T00P0D1@X00`0C10P04`@701<41`0301<41`0601@6200W
61/07PlB01841P0F1`X03P02100C10L301831P<04@8500<04P<601<41`0C10L00P0D1@P05P0B0`H0
5PL:01L82`0F1`X02P0001h?4P0Y6Qd06P/>01@6200@10@03`@201451@0?0`<03@4101P<3P0O4aD0
3`<501`A501oLgL081@H00l41P0B0`H201430`030184100C1@D050H600H04`D500H02`4201P<3P0B
1PP02`4201L;3@0>10D2018620@04@D700`04`@701831P0B0`H04@8501831P0C10L06@/=02@E600I
2Pd04`@701L82`0C10L201@520<04`@700L04P<601H82P0V61X02`0001T:3@0F20X05PL:01Cooooo
000Kooooo`0N01<72`0E2@d04@D901452@0E2@d04`L;0104200?0`L04@D90104200A1@T060`@0145
1`0D20X05@T;01<72@0A1@L040@601X>400F2P`040@60147200O4aD0BSi003T];@0F2PX07a<C01D9
2@0@10@06Ph>1P0B1PH02P0D20X040@60186200L418060`>00h2100B1PP04@D70186200E2@/201H:
30@050P:00<05@T;01@82P0D20X00`0C1`T0200B1PP04PH701451@0B1PH04`L701@8200E2@T050P8
1@0C1`L04P0>10@0<BDW0:JJW01XG5h0200001dA4`0O4aD06@d?01X>400B1PP040@601D92`0C1`T0
50P:01<72@0E2@/05PX<01D92`H050P:00d050P901861P0A1@L04`L901D92`0G2`l04PH:01D93@0F
2A006@`C01`?5P0I31@05PT@00805@T=00<05PX>01L;3`0E2@d00P0D20`02P0F2Ph05`/?01L;3`0G
2`l05@T=01T=4@0G2`l04@D901@8300H310301H:3P<05`/?00P05@X@01H;4@0G31806@hD01X?5@0K
41H050T?01H;4@806a0F00<060dC01/B5`0H3a800P0C3@l00`0H4Q@06Q@F01PB500201`F600_01dG
6@0N61X07aTK01lI6`0J4A807A@E01P@3P0O6QL07QTG014;2`0M6AP081dM01lM7P0L6Qd06aTL01`J
7@0>30d09bHT02<R800W9R@06QTG02PW9@0R8Al0FeYH02DT8P0V9B<07A`J028Q7`0T92@09BDU020P
800N7Qh0820R01hN800Q8B<081lT024P9@0U92T09RD[02DV:`0R9bP0;38b01/Q8@0N92@08BLW02`b
<P0_=CD00P0[<C404P0^=3@0;cDe02hc=P0_=cT0:C4d02H^<@0^=ST0>3m503LnA00c>T80>D1803Po
B00g?TP0?4==03a5C`0iATl0>4E>03I3C080@DiG00L0>dQA02`i@P0lBE80<3e603M4C@0jAe00=T5;
0080>dE?00H0=T9;03Y7D00nBe@0A55J045?F00kBE8203Q9D@0?03]<E00lBe<0?DY@03Q5B`13D5H0
>4E;04ICF@17E5X0@TmE03m<DP11CU@0AE9H04ABEP1XMWT0@4i?0080B5IG00H0>TQ903m=CP17EEH0
BEMH04IDE@13DE8204MEEP0/04]IF@19EeL0AeEE055OG`1>G5`0FfUZ04mMH01AGf80CeeP04eJH01A
GV@0Df1V05ISJ`1DHFT0DEiU04iKH@1=Feh0CUaN04aJG@1@GF<0E65X05QUKP1JIW80D5aY055JH`1C
G640EUmT05YTIP1OJF/0HVa^05EOH01LIVL0FF=T06=]K01OJFP0EV1Q05mZK01JIFL0DeiP05EQH@1H
I6@0DEeM05m[J@1IIF<205EQG@1c05IRGP1EHEd0F6AR061/K01LJ6P0F6AT05YVI`1LIfT0FFAV05QS
IP1HHfL0FFAX05QSJ01EH6H0BEIL059OI@1GI6X0E65W04EBF01;F5h0Df1V059OI@1AGV@0D5eS055N
I01AGf80CUaL04aJFP1?GEd0D5iN04UGF014DU<0@4iA04=AE01;FE`0C5UO049?E@0nBe40>DI<04A?
D`17DU@0@DU:03i4@P10A4<0>S`i02X^;@0]<C00=Shm03i6B011Bd`0?4M;04QCE`16DED0>TA603@n
@00g@480=Si003@m?00_=cH0:Bl_02D[:`0/;c00;Rla02d^<P0^;c@0:BTa02l_>@15ADl0ATI@03<c
>`0W9bh09BHZ03@e>@0Z:S80;2Xg02l]>00c<ST0<S4f02d];`0T92<0:BTW02d]:`0S8b4092@T02TY
:@0Z:R/0:2PZ02LW:@0/;2h0:RX/02PX:P0S8bD07QhP028R900M7Al061PJ01hN7`0T8b402`X801XH
6P0N71l09R@Y02DR:@0N6b808AlT02DS9`0T8RD08b4R028P800M6b007Q/R01`J7P0M6ah08R0Q024P
7P0201hM6`0N01hL7@0O7B8081hS028O9@0G5AX081hQ03/i?01EDeH0;B/^01XH6`0W9BP0928U024O
8P0Z:2/07A/N020N8@0O6a`061@E01/G600L61T06aLH02<O800Y9BH07QXK01lK700L61T05A4B01XF
5`0D41406ADF0P0J5QL06`0D4140:RHW02HR8`2c[k00:bLX010<3@0O6a`061@E01PB500/9RP03`T;
01H@4P0H4Q@040X<01PB500F41805@lA01LA4`0I4aD0618D01D?4@0F41806aDG01TC5@0C3@d05@l?
01H@400201D@3@0P01@?300C3PX04`h:01LB300G4Ph061<?01LB3P0E40d050l<00l:1`070@405Q0@
01TC4`0=1`T04`d?018<3P0C3@l071HH01LA4`0/9RP0<bd_020J700A2`d04P`>01lI6`0C3@l05a4C
01XD5P0F41806Q@F01dG6@0K5AL201XD5P0G01PB500G4A<05Q0B01H@4P0H3a8060dA01L<400I3Q80
60dA01H;3`0C20`05P/?01X?4`0H3A4050T=01D:3P0G3@l01P0001<:2`0K4Q<04PT:01dD5@0E30d0
0`0D2``201<:2`0701D;300H30h05`/=01H:300D20X04`L901H:300201D92`<050P:01804PP901D;
300C2@X04@L801@:2`0C2@X01`0001`B4`1`IVL0[ZBU01`B4`0?1PH04@D701<72@0E2@/04`L90186
200C1`T2018620<04@D700l04PH801L;3@0=0@<060`>00X0000;00409ATK01X>400D20X04`L90186
200@10H05@T;00P0000A1@T00P0800000`0I3A407Q8F01862P0301452@0301<72`0D20`050D800@0
5@H900T050D801H72P0H2@`04@8501T:3@0C10L05PL:01<72@0B1PP00P0F2P`03@0C1`T050P:00l3
1@0L41803P8401P<3P0N4Q@03P8400h30`0@10@060`<01D92@0H30`00P0C1`L04P0G2`/05PX:0186
1P0A1@D04`L700l20P0D1PH04@<301T;2`0I3@d04@D501H<2`0a9bH0KfET01TA3`0G3`d06A4?01@<
2@804`/900X04`T80147200@1PL040@601@52P0F1``05@H;0183200D1@T05PL:0P0E1PT02@0D1@P0
4`@701D62@0Q4QD06P/>00l10`0D1@P04P<601D62@0301@520H04`@700<050D801D62@0D1@P00P0E
1PT00`0B0`H050D801<41`0301<41`0501@5200;00004P<601T<300B1`D00P0E2@T0300@10@03`<5
00P0000J3Q00K61T08MkO`0H31008ADH01D62@0E1`L050H6018410P04`D500H05`/=0186200:0040
7A4C01lC5@0L418201<72@040186200A1@L04@D701041P804`@70P0B0`H201<41`0601@5200K30l0
4P<600d00@0?00<030000P0C10L201831P804@8500H060T<01@5200I2Pd070d@03<T9`0O41<Doooo
o`006oooool201@830804`L;0P0D20`0600B1PX050P<01@8300C1`/050P<01P<400B1PP05PX<01L;
3@0D20X040@600l31@0K3a404`L901D92`0C1`T0200001H:300=0@40200001/?3`0E2@T05PX:00l3
0`<04@D50`0B1PH0200>0P@040@601@82P0J3Q005PX<01041P0H30h05@T;0P0B1PP0100F2P`06@d?
01<72@0D20X201451`050186200A1@L04`L901<72@0D20X00P0C1`T0100B1PL04PH601861P0C1`L3
01@820D04`L701<04`L800P00018?3h0=RX/01<72@0H30h03@<401@82P0E2@/04PH801T=3`0L4180
5`/=01@82P0A1@L05@T;01L;3@0E2@/04`L900D050P:00<05PX;01L;2`0D20X00P0B1PP0200A1@T0
4`L;01862P0C1Pd05@P?01L:4@0F2A405@P?0P0E2@d01P0F2Ph05`/?01L;3`0B1PX04`L;01H:3P<0
60`@00H050P<01L;3`0I3A405PX>01L;3`0H310201D93@1K01H:3P0G2`l060`@01P<400E2Q005P/A
01L<4P0I3Q@06PlE01/@5P0H3A<06PlE020E6`0O51X06a0F01`C600H3a804P`>01@>400I4aD06aDG
01LA4`0H4Q@06A<E01XD5P0K5AL07ALI01dG5`0K4a407QHC01<;2@0M61D08A/J018<300M6AP07Q/K
01`J6`0J61/06aTL01hL7@0S8R006QTG014@3P0L6aT081lM024P7P0M71X0>CPf01@C4@0R8Al07A`J
01TH5P0T92@09BDU024Q8@0O7al08B4S020P8P0R8R@07QdR01lN8`0U92T09B@Z028S9`0O92D0:2h^
02dc<`0^=3@0=C/k05EKF`0b>3P0;S@d02dc<`0_=CD0<3Hf02le=@0`>3/0?4A703U1A00b>Sd0<3Lm
02lf?00f?DD0?DA<03PoB00g?TP0>T5;03M1BP0mBU<0?daE03I3C00203i;E00`03I3C00]>T<0?4UB
03M4C@0nBe@0<3e603]7D00lAU00?DMA03U5CP0mBU<0@DiG04=AFP10CUL0?DiF041AF@0lCED0>4UA
03I6C010CE<0>DI<04AAE`0mBU00A55G04QEF`15DUP0?T]A03m<DP12CeD0?daA041>D@14DU<0@U1A
03a:B`1=Fe`0B5IG04ECE017EEH0AE=D04=ADP17EEH0B5IG04IDE01;FET0?Ta<04eKF`1EHf<0DV1Q
0`1?GF00;`1?G680DUmU05ERJ01BGfD0D5eS04iKH01=Feh0CE]L04aJF`18EUL0CE]N051MHP1@GFD0
E65Z05EPJ`1BFf80E5eR05YSJ01LIVP0GVQZ06=]K`1GHF80IFm`05eWJ01NJ6L0FVAS05iXI`1JIVH0
GVU[05IQH`1FHV80G6QX05EQH@1IIF<0EV9O05=OF`1DH5`0Ef=O05UUH@1IIF<0IG5a061/K01HI6@0
FfMX069]K`1LIfT0FfIY0080FVEY06X0F6=X05AOI@1IIV`0D5eS04eJH01DHFL0Hg1f082=T`1GI6X0
Df1V051MH`1=FV00BeQN04YHF`1=Fe/0C5YJ04eKF`1>G5`0BEMH04IDE@10CU40AeEH059PH`1BGfD0
@TmE03]8CP0nBe00?dY>04E?D@11B4T0?T9104Q<B`0d=S<0;c<b03Xn?@0f?3`0@TY<03e7B00kADP0
AE1D04=>DP0h@T@0<cdo03U2A00g?d40<S/j030g=`0]<c<0:Bl_03Xn?`0e=SP09BHZ02l`=P0b<SX0
<S8l04E5C`11@D/0:BTa038c>00I6Qh0=SLi02@T:P0]:cH0;bhf034`=P0_;c40:b/[02/[:P0l?3X0
?Shl02LW9`0U9BL0:RX/02LW:@0U9BL092@V02HV:00W9bT0:BT[02HV:00M7Al0:RX/02PX:P0U9BL0
7AdO01@D500Q8B409bHZ030^<`0R8BL0928X01`I8P0P7bD09R@Z02HT:@0T92H0:2HW024O900S82L0
81hR01lM800S8B808b8P01lN700N7A/07Q`M0P0N72407P0P7B<07Q`Q01lM800X9RT0?S`o024O8P0O
7B007Q`O01/I700R82<0=38e020N8@0O7B007a/L01LC500K5aP07ATJ01XF5`0K5aP0;RX[01hJ6`0J
5QL06ADF01HB4`0N6Q/05a<D01DA4P0M6AX09b<T01XF5`8071PI00l0J6AU01LC500F4Q<05Q8C00h:
2`0:10H04@/=01LA4`0Q6ad050h@01XD5P0I4aD05Q0B01@>400F41800P0I4aD02P0G4A<04`d?01D?
4@0D3Q004`d=01LA4@0I4a<061<@01LB3`0F4@h201@?2`0=01PC3@0H4`l05a8>01LB3P0F4@h05A0=
01XE4P0F4100618B01dG5`0:10H07QPJ020J700201<=3`0<014;3@0U7b40@C/m02TS9@0@2P`06Q@F
01dG6@0E3a4050h@01TC5@0E3a405a4C0`0I4aD00`0J51H06A<E01PB500201PB500601P?4P0D2@d0
4`P<01P=4@0L4AD06PlC0P0G3100300H3A405P/?01<8300C20`06Q0B02PO800F3@h04`X;00H0000K
4Q<05Pd>01D<3@8050/<0P0C2P/00`0D2P/05@T;01D92`0201D92`0401H:300E2@/05@T;01D92`80
50P:01404`L901D;300G3@h05@/<01<92P0F30d04`T:00d3100H3Pl0:1hO02/Q8P0I3a0040H70104
1P0C1`T05PX<01@82P03018620804@D700<040@601451`0B1PP00P0?0`D02`0G2`d03`<501T=3`0J
3Q007A4C01D92`0C1`T04PH801041P0E2@/04`L;00806@dA00@060`@01862P0800004PH:0`0A1@T0
100C1`/050P<01<41`0E1PT201H72P0801D62@0C10L06P/>01T:3@0G20/04@8501D62@0I2Pd201@8
2P0<01D92`0D20X04`L901<72@0B1PP06@d?00P0000K3a40=2PZ02LK7@0F2PX02P000P0D20P0600G
2`/05@T901<71`0G2`/05@T901451@0E2@T06`l?01`>3P0?0@4050H601X<300A1@D03@4100h40`0c
:BP0L6IU01H>300A2@L05@d;01H>2`0C2`T04@T701471P804@L800H05PX<01421`0A0PL04@8701@5
2P0G20`201H72P0:01D62@0C10L04`@700l2100B0`H04@8500d00@0C10L05@H901H72P805@H90P0D
1@P501<41`0401@5200E1PT04P<601831P804`@701D05PL:01D62@0@0P@02P0001T:3@0H2@`02P00
01L82`0@1@D04@H401<71`0E2@T040@400h2100F2P`03002024E6@0`92P06PhB00`2100@0@@00P0@
0P800`0A0`<04`D501D71`0601<51@0701<72@0@10H05@T;01H:300U6A/03P@501@82P0201<72@80
4@D700<040@601@5200C10L00P0B0`H01P0C10L050D800`0000D1@P04P<601421@805PL:0P0E1PT3
01@5200701<41`0J2`h04`@701421@0C10L0814D00d00@0Dooooo`006oooool01`0E2@d050P<01H:
3P0F2Ph050P<01D93@0C1`/00P0I3A405@0F2Ph050P<01452@0C1`T05PX<01L;3@0D20X04PH80145
1`0C1`T04PH801T=3`0Q5AL0:1`N04/o@@1=@D403P8201061P0A1@D04`L701@8200401<71`804PH6
01405@T;01dA4`0O4aD05@T;01041P0D20X05PX<024E5`0P51H05@T;0186200D20X06@d?01dA4`0F
2P`04`L901D92`020186200801<72@0E2@/05@T;01<72@0D20T05@T901@8200C1`L201861PH04`L7
01<060`=01461`0F2P`04PL801X>400C2@X050T:01P<3P0F2P`05@T;01<72@0A1@L05@X;01<72@0B
1PP050P:01H:300D20X04`L900D050P:01D05`/<01`@400M4A<05@T;0186200F2Ph06@dA01D93@0C
1Pd05@P?01@73P0F2A4050L>01D93@0G2`l05PX>01L;3`0I3A404`L;01@8300F2Ph0100H31001@0F
2Ph06@dA01/?4`0G2`l04PH:00<05`/?0P0H3100100I3A406@hD01T>500I3Q@201P=4`0:01L<4P0L
4AL07A8H024F700N4aT06@hD01XA5P0J4A@05a4C01PB50806Q@F0P0H4Q@06`0I4aD06Q@F01/E5`0L
5QP07ALG024I5@0O614071D@01TD400Q71P071LD01hJ6@0J5aL06QPI01dK700P7Ql07adM01dL6@0Z
:BD0?chj01dL600Q81d06aXH01`K6@0D4a40:2LU02@S8@0202<Q8P07028R8P0U9BD08B4Q028R8P0U
9BL092@V02PX:P0202@S:00:02LV:`0V9B/08b@X03Pm?`0g?Cd0;S@d028X:00S:BT0;S@d02/a<@80
:2h^00`0;38b02hd=00^=3@0FV9U03Y2A@0Z<SD0<3Lm03Dl@P0_=S`0<SU103PoB@0g?TP203i5C`0g
03U2C015DU/0BUMP03a9DP0iATl0>4E>030mAP0hADh0:cQ103a9DP0iATl0>4E>03]8D@0mBU<0?daE
03e:D`11CUL0@e5J04ECG012D5T0?e1G04=DF`0oD5L0>TeC03e=D`1BGfD0@TmE045>E00nBe40A55G
04UFG015DUP0@DiD04AAE`17E5X0@e5E04aJG@1AGf00@Dm@04aJF`0jB4T0F6IW04QFE`1:F5T0AUAE
04=ADP15De@0AUAE04YHF016E5@0CUaL04UGE`13DE40CE]L04iLG`0204aJG@80CU]Q00l0DUmU04]I
G@1:F5X0BUQJ04iLG@1?GE`0C5YI051NGP1;FEX0B5II05MTJ`1RKgL0FVI_05MPI`1IHFD00P1QJF`0
2P1PJ6X0JG5c06Q`LP1TK6d0H6UX06E^K@1LIF@0H6YY05QSH`1IIFD2055MG@0b05QTH`1FHV00DemM
05EQGP1FHUh0F6AP05aYH`1QKFT0Ef=Q069^KP1MJFT0Ef9T05eXJP1SKW00GfY^05aWJ`1II6P0F6=Y
05EPIP1@Ff40BeQN055NI01EHVP0DEiT05]XKP1kR8h0Df1V051MH`1>Ff40C5UO04YGG@1:F5/0CUaM
04]IF@19EeL0B5IF04QFE`17EEH0B5II049@D`13DE@0@TmE045>E014DEL0?4U=03Y4A`0kADL0ADa<
03m3@P1>Ddl203Pj=`0703e1?@0f>cX0?DE403Dn@00i@dH0=T5503@o@`0203@n@00l03M0@P0d?3h0
;SLf02he=@0_=CD0;38b030c=@0Y:Rh09RL/030a>00/;3H0:RXf02h^>@16AU00;2`d069SJ00e=SX0
:2T[02h^<P0`;cD0<c8h03<b=P0_;c00;Bd/02TY9`0_;bd0<C4a024Q8`0T8bP0;2/`02d/<@0];Bl0
:BT[02HV:00Z:R`0:b/]02TY:`0J6Q`08b<U01`L7P0U9BL092@V04a=C`0Z:bd09BHY04=3BP1HF600
92@]024P:P0S8b`092@/024Q9P0N7b80820S02<R9`0W92/09B<W020N8@0R824081lM0P0O7Q`0700N
71d07A/P01dK800M6b406QPM02HT9`0K6A`0928U01hL7`0P7R407A/N01PF6@0F51L0928U01LE600L
6Qd07a/L01XF5`0K5aP07QXK01`H6@0H51D08AdN01LC500L61T07QXK01PD5@0I5AH301PD5@0>01/G
600H51D0;BTZ04M3A00O6a`05a<D01TE5P0X92D081`M01TC5@0L5QP06aDG01dG6@0L5QP201TC5@03
01H@4P0E3a405a4C00806A<E00X0618D01TC5@0N61X06aDG01@>3P0E3`l06A<C01PC400G4Pl05Q4>
0P0E40`00`0J5@l061<=01LB300301LB3P0;01D@3@0C3P/07QTF01<=3@0E3`l07ALG04@n@00J51H0
50h@01`F600D3Q000P0J51H201PB500601H@4P0P6Q`071HH01/E5`0I4aD06Q@F0P0I4aD201/E5`0F
01XD5P0H4Q@05a4C01H@4P0I41<06@hB01P=4@0J3a<06a0D01T>4P0J3a<06@hB01H;3`0L4AD08AHJ
01dB5P0]8bD0_;Jf04e7A`0D3Ph07ALG00`61P@04`d=0P0B30`0100E2``05PX<01H:300E2@/201@8
2P805@T;0P0D20X201<72@0B01D92`0F2P`04PH801<72@0G2`d04PH801H:300;0@806Pl@01hC500Q
5AL03`@501451`0C1`T05@T;01@82P0B1PP04`L90P0B1PP301451`0D0186200D20X040@601@82P0A
1@L05@T;01051P0L41805@T;01<72@0B1PP040@601D92`0E2@d03`D701D93@0@10P07Q<F04i2AP0B
1PX301452@0401<72`0D20`05@H901H72P805`P;00X05PL:01D62@0H2@`050D801X;3P0D1@P060T<
01431@0E2@/05PX<0P0C1`T03P0F2P`05@T;01L;3@0@10H06`lA00d3100K3a40?c<e02DI6@0C1`L0
50P801451@0D20P04@D50P0E2@T201451@0J01`@400S5aL0?Bl_00d0000C1@D05PP800l30`0K3`l0
5@/:01061@0J40l05@d;01L?3@0@20H06A4>01H>300E3@/05@/:01H<3@0G3@h050P:01@52P0H2@h0
50D:01421`0E1PX301@520804`@700L05@H901H72P0K30l060T<01<41`0D1@P04P<600805@H90P0D
1@P201<41`<04P<600<04`@701@5200C10L00P0D1@P05P0C10L05PL:01L82`0G20/05PL:00d10P0S
5AL04@@601/>400B1PH03`@201451@0C1`L040@401451`0C2@X04PP9024E6@0D20`05`d?01H:3@0E
1PT201@61P804`D500<050H601<51@0C1@D0100C1@D01P0?10D03`D601H;3@0X7Ah0OG5c01P>3`@0
4`L90P0B1PP201@520804`@70P0D1@P01P0C10L05@H901<41`0B0`H050D801<41`8050D80`0C10L2
01831P0501X;3P0<00405PL:01@6200H2P`05?ooool001_ooooo00d05@T=01<72`0H310060`@01<7
2`0E2@d040@801L;3`0C1`/04@D901<72`0?0`L04`L900805@T;0P0C1`T09`0E2@/02`0101L;3@0P
51H050P:00T0000W6ad08QPH02LL6P0900007A8@01L<2P0=0P005``:01H;2@0E2PP050T701871@0A
1@D040@601T=3`0M4A<05PX<01D92`0L41804PH801451`0?0`D04@D701lC5@0X71h0;20R02lS9@0Q
5AL05`/=01D92`0?0`D04@D701<72@0201D92`0301<72@0C1`P04`P600X04`P601804PH701@82P0I
3@l040@601D92`0>0P@06@d?01451`0;00405`/=01dA4`0/8280;b<U01<72@0D20X04`L90186200C
1`T601@82P0301<7200B1PH04`L900804`L900X04`L;01D93@0A1@T05@P?01X=500F2A0050L?01<6
3@0E2@d060`@0P0F2Ph00`0J3Q805PX>01H:3P0201D93@0901H:3P0G2`l06@dA01L;3`0J3Q806`lC
01L;3`0K3a<06@dA00@060`@00D05`/?01T>500I3Q@06@hD01P=4`0201L<4P0701/@5P0J3aD06a0F
01T>500E2Q006A0E01XA500201hH6P0401TC5@0G4A<06Q@F01/E5`@071HH00h071HF01TB300M5Pd0
=c0X01TD3P0I514071LD01dI600N71X07QdK01dL6P0N7A/081lM02h]:@807A`H00/05aHB02<R7`0M
71X08B0N020O7@0S8R007adN01PF5`0R824092@T02LW9`02028R8P0302DU9`0T92H08b<U00808b8W
00X08R4V02<R:00T9BT0:Rl`02dc<`0N92@0:Bl_030f=P0]<c<0;S@d0P0[<C404P0_=CD0<CLg034g
=`0k@dH0=ci403Dl@P0i@4H0=3]302Xa>@0b>D40=3]503Y1B`1:DE/0AdiH03Q1B`0d@DX0=D9;03Q5
CP80>dQA04@0=dA=03a9DP0^>d@0?DYC041=EP0hADh0=D5<03m;E`11CET0?daF04=@F@14DU/0AEAM
041AF@0lCE@0?U1G03a?E@0mD5H0B5QN06]hOP1DHFL0@e1F03a9C`0mBU00@4eC03e:D011CU@0AE9H
04AAE`11Ce<0Gfe`0;2n_`1EHf@0>TQ904=ADP0nC4d0CE]L04mMGP1:F5T0AUAE04QFE`17EEH0CUaL
04=AD@1=Fe/0@4i>05YXJ01GIFH0E69U04mMH01>G5l0CeaR04]HGP1?G680EfEX05ARH`1BH640Df5Q
051OG016EE40?di;04QFEP1<FU`0AU=I04YGG@1FHVT0GVM/05UQI080GVIY00T0I6a_07^3Q@2OYjT0
SiRH06]dL`1YLVl0I6eZ05USHP1NJ6T00P1FHV804@1GHf<0EV9Q05MSH@1MJFD0H6aX05eYI@1HIEh0
Df1I05=OF`1HI680FFEU05EQH@1HHfD0H6]^05iYK@1JIFT0F6=X0080Ef9X00/0E5mU051KH@1EHVP0
D5eS04=@EP1DHFL0P8fC0:Vf_01>Ff40C5UO04]HGP0204YGG@1I04]IG01<FU/0BeUI04UGE`15De<0
@U1A045?D00lBTd0@U1C04IDE`0nBe40>DI<03e:D01HHfL0GVQZ04A>C`0nA4@0;30_03m1?P11@ch0
@dE203Tk>00j?cd0?TA404I>D00jADP0=3m3034l@00b?3h0<cdo03@m?`0a>C/0;3Dd02T`<00Z<300
:c4a02HZ;00Y:Rl0<S8j038b>`0Y:C<0:2Pd02h^>P0P82X07AdU038c>00N7b<0<C8d020P900Y:2d0
;2/`02/[;@0W9bL09bLU02XZ:00^;R`0;bl_02d]<00c<SP0?3]303/j@00b<CH0;Rdb02/Z;`0`;c@0
;2/`02<R9`0Y:2d0@d97024P9@0];340EUEJ0=SIg@14B4/04aHK03Dh?`12ADh061XV02T[=`0W:S<0
9BP`02<V:`0Q9BP07b4U01hM8`0U8RT0:2HZ028P8`0R82400`0O7Q`0200M6a`06aTN01/I7P0K6Al0
5Q@I02DS9P0F51L07A/N0P0J61/01P0O7B008R0S01TG6P0L6Qd06ALJ01hL7`8071PI0P0K5aP02P0L
61T06ADF01`H6@0L61T081`M01XF5`0C3a007a/L01HB4`0K5aP201TE5P0>01lK7015@D80Z:BU01TE
5P0N6Q/07ATJ01HB4`0L61T05Q0B01LA4`0A2`d040X<01hH6P0D3Q0201H@4P0801LA4`0I4aD06A<E
01H@4P0G4A<06aDG024K7@0M5aT201<=3@0401D?3`0D3``050l<01@?308050l;00@06QD?01PC3@0G
4P`05a8<0P0H4`l04@0P6aP050l<028M6P0D3Ph04P`<01@>3P0I4aD05@lA018<3P0?2@/0618D01`F
600I4aD07QPJ01LA4`0I4aD07QPJ00806aDG0P0M5aT01P0J51H06A<E01XD5P0J51H06A<E01PB5080
5a4C00H06a8E01lD600O51P0714E01P=4@0G310201D:3P0901T>4P0U6Qh09Q/O01hC5`0H3a409b4Q
018<300H4Q8071HF00804`d=00<050h>01<=3@0C3@d00P0B30`0100D2``05@T;01D92`0D20X201<7
2@<050P:0P0C1`T0300B1PP060`>01L;3@0D20X060`>01`@4P0G2`d04`L901L;3@0:00403P8400`0
0P804`L90P0D20X00`0B1PP04@D701@82P0201<72@<04PH800<04`L901D92`0:00000P0F2P`0100>
0P@07Q8D01H:300B1PP201<72@0901041P0D20X0200001452@0K3a<040@80106200b9RX04PH:00<0
4@D900@04`L;01@8300G20/05PL:0P0E1PT03P0F1`X05`P;02<D5`0L3A005`P;01P9300D1@P03P02
01<72@0F2P`04@D70186200H30h05PX<0P0E2@/07@0:00005@T;01H:300800003`<301861P0A1@D0
3`<301P<300A1@D050P801861P0A1@D04`L701L;2`0I3@d05PP800h0000G2@T070h>01@8200E2@T0
3`D501`B4@0J40l03`L501@<2P0A2@L04@T6008040P600`04PP701<92P0C2@X04@D701D62`0O41D0
6@X?00d00`0B0`L04`@701@5200E1PT301H72P0500h00P0H2@`05`P;01831P0I2Pd0100C10L30183
1P<04`@701h050D801D62@0D1@P04`@701421@0>00804`@701H72P0@0`D060T<02dN8@1nKg8070d@
00X0000I30`04@H401L;2`0F2PX040@40186200K3a402@0001L;3`080000:AdQ02PN800I2Pd060X:
01H8200D1PH801<51@0601H:300>0P@02`4200`00P0A1@L050X;0P0A1@L201<72@0301@82P0E2@/0
5@H9008050D800L04`@701@5200E1PT05@H901@5200F1`X060T<00806@X=0P0C10L201831P804@85
00H03P0201431@0B0`H0404401X;3P0K30lDooooo`006oooool02`0F2P`04`L901T=3`0I3@l04`L9
01H:300@10H05@T;00l31@0>0P@050P:00804`L901l05@T:01@82P0B1PP050P:01L;3@0H30h04@D7
01D92`0E2@X0200001`@400T61L0ZIfM048g=@0>10@06Ph>020E4`0I3Pd05`/;01H;2@0D20L04PH6
01451@0D20X05PX<01T=3`0B1PP0300201041P0C1`T050P:00805PX<02`04`L90186200K3a408QHH
01L;3@0D20X05`/=01<72@0@10H04`L901D92`0F2P`04`L901861`0A1P@04PH601<81`0D2@L05@T9
01@9200C20H04`L701<81`0C20H04`L701D92P0>0P@0710B01L;3@0I3@l040@601451`0H30h07A4C
02`P8P0G2`d04PH801lC5@0D20X05PX<01<72@0@10H04PH801D92`D050P:00l05@T;0186200A1@L0
5`/=01T=3`0C1`/05PX>01@8300N4AP09APO01lB6@0I31<04`L;01D93@0H31000P0F2Ph01`0K3a<0
60`@01L;3`0E2@d050P<01D93@0G2`l00P0F2`l01@0L4AD06a0D01X?4`0[82@06@hB008060dA00@0
5``@01H;3`0F2`l060dC1@0G3Q<02`0I41D05`hC01T@5@0H3a@05PdB01`C600I4aL08A/M020J7P0I
4aL05Q0D00806aDI03006aDG01/E5@0K5AD06aDD01XE4@0J4`/091dC0519@@0V8A/07QTF024K6`0K
5aH0920O028Q7`0N6QT071TH024P700G4a0081hJ01PG4`0M71P061LD02DT8P0f=C<0<c8`018@4@0X
9RL06aTJ028R900W9bT0:2PZ028T8`0Q8R408b<U024R900S92H09bLY02DV:00T9BL0:2PZ02//;P0]
<S809bd]02@Z:P0[<C409B/[034g=`0]<c<202T_;`0Q02`b<P0]<c<0;C8e02hf>P1:DEL0A4]A02lf
?@0b>D40>T5903PoB00g?TP0?4E?04iGH018D5/0@DYD03]8D@0e?dT0>TE?03]8D00jA4d0=418034n
AP0h@T`0A51I05UUL@18DUh0?TYF04=?F`15DEd0@TiJ04EBF`16E5d0@e9K0080?4eE01T0@E9I03e@
EP0lCE@0>4Q>05]XKP1<FEl0A55G03m<DP0mBU00@DiD049?E@18EE/0BUMM04EBF010CE<0=dE8075o
P00gADH0D5iO03=1@P11Ce00@U1A04ABD`11Ce00@4i?0080A59C02P0BEMH04MEEP15De@0CE]L0:Bb
/`23TI80DEmP04]IFP1:F5T0BUQK04ECEP18EUT0AeEF04IDE@19EeL0DEmO059QGP1;FUL0CEaI04QF
EP0oCDh0AE=F059OI@1HI6X0HF]]05QPHP1JHV@0Ff=V06Y_LP28SI00k_?f0=kTi@29TY40Ig1]05mX
I@1HHV40G6QV055MG01GHf40FVIV0P1CGed0>@1EHEd0FfMS05eYI@1JIf00EfAM05QTH01KIfD0EV=S
05=QH@1KIVP0Hg1b05e[KP1II6P0EV9X05ERJP1IHf`0EV9Z059OI`15DUP0D5eS04eJH01?G640E69U
06EcMP1@GV40CE]N04]HGP19EU`0AeAJ04MEF01:F5T0C5YK04]IFP15De@0?Ta=03a:B`11Ce80@TeA
03m:CP0iA4P0@Da@04eHG02LYjT0D5YK01dU9`0i@Cl0;C4`02hc;`0f>cL0@TI503Di>00l@D40?D=3
04mGF@0lATP0>TA603I0@P02038j?@0i03Dm@00c>cd0<3Dh02X`<@0Y;bl0:Rlb02la=@0_<3D0:b`a
02LW;`0/;3@0:2Pb01hN:00W9c406ATQ024R9`0X:Bd0:BX/02DV:@0Y:Rh0;Bd_02//;@0W:BP0:BTY
02`];00Y:bX09bLY02LW:`0V9b`0;Rdc03@c>@0`;cD0;2/a02d/<P0f=CX0<C0f02PW;00N7B80<c8g
02LV:`0f=CX0>c/o04I7C00`<cX092H]02<S;@0T9c009bPd02DU<@0P8b`07b0Y02<T:@0R9BX08B8V
01`K8@0U8RT0:BL]00809B<V00D08R0Q020O7@0O7Q`07A/L01/I700201XH6`0>01dK7P0V92L05aDH
01lM800H5QT071XM00l=400L6Qd07A/N01lM800J61/05aDH01TE5P0K5aP201TE5P0W01/G600I5AH0
5A4B01TE5P0J5QL0510A01hJ6`11?Ch09b<T01lK700J5QL07QXK01DA4P0Q7Ah0<Bd^01@@4@0E4A80
2`L801PD5@0C3@l08A/M01D=400V828091/N01/C5P0I4aD05`hA01L?4P0H4Q@071<F01XB5@0E3a40
6A<E01D?4@0G4A<05@lA01<=3@0F41005@l?00<05A0=01@05Q4>01HA3@0K5Q4061<?01LB300G4Ph0
61<?01TD400L5a@03`X700`7100G4A4071HF01TC4`0J51H05@lA01PB500M5aT081XL00l92`805a4C
00D05@lA01hH6P0K5AL071HH01PB500201`F600301PB500F41805a4C00806A<E01H06aDG01dG6@0O
6A/07AHH01dD5`0Q5QX07A<F01P?4P0J3a<060hA01XA500V6al0;bDY02PO8P0M4QH06A0B01@>3P0Z
92@0=2h^04]5A@0J51@0618B0P0D3Ph02P0D3@d050/<01@;300B20P04@D501861P0D20X05PX<01L;
3@0D20`201@82P0?01<72@0B1PH04PH601@82P0C1`T04@D701D92`0J3Q0050P:01L;3@0@10H04`L9
00h2100A1@L03`@5008050P:00D04`L901041P0A1@L05@T;01@82P0201<72@0D0186200C1`T050P:
01D92`0@10H05@/<01<72@0A1@L040@601@82P0A1@L050P:01<72@0@10H04`L901L;3`0D20`04PH:
01<72`0D20`201862P<04@D900@04`L;01@8300H2@`05PL:0P0D1@P01P0F1`X060T<038S9P0Z6ah0
6@X=01/<3`805@H902P04PH801H:300A1@L04PH801T=3`0G2`d05@T;01041P0C1`T040@600l31@0G
2`d05PP8020D500K3`l04PL701D;2P0:00004PP701061@0B1PH04`L701<51@0A0`<050H601T;2`0A
0`<04`D501P<300D20P0718A01471P0N51<03`L601`B4@0@20H040P501491`0B2PP050X90P0E2``0
4`0E2@/04@D901P<400D1P/03`0501<62@0C10L050D801H72P0H2@`06@X=01`=400B0`H06P/>01H8
2`0>0P@05`/=01441P0C10L00P0B0`H201421@0N01<41`0E1PT050D801@5200E1PT05PL:01D82P0E
2@/04`L90186200K3a408ADG01d>4@0H2@`02P0001/>400:00007PlB00d20P0C1`L07A4A01X>3P0A
1@D04@D700l31@0G2`d03@<501H:3P0H31004PP90P0C1@D20184100301<51@0D1PH04`D500D04`D5
00H02`0001dA4`0@10H08ADG00P0000E2@/201041P050186200D20X050X;01H:300C1`T00P0D1@P0
100C10L050D801D62@0G20/301<41`040101100?00<05@H901D62@<050D800L04`@701d>4@0@0P@0
7a0C00X0000L3Q003@0001Cooooo000Kooooo`0<01P=300F2PT04`P701<71P0E2@P05`/:01D:2@0B
1`H03`@30145100G30/0710?0P0D2PT01`0F2PT04PH603da<P0R5QP040@601451P0B1PH00P0C20L0
0`0C1`L05Pd<05I<C@0201H<300=00d3100I3`l05P`<01892P0@1`L06a8B00/20`0E2``0<RHX0147
200@1@H050P:01X>400301@82P804`L90P0B1PP05P0E2@/050P:01@82P0E2@/04`L901451`0D2@X0
4PP901<82@0E2@/07Q8D00l51P0T6QX0<2HW01`B4`0@1PH04`T:01<92@0B20P050X;01D;300D2PX2
01<92P0H0147200@1PL04PP901@:2`0B20T04`T:00d3100G3@h07aDF01P>3`0F30d04PT:01H<3@0H
3Pl05@/<01@:2`0C2@X04PP901P>3`0J41405@/<01882@0C2@X050X<100C20`02P0D2@d05``@0146
2P0R5a/0:QlS01P=4@0C20`04PL;01@93@0F2`l201<8300a01P=4@0J3a<05``@01<8300A1PX050T=
01P>4P0G3Q<04@X>02/T:00B2`l0610E04i6B`0Y8RH02P<701P@5@0P6Ad04``@01H?4`0H4QT04`dC
01H@5P0F41L050hD01PB600G4AP05Q0G01TC6@0G4AP04`dD01LB5`0I51P07APL01TD6P0C3QD06QDM
01PC6P0M61h07APK01/G500K61806aT?01/I3@0M6@d07a/@03Te;00K5Q007QPG028L7P02020J7@0@
01lJ6@0P6QX07a/H01lK5`0Q71P08QhJ02<O6`0S7a`08alM02<O7P0N71d071XL01hL7`0R8R@08b<V
024Q9@80:2X^00L07b<U01hQ8`0X:b`082@T024U8`0S9b@092TV00809b/V03409R/V02H/:00S:BH0
7B<P02`b<00Z<2h0:c4_02/a<@0Y;S40;S<f02db=@0/<C@0<3Di030g?P0g?TH0=Ca403]2B`0d?DH0
<ca503Y2C@0g@4`0=d9=03U4C`0kAU80>TAA03U2C`0j@Td0?4I>03e7C@0lADX0>T=803Y4BP0h@DX0
>T=?04M?GP18Cf40@4YJ04ECH01:F6D0AUAQ04MEH@1;FF@0A59M04eKI@0mBe@0CeeV03e<E@0mC5<0
?diE0080@4mF00D0A5=J04EDF`13DUT0@e9I04ACFP0204EDF`0O04=BF@12DEL0?Ta?04ECE00lBT/0
A59C045?D00nC4d0@e5B04ECE012D540BeUJ03a:B`1;FE/0A5=H04aKH010Ce<0EfIZ07n>T@1RLW<0
D61P04eMG01<G5X0D61M051QG01:FUL0CUaM05ARH`1<FU/0AeEF04]IFP0204UGF00J04IDE@17EEH0
CeeN05ARI01CHF80E61P05MQH@1MIVD0HFMX075cM@2ZZjd0j>WZ0=CGf01mPh<0I6e/06]eL`1KIfD0
FfQU05MVHP1JJF@0FVUU05MVH@1IJ6<0DF1K05=RG@1EI5l305IUH020055QG01GIf<0EVIS059QH01A
H640EFAW059PIP1CHFP0E69[05ERK01AGVX0C5US04aIH@1=FUl0CUaO04iLG@1=Fe/0CE]J04]JF016
E5D0BEMI04YHF`19EU`0C5UO04UGF`10CE80AUAH04ECE`10Bdl0AE1D04YDF01BG5h0@D]=03]4AP13
C4h0A4e=03a6@`0c?3P0=Chj038k>00^=C<0;cLd03Lo?@0b>CX0<CPi0418B@10B4X0<3Pj03Pm?@13
B4P0@DI603Xo@00g?3l0<3Dh02X_<P0^<CD0<3@h02ha=@0h>d00>ce102`]<@0Y:Rh0:2T^02<T:@0R
8bP0:2T]02DV:P0a<SH09RL[02h_<`0Y:Rh0;Bla02X^;`0X:b`0:2`]02T];P0Z;Bh0:bl_02HZ:`0U
9bT0;C0b02L[;@0P8RD0<c@j04a<E@0`<3T0;Bde02TY<00X:300:BX_01lP9@0T9BT0<C8f03<d>00e
=SX08R4]03hlB`0X9c@09B<`02<R;`0Q82/0<2hh02HU;@0R8RP08R4W01dM8P0S8RL07Q/U02HS;P0R
7bT0A45903<`=`0Q7b@081hP020N7`0N7A`071/H01/J5P0K6QL07a/K01`H6@0P71d06QHG020L7@0R
7Ql06aLH01`H6@0O6a`2020L7@1401hJ6`0]:BX06aLH01@@4@0d<340>cLh020L7@0K5aP071PI01XF
5`0H51D07QXK02DQ8P0K5AL071HH01XD5P0O6A/05a4C01hH6P0M5aT07aTK01dG6@0I4aD071HH01H@
4P0J41L07A8I01D;400I3Q@07A8G01dC5P0N4aL06@lB01L>3`0I3a006A0@01L?3P0F41006Q@D010:
2P0G4A403PP801dG5`0J51@02PD501TC4`0H4Q8050h>01XE4`0I51406QDB01D@3@0G4Pl05Q4>01@?
300H4a005A0=01/F4`0J5A805A0=01`G500M51D07QDF01T@4@0L4a@07aHG01`C500O5QL401hE5P0c
01hE5`0K5AT07QPL01PB5P0P6Qh06A<G020J7P0@2Ph09AlS01/E6@0L5QX05@lC01/E600P6Q`08a/N
01XC5@0J51H07QHI01`E5`0J51H0:b<V02LP8`0B30h0614C01TA500N5AP05@lA01`G6@0;1`P05a<D
018>3`0D3a005PhA01L=4@0F2Ph05PP=01D92@0F3@L05P`:01H<300E2``050T=01<83P0N4aL081HF
01881`0@1`<05Pd901@9200D20P05`/;00806Ph>00h05PX:01<71`0B1PH04PH601451@0B1PH04`L7
01@5200@0@@05`P;01421@0G20/05PL:01D62@D05PL:00<040H701lC5@0P51H00P0@10H03P0A1@L0
6@d?01<72@0A1@L04PH801@82P0A1@L050P:01451`0F2P`040@601@82P0@10H050P:0P0C1`T02@0D
20X04`L901451`0B0`H05PL:01h?4P0F1`X05`P;01@5200201H72P805@H90P0D1@P01P0A1@D05@T9
00d20P0T61P0DTI601461PD04PH601/050H601H62@0D1@P04@D701X@4@0C30`05Pl?01D=3P0=10D0
50X;01P;3@0H20/05@P801<71P0E2PP05``:01@91`0J3`d08aPF09Z?S@1KD4h060d;01H;2@0N4a40
5@/901L=2`0E2`X00P0D2PT201D;300B01<92P0C20`04`P<01872`0A1PX04PL;0104200^8RH0VhjB
01T:3`0B0PL070`A01H7300E2@d04`T<00/51P0<1`T050/=0P0B1PP301451`0@0186200A1@L03P84
01451`0E2@/05PX<01X@4`1bJfd0Ng=f028I700>1@L0DTM;01D93@0C1`/05@H;01D52P8050<900D0
5@L:01@82P0@10H03P8401<72@0200h3100601451`0B1`P05`/=00l41@0@1@H050H60P0C1@D02P0B
10@04`D501@61P0N410060X:02DG5`0;00005`T901861P0E1`L201@61P0G01<51@0D1PH04`L901<9
2P0@1PL040H901H>3`0C2Pd03`D901X@4P0_8bL03`@701/?4`0G2`l03`D70104200A1@T04`L;00/1
0`0^8RH0O71d01D93@0C1`/00P0A1@T0100C1`X05@T;01451`0A1@H201451@0301461@0A1PCooooo
01?ooooo000Kooooo`0801@8200C1`L04PH601<71`0F2PX060`<01@8200C1`L201861P0<01D92@0G
2`/04@D500h30`08000060`>0186200K3a406Ph@01L;3@0D20P04`L70P0D20P04P0A2@T03@<400d3
100G3@h0308301<92P0F30d06@l@065GF01iKg003`D601061`0J3Q007Q8D00P0000M4A<04PH800P0
00805@T;0P0D20X301<72@050186200C1`T05@T;01@82P0B1PP00P0J3Q002@08000040H702TM7`0>
0`D06a4B024G600E2``04@L801<92P0201061`090147200C2@X04`T:01<92P0D2P/04`T:01882@0D
2P/05@/<008050X;01@05`d>01P>3`0C2@X02@0000l51P0I3a003@<401T?400?1@H08ALH0147200B
20T06Q0A01L=3P0C2@X03`D600h41@0D2P`04PL;01<8308050T=00H05@X>01462P0?10P04`P<01H;
3`0C20`201@93@0701D:3P0F2`l05P/?01H;3`0J3a<05@X>01H;3`0201P=4@1701L<400E2`l02P46
02TS9`0c;C403PP<00L11@0F41@03PP<01TC5`0C3A406Q@H01/E6@0C3A405A0F010;4@0A31804`hD
01`G7@0C3Q@06A@J01<>500H4aT071LM01PC6@0D3aD071LK03@_=00K5Q`081/R02@O9P0M61l06QDK
01XE600I5A806QLB01/H3P0L6Pd0:2HI024O4`0P7A@071TB038^;00J5QL081/O020K7P0O6aX07QXI
01dJ5P0L6A@07aXG020K600Q71T081`K020L700P71d07adP01dL8@0N7B808R4V02<R:00Q8RL0828V
024U:00G6ah07R8S02DY:00R9RD082@S024V8P0R9b<00P0S:2804@0R9b408bTU01hT8P0X;R`0:c4_
01PN7P0f?3`0;C<c02X_<P0/<C@0;C8e02ld=`0c>3`0<SU0038i@@0mA4`0:34j0080>45:01d0>D==
03Q2CP0h@dl0>DEA03Y6DP0kAE80?4AA03e5D00lADd0>45803Dn@`0e?T@0>T=:03a5CP0mAE40@TUI
04A;GP0nB5T0@U1M04MEHP15Df00AUAQ04MEH014DUd0AE=N03E3C011CeP0?deF041?EP0203m>E@06
045@E`16EE`0B5MN04IEG015E5/0AeIM0P18Eeh08@15E5/0@E1F03e;CP1SLG80@Dm@03]9BP0`?Sl0
@U1A03]9BP13DE80AUAE04aJF`14DU<0AE=D04]JG@1<Feh0BUUL049AE011D5<0D5mQ04]KF`19FEP0
BUYI04iNG@1>GU/0B5QG045?D01=Fe`0EfEV04=ADP1CHF80FFMX04QFE`0204ECE00G04aJF`1?GEh0
CeeM04YHF01JIV@0DE]J05]TH`1XKFd0IFUZ08N8RP26Rh`0H6UX05USHP1JIV@0Df9O05]ZI@1CHUd0
E6=N05MVH@1FIF00EfIQ059QG01DHeh00P1FIF009`1GIV40EVEP05IVH`1FIV<0Df=P05=SHP1CHf@0
E6=V055PI@1EI6/0E69[04iLI`1<FVD0D5iW04iKH`1>G600CUaO04eKF`1:F5P0BEQE04mNF`1=Fe`0
CUaM04UGFP16DeT0BUMM04QEF`11CU@0BEIL03m=D019E5P0@Da@03Q2A011Bdd0F69T03Y2A00d?3h0
=3dl03Y3?`02038k>00603@m>P0f?ch0>T=203M0?`0g?d40<c/m0P0j@T@06`0a>C/0=c/l03i2@`16
BT/0=SXk02/_<P0b=ST0:Bd`02HY;P0Z;C80;C0e03Hi@00k?D80:2T]02d^<P0V9b/07AhR02PY;@0P
8BD07b0T02DV:P0/;C40=3Di01TJ7P0[;C00:2`]02HZ:`0202DY:P0402@X:@0N8R<0;c<d01/O8080
<CDf01`0>3`m06]]LP18B580<30j02PX<@0L72@0:BTa0411A`0i>Sl0;2da02PY;@0T9BT0:b`a020N
:`0c<Cl0:bTg02TW=00S8Bh0<Blj028Q:@0N7BD09bH/02d/<P0T8bT07ahS02@Q:P0U8R/07AXR0P0I
5Qd03`0P7R<071XM02<Q8P0Z:2P08R4O01`K5`0M71P07ATH01LC500M6AX06ADF01/G600M6AX06QHG
01/G600301dI6P0801`H6@0J5QL08AdN01/G600P71d05A4B00h:2`0L61T201dI6P0701`H6@0N6Q/0
8AdN014;3@0H4Q@04`d?01TC5@0201LA4`0c01`F600A2`d03PP:01hH6P0J51H06A<E028H800E3180
60lD01H=4P0M51P07A@G01T@4`0G3Q005`h?01T@4@0J4A40610>01D?3`0K5AD03PP802DO7`0I4a<0
4P`<01@>3P0R71`08A/K01hH600M5aL0=2h^02HQ7P0K5Q<07aXG01LB3`0L5a@04Pd:01D@3@0?2PL0
7QTF01PC400J5A805A0=01P?400K4Q<06Q4B01dD5@0O5QL071<D02<J6`0P5aP07QDF00<07A@E00H0
7QPL024L800K5QX0:bHZ02lZ;P0^:Bd2024L800601/F6P0X8bL06aHJ01`F6@0H4Q@06Q@F0P0I4aD0
8P0F418050h@01/E5`0E3a404`d?01PB500G4A<06A4D01`C5P0=1`T040/<02/W:00@3Pl04Pl@01DA
4P0H3a806@hB01P<400H2@h05PX901@;100E2`T05@/:01@:2`0C20`03@8601hC5`0T6QX03P@300/2
000R6A@050T701@8200E2@T201P<300301@8200C1`L04`L700<04PH600H04`L701T:3@0@0@@05PL:
01P9300O41<701@5200401<72@0L41806Ph@0186208050P:00/05@T;01<72@0A1@L04`L901@82P0B
1PP05PX<0186200D20X03P8401@82P020186200;01L;3@0F2P`04@D700l31@0B1PP070d@01421@0B
0`H03`0301L82`0B0`H00P0F1`X201D62@8050D800H040@401D92@0C1`L05`/;01D92@0K3`l50186
1P0>01@61P0I2@`05@H900`00P0L4Q<05@l?00d71`1;ADD0;RDV01061`0C1@P091@G0141100C1PH2
01P<300:01861P0O4a<0;R8R0=O;b`24N7P05@T901T=3@0F2PX050P801@:20805@/:00@04PP700l5
1P0=0`@04@L80`0B1`/03P0@1@T04PL;00d21P0A1@T07A0D00X0000c8RP08a<I01<42@0900409adQ
02HP8P0;1`P030@60P0A1@L30186200@01D92`0C1`T04@D701P<3P0M4A<060`>02HL7P3KeML0ooKi
03P_<P0I41<01`0001872`0C1`/05@H;01D52P8050<900L0:1TM01`@4P0@10H06@d?00l31@0?10D0
5`/=00805@T;00@040@601P<3P0E2@/050H60P0C1@D06`0B10@04`D501@61P0:0000818B00l10@0K
3@d05`T901/=3@0E1`H050H501@61P0C1@D050H601<72@0C2@X040H700`31@0600005`hA00l62@2/
X:@0^Zjb01lC5`0@10P04PL:01lC5`0200h21P0601H:3P0C1`/060`@03DY;@0E2@d050P<0P0B1PX0
100D20/05@T;01451`0A1@H201451@0301461@0A1PCooooo01?ooooo000Kooooo`8050P80P0C1`L0
100E2@T05`/;01@8200D20P401<71`0O01hB4P0G2`/05PX:01D92`0B1PP04`L901lC5@0L418060`>
01L;2`0I3@d06Ph@01/A4P0=0`@07Q@E01061`0=0`@05`d>01H<3@0B20T0HEMH071VI`0?1@H05`d>
00d3100I3@l020000147200:0000:AdO01<72@03018620804@D70P0C1`T03@0D20X05`/=01H:300D
20X03`D60186200L41809a/M09>7R@0h;Bl050X;01H<3@0A1`P00P0B20T00`0@1PL04@L801882@03
01882@<04`T:0`0D2P/03P0@1PL04`T:01D;300=0`@03P@501D;300C2@X04PP901H<3@0C2@X04PP9
01@:2`0G3@h04`T:0P0J41403P0@1PL04PP901472@0B1`/04`P<01@93@0E2Ph05P/?01D:3P0G3100
5@X>01<8300G310060dA1@0F2`l00`0H3A405@X>01H;3`0201T>4P0701P=4@0E2`l08QTN01lI7@0F
41@06A<G030Z;P0201hH700W01TC5`0F41@06Q@H01XD600C3A405a8H01D@5P0O6R00100500h93`0?
2Q006QDK01@?5@0H4aT06aHL01TD6P0J5A/04@`@02@O900F4AL05Q4H01LB6@0E41H071LM01/G6@0J
5Q<06QLB01/H400L6Ph04a45055?A00o?3D0:BHQ03Te<`0I5AH06aHJ01`G6P0M6AX07ATH00807a/H
024081/H028L700S7Ad08QhM028N7`0Q72007adP01lN8`0P7b@08b8W02<R:00Q8RL08BDX01TM800f
>Sd082@U02DY:00M8B008bLV02@Y9@0U:RH09BXT02@Y8`0S:28092XV02@Z:00Z<2h0<SPf03a2@P0h
?Sh0;38b02`a=00_=3L00P0`=CP08`0a=SX0=Se402P_=`0g?TH0>T=<02/d?@1>Ef00=d5;03Q2CP0g
@Th0=T9>03Q4D00h@dl0>T9=03e6C`0lADd0=d1703Dn@`0f?dD0>T=:03a4C`0mA580@4MG04A;G@13
CEd0AE=P04QFH`13DEh0@4iK03m=F010CUT0AE=N03e;E010CUL0?deF0080@U5H00L0@E1G04=BF@17
EUd0B5MN04EDF`14DeX0AUEL0080AeIM0100@e9I03i=D`0lBTd0O8Z;04ABD`17EEH0@e5B04YHF@16
E5D0DEmP04=ADP0nC4d0CE]L04iLG@18F5P0@U5D0P16EEP07P13DUD0EfMW04]KF`1:FUX0Be]K04eM
G@1;Fe/0AEEE05ITI@10CTl0D5iO04UGF01<FU/0BEMH04QFE`17EEH0B5IG04iLG@1AGf00DV1Q04eK
F`1JJ6D0D5aJ05aVI@1RJFT0DeUI06E[J`1ZLG40G6IU05]WI@80Df9O00T0F6MR05ASGP1FIF00EVEP
05=RG@1FIF00DV5L05ASGP1FIF000`1GIV404@1BHUl0DF5N05=SH01GIfH0F6QY05ETI`1DHfP0EFAZ
055OJ01=FfH0C5YU04mMIP1;F600C5YN04eKGP1=Fe`0C5YJ0080C5]H0180C5YK04iLG@18EUT0AE9H
04UFG018EE/0@TmE04aIG`0oCE00DUeQ04=>DP12C4h0A4i@09:LWP1HH680=Cdo04YCDP0h@Cd203@m
>P0603Ho?00h@D00>T=203Dn?@0g?d40<SXl0P0a>C/0?00/=3H0<SHg03<g>00i?Ch0<SHg02da=00d
>3/0<CDh02LZ;`0Z;C80?D1503Tl@`0`<SL0:b``0411A@0g>3`0824U02X[;`0V9b/0IFIZ03@e>@0X
:Bd0<S<g01`M8@0];c80:Rh_02L[;00U:BX08bLX020T9@0M8B80LGEf02HZ:`0G6a`0:2`]01`P8@0h
>Sl06a/U02h^>00V9Rl0<C4i03Ph@014AD/0=CHk02PY;@0S92P08B8V02`]<@0R82d09bDc028P;P0[
:CH0;B/h04Y8D`0o?TH0<c8j02/Z<00Y:2h08b8X02DT:@8081dT00P09bD[01XG7P0Q7b@09B<X01XH
6`0O7B00928S01hL7@806QTG00L061@E01DA4P0U8B8081`M01/G600M6AX06QHG00D06aLH0P0L61T0
1@0C3a005a<D01LC500T824061@E00D06QHG00H05@lA01`F600E3a4071HH01dG6@0K5AL201LA4`0P
01`F602ARhd091hP020J700S6B4050/A01dD6@0J4AH07aHJ01dD5`0H3a805`h@01L>3`0H3a0060l?
01D=2`0I4a<04P`<010:2P12?3`0:28R00D0000H4Q803@L701H@400:10@0H5YJ0>kXj01>BDH02`H3
020K600E40d201LB3`0?018=2P0C3P/08ahK01LB3`0H4a003`X701XA4P0M51D07QDF020G600O5QL0
7A@E01hE5P0M51D071<D00806a8C00D06A<C01@?4`0Q72006aHJ024L800201dH700801XE6@0^:Bd0
91lS010;3`0C3Q807APK01hH6P0O6A/2024K7@0R01hH6P0J51H0:B<U020J700L5QP08Q`N01H@4P0I
4A@0:1lR018<3P0X8b@0GUYK01/I6P0H5AH05A4B01H@4P0G3A405`/?01T:3`0G2`X05`h901L=2`0G
3@`05P`=01D:3P0B1`/050X;01@:2P0A1`D04PP601P?2P0C20H04PH601<71`805@T900<04PH601@8
200C1`L00`0B1PH01P0D20P06P/>00l00`0F1`X0814D02TJ7@<06P/>00X05`P;01@5200B0`H04@85
00T0000>0P@03`<501041P0E2@/05PX<0P0C1`T0200B1PP04`L901@82P0C1`T05@T;01451`0E2@/0
4@D70P0J3Q002`0C1`T05`/=01L;3@0D20X04PH801@82P0M3Q406@X=01L82`0=00404`@700<05PL:
0P0E1PT201@5200401451@0?0`<060`<02`P80804@D51P0B1PH00`0H2@`050D801H:300200h51P08
02HP803DcLd0ShF602DK700?10D070`?01P9300C1`L201H:2P0A0104100F2PX08ADE04/o?`0a9BD0
3`<301T=3@0?0`<050P800l50`0@1PD04@L601<9200D2P/05@/<01@:2`0B1`/00P0A1PX04@0>0`L0
2P4301052@0A1@T03`@602XK801nKG<0?2`b00l01@0K3a<0UXb@07miN`0M6AX04@T;01041P0A1@L0
4PH800804`L90P0F2P`20186200<01H:300G2`d06Q4C05YDEP26OH006A0C01lF6@0A1PX040@801<7
2`0E1P/05@D:0P0D0`T0200S5QT05`/=00l41@0J3Q0040@60186200C1`T020000`0?0`D09@0@1PL0
50H601<51@0C1@D04P@401<51@0D1PH04@<301lA4@0J30`0;AlO02DG5`0<00005@L601@61@0D1PH0
4`D501@61P0C1`T04@L800L0000N4aL03`H900h5200O5QT060`@040d>00E2@d0710D0104200;00<0
6`lC00d21@0?0`L04PH:00/10`0800000P0B1PX20104200401862@0B1PP04@D701451P804@D500<0
4@H501461?ooool04oooool001_ooooo0P0D2PT0100C2@P04PP701881`0A1`H401881`0B01471P0A
1`L03`D601/?4P0D2P/040H701X>400>10D05@T;01@82P0B1PP04`L901D9300F2Pd050X;00h41@0L
4Q<03PD50P0C2@X01`0A1`P04@P901@:2`0H3Pl05P`=01061`0C1`T00P0E2@/00`0O51D0PWIh04Xn
@00201@82P804`L90P0B1PP04@0E2@/050P:01H:300H30h05`/=01D92`0G30h0308301/?4@0@1@H0
:1`N01H;300C2@X04PP901@:2`0G3@h05@/<008050X;00<04`T:01882@0B20T00P0B20T00`0C2@X0
50X;01<92P0201882@0;01<92P0A1`P05P`=0147200I3a007A<D01@;300F30d02P4201P>3`0<0`@0
0P0E2``01`0<0P<08ALH02PN7`0I3a007Q@E01472@0D2@d01@0E2Ph0200G31005P/?01<8300E2Ph0
4`P<01T>4P0G31005P/?0P0E2Ph0400D2@d060dA01L<400G31005P/?01L<400G3A405@`A00l93@0J
51P06A<G01XD600B31004@/?00l93@0J51P2010:3P0801/E6@0G4QP050lE01PC6@0@2a409b8X02TT
:P0J5A/201PC6@0E01D@5P0F4AL081/Q01XE6@0E41D08ahT01PC6@0I51X07APM01PC600J5AL06aLE
01hK5`0R7aP0924H04Y7?`3KfM40UY>=03Pd<00O6aT071PG00808AdN00/081`M024M700Q7AX08AdK
01lK6`0P71h08AdO024M800P7B407adR020O900302<R:00:024R9`0R8bP082@V03<g>022QXL08RHW
028V9@0N8R408RHU02@Y9@809BXV0P0T:B@03@0X;b`0CeQE04QACP0_>3D0F65P02`e=00Y<C<0;SHh
030h>P0b>Sd0<CTl02hf>@0e?4@00P0_>3l05`0nAe00GFM`03@nA`0i@dd0>dMC03Y6DP0iAE40>dMC
03e8D`0nB580?dUB03Y5C00c?T@0<Se303Q3B@0jAD`0>TA>03e7D`11BUT0ATmP04UEI01;FFH0C5YW
0080AeER00P0AUAO049@F`12D5/0CUaU045?F00nC5D0?TeD04ACF@80A5=H00<0AUEJ04EDF@13DUL0
0P11D5D05P12DEH0@E1E03i=DP0lBdl0@U1C04=ADP11Ce00?de>03M5AP1=Fe`0E69S03m=CP19EeP0
DV1Q04MEEP18EUL0CemN04YJFP18F5P0@e=C045AD@1AHF4204mNH@0:04iMH01<Fel0BEQL04EDF@17
EEL0EF=T05ARH`1GIFH0SifN07:0P@80AE=D01T0B5IG04aJF`1?GEh0DV1P051PG`1DHf00Df1N05UW
I01HHf80GVQW05eWIP1LIfH0F6ES05]XIP1?Ge`0EfMT05IUH01HIf80FVUT05IUH01@GeX0Df9M04mN
F@1@GeX0DV5L00<0Df9M04P0DF5N059RH01FIVD0FFUY05MVJ01?GV40EfI[051OI@1=G6<0CeeV051N
J01=Ff@0CU]S04iLH01=Feh0C5YJ04UGE`18Ee@0AEAA04IDE@1<FU/0BUQK04ICF@17E5X0AU=I045?
DP17EEP0?Ta?04iIF`10Bdd0=Cm1034k?01DGUl0>41203Dm?`0g@3l0=d0m03U2?`0h@Ch0=Sll03@m
?00b>cX0=Cdo03U1@`0g?d40=3`o03Dm@00f?T00=c/m02lc=00V:R/0;c<f03@h>`0V:Bd0<C@i03Lj
?`0c=S`0@TE<0454B`0`<SP0;Bhb04A5B@0f=c/06Q/O02HW:`0j>cl0a/O;05UJGP0Y:Rh0;2da02//
<00/;S4202P/;@0702X^;`0[;c00:Bd^02``<@1WJf`0<CDf02DY:P0202/_<00902`^=00W9c40<30j
02h^=`0c<c/0820X02d]=00V9b`0;c0d0080;Rlc01809BH[034_>P0Y9c<09R@`02LU<@0R82/0:RPc
02TX<00O7RH081lU02HU:`0P7bD071/Q01dK7`0H5QX08b4T01TG6`0S8B@201lM800301`J7@0J61/0
6QPK00806aTK00@06QHG01@@4@0Z9RL09b<T0P0I5AH201`H6@0:01/G600J5QL06aLH01/G600F4Q<0
61@E01hJ6`0T82406QHG02HR8`@06QHG02d06ADF01HB4`0E3a40618D01LA4`0P6Q`06A<E01LA4`0L
5QP05a4C01XD5P1LEUP08Q`N01hH6P0I4QT06A<I01LA5@0J51P05a4D01D@4P0O6A/06aDF01LB4@0H
4Q805a8@01@?300H4Q8071HF00l92@0M5aL04`d=01H@400B30`06A<C020J6P0M5aL0BdE508^5Q@0g
<Rl04@`901hI5P0E40d06A@A01@?300I51400P0G4Pl00`0D3``05A0=01dH5@0201XD500301`F5P0K
5AD0618B00<06A<C01006Q@D01/E5@0M5aL07QPH01`G6`0V8BD07APL01hI7@0G4QH07aXN01/F6P0f
<CD0?STm01LB5P0S7R806QHH0P0I5AH06P0L61T06aLH01XF5`0L61T0:bLX02LS900O6a`07QXK01PD
5@0N61T06a@F01dG6@0F4Q<08AlP00h<3@0D4Q<0514B01D?4@0F31005PX>01L:3P0F2`/05Pd801H<
2P0F30/05@/:0P0D2P/0200B20T05@/:01H<2P0C2@L04@L401P<2`0F2PX05@T90P0G2`/00`0E2@T0
50P801@8200301<71`0>01@8200J2`h0404401L82`0M3Q409AHI01P9300L3A006``?01T:3@0G20/0
5PL:01@5200C1`T201@82P0401<72@0D20X04PH80186208050P:0P0C1`T01P0D20X05PX<0186200E
2@/040@601L;3@805PX<00/04`L901D92`0I3@l06Ph@01D92`0@0@@0:Q/N03HW:P0O41<050D801D6
2@0201H72P805@H90P0D1@P01P0B1PH05@T901861P0Z7Qh05`/;00l30`H04PH600h04`@701@62@0D
20X04`T:01892P0S6Q/0UHf>06ILG@0@20P06@d?0101100D1@P04`L701451@805@T900l04PH601@8
200H30`05`/;01X>3P0A1PH08QHF01T=3@0E2`T04PP701471P0E2`X0718C01lE5P0D2P/00P0?10P2
01<8300=01872`0?10P03P@601T<400?0@D09QDK01/;400D1@X040H804a3AP0k=CL02@D601082P02
018620804`L900h050P:01051`0D20X06Ph@01D92`0=0@<040@601@:300O5QT0:R4T01D;3P0>0`L0
5@X>01@830804`L;01004`H:01<42@0C10T04PD801041P0A1PL04`L901451`0>0P@040@601D92`0D
20X04PH801@82P0K3a4050H60P0C1@D08@0B10@04`D501@61P0B1@D060`<07AVIP0E1`L04@D501P;
2`0E1`H050H501@61P0C1@D050H601<72@0<10@03@<401P?4@1HCe807QDH01D<3`0J3Q803P@601T=
4@0=0`D05``?0104200B1PX05@T=01<72`0A1@T04PH:01D;3@0401862P0401862@0B1PP04@D70145
1P804@D500<04@H501461?ooool04oooool001_ooooo00P04PP901<92P0C2@X04`T:01882@0A1`P0
4PP90147208040H700l04PP901<92P0P51P0C4140104200a9BL040H701L;2`0C1`L04`L801<72@0D
20`05@P?01D93@0H3Ph00P0B20L03`0C2@P03`D400`20@0D2PT05@/:01`B4@0@1PD04@L601L=300C
2@X04PH802dQ8`0:0040CD5302LK7@0201D92`8050P:0P0C1`T0300E2@/04`L901@82P0E2@/04`L9
01451`0D20X09a/M00h2100F2P`03`<501P=3`803`D60P0D2P/20147200N01<92P0B20T04`T:01D;
300G3@h05@/<01@:2`0F30d050X;01882@0C2@X04PP900/10P0H3Pl0:b8R01061`0=0`@05`d>00`2
0`0[8B8050X;02DK700<0P<050X;00h41@0B20T0718C01@:2`0@1PL05P/>0P0F2`l01`0E2Ph050T=
01<8300H3A405P/?01L<400H3A400P0F2`l01P0H3A405P/?01@93@0G31006@hB01P=4@805P/?0`0E
2Ph0600F30l06Q4F00`62P0B3A0050hB00d72`0G4AD06Q@H01H@500[9BT0L6Y^034[;`0J51P0BDA:
05aGG@0F4AL06QDK01dH7P0B3A<06A@J01LB600J5A/06A@J01D@5P806A@J01004PdC01HA5`0F4AD0
5a8F01HA5@0H4aL06ADE01/G5P0N6QL08QlJ02@Q6P0Z:B@0OGag04]:AP0_;RX08R4O0`0Q81h01`0P
7ad07ahL01hM6`0M6a`07QTM020K8@0Q72800`0O72<0:P0P7bD09B@Z02DV:`0R8RX08B4Y028S:00S
9bT0=c/l06EYJ00S9bH092PW02HZ:@0R9RD08bLV02@X9`0V:bP09R/W02D[9`0R:RL0<CXi04YCDP0R
:bX08b/]034i>`0/=3H0;cLj02de>00a>C`0=Ce0038j?@0i@TT0:c@k03@mA01HHV/0h>[c08B>U`0j
Ae00@4aH03i;E`0kBE@0?D]F045<E`80@TaE00h0>49;030j@`0b?4D0?4I?03e7D00mAe40ADmJ04A>
FP13C5/0AE5O04MEHP14DUl0?deJ045?G080@4iI00T0?deH05ESK013DEX0AUAM049AF015E5X0@e9G
045@E@12DEH00P13DUL06012DEH0@E1E041?E00oCU<0?TeB041?D`0d@TD0@e5B045?D01<FU/0B5IG
08ZHV@2AWj00EF=T04IDE@1<FU/0BEMH06ilO@1QLG00BEUF03m?CP1;Fe/0BUYJ05ETI`80D5mT00X0
CUeS04aKHP1<Ff80CUaT04mMH01DHV<0FVQY04]IFP10CTl0BUQI0P14DU<204ECE00704IDE@19EeP0
C5aK055TH01AHEh0EVIS05ASH00205]ZI`0>05YYIP1CHf00EfMT059UH@1OKf`0I7=`05QWI01DHf00
EFAQ059QGP1?GU/0Df9O05ETH@1GIV<305QWI00^05ATH`1CHf80DV9R059RHP1@H640CUeP055PI@1?
GV@0CUeT04mNI@1?GVH0CeeV055NIP1@GF80CE]N04YHF015De<0A5=@04QGE016E5D0CUaM05=QI01;
F5h0AeAJ05ARI@1:F5/0AE=F03i<C@0jADL0<C`n03Do@00a>c`0A4i?03e6A@0c?3/0>dA303Y3@00n
AdH0>D9103Ho?P0f?T00<c/m03Y2A00i@D@0=Si102lg>P80:S8e00d0<CDh02X^<@0T:2/09RX]02d`
=@0b=CX0<cHk03XmA00n@DP08bH]01/N9`0Q8bT08B8V00809bP/07H08R<W02X[;`0U9RX0EEIJ03Lh
?00[;300:R/_02TZ;P0R92L08BDV028V9`0V:R/0:2`]02L[;00T:2T07R8S024U9P0U:BX0720Q02@X
:@0V:2h0:b/e01hN:00];CH08B4Y01XJ8P0U9R`0:2T^02<T:00G61`0:R/_02HW:`0[:S80:RTa034`
>@0Z:C408b8Z01hM9@1LFf<0A4=;02HU:`0N7B<071/Q02@S:@0R82<071XK01lM7P0J61T07Q`M01hL
7`0M6ah071XM01/I7P0J61d071XO024O900_:Rh04`l@01TE5P0R7Ql06aLH01`H6@0N6Q/07ATJ01/G
600J5QL06aLH01`H6@0Q7Ah07a/L01@@4@0@30d0:bLX07McM00P71d071PI01/G600L61T06aLH01LC
500K5AL091hP03hh>P18@T@09AlQ01PB500@2P`06Q@F02HP8P0<1PP06aDG00P2100@2a409B4V00H4
1`0G4QH04PlA01TG600Q7Ah06AHF01<B400E4A005Q<A01LC400C3@d06Q@D01hH600K5AD04@/;034[
:`0H4Q805Q0@07ihN01OFET04@/;01TC4`0@2`P07APE0P0H4a003P0K5Q<04`h;01LB3`0D3``02`H3
02LR7`0@2`P08A`I01TC4`0F41006Q@D01TC4`0H4Q8071HF0`0J51@04P0L5QH07ALG01hH600H51P0
6ALJ01<A500K6A`05Q@G024O8P0`;S404a4D01HD5`0L6Qd09bDX028P8`0P7R40928U02PV:@808AlR
00L07adP018@4`0F51L061HI01LE600Q7b809b4T00803`T;00/09b@U01<A4P0I6AT05A@D01@B4`0E
3a405@d@01H;3`0G2`l05P/<01@:200201D;2P0?01@:2@0C2@P040H501061@0E2`X04@L600X0000A
1`D05@T901<71`0A1@D04PH601<71`0A1@D05@T9008050P800T04`L701@8200E2@T05@T;01041P0F
2P`04PH801L;3@0C1`T0100B1PP201451`0700`00P0?0`D05@T;01D92`0C1`T050P:0186200201H:
300901<72@0A1@L04PH801D92`0A1@L05@T;00h2100B1PP03P8400804`L900X05@T;01H:300G2`d0
5@T;01H:300J3Q006`lA00d10`0A1@L060`>0P0D20X201<72@804PH800H040@401D92@08000040@4
00/0000A1@D601861P0901H:300C1`T030020147200C2@X0718C02/Q8P0K4A805@/<00803P8400<0
5@T;0186200A1@L00P0E2@/0800D20X060`>00X00@0F2P`050P:0187200S5aT05PX:01@:200A1`H0
3`D401061@0D2P/05P`=01X@4@0?10P03@8601872`0E2Ph04@H:01hC5`0N4QH04@<801X;400R4AL0
3@0201D62`0H31004@P:018<3P0R7Ql08ATJ100C1`T03P0B1PP040@601P<3P0R5QP07Q8D01<72@0B
1PP040D701L=3P0<0P<03PD601<92P0800004@D70P0C1`T01P0B1PP04@D701451`0A1@L050P:01D9
2`804`L900P04PH800`00P0G2`d06@l@02HJ700800005PX<01@61P804`D502404P@401<51@0D1PH0
4@<301<51@0=0@4060X:01d?3`0C1`L05@L601@61@0D1PH04`D501@61P0C1`T04`T:014720070000
?cHi0189300@20X06`lC00/00`0B1PX03`<701L;3`0:00805`/?00d31@08000040@801`@500A1@T0
0P0B1PX201<72`0401862@0B1PP04@D701451P804@D500<04@H501461?ooool04oooool001_ooooo
00<03`D60147200B20T00`0C2@X09@0B20T04@L800l51P0?1@H04PP901@:2`0A10/06`hD01hB5008
000060`<01050`0B1`D04`L701@82P0D20/04PD<01862P0@1PH04`T800h40`0A1`H03P@301/A400F
30/05`d<00`20@0E2`X06Q0?00/1000B1`P05PX<00X0000F2P`060`>01451`0C1`T00`0B1PP20145
1`0B01@82P0B1PP04PH801<72@0@10H03P8401<72@1;?d405@T;01L;3@0?0`D04PL801<92P0D2P/0
6@l@01P>3`0D2P/04PP90P0A1`P05@0D2P/060h?01/A4P0H3Pl05P`=01L=3P0E2``04`T:01D;300J
41402`4201dC501jL740ETa=01L=3P0E2``08QPI06aRH`0K4A80<RPY00L0000201X@4@0A00X00@0E
2``050X;00T0000L4A@060dA01L<400D2@d04`P<01872`0F2`l040D901<8300F2`l04PL;01L<400F
2`l00P0D2@d00`0I3Q807A8F01`A5@0201@93@805P/?01d05@X>01@:3@0F3A802P@801H@500G4AD0
5Q0D01@>4P0J51P03@L;05I@E03ooOl0NG=g01/E6@15@4H0NWEk01<>500J5A/05a8H01/F700I51X0
5A0F01/F700N6Al05Q4G010;4@0J5A/07APN00d8300201XE6@0501@@4@0M6AX07ATI01/G5P0K5a@0
0P0L61D01`0L6aL0@D0l028Q7`0Y:2H06aXH01lN700J6AL00P0K6QP01P0L6aT07A`J01hL7@0Q7280
8ahU02@O9P808QlV01008B0V020O9@0U9R/09RL/028R:P0Q8BT08R<X02/_;`0O8b808RHU02DY:00Y
;B`09RXY02@X9`0V:RT09b/Z0P0Z;Rd06@0Y;bd0;3Db02L`;`0P:BP0<CXi02lg>@0`>3X0;cLi02hf
>@0Y<C@0;cLj03Q0@`0e?T<0EUmV02/d>`0h@DP0@TaE092JX`1:E5d0>4E>03m;E`0mBUH0>DMB03]9
E00nBe@00P10BU<0100h@T/0<ce603I0B@11Be@203m9D`0A04YDG`16D5`0?dQG03U6E00jB5D0>DMD
03]9EP15Df00BEMR04ECGP0fA4l0CE]T03a:D`16E5d0@4mF045@EP11D5D00P0oCU<09P13DUL0A5=H
04EDF@13DUL0@E1E041?E011D5D0A5=G04UGF00e@d@0@U1A0390@@1=Fe`0CeeN05aZJ`12D540AUAE
04MEEP1=Fe`0BUQI04YJF@10D4d0Be]J04]KF`13De<0MhJ9051OI01?GV<0CUeT04eKI01>G6D0Df5Y
05ARI@1FI6D0BEMH04iLG@1?GEh0@Dm@0`17EEH204ABD`0704IDE019FEP0EFQT051SG`1HJ6D0EfMT
051SG`0205EUHP0B04eMFP1?HUh0Cf9N05][J01_OW/0EVER04iMFP1EI640E6=P04eLF@1BHEh0E6=P
05ETH@1FIF80EfIS05IUHP1CHf80DF5Q0P1>GUh0J@1AH680E6=V04]JG`1AH6H0DF1W04iMI01>G6@0
DV5X04eJH01=Fel0C5YM04]IF@18EUH0AeIC04ACD00oCDh0B5IG04mMH014DEL0?T]A04QFF@11Ce80
>dU<03e;C00f@D<0=3m103]5AP0g@D80<S`m03i7AP0mATD0?TM603a5@P0oB4L0=d0o03Ho?P0i@D<0
=cm103Dm?`0e?D00=Si1038j?@0_=cX0<CTl02hb=@0]<C@0<CDh02T]<00^<CH0@DA902@W;00T9bh0
BdiE030c>P0R9Bh0;Ble02TZ;P0V9b/0:R/_02PY;@0S92P0;2da01hO8`0^;c<0:2T]02HW:`0W:2`0
:R`_02L[;00V:R/0:2`]02L[;00T:2T07R8S02da<P0Z;Rl07b<T02T];P0J7Ql09RP]034a>`0[:cD0
;Rhg024Q:@0e=Cd09bL^02d^<`0/;C407QlS038c=`0T9BT092<Y02LV;P0`;cL08R4Y024P:00T8b/0
>3Lo02HU;@0I61h07ahT024P9P0Y:2d06QPK01XH6@0201lM7P0501`J6`0N71l05aDH01/I700O7B80
0P0J61d02`0R82H0GEQL02l[;00M6AX09B4R01lK700K5aP07a/L01hJ6`0L61T06QHG008071PI0180
:bLX01HB4`0H51D08alP01DA4P0O6a`08AdN01`H6@0I5AH06aLH01XF5`0G4a@07QPJ01<=3`0P6Q`0
:R@V018<3P0H4Q@201`F600Z018<3P0S7Al05@lA01HB4`0^:Bl0A49600h<3`0L6Qd040h@01TG600K
6AX04a8A00d<2P0>3@/04a8?01DD400D3Ph05Q0@01/E5@0E3`l0:28R06QRHP0P6QX0618B044k>`0c
;Bd09b4Q010:2P0N6AH050l<018=2P0I51405A0=01/F4`0G4Pl07QTF01TD4@14?c`050l<020K600J
51@05a4A0P0K5AD0100L5QH08Q`L01XD500I4a<201PB4P0W01TC4`0H51<061HI01hL7`0L6Qd09B<V
01/I700T8RD0GUaO02d[;P0M6ah08b4T01DC5P0F51L05QHH01lM800S8R@05aLI01LE600R8B@05QHH
01dK7P0N7B004A4C01HD5`0A3Q007ATJ01TE5P1;BDX071XK00d=3@0I61T05A<D01HB4`0F3Q405``@
01T=4@0H3@h05`d;00805`d<00/05P`;01D;2P0J40l04PP701471P0F30/050X901H<2P0I3@d05PX:
01@8200201D92@0=01@8200E2@T050P801@8200C1`L050P801D92@0B1PP040@601P<3P0@10H05PX<
01P<3P0201/?4@0K01T=3`0G2`d05@T;01@82P0@10H050P:01X>400G2`d04`L901@82P0B1PP05`/=
01H:300C1`T040@601451`0C1`T04@D701L;3@0A1@L05@T;01451`0@10H05@T;01H:300B1PP04@D7
008050P:00D04@D701P<3P0E2@/060`>00l31@0201@82P804`L90P0B1PP01P0H30`04`L700l30`0H
30`04PL701<71`H04PH600d05@T;01451`0G2`d040H7024G601?ADH0Fe5B00d3100W7Ah040D601P<
3P0:00004`L9008050P:00D03`<50186200J3Q004`L901H:300201D92`0300`00P0H30`050X90080
4`T801D050X901D;300F30d08aTJ01<8300=0PH03`@801052@0>0`L0200101452@0E1``02`0101T8
3P0E1@X04P<80104200B2P/0100000<0000C2`d00P0D20X0400C1`T04PH80186200B1PP05PX<01T=
3`0E2@/03`<501041P0I3Q002@0001L=3P0?1@H050X;00d10`0G2`d201<72@0=0186200A1@L04@D7
0186200<0080304200l31@0=0@<04PH801041P0F2P`0Cd=507eaL`0201451`0K01@61P0C1@D04`D5
0184100C1@D050H600l10@0J30`03P4101L92@0>00004@<301D71P0D1PD050H601<51@0D1PH04`L9
00d3100?1@H05P/?00H0000D2`h03`L900T00@0Q5AT03`D700804@D900T05@T=00X00P0J3Q805PX>
00l31`0B1PX04@D900l31`0@10P00P0A1@T0100@10L03`<501451`0A1@H201451@0301461@0A1PCo
oooo01?ooooo000Kooooo`0401482@0C2`/05`h?00l61`805@`=01L05Pd>01@;300C2P/04PT:01@;
300I3a4050L=01@7300J3Pl06Ph=01D:1P0G3@H050X301P=2@0F2PT04PH801<7300E2@d050X801D;
2@0F30X05@/901<91`0201881P0601<91`0D2PP05@/901@:200D2PT04@D70P0D20X03P0C1`T050P:
01D92`0E2@/050P:01451`0E2@/04@D701L;3@0C1`T05`/=01451`0S5aT05PX<0P0A1@L0;`0E2@/0
5`/=01L;3@0D20X05@X<03hd=@0A1`P0CTA501lE5P0@1`P05@/<01<92P0F30d05@/<020F5`0T6Q/0
60h?01<92P0?1@H050X;01L=3P0D2P/04`T:01T?400<0`@07Q@E01T?400:0@804`T:01/B4P1OEEH0
5`d>02DK700>10D04PP901P>3`0F30d05@/<01P>3`0C2@X05P/>01D:3P0L4AD050T=01T>4P0E2Ph0
5``@00805P/?0P0H3A4201H;3`0601L<400C20`06a0D01H;3`0D2@d05P/?0P0D2@d02@0F2`l05``@
01H<400E314050hB01D?4`0A2`l05@lC01@?4P0201TC5`0402LQ9@1XHVH0>C<g01@>4P805a8H01/0
5Q4G01@?5@0E41H05A0F01XE6`0H4aT040/A03Td>P0H4aT05Q4G01PC6@0K5Q/06QDI01PC5P0O6a`0
71PH01/G5`0K5aH071PG01dI600P71`08A`N01/J6P0R8B408B0O01`J6P0L6aT00P0R8Al0CP0P7ad0
8b8P024P7P0O7Q`08b4R020M900R7bP08AhW01lL8`0O7R@08B0V02<S:00Q8RL08b@X028U:P0P8bL0
7B4S024U900P92<08BDT02<W9P0T:2L09BTX02L[:P0T:2L09b/Z02HZ:@0[;bl08bTY02D^;@0V<2l0
<3Xi02`f=`0[=CH0:38c038l?P0`>S`0;cTk034j?`0e?T<0=Sm403Q2B@0e@4H0;STo03Q2B`0f@d/0
>4E=03U6C`0iAe80>dUD03M5D00iBU@0@4mG04EBF011CU@0=T=:03E2BP0iATl0>TI@03]7D`0hA500
?TYF03U5D@0e@Dd0?T]H04=AGP15Df00@DmL04=AGP13DE`0?deH041>F@13DEX0AeEN04IDG@14DeX0
@U5G049AE080@e9E00<0@U5D04ACEP12DE@00P0oCU43041?DP80@4i?00@0?de>03e;C00oCDh0A59C
0P16E5D204MEEP0X04QFE`1;FEX0@E5@04=CDP15EED0B5QH04eLGP1BHF@0BeYO055PI@1<Ff80Df5Z
04]IHP1CHF/0CE]N04iLG@1@GUl0CE]L04UGF014DU<0BEMH04IDE@15De@0BUQI04]IFP16E5D0EVIU
04mPG01CIV80DVEQ05EYI01;H5/0E6QS059UH@1@Hel0DFAP05AUHP1FIV<0E6=P05]ZI`80D5mL02d0
GVeZ05QWI01BHEh0E6=P055PG@1>GEX0CEaI051OG@1@H5l0C5]M055PH`1BHF@0CeiQ059QI01PKg@0
CeiS04aKH01AH6D0CeiT04YIH01:Eed0BeUM04YHF`16E5@0@U1@045@C@14De00@U1A04ABD`13DE@0
A55G041>DP10CU00@4i?03e;C00jB4T0?4Q803e9B@0h@T<0=d5003U3@P0j@d80>T=003a5@P10BDP0
0P0a>ST06P0i@D<0=Si003a4AP0i@D@0=Si103Q0@`0c>T00:S4g02Ta=@0b=ST0;S8e02/_<P0a=3T0
<3<h038e>`0_<ST0;c8k030c?00_<S/0;C0i02X/<P0X:Bd0:R/_02<T:00];S80=CHj0P0Y:Rh202`]
<@80:BX^00H0:R`_02@X:@0V:R/0:Rh_08>7R00[;c0202<W:00_02X^;`0/<3409RX[02T];P0/;S@0
:2Pb02TY<`0Z:S<08b<[02@T;00Y:C008b@Y02PY;@0Y:Rh092DY03Hg>`0`;cD09B@Z01lN900[:S00
7QdS02@S:@0O7R@07QdS02/Z<00W9Rh08R4Y02DT:`0O7B008AlP03Hd=@1=Bd`05aDF01dK7P0K6A`0
7Q`O020N8`0L6Ql07A/P02DS:01:ADT0:RHW01TE5P0V8R<08AdN01hJ6`0S7b000P0M6AX00`0N6Q/0
6QHG01dI6P0601/G600601LC500N6Q/0Ad=402<O800K5aP05Q8C0P0I4aD201XD5P806aDG100J51H0
400I4aD05a8C03@_=@1THFH04@lB01DB5@0J61X0:2HW01DB4`0E4Q8051<A01DC4@0F5A8061DB01D?
3`0F410201LA4@805Q0@00<05a4A01H@400E3`l00P0F4100200G4A4061<@01PC400G4Pl05Q4>01PC
400I51406aHC0P0I51404`0J5A8061<@01HA3P0J5QD07QXI01PD4`0P71/0:RHU02HR8@0I5A@06QHE
01hJ6@0L61L061@C01PF500K6A`061HI024O8P0H5QT00P0Q7b802P0N71l07adP02@R9@0N71l071XM
01`L7P0K71h07QhP020P8P0N7b4201`M7`0F01HG6@0@4A<06a`N01XK7@0K71h0ATE6028N7`0D4A80
6QTI02XZ:P1TI6@0G5aL01/J6P0D4A805a0B01T@4`0>1@L05`d>01@:2@0K4A005@/:00h40P8060h<
00<050X801D;2P0F30/00P0B20L00`0D20P04`L701<71`0201861P0301@8200@10@04@D500@04`L7
00X03@<401<92P0D2P/04PP901D;300G3@h0718C01L=3P0A1`P04PP90P0E2``0100C1`T04@D701`@
4P0O4aD201<72@0401D92`0C1`T050P:01@82P804`L901P04@D701@82P0C1`T05PX<01<72@0@10H0
4PH801<72@0D20X04`L90186200@10H03`H701D;300?1@H050X;01071`0L4Q<08ALH00l51P0E2``0
4PP901482@0H3Pl201451@804PH60P0C1`L04P0A1@D04PH601861P0M4A406@d=00h30`0F30d050X;
01/A4P0H30h040D604Di>`0J3Q004`L901L;3@0@1PL03@<401D;30H04`L900<050P:01<72@0E2@/0
0P0C1`T06P0C2@T04`T701@:2@0C2@P04PP701D;300F30d03PD601872`0F2`l04`P<00l4200B1`/0
4@H:01452@0C1PX05PL<01D42P0B0PL04`@901862P0A1`X03PP:00`82@0>1PL04@D70P0B1PP201<7
2@0301D92`0F2P`05@T;008050P:00<05`/=01H:300B1PP0100B1PP01`0C1`T040@600d3100?1@H0
40H700l51P0@1@H01P0B1PP03@0C1`T05@T;01D92`0D20X04`L901430`0H2PX04`D500h10@0E1`L0
4`D50184100C1@D00P0F20P04`0E1`L04`D501@61@0F20L05@L701@61P0G2@T04@D701<92P0@1PL0
50T=00l62@0A20/050/>01@8300E2@d050P<01862P0D20`00P0C1`/02P0A1@T05PX>0105200C1`/0
3@<500d21@0A1PT05PX>00`1100E2Pd201D92`0501@82@0C1`L04PH60145100@1@<05?ooool001_o
oooo00<06A0C01D<3`0>1@P00P0C2Pd04`0G3Q40=2/^00`51P0<0`H050/>01H=400<0`H040@801X>
3`0D2@L0304001470@0L4PP06Q0601X@1`0A1P005@X901P<3P0C1`T00P0F30X201L=2`805P`:00@0
40H401471@0A1`D04PP60P0A1`D0100C1`T05`/=01L;3@0D20X20186200;01@82P0C1`T04@D701H:
300@10H05@T;00l31@0H30h04@D701@82P0@10H00P0C1`T201@82P805@T;02003`D602TO800:0040
3@D501hD5@0I3a005P`=01882@0C2@X0308301<92P0I3a0040H701@:2`0F30d050X;01882@0D2P/0
60h?01L=3P0>10D07aDF01061`0O5AH060h?00l51P0700005`d>01882@0J41405`d>01P>3`8040H7
01D06@l@01@:2`0D2@`05P/?01T>4P0H3A40:b0T01T>4P0K41@05``@01H;3`0L4AD07Q<G01T>4P0?
10P06@hB01D:3P0H3A405P/?01@93@0F2`l00P0D2@d03`0F2`l05``@01H<3`0@1``06A<G014;3`0;
1@T04@/?01TC5`0G4AD071HJ00l93@0G4AD04P`@01<=4@0401D@5P805Q4G04D06aHL01PC6@0B3A<0
6A@J01HA5`0I51X06QDK01TD6@0S7R805Q8C01/G5P0M6AH07a/H01`H5P0I5A@06ADF01hI7@0Q7280
7adR01dL8@0M7Al07QhN01hN700M7QT071dH01/L5`0Q8Qd08R8P01hN7@0O7b408AlT028P9`0Q82H0
7ahT020O9@0R8bL08b@X02DY;00V:R/08bLY01lS900O8b808RLR024V8P0R9b<092TU02DY:00V:RT0
8bLV02X^;`0]<C809b//02hb=@0Y;S40:C8d02<];P0M9bP092h_02dg>@0Z=3H0;CLi02hg?00_>3d0
<S]003<l@`0d?D@0B5=I04MBF00b?D<00P0iATh04`0a?TH0=TA=03Q6D@0nCeT0DF9/0352C00jBU00
=dI903Q7C00iB4h0?TaE03a:E@0e@dl0?4YG03Y8D`0hAU00?4YC03Y8D@10CUX00P12D5d05P15Df00
BEMT04ABG@0mBeH0@DmJ04ECG018EUl0AeEN04ACFP11D5D0?Te@03e<C`13DUD0AeII04ACEP17EUT0
?diA03U8B`1GIVT0IgIi049AE00nC4d203m=CP0303i<C@0oCDh0A59C0080B5IG0P17EEH04`18EUL0
BEMH04eMG@1?Gel0CeiQ04MFF@13DUL0AeIK06MfO@1KJW40D5mV059QJ01KJW40EfE]055OHP1AGf00
D5iO04eKG01;FEX00P18EUL08`16E5D0A59C049@D@12D540@e5B055OG`1AHEh0E6AQ055TH01?Heh0
BUmJ04mTG`1;Ge/0BUeI051PG@1CHUl0DV5N06=aL@1EHf<0CeeM059PH01=Fe/0C5YJ04mMG@1AGel0
D5iN04iLG01?GEd0DV1P051PH01:FE`0CEaO051OHP1>GF00CEaO0080CEaQ00/0CeiS04aKH018Ee`0
C5]P04mLHP1:F5`0A59E049@D011Cdl0@U5>04ACD00204ECE00404MEF01CH6H0?D]>03i<CP80=TA5
0100>4I603M3@`0c?cl0=T0o03Q2@@0`>cL0>T=0045:A`0i@Sl0=Sho03e5A`0e?Cl0@TY<038j?@0m
ADP0@TY=0P0j@DL0100c>T009bhf02@[<@0^<CH202d`=@0302HY;P0Q92/0:Rde0080;C0i00/0;c4l
02d_>`0W:CD092H]02DV:P0Z:bl09RL[02h_<`0d=CT09bP/02HW:`0202TZ;P0^02HW:`0U9RX092HY
02L[;00R9RL0:Bd^020T9@0X;2d07b<T02P/;@0[;c0092PY02/_<00Z;Rl09BL]02TY<`0Z:S@0;2`e
02LW;`0X:300:R/a02X[<00Z:bl09BHZ02@U:@0X:Bd092<X02/[;@0P7b@0<2ld020O900Z:Bh09B@Z
01/J800Y:2h0<C0h02`[<`0S8RT07A/P01lM801_KG00VINJ03/i?00K6A`06ALJ01`J7@8081hQ00h0
71XM01LE600B3Pl05Q8C01lK700L61T05a<D01lK7014@4409b<T01/G600S7b006ADF028N7`H06aLH
00H06QHG018>3`0Y9BH07ATJ01HB4`0P71d201PB50806A<E0P0J51H201TC5@0@01XD5P0I4aD0618D
01LA4`0F3aH050hC01/F6P0H4QH04@/>02@P8@0J51H06A@E01LC4P0H4Q8061@B01TD4@<05@l?00H0
50h>018<300A2`/05a4A01H@400E3`l201H@400301LA4@0H4a0061<@00806A@A00<061<@01LB3`0K
5Q<00P0J5A802`0L5a@06A@A01LB3`0@3@`04A0>01HE4`0W9R@09B@R01HE4`0J6AL06APF008071/I
00P06aXH01hM6`0N7B005QHH01DE5`0C4aD0:2PZ024Q8`809BDW00@08R8T02HV:00V9RP08R8U0`0M
8B@301`P8`0C01TM800N8RD0720S01PL7`0L82<08R4S020L7@0R82406APH06][J`3Adm80/K:b01dM
7@0@3Pl03PT;01P?4P0O51P05P`>01`B4`0201D;2P0501lE4`0C2PH05Pd801<:1@0B20H00P0A1`H0
0`0L4Q<05@T901D92@0201D92@0501H:2P0H30`04`L701<71`0D20P00P0C1`L04`0B1PH050X;01H<
3@0D2P/05@/<01T?400F30d03P@50147200E2``050X;0147200?1@H06Ph@01451`0?0`D04`L90104
1P0E2@/00P0D20X01@0C1`T05@T;01H:300C1`T07A4C00805PX<00@0300201@82P0C1`T04PH80`0C
1`T0100B1PP04@D701@:2`0@1PL201@:2`0801`C4`2KTI80]jf^02dS900E2``09A/L01T?400G3@h2
01451@804PH60P0C1`L04P0>0P804`L701D92@0J3Ph060`<01861P0:0P808QPI00h41@0=0`@05PL:
01D62@0D1@P06@d?028F600I3a003PD601<92PH04`L;01l091PL02/O8`0J3Q802`43020D600J3Q00
3`D301@:2@0E2`X04`T80147200B20T07aDF01H;3`0?10P0304501872`0E2Ph04PL;01452@0C1PX0
5@H;01@32@0C0`T04`@90104200?1@P030H800`82@0@20T04`L900<04PH800P04@D701041P0@10H0
4@D701041P0A1@L050P:01H92P8050H600L04`H601861P0B1PH040D400l5100A1`H040L600803`L5
00<04PL70186200B1PP00`0B1PP00`0?0`D040@601451`0201451`0301041P0C1@D04`D500804`D5
00@050H601D71`0D1PH05@L70`0F20P0500E1`L03P0001@61@0F20P04@<301<51@0B1PP060h?00L0
000@1@T01P0001H=400?1PT040@801@8300F2Ph040@800h21P0C1`/060`@0P0>0PH02`0;00<050P<
01452@0R5QX05`/?01hB5P0@10P04PH900P0000B1PP04PH700804PH600<04@H501461?ooool04ooo
ool001_ooooo01T060lB01482`0B2@`02`8501H=400Q61/0=Rd`01D<3`0H3a803`H901072P0G3Q40
40H701H;2P0A1P804@L001P>0`0G3P0060l001/A1P0E2`805``901H:2P0=0@405@/900805P`:0`0G
3@/0100C2@L050X801@:200D2PP201<91`0>01@82@0I3@l06@d?01D92`0A1@L040@601L;3@0@10H0
300201@82P0B1PP060`>01@82P0G2`d301<72@805@T;0P0C1`T04@0D20X05@T;01H;300:00404`T:
01P>3`0J41405P`=00l51P0D2P/06a4B00l51P0@1PL05`d>01061`0D2P/05`d>00804`T:0P0D2P/0
5P0J4140200001hD5@0?1@H0718C00d3100O5AH040H701@;300<0P<06a4B0147200H3Pl05P`=01L=
3P0J41404PP901@9300=0PH04`P<028G6`0c:2`201P=4@0701<8300A1PX060dA01/@500F2`l03P<7
01X?4`0201@93@0901D:3P0D2@d05@X>01@93@0E2Ph05``@01P=4@0F30l03PD:008050hB00T08A/O
02XT:01<ATX03@L;01LA5@0P6Qh06A<G01XD600G4AD00P0D3aD03`0F4AL05a8H01LB600G4QP05Q4G
01XE6`0O6R0050lE01TD6P0F4AL08QdS01PC600S7b005a<B01`H5P0201dI5P0I01`H5P0J5QL06aHJ
01dH7@0L6B007Q/R01dL8P0L6b0071`N01/K6@0J6aH07b0K01/L5`0M7QT07alM020P7`0S8bD08R0U
02<Q:00R8BL081lU028R9P0T9BT08B8U02L[;00202``;`03028V9@0L8Ad092TS008092TU02d09R/W
02P/:`0X;2/09RXY02P/;@0Z;Rl09RX[02hb=@0Y;S40:S<d02dg>00V<340=d5202li>`0Q:bd0:S@f
02df>`0_>3d0<S]003<l@`0b?D<0?DQ>041;D@0d?dD0>4E=03M4C00d@DT0>TQA04=DGP0jBeD0L86;
041AF`0lC5<0>dY=03]:C`0lBe40@4iG03a:E@0e@dl0?D]H03Q6D`0nC5H0D5iW04UGH015Ded00`18
EV<02@14DUl0?D]F03]9E012D5/0AUAM04UGH017EEh0@e9I049AE@02049AE00404EDE`14DeH0@4mB
03e<C`80>TU<00D0A5=F04UHF`10Ce80?de>041>C`02045?D003049@D@16E5D0B5IG0080AeEF0P16
E5D02017EEH0?Te@03]:C`0mC540@e9G04MFF`1AH6D0EFA[0P14DeX02@1FIF`0MXF<07b;TP1BH6<0
DEmP04iLG@1<FU/0BeUJ04YHF@0204ECE00F04=ADP11Ce00@e5B04QFEP1=Fe/0DV5N04mOG01AHEh0
C61K04iSGP1=HUd0B5aH04YJE`1?Ge`0Df9O051OG01EHf<0B5IF04eKF`1JJ6P0CeeM05ARHP80D5iN
01L0CeeM04iLG01?GEd0D5iO04iMH01:FE`0C5]N059QI01CHVD0D5mR04UHG@1:FEh0CEaQ04YIGP17
EU/0CUeR04aIG`1>G600@e5D03Q6AP11Cdl0C5]H03m>B`0204IDE@0<03M5B015DUP0>4I903e;C00g
ADH0=TA503I4A00e@D40<clo02Pb<@0jAD40?4M30`0kA4407`0d?Cd0?4A603<k?@1:DU@0@DU<034i
?00oAdX0>T5703U0AP0`=cd0:2lg02Xa=`0`<cT09BP]03Lj?`0[;S<092L^02X]=@0Z;CH0:bhg030b
?@0_<Cd0:B/g02HX;`0X:Bd0;2da02TZ;P0/;C40;c0d02HW:`0Y:Rh00P0/;C400`0Y:Rh0:2T]02DW
:P0202L[;00i02P/;@0B5QL0;C4b02DY:P0V:R/08RHW024U9P0X;2d0:Bd^02PZ;`0Y:C<0:RXd02d]
=P0Y:C40:b/c02//<P0/;C80;2da02TZ;P0/;C40:b``02PX:P0W9bT09RHX024P9@0K6Ql0>cXo02HU
:`0H5ad07ahT02@S:`0U92`08R4X01/I7P0R82D09B<W02XX;@0H5QT071XM01dK7P0K6A`06QPK01`J
7@0M6a`06aTJ02@P8@0S7b007QXK01/G600M6AX06aLH034];P0O6a`071PI02DQ8P0M6AX071PI00H0
6QHG00<05A4B01dI6P0@30d00P0O6a`00`0E4A806A<E01TC5@0401XD5P0>01PB500I4aD06A<E01TC
5@0H4Q@05a4C02@M900L5A/050hB01H@500D3Q405Q0B01XD5P0I4a@201LA4@0301LB400G4Pl05Q0@
00805a4A00H05Q0@01@>3P0D3Ph05a4A01H@400E3`l201H@400E01LA4@0G4Pl061<@01XE4P0K5Q<0
61<@01HA3P0J5A806A@A01XE4P0K5Q<06A@A01HB3`0H5Q@06aXH024P7P0];2X08R4O018A3`0J6AL0
61LE008071/I00<07A`J024P7P0I6A/00P0S8bD00`0G5aT0;Bd_01LG6@0201dM7`0501PH6P0R8R@0
9BDW01lR900O8bH00P0N8RD06P0O8bH082@W01lS9P0R9RT0;c<f01lS9P0F6Qd07B4T01`L7P0D4Q<0
7Q`M01`L700b<S80LG=b06a]K00?3`l04a4B01XE5P0H3a8060dA01H<3P0M4a@04@L801P>300_9B<0
6Q4<0P0D2`H02`0F30X05@/:01H<2`0U6a`04PH601451@0B1PH04`L701D92@0G2`/050P800805@T9
00<050P801<71`0B1PH00P0F30d0100C2@X050X;01L=3P0B20T201lE5P0E01T?400@1PL03`D601@:
2`0H30h04PH801@82P0J3Q005PX<01<72@0H30h05`/=01<72@0D20X05@T;00h2100V6Q`03`<50186
200G2`d040D600H04`L900d04PH801061`0D2P/040H701882@0]8b@0`[Ri0=_AdP0d:R/02@0001T?
400A1`P0308300804@D50P0B1PH201<71`0B00l30`0B1PH04@D501451@0B1PH04@L601492P0N51D0
4@L801451`0L3A003@0101D62@0Q4QD09a/M01dC500A20T04`X;1P0C1`/01`29OH40XiNK01lC5`0I
3A407a<G00P0000@1PD00P0D2PT01@0C2@P04PP901<92P0>1@H06PlC00803`@800h05@X>01052@0B
1`/04PH:01<62P0D1@X050<901D52P0C10T04@D901882`0=1`T030P901492`804`L900X04PH80145
1`0A1@L04@D701<72@0B1PP040@600h2100?0`D04`H70`0D1PH201861P0701871`0D2PT05@/:0148
1`0>1P@04@T701<:2@06018620D04`L900D05PP80184100C1@D050H601430`0201@61PD05@L70200
4P@301X<2`0K3@d04`D501@61P0D20X0718C01<92P0Q5QX06A0C01P?4P0?1PT05@T=01<72`0B1PX0
40@801452@0G2`l03P8601T=4@0M4AD03@4500l41`0G2`l03P860106200A1@T02@0101472@0E2@/0
4@D701451P804@D500<04PL601871Oooool04oooool001_ooooo00@03@L9010:300_:B/02P@60P0C
3@l0500H4Q@05@lA00`6200;1@L04P`>01082@0B20P050T701@:100H3PD0:R4@03`c800a:AL07QD5
01H<0@0K40X05`/:01871P0E2`L050/60P0C2PD301@;1P<05@`700<04`X501<91`0G2``00P0J3Q00
1`0F2P`04PH80186200C1`T050P:01H:300L41800P0@10H0200G2`d03@<401<72@0D20X05PX<0145
1`0F2P`050P:0P0C1`T01P0E2@/05@X<00`3100I3a006A0A01X@4@805@/<01X04@L801P>3`0G3@h0
718C01X@4@0<0`@05@/<01L=3P0B20T05@/<01@:2`0?1PL06@l@01061`0H3Pl04`T:01882@0F30d0
4PP901H<3@0A20T081HG01H<3@0D2P/07aDF01dC508050X;01<05@/<02HL7P0I3Q805P/?01<8300B
1`/05@X>01H;3`0C20`04@H:01@93@0F2`l05@X>01P=4@0M4QH06@hB01hC5`0K41@06@hB00805@X>
01805P/?01T>4P0I3Q805P`?01P?500B31005@lC01PB5P0<1`X071HJ01PB5P0B31005@lC00`62P0C
3A40618F01@?5@0E41H301PC6@1Z01LB600I51X05a8H01`G7@0K5Q`061<I01XE6`0M61h05A0E01DA
4P0F4Q407Q/H01hK5P0I5A806aLE01hJ6`0O6Qh07APN01PE7@0L6B<07ahV01dL8@0H61X05QHD01TJ
5@0L7AL071dH02HW8P0Y:BL08R8Q01`L7P0Q82D08b8W028Q9P0Q82D08R<V02DW9`0Q9R@07B8O020U
800V;BL09B/V024X8@0S:2808RLQ02<X8P0T:BD09RXY02L[:P0f>ST0:Bd^02L[;00W:bh0;S8e02H[
;P0X<c<0<3`l01dY:@0]>3X0:SDg034l?P0Z=CT0;3Lk02hi?@0`>d40<Ca2038m@`0`?480<Ci403I3
B@0gA4`0<3m603i=E00nC5D0>DYD03I7D@1KK7H0<dE?03];D00mCDd0>TU<03Q7C@0mBe@0?4YF03Q5
E016Df80@e5N03e;EP1;FF80EVE/05=QJ`15Df00BEMT04MEHP0mBeP0>TQC03m=F013DE`0AUAM04ME
GP14DU/0@U5H03m>DP13De<0AUIF04ADE080@51@00P0A5AD041@D00jBTX0?Ti>04ADE010D500?D]<
03m=CP80@Dm@00@0@U1A04ECE017EEH0AUAE0`15De@04016E5H0IgIl05=RJP13DEX0BEQP04aKH`1?
GVD0BUUP04mNI01FIFX0AUEJ04]JG`1CHVL0D5iP04mMGP1=Fe`404aJF`0?04]IFP18EUL0AUAE04ME
EP1:EeP0FVEU05eXIP1>FeT0E6=P04ULF01?I5l0CF9M04]NFP1<G5T0CeeJ0080DeiL00P0CeaL08VG
U`1LJVX0CE]K05=QH@1:F5P0E69R055OG`80CUaL00T0CE]K04]IFP1<Fel0CEaQ04]JG`1<Ff00CUeR
04]JG`1?GV400P18EeX08P1:FE`0BEQK04]JG@19EU`0AE=G04IDE`19EeP0A59B03m>B`10Cd`0?D]<
045?D00oCE00?daB03a:C@0jB4T0?4Y:03U7A`0c@D40=T9003Q4@P1DGUd0=3lk03U4@00h@Ch0<S/f
03U2?`0h@440<SXl03Q0@P0e?D00>4130418B`0c>T0203Dl@P0:02`c>`0^=Cd0=Se3030c>@0a=3T0
>Ca102X]=00^<CP0;c8j030c?080<C<o04X0;Blk02PZ=P0W:C009RL[02`]<@0[;300;2da030a=@0Y
:Rh0:b``02`]<@0Z:bl0:BX^02X[;`0X:Rd08RHW02da<P0P92D0;C4b02P/;@0S9bP07b<T020T9@0c
=cP0:Rh_02DY:P0[;C<0:2Pb02XZ=00];CH0:BTa02XZ<P0^;cD0;Bhc02X[;`0[;300;Bhb02TZ;P0[
:b`05ADE02PX:00N7R008b<U03He>P0P7bD07A`R028Q9`0K6R808b8Z01HE7@0S82P0:2D]02DR:@0R
7bH081dS02<Q9P0N71l07Q`N01hM7@0N71`07A`I01/J5`0I5AD071PI01/G600J5QL07ATJ01`H6@0H
51D07QXK01`H6@0I5AH081`M01/G60H06QHG00H07ATJ01PD5@0R7Ql0920Q01TE5P0F4Q<401/E5`80
6Q@F01D05a4C01PB500I4aD06A<E01PB500G4A<06a4I01dC6P0?1P/09QdR01D<400I41<06Q4D01T@
4P0H3a005`h?01L?3P0G3`d050h>01D?3`0F4100100G4A406@0F41005@l?01H@400F41005a4A01PC
400F4@h061<@01/F4`0H4a005A0=01PC400G4Pl061<@01XE4P0I51405Q8?01dJ6@0F5A<051<A01TH
5P0L6aT06aXH01TH5P0G5Q@00`0K6QP01@0O7Q`07AdO00`<3P0P82807alQ0080820R0P0U9BL0:00T
92H0;Rh`03<c=@0/;c409R/^02@Y;00P9BP07R<V01lT9`0L8B@09R/^03Dj?@0T:B`06QlR028W:P0N
82807A/L028Q8@0J6QX07AlN02DW9P0M7ah051DE01@B4`0I5AH06aDG00X1100F31006@lA01882@0G
3@/0:AlL01XA2`0D2`@050/501L=2`0D2PX040H701P=400C1`P201861P0301<71`0E2@T05`/;0080
5@T90P0F2PX00`0E2@T050P80147200201482@0:01@;300J4A8060l@01@;300E30d04`X;01482@0B
2@X06A0A01H:30804`L90P0F2P`03P0D20X05PX<01H:300A1@L05PX<01/?4@0B1PP05@T;03<W:@0<
0P<05PX<01451`0?0`D050P:0`0C1`T03P0E2@/050T;0147200D2``02P4201482@0C2`/0:R4R044h
>@0E3@h05@`=01<:2`0B2P/04`T:0P0A1@D201861P804`L701805@T901<71`0B1PH04`L701X>3P0O
5A@0F51@00h51P0;0@804@@601X:3@0G1`X05@D801P9300I3@l050X;00d51P0>1@H601<72`0N02dQ
9@0Q5AT02`4301@9300E2`d060`>01D;2@0D2PT04`T801881`0F30d060h?04@j>`0A20X03`@80187
2`0=0PH04`P<01872`0D20`050H;01<42@0D0`T05@D;01011P0?0`L050X=00/51`091@H04@T;0P0C
1`T2018620804@D700H04PH801<72@0A1@L040@601451`0D1`P201D51P0:01D61P0D1PH04PH601@9
2@0E2`X04@T700d50`0;0`403PT601<:2@D04PH80P0C1`T30186200301<72@0E1`L04`D500804`D5
00<04P@401<51@0D1PH0100C1@D0100D1PH05PP701`>3@0L3Ph201@61P0K0186200?1@H07Q@E00`3
1@0=10L08aXM0:NNX@0W6al060`@00h21P0B1PX04@D901<72`0A1`T06`lC02HJ7P0K3a<050P<00/0
0`0L41@0:QhR0105200D20`050T;0187200A1@L04@D600804@D500<04@H501461?ooool04oooool0
01_ooooo00<04`d?01LA4`0i<cD00P0C3@l05`0?2@/03PP:06IPHP0i<cD04`d?00d72@0Q61T02@00
02PM600V718030<0048j9`2m]Ih0Z:2;04Y1;P0J4@80718:01D:1P0G30P05Pd801<:1@0B2@@040L2
00804@P3100C2PD00`0A20<040H401L;300201T=3`0@01H:300E2@/05@T;01L;3@0J3Q007Q8D02DI
6`0E2@/04PH801@82P0800005@T;01<72@0G2`d03`<501H:308050P:0P0C1`T0:P0F2``05`d>01hD
5@0G3@h05P`=01T?400?1PL09adN03P^;`0P5QL03`D601P>3`0C2@X06a4B020F5`0D2P/04`T:01@:
2`0E2``03@<404To@00[8B805P`=01D;300?1@H01`0001T?400B20T02@000147200L4Q<09A/L01hD
5@0D2P/05P`=01X@4@0b9bX07a@H01462P0F2`l07A8F01872`806PlC00<060dA01@93@0C20`00P0H
3A401@0D2@d06PlC02`Q9@0N4aL04PL;00805@X>01805``@01X?4`0J3a<05P`?01483@0D3Q805a4E
018<400?2@d02P@801D?4`0K5AT06A<G01<=4@0L5QX050hB01D@5P0G4QP201TD6P0=01HA5`0D3aD0
71LM01<>500E41H0=S4g01HA5`0M61h05A0F02HQ9@0@30d061@C01LC3`0201LD3`0N01TE4`0L61T0
7QTM01dH7`0J5b007AXU01`K900L6b406aXO01/K6P0K71L07AhH01`M5`0U9R40:BTW020P7`0H61X0
7ahS024P9@0Q8B<07b0R024R900U9bH08bPU028W8`0N8ad072<K024X800V;BD08bPQ0P0S:280400U
:RH09b`X02L[:P0]<C409BTZ02HZ:`0X;2l0=CPm030e>@0V<C40=41003U5A@1LIfT0;3Lk020[;`0^
>Cd202dh?P0P02lj@00a?480<ci403A1A`0b?dD0<3e303A1B@0gATd0AUEL045BFP0gB580@59L03]=
E`0bA4h0>DY?03];B`0lBdh0=dI<03U7D00jB5D0>4ID049?G`12D5d0?D]F03Y8D@13DUT0BUQQ03U7
E00lBUL0@U1M03i<F@0oCEP204ABG@80@e5J00<0@4iG03m>E@0oCU801@0oCdl0300iBDT0?4a<04EE
E@0lC4`0<41003];B`0nC4d0@Dm@04ABD`15De@0AUAE04QFE`<0AUAE00l0AeEF04QFE`1:F5X0IgEn
051NJ@0nC5P0@e5L04ABF`19Eel0I7=j05e/L@1;FUh0CeiQ04iMH01?Gf00101?GEh204iLG@03059P
H@1?GEh0C5YK0080C5YK01H0BEIF05INH01JHf80BUID05UXI@17FED0B5]G04]NFP1?H5d0CUeJ04]G
E@1>EeH0E5eL05EQH@2>W9d0FVQY055OH01HIVL0CUaM05=QHP1?GEh0CE]L0P1>G5d02@1;FEX0CUeR
05ETJP1>GF80BEQM04YIGP19F5d0CeiQ04UHF`0204YIG00j04ADE@14DeH0B5EK03m=D@12D5<0CeeN
04]IF@13DTl0BUUF051NG`0e@d@0>DM:030m@`0c@D@0=D=403A2@P0c@D40<T1003A0?P0e@Cl0GFQT
030k=`0_>SH0=Slj034j=@0c?3T0<c`l0418BP0j@T@0D5QK03@k@@12BDl0>D16034h@00`=cl0:c8j
02T`>00/<cT0>Ca204I9D024Qhh0<C@k02LZ<`0l?dP0=CQ103HhA00`<Sh09RPd02DW<`0Y:c809BHZ
02X[;`0/;C40:b``030a=@0[;300:R/_02PY;@809BHZ03d0:BX^02X];`0P92D0;S8c01lS900]<C80
;c<d02<W:00Q9BH09BTZ038f=`0X;2d08bLX02PZ<00V9S00:2Pb02XZ<`0U9Bd09bL_038c>@0/;C80
9RL[02TZ;P0V9b/09RLZ020P800b<S00>CTi02DU9@0B4Q80820R01PG700N7B8081lU01XI8@0d<c/0
61LO01lL9`0W92l06QLQ00h;500O72<081hS01/I700M6a`07adM01/J5P0J6A@07ahI01XF5@0M6AX0
8QhO01hJ6`0H51D06ADF01XF5`0N6Q/071PI01HB4`0K5aP07QXK00H06ADF00H07ATJ01PD5@0_:b`0
IF5R01hJ6`0I5AH201TC5@80618D0P0G4A<00`0E3a405a4C01PB500301PB500801H<500D2A007A8H
02DJ800J3a@07Q<G01T>4P0I3Q4201P>3`0401X@400I4@l05Q0@01H@40805a4A0P0F41000`0G4A40
5Q0@01D?3`0201H@400?01LA4@0G4Pl04Pd:01<>2`0H4a005a8?01<>2`0H4a005a8?01TD4@0K5Q<0
6QDB01LC400D4Q006APF00807ahL00h061LE01DD4P0I61H06APF01dL6P0L6aT061LE01/J600G5aT0
=SHh05eMG`0`<380:b/]01`L7P807AdO0P0R8R@02@0U9BL0:B`^02P]<@0V:bl092T]028W:`0Q9RX0
82DY02H[;`0202DZ;P0L02@Y;@0P9BT0=3Hh024O800B4Q808b@T014C4P0?4a806QdL01HH5`0V92D0
5Q8C01TC5@0G3Q406@lD01H;3`0I3a0050X901480`0E30H04`X301480@0D2PP05`d>01H<3@0J3a<0
5PX<01H:2P805@T900`05PX:01L;2`0D20P05@T901H:2P0G2`/05PX:01H;2P0A1`P050/<01892P0>
1@H200l61`0601482@0@1`P04PT:01892P0@1`P030<40P0D20X00`0@10H03@4300l31@0201D92`0M
01L;3@0C1`T06`lA02DI6`0I3@l081@F04Tm?`0H30h05PX<01L;3@0A1@L050P:01<72@0B1PP04`L9
01D92`0E2``081HG00d51@0A20T0200001<:2`0N5AH05Pd>00`3100;0P<02P4201892P0600000P0A
1@D201861P804`L701805@T900l30`0B1PH04`L701@8200I3`h04P/<01H=3P0X7Ql05PP;00/0000A
00806@L;01<41`0B1PP05P`=018<300@1`P601<72`0O01872P0C1`/07a<G00h21P0K3a<05`/=01<9
1`0D2PT04`T801881`0D2P/05P`=01H>3P07000040D901T>4P0<0@D04@H:01872`0E2@d04`H:0142
1`0D0`T06@T?01<42@0>0PH04PP;00X41P0<20T04`/=01451`030186200301<72@0A1@L040@60080
4PH800<040@601451`0D1PL00P0E1@D01`0E1PD050H501871@0B20H040H400h60`0?2@D00P0@2`L0
0`0A20P04PH8018620040186200U01451`0@10H03`<501041P0B1PP0408201H8200D1PH04`D501/=
3@0J30`05@L701@61P0C1@D04P@401<51@0E1`L04P@301H81`0E1`L04`D501D71`0A1@L01`0001D;
300E2Ph050/>0189301TFeh08aLK01D93@0@10P050P<00l31`0B1PX07a<G00d21@0200P0000:01@8
300B1PX02P0204/o@`0[7b<04@D900l51P0?0`D04PH801861`8040@400<03`@300h30Oooool04ooo
ool001_ooooo01/060lB01492`0U71l030<600l82@0F3A004PT<07U`L`0n=CP06a8E01092P0B2@X0
5P`;01dB3`0T6Q409A/?081hIP3oonX0oo[U079YE`0Q5`/06a4:00l40P0B1`D060h<01@:2@0B20H0
0`0@1P@401@:200501881P0A1`D060`=01T=3`0H30h00P0F2P`01P0G2`d060`>01041P0?0`D06Ph@
0186208050P:00D02P0001T=3`0B1`P060`>01<72@0201D92`8050P:01804`L901872@0^92D02P01
01@;2`0C2@X03@<401T?400D2P/07Q@E01D;300C2@X06@l@00l51P0O5AH0:1hO01H<3@0@1PL201D;
300S030V9`3?aLH0OgEf0147200B20T04@L801L=3P0R61T0718C00l51P0M4a@03@@501X@4@0F30d0
4PP901@:2`0A1`P04`P;01462P0H3A004@L801X@4@0E2``06Q0A01`B4`0K41@04`P<01872`0I3Q80
6a0D01@93@0Q5QX0>Rlc02@I7@0B1`/00P0E2Ph0@@0G31006PlC01T@4`0E2`l050/@01dG6`0H41D0
3PD:01lI7@0J4QL02`8701dG6`0E3A803@@901`F6P0E3A805a0G01PA600K51/06Q<J01LA5`0C3Q@0
6A@J01@?5@0K5Q`0CdY@01PC6P0J5A`08A`R04<n@`0Q7Ah09B4P01TF4P0I5Q4061D@01TE4`0J5QL0
6aHL01hH8@0M6R<07a`W01TH8@0J6Al0820R028R800L7AP09bPR01/L5`0J6QP07QhN01hN800O7R<0
7QdR020O900P82807b0R024R900T9RD08RLT030e<@0]<R`07R@N01hS7@0T:B<0:2`V0080:B/V02d0
:RdZ02`^:`0[;bh08bLX02L[;00]<C80<CDh04A7C014BDd0;CLi02La<`0H8bD0=T5402Xe>@0oBTh0
<3/o02dh?P0/=cd0;STo034l@P0a?T@0=T=903E2B00X=C/0<Sm703m>E@19Ef00?DiG03m@FP0oCe`0
?4iJ04=CH00iBDl0@51@049AE00kBU00>4I?03Q6D@0hAU@0=dEB03I4D@15Ded0?deF0350A`0hAe00
0P0e@e006010CU/0@DmJ03m=F013DEX0A59K049@F@10CUL0?deF03m>E@12DEH0?diA03]:C@0lBdh0
?Ti>03]:C@0mCDd0>d];03I6AP0lC4`0@U9B03Y:BP0iAdP0?4Y;041>C`80@Dm@01D0A59C04MEEP17
EEP0B5II04UGFP1:F5/0CEYO07>1S01OKGX0CE]X04aJI@18EV40CE]T04ACFP1CHVT0Df9W05UXK@19
F5d0CeiQ04mMH01@GV400P1AGf809P1@GV40D5iP051NH@1<FU/0BUQI04mMGP1AGf00BeQH04I?CP1?
F5L0AE5?05UXI@18Ee@0AeMD04]KF01AH5d0CUeJ04UED`1:E5<0DeaK05MSH`1@GUh0@e5A05]YJ@1:
F5T0C5YK055OH01=Fe`0C5YK04iLG@1@GUl0CE]N04EDF@1@GfD0BUUN04=BE`16EEX0B5ML0P1;FUd0
9@1=G5l0BEQK045@DP10D500AUAG04QCE`10Bdl0@4]=059NGP1OJfT0Kg]k08^FV01@Fed0?dY>03Q3
A`13CU80=40o02hj>00_>cT0=40n03@n?@0a?3P0<Sdi03Ho?00g@3d0=Slk03@m>P0c?3T0=d1105eU
I`0mAdP0Ri>F051GG@0f?D<0<STo02H]=@0Z<CT00P0c>T803P0d>440=CPm01hO9015B4l08bH]02P[
=00_<S/0<SDn03Dg@`0]<C`092Pa02HZ<`0]<3H0:2T]0P0[;3004@0X:Bd0;Bhb02//<00[;300:2T]
02@U:@0V9b/0:b``02`_<@0R9RL0<3@e02P/;@0Q9BH0?d=402/_<00V:R/08bLX00808BDV034092PY
02LY;P0V9Rh09bLa02PX<00T92`09BD]03<d>P0Z:c0092DY02//<00U9RX0:BX^01TI6`0f=SH07AdO
030`<P0L71h06aXO01hM8P0S8RP07A`R01lN9P18Adl0;B`d020M:00H5B009B8[02HS:P0L6B006ALK
01/I700K6AX05aDE018A3@0H5a<0:RTU02LS900K5aP05a<D01lK700M6AX06aLH01TE5P0E4A8071PI
01lK700G4a@06aLH00H06ADF00H0<2`]01/G600I5AH0;BTZ01HB4`0L61T201LA4`0601H@4P0E3a40
5@lA01@>400E3a405Q0B100H4Q@02P0Q61d0718G01/B5`0;00H07Q@H01482`0I3Q806@lA01P?400J
414201/B4`0401/E5P0K5AL06Q@D01XD5@<05a4A01D05Q0@01D?3`0F41005Q0@01LA4@0H4Q4040/8
014<2@0G4Pl05Q4>01<>2P0I514061<@01TE4P0L5aL06aDE01PD4`0M71X05QDC01LF500L6aT00P0K
6QP0300J61T06aTJ01lM7P0M6a`061HG01TG600N7R003Ph@03`l?P0V9RP06a/M02XZ;P808b@X02X0
:R/_02@U:@0U9RX09bX^02<X;00T:Bl09R/`02L/<00X;C<0:Bhc02T^<P0L8BL092T^02H[;`0I7R@0
92DZ02@T9P0M7Al07QlQ01lQ800M7ah061TH024Q8@1ACe00:RDW01<:2`0M51L05Pd@01<:3@0N51D0
5P`<00T0000H3`X07A@?01L>2@0C2@P04`T:01061`0A1PX05PX<01H:2P0E2@T201@8200301D92@0D
20P050P800@05`/;00l03@<401892P0E30d04`T:01D<3@0J41405@/<01482@0?1PL050X;01D<3@0D
2P/03P@501882@0E2@/00P0@10H05`0C1`T04@D70186200<008050P:01hB500?0`D060`>01H<3@0<
00805`/=0187200E2@/050P:01<72@0B1PP04`L901D92`0G2`d0DdU:00l51P0K4A804PP900803`D6
00P02`4201H<3@0G3@h02`4201482@0F30/04@D501461@804PH60P0C1`L0500L410050P801L;2`0D
20P03P820104100>1@<040H501861P0E20X05PH901L72P0F1@X03`0300l31@0G3Ph05`l=01482@0C
1``04`H=100C1`/02P0@10P03P8600h21P0G2a002P0401@8300?1@@050X901D;2P0C2@P201882@0B
00h61P0L4AD04PL;00d21P0B1`/03`@901873@0E20l04`D<01422@0C10/07@hC01T:3`0@10P04PP;
00h5200C3@l060lA0P0A1@L00`0B1PP04`L901<72@0201<72@0A01@82P0A1@L03@4300d10`0A10D0
5@D501D51P0E1PH050H501861P0B1PD03`D301471P0H3`d06a<@01P@3P0C2@T01@0B1PP04`0C1`T0
4PH801041P0?0`D040@601<72@0=00005`T901D71`0D1PH08A<C020B4P0G2@T05PP801@61P0C1@D0
50H601L92@0@0P800P0C1@D04`0D1PH060X:01<72@0[7b405`d>01052@0C20`03P<701L<400E2@d0
3@4501452@0F2Ph040@801L;3`0=0@D04PH:01X>4P0A1@T00P0D20`0300G2`l0PGEi05]?D`0D20`0
308401X>400C1`T04PH80104100?0`D03P8200d10ACooooo000Kooooo`0T01461`0A1`P04@H70187
200D2@X0=b`^020E5P0F2`d05``=01H;300C2@X0:1dN05M:D00l<3806Pl<02HK501[HED0dLbl0<k5
]@0n=2P09AXC01461@0I3A003`@9038W;@0]92X060lD01072`0D2`l03PD901<:300=1PL060lA0108
1`0<1@@040L71P0E2@T01`0B1PH04`L701@8200B1PH04`L701D92@0C1`L00`0E2@T201<71`0601@8
200<0P8060`<01@8200A1@D050P80P0E2@T0100G30`081@D01H:2P0D20P201<71`0401861P0C1`L0
4`L701882@804`X=02D04PT<01<:3@090@<05Pd@01D<3`1=A4L0<BP[01<:3@0F3A004PL901P<3P0a
9BL05@T;01041P0D20X05PX<01041P0I3@l07A4C01@82P0F2P`05P/<01H<3@0G3@`05P`;01D;2P0C
2PH050X801@:2@0F30d05@X?01@93`0C20h05PX>01T=3`0H30h060h?00807A<D00P04@P901/B4`0D
2``0614A01H@400F3a005@/@01T?5`806@hF03T0718J01P=5@0C210091XR01P=5@13>400>Rlg01T>
5P0H3AL06@hG01/A6@0L4aP071@H01XC5P0K5AT06Q@I01PC6@0G4QX0618N01TC7P0J4AX08APO024J
700L5QL071LD020K5`0J5Q<06aPG01PF600G5AX06QLP01`I8P0M6R4071TN01XH6P0I5aP06aXG01lN
6@0K6QH08R0O01dK7@0M6al08b4Y020O9`0P7bH07QlS024R9P0N7b<0:R/]02DV:00/;Bh09RPW028T
8P0Q924092HT02DW9@0W9bD00P0T92803@0U9RD0:BTY02X[:`0Y:R`0:2`_02HZ;@0]<C@0<CDh02db
=P0[<SP0:c8i02/c>P0]=S`00P0]=Sd00`0a?480=D98038oA@02030m@`0U02hk@@0b@D@0<d9503A3
AP0hAdd0>4I>03e;E00nC5P0?TaJ03i;F`1:FFT0=T=E045>F00mBT`0>dU<03e:DP0kAe80>4IA03]9
E@0nC5T0>d]H04IGH@11DUX0>4UA03i>F@0fAUD0?TiK041@F`0jBe80AeIM03Y9CP0lBdl0?DY@03e:
D@0mBU80@DaF045=EP0203i;DP0M03m<D`10CE80?daB03i<D012D5<0@DmB03U7B@0kBDX0?de>04UG
E`16E5@0HW1a04aJF`0kBDX0@DmB041>DP15DUP0BEIM04MDG@19EUl0DUmY07F3SP1<FVD0AUAO04mM
J019Ef80CE]V04aJI01WMGl00P1EHfd01@1=FfD0BeUR05QVKP17EU`0CUeS0080CEaR02l0C5]O04iM
HP1>GF40C5]N04MFF@16EEP0B5MG04IAC`1;EU80BEA@04iJEP1:EU80DUiJ05AOF`1<F5@0CeYF055L
F01;EU80BEEA04YFDP19F5<0BEQE04YIEP1<FUT0C5YJ04]IFP1=Fed0CE]N04]IG01=Fel0DUmU059Q
J01;FV40BUUP04MFG@1?GV@0AUEJ04aKH01>GF40AUEH04EDE`1;Fe`0BEMH04A?D@18DE@0Ae1C04A=
C`0204=<CP0]04M@D`1<EEL0@DY<03]4A`0i@TD0<S/m03Dm>00j@S`0ADe703i6@P0b>SH0=chk03U1
?P0j@3h0>3hl03Dk>P0e>c/0=Chm03M2@`18DeD0=D1208bFV`0kA4T0;CHk02lh?`0b>D40<CQ003e4
CP15BE@0BDaE034b=@0a<3D09bL]030`>@0]<3T0;c8m038f@@0e>d@0=Ca402hf>`0Y<CL0:Blb02X^
;`0Y;Bh0:Rh_0080;C4b00@0:2`]02HZ:`0U:BX09BTZ0P0T:2T02P0V:R`07R8U024U:00R9RT0:2`_
02da=00T:2/09RX]02L[;P0X;2l202L[;P0502LZ;P0Z:c009bL^02DV:`0W:2d00P0Y:Rl0>@0Q8RL0
9RL/02X[<00N7b@0:BX_02DT:`0V9B`09B@[01PG7P0M72<0De9I02@S:P0o?TH06aXR01lN9P0/:c<0
8b8Y020L8`0W8RL061<H02<N8`0G4QL07APL01lJ7P0F4AD081/N01XE600H51H0KVY/02PT9@0R7Ql0
7a/L01hJ6`0I5AH06aLH01TE5P0M6AX06QHG01LC500M6AX06ADE01dI600K5aH081`K010<2`0G4a<0
5a<D01PD5@0H4aH09R4U02@O8`0N6Ad050lC01D?4P0J51H071HH01D?4@0201lI6`805a4C0P0F4182
01D?4@0701/E5`0H4A@06A<E01TB500E3Q405a4C01D>400201LA4`0801L@4P0G4A<06A<E01@=4`0B
3100618E01D?4P0F418201PB501<00l92@0F410071HF01XE4P0D3Pd04`X<01dD5@0D30/04`h<01PC
3P0I50h05Q<=01DC3`0D4a4061DH01XF700E4aL0518D020N7`0E4a@081hO01dK7@0J61X06aTL01`J
7P0Q7b<07Q`P01TF700J61h071/P01lN8`0Q8BD08B8V024S:00Q92T08RD[028V:`0R9Rd0:Bde02T/
=00S:2l08bXa02D/=00W;SD0:C0g02T`>00T:c80;3<j02L^=P0mA4/0GfI]02Xa>@0S9Rd071dS01hO
900P82H06a/N020O8P0N6ad07QTK024I6P0N5AD06Q0?01/A4@0I410071HF02<L700J4Q804@T801hE
5@0C2@T05`d=01/A4@0F2P`04`L901L;3@804`L901h04PH801T=3`0P51H0ACTk01041P0D20X04PH8
01T=3`0C1`T04PH801451`0K41409Q/M01@82P0B1`T04@H801D92`0?10D04PL901D92`0@1@L0714B
081eN@0_9RT040L:01hC5`0B1`/04@L801451`0B1@H401<51@0800l30`0C1`L03`<301H:2P0Q5AD0
5@T901861P0E2@T201H:2P805@T91P0D1`L201D8208050L70P0C1PH00`0E1`H05PP501<50`0201@6
1@0O0104100D1PH07@h@02XK7P0G20/05@H901@61P0D1P@05PL501L81`0G1`T05`L<01H7300@0`P0
5PX>00l31@0G3@`04PT501471P0C1Pl040<=01@73`0E2@h04PH901<72@0D20X05`/?01P<400C1Ph0
5@PA01853@0201L;3@0401D92`0C1`T050P:01H:30805@T;0P0D20X01@0C1`T04`H=01@74P0F21@0
50LB00804PD>00L05@P?00T00`0G2`l04@H801L<3P0]8R<05@X;00D04PH80P0C1`T401451`0M01D8
2P0H2@/05`P;01D62@0C1@H04P<601<41`0C1@L04`H801@62@0D1`P050L901<72@0B1PP04`L90186
200A1@L040@601882@0H3Pl050T:01051P0>0`@050T;04Tj?@0S51L050D80101100D1@P00P0F1`X0
3P0D1@P04`@701T:3@0J2`h050H801D62@0@0@@050H801831P0L3A0040<401@5200C1PP050H80`0C
1PP00`0A1@T050P<01L;3`0201H:3P0:01862P0:00805@T=00h31P0@10P0710D01H:3P0?10L06`lC
01L;3`804@D900L03P<601H:3P0A1@T04`L:01@8300B1PT05PX=01Cooooo000Kooooo`0T01D92`0@
10H03P8401`@4P0F2P`03@4302/O8@0K3a404@D701X>400P51H03`<5034T:`0d:2/03P<101X?2`0A
1`40;bDI044g:`0K4@H050T501<71`0H31003P<900X11`0900L01`0501P?500L4aH03`H900l72@0N
5AH07aHG01482@0B2@X05`h?1P0E2@T01P0A1@D05PX:01D92@0C1`L05@T901H:2P804`L70P0D20P0
3P0C1`L04PH601461P0N4Q804`L701P<300;000050P800h20P08000040@401dA4@0G2`/03`@40P0C
1`L04P0B1PH04`L701<71`0C2@X06a8E01P?4P0C2Pd03`H900h5200H3a801`0100l62@0<0`H05@`?
01072P0B1`X06Ph@02`P8P8060`>00d05PX<01051P0L41806Ph@01D92`0H30h050P:01P=3P0E2``0
5P`;01H<2P0E2`T050/600805@/900h05P`=01D:400D2@l04`P?01H:3P0K3a<06@dA01P=4@0M4QH0
4`P<01hE600F3A0060lB01H@4P806Q@F00D05``B01X?5`0J3aL060dE01X?5`0201P=5@05020E7@0K
41P08AHN01dB6P0J3aL00P0J3QP0:P0I3QH060lD01T@500J4A@06A<G02<M8P0T7bD071HP01H@700G
4Ad05`dF01dC6P0N5AP06A<E01TD4P0M61D08QhM01hK6`0O7B008b4V024N9`0K624081dT01`J7P0O
7Ah07Q`M01XI5P0Q81`09bHT02DS8`0V92L09B<X024N9`0Q82P08b8Z01LH700X:Bd08b@X02@U:01S
I6H0=CHh02PZ:@808B<R00<09bTX02`^;@0Y:2H00P0U9BD02P0V9RH09RLY02PY:`0[;2h09b/^02@X
:`0[;c80<3@g02`a=@0Z<3L202`c>`1`02Tb>@0[=3/0;SLn02`g?@0X=C/0<Ci402`i?`0Y=S`0<d16
03I5B00c@TL0=4=803A3BP0]>d@0B5IO03e;F00iAUH0FFIf04UFI`0d@E@0?d]G03e8C00e@TP0<3e6
03M3C`0gAE80?4UI04YGI`13Df80AEER04QIH`0nCeT0?DeI045AH010D5d0<dA>03U:D@0oCUD0>TU=
03]:C@0mBU00?4U@03a9D@11BeD0@diG03m<E00nBe<0@4eD041=D`0mBU00?4Y>041>D@0lBTd0=D=5
03U7B00oCDh0@Dm?03i<C01?GEh0?de>03E3A01<FUd0A55G04]HGP1=FV80A55J04=@F@1CH6T0D5iY
04ABG@0jB5<0CUaW059PJ`1GIG00FFMb08jLY`1MJgH0GVag05QVL@1BH6X0A59K049AF017EUd0CUeT
04mNI@1BHFH0CEaO04mNH@1@Gf80C5aL04YJFP1;FUX0BEEC05ANG@18DU40C5IE04mIF01@FUT0GFMV
051JF@18DU40BE=B04aFE@1CGed0Ef=Q04mNF`17EED0AE=C04QFEP1;FEX0BEMJ04UFF`80AeAJ00l0
CU]R05ISJ`1AH6L0BUUP04=BF@11D5L0CUeS04=BE`18EeX0AeII045@D`12DU80Be]K04mMGP12C4h0
0P15CE000`11BD`0@4Q;0459C00204=;CP0=03U1A00h@4<0?4A703Q0@P0d>cD0>d8k03m6?`0m@cl0
=C/i038h=P0i?cd0>Clo03Pn?P0203Dk>`0L03@m?00f@D<0;STk02dh>P0_>Sh0<3Tn02hg?00c>T80
>3m7034h@00]<C`0:blj03PkA00/;340=CHk02h_=00[:c@0:2Xf038e@P0`=3l0<SU303<j@P0^=C/0
:34f02P^<@0W:2X092DW02DV:0809bPZ00<0:R/]02//;P0Y:R`00P0W:2X0200Y:R`0:R/^02d^<P0Z
:bl08B8V01TJ7P0V9b/0=CHj100Y:Rh0100X:Bd09BHZ028S:00O82D202TZ;`8071dR03/0:b`a01/L
8@0P8BH08R<X02<T:@0X9bl07ahV01hM9@0S8RX092<[02h]=@1LFf<0F5MO02<R:P0E51`061LO01LF
7@0H4aT091lS01PC5`0F4AD0:RDY03@_<`0N6Ad07aXN01hI7@0J5AT061<G01D@500L61T06QHG01/G
600L61T06QHG01/G600G4a@06QHG01TE5P0G4a@06QHG01LC4P0B3Pd04Ph<01/G5P0Q7A`0EU9B08=o
P00F4Q<05Q8D038]<@0A31006A@I01`G6`0G4AD07aTK01D?4@0>20X09b4S02HP8P0201LA4`<05Q0B
00H05@lA01TC5@0F4180618D01LA4`0C3@l201D?4@0701H@4P0E3a404`d?01@>400F418050dD01@>
4P0201LA5@0Q00d72@0E3a405a4C01XD500M5aL08adM01TD4@0A30T06A0C01892P0A2@L091lK01dH
4P0400004a0;028Q7@0Q81h0=38e04m<D`0O7B804Q0B01DC500A3a006ALH01<A500F51L08R0S01`J
7`0M6b006aTN01XG7P0N6b807QhR00<0824U02D082<X028U:`0T9bh08RL]028V;P0Y;CH0:2lg02Xa
>@0U;3@08bXb030g?`0_=Sh0:S4i02lf?P11B5008BP`02P_=`0^=Cd09Rde03Pk@`0Z;C@092@/024Q
9`0P7b@08b4V01XG6@0I5AH06aDE01XC4P0I4@l06Q0?01`D4`0M5aL07aTI01dF5P0I41405Pd>0080
5`d>02@05P`=01H:300F2P`05PX<01D92`0D20X05`/=00l31@0800006Q0A01P<3P0K3a405@T;01T=
3`0F2P`06`lA01D92`0G2`d04@D701D92`0<00804`L9024E5`0F2P`04@D701<72@0A1@L060d?04a1
A@0A20/02`<501L<400I3Q8050X;01451`0B1@H301<51@0:01<5100A1@D05PX:01451@0C1`L0710@
01T=3@0@10@03`<301<71`805`/;00<04PH601D71`0E1`L0100E1`L00`0F20P05@L701D71`0201@6
1P0501@61@0B10<05`T601<50P0B10<00P0F20L0200H2PX03P0201@5200A0PD06@X=01L82`0E1@D0
5PH60P0G1`P201D62@0I01451`0L41803`<502@J6P0P5QD040D901D74`0E1a@05@PB01032@0?0`L0
50P<01H:300800003`<701452P0=00L03P4801D9300E2@/050P:01<72@0E2@/05`/=01D92`0201@8
2P804`L900d04`L>01D7500F2A<05@PB01853`0C1Pl050L?01442`0G2`l04@D800h2100A1@L03@<4
00H04PH80P0A1@L01@0B1PP04`L901D92`0F20/05PL:00805@H90`0D1@P01P0E1PT050D801<41`0B
0`H04@8501851`804`L90`0B1PP02`0H30h0200000h2100?0`D0300201hB500O41<04@8501H72P0B
0`H0404400805@H900/04`@701@5200J2`h06``?01P9300F1`X03@0101/<3`0@0@@04`@701831P06
01@5200H01D93@0@10P05PX>01X>4P0?0`L03P8600l31`0>0PH04PH:01L;3`0I3A405PX>00/00`0F
2Ph05`/?01<72`0A1@T03@4501862P0F2Ph04@D900d11@0@10P04PH:5?ooool001_ooooo02@03@43
01/?4@0D20X060`>01H:300C1`T05PX<01041P0D20X05PX<01X>400>0P@070lF01L;3P0I3P`04`P4
02TO5P0P5PX07aD901X@1P0@1@404PL701862P0F2A008QLO03T_=`0W7BD02`<701072P0H3a806Q4D
01<:2`0A20T02P8301892P0J414701@8200601T=3@0E2@T04@D501451@0@10@05@T90P0D20P03`0F
2PX05@T901<71`0G2`/0Ac/k01<71`0D20P04PH601L;2`0N4Q806`l?01<8200=0@40710@01H:2P02
01<71`0D01861P0C1`L04`L700l41P0F3A003@@701482`0@1`X04PT<01072P0F3A007QDH01P?4P0@
1`X02P4401@82`0C1`T07a<E01<72@0I3@l20186200801P<3P0G2`d050P:01451`0D20X06Pl@01D;
300E2`/201D;2@0D01D<1`0E2`T05P`:01H<3@0E2Q0050T?01@94@0L3aH05PX>01852`0?10X040D9
020E6P0I41D030<601L>4P0>20`03`T;010:3P0G31@201T>5P<05``D00H060dE01T>5P0N4a/05@XB
01@94@0J3aL201X>600801T>5P0H3a@06a8F01dD5`0L5QX08ahS02@O9@0O6B<201TC7`0V01T?600M
51X07A@I01TC5@0H4Q806QDB02<O7P0K61X0928W02h[<P0T8BX04PlH01lL8`0I5a/07Q`O020N7`0K
6QP07QdI03He<`0V92H08b4V028O9P0P7BH0:BP`01`K8`0b<cP06AXN028S9`0W:2/04Q<E02<T9P0S
9B@092HU02HX9`0W:BP0:2XY02TX9P0W9bL202HV9P809RLY00h0;2d_02L[;P0S9bX0:2`_02``<`0X
;C40:S4h030g?`0_=Sh0:S<j02df?@0b>d80:SDk02Hc>@<0;3To05/0<d1602`k?P0a@4D0@U5F04MF
G@1HIVl0UjF^08FCW`0lBET0A55R03i;G00b?e80=d=@03M2B00a?TH0<Ci8038nC00gA5@0AU=T05=P
L015EFD0@51O04YJI`11DEh0>d]I03];FP0oCe`0?DiH045BF@0fAD`0>DQ<03Y9C00lBDl0>dQ?03]8
D010BU@0AU9K04=@F00mBU80?DYA045>E010CE<0?deA041>D@0mBdh0>TQ:03a:B`10CTl0A59B03Q6
AP0kBDX0?de>03Y8B@14DUD0AE9H04UFG01:Eel0@TmH041=EP18EEh0=TA?04eKIP19Ef80A59M03m=
F01;FF@0B5IQ06ilQ`1>G6L0CE]V04UGHP1>G6H0D5iW05MVK@1?GVD0Df9Y04iMI01@Gf@0CeiQ055P
H`1CHVD0CemO04aLG01<Fe/0DEeM05iXI`1<EUD0CeUH05EOGP1BG5/0C5IE0080BUAC00X0C5IE04iH
E`1@G5X0EfEU055OG`19EeP0AeEF04QFE`1:F5/0CE]N0P1<FEl04@1=FV00DUmW05ISJ`18Eeh0AUEL
059QJ01<Ff80BEQN04EDF@1:FE`0AeII049AE011DE40AEEE04MEEP0lATP0@DU<0080@d]>00l0A4a?
04I>D@10B4/0?dM:03U1A00j@TD0?DE803Y2A00h?cT0=3/d02he;P0_=C40<3Hd02`b<00b>3H00P0e
>c/203@j>P0O03@l?P0^>3X0<3/m03m:C00Z=CT0<CXo02Tb=`0e?4@0<cY202lf?P0c=d809RXe02X]
=P0/:c80=SHn02h^=P0Y:C@0:R`i03DhA00]<Cd0;c<o02lf@00]=3`0:2le02P^<@0W:2X08b@V02@U
9`0U9RP09RLY02//;P0302`];`0902X[;@0Y:R`09bP[02h_<`0Z:bl0:b``038c=`1BDeL0FU]O0080
:BX^0P0Z:bl01`0X:Bd0;Rlc03Hg?00_<3D08B8W01TJ7`0Q8RL00P0Z:c00700N7b@0<c@i02LX;@0I
6Ql0:2L_01dL900J6B408B0X01hM9@0H5al06QTQ02<R:P0T8b/09B@/02<R:P0V9B`07APN02@O8`0N
6Ad05a8F02`W:`0g<SH08QdQ01lJ7P0I51P071LK02@O8`0N6Ad201TE5P0501/G600L61T06aLH01XF
5`0G4a@0100H51D04`0G4a805Q8A01/G5@0L61L05Q8A01hJ6P0Y9BH08QhO01XE601FDED09b8V01@?
500O6Qh06Q@H01PB500J51H050h@01`F600I4aD01P0F41801P0I4aD05Q0B01PB500G4A<04`d?01D?
4@805a4C02T05@lA01<=3`0C3@l05Q0B01L@5`0E3a<02P@801/E6@0E3a403@L901<=3`0J51@071HF
02@N7P0K5Q<05Q4>01P?400A20T040P605=>BP1MF5807aXD01LC3`0D4a404Q4?08n=T036a<T0?3Xo
01`J700J61T05aDF01XH6@0@3Q405aDH020N8@0K6Ah07A/P01/I7P0L6B007ahT028R9`0202<T:00b
028S9`0R9BX08bH/028U;00P9B/08BH]02/_>00/<c/0<3Lo02T`>00X;cL0=Se502lf?P0/<c/0ADaD
06E/M00k@TX0?4=;02T`>00^=Cd0>Cm602LZ<@0T92`081lV020O9@0T8RL071PM01XF5`0K5AL06Q<C
01TA3`0J40l0614@018<300>20P050d=01XA4P0@1`P06Q0A01H<3@0C2@X05PX<01L;3@0F2P`06`lA
01@82P0J3Q005@T;00/00@0C1`T20186200H00l31@0I3@l05@T;01451`0G2`d06Ph@01051P0K3a40
3P8401X>400T61X06Ph@0186200C1`T040@601461`0J3a<04`X=01XA500H3A407a@H00X10P0B1PP0
4`H70`0D1PH01@0D1PD050P801P<300?0`<02P0000803`<300H0710@01D92@0D20P060`<01T=3@0C
1`L801D71`<050H600l04`D401/=300=00006P`901H81`0B1PH0>bd/02TK6`0D1PL04P<601421@0E
1PT0404401D5200F1PT00P0G1`P0300E1`H050H50104100I3@l040@601hC5`0K41@04`P@01@6500D
1QD060XG01@73`80300400L06Ph@01451`0I3@l05PX=0104200K3a<04`L9008050P:00<04`L901H:
300H30h00P0D20X201<72@050186200C1Pd05@PB01L:500E21800P0C1Pl01`0B1@d05@P?01@8300C
1`X04@D700d10`0A1@L01@0B1PP00`0C1`T04PH801451`0301041P0301851`0D1@P050D800<050D8
01L05@H901@5200D1@P050D801<41`0B0`H05@P:01L;3@0E2@/04PH801041P0?0`D07Q8D00P0000N
51D07A4C02DI6`0?1@H05@H90101100G20/05@H90101100201421@80404400P050D801D62@0C10L0
4`@700X0000H2@`04@8501<41`L050D800X0710D01452@0B1PX050P<01452@0S5a/0710D00l31`0B
1PX05PX>0P0A1@T0100@10P05PX>01L;3`0E2@d201@8300600h21P0D20`03P8600`0100?0`L02`03
5?ooool001_ooooo01`05@X;01/?4@0<00804PH801H:300C1`T03`@501P=3P0^8R@06@d?01041P0I
3@l050L=01H;3@0=10<05``8024F3`0I3`L06@l601H<100F2`L05P/;00/00`0H2a8060dC01dB600F
2a404@L<0P0C20`01P1PEUL05`l?01@:2`0A20L04PP701<:2PH050P800L04PH601D92@0B1PH05PX:
01D92@0>0`<050P800804@D50P0D20P03@0A1@D050T903<W9`0C1`L05PX:00l30`0D2@T05`/;01<7
1`0E2@T04@L7038V9P0O4a<00P0C1`L01P0B1PH04`L701<71`0X7Ah0?C8f01H<3`804PL;01H06PlC
01872`0I3Q802P4301872`0F2`l060dA01L;3P0B1PP05`/=01D92`0Q5AL05@T;01X>400:0000710B
02`P8P0C1`T050P:01H;3P0E2`d05@/<0P0E2`T04`0G3@/060h<01L=2`0F30d05@X@01D:4@0E2Q<0
5`XC01853@0J3AD05P/C024F7@20MGd091XR01D;4P0G3AD03PL>00l83P0H4AP00P0F2a<02P0H3AD0
5@XB01@94@0H3AD05@XB01873`0M4QX06PlG01/@600J3aL201X>600;01X?5`0K4QL07QDI020G6P0K
5AT06A@I01PC6@0J51h06Q@P01PB7P0O5Ad00P0O5Q/02P0K5AL06A<D01PB4`0R7Ql06aPK01`J7`0J
5ah05a@L01`I8P0K6Ah201`J7@0A01lM7P0O7Ad061HF02/Y:P0P7R4081hS024N9@0N6b@081lW02<R
:@0c=3P06AXN02//<00M7R408R<U024R900R92<00P0S9B@0100Q8b80828Q02PX:00W9bL202PX:080
9bPZ00L0;c<f02``<`0X;2l0:Rlc02/`=00W;300:S4h0080;SDm06D0:S<j02`e?00`>D00;3Lm02dj
@00X=C/0<3e303I3B@0_?480<T5603A3B00_?T<0@e9I05ESK01JJ740CUaW04ABH00lBET0?T]K04AA
HP12CE/0>D=>03Q5C`0mBEL0<cm@03]8FP1GI7L0Gfan04aKKP10Cf40AUIU03m?G`0nCUd0<41?041@
G@11DU`0@U=J03=2B@10Ce<0?Te@041=D`0oC5<0?daD04A>F013CUL0?T]C03m<E012CeH0@DiD03m<
DP0mBdl0?D]>03a:C@11Ce40?de>03i<C@15De@0>DM8045?D00oCDh0@4i?04ABE@10CE<0@DiD04IC
F@19EUd0AeAK049?E`16E5h0CeeX04ECGP1AGfX0FFMb05ITK`1CHF`0CE]V05ARK@17EF00@4iI051N
J015E5`0GVed04MFG@1@Gf@0BUUN059QIP1?GV40DF1S05=SH`1@H600CUiN04iMGP1CGel0GVYZ04iJ
FP1AGEd0DemO04mKF`1@G5`0DEeM04]GE`0204QDE00^04IBD`12D580A59E04QEFP1:Ee`0C5YN04eJ
H@1:Eeh0BeQP04aIHP1=FV80BeQQ04QEGP1>GF@0D5mV0760Q`1RLGH0A5=H04QGF`14DeH0@e=D04AD
E013De<0?dm?041>C`0mAdT0@TY=04=;CP12BTd0@d]>04A<C`0j@TD0>D5403Lo@P0i@D@0=cm203@l
?P0g?CX0<SPd02le<@0b>3@0<CLe02dc<@0[<C40;cDe030f=P80<3Dh01h0;cLi03I0@P0/=cT0;3Li
03<l@@0d?D80=Ci303LnAP19CEH0>Ce6038f@@0W:cH0;2hj030`>P0d=3l09RDb02l^?00h>TP0?3i=
034d@P0^<Cl0;S8n02dc?00[<3P0:Rda02<T9P0P8B<09BHX02<T9P0U9RP202TZ;00U02//;P0/;Bl0
:2T[02@U9`0V9bX09RL[01dN8P0Y:Rh09bP/024R9P0[;30092DY02<T:00W:2`0:2T]02HW:`0R8bL0
9BH[02l`=@1;C540ADI;02//<@0Q8RL08b@Y030a=P1KG640=CHk020Q9P0Q82H07ahT024P9P0R8BL0
81lU01hM8`0L6b405aHL020O9@0201PG7@0901hM8P0Q72807QTM01`G6`0J5AT06A@H020K7`0L5a/0
6A@H00807QTM02006A@H01hI7@0M6AX07a/L01dI6P0K5aP071PI01XF5`0H51D05a<D01XF5`0K5aP0
61@E01PD500M5aL06Q@C014;2`0G4A40618C01dG6@0J51H08A/N03Tc=`0<1PX071HK06=MH@2VX:@0
>38d01@>400L5QP06aDG01LA4`@05Q0B0P0G4A<01P0N61X06Q@F01`F600K5AL05a4C01XD5P806A<E
03L05Q0B01@>400F41806A<E01PA600G4AD05Q0D018<400I4aD06aDG01H@4P0G4A405@l?01/E5@0H
4a005Q4>01T@4@0D2`/08a/I01XE4@0E40`07aXF01/G500H5aD05aHE04I4A`1ZJ6d0928V018@4P0J
61T05Q@E01XH6@0G5AP08AlR01PF6@0J61d07adR020N8`0N6b8081lU01hO8`0O82@07AlS01`P8`0O
8RL08RH/02@Y;`0U:S009bdd038i@@0f?DD0=Ce6034j@`0c?4D0>dA=0080<CY30340?4E>04A=EP0[
=3d0=Sm802L`>@0X<CX0;38k02HY<00Y;3<08R<Z01dN8`0Q82H07A`P01hL7P0M6AX071LG01TC4`0I
4@l05a0?01TC4`0J51@050d=0107200G3Pl06@l@01H<3@0B20T05PX<01P<3P0E2@/081@F0186200D
20X05@T;0186200C1`T06Ph@01T=3`0J3Q00;b<U02TM7`0E2@/03`<501L;3@0C20X05`/=01451`0H
30h05PX<00804PH800/05@T;01@82P0A1PP03P@704Hm@00S6ad04`P<00h31`0C2@X04`L901@72003
01D71`0=01D71P0@10@050P801451@0@10@050P801T=3@0V6QX06`l?01861P0C1`L050P801451@08
01D71`8050H602P04`D501<5100C1@D06@/801h@3@0E1`H06@`;03X/:`0U5aL050H701H72P0E1PT0
5`P;01021@0F1@h05`H=01L72P0G1`L050L201@60P0A1P@05@T901@8300B1`l03P8>01dA800O4280
3@0@00h13`0D1a404@@;01041`0E2`/050T901P<300E2PX0308201H:300C1`T050P:0P0C1`T00`0E
2@/05`/=01@82P0301<72@050186200C1P`05@PA01H94P0E21400P0B1@d00`0B1@`050L>01042002
01<72`0300l31@0D20X04PH800@04PH800<04`L901@82P0C1`T00P0B1PP0100C1`T04`H801<41`0C
10L601@520805PL:00@05`P;01L9300E2@/04`L90P0A1@L03`0C1`T05@/<00`20`0G2`d04PP90106
1`0G2`d05@H901H72P0C10L06P/>01L82`0D1@P05PL:01D62@0401@5200300h00P0I2Pd04`@700<0
5@H91P0D1@P01`0C1`/040@801D93@0D20`05PX>02lS9`0S5a/00P0C1`/0100E2@d04@D901D93@0B
1PX201452@0601862P0A1@T050P<0104200A1@T04`L;0`0D20`Dooooo`006oooool05P0W6ad07Q8D
01@82P0P51H0710B01D92`0C1`T05PX<02DI6`0@10H04`L900d10`0900405@T<00P0000O51004@H3
01T?1P0A1P004@H101H;1`0F2PX201<72`0<01H;4@0@1@/040D;01L<400D2@d03083020F5`070000
3P@301@:2@0<0P401`001P0C1`L201D92@0<01@8200S5aL08ADE01861P0F2PX040@401451@0F2PX0
5@T901861P0A1PH020000P0F2PX0200<00003P@400d10@0800006`l?01dA4@11=CD07A4A0P0C1`L0
400B1PH04`L701<71`12=cP0Jf5R02TO800@1PL02P0101lE5P0?1@H06Q0A01D;300J41402P0101@:
2`0A1PL301<72@0Z01hB500>0P@06`lA01451`0L4180<2@V01lC5@0G2`d05P/>01D:3P0D2P/050X9
01D;2P0H3P`060h=01L=300F2`h050T?01D:4P0F2Q@08aHP01T<5P0C1Q0040@>00`02P0E2A<060hG
00l53P0=10`07QLO01TB6P0B2a<05P/C01D:4P0I3QH05``D01@94@0M4QX05``D01H;4`0G31@0714I
0P0N4a/201/?6@0=01`A6@0K4QL06Q4E01T@4`0G4AD061<H01PC6@0G4A/06A<O01XD800L4QX071<H
01dD6@0201`F6P0J01XD6017@TH08AdS01PE700Q7RD07AXR01HC6P0G5AX0<c4d02DS9P0I5aX07adP
01PF6@0J61/06aTN01`I800Q7RD08b0X01TH800U92X09bP/0411A@1dMGT0;2d`01TJ700P8B<2020R
8@0802@V9@0W:BP0:B/Z02HV9P0V9bT09bPZ02PY:`0X:Bd202HZ;@0902L/<00V:bl0:Rlc02X_<`0U
:Rh0:C0h02Xa>@0[<SX0:c@k0080;3Dl00<0;CPn02`i?`0^>d400P0d@DL0;P0`?D<0=TE<03]:D@0e
A4/0AeEN05]YLP0_?DH0>4IA04MEHP0kB5L0AE9R04UFIP11C5X0@deI045=F`0nBU/0AU5U04MDI`1=
FFl0EF5g04MFJ`15E6L0@U9R03e=G@14E6<0?dmN061`O@0iBU@0?TmF03]:D@10Ce<0>dY=03a9C`0l
BE00?4UA045;E@0oBU<0?DYB049?E`12CeH0@DiD04AAE`15DUL0?4Y=03]9C012D582041>C`0>03Q6
A`12D540CeeN04eKG00lBT/0@DmB04QFF@19EeX0BUQK04IDE`10CU40>DI<038oB00jAe0304eJH`0I
04aIHP1;F640BEIO04QEGP13D5T0@4eF04MDG@1ULWX0R9FK05QUJ`1FHfT0AeAJ04eKGP19EeX0BUQI
04iLG@1>G5`0D5iN05ESH`1>FE/0E5mQ04mJG01AG5h0B5=E04YEE`0205UTIP0_04]FF014Ce40AU5C
04E@E014DEL0AeAL04YGG`1;F600BeQQ04YGH01<FF80BUMP04UEH@1;Ef<0BEEQ04AAFP13D5P0AE9H
05MTJP1AGV@0BEMK04QFF@11Ce80?Ta=049@D@12D500?Ta<04A@D00nB4X0@TY=0459C00oAdX0?TI9
03m7BP0mADP0=Si103Dm@00f?T40=3`o03<k?@0k@Ch0<CLc03Hl>00a=cD09R`/02D[:`0/<S800P0`
=CP0100/<C@0:Rlb02P`<P0[=CL203Q2A00H03Q1AP0/<cT0<CPn03m3C01JGVL0=c]4030b?P0c=D40
=cU503<c@00`;cd07A`/03hmCP1<Bed0@D5C03XlB`0_<D00:2Xg02LY=@0U:3409RP^028R900Q8B<0
:RX/0P0W9bT08@0^;S00;Bd_02`/;P0[:bd0:BT[02PX:P0Y:B`0:2L/02d/<@0U92T071/P024P9@0T
8bP09B@Y02@S:00Z:Bh0;Rdb02/Z;`0R8RL08B8W02DV:`0_<3D092DZ01dN8`0X:Bh07AhS02DV:`0b
<cP07QlT02TZ;`0Q82H09R<Z02@Q:00201/H7`0@02DR:@0O72<0<Bhe05YGGP0^:c806AHM010=4`0O
6R009R4U01/F6P0R7B406A@H01`G6`0N6Ad06aHJ01PC5`805a8F01l091lS01dH700P6al071LK01PC
5`0L5a/06aHJ01TD600G4QH06aHJ01hI7@0H4aL06ADF014;2`0N61L07ALG02PR8P0L5QL071HH01dG
6@0D3Q406aDI01TC5`0O6Ah0Qh650=WCe`1<ATP03@L9010:300F41806aDG00805@lA0P0F418201LA
4`0601PB500E3a405a4C01H@4P0B30h050h@0P0G4A<04`0D3Q004`d?01H@4P0K5AL081TP01/E6@0N
61`09R0T03dg>@0G4A<0618D01<=3@0D3Ph04`d=01<>2`0B3@X06Q8@01`D4P0B2PP00P0B3@X0500;
1P<05A4@00d;300G5AH0518C01PF6@0J61/071XK02d[;00N71d061HG01DC5P0K6A`05Q@G01PF6`0M
6b007Q`Q01`I800M72808B<W0P0P92L04@0R9RT09BX^02L/<@0X;C<09bhd02/b>@0e?4@0=Sm603Dn
AP0e?dP0=d5:03Y4C@0kADh0>TA=03M1BP0a>d@0<ce60080<Sa501<082Xc02H^=`0X;3D0:Rhg02<W
;@0Q92T092DZ01`M800M7Al06aTJ01/H600J5QD0618B01TC4`0F410040X:01D>3P0J4A804PT:00<0
5@/<0P0F2P`00`0D20X06@d?01451`0201D92`0L01L;3@0N4Q@040@601451`0@10H07A4C01P<3P0>
0P@04`L901D92`0F2P`03`<5020D5P0D20X05PX<01L;3@0E2@/040@600l31@0@1@H08QLK0<2g^P0i
<3<03@8601hC5`0E30d04`L901@720<05@L700d05@L601@8200D20P050P801861P0@10@04PH60145
1@0@10@04@D501<71`0H30`06Ph>00H05@L70P0D1PH301<51@0[01840`0@0P407a4>01H81@0A0`80
6@/:01P:2@0D1PH03`8301P9300C10L06@X=01L83@0G1A005`H>01L6300G1`H050L001<6000A1`40
5PX:01862P0B1Q803@0D01P:8@0_83H060TL01<55P0C1Q8040<:01041P0Z7Ql040D301<81P0g;2X0
91TG01D92@0D20X05@T;01<72@0A1@L04`L901@82P0201<72@804PH800D04@D701452P0B1@`050L>
0185300201032P0701<72`0>0PH04@D901P<400B1PX040@801041`070186200601451`0@10H040@6
01041P0B1@L050D8100C10L501@5200C01D62@0C1PP040@600l31@0@10H04PH801H:30080000<BDW
06iRI00D20X05PX<01451`0@0@@06@X=0102100I2Pd05`P;01@5200301831P090101100A0PD050D8
01831P12<cH07@hA01L82`0A0PD04`@700H050D800T040@801862P0C1`/040@800`1100;00<040@8
00h21P0?0`L00P0@10P00`0B1PX05@T=01<72`0201T=4@804`L;00H060`@01<72`0F2Ph03P8600`2
100U6AdDooooo`006oooool0900F2P`05`/=01D92`0J3Q004@D701<72@0J3Q005@T;01`@4P0F2P`0
;B4S0186200G2`l040H701T=3@0>0`405@X601<80P0F2`L05``801<81P0A1@H06`lA01<72`0@1@/0
5``B01H;3`0C20`04PP90147200D2P/03P@301061@0C2@P05`d<01@:2@H04`L700T050P80104100?
0`<07a<C01/?3`0900006`l?01@8200E2@T00P0J3Ph03@0G2`/05PX:0104100J3Ph04@D501D92@0D
20P07A4A01D92@0L4100200002LK6`0>10@00P0C1`L0;@0B1PH04`L701<71`0C20T0:R0Q00`20`0I
3a005@/<028H6@0A1`P05P`=00T0000D2P/03@<401hD5@0D2@X05`/=01H:300E2@/07Q8D00d10`0G
2`d04`L900`00P0F2P`06@d?01041P0F2Pd050T=01@9300D2P/05@/:01P>300I3`h060h?01H;3`0D
2A405@XB01L;5@0B1@l06`hH01`?6@0I3AL07a<M01X>600201P>5`0@020F7`15?TH0>C8j01PA6@0G
31@05P/C01/@600J3aL05P/C020E7@0J3aL0714I01<8400H3AD06a0H028G7`80710J01807A8J01XA
5P0G3Q804`X=01PB5P0O6Ql081/Q01/E7`0J52007aTU01T?5`0I41D071<H01`F6P0M5a/071DL02@O
9@0H51X201/H7`0F01DB6P0M6R405aDJ0490@`0]:bh05Q@G01hL7`0K6Ah07Q`Q01hK8@0G51/07Q/R
02/X<00S8RX08B0V028S9`0S92P0C4eA01DF6@0W:2X08R<U02@V9@809BLV00H08B<R020R8@0U9BD0
9RLY02LX:P0Y:R`202L[;P0902DY;00X;C40:Bhb02ld>00`=CT0:c0f02`c>`0[<SX0;3<k0080;SLn
08H0;CHm02`g?@0X=C/0<d1603E2B00_?480<d160350A`0eA4/0@E1G03E3C01?GFH0?4YC03m=F01K
JGH0AeAS03e:FP0jAeL0=3m=03m8E`11CEd0@diP06UdR01ZMX`0CEU`04=?I`0mC6<0AUEZ045@H`0n
CF00AEEU04iNK@1mSIX0>daF041AF011D5L0?diB03i=D010CE<0?daC03m<E014CUP0AE5J04AAF@13
D5P0?DYA041=D`1>Ff40DEiS03m=D00lBTd0@e5C049@D@15De@0@U1A03U7B011Ce00AE=D04IDE@0n
C4l0?de@04ABE@17EEP0@DmB03i<C`0oCE00AE9J03Y7D016De`0@TmH04]HH@1EHV/0>TM@04mLI@0k
B540AU=L04YGH01;F640?4U?06IcN@0kB4h0AE9H03i<C`1=Feh0A59C04IDE@1:F5T0CE]K059PH01I
IfL0CEQJ055LGP1@Fed0DeiP04IAD`19E5H0@Da>04UDEP14Ce40@4]=049=C`0oBTh0>TM?03i;E013
D5T0AeAM04aIHP1>Ff@0BeQQ04IBG@13Ce/0AE5M04IBGP13D5T0BeQP04ICF@0oC580?4U?04UGFP0k
BD`0A59C03e;C00oCDh0?de=03a:BP14D500>D=503i6B@0oAdX0?TI903m7BP10B4/0>d=6030h>`<0
;SHi02D0;cLi03Y0?@0[<Bd0<cTe03<i=`0a=cL0>Clo030f=P0c>3/0<CHi02/`<`0V:bh092`^02Pa
=012C4h0BE=E03HoA00b>Cl0>T5703Hj@`16BU<08RH_030b?P0j?4P0=3I203@c@@0_;Sh06aXZ04M6
F01BD6D0ADAH04A5E`0f>4L0;2hj02T/=@0X:380:BT_008092@V00H0<30b02/[;@0[:bd0<30b02/[
;@0W9bT202<S9@0C02DU9`0X9b/07A`Q02DT:@0];340=C@i03<b=`0O7R<081lT01lN8`0V9BX0:bX_
02TX;@0V9R/09RL/02X[<01:Be00A4E:02X[<00202<T:@0i03Pi?P0];S<07b0U024R9`0S82L07Q/R
01XG7P0P7B@08QlV01LD6`0K61l05A8I02PU;00@3A@071TP02DR:00H4aL0:RDY01HA5@0R7B407QTM
020K7`0G4QH071LK01dH700O6Qh08A`P01PC5`0L5a/07aXN01TD600F4AD071LK01dH700J5AT05a8F
01`G6`0O6Qh061<G01XF5`0R71`0:R@S01XD500N61P040X;01TC5@0B30h08A/N00D00`0N61`0614G
02@N8P0k=CT05Q0B01hH6P0R71h06aDG00<05@lA0P0F418201LA4`0501XD5P0F4180618D01LA4`0C
3@l00`0E3a40900B30h04@/=01D?4@0K5AL05a0G018<400=1`/0CDM;07QbM00D3Q005@lA010:2P0E
3`l04`d=01D@3@0D3``04`/901hF500C2`T06aHC020K600G4Pl05Q8A02<Q8P0:20T05Q@E028P8`0A
3a806QPI034_<00N71d05Q@E01DC5P0I5aX061HI01LE6P806aTN00<06QLN01`K8@0Q92L00P0Q9BP0
?`0S9bX09b``02L/<@0U;3809bhd02Xa>00a>400<3U0034k@`0f@4T0=Cm803U3C012C5D0?TQA03a6
C`0g@DX0?TQA02hh@@0i@d`0:38k02dg@00T:c<092Pa024U;@0W:S409RT^01`L8@0K6ad06ALJ01/H
6@0K5aH061@C014;2`0D3Ph07ALG01PA4@0A20T06Q4B01<92P0D2P/05P`=01H:300E2@/04`L901L;
3@0E2@/06@d?00l31@0=0@<05PX<01D92`0G2`d04`L901P<3P0D20X05`/=01D92`0@10H04@D700P0
000U6A/03`<501041P0201<72@0;01041P0C1`T06a0A03DZ;P3Sf]d0@STl00h31`07000050X;01<7
2@0D1`P00`0E1`L01@0E1`H050P801@8200F2PX05`/;00805PX:00@04`L701H:2P0F2PX050P80P0B
1PH601D71`8050H60P0C1@D04P0B10@04P@301h@3`0A0`804@<001840`0A0`805`T801H8200D1PL0
6P/>0101100E1PT05@H;01L54@0G1Q005`H<01L71P804`H001803`@001H:300=00L05PTH01436P0>
01T05`PN0183600E1aP05@PD01442`0A1@L0<2@U02TN700G30X06a4@01050`0A1P@201D92`0301<7
2@0A1@L04PH800<04`L90P0B1PP01@0A1@L04@D801862P0C1Pd04PH;00803`<700L04`L;00/00`0D
20`07A4E01D93@0D20`03`<600D04PH800L05`/=01/?4@0H30h05@T;0186200A1@L04PD7008050D8
01404`@701831P0B0`H050D801D62@0D1@P04`@701831P0A0PD04PD70186200?0`D03P8401041P0C
1`T0<2@V00l31@0201H:300800X0000G2`d03@0101`=400A0`D05PL:01421@0@0`D201831P0:01<4
1`0B0`H050D801P9300G20/0FDY=02HG6P0H2@`03@0101841PH050D800T04@D90104200>0PH04`L;
01T=4@0?0`L0300401<72`0E2@d00P0D20`03@0@10P04PH:01862P0L41@07A4E01862P0>0PH04@D9
00l31`0J3Q804@D901H;3P17>cl05?ooool001_ooooo00P06@d?01051P0G2`d0>Bd_01L;3@0D20X0
40@6018620805@T;00`04PH801041P0S5aT08QHH01451P0F2PT05P/901@91P0F2`T050T801<81`0J
3Pl201hB50804PH:00X04`L;01<72@0B1PP04PH801451@0D20P07a<C01X?3@0A1P@05P/90P0B1PH0
100K3`l04PH601/?3`0c9bL601861P0701H:2P0D20P04@D501<71`0E2@T04`L701P<300201T=3@0?
01L;2`0C1`L04`L701H:2P0?1@D05@T901@8200<0@4050P801L;2`0C1`L0;b<S04/o?`0L41005@X;
00805@T;00H050P:01<72@0C1`T04PH801<72@0D20X401L;3@805PX<01D060`>01T=3`0J3Q0060`>
034U9`0T61X04@D701P<3P0>0P@05P/>01D:3`0D2@`04`T:01@:2P0F30/04`T:01061`0G310060dE
04<g@00h;3P00P0I31H0=`0H2aD05PXD01H:500E2A<03`D>01T?600K4AX0ViBL04Q1B@0=1Ph04@H>
01/@600I3QH06PlG01P=5@0G31@081DM01053@0J3aL0;B8Z044f?P0H3AD06`lI01P<5P0H3AD07A@I
01lF6P0H3a8071HJ01PC600`:c40;BLa01D?6`0O6B@07Q@L01dD600K4QL06Q<J01`E700M5Qh07QTP
01DA6P0G51d061DN01XG800F4aX071XM01TG6@0J61/06aTN01XH7P0L6B008QlV020M9@0Q7RL00P0T
8BX0C`0Q82P07ahT01lP9@0N7b<07AhR020Q900S92H09BHX024S8P0S9B@0:B/Z02HX9`0R92<08R<U
02TZ;00X:B/092P[02P/;`0/<3<09BX^03<h?00/<CD0:c8h02L^=00g?T@0:C0h02/b>P0e?4@0:S<j
02`e?00a>T40<Se303E2B00f@dT0=45703=0AP0d@DP0=DA<03E3C00d@T/0>TQA03i<E`0kBE@0?D]F
04ABG@0nC5P0=TAA03Q6D`0oBUP0>T=B04=?G`1=FF/0IG2405EQM`1?Fg@0AE5Z03m>I@12DFH0AEAW
04YIK01>GVd0CEe/04QHI@0oD5X0?e1G049AF011D5@0>dY=03i;D@11CUD0AE9J08^EW`1CGfP0@DiF
03m<E010CE@0@e1F049?E@10CE800P10CU401P10CU00?de>03i<C@10CU40@U1C04ABE@80A59C00P0
@e5B04ABD`11Ce00?Ta=03m=CP11Cdl0@U1B04A?EP80Ae5J02/0BUAM04iHH@14CUL0ADmH03m9DP0m
Ae00?dUB03i8D@13CEH0BUEK049=D`11C500BUEI04aGF`1<EeX0CeYL04MBE01NJVX0CEUI055MG@1Q
KFd0B5IH04iLG`1<FUd0AE=F041>D@11Ce80AeEH04IDE`14DUD0@e5D041>D@0lBDl0AE9K045=F@13
Ce/0@TiJ04EAG@1BGVX0A51L041<F00oBeH0@TmH0080AU=L00D0Ae9I04IAEP18DeL0AE1D04UDE`02
03m:C00;03i9BP15DE40>TI604UEE@12CTh0?TM903i6B@0mADP0?4A703U1A00h@4<00P0e?D001`0m
ADP0=3`o03Hn@@0^=SP0<CLf03@j>00f?3X00P0e>c/0200f?3`0=CXm03<h>`0g?3l0<SLk02`a=@0_
=CT0:C8d0P0c>ch07@0/<cT0:c0f02db>00e>D80=CQ103Hi@P0f>4@0;S0l02T[=`0X9cL0;B`n038a
@`0k>Dh0Geeb04a;GP19B5T0=CA303/iAP0T92d0<C0i030_=00Y:B/08R8T034a<`0^;S008B4S02d]
;`0Y:B/09bLY00809RHX0180:2PZ02`[;`0M7240<C0e02XY;P0l>d0071/P02TX;@0T8bP0:2L/01hM
8P0_;S<0:BP]028R9`0Q8RL0824V028S:00T9BX202<T:@050452A`0Z:c00824V01/L8@0P8BH00P0P
7R<01@0Q7b@081hS01lM8P0M6b007Q`Q00807A/P00<07Q`Q01lM8P0P7R<00P0M61`201hI7@807aXN
00L071LK01hI7@0I51P06aHJ024L800O6Qh06QDI008071LK01h06QDI01dH700P6al06QDI02<N8P0K
5aX08A`P01`G6`0Y9BH07AHF01hE5@0L4a@06a8C01T@4P0H3a807A@G01/B5P0J4AH06a8G01T@5P0E
31406A<G01LA4`0E3a40618D03@^<00F418050h@01LA4`0H4Q@201TC5@0603D_<@0O6A/05@lA01`G
600H4Q@05@lA0P0D3Q00300a:bd050h@01TC5@0D3Q0071HH01dF7@0E3a<05a4E01hH700J51H050h@
01D?4@<05a4A03h05Q4>01D@3@0J4Pl05Ph;01lG500E40d04@/;01D?3`0C3a005Q@E00l=3P0B4140
6aTJ01LE5P0H5QL03P`=01/I6P0J61T061HI01dK7P0H5QT06aTN01XH7@0N72408AhU01dL8P0M82<0
8RHY024U:00O92L08bP/02H]<P0/<cT0:S8h02Xc>@0kA4/0>T=:03<mA@0gADh0>4E>03Y7D013D5T0
@4eF03M4C@0nC5D0<d1903e:D`0`?DH0=dA=02dh@@0]=Sl0:S8i02L^=@0T:S008RH[01lR9`0J6ah0
7alQ01/J6`0E4a@07A`J01PD4`80618B00T05`l@01D<3@0D2``04`T:01X@4@0I3a0050P:01H:300E
2@/00P0B1PP201D92`0301@82P0E2@/05@T;008050P:0`0C1`T0500F2P`06`lA01X>400E2@/05PX<
01<72@0@10H050P:01<72@0A1@L05@T;01<82P0I3Q80;B@W01H>400A1PX05``@01882@0B1PP050L8
0P0E1`L0100F20P05`T801dA4@0E2@T201<71`804PH601<050P801H:2P0F2PX05@T901@8200A1@D0
5PP80184100E1`L07@l?01L92@0E20P05`T901H8200E1`L050H601<51@0B10<050H500805@L402T0
5@L601@61@0C1@@05`T901D7200P4A@0B3/m024C5@0C1@T05`H@01X94P0J2@l05PL701@6100D1P<0
50T801@73P0C1Q404`HH01<57@0D1Ql0=BHl03<T>00G2AX04PHA01H:400=0`@04`L801<81P0D2@L0
4`P601@91`0E2@P05`/=01D92`0G2`d06Ph@01L;3@0B1PP04`L901@82P0201<72@0B01451`0N4Q@0
8ADG01D9300A1@P05@T<01@8300A1@T060h@01L;3`0A1PT05@T=00l31`0?0`H04`L901@82P0A1@L0
5`/=0P0J3Q001P0V6Q`06@d?00l41@0C1`T03@4301D82P805@H900@050D801<41`0C10L04`@70P0G
20/01@0C10L05PL:01D62@0B1@L04PH800805@X;00l04@L801L;3@10=3H07A4C00d3100J3Q004PH8
01461`0C10L050D801D72@0D1PP060T<01<41`0F1`X00P0D1@P201D62@0701831P0A0PD05@H901D6
2@0A0PD04`@701@5200601<41`804@D90P0D20`01P0B1PX04@D901L;3`0A1@T060`@00d31@8050P<
1P0A1@T01P0C1`/050P<01X>4P0G2`l04@D901H:3QCooooo000Kooooo`0600l31@0A1`P06@d?00/0
0@0B1`P07A4C0P0B1PP201<72@804PH800d03@4301<72@0?0`D05PX<01861P0>0P8040@401@8200H
30h050P:00d10`0;004050D:00<050D80P0D1PH02@0G2@T04`D401P:2@0F20L04`D201T;2P0A1@D0
50P801L;2`0201861P0301L;2`0B1PH04PH600@04PH600T06@d=02HJ6P0I3@d04@D501H:2P0D20P0
7a<C01T=3@0E2@T00P0B1PH03P0C1`L05`/;02DI6@0P51@03`<301@8200E2@T060`<01T=3@0F2PX0
91PH01<71`0M41005PP80P0G2@T201P:2P0701L92@0F20P05PP801L92@0H2PX06@/;01T<3@0201H:
300<01D92`0F2P`05`/=01<72@0P51H06@d?01@82P0E2@/03P8401L;3`0D2@l05@X>0P0E2``02P0D
2P/05`d>01D;300J3a@02P0701X>600F2aH05PTC01H94P0G2Q<201H;4`0l01L<500I3aL040H>02LM
9@0?20l050dD01TB6@0C21006a0H01X?5`0M4QX05P/C01<8400=0PX03`@<01`A6@0J3aL09AXR01L<
501JCUP0?C4k01T>5P0B2@h060lC020G6P0O6Ad05Q0E01D@5P0D3QP05Q0L02@N:00N51`07QDI01dD
6@0L5A`07QHP01hF8@0F41X08alZ00h;5P0=2Q<07AXR02d[<00O7B009R@V01dK7P0I5a`07Q/S01/H
8@0L6B808QlZ02DR;@0N6b@07Q/S02`[<@0P7bD0824V020Q9@0N7b<0824T0P0S92H01P0Q8b808bDT
02LY:00U9bH08R@S02DY:`80:2`_01`09BT/02DZ;P0X;C40:2da01lV;00M92X08RT_02D^=@0h@DP0
<3Lo0458D01<De/0>T=:03M0A`0i@TT0;cY0034nA00c@4H0=D9803Q5B`0jAdl0=D==03A2C@0e@dh0
?deH041>F@0iAe80?D]F0P10CUT0900mBeH0?TaG04EAG00lAE@0BeMW05aWN@1?FVh0?DUO04]GKP17
Df/0>dYQ04]JL01=G6l0AUEX059RL@1>GVd0Be]X04=DGP11DUT0@E1G041?D`0fADP0=45703e:D@1N
Jg<0^lG?055LI@0lBE40=dA<03a9D011CU@0@4eC045?D`13DE@0@DmB041>D080?Ta=0`12D5<04P11
Ce00@4i?03m=CP0mBd/0@Dm?04=AD@0oCDd0@4m<04QFEP16DEL0A4iG04I@F@15CeP0?dUB03a6C`0g
@DX0=3i703I0B@80>dE>00h0@TaE03Y5B`0lAd/0AE1D04IAD`12CDl0Ae9D04IBDP13Cdl0F6AT04mK
F@14D4h0A51?04MEF080BeYO00<0AUEJ049AEP12DEH00P16EEX02P13DUL0@U5F041?E00oCUD0@dmK
045=F`14D5h0A51L045=F@14D5`204MDG@0A04EBFP14DET0AU=K04UFGP17DUP0BUEI04aGF`15D580
>TE703@o@@0oBd/0B5AD03Y6AP1EHEl0Z;Bb049>CP0k@dH00P10B4/02P0i@D@0=Ce003Dm@00g?d80
>d=602Ta=00a>C`0<SXm03Dm?`0^=3<2038h>00B034g=`0b=cX0<cPk03<h>`0`=CT0<CHj02db=P0Y
;S@0:c0f02de>00g?d80=3`o02/`=P0_=3X0=ca203Hi@P0b=Ch0;C0i0P0Z:SH04`0[:cL092He03m1
D010@U40<C1203lnD00c<D<0=35202h/>P0i=T40:2D/02XX;@0S8BD0C4Y=02LU:00Q7b80:BLZ02XX
:`0X9RT00P0S8B@04P0T8RD09bDX02XX:`0R82@0>SPm03Le>P0d<SL0:bT^01/I7P0^;340928W01/I
7P0U8bP0518G03<a=P0R8RL08R<X024R9`808b@Y01<08R<X024R9`0o@4D0:2T^01XK800R8bP0:b/a
028P9@0T7b<09B0T028M8@0N6Ad06QDI01/F6P0O6Qh091lS028M8@0Q720091lS00807APL0`0N6Ad0
5@0O6Qh07QTM01hI7@0K5QX06QDI01dH700K5QX08ahT01LB600D3aD071LM01PC6@0E41H040/A014<
4P0F4AL04`hD01TD6P0E41@071<D01/B4P0201T@4@0;01`C5@0M51L06A0C01XA5@0M51T07aHK01/B
600F3A80618F01PB500M5aT00P0A2`d06`0?2@/0618D01LA4`0C3@l05Q0B01TC5@0d;S008A/M01<=
3`0400005@lA00h82P0M5aT0<B/]08b6R00M5aT09R0R018<3P0?2@/07AHM01H@500E3a<05a4E01LA
4`0F41806A<E01D?3`0201<=3@0>01@?300E40d0614<01dE4P0C2`P06A<B01PB500:10H06aHJ00X8
2@0<2P/06ALH00`;2@0H5aD201HD5@0;01@B4`0I5aP07A/N01XH6`0H5QT06aTN01TG700N72408AhU
01hM8`0O8bH00`0S:2/0500T;2l0:30d02Pa=P0Z<cP0;cTn03<nA00e@4H0>4A=03Q9D`0iAe80>TUD
03m@FP10CUT0>TYD03]<EP11CeX0EVE`03I7D@0c@D`0<3a50P0`>T<07@0W<3L07RD[01dT:P0P92T0
4aLJ034b=00P8B807QhN018B4P0G51@0618B01LA4@0E3Ph050/<01<:2`0E2``04`T:01061`0D20X0
6Ph@01H:300E2@/06@d?01H:300G2`d07A4C01L;3@0D20X05@T;00805PX<00<05@T;01<72@0D20X0
0P0H30h04@0C1`T050P:0186200D20X04@D70186200C1`T04@D70187200;00@050/>00d41`0A1PX0
4PL;01<92P0D20X05@P900805@L700X05@L601@61@0Z7Qh08ADE00l30`0>0P805`/;01<71`0B1PH0
50P80`0E2@T01`0D20P06P`<00d0000I2`/03@0001H:2P0I2`/01@0D1PH04@0D1PD05PP701H81@0E
1`@050H501840`0@0P4060X:01d?400G20/09AHI01X;3P0?00<06@P>01/:400J2Pd05`L:00805@H;
00@050L?01D7500G2AP05PTK0P0E21`01`13=4P0?2e000l1400F2A@0200202TM7`0B1PL00P0C1`L2
01D92@0C01D92`0G2`d060`>01L;3@0E2@/05PX<01P<3P0D20X04@D701041P0A1@L050P:01D92P0A
1@D03`<301D92@0H30`050P:01041P0200P0000A01@8300800007Q4H0145200B1PP040@601<72@0J
3Q005`/=00h3100C1`T040@600l41@0C1`T03P8401<6200E1PT00`0D1@P01@0C10L05@H901P9300H
2@`05@H900805`P;01D04`D802`P8P0Y7Al03P8401@82P0H30h0200001041P0A1@L03`<501D92`0B
1PP04`@700l00`0A1@H05@H900/0000D1@P05PL:01D62@0D1@P00P0E1PT201<41`0401P9300F1`X0
4P<601@520L04`@700`04@D901862P0C1`/04`L;01862P0A1@T040@801472@0800006PhB01D93@0:
008601862P0601452@0C1`/05`/?01D93@0A1@T050P<5?ooool001_ooooo00P05PX<01L;3@0I3@l0
200001L;3@0N4Q@050P:01<72@804@D701804`L901@82P0B1PP05PX<0186200H30h03`<500/0000D
20X05PX<01@82P0=0@<050P:01lC5@0E1P/05@H901@5200E1PT201D71`0801P:2P0D1PD05PP701@6
1@0B10405`T601451@0E2@T201861P0301451@0=0@404`L700D04`L701P05`/;02LK6`0H30`04@D5
01H:2P0B1PH050P801H:2P0G2`/05PX:01<71`0B1PH06@d=03@X:00/82003`<301L;2`0E2@T06@d=
01dA4@0=0@403`<300P0000I30`701L92@805PP800@05`T901T;2`0I30d05`/=0P0E2@/301@82P1B
01X>400F2P`06@d?01@82P0?0`D05``A01@93`0F2a005P/?01D;300D2P/060h?01H;3`0L4AL040@>
01H:500E2AD05@PA01D83`0G2Q805P/C01L<4P0H3A@040H>01H=4P0G3A@0614H02<M8@0E3QD04PL?
01L<500F2a<07A8J01P=5@0G31@0714I01hC6`0H3AD02P0701@94@0J3aL0;20Z01dA6`0J3aL07aHK
01L>4P0F3A00618F01XE6P0H4aT06A<M01dG8`0M5b40718J01dD600M4a/071DM01dE800N5R<071HR
01DA700L6B@04a0I01lL900B41D07A/N02/Y:`0N724061DL024N9`0L6B@08AhY01dJ9@0N6bH05A8K
03`i@@2GUY`081lU028S9`0Q8RH0824U020Q90808R<U00H0828Q028T8`0U9bH08bDT024S8P0R9RT2
02DY;00M02<W:P0S:2`09R/_02T^<P0^=C/09B`b02he>`0/=C`07bP_02he?@0e?4@0?4=;02lh?`0d
?D@0=Ci5030k@@0a?T@0<Sm503A1A`0hAD/0>dQ@03a:E00jB5<0=dE@03]9E00mBeH0>4IA045?FP0o
CEP00P10CUT09@0oCEP0@dmK03m9E@1AGF/0F6Ae04IAI@0hA5X0A51W04QDK010CfH0F6Mk059RLP0j
BUX0AUIV04MGIP16EV<0@U=M049CFP12DEP0@U5E04YIG014DEL0?DYA04EBFP0lAU00AU5J03]8D00h
ADd0>TM>03Y7C@0lBDl0?4U>03a:C@12D5<0AeEG04ABD`0mBd`00P10CU401`0oCE00?de>03i<C@0m
Bd`0@4i>045?C`11D4h00P0nCDX01@12D4l0AU5G041:D`13CEH0@4YC0080=Cm801<0<3Y302li@P0e
?dP0>TA=03]5CP12CE@0?4M;03i9C@16DED0AU5C049=C`18DeD0CUYJ04IBDP13Cdl0BeME03Q4@P17
De80B5II0080BUUN00h0AeIK049AEP11D5D0B5ML04MFF`13DUL0@4mD03i=DP0mC5<0>DEA03Y6E010
C5P0A51L04QDH080BeQQ01T0CEYR04QEG@12CeL0@4eD04=@EP13CU80?TU=03]6BP0nBD/0?4M904QC
E@10C4`0>TI603U5A@0oBdT0Gf]Y03<m?00h@4<0>T9503a4A`0j@TD0=Si103@l?`0nATT0;SHi0080
=3`o00@0<SXm034i>`0^=3<0<SPh0P0c>CT03`0e>Sd0=c`o038g>P0_=3P0;S<g02/`=00Z;cD0:c0f
02de>00d?3l0<CTl02`a=`0]<SP0<cPn02P[=00202lb>`0402/[=`0Z:SH0;2`h02`^?080BD]J0P0d
<dD03@0]:c/0:BLe02DQ;`0Y9Rl08b4V02DS9P0_;C00Y::U055?DP0W9BP0>cTl02<Q900N71l00P0Q
7b80500S8B@09R@W02PV:@0R82@0<c4f010>4`0Y9b`0:bT^028P9@0[:Bh09R@Y01TG700W9BX071XO
02DS:00R8BL08b@Y028S:00T9BX08b@Y0P0P8BH04@0W:2d07QlT01dN8`0C51T071`Q020N8`0S7R80
91lS028M8@0O6Qh06QDI01TD600N6Ad08ahR01dH700I51P06aHJ00H07QTM00T06aHJ01`G6`0L5a/0
71LK01hI7@0O6Qh0THbB05iIG`0R7B<00P0K5Q`0500M61h081/Q02<N900L5ad06aHL01PC6@0L5QX0
7QDF01dD500K4Q<06Q4B01XA4`0I41<060lB01T@500N5AX08QTN02@J8@0Q61d07aTM0`0I4aD0700H
4Q@04P`>01dG6@0?2@/04@/=02@N800F41801`4301@>400K5AL081XL02`V:00C3@l05a4C00@0000O
6A/02`D700h82P0J51H03`T;018;4P0C3A405@lC01LA5@0L5QP07QPJ014;3@0E3`l201PB4P0V01@?
300B3@T05a0:01hF4`0@20D06A<C01`F600C3@l071LK01TG6P0>30d071XJ00l>300M71X05A<D01PF
5`0F51D061HG01XH6`0I5aX07A/N01lM8P0L6Ql07Q`Q01lL8`0K6R007b@W02<X:`0T:B`09BX]02D]
<00Y<CD09c0e02`e>P0d?T@0<3]103E0AP0lBU8203Y;E@0F03i?F@11DU`0?e1J03Y;E@0hBE<0?TmI
04MHHP0`@D/0:3U302djA00a>d@0;cU202Pa>@0P:C0082L]024W;00[;S<0Rhb@05eNH00T92@05ADE
01@A4@805Q0@01H05Ph?01D<3@0E30d03@<401D;300J414050P:0186200F2P`05@T;01/?4@0H30h0
6`lA02PL7P0O4aD050P:01D92`0H30h05`/=01H:300C1`T040@60P0B1PP04@0?0`D03P8400l31@0E
2@/040@60186200D20X03`<501461`0E2Ph050/>01<:3@0E2Ph040D901061`0E2@/05@P900805@L7
00P050H601<5100G2`/08QHF01L;2`0D20P07A4A01D92@805PX:00/05@T901@8200C1`L04@D501/=
3@0J30`05PP800h0000J3Ph05@L701<51@0401@61P805@L60P0E1`@0700E1`H04`D401840`0J30`0
40@401X;3P0;00003P02024B5@0I2@X06PX;01T9300F1@`050@>01D5400B11805@LH01P:6`0G2Q`0
5@PJ01@76@0A11@06P`M00P02@0E21803`8901<72`0G2``201@8200<01@82@0B1PP040@60186200F
2P`05@T;01<72@0J3Q007a<E01H:300C1`T04PH80P0A1@L01@0B1PL04@D501451@0F2PX05`/;0080
4@D701808ADG0104200H31002000024D6`0B1PX04PH801451`0C1`T05`/=01T=3`0D20X04PH80145
1`0B1PP050P:0186200D1PT801@5200P01<41`0D1@P050D801851`0O4aD06@d?0186200N4Q@04PL8
01041P0J3Q005@T;00T0000>0P@040@601L82`0?00<060T<01l@4`0>008050D801L82`0E1PT04`@7
01@5200E1PT04`@701D62@0I2Pd060T<01831P0D1@P701<41`L04PH:00D03`<701`@500^8RH0?30d
01<72`0601862P0400d11@0>0PH040@800l31`803P865?ooool001_ooooo00P07Q8D01L;3@0@10H0
40D601L;3@0?0`D05@T;01@82P804PH801P050P:01D92`0@10H04@H80186200J3Q0050P:01H:3@0H
31004`L:01T=3`0F2P`03@8300l51P0G20/05@H901@5200E1`L05PP801L92@0E1`H05PP701P:2@0F
20D201<50P8050P800@04@D501<71`0E2@T04PH61P0D20P01P0B1PH060`<01861P0B1PH05@T90104
10804PH601H04`L701@8200E2@T05PX:00/0000A1@D060`<01D92@0H30`04`P800h20P0F2PX04`P8
01P<300?0`<060/;01P:2P0G2@T05PP801@61P0C1@D05PP80P0G2@T01P0F20P05`T901P:2P0H2``0
5`/=01D92`<050P:0P0E2@/0800D20X05`/=0186200A1@L05PX?01D:4@0G31405``@01H;3`0E2``0
5P/?01D:3P0F2a405`/E01X>6@0H31P050L?01D93@0F2Pl05``A01P=4@0I3Q806Q4E01<:3@0E3100
6A<F00`6200F41<05``C01L<500E2Q807Q<K0P0I3QH0:`0B20l06PlG01X?5`0O51`08AHN01/@600N
4Q`06`lI01X?5`0I41D06Q4E020G6P0C3A406A<H01HA5`0H4Q`07ALS01@>600I41H06a8F01`B6P0K
51`071@Q01`D8`0F41h0>CA107EbO@0V8b`05a@L01hL8@0J61/09R@V01dK800I5Qd08QhY01lK:@0K
5bD0920]01hK9P0R7bP0;b`d02DT:P0R8BL00P0T9BT0700R8bL08B8U028S9@0T9BL09BLV02HX9`0W
:BP09RPW02DW9P0R9RT092P[02DY;00V:bl09b``02P]<@0V;C<07bH/02/b>00[=3/0:S<j02Pa>00^
=Cd0;3<k038i@@0`>D00=3e402df?@0c?T@303=0AP0603E2B00hADd0>4IB03U7DP0e@dh0>4IA0P0n
C5L04@13DE`0?deF03i<E@0nC5D0?4YC041<E@1:E5l0EV9^04EAH014Cf40?4UL045=HP18EFT0>dYN
045AHP17EfH0?DeL0080AeMV01H0AUIS049CG@12DeX0@U5H041?D`12DE@0=D9804AAF011CUH0?4I@
049=EP0kB500?DYB041=E00lBDl0@e1F04ECE`0nC4l0@4iA04=AD`11Ce00?de>0P0oCE000`10CU40
@4i?045?D00204=AD@09041>C@0nCDX0@U5=04ACCP11D4`0@D]@03e6C@0oB4l0?4E<0080=3e400T0
>T=:03U2B@0lAD`0>dA;03Q1B010BE00Ae1E0419CP0nB4X00P13CDl06015Ce00A4i?04iHF@1DGUd0
@4Y908fGUP1?FUX0B5EK04MFG@14DeX0@U5H041?EP0oCUD0BeYQ04aKHP17EUd0@4mF03U8C`0hATh0
?4QD045=F@10C5P0@DeH04MDG@80BeQQ01d0C5UP04UGF`15DUL0@U1D04=AE017DEH0AU1C049<CP1:
E5H0BE=D06ihN@1DGUl0?TQ803Do?P14CTd0?DM603U3@P0lA4L0>D5403Lo@P0h@4<0<SXm02hf>@0f
?T40>41304I>D@0b>Sd0>T9502H^<002038h>008034g=`0`=CP0<CHi038g>P0c>3`0;c@h02/`=00/
<CL202ld>P0M02Ta=00]<SH0;S<g02ld>P0[;SD0:2/b02`_>00c<cd0<S8l02l_>`0e=D40>SY603Tk
B00h>TL0<SA102d/?00e<T<0=C9102TV<P0[:340:RH[02hY;00W8b<0:2@U03Hd=`0E4aH0:2HY02@R
9@0/:Rd01@0T8RD03`0U8bH0:RP/01XH7@0/:Rl0IfEZ02<Q9P0U8bP07A/P02LU:P0X9R/06aTN02@R
9`0M6b00@3i402DV:`03028S:008020Q9P0M7R<07b0U024R9`0V9b`09BH[01dM8P0P7R<2028M8@09
020K7`0O6Qh071LK01/F6P0O6Qh08ahR01lJ7P0L5a/07QTM00807aXN100N6Ad0500L5a/06aHJ01dH
700K5QX05a8F01PC5`0R7B<05a8H01XE6`0U82H07APN01PC6@0C3Q@08A`R01hI7`0D3aD06aHL01dG
6`0J4A807A<C0P0N51D0300L4A@06PlC01hC5`0J3a@06PlE01dB600R5ah08QTN01@<4@0M5aT04@/=
01<=3`80618D00X05@lA01TC5@0B30h05@lA018<3P0L5QP07ALI020J702UWj40:28T0P0G4A<02P0R
71h04@/=01LA4`0A2`d050h@01LA4`0B2a80618F01XD600G4AD201@>401E01PB500G4A405Q0@01D?
3`0E40d05A0<01PA2P0I4Pd04PX701D?3`0H4QD06A<G04Y5BP1hMWT0:bTZ01@C4P0J6AH02`X701HD
500C4A8061HG01HD5@0G5AP071XM01dK7P0O7B807A/P024O900T8BP081lU01hR9@0O92L08RP[02<[
;@0U;C009c0d02D^<`0Y=3P0<ci302lj@00d?dD0?D]C03a=E`0oD5X0AEIP04AEG`12Ded0A5EO049C
G@13E5h0=TMA03a=E`0fAe40=D==02hkA00[=Ch0:SDl02Tc>@0U;C<08bT^03i3A`31aLP0PH>501`M
7`0O8B005Q@D01PB4P0I4a<06a<D01`C500M51D0;B<T02HL7@0M4a@05`/=01@82P0E2@/04`L901L;
3@0D20X05@T;01hB500F2P`050P:01D92`0201L;3@0901H:300C1`T050P:01@82P0E2@/050P:0186
200E2@/04PH800@04`L900T04`P901@93@0;0PD04PT<01<8300A1PX04PP901D92`0E20T00P0E1`L0
1`0E1`H050H501451@0S5aL06@d=0104100C1`L01@0D20P0200E2@T05PX:00d0000b92@06@/;0143
0`0G2@T06P`<1@0D1PH01@0E1`H04@<201<50P0E1`@05@L600805PP702H03`8201L92P0@0P@060/=
01d>4@0<00005`P201L81P0F1PP05@@?01D45`0G1Q/04`@L01D67@0G21h05PTJ01@85@0B1Q<07a8O
0963T@0U62<03`<901T=4@0C2@/05@T;0186200C1`X05`/?01H93`0C1P`05`/=01X>400G2`d04`L9
01X>400P51H04PH801@82P805PX<01@04`L901861@0@1@803`@20146100B1`D04@D501041@1nLW@0
BCe101<8300G2Q403P4801862P0C1`T05@T;0186200A1@L06Ph@024E5`8050P:00@04PH800l31@0D
20X050H9100D1@P201D62@0A01<41`0A0PD04`@701831P0C10L050H901451`0B1PP05PX<01L;3@0B
1`T04`L900l41@0B1PP050P:01451`0D20X00P0B0`H01P0b8bH0>2T/024B5@0@0`D060T<01D62@80
4`@70`0D1@P0100I2Pd05`P;01831P0D1@P701<41`0301<72`0B1PX04PH:00804PH:0P0C1`/01@0E
2Pd04PH:030T:00]8RD03@8500H040@800H04PH:01<72`0A1@T04PH:01@8300@10PDooooo`006ooo
ool0200H30h03P@501D92`0I3@l081@F01`@4P0E2@/050P:0P0C1`T05P0D20X05@T;01<71`0B1`L0
4`L901T=4@0=0@D03`<701X>4P0G2`l03P8600`20`0h;2`0HeMG01P9300E1PT050D801D71`0G2@T0
60X:01@61@0F20D201L91P0801H81@0D1P<04PH601D92@0F2PX04`L701861P0E2@T601@820030186
1P0@10@04`L700804PH601<05`/;01H:2P0D20P04`L701@8200E2@T050P801T=3@0H30`04`L700h2
0P0I3@d0:1`L00d10@0E2@T06`l?020D500>0P8040D400805`T800@05PP701D71P0E1`H05@L60P0G
2@P0100H2PT05`T801L9200G2P/201H:30<05@T;05H05PX<0186200C1`T04PH801@82P0H30h05@X?
01H;4`0F2a405@X>01H;3`0G3@h050T=01/@500E2Q406@dG01hB7P0N4Ql05@P?01H:300G2`d05P`=
01L=3P0H3Pl060l@00H0000D2``06A<C01D?3`0B30d05@X@01@94@0H3AD09AXR01`A6@0H3AD08aPP
02@I8@0B1`l07A8J01lD700I3QH03@4;01L;5@0K41P06a8G01lF6P0E30l07ALK01XE6P0F4AL06A<M
01dG8`0J51h060lD01XA5@0M4a/07AHN01dE8P0M5B@0D4UI03Lb@00g=3l03``E01TF7P0]:bh07adN
01lM7`0N72407AXQ01lK9`0O6bT061@S02/W=@0Q7RT081dV02/X<00H5a`08R4W02@U:P0U9RX08b@X
024R9@0Q8R@0824S028T8`808bDT00<08R@S02<U900U:B`00P0U:B`04P0W;30092/a02@[<@0P9bd0
<3U006I_MP1BFf80;3Dl02Xc>P0/<c/0;cHn03<j@P0a>T40=3e402/d>`0b?D<0=45703E2B080=457
00X0=D9:03]9E@0iAe@0>TQE04ECGP13DE`0>TQC03m=F00lBU<0>TQA0P0iAe006@0kAe00@D]E04UE
H@0mBEP0Ce][04YGJ013D680B5EX04UHJ`0oCel0AUIU04EEI010D5h0AUIU04EEHP0oD5X0@55H041?
EP1:FEd0LX6403i;D@0nBe80>DI>03@nB013CeP00P0iATh04P14DEP0@TmE04=@EP15DeL0?de@03e;
CP0lBT`0?4Y;03m=CP0mBdh0?4Y=03]9C00kBDX0?4Y;03i<C010CTh0?di;041?B`80@E1;00L0@4m:
03i7C00nAdh0>dA;03a5C00oB4l0>T=:0080=3e400L0>T=:03a5C00nAdh0C5EL04QAEP0oBD/0>TA6
0080?4I802h0?TQ905=MGP0g@D80A4i=03E0?01PJfL0@4]904=@EP0nC5D0>dUB03a:D`10CUL0@U1I
04]IHP1@GVL0CE]T04ABF`0jB540>4I?03Q4D018E5l0B5EN04=@F@19EUh0CEYR04QEG@17E5X0AUAG
04MEF016E5D0@e5B03m9B`18DU@0>49403U3A@1NJ6T0d]cM075kO00kADD0A4i=04iIE@0^>CD0@D]:
03e5A`0oAdX0>T950P0a>C`0500e?D00<SXm03<k?P0f?T40CEEH03@l?`0h@480<CHh034g=`0`=SH0
;c@g034f>@0c>3/0<3Di02db>00W;380;34g03<h?P0a=S`0;C8f0P0^<cL06`0]<SP0;2lf02`_=P0b
=Ch0=3@n03<c?@0c<Ch0>SQ503dmB@0`<Sh0=CM303LiA@0k>TP0<Blm030]>`0T8BX0<2/b02XU:@0d
;Rh08ahK01hJ6@0L5a/06QDI020K7`0/9b/0;RT]02LR9P0202PS9`0C02TT:00X8bL0:2<W01lJ7`0]
:2h0:2<Y02hY;`0/9bd09R4W02/V;00N6Al091lU02dX;P0O6R00?cY0059@EP0W:2d08R<X01lP9@02
020Q9P0<024R9`0W:2d09BH[01TJ7`0O82D06QXO02DP9P0U7b<08A/O01hH700M5a/071HJ0P0M5a/3
01hH700501lI7@0O6Qh07aXN01lJ7P0N6Ad00P0M61`02P0S7R808A`P02<N8P0P6al061<G01TD600>
2@l05A0G020K8P0O6R4201`G7P0;04a7CP2i];/0=2lf030[<P0R7B@0@ca301hE5P0M4a<06Q0A01T?
400L4A@00P0N4aL05@0J3a@060dC01T>500J3aH06A0E01L>4`0L5QP06A<E020J700C3@l06aDG01@>
400H4Q@050h@01XD5P0A2`d02P@601D?4@0B30h030H8014;3@0201H@4P0U018<3P0L5QP03@L901H@
4P0B30h09b4S018;4P0E3a<0618F01TC5`0G4A<05@lA01lI6`0H4Q8050h>01<=3@0F4@h061<?01XC
2`0H4@/050`902@O7P0W8BD04``C014<4P0G5AP040h?01<A4@0F5A404Q4=03Dc<`0T8R<05A<D01HD
5@0P7R406ALJ01HD5`0201/I7P0W024O900V8bX08b8X01dR9@0L92H08BT[02@/;P0U;c409Rlc02L`
=@0Z=CT0<3]003@oA@0h@dT0?DaD03e?F@0nD5X0AEMQ04AFH017FF<0B5YT03I8DP0oDE/0>TaF03a>
F00V>480;Ce6034nA`0^>d<0:cHo02Lb>00U;S<082T]01XO8`0/<3<08RHX01<G600I6Q`04a4A0080
5@l?00T05Ph?01H=3P0F3@h08aTJ01D;300>10D06@d?01/?4@0J3Q000`0H30h00`0F2P`05@T;01<7
2@0301@82P@04`L901<040@601<72@0C1`T040@601D92`0<00805PX<01<72@0@10H06Ph@01H;3@0J
3a<03`H901@;3P0=0PH04`P<0147200B1PP050L800805@L70P0F20L01P0@10@04`L701451@0?0`<0
50P801`@40<04PH600/04`L701H:2P0H30`050H601L92@0@0P805@L701P:2P0=00005PP801D71`02
01@61P0501<51@0B10<04P@301<50P0D1P<00`0E1`H09`0S5AD03`<3020A500L3A00404402DG5P0E
1`005PL201H61`0F11<06@LO01/8900G1bD05`LR01H77P0D21L04`LA01<8400<00T0:A`V00P0100L
3aD0300400h2100E2@/04PH:01D93@0M41P07A0I01X=5P0E2@`05@T;01<72@0?0`D04@D701@82P0A
1@L04PH801@82P0201H:300>01D:2@0B1`<04PL301@91P0E2PP05@T901861`0B1PP04`L;01862`09
00<04`H=01L;3`0B1PP201@82P0900h2100C1`T0710B00d10`0@10H040D600d10`0F2P`04`H80080
4`@701d050D801D62@0E1PT05`P;01<41`0A0PD05@H901<41`0E1PT050L901041P0B1PP03@4300X0
000?0`D04`L900l31@0B1PP05PX<01451`0=0@<050D801421@0J2`h05`P;00d00@0A10D060T<01H7
2P0201831P8050D800H04@8501H72P0E1PT04@8501<41`0D1@P601<41`804`L;0P0A1@T0200B1PX0
4`L;01P<400G2`l03P8601<72`0>10H03@45200A1@T0100=0@D03`<701@8300>0PHDooooo`006ooo
ool0100N4Q8040@401`@400@10@201D92@H050P801h03P8201051@0E2@/07A4C0145200B1PP04PH:
01862@0I3@l03`@50104100O4a<060T<01D62@0D1@P05@L701L92@0H2PX05@L601H81`0E1`@05`T7
01P:2@0G2@P04@D501D92@0J3Ph04`L700h20P0E2@T701@8200=0186200H30`040@40104100L4100
4@D501L;2`0K40h06a0?01D:200C20L06@d=00l30`0201D92@0900h20P0L41803@4301P<3P0D20X0
4`L901451`0G2P/05PP700<05`T800P060X901L9200G2@P060X901T;2P0G2@P05PP701H92P805PX<
05P05@T;01H:300G2`d05`/=01@82P0F2P`04@D701T=3`0P51H05``A01L<4P0E2Q0050T=01D:3P0H
3Pl060dA02@I7@0H3A@04@D?01@84P0C1a805PT@01H:300G2`h05P/?01L=3P0G3@l05`hA02HM7P0B
2@/040L:014;2`0G3Q405@`A01L=5@0Q5Qh0=2Ta02TO9`0S6B404@H>024G7`0J41P06PlG01@:4P0J
3aL06a0H024F7P0H3AD06@lG02dS:`0Q6al071HJ01PC5`0I51X06aHM01XD7`0F41X05a4E01XD5`0M
5Qd07QLO01hG900M5bD0C4ID03Lb@00O72L07a`U01`J7`0L6Qd0928S01dK7@0O7B8081dT01dJ900N
72T0;BTg01dK:00V9340:2Ha01dL900X9bd08R<X02DV:`0V9b/092DY028S9P0Q8R@08b@V100V9bT0
5`0V9b/09RT]02@W;00T9b`08bP]028W;@0O9R`09Rdc01hU;@0h@DP0;CHm02`e?00]=Sd0<CY103@m
AP0c?4<0;CLo03U2B`0e@4H0<3Y203A1B@0f@dT0=D990080=D9:00H0=D=?03A2C`0oCEP0F6I`05ES
KP16E5l203]9E00T03Q6D@0gAE00>TQE041>F010CEH0Ae=O03m<F@1<FFT0AE9S04UFJ01EHWD0EFEe
03a<G016EVH0CUi]03i>G@10D5d0?dmL03]<E@0oD5P0@E1G03e<D@0iAT`0AeAJ03]8C`1AFf@0AU1I
06A`N00iAT`0<d18045>E00oC580>DI<03Q6B@0iAdX0?4Y=0P10CTl04`0nC4d0@e5D045?DP10C500
?dY>03e;C010C4h0@4a<045?C`13D4h0?DU703M6@`0kAdD0?4M903m8C@0j@dP0?TM<04M@E@0oB4l0
0P0i@TT0EP0lADd0>dA=03a5CP1:De/0Ae1E045;C@0mAdP0?4I803Y4A@0mAdP0>dE603e7AP0h@T00
AU5=02dh=011C4T0?de@03U8CP0fAD`0>DM@045?F@15Deh0BUQU055OJ`1@GVT0B5IQ03e;E00kBE80
?DYC055NI`1?G6@0A55J04=@F014DET0B5EK04AAEP13DE@0A59E049@DP0lBT/0@De=04=?C@14D500
DUaM03]5AP1OJFX0A4i?03e7B00^>3T0:S@e03Y4A@0_>CX0;SPj03U2A00d?3l09Rha02de>00g?d80
;cLj02hf>@1@EEP0Ri2D02L/<00m@TD0;C<d030e>00a=ST0=3Tl03Xo@P0m@TD0;S<g02`a=`0U:S00
;2lf03@g?P0c=Sd0<3Dk038g?@0_=3X0:blh02la?@0d=T80:2Xf030b?P0f=T80=cM30P0e=D40>00`
<ch0;C4l02/_>P0a<cl0;blk03Dd?P0T8b/0;BXa02DR900e<C009B4N02DP8P0b<3<09b8X02<O900Z
:2/04@`B02XW:`0V92L0:B@Z02TV:P0X9RT0:RD[02LR:00S7R@0;RT_02<N900G4QP07aXP02<N900/
9bd0:RD[01XE6`0h<cT0K6M]03<a=`0X:Bh08R<X01hO900O82D0824V024Q9`0G5Q`09B@Z02@S:@0R
8BL0>SPn02TT:P0W82L08AXQ01`E700K5AT06aDJ02DO8`0S7B4081XN0P0O6Ad0TP0M5a/07aXP01lJ
800O6R007QTO01dH700M61d07APL01/F6P0P6al07QTM01LB5P0J5AT081/Q01`G7@0D3aH06A@K01lJ
800E41L09R4X0:FPYP0X8bT03`XA01lJ8@0U7b<09ahO020F5@0F3@h050/<01L>4@0J51P06A0E01P?
500I41D06a8G01dB600I41D08APK00l92`0K5AL0<R`^01H@4P0E3a4050h@01TC5@0A2`d05Q0B01D?
4@0J51H050h@01D>400_:B/07A@G01`D5`0=1`T05@`?01H>4@0M5aT06a8E018:3@0B30h06Q@H01LA
5@0F41@05a4E01<=3`0@2P`0618D01TC4`0J51@06A<C01LA4@0F4@h06Q<=01XB3`0G3`d0=S0a03/e
>@0D3Q806aHK01TD600D4Q<04a4@01/G500B3P/0Ddm?03/g>00H51D06A@H02TT:P0D4QL061DJ01XH
7@0I5a`07Q`Q028O9P0O7R@07b8U01hS9P0S:2/09Rha02L_<P0X<CH0;3Dl02hi?`0c?DD0>DI>03]8
D00oCeP0?U1J03e?F`12E5l0@eEO04YLJ01RM7l0BeeW04AFHP0kCEP0?DmI02m1C@0jBU<0=45:03A1
B@0[=cl08bdf02</<`0O:2`0<3Di01/O8P0P92H071dO014B500K6A/06A<E01PB500G41405Pd>01D<
3@0C2@X050X;01`B4`0M4A<05@T;01H:300D2P/04PP90P0F30d01@0A1`P05@T:01D92`0D20X04`L9
00804PH800<04`L901D92`0A1@L00P0D20X0400A1@L060`>01<72@0Q5AL07A4C01P<3P0W6ad08QHH
01462P09008040D900T00P0E2Ph05PX<01451`0C1PL201D71`0601H8200G2@T05@T90104100D20P0
5`/;0P0A1`H03`0E2`X050X901<71`0B1PH050P801D92@0D1PH04PH6020B4P0A0`<050H6024C4`0G
2@T05PP801D71`0201<51@0301430`0D1PD05@L500805@L6024050H501<5100A0`<06`d>00/0000C
1PP050D801840`0D1`005@L401D62`0F1aL06@TS01/<:@0J2bT05`TS01H87`0D2AL04`TA01@93`0F
2A803P4801H9400<0@@0710B01D92`0A1@L03@4500l31`0F2A0050L@01442`0D20/00P0E2@/02P0D
20X05PX<01P<3P0F2P`04`L90186200C1`T05@T;01<81`0@1@<20146100E0104100?0`<050P90145
1`0<00@050P<01P<400900<05PX>01041P0B1PP05`/=00l31@0=0@<050P:00P0000?0`D04`L900l3
1@0J3Q0050L900804`@701d050D801D62@0E1PT05PL:01421@0@0@@050D801421@0D1@P05`X<01@8
2P0?0`D040@601D92`0@10H04PH801<72@0@10H03P840186200C1`T050D801L82`0L3A006``?00l0
0`0F1`X06@X=01H72P0201831P8050D800H0404401@5200D1@P04@8501<41`0D1@P601<41`0<01@8
300C1`/04@D90104200B1PX050P<01X>4P0?0`L0710D00d11@0D20`04@D91P0B1PX201<72`0400h2
1P0@10P05PX>00l31aCooooo000Kooooo`0301@91P0C20D05@X700805P/805D050T6020E4P0A1P@0
7Q<@020E4P0A1`D04@H301@8200?10@040D501451@0F2`/050P801/?400H30d050P80104100A1@D0
50P801D92@0D20P05`/;01T=3@0D20P05PX:01<71`0E2@T05`/:01H:2P0C1`L04@D501861P0F2PX0
40@401L;2`0M4A405`/;01@8200B1PH04`L701D92@0C1`L04@D501@92`0B20X060`?00l41P0U6AT0
M6QX01P=2`0D2@H050T501D:1`0D2@@04@L501881P0C2@P04PP801882@0C2@/04@H:01P=4P0:0@H0
6a0H00l4300A1@h0@CDi01/?3`0C1`L05@T901@8200C1`L050P801L;2`0/82008aLG0188200J3Ph0
60`=0104200Z7R806@dA01@83010=3P05P/>00804PH:00<05PX>01862P0B1PX00P0H31000`0F2Ph0
50P<01@8300301H:3P0501L;400J3A<06PhC01L;400E2Q000P0G3140B@0D2@l050T>01P=4P0F2a40
6PlD01D:3`0E2Q0050X>02HL8P0S6Ql05a4E018;3`0H4AD0618F01TB5P0K51P04`dA01XD600I4QH0
4`dA01PA5@0I418071<E01/A6P0I41h08ATW01lG8P0J51X06aPH01LF5@0J61X07AXQ01DB6`0I5Q/0
6aPL01XF7@0H51`06QHQ01hJ9`0M6RH06QLP01`J800L6Qh06QPH01dL6`0M7Al071/O01dL8@0P7bD0
8b8Z028R:`0P7bX0824/024R;P0P8Bh07R0/01XN:00R8Rd092@/02@T:`0T9BX08b@W028S9@0U9RP0
:2T^02TZ;`0X:Bl0;Bdf02DU;P0W9c008bH^02@W;`0Y;CD00P0Z;SL00`0/<CX0;SDm02he?@0202`c
>`0j02df?@0f@DX0:3@m02hj@`0`?DD0<Ca602llA00d@DX0=D9;03=0B@0c@4P0=D9;03M4C@0kBE@0
=dE?03m=EP10CeH0JGR004ECF`0lBUD0@e1O03Q5EP19EVP0>TML03m=G@0nCEP0@51J04EEH@17Ef@0
AeMV049BH@11DF40@U5T04ACIP1;FVh0AeIZ041?GP10CUT0?TaF03e;E00nC5D0?daD03m;D`0lAdh0
AU5G04]FG00j@dX0CEIM05IQI`0gADP0A59F05i/K`18EUT0?4Y<04=ADP0lBT/0>TQ8045?C`80?Ta<
03H0@deA04==E014CUD0A4eD04==DP12C580@T]A04E?E010BDl0ATmE05EOI@1FH6D0A51@041<BP11
CD`0@di?03i9B`0kAT/0=T57041:D`0g@DX0?4IB03m9E@11BUH0@4Q<03e6AP0lA4@0?dQ8045:B@0l
AD@0?dQ603Y3@00kA400?dQ403a5@00jA400>dM403e;BP12D5<0@DiG04=?GP1>FFd0DEaa04aGJ`1;
EfP0BEET045=F00b?dP0>49:03i9D012CE<0@diE03m:D011C58204IAE`80A4mE04l0@diC045=C`11
D4T0IWM/04EEC014DT`0?DY703m;B`10Bd`0>49603Y3B@0i@TX0<ca503<lA00g@4D0>495034k?@0/
=SP0<CTl03<k?P0j?d80<3@f038f=`0h>cd0;Rlc03Hg>`0`<SH0=CPm03@i?@0_=SX0=cm203<k?P0b
=c/0:bhc02X]<P0];380=C<i03dk@P0g>T<0<3@n02lc?`0d>4H0:Rdo02d_@P0b=DP0SI2P0412D00]
<3/0>3a5030d?@0/=3d0;3@n02de?`0_=cl0;S@k02lc>@1GFUl0?T14028S9P0S8b@092<T02@S9`0U
92X09bD[02DT:@0N7B<08b4W02/Z<00P7bD09bD/02DT:P0W9R`0<2hd02<Q:00[:2l09R<Z02@Q:00Z
9bh0924X00808b0W00T0924X028O9P0Q7RD08QlV024O9@0R8BH09bH[02@S:00M72400`0N7240?@0O
6b406QHL01XG700T7R@081XS01lI8P0R72D081/R01XE700K5Qd07aXP01hI7`0L5a/06aHJ01`G6`0N
6Ah08A`S01/E7P0J51d07QTP01XE700I51/071LM01/F700T7b<0:RDY02<N8P0M61`0618F01TC5`0J
4aP06A8H01/E6@0M5a`071HK01dG6`0Q6b005PlE01L@5@0I4aD081LD01/C3`0M61D05Q8A01/I700A
4AH05aHK01DB600H4aL06Q@H01/A4`0E30d07aHI01@>400O6A/0>C<e01XD5P0E3a406A<E01H@4P0E
3a400P0F41803P0D3Q006a4D01H<400Q5a/0:b0T02<I700F31005``@01H;3`0D2Ph05P/?01P>4@0I
41<05PlA1P0E3a40;@0B30h06Q@F01@>400=1`T071HG01LA4P1ECe00=2h_01@>400H4Q@06A<E01XD
5`0B30h06aHG01HA4P0L5QL05Q0A01dD5P0K4aH071DI01D=5@0Q6R<071DN01`E800T7RP06A<L02<N
9@0L5ad08AlT02DS:@0O7bD09bP^02`_=P0U:S40:2lh02`e?P0^>480<3e603E3C@0kBUH0?U1L04YL
J@1>H6h0AeUV04YLJ@0204YLJP0n04IHI@10DV00?e5O03mAGP0kCE/0=TQC03M7C`0d@T/0:cQ102/g
?`0Y<ST08b/`024V:P0W:bl0<C4e024Q8`0H5aT07ATM01H@5@0J4AH06a8G01P?4`0K41@04`P<01T>
4P0G2`d060`>00l31@0E2P/04`X=01@<400F3Q004PT:00h61@0G3P`050X901<9200D2PT05`/>01L;
3`0D20d04`@801L82`0M3Q4070d@01P9300D1@P04@8501X;3P0F1`X05`P;01<41`0F1`X050L901<6
200C1`T06@/>01851`0E1`T06P/>01L82`0E1PT201H72P0A01D7200B1PH04@H601H<2`0S6QT0>S<a
01@=2`0>20D04@X900`30P0A1`H05@X:01L;2`0L3Ph060X:01@61P0E1`L00P0F20P601@61P0601<5
1@0E1`L05@L701<51@0D1PH05@L70`0D1PH301D71`0=01D:2P0L41D040D>01465`0C2R805@hV014:
8P0@2Ql05a4Q01<<5P0H4AL04PT<01<62P0201@52@<050D801P05`P;01@5200C10L050D901H72`0G
20`05PX<00`10P0I3@l04PL902HJ700>10D04`L901D92`0B1PP04`L901451`0>0P@050P901<7200B
1PL07a<E020D5P0E2@/201451`040186200C1`T04`L:01<62PD04`@901004P<801@52P0D1@X04`@9
01T:3`0H2@h04PD801451`0@10H03`<501041P0C1`T04PH801451`0C1`T04PH80`0A1@L01@0B1PP0
50P:01@82P0C1`T04PH800H04@D701P060`@01472@0B1`X050X<04i2AP0F2`h06PhB00`2100F2Ph0
:AdQ01H:3P0B1PX050P<0104200C1`/060`@01D93@0A1@T05@T=0104200D20`03@4500d31@0D20`2
01862P0301@8300=0`D04`P;00<04`L;0P0B1PX201452@0<01H:3P0@10P050P<01D93@0F2Ph040D8
01452@0J3Q804@D90104200B1PX03P865?ooool001_ooooo02003P<001<8100C20@040D101<8100J
3`/0?34]020E4@16>cL0C44m01hC3`0O51004`L701D92@0L410040@400/10@0<00003@4100h30`0M
4A405`/;00h20P0E2@T0:alO00P0000C1`L050P801H:2P0I3@d04PH601<71`8050P800T04PH60145
1@0F2PX060`<01861P0E2@T06@d=01@8200E2@T00P0?0`<07`0A1@D04`L701<71`1QEET07a<G01H:
3P0J3Q00200001@8200C20H04PL301<8100F2`L050T301D:200I3a003P@501/A4P0J41402`0400l6
200K41@04@H<02hS:@0L4AL04`P@01@8300B1PH04@D501L;2`0F2PX00P0D20P0300E2@T09QXJ02`P
800P51@06@d=00T0000n<SH0`;Bh04e1A@0800003P8601dA5@804`L;00d05PX>01<72`0C1`/0710D
01dA5@0G2`l04`L;01@8300H31005`/?01D93@0D20`05PX>00805`/?03405``B01D:400E2Q0060dC
01/@5P0M4QP03@8801D:400S61h08AHL01H;4@0E2a407A@I01<=4@0@2Ph050hB01D?4`0H4QH06Q@H
018<400N61`050hB00l93@0J51L06Q4B01/B4`0I3aP05@dL01XA8@0I4A`06QDK01`J6@0H5aD05aDF
01LE700C41T06ALL01LE6@0F4aX061DN01TF800I5R4061DP01LD700L6Ql07Q`O01`K6@0O7Q`0820R
00807A`R00D07ahT020O9P0N7RH08B4[01lP:`0201dO:`0?01lR;P0P92l08b<_02@T;@0U9Bd09BH[
02@U:@0S92H07AhP01hO900T9BX0820X02LW<@0T92h0:2/d00<0:Rdf00<0:2`e02T]=P0[;cP00P0]
=3`202/d>`0902`e?00Q;CH0;ca503I3C00b?dP0=dA=02hkA00e@T/0<Sm80080<3e601`0=T=<03Y7
D010CUT0=TA=03Q6C`0fAD`0>dYA02hmA00nC5L0?DYJ04MDIP0jAeX0=41H03I4E@0kC5H0?TmI03i?
FP10D5d0AEET04MGIP19FFT0BEQ[04=BI@11D6<0@E1U03e;F`0jB540?4YC0P0oCEH06P0oC5@0AE1I
045;E00oBU00BeEJ04E>D`0kA4T0?TU=03=1A00iAdX0Df5T03e;CP0hATL0@4i?03Y8B@0nC4d0@U1A
03a:B`0oCDd0@DY?04=<D`17D5L0B55H04E>E@10BE00?4E<0P0kA4/0:00mATd0@4U@04A=D`18E5@0
@De=03e9B@0lAdT0>4=503Q3A`0e@4H0=3m503M1BP0c?DL0?4I@04E?F@0nATP0=d0m038k>00i@T40
?TM603a5A00oB4L0?4E403i7A@0kA4<0=Sll03M1@010C4X0@Dm@04ICF@14D5`0@DeO04QCJ@1KIW`0
Ef9g04IAH`15DEl0=D9<04MDG01=F5h203a7B`1603@o@`12CE40@4]?04IAE@15D5@0@diB045<D010
Bdl0?TU;041?BP2AX9P0@U5<03U8@`19Ee@0=d=303m:C00f@4D0?dQ?04YAF`14BeD0=3e403<m?`0g
@D80@DU;03Lo@@0`>3X0=Si003m4A`13B4/0=3Tl03@h>`0E61d0>3]003Dh?@0[;S<0;C8f03Hn@@0`
>3/0;cLj02`b=P0Y;3409bX_02DT:P0[:2l0<S4g030b>`0`<Sh0;2hk02h`@00/;D40<cA803DfBP11
@U@0;c5002d_?00i?4D0<SHo02lf@00X;cL0:S4i02le?@0Z;cD0:2/a059CF00n?d<0824T024Q8`0[
:bd0:RX^02HU:`809bH/00D092<Y02TX;P0];3808R4W02HU:`02024P9P0@02h]<`0W9B/0:2D/02DR
:@0S82L09b@[02PU;00Z9bh0924X028O9P0O72<07Q/R024N9@0T8RP08b8W028Q9P8092<X00d08AlT
01lM8P0N72407aXP01`G7@0J5A/06Q<J028L9P0N62807aTS020K8P0N6B008ahU00807QTO01D07QTM
01dH700M61`071LL01PC6P0S7BL08A/U01dH7`0]:2l05a8I01`G7@0J5A/07aXN02<N8P0O6Qh071LK
01lI7@0J51P05a4E01XD600L5QX00P0I4aL06P0G4AD06Q@H034[;`0O6Ad05Q0B020F500H40`05A0=
01/G5P0B41<06QTN01XI7`0C4QL03PT=024K7`0C2P`07aHG01L>4@0J51H05Q0B024K7@0E3a407ALI
01LA4`0E3a4050h@0P0E3a403`0C3@l06PlC01P=4@0H3A405P/?01L<400P5AT06a0D01H;3`0C20`0
5``@01X?4`0H3a8050`?01@>400201D?4@0A01<=3`0B30h06Q@F01<=3`0<1PP050h@014;3@0H4Q@0
6Q@F04<m?`0T7R005Q0B01D?4@0500406A<E014;3@0=1`T00P0W8B<03@0:10H05Q0@01XD5P0D3Q80
71DM01`D7`0<1Q007aTU01/E7`0H5Ah08b0W01/I7P0P7b@00P0V9B/0=P0X:2l0:2/b02@X<@0/<c`0
=T1903U3C@0b?dT0>DMB041@G@0nCed0BUaZ04AFI01;GF/0CV1^045CH@1<GV`0BE]Y04MII`18FVP0
AUQV041BH00iBeH0>4UA03M5CP0c@4T0<Sm7034j@@0Z<CP08bP/02@W;00Y:Bh07A`Q01PH6P0O6b00
50dD01<=4@0I4AH06a8G01XA500I3Q8050T=01T=3`0D20X06@d?01P=3P0A20/06Q@H01@>3`0G3Pl0
5`l=00P1000D2PP04`T701@:2@805PX>01@050P=01H7300G20/05`P;01D62@0D1@P05PL:01d>4@0>
00805PL:01L82`0B0`H04`@701421@0@0@@0814D00/0000I2Pd03P4201H72P<05@H901@04`@700h0
0P0M4A405P/:01881`11>CL0TX^901D@3@0;1P<05Pl=01/C4@0F30/04`P701L;2`0]7al070h>0102
0P0B10@05`T901D71`H050H601T04`D501D71`0E1`L04`D501@61P0E1`L060X:01L92@0F20P05@L7
01@61P0C1@D06Pd<01052@0F31@05P`K00h66`0B2R402PHK01<>8P0I5BH02`DA00l5400J3aL04`H9
00D050D800l05`P;01@5200C10L050D801H72P0G20/04@L800d10`0L41808QHH081dMP0k;c404`L9
01D92`0C1`T00P0D20X01`0@10H050P:01@82P0@10H05`/=01H:300@10H00P0A1@L0100B1PP04`L9
01<72@0C1PT601<42@0<01D62`0F1``05`P=01X;400F1``040<60186200E2@/04`L900l31@0@10H0
4PH80P0@10H01@0D20X05@T;01451`0@10H04@D700<04PH800<04@D701@82P0D20X0100D20X03008
00004`L;01H:3P080000@cLk01862P0G2`l03P8601D93@0O4aL04@D901<72`803`<700T040@801@8
300G2`l04@D900T00@0D20`03`D701862P0N4QH00P0@10P01@0;00<03`D702lS9`0B1PX020000080
4`L;0`0B1PX03@0A1@T04`L;01@8300@10P04@D9030T:00k;c<08ADI00h21P0D20`03`<701X>4P0F
2Ph05?ooool001_ooooo100E2PL07P0D2@H04`P501<81@0C20H04PL401D:1`0F2`T03P@301X>3P0A
1@D04`L70188200D2@T060`<01D;2`0F2PX0;R8R02DI6@0E2@T07A4A038V9P0@1@D07A4A01861P0H
30`03@4101<71`0D20P05@T901H:2P805@T901<050P801D92@0A1@D04`L701@8200B1PH05@T901<7
1`0D20P05PX:01D92@0C1`L0@cLj020D5`0D20/04`P901D;2`0I3@d050T700804`P502405@X60187
0P0F30X07Q@F02PM8P0D2`d03`@701lD600D2@d030<5024F6P2MTYH0;28T00/21@0F2``05@T901L;
2`0M4A406Ph>01H:2P0E2@T04`L701D92@0E2PX04`L701@8200D20X02`4303hb=P0H31006PhB01@8
300F2Ph01@0E2@d0100G2`l060`@01L;3`0F2Ph201L;3`0401T=4@0G2`l05@T=01L;3`806@dA00<0
6@hD01H;4@0F2a400P0J3aD0100E2Q0081DK01D:400I3Q@201@93`0Q01P>4`0J4AH05@lC01LA5@0H
4QH05@lC01LA5@0L5QX05@lC03D_<`0/9RX06A<G01LA500K4Q<06Q4C01T?600F3Q`06A4O01/C7@0F
4AD07A/I01/J600F51H08QlW03Pe?`0L6R0061HL01TF7@0L6B8071TS01PE7`0J5b0061DL008071XM
00<06APG01`J6P0N7R400P0L6b407P0N7B@08B0X01lO9`0M7BL07QlY01hQ:`0P8Rh082<_01lS;P0P
82X08R8[02<S:`0S92T08b@X02<T9P0V9bT092DZ03@e>P0V9Rh09RH`02TY<`0W:S<0;2lh02d`>@0Z
;CH0:Rhg02``>@0Y<3P0:S4i02/c>`80;3Dl00h0:cHl02dh@P0`?DH0:cQ107N4S@1?G6D0;CY303=0
B@0d@DX0<d1903A1BP0f@d`0>4E>03i<E`80>DM@00h0@U5H0391B00mC5<0?TaG03A1D@1@GFl0>TMJ
03e9H@0iB5T0?4eG045AG@10DEd0?dmL04ADH`80C5a/00h0AeMX04EEIP14E6D0@e9T041?G00nC5D0
?D]D03e<E00oCED0@DiF045=E@11C580?dY@03m9CP80@4U>00D0>dI:03U7BP0mBdh0?Ta?03m=D002
03e;C@0=041>D00nC4h0?de?041>D00oCDl0@diC04A>E@15CeD0A4iD049<D`10BU40@TaB041:D002
04==E00]03m9D014CU@0@4]>03e9BP10Bdh0@diA03i9C00iA4P0?TU>03Q3B012C5<0=T58049<E01>
F600BE=B041:AP0f@3/0>D=003]5@`0g@3l0?4E503U2@P0i@T<0>D9403Y3A@18DE@0AU5E04=@EP15
DUd0AE5P04IAI@1>FFl0D5]a04A?H`15DF80BEER04EBFP2]^kl0SIRL03]6B@0oBTd0>dI9041;CP13
CU40@Da?0080@4]>0P0oBTd0800nBD/0?4Y904MFE00nCD`0>DI703e9BP0iA4L0=d5503@m@P0i@DL0
@4M>03i5C@0d>d00@4M802lf=@0nADH0A4]<03@k?@0b>3/0CE=F05UPH`0a=c`0<SPm030f?@0Y;c@0
<SDk02X_=00^<cP0=Se202Ta=@0]=SX0;3<h0P0U:2h0<`0X9bh09R<[02HU;@0_<CX0<38n02la?@0k
?D/0=cQ903PiBP0`<D<0<39103DgA00T9S80;S4j02/^=`0^<S`0;S8k02d`>@0Y;3@09BL^028S:P0]
;C<08b<X02LV:`0K6Qd08b8U02XY;P0W9R`09B@Z02HU:`0T8bT0:2L]02XY;`0S8RP092<Y02PW;@0T
8bT08b8X02/Y;`0`;C@09b@[02HS:P0W92/07a`S02DR:@0W92/09R<Z02@Q:00U8RT0:BH]02PV;003
02@S:004028Q9P0Q7b@08b4V024O90<07QTO01L07QLN01lI8`0M5b4081XT01lJ8@0I51/06QDL01/F
700L5ad07aXN01hI7@0L5a/06A@I01lJ8@0K5Al08A/U02<N9@0>2A0081/R01/F700I51X061<G01XE
6@0201`G6`0K01XD600I4aL07QPL01hH700I4aL06aDI038/<00H4QH07aTM014;3`0L5QX060lB01X@
3P0P5Q@0;2@R03La<@0H51P061LL01DA5`0I51X03@H=02DL8@0O51P06Q0B01<:3@0J51H04P`>0080
5Q0B00h05a4C01D?4@0D3Q0050h@01H@4P0E3a404P`>01D:3P0G3100714E01/@500D2@d05P/?01T>
4P805@X>00D06PlC01hC5`0L4aH04PX=01<=3`0201D?4@<04`d?03405a4C018<3P0P6Q`05@lA014;
3@0A30d0618D01TC5@0F41807ALI02XT9P0J51H04P`>020J700R71h02`D7028L7P0I51<07APJ01<>
400G4QP040/E024L9P0F4ad08R0X024Q:@0L6b006a/O028R9P0X9bd0:BT_02LY;`0V:C0092Pa02`d
?@0i@d`0?T]D03U7D@0nCUP0@U9O04QII`0mCed0DVAb08>EX`1VN8H0DVAb05AVM01@HW00Cf5_0080
D69`0280Cf5_04IGHP0kC5D0>4M@03E2B`0_?4@0;3Lm02Ta=`0T:Bl08B@Y020R9`0M7B80820S028N
8`0F3aH06aDI01dF6P0E3Q805@`?01/@500@1@T06Pl@01451`0J3Q005@X;01<:3@0D3Q805Q0A01/B
4`0S6aT05`l=01@:200C2@L04`T80P0F2Ph0100C1``050D:01D62@0F1`X201@5200P01H72P0J2`h0
3P0201/<3`0C10L06@X=01H72P0E1PT05PX;03<T9`0C10L06P/>01@7200D1@P060T<01L82`0E1PT0
50D801P9300E2@T060d<01881`0C2`T07aTG00h91P0C3P/030L501H>300C2@P040H601<71`0E1`L2
01L92@0301H8200D1PH04P@400H050H600H04`D501D71`0E1`L04`D501@61P0E1`L501H8200>01H8
1`0H30P03`<301882P1IDEX0DdaK00`65`0I52T01`4G018:800D31h081@V00h3400C1@X501@52003
01H72P0E1PT05@H900805@H901<05PL:01<72@0A1@L05@T;01<92P0O4aD050X;0186200C1`T040@6
01<72@0D20X040@601<72@0D20X04`L901D92`0C1`T040@600804@D700@04PH801<72@0C1`T04`H9
1@0C10T301@52P805PL<00l04`@901<52@0F2P`05`/=01<72@0?0`D04PH801D92`0A1@L040@601<7
2@0@10H04@D701<72@0B1PP00`0C1`T00`0B1PP04`L901<72@0401<72@05020D600A1@T04`L;0186
2P0D20`00P0A1@T05`0@10P04PH:01862P0>0PH04PH:01<72`0G2`l04`L;00h21P0B1PX050P<00l3
1`0C1`/0?c@g075UJ@0I3a404PL:00/10`0G2`l0;20T0;jb]P0S5a/040@800H04PH:00`05@T=01H:
3P0?0`L08aLK09R<T03Sfml0Ge=G01hB5P0F2Ph03@4501`@500F2PhDooooo`006oooool02@0U6QP0
5``:00`1000>0`4050T701D:200?10804PL501<81P0201050`0301<81P0@10@060`<00806@d=00D0
714A0104100O4a<05@T901/?3`0201D92@07024E5@0<0P803`<301861P0?10@06`l?00h20P020104
100401451@0B1PH04`L701<71`805@T902P050P801D92@0F2PX05PX:01451@0B1PH050P801D92@0A
1@D03P8201061`0D20X05PX<01P<3P0K3`l05`/;01P=2`0D2@L04PL501<8100B1`<030<20<Fj`01[
H6H08QTM081eN@0H3A4050T=02@J6`0B20T050X;01`B4@0Z81l05@X:01@8200F2PX06Ph>01D92@0C
1`L04PH60P0G2`/0100D20P04PH601861P0L414200h21P0401X>4P0;00<02P0200h41P805`/?00<0
50P<01L;3`0G2`l00P0B1PX01@0F2Ph060`@01L;3`0E2@d06@dA00805`/?02`06@dA01X>4P0J3Q80
6@hD01D:400@1@/050T?01dB600Y7R@02@0401873@0k<3H09Q/Q01L<4P0F31806a8G01D?4`0B3100
4@/?01@>4P0V82@01`45018<400K5AT03PP<01/E6@0C3A407A@G01T@4`0I3aT06A4N01TA7@0N5al0
5A0D01/I5P0I61H04a4D01hK900j=d807AXQ01`J800L6B007AXS01`I8P806AHO00H05Q@J01XH7@0L
6Qd06aTJ020N7`0L6b0201/J800Y01hM9@0P82P07alW01dM9`0P8R/092L`02DW<`0S9S407b<^01`O
:00O7bP08B4Y024R9`0R8bL08B8T02HW:@0U9R/0?d1502LW;`0O7bT092L`02HY<P0Y;3D0:Rdf02X^
=`0[;cP0;30i02P_=`0W<3L0:C8i02df?@0/=C`0:C@j02hkA00[>440>dQA02Xg@00_?4D0@4eF034n
A`0gA4d00P0hADh203M4C@0D03M5D00iAe00<d5:041?EP0_?TD0@U5H03i<E`11CUh0@e1R038oDP14
D6P0CE]^03m@FP13Df00A5AQ049BG`13Df80C5a[04YJJ@13Df<204IFIP0M045AH@11D5d0@DmH03i<
E@0lBe<0?TeD045>EP1LJ6l0H6]a04]FFP13CE80ADiC0419CP10Bdl0=dE8030n@@0e@dH0<Cm203U7
BP18EUT0@U1C03a:C@0oCE00BUQK04UGFP14CeD0@diD045<DP0oBU000P0nBDl303a7C@0903e8CP0n
BDl0?TU?04A?D`0nBDd0>dI:03m:CP10Bdl0AU5E0080Ae9F06D0AE1D03@o@`0e@4@0>TE8041;A`0l
Ad40>4<m03Q3?`0iA400=T10049<C@0jA4H0<C/n02hg?00`>D00?TM?03e7D@0jAU<0@TiN04QCI`1>
FFh0F6=i051KL@1<EfT0?TYH04=@F@0nBe40EfEV05=NH00oBT/0>dM7034l?P0oBd`0?DU903e8BP0m
BDX0?4Q803a7B@0kAdP0>dI803]9C00mBU00HFid045<DP0lAd/0=D1402lh?@0c>d40<3Lm02lf?00a
>3d0<SLj034e=00_=300=SXi038g=`0^<cH0=3Tl03Dm@00d>d40;C@j02L_=P0b>d80<CY1030e>`0]
<SP0:c8h02he>`0W<3D0:S<h02he>`0V:c40:B`c02d/=00V8b`08R4Y02X/=@0X:SH09RPd03HhA@0`
<Sl0:R`i02la?`0X:SL09BLc02PZ=P0`<c`09bXc02T/=@0a<C/0;Rhh02@T;00S8RX09RD/034`=P0V
8bX07adS02`Z;`0k>Ch0;B/a02TX;P0302DT:P0802PW;@0[:S00:BP^02HU:`0b<CL0:bX`01dL8P0S
8BP202HS:P0503Pe?00f<cX08QlV01dJ8@0O72<00`0Q7RD02P0T8BP0928X02<R9`0T8bP08B0U01dL
8@0O7B8081hS01hL8@0N6Al201`G7@0901lH7`0L5R0071HP01`F800I51/06aHM030[<P0I51X06aHL
00807QTM00P07APL01/F6`0J5A`0;2H`02dW<@0>2A005Q4H020K8P806QDK0P0F4AD201/F6P0301`F
6P0J51P071HJ0080618F01@0<2X^0<_5b@18@TH02`D900P21P0G4AD040L:01X@3`0L4A409A/L02XQ
900H4QD05a8H01<<4`0F3aH06@lG00l42P0O4aT05P/?01@;3P805Q0B0P0G4A<02`0A2`d04`d?01<=
3`0E3a405a4C01H@4P0B30h07A8F01D:3P0F2`l06@hB008060dA00T05P/?01P=4@0H3A405``@01H;
3`0C2Pd04``>018<3P0C3@l00P0E3a401P0F418050h@014;3@0A2`d07QPJ01LA4`806A<E0P0@2P`0
:P0L5QP06aDG00l92`0G4A<07QPJ00d72@0J51H04@/=038/;00I5A<08alN00h<3@0K6Ad0924X05QG
G`0f=Cd08b<[01hO900K72407b0T01PI7@0W9R`09bP]02DW;@0T:Bl08RTa030i@@0c?DH0<Sm803A3
C@0kC5H0A5AQ049CH@1?HFl0CEm]05U[N@1KKG/0Bee[05U[N@1JK7X0EVQf051RL080CEm]0240B5UU
03a=E`0hBE40=dM?03=0B@0b?4D0;3Dl02H]<`0Y;S@0:B/`020Q9@0J6Ah06AHL01/D6`0V82@08Q`P
01<=4@0H3a8060dA01052@0H3Pl050P:01L;3@0Q5QL0<RT/00@00P0=1`P05@`=01dE4`0C2`P04`T7
01881P0B20L00P0E2@d0:00B1P/0404601<41`0H2@`05`P;01D62@0D1@P070d@0101100E1PT070d@
020A500C1PP070d@01<41`0H2@`04@8501/<3`0L3A0050D801D62@0D1@P04`@701831P0A0PD09ATI
030U900C2@P040P601XC4@0910401`8002<L6P1TG5X050X901D<300H30`050H601X<300G2@T20143
0`0301T;2`0D1PH050H600@050H600T04`D501D71`0E1`L04`D501@61P0E1`L04`D501@61P0E1`L0
0P0G2@T03P0H2PL04@H002<I400C2PD081HH02PP:`0B31X01`4C01<;8P0G3bH08AL`09V=Y@0^8C<0
4`D;1@0D1@P601D62@0601@82P0M4A<0200001L;3@0800005PX<0P0B1PP01@0>0P@040@60186200@
10H04@D700<04`L900D050P:01<72@0A1@L04@D70186200201<72@0301<62@0C10T04`@900<04`@9
0P0A0PL01P0H2@h08Q<H01/<4@0B0`P040<601451`@040@600@04PH800d10`0=0@<050P:0P0>0P@2
018620<04`L900<04PH801451`0A1@L0100A1@L01@0800006PhB01L;3`0800005`/?00804PH:00<0
5@T=01@8300>0PH00P0D20`0100@10P03@450104200D20`201862P0=00l31`0A1@T0>2d`06aPI00A
1@T050P<01dA5@0G2`l03@<5028F6P0C2@/081@H01452@0301862P804`L;00P040@801L;3`0A1@T0
5`/?06YNHP2aYJT0ASXn01<82`8040@800<050P<00T00Oooool04oooool001_ooooo00P07Q<A01L<
2P0@1@<03`@201871@0E2PP05P/901<81P806@h<00/04@H401@91`0I3@d03@<301T=3@1?@d<0GE5A
01@8200B1PH040@401861P0200h20P0801@8200h;2`07Q8B01@8200F2PX04`L700T0000?0`<20104
100Z01861P0C1`L050P801H:2P0D20P04`L70104100?0`<040@401861P0A1@D04PH601<71`0B1PH0
40@4020D500D20P0200001X>3P0800005@T901T=3@0C20H04@H401<81P0E2PP06PhA028G7`0?10`0
4PL=01`A5`0C20`05@/=0147200<0P<05`d<01H<2P0?1@<04@H501861P0C1`L05@T90`0B1PH0300F
2PX05@T901H:2P0D20P040@401T=3P0I3@l05PX<01<72@0@10H07a<E020D5P8060`>00l050P:01P<
3P0H30h050P;01<72`0E2@d05PX>01D93@0D20`05`/?01H:3P0G2`l06@dA01X>4P0G2`l00`0D2@l0
2`0I3Q@08AHL02lT:P0R5ad06@hD02/P9P0?10X03@8801lE6`0D2a004@/?00804`dA01D05a4E02XT
:00V82@07QPL01TC5`0H4QH091hR02dW:`0O5QT06Q4F01X@6P0I4Ah05`lK01/D6`0C3a0061DC01lN
700K6A`04PhI01DA7`0J5b000P0M6R409@0L6B006QLN01XG7P0L6B005aDK01PF6`0I5aX06aTJ024O
8P0N7B<071/S01/J8P0M72@07ahV01dM9@0N7RP07b4Z020S;00Q92d082</01hR:`0L7bP07R4Y01lR
:@0P8bP082@W020T9@0X;2d0;S4f059EFP0e>3l092L`02T/=@0[;SL0:2`e02T]=P0/<3T00P0Z<CT0
2P0X;cL09Rlf02Pa>00/=cd0:cHl02Td>P0_?4D08c0i03Y7D00]>T<2038oB00B03=0B@0gA4d0>4E>
03Q5CP0iATl0>dQA03Q6D@0nC5D0<Cm803a;DP0c@TT0@4mF03Y8D`11CUh0BEIW04]HJ`0nBV80AE=U
0`11DEh02@12DUl0@e=P04YJI`18F6D0@e=R04EEI00oCeh0>d]J03e<E`0303e<D`0>03m>E@11CU@0
GFU_05aWK@11C500?4I903e7B@0kADL0?DQ:03U7B00lBT/0AE=E03e;CP0jB4/2041>D@80?DY@0P16
DeT3045<DP0N03m:D00mB4h0>dI<04E@EP17DUP0@DaB041;D@16DEL0@4]A04A?E@0nBDl0>dI<03m:
CP11C500Ae9F03Y5A`16DE<0@Da>03Y5A`0h@dD0>dM803Q3?@0iA3`0>dI003Y5@@0h@cl0=d5104QB
E00oB4d0=3e30P0`>D80J00f@4T0>D9A03Q4E@13CV80BEAX04]FK01@Fg40@TeQ045<G00jAU80@4eE
04=@E@0e@d@0<Shn03i:B@0lB4H0>4A4041<B`11CD/0?d];03i:B@0kAdD0>TI603Q4@`0f@D<0=3m5
03e7D01JI6d0>TA=03a6C00h@DP0<3Tn03Ho@`0b>Sd0<cPl03Dj?P0b>3P0;2h[034c;P0`=C40;30_
02`b<P0^<cH0<CTl02lh?@0c?4<0;CM002Pb>`15CUL0=S]202/`=P0U;3809Bdc02Tb=`0S;340;3@j
02db>00_<ST0:RXb02DT;00V9Bd0;Bdg02XZ=00P82X0:RXe02PX=00U9C40;bll03XjAP0[:cD0;2`f
02h^>00f=T00:2P`02d/=00/:c<09RD]02DR:@0[:2l09b@[01hK8P0U8RT061DL02TV;@0[:C009B@Z
024P9P0S8RP092<Y02PW;@0[:S00:RT_02@S:@0];3809RD[01`K8@0U8bX08AhU020M900a;SD0<2dd
024N9@0O72<081dT0P0R7bH201lL8`0302<Q9`0S8RL08B0U00808R4V01008AlT01dK800N724091lU
020K8@0M61h07AHM024K9@0R72H07aTS01LB6@0M61l0@3]201/F700L5ad07aXN0P0P6al02@0O6Ql0
6QDL01hH8P1/IW00I5mV03Ha>00@31806A@J01XE6`0201D@500W01/F6P0J5AT07ALK01PB5P0J51P0
6A<G01H@500Y8bL0=S0d01LA5@0J51P08adQ01D?4`0M51L08QPI01L=3P0D2P/040L:01XA5@0J51P0
718J01/A6@0l<SX02`0801L<500N4aT05Pd@01H@4P0L5QP05a4C01D?4@0F41804`d?01@>400G4A<0
6A<E01LA4`0C3@l0714E00805@X>0P0G3100200K41@050T=01`A5@0M4QH06@hB01@93@0C2Pd05@d@
0P0B30h0EP0D3Q005a4C01TC5@0G4A<02`D7018<3P0H4Q@04P`>01`F600H4Q@05a4C01D?4@0?2@/0
6A<E024K7@0=1`T05@lA018<3P0<1PP0A3i00=C>cP0g=3801@@201/K6`0H61/092<Y0:n`]@11@DT0
6Q/P020S:00B5AT05a/N02<W:P0T9BX08b@Y02@V;00U:S008bXb034j@P0a>d@0<Sm8049AF`15EV00
B5YV04YLJ@1OLGl0FF]i04mQK`1MKgd0FVaj061bP01MKgd0FVaj05AVM01=Gfd0Bee[04MII@0mCeT0
>DYD03];E00jAe00?4I?03<l@`0W;S@0:Rle02LY;P0O82D05aPL01PE6P0G4QP07aXN01lI7@0E3a<0
6A<E01D<3`0B2@`05`d>01`B4`0M4a@0?S@d0=O>d@1<ATX040X;00H0000B2PP03`L40P0B20H0200B
20L05@T=01D93@0B1P/040@80186200F2P`05@T;0P0D20X02`0L418050P:01H:300H30h04PH803L[
;@19?Cl060`>01@:2`0Y7Al05@T;00804`L901L03@4301<72@0N4Q@0710B00`00P1EBDT0]:VY034W
9P0>1P@03PP601PC40091040<BXX07I^K00O5A@04PT901/?3`0H2PX06@/;01D71`0A0`<04`D501X<
300601@61P0601<51@0E1`L05@L701<51@0D1PH05@L70`0D1PH201D71`0>01D7100`8aP04`T001P?
1P0L4a402@8900X43P0E3Qh03`LL00`4701FBVH0XI:a02<E;00C1@/501@520805@H90P0F1`X0200E
1PT050D801D92`0J3Q002P0001@82P0@10H06@d?0P0D20X02P0?0`D04@D70186200A1@L04PH801<7
2@0B1PP040@60186200D20X201451`040186200C1`T04`L901<62@H04`@901<04@8701H7300P4AH0
6P/@01@52P0B10P03`<501041P0E2@/05`/=01451`0C1`T03P8400d10`0O4aD06`lA01451`0>0P@0
40@600804@D70P0@10H601451`0@00h21P0G2`l040H801@8300W6al04`L;0104200D20`04@D900/0
0`0F2Ph040@803DY;@0J3Q802`4301D93@804`L;00`0710D01<72`0C1`/0710D01L;3`0?1@L02@01
00d11@0I3A40200001<72`08000201452@804PH:0P0C1`/201H:3P0701452@0800006@hA02hR9P0H
31002`4300l31`0201@8300301862_oooooooooo01;ooooo000Kooooo`0F01861@0D20L05P/:01D9
200B1`H04PH501D9200B1`H04PH501461@0S61L04`P700h4100H30`04PH601P<300U6QX060`<0186
1P0D20P05@T901@820@04`L701404PH601451@0?0`<05@T901861P0D20P04@D501@8200C1`L05@T9
01861P0?0`<04PH601T=3@0G2`/050P801H:2P0201<71`<05@T900L05@/:02LL6`0O51<040D401X>
3P0A1@D060`<00804`P701405@T801L;2P0C20/03PD;01dB6@0D2@l050T=044f>P0l<S<06@l>00l5
100D2PP060h;00`3000D2PL050P801861P0201<71`0?01D92@0F2PX05`/;01<71`0D20P05PX:0186
1P0C1`P05@T;01X>400E2@/060`>01451`0F2P`05`/=00805@T;00<06@d?01L;3@0F2Pd00P0G2`l2
01H:3P805@T=02`05PX>01P<400H31005`/?01D93@0H3A<05@X@01/@5P0F2a4040D;01T>500L4AL0
4`X>01X?5@0E2Q00714G01X@5@0F3A805@lC01TC5`0F41@04`dA01H@500[9BT05a4E01D?4`0J51P0
4@/?01XD600O5QX07A<J01/A6`0D31T091dW01`E6`0I5AD04Q0<01LF4`0N71l09b@^01LC8P0H5Al0
6aPP01`I8@806aPO00`07AXP069PIP0_;C406QPL01hL7`0N71h08R0T01dL8`0N7BH071/T01TG8@0M
7BH2020P:@0B01hO:00M82P08RD]01TL900R9Rh08BD^01hR:P0P92X08bL/02<W:P0M8R808RLW01hR
9`0_<cL092P^02@W<00/;cP0:Rhg0P0T:3401P0W;CD09bhf02D]=00X<CP09c0g02Tc>P80;CPn0100
:cHl02dj@`0d@DX09c@m02llA@0f@d`0=D9;03A1BP0gA4d0>DI?03Q5CP0kB540@DiG03M5D00jB540
<T190P0gATd01`0lBe80?4YE041=G@13D680Df1c04IBJP14DV@00P14E6408@0oCe`0?4aI041@G@15
EF80@U9O04YJI`13E600=TMB03Y:F00iB580=dI=03U8C`0oCU@0@U5F04=@EP15DUH0AE1D049=D@15
Ce80?dU;03e7B@0mB4X0@Dm@04=ADP0kBD/0?D]>041>D@0nC500>dU=03m<D`0hAD`0>TM>03m<D`02
03m;D@80@4aB00/0?d]A03e9C`0lB4h0?TY@03Y6C00lB4h0A51F049>E011C540?TU>041;D00204IA
E@0404E@D`0kATP0AE1B04=>C`80?TU:04/0?TY903I2?@0nBT80@Te8049>B`0mB4H0>DA5045;D00m
Add0=d1903m8DP17D5`0ATmL03]6E`0mB5/0@TeQ05EPM@14Cf<0A4mQ04UEI@10C5T0?daD03]8C@0j
B4X0>TQ803i:B00lB4H0@De;04IBD011CD/0AE5?04A@CP0oBdT0>dM503Q4@P0b?S`0=D5104==EP0h
@T`0?dUC03HoB00c?4@0=Si603@l@@0e?400<cTl03@i?00c>CX0;C4a02h`;@0a<bh09RPS02``;`0]
<c<09bd]02de>00c?4<0=d1707^5SP0i@dd0CeQQ0415C@0]=3/092/b02L`=P0^>3h0=T1503Y3B@0[
<ST0<SHn02PZ<P0V9Bh09bH_055AFP0n?TL00P0V9Rl0600Y:C808R8[02XZ<`0];CH08B4Z02h^=`0J
6R<09bL_02TW;`0Z:2l0:BL^02/X<00Y9Rd0924X02DR:@0V8b/0:BL^024O9P0X9Rd08b8X01`K8@0M
72808B0V02<R:0<09bH/0P0Q82H201lN900402PV;00R7bH07Q/R01hK8P8071TP0P0R7bH202<P9`0c
024N9@0S82L09B<Y024P9@0L6b007A`Q02LV:`0U8bP07A/P01lM8P0T7bD08A`R01hI7`0M5Qd0618L
02dW<@1dKWP0:2<Z01LB6@0S7RD07APN01hI7`0O6Qh081/O01lJ7P0P6b009B0W024K9@0V82X07APO
01D@5`0L5ah07aXP01TD6P0L5a/091lS024L800M61`06Q@H01LA5@0J51P06aDI01H@500H4QH05a4E
05]EF@0O6Ad0618F01TC5`0D3Q805PlA00807aDG01H071<F01`C5`0G3Q<05PdC02<I8@1<@TX081DN
01/@6@0K4QX06A<G01PB500N61X06A<E01@>400G4A<03`T;01H@4P0J51H07ALI01H@4P0C3@l060dA
0P0G31004@0F2`l05``@01/@500F2`l0714E01hC5`0K41@06@hB01XA500D3@l0618D018<3P0C3@l0
@cdo06USI@0F41803`T;00805@lA03l04@/=01LA4`0E3a403PP:01/E5`0G4A<040X<01LA4`0E3a40
6aDG024K7@0T7R003@L902XV9@0I5a<06a/I00l?3@0F5QP051DI03@e>@0H6Al071lT01/N8`0E6A/0
7B4R01XN7`0R8bP08R@Y02@X;@0X;C<09Rde02df?P0^>d<0=D=<04UJH`17FF<0AEMS04aOK01=Gfd0
EfUg05a^O01NL7h0I7J4069dPP1QLh40H7:005]]N`1CIG<0D69`04]NJ`12EF00?DiI03Q9D`0b@4T0
;ca502hg?`0/<c/0:c0f02<W;@0N82D07QlT01hL8@0J5A/00P0H4aL05`0E41@05Q0B01XB5@0K4aH0
60l@01@;300G3Pl0<2HV07=ZK@0V82@05Q0A01<:2`0G3`d05Ph;01@:200C2@L04PP701@8300C1`/0
4`H<01<8300D2@X05@X;008050T:01005P/=01051`0C20X060d?00l41P0>1@D0CT=506mTI@0L4A<0
9a`N069GF@0F2``05@X<01/@4P0?10H06Pl@0P0_92H03P0D2@/0BShn085hM`0B2@T04`/901<<2P0C
3P/06QDB00l81`0L51805`d<01<8200D20P050H60P0E1`L201H8200501D71`0F20P04PD501D71`0D
1PH00P0E1`L00`0D1PH05@L701H8200601D71`0@01@61P0C1@D04`D201d?1@0O4`P04@L101480`0A
30/03`P=00`64@0L52D05P`S01/>:`0=0Ql03`<K01@530805@H90P0D1@P01@0E1PT050D801D62@0F
1`X05@H9008050D801P050P:01451`0H30h04`P901882@0T61X06`lA0186200A1@L04PH801@82P0B
1PP04@D70186200>0`D03P8401<72@0B1PP03P<401H:300c9bT05PX<0186200B10P201@52P0B0143
1`0L3A80408601H8300>0@@04P<801<52@0J2a0040@601L93@0E2@/05`/=01lC5@0M4A<04PH801@8
2P0B1PP04@D70P0O4aD00`0E2@/03`@501L;3@0201451`0=01X>400Z7R003`<501X>400S5aT03P<4
01451`0E2@/05PX>00h31P0B1PX06@dA00`2100201<72`0I01D93@0B1PX03`<701L;3`0A1@T0ACTm
02/O8`0C1`/050P<01862P0C1`/0@cLk0104200L41@05@T=01L;3`0A1PT05`/?01D93@0@1@P050P<
01H;3P0N4QH04@D901862P0201<72`0601862P0A1@T04`L;01452@0E2@d050P<0P0C1`/01P0H3100
5@T=01452@0D20`04@D9010521Cooooo000Kooooo`0301P<300D20P04`L7008050P800T04PH601D9
2@0K3`l02P0001P<300L41003P8201<71`0E2@T00P0F2PX02@0E2@T04`L701<71`0A1@D03`<30104
100A1@D04PH601<71`0201861P0301<71`0D20P050P800804PH600X03P8201P<300K3`l07a<C01H:
2P0B1PH05PX:01dA4@0I3@d04`L71P0D20P01@0M4Q00<bPV02DJ600A1P@06`l?00805@T901H04PH6
01@8200C1`L04`L701872`0E2Q004PL=01052@0@1PL04PP901L=3@0H3Pd04@L50147100E30L06a8=
01X?3P0D20P04`L701861P0C1`L050P80P0E2@T01@0D20P05PX:01T=3@0H30`05PX;00<05@T;0P0D
20X0200G2`d05PX<01<72@0G2`d06`lA01T=3`0F2Pd05PX>0P0G2`l301H:3P805`/?0`0F2Ph03@0B
1`d03P<9024F700L4AL04@H<01052`0E2Q005``B01D:400D2@l05``B01D;400F3A800`0D3Q8201D?
4`<05Q0D03`05@lC01H@500F41@04`X?01L=5@0M4ah04PXG02`U;P0M5aT05a<@01@B3@0I61@04Q0C
01`I9@0I5B@081dX01`I8P0J5b006aPO01XH7@0H5QT0<Blb01hL7`0K6A`07Q`O01/I700I5a`07A`T
01PF8@0Q7bX0;B/f024P:P0H628071`T01/M900G6R406QdT02DY;`0A5Q`0720Y02@Y<00T:Bl07R<W
01hS9P0V;2`09B/[02DZ;P0V:bl0:Bhd02``>@0]<CX0:Rhg02L[=00X;3D0:C0h02H_=P0T;C@0:C8i
02Pc>@0Y=3X202dh?P0502/f?00]>T<0<3e602dj@`0`?DH00P0e@T/07P0b?dP0>4E>03e:D`0jAe00
>DI?03e:D`0e@dh0=49;03E3C00hAdh0?4]B03i=E00lBUD0?DYJ03m<GP1?G6l0Ce]c045?H@0mCEX0
@51M045AGP0nCU/0>d]H03m?G010DE/0BEYT049CG@0kC5H0@E9L041@E`80?diE00L0?4]A03Y9CP0o
CE00?T]>045<D00nBD/0>dE70080>D=500h0?DQ:03Y8B@0e@d@0>TQ:049@D`0oCE00=45603A1A`0o
C5@0@4eF03i;E012CeP0?T]C03i;D@<0?daB00<0@4eC03Y7C@0kB4h00`0lBDl01@0kB4h0?dY>03e8
BP0mB4/0@Da@0080@di@0P0mB4X06P14D500@4a<04YFEP1AGEd0@4a804A@C00lB4H0?d];03i:BP11
C4l0@DaB03a6C`0b?4H0=T1<03e7D`0i@U40@diP04aGJ@16DF<0FVEg04E@H@0f@U00>TIB03U6CP0g
A4X0=dE60P0hATH0C00mBDT0?DU8041<BP12CTh0@De<03i:B010C4`0=T9103A0?P0jATH0@Ti=05YU
I`0oBU00=d5;03I0B@0f?dP0<SY1038i?`0d?3l0=C`n03Hl?00e>c/0;cDc02T^:P0K7AX0<S@_02L/
:00c=cH09B/[02H[;P0X<3<0>D9704]DF`2S[KH0=T19030i@P0Y<3P0<3Lo02/d>`0Z=3X0:SDk051K
H@0mATd0>D1802`c>`0T9c00:BTc020N:@0`<3P07alW04Q8D00Z:S406a`Q02<T:00W:2d0;2db02l_
=`0Q8BT0:BTa03He?@0V8bX09b@[02DR:@0X9B`09b@[02HS:P0N7B<05A8K01PG7`0X:300;Rde02PW
;P0M72808R4W024P9P0O7R@202<R:00;02DT:P0S8RP08R4W02<R:00T8bT0:2H/030]=00a;SD09R<Z
02<P9`0U8RT00`0S82L2024N9@0902@Q:00W9B/09RDZ028Q9P0Q82D0;bhc02d[<00T8RL081hS0080
71LM00H07APN01lH7`0X8R`0:B<]065KI@0Q72<201XE70807QTO01407QTM01dH700L5a/071LL020K
8P0I4ad07ALQ01`G7P0M61l05A0G01`G7@0F4AL06aHJ020K7`0H4aL05a8F01XD600201TC5`0G01PB
5P0I4aL06Q@H014;3`19@dL05a4E01D?4`0J51P06aDI01XD600@2P`04P`>01@;3P0J4AD06Q4F024H
7@0G3Q@06Q0H01hG7`0M5Al03@H>020J7P0G4A<00P0E3a401P0D3Q005a4C01H@4P0H4Q@05@lA01/E
5`8050h@01`06PlC01L<400D2@d050T=01L<400J3a<060dA01T>4P0H3A405``@01T>4P0J4A@05a0B
01LA4`0I4aD05@lA02XT9P14?T005@lA018<3P0A2`d04P`>01D?4@0G4A<05@lA01H@4P0G4A<0618D
0P0G4A<08P0C3@l05Q0B01lI6`0L5QP050h@01H@400G5A405aHB01@D4P0I6AX06APM01<D600F5a`0
61TN01LK7P0I7Ah07R8Q024U9P0T9RX082<X020U:P0Q:2h08b`c02Hb>@0]?4<0<Cm803a>E`10DU`0
?e=N04ePK01BI780FVaj06=eP`1XNXP206]mR`0V06UkR@1VN8H0H7:005Y/NP1FJ7H0DFAa04QLI`13
EF40@59M03a=E`0gA4d0;SU202`e?00[<SX09BT`01hQ9P0N7b@081lT01lJ800F4AD05a8F01<>4P0[
9BL0;bT[00D00@0J4A808aXK00h51P0A20P05a4C01H@500D3Pl05Pd>01TA3`0M5A805P`:01D;2@0D
2PT201<72`0401<7300D2@d050X;01@:2`@04`T:01H03`D60147200J41406a4B01@:2`0I3a005P`=
0147200N51D04@L801882@0700004PP901<92P0700006Q0A00`20`0<00008AHE01hD4`0D30X04@X8
0P0:1@801@0@2PL04@T701061@0B1`H05@T900H050H600P06@/;02<E5@0E1`L04@<301D71`0>0000
50H601D71`805PP800@05@L701@61P0C1@D050H60P0E1`L04@0D1PH04`D201P:0@0H2P405`X101D;
0`0C30H04@`901@=4`0h<3l0:b8e01<6800C12D05PHP01@5300F1`X05@H900804`@701L05@H901H7
2P0B0`H050D801P9300F1`X050D802TM7`0W6ad040@600/10P0l<380QGUk01<72@0H30h081@F01L;
3@0B1PP02P0101451`0K3a4060`>01451`020186200C01@82P0A1@L0<BDW01<72@0A1@L04@@70183
200E1P/07PlD00X0000F1``060T>01X;400N3a@06``A01H7300G20d03P<401P<3P0201D92`0301<7
2@0?0`D050P:00H04`L900h05PX<01041P0B1PP04`L902/O8@0H30h04@D7034U9`080000:1`N00d3
100C1`/04PH:01452@8040@800L04@D90104200<00@03@4501<72`0E2@d05PX>00H04@D900h08aLK
00T00@0J3Q805@T=0104200B1PX030040104200B1PX040@801D93@0=0@D040@801862P<04`L;00<0
4@D901862P0B1PX0100B1PX01P0M4AD04`L;00l31`0B1PX04`L;00d11ACooooo000Kooooo`0=01P<
3P0E2@/04PH80186200C1`T040@601H:30080000710B00l31@0E2@/040@601<71`0401@8200801<7
1`0E2@T05`/;01L;2`0F2PX04`L701861P0D20P201<71`0?01@8200E2@T05PX:01D92@0C1`L03P82
00l30`0>0P802`0001@8200C1`L05@T901L;2`0D20P04@D500H050P801h06a0=02PM6@0T6AD050T7
01X?3@0F2`T04`L701041P0C1`T04PH801451`0C20/06@hB01H;3`0B20T03P@500/10P0B20L050X9
01`B400F30X04@L50106100<0P804PH601D92@0D20P04`L701D92@0F2PX201@8200601P<300J3Ph0
60`<01D92@0C1`L050P80P0E2@T02@0D20P05PX:01D92@0C1`L05`/;01`@400K3`l06@d@01L;3`02
01H:3P0601L;3`0H31005`/?01H:3P0E2@d05PX>0P0G2`l03@0L4AL060dC030U:`0X7B<081DK01D:
400G318050T?01H;4@0G31805@X@01H<4P0H3a@00`0F41@201D?4`0a01LA5@0I4aL071HJ01dG6`0K
5AT0618F01H<500H3QH08aTU01D=6P0M5Ah050h@01lK600F50h06aXF010>4@0B3a/07a//02@P;P0N
6bD06QLP01XG7P0I5a`0518E014?4P0O7Al08AlR01hL8@0R82D08b0W02TW<P0H5R<0<Bll02@R;@0M
72H08b<]028R:P0O8BP0:B`c01/N8`0S9b/07B8X01TM9P0T:30092T_01`Q9@0N8bH0:S0`02@Z:P02
02@Y;@0C02H[<@0W:c@0:2`e02H]=@0W;SH0:S4i02dd?00Z<cX0:34h02dh?P0[=S`0;3Lm02hk@@0]
>T00;3To02dj@`0`?DH0;CY302llA@0303A1BP0303U6C`10CEH0?T]D0080=dA=0100=dE@03I4C@0f
A4d0>DQ?03a;DP0nCE@0?4YE041=G@0mBU`0AeAW04]GK`16E6L0?DeL03Q8E@0oCe`0@e=P0P0jBeD2
03i?F@0=03e>EP0kC5@0>DYB03Y:D@0jBDh0@4mD03e<D@0jBDh0@DmB045=D010Bdd0?DQ:03Y4AP02
03U3A00D03]7A`15De<0B5IG03i<CP0mBdh0@4eC041=E017E5`0@e1I045=F00jAU80?4UC03]:D@0n
CE80@E1E03i=DP0kBTl0?DaA03Q7C00jBDh203e<D@0603]:C`0iAd/0?TU;03a8B00kAdP0?DQ:0P0o
Bd/03`0lAdT0>dI8049=C`11C4h0C5MI05MSI013Cdl0AE5?03]7A`0nBD/0?dY>04=>D`12CE<0>TA=
03<mA`0203<mB@1L03M1CP11CEd0?4QH02Lc@`0^>TP0A51M04AAFP0f@d/0=T=803E3A00fA4D0=dE5
03Q6AP0mBDT0?4Q903i:BP10Bdd0?TY;03]7A`11C4h0?4Q902Xf=P0Y=3H0@De>07f8RP0g@4L0<ca4
03DnA@0f?dH0<SXo038j?@0_=3P0=3Tl03Dk>`0d>3T0;C4`02T^:P0/<Bd082DQ02L[:P1]LW80B4e@
030e>00]=CP07bH/01/R:01:DUX0;3Dl03M0A`0e?4@0:c8j028[<P0`>T409c8h041=D`0g@DP0>3m7
03@k@`0h>d@061PR030`>P0V9Bd08b8X04=2B00Z:Bh0<c8g02HV:00/:c0071/P02`[<@0K6R009B@/
01XI8@0W92X0:BL/02HT:@0X9B`09bH/02/Z<@0[:c<09bH^02TY<P0Y;3D09bLa02DT:`0R8BL09bH/
024P9P0K6R008B0V020O9@0S8RP302@S:@0602<R:00U8bT0<2dd030]=00P7B@07a`S0P0N6b8202DR
:@05028O9P0P7B@08AhU024O9@0R8BH00P0P7b@03P0Z:Bh09bDZ02<Q9P0Q7b@06QDK01dH7P0Q7280
8Q/R03Tc?@0W8B/07QPR01lJ8@0N6B0061<J0P0M61h0400M61`071LK01`G6`0L5a`05A0G01XD7P0O
6B<06aHM02PS:P0Q72<07aXP020K8@0N6Ad061<G01LB5P0J5AT201XD600401TC5`0H4QH06A<G01XD
60<05Q0D0P0N61`03`0T7R805A0D01<>4P0W8RH07QPJ01dF600<0`H0>2ld020H7P0J4aX08QdT028L
9`0I4ad08adQ01/E5`0201XD5P0:01PB500J51H05@lA01@>400>20X05Q0B01<=3`0B30h060dA01L<
40805P/?00<05``@01P=4@0E2Ph00P0H3A403P0F2`l060dA01/B5@0Q6A`03`T;01<=3`0D3Q003@L9
00`6200H4Q@050h@014;3@0B30h050h@1`0F4180BP0E3a4050h@01@>400E3a405a4C01PB4P0G4`l0
5a<@01HE4`0O7Al071XO01<B5`0D51T05QLK01PI7@0K71h0828Q02<T9P0U:2`07b8W01dR9`0P9bd0
92dd02Te?00_?TD0<3i703i?F015Ef40@eMR04mRKP1GJGL0GW1n06IhQP1/OX`0Kh6?0722T01]Ohd0
JWb:06EgQ@1OLGl0G6il05MYM`1:GF/0@UAP045CGP0oD5X0=dA=030kA00^=ch0:S4i02D[<@0Q9R`0
7b8W020P9@0K6Ah05A<F01XG6P0B3A40=c<d0<o9b`1=AdT02`H601L>3`0@1`P0610?018<3P0B3100
4`d>01L>3`0I4@l071@A01P>300G3@/05@/:0P0D20`0100D20d050T=01@:2`0C2@X201882@0;0147
200G3@h04`T:01882@0I3a004PP901D;300@1PL02@000107200@1PL00P0A1`P04P0S6AX06@l@00`2
0`0W7Ah030<302@J6`0:00004PL601D;2P0A2@L03`P6010;200?2PL07aPF01L?3@0=0`803`@30186
1PH04`D500L06P`<03PZ:P0D1PH050H601X<300?0@4050H600@05@L700<050H601<51@0D1PH00P0E
1`L0A00D1PH04`D401P90`0H2@805`X201D;0P0C30@04`/801@>400n=3l0;b@d01<57@0B0Ql04`@K
01D6300F1`X05@H901<41`0B0`H050D801P9300@0@@04@8501T:3@0H2@`04`@701@82P0@10H05@T;
028F600K3a405@T;01H:300W6ad0<2@V024E5`0K3a404`L90186200<00804@D701@82P0?0`D040@6
01/?4@0<008050P:0186200C1`T04`H901h?500<00804@@701P93P0]7R<02`0101X;400=00<040<6
00d00`0J2a0060X>01L;3@0D20X04@D700l31@0>0P@05@T;1@0C1`T0300E2@/040@60186200E2@/0
2`0101H:300@10H0200001<72@0H30h03@4301<82@804`L;00X04PH:0104200@10P04@D901lC5`0D
20`03`<701@8300@10P03P861P0@10P01P0?0`L02`0301862P0C1`/04@D901862P804`L;00H04@D9
0104200h;3008aLK0104200A1@T201<72`0301@8300C1`/04PH:00D04PH:00H060`@01<72`0@10P0
4@D901862P0A1@TDooooo`006oooool0300C1`T050P:01041P0B1PP05PX<01451`0F2P`0?S8d0188
2@0E2@/05`/=00h210L04`L700P060`<01dA4@0J3Ph04@D500d10@0H30`05PX:01D92@8050P800d0
5@T901861P0G2`/06@d=01P<300K3`l03`@401D92@0G2`/05PX:01<71`0B1PH04`L700D050P800l0
50T701D:1P0G30P07A8>01<81@0D2@L04`P601@8200B1PP050P:01<72P0B1PT050T:01T?3P0E2`T0
0P0D2PT0500C2@L0;28P01081`0>108050X901L=300E2`/050T801H:2P0L41006@d=01<71`0E2@T0
60`<01<71`0B1PH05PX:01<71`0B1PH050P80P0C1`L00`0E2@T05PX:01@8200201D92@0601@8200F
2PX060`<01P<300H30h05`/?0P0F2Ph01P0G2`l06PhB01H:3P0D20`04`L;01D93@805PX>00d060dC
0146300K41H05@X@01<83P0G318060dC01<83P0I3Q@06PlE01<83P0G3A<060lD00805Q0D0`0E3a<0
<@0G4AD06A<G01/E6@0K5AT06Q@H01PB5P0J41P04PPA01dC7`0J4Ql06A4J01LA4@0L6A@061L?018A
3@0E4aH071TW01TE9`0J5RD07Q/V01`I8P0I5Qd06QPL01dK700P7Ql06QPI01/I700M6b006QPM01XG
7`0@3QX09B<`07MePP0b<3`08B0[01hN:00H62007R0W01PK8@0R9BX08bL[01hS9`0O9B/082H]028X
;P0R:B`08BLZ01hU9@0T:b/00P0T:bh0300U:c409BXc02DZ<`0T:c<09Rde02P_=`0]=Sd0<ca303Do
AP0]>3h0:CDk02Xf?080:cPn00D0:SLm02dj@`0b?dP0<3e603A1BP0403Q5CP0T03i;E00mBU<0=T=<
03I3C00kBE@0>DM@03Q6C`0hAdh0>TU@03]:D@0oCEP0AE9R03m<GP11CV40Ae=[04eKKP15EF@0>DUG
03Y:E`0oCe`0>daF03M8DP0nCeL0@eAL04MHH00mCUD0=DI>03e=DP0kBTl0@4mD049AE@10Ce80@e5D
03i:C00oBT`0?4M80P0i@d@04`0kADH0?d];04]IF@1=Fe`0?de?03e;CP0nBe40>TM>03a9D@0f@Td0
?TYF04=?G00jAU80>DQ?03i=DP13DUL0?DaA03U8C@0lBe000`0kBTl0:00lBe00?TeB041?D`0oBdX0
?d]803i:A`0mBDP0?TY903i:BP0nBD/0>TE7045<C`0lAdX0?TU<049=D@0lB4`0@TiB045=DP18E5T0
A51G03a8C`0lB500=D1903<nA`0b?DH0;SY303e9D`15DUd0?TYE045=E`0a?TP0>DI=03A1A`0hATT0
>4I703Q6AP0iAdL0>dU703a:BP0lAdT203a7BP1:03e8B`0kATT0=d9503a7BP0c?T40;CPk04=>D@0c
?T40=d9403Ho@P0c?3l0=d5403Q1@`0c>c`0<CPi02X_<@0^=3<0;S<a02/_;P0Z;b`0;C<`02hf=00]
=3<09Rd^03m6A`0_=CP0:2la02L]<00W;S40;S@i02`b=`0_=C`0:c4h03m6CP1HHFT0=d1803<mA@0]
>T40;ca3069]M01>Eel0=3]402LZ=00[:cH07alY024P:00V9B/08R4W02HU:@0];Bh07QhM02@T9@0T
92H08B0U02`[<@0R8BT0:RT_02@S9`0X9bX09B@W02@S:00T92X09RH]02@U;@0R92`08bH_020U;P0U
:380:B/c02@S:@0Y:2h08b8X01dL8P0S8RP2024P9P8081lU01/07ahT020O9@0Q7bD0;2T`02h[<P0Q
7RD09R<Z02@Q:00M6R408QlV02<P9`0Q7RD08QlV01lL8`0M6b407ahS01hM8P0P7b@08b8W01lM8P0M
6b006aTN01TD6P0Q72809R4W028K8P0Z92h00P0N62800`0R7B@050lF01`G7P0201`G7@<071LK0100
71LL01`G7P0Q6bD07QPR014<4`0J5A`0;RT`01/F700P6b406aHJ01HA5@0K5QX06A@H01/E6@0J51P0
6A<G0P0H4QH05@0I4aL081XN010:3P0L5QX07QPL01/E6@0F4AD05QDJ01lO900@3a804`lC01LA500H
4A<050d@01TC600I5A`040hG01LF8@0>31@06QDI01XD5P0201lI6`0901LA4`0C3@l04@/=01XD5P0B
30h05Q0B01@>400E3a405P/?00@060dA00P05P/?01@93@0H3A405``@01D:3P0G31006a8E01/D5P80
5Q0B00/04P`>01<=3`0H4Q@07ALI01PB500E3a4050h@01H@4P0G4A<05@lA01<=3`02018<3P804`d?
04L05a4C01XD5P0G4A<06A<E01/E5`0G4A406ADA01@@3@0E4@h08AdN020L800H51T05Q@I01PG700I
6Ad06QXK01`M700N7b007b<W01lT:00S:Bh0:C8g02lh?`0`?4<0<T5802hoA`0nDET0C61Y04QLI`1@
Hfl0F6Yh05maO`1WNHL0KGn=0763T@1cQI<0LH>A06n1S`1[OH/0IGN5069dPP1JKG/0D6Ab04aNJ`15
Ef80?4eG03M5D00f@DX0;cU202P_=`0U:c8092T_020S:@0M7B80928W028P8`0N6ah0510D01/G600Y
92H05a8D01dG5`0=1PL05@h>01L?3P0B30h04P`@01<=3P0D2``04PX801491P0201L=2`0801D;2P0D
20`050P<01@83@0D2@d050X;01<92P0A1`P201061`0N0107200G3@h06a4B03L];P0[8b<060l@01<;
2`0K4Q<0610@01061`0?1@H04@L801D=3@0K4Q<07QDF00X20P0j<3404PP901L;2`0D2@P081HE020H
5P0A2PP03@P500h91P0N5aD05`l=01061@0C20L04@D51P0D1PH01`0B10@09aTI00`0000G2@T05PT9
01D71`0C1@D0100E1`L201<51@0D01@61P0E1`L05@L701@61P0C1@D06@L901L81`0F2@D050X3018;
0P0B2`@04`d:01/A5`0E2a@05PTK01H67P0=0A805PH=01H72P0E1PT201<41`0301@5200L3A006@X=
00804`@700`05PL:01<41`0F2`d0=b/]034U9`0C20T06`lA01<72@0A1@L05`/=01dA4`0A1@L201<7
2@0H01L;3@0D20X05PX<0186200?0`D05@T;01051P0B1PP04PL80186200D20X06Pd@01<42@0H2@h0
5`P=01H9300C1`T06P/@020A5P0E1P/06`dA01P93P0I2`l03`850`0F2P`00`0C1`T03P8401<72@05
0186208040@600d04@D70186200D20X04@H701<72@0E2``040@601@82P0?10D04PL801@8300C1`/0
4PH:00804@D900L04PH:02@H700G2`l04@D901D93@0?0`L03@<500H04PH:00D03`<7024E6@0F2Ph0
60`@01@830020105200501@8300C1`/05`/?02lS9`0R5QX00P0B1PX301452@030104200B1PX04PH:
00D04PH:00D04`L;01862P0A1@T04PH:01D93@0Dooooo`006oooool0300C1`T05`/=0186200E2@/0
7A4C01L;3@0M4A<0A3Pj00T0000O4aD02@0001L;3@8050P80P0C1`L201@8200501L;2`0C1`L03`<3
00l30`0B1PH00`0C1`L0400D20P05PX:01P<300I3@d060`<01H:2P0C1`L02P0001T=3@0?0`<05@T9
01H:2P0E2@T04`L701861P0C1`L501@8200Y01@91`0C20@04`P401P=2@0D2@D05P/901871@0D20P0
50P:01L;3@0F2Ph04`L;01L<300L4`h05@`701D;2@0H3P`05`d;040f=@0P5QD050X901H<300I3a00
200001P=3@0I3@d0710@01X>3P0E2@T050P801T=3@0D20P04@D501L;2`0D20P05PX:01/?3`0F2PX0
4`L701@8200G2`/00`0E2@T201@8200301<71`0D20P04`L800804PH:00/04`L;01@8300F2Ph05@T=
01L;3`0I3A405PX>01@8300E2@d05``B01D:400201/@5P0;01T>500P5A/05``B01P=4`0M4QP06PlE
01D:400G3A<05@`A01<=4@0D3Q800P0E3a<0=@0F41@06A<G01PB5P0F41@05@lC01H@500I4QP07aDN
01<9500D2AL05@dJ01H?5P0F410040d602XX800H5a<04a4D01TF900J5BT06ADT01lK:00M6R<05a@K
01LE600N71d07A`J01`K6P0X9RL0928W01/I7`0[:340;2Xg01XH9P0[:CH081h[02PW<`0a<C/09BD]
024S:@0O8RL092L/018F6P0V:bl07B@Z02Xa>00Z<CL08BT/01hV:00U;Rd08R/Z02<[;P0T;2l092/a
00808bXb00L0:S4i02L^=P0U;3@09c0g02hi?`0c?T@0;cY00080:SLm04H0;CY002ll@P0_?480;S]4
03A1BP0c@4T0=T=<03Y7D00iATl0>TM@03M4C@0iATl0=dA=03I3C00iATl0=D=>03E3C00fA4d0>TU@
03i=E00oCUD0@4iI04=@H013D680@e1S04A@J010CV40>d]J03e=G00oCed0?TiK03a=E`0jBe@0?TmG
04aMI01AHVT0?DiE03Y<D01;G600BEQM045@E@0mC500@E1C04IDE@11CDl0@4]=03a8B00iA4D0>dE6
03i8B@0nBTX0?D];03m=CP0kBD/0>DM:03i;D@16De/0?daE04MCG`0hA540@4aJ04UEI00iB4l0?DaA
041?E00lBe00>TU>03a;D00mC540>dY?0P0iB4d01@0mC540A5=F03a8A00mBT<0?DU40080>TI201X0
?DU803]6B00g@T@0A4mC045<D010Be40@TaD041=E@13D5P0?DYB04EBFP14DET0?daD03]8D00hADd0
=45902`i@@0Z=cl0=D9:04]HH00`?D<0=T=9030m@`1AGf40LX2003U7A`80>4I604`0>4M403Y9AP0j
B4P0>dI803Y5B@0kATX0?4M;03Y5B@0e@4@0<ci203i9C@0iA4P0CEQL03I1A@16DE<0=Cln034l>00c
?SX0<c`i02`c<@0Y;bd09bd[02H[:@0S9bH08bPT02T^:P0^=3808b/]028/;@0W;c40>T9403Q0@P0`
>3X0;34d02H[;P0Y;S408bLZ03Hi?P0b=CX0?4=<05eVK`0Z<c`07RPa045>EP0_?4@0>D=<045:D`0W
<3T082@_02<S;`0];CL08R0Z02@S:@0`;c@0=CDf01lO7@0];B/09BDS02`/;00A4A<0;2/a02d/=00Q
82H08R4U02PX:P0S92H08B8V02<T:@17BU00C55G02lc?00Z<CT0;3<k02D/=P0S9Bh08B0V0P0V9B/0
300U92X0:2L]02@S:@0U92X08R4W01lN900N7B<07ahT01/I800J5ah06aPO01XG7P807Q/R00L07AXQ
02<P9`0S82L081dT02LT:`0U8RT07A/Q00807A`Q00l07QdR01`K800I5a`05Q@I01@B5`0I51X08QdS
02@O9@0P6B006aDO010:500T7RP081/R01HA600Q72<00P0K5Q`04`0K5QX071LK01`G6`0L5a`05a8I
01TC7@0Q6bD09B0W03@_=P1PFf805Q4G01TD6P0H4aL06A@H01hI7@0G4QH071HJ01/E6@0J51P00`0H
4QH05@0C3A406aDI01LA5@0G4AD06aDI018=4`0:2a0051LL01@E6@0P82805a@F01TC5@0D3Q003``?
00d<4P0=3AD0F5]U03@d?P0O6R005Q0B01<=3`0201@>400901PB500J51H081XL00d72@0?2@/04`d?
01H@4P0F2`l05``@008060dA00@05``@01H;3`0I3Q8060dA0P0G31000`0H3A405`hA01D>4002010:
300c018<3P0@2P`03PP:018<3P0A2`d04P`>01D?4@0I4aD06Q@F014;3@0B30h04`d?01LA4`0K5AL0
7ALI01D?4@0B30h04@/=01<=3`0F4180618B024L5`0I510050l<01XD5@0J51P04`hB01dH7P0P6b40
7Q`O01dK700M71X07AdM01/O8`0O92P09B/`02Pa=P0Y=3X0:cPo0393BP0a@TX0?U5I04mSK019GfX0
DVIb05e_O@1SMH<0JWb:0763T@1eQiD0N8ZH0080MhVG02@0M8JD06anS01WNHL0GW5o05Q^N`1HJgT0
BUeZ03]=F@0kBE@0>DE@030j@`0Y<ST09bdd02DZ<00P8bX07QlU02d[<00T8RD05Q@G01XH6`0A3@h0
4`l@010<3@0=1`L04@/;01lI6@0D30/04P`>018<400C3@h05@`=01D=2`0D30T05P`:01D;2@0D2PT2
01<72`0401<7300D2@d04`X;01892P804@P901l040L800l61`0A20T0>C0a0<k5aP3Id=40@3Lh04Po
@02LTi@091/L01L>3`0I41403PH703Xa<P2IT9405@`=01XA4P0@20T02`8301451@0@1@D07aDD02<K
6@0I4a005A0=00`7100@2PL04`/901<9200B1`H03`<300H05@L700L05PP801D71`0>00006`d=0186
1P0F20P04`D500@050H60P0C1@D04P0D1PH05@L701D71`0D1PH050@701P43@0F1@/05@L701@80`0B
2@004@X001L@200=1@<040L:01454@0A0QD05PPG01@52P805@H900L04`@701@5200E1PT07a0C02@E
600I2Pd04P<600805`P;00H07a<E02dQ8`0X71h04PH801H:3008000201X>4004028F600M4A<06`lA
01P<3P80200001L03`<501041P0D20X05`/=00P0000E2@/04PH800d10`0B1PP050H:01H7300T5AX0
6`hA08enP`17>3d0:1TN0=C5bP0P4AH07A0C01L83@0:000070hB01H:300200l31@030186200@10H0
5@T;00D04@D700`040@601T=3`0B1PP02`0101/?4@0C1`T03P8402dQ8`0C1`T040@601451`0F2P`2
01@8300501<72`0B1PX04PH:01862P0@10P00P0>0PH00`0@10P04@D901452@0601@8300>00h21P0M
4AD050P<01L;3`0B1PX03`@701452@0G2`l04`L;01862P0>10H040@801<72`0B1PX3010420030145
2@0B1PX04PH:00@04PH:00H03`<701862P0B1PX04@D901862P0D20`Dooooo`006oooool03P0C1`T0
60`>01451`0C1`T0710B01@82P0M4A<02@0001T=3`0C1`T04@L801hB500F2PX05@T90P0C1`L0200E
2@T05PX:01L;2`0E2@T04PH601<71`0E2@T05`/;0P0B1PH03@0C1`L05@T901L;2`0H30`040@401dA
4@0R5QH0710@03/_;`0b9RH04`L701451@0@10@00`0A1@D501@8200J01@91`0D2@@05P/701L<200D
2@D06@h<0146100D20P050P:01P<3P0F2Ph04`L;01H<2P0L4``05Pd601L>2@0I40/05@/901/A4007
000050X;01X@4P0Z7b<040D901hC4`0E2@T201L;2`0?01H:2P0E2@T0710@01P<300C1`L060`<01@8
200G2`/07a@C01T>300C20H050T701L<2P0F2`T050T700805@X80P0D2@L0100F2`T050P901862P0D
20`301D93@0:01H:3P0L41@081@H01T=4@0D20`05`/?01873@0>0`T05@X@01873@805@X@04@060dC
01lD6P0Q5Q`06PlE01T>500H3Q@05@`A01<=4@0E3a<05Q0D01LA5@0I4aL06aDI01XD600I4aL0618F
01TC5`0K51X081HO01/A700I3Q`050`G01LA5`0K5AD061D>02TW7`0J6AD06ALJ01HB8@0M62h07QX[
01`I9@0J5b006QLN01XH6`0J61T06APF01dK6`0J61T0518G01LD6P0S82/061HS01PF900F52809B<`
02DT;`0I6B<08R8Z01DG7@0O8RL05QXM02lc=P0T:Bd08BP^02L^=@0U;3807bLZ020X:P0Y<S407RLV
020X:`0Q:B`08RT_024X<00P9bl0:34h02L`=`809Bhe00<0:SDk02hi?`0b?D<00P0/>Cl02@0a?T@0
<T5603=2A`0`?DH0=T=<03A1BP0e@T/0=dA=03E2B`0203Q5CP0d03U6C`0d@DX0=45:03Y7D00b@4/0
<d5:03E3C00iB4l0?TeD041?EP10CUT0?DYJ04AAHP17E6L0@dmW03Y8F`0iBEP0?TiM045AG`0oCe`0
?e1J03m@F@0eATh0@U=J04AEF`0dATX0>D]?049CEP10Ce80?Te@03a;CP11D5<0BUQI04IBE013CU00
?d];03e8B00oBDX0@de<03e9B00kBDT0AE=C03m=C`0`?T40@4eC04]HH00lBE80IG5m03m;F012CUh0
K7R703]:D@@0?4]@0P0mC540500kBTl0>DQ=03Q7C00jBDh0?Te@03Y7@00kB3l0?4U103U6?`0iAD40
?DU803e8BP0g@T@0@diB049=D`11Be@0AU1I04=@F@14DEX0>dQB0P14DEX03`11CUL0?DYB03m<E00h
ADd0;3To02dj@00b?dD0>DI<03I4A`0lBT/0=dE603e;B`10Cd`0>TU603U8A@0303Q7A01H03U7A`0j
ADT0>DA:03]6C00lAdd0>dI<03I1A`0e@4H0;cY0041;D@1iQ8X0CEQN028];`0d?c/0;cPc030i=00_
>3<0:30[02L]:@0T:RH08BLS020U8@0S:2@0:RdZ02/_;P0I8b@0<C`n02/e=`0N:2X06R8U02de>00]
<SD0=3Pi03Hj>`0e=SP0<C8f02/^<`0c>d<0=d1901lX<@0iADd0P8fE06=`N00`>d@0;cQ1034j@`0X
;3L06QXV02DU;`0V92h08R4W02d/<@0P82407alM01/L5`0P8Ad06a/K01hN8015A4T0SXfE03dl@P0U
92P0:R/]02HW:@0R92P08bH[02hc>00U;3806b8Z02`e?@0_>44092df028V;P0P7bD092<Y02TX;P0Z
:Bl0:BP^02<R:00U92X08b8X020O9@0M728071/Q020N900P7B@07a`S02@Q:0808AhU00L08QlV02@Q
:00S82L07a`S02LT:`0U8RT07A/Q00<071/P00T061LL01HD6@0F51T05aDJ01XE6`0N6Al081/Q020I
800N62800P0J51h00`0Q72<07QTP01lJ8@0201XE6`806aHJ00/071LK01`G700O6R407QPR01/E7`0C
3QD07QTP02TT:`0H4aT06aHL01`G6`0301XE6@0901`F6P0K5AT06Q@H01PB5P0G4AD0618F018<400I
4aL05a4E00806aDI00l05Q@I01@G700L82@0BDY>024Q8`0;20X08alN01/G600G51L07A`R02l_=`3;
c]@0Y:N`024O900I4aD00P0D3Q001@0F418071HH01PB500M5aT04P`>00806aDG00<040X<01L<400G
3100100G31000`0N4aL060dA01H;3`0201T>4P0;01@;3P0H41<030H800X41P0C3@l0618D01H@4P0@
2P`04@/=01<=3`0F41800P0G4A<01P0D3Q004`d?01@>400G4A<06aDG01dG6@804`d?04P06aDG01PB
500C3@l05a4A020H500M5A806A4?01TB4`0G4AD04P`@01XD6`0N6Ad07aXN01lK700O6aX07AdM01/O
8`0N8bL08bT^02D^<`0V<CL0:CHm03A5C00eATh0@5=K051TK@1<HVd0EFUf05maO`1UMhD0K7j<07>5
T`1hRYP0O8jL07j@WP20TZ00OHnM07B6U01/OX`0H7>105Q^N`1EJ7H0BE]X03]=F@0iAe80=d=>038l
A@0^=ch0:c0i02HZ<`0P9B/07b0V02DT:@0K6ad05QDG01TG6P0H51D07ATJ02LS900K5AD03`T900L1
0@0J5A<04P`>018<400B30d05@`=01H>300F3P/060h<01L=2`0E2`X201@8300401@83@0D2@d04`X;
01<:2`<04PT:01h04`X;01H=3P0e;2d0iMcM0?olo@1=A4D071<D05=:B`0=1@D01`0001hE5P0E30d0
6a8C03Xa<P0<0`@01P0000l8200M51D04`L700l51@0@1PD04`/901PB3`0K5Q<061<@01D>300L5180
6@l>00d20P0@10@601@61P0801H8200H2PX06P`<01X<300D1PH05PP80184100C1@D201@61P0401<5
1@0B10@04`D501@61P805@L700l050H601@41`0H11005PD=01D62@0D20@04PT0014;000F40H02@40
01XA4P0I3AH03P0?01L95P0B0`P00`0D1@P03P0E1PT05`P;01X;3P0P4A@05PL:01D62@0H2@`050D8
00/00@0D20X04`L900`20`0O4aD091PJ0P0@10H0500H30h05@T;01D92`0H30h0200001H:300J3Q00
3@4301L;3@0@1PL02@0001P<3P0@10H04`L900d10`0I2`l03002028C600D1@X09QLL0P0:0000300k
;3402P0001H:300E1P/0:1TN0185200G2`d03P840186200G2`d04`L901@82PH04@D700h06@d?0186
200<00805`/=01451`0C1`T0QGUk02DI6`0800007Q8D028H6@0E2@d050P<01<72`804PH:00L04`L;
00d11@0F2Ph050P<00d11@0A1@T03P<600H04`L;00`03`<701@8300C1`/05`/?01862P0A1@T06`lC
01X>4P0A1@T03@4501D93@0N4QH201862P0401452@0B1PX05@T=01L;3`H04PH:0P0@10P0100A1@T0
4PH:01862P0A1@TDooooo`006oooool0NP0A1PL05@/;00h30`0?10@05P/=0187200E2@/05`/=0104
1P0D1`X070hB01851`0E2@/05@T:01`@4@0?10@0;20Q038V9`0?0`@06@d>01dA4P0G2``06@d>00h2
0`0F2PX04@D501<71`0E2@T03P@401D92@0H30`0HUIF07a`L00V6QX06`l?01451@0F2P/05@T:01H:
2`0B1PL06@d>01@82@0C1`P03`@401T=3P0C20P04PH701L;2`0E2PP040H401<81@0E2@P05`/:02`Q
800D20P050P901/?400D20T04PH901<81`0D2PH04`T501@:1P0D2@P040D401<81`0D2@P07A8C01@9
2P0L4A8030<401/@400D20L04`L701D92@0F2PX050P901T=3P0H30d07Q8C01<82@0I3@h04PH901dA
4P0G30/04`L801H:2P0F2PT05@T:01P<300G2`X05@T:01H:2P0D2@P05`/<01T=400E2@h06@dC01P<
500L4AH05PX@01P<4`0K3a@07Q<I01/?5`0H31405`/B01/A5`0D31407A@I00h42P0E3A80610E01<9
3P0N5Q/06A0E01T?500F3Q<05PdB01@>4P0F41@05a4E0P0F41@00`0I4aL05a4E01PB5P0201LA5@0c
01TC5`0G4AD050dE01LA600K4a`05a4H02<M8P0b;Bd06QHD01/H5P0H5AD07AXM01PD7@0G4al081`V
01XF7`0H51`06aLM01/I7@0H5QP05aDG01/J6`0M6al07Q`Q02@R:00G51`07AXS020N:00M6R@07Q`V
020O:00O7bP0824Z020S:`0F6R807B4Y07b1R00O92`08RH_020T;@0N92/08bL^02L/<@0S:Bd09R/`
02HZ<00T:C408BH^02`_>00U:c<09B`d0080:30h01T0:C4h02/c>P0[=C`0;CHm02`f?@0[=C/0;CLn
034l@P0b?D<0=3e603E0B@0d?dP0=dA=03Q5CP0c@4T0=TA=03Q5CP0jAdh0>4A:03Q2B00iA4X0=45:
03I3CP0f@dd0?T]F0080?DYE04h0?T]G03]8F011CUh0@dmQ03m:GP0mBe/0@4mK049AG`11D5`0?TeH
04=BG@1:FV80>4Q@03M7CP0kBe40>T]?03i>D`0mCE40@4iB045?E00oCE40?D]?041=DP0oC4l0>dM:
03M3AP0hADL0?DY<045<CP11CU00>DM:03Q5B@0kBDd0>4E<03a9D011CUH0A55J06]hP@1=FF@0>4A@
04AAG00nBe80?D]?03i;C`0oBe00?Ta@03e:C`13Ce@0A59F041=D@0kAd`0>dU=03a9C00jBDD0?4Y3
03a:A@0iAd<0>TM503e:BP0oC4d0>dM903i:CP0lBDd0?TY?049?EP0oCEH0?TeH03m=F015DU`0@E1J
04UGH@0lBU@0@E5H03a;E00_?DD0;cm603A2B@0jB4h203M6BP1S03e;CP11Ce80>dU<03m=D00mBdh0
>TQ;03Q7B@0hATT0>4I803Q3A`0iA4P0>TE803Y4BP0jADT0>DA703M1AP0i@TL0;3Di03U1A`0b>Sl0
?4A703Ln?@0/<c00:c8_02ld<@0[<2l0:2d[02X_;`0N8R40:Bd[024U9@0[;bh0:Rh]02`c<`0W<C40
72DW02Xb=@0T:bl0:2lc02`a=P0_=3P0;30e034e>00[;C80;30e03<j@`0e>dD0:C4j02`e?@1:De/0
=3e502/d>`0P:300:2he02``>01LH6L0;Rlh02LY<@0U9bh0>3Xo02<V:00T9bH07B0O028U8`0V:BP0
9bXY024T9@1ZKFl09RT/02DW;00T9R`09RP]02@W;@0U:2h082@[01dP:`0Q9Bl0:Rdh02LZ=P0T9c<0
9bLb020N:00P7bP0:2L`02d/<`0Y:2l081lU01lN900N7B<081lU01lN8P0K6Ql071XO01`J800J5ad0
7A/Q01lL8`0N6b8081dT00808AhU04d081dT024N900N728071XO020N8`0Q82D08R0U01lM8P0L6Ql0
6QPM01TG700J5Q`07ATO01lK8@0N6R007APO02@N9`0F41T071LN01/F7@0G4QT09B0V02@O9P0N6Al0
61<J01XE6P0M61h06A<K01XD7@0K51d0618I020J8P0J51/06A<J01XD6`0L5Qd06A<J01H@5P0J51X0
6a<K01TA5`0K4AT06a0I01L?5@0K4AT06@hG01L?5@0I41L0714J01L=5@0I4AT06QLP05UHG`3Sh>D0
OW^001`J6`0H5A@0514A01PH6@0D5AT03a8H07EhP@1@DUX0618I01T@500I4AD06@lD01L>4P0F3a80
5`dA01/C5P0M5QT0:AlT02@K7`0C2@d060dB01L<4@0201H;400F01P=4P0I3Q<0714F01T>4`0F2a00
5``A01P=4P0F2a005PdA01@:3`0K51L060lC01L=4P0C30l05PdA01dC5`0D3A005`lB01D;3`0B2Pd0
61<B01H@3`805@l@07@04`h@018=3`0E3a<0618H01PD6@0/:2l061@K01`H700I4Q<05Pl@01PB500H
4A@071HK018=4P0H4QP06QDJ01/F6`0L61/07APK01/I7@0N82H07B4W02<X;P0R:S40:34i02`h@00`
?TL0=4A=03e?FP18FfH0C5m[05AXM01QLh40J7Z806alS01fQIH0P8fO08RDY`2>VZh0U:2b096N[`21
Sil0MhFE06YlRP1NL7l0EVQi04eNK@10DUl0>T]H03I5D00c?dP0;cY302/d?00V;3D08RH`01hP9`0N
7B<071/P01dK8@0G51T06A@I01H@5@0K5QP05@hA02LO8`0J41<060hA01L=400D31006@lC01X@4P0F
3@`05@`<01D;2`0F30`05`d>01D93@0D2@d05PX?01@93@0B20/04`T<01@:3@0C2@/050X<01882P0I
3a8050X=07E[KP2>Q8H09adP01XA4P0>1PL06a4B01882@0D2P/04@H801872@0[82405@`=01<82@0B
1`T05@X;00h20`0C1PL04`P801@92@0D2PX03`D501<92@0B1`P06Pl?01P=3@0A10D05`T;01L:2P80
4`H600T04@@401851@0M4100304101H92@0G2PX040<301D92@0C1PH00P0B1@D201<61P804PD51@0C
1PH0A00C1PP05`TA01<63P0I31407aHE02DN6@0A2PD0610;00d61P0G3Q007A<I01@8400B1Ph040<9
01<52`0D1`X05@P<01L93@0H2Ph04`H901X<3`0B10L05PP;01P:300@10H04PP900l31P0B1PT050P;
0145200>10H04PH901<52@0F2@`05PP<01/>4@0D20/06@dC04Tl@P0i;C802P0201H:3`0A1PP04@D7
01P<3P0B1PP060`=00h30`0C1`T03P0501H83@0@10L04P@901D8300H2Pl04`P:01/=4P0C1`X060X?
00l41P0F2Pd060`>00h41@0I3@l05@X;01L;3@0B1PP04@D70P0B1PP03P0A1@L04PH80186200A1@P0
5@X=00l31P0A1@P04PH901H:3@0S5aX04PH901<72P0@10L04PL:100C1`/201862P0Z00`2100F2Ph0
5PX>0104200D20`04PH:01<72`0@10P04`L;0104200A1@T04`L;01@8300C1`/040H801P<400G2`l0
50P<01D93P0C1``04PP=01863P0F2a40304601<73`0C1`h03P<701D9400G2a805PX?01853@0B1@`0
4@@:0144300D1`h05@P>01H94@0B1``04PH;00h32@0I3A<03P875?ooool001_ooooo00T03@D301@<
2P0H40h0718A0188200E2``04`L901D82P0F1`X00`0F1``201<72@0G01lC5@0>0P@0=2PZ03<W:@0N
4Q@02@0001D92`0B1`P0300201H:300A1@D05PX:01hB4P0?10@07a<C01@8200Y7Ad0flo?0?kblP17
>c/04PH601/?3`0P51H00P0C1`T05@0;00406@d?00`00P0B1PP07A4C00l31@0J3Q00=BT[01041P0B
20P081@D01H:2P0=0@40BShn0:fQX@0P51@03P8200/0000C1`L050P801P<300201D92@0301@8200C
1`L04`L700805`/;0P0D20P0>P0?0`<02@0001D9200G30X05`/;01H:2P0D20P05@T;01dA4`080000
3`<701T?4@0C1`/0300401D9300C1`T04PH801L;3@0D20X04`L901L;3@0C1`T050P:01X>400F2P`0
5@T;01D:3`0@1@d060dE01@94@0M4QX05@XB01L<500F2a<05``D01P=5@0I3QH05P`D01H=4P0H4QH0
5Q0D00h8300L5QX05a4E01<=4@0I4aL04P`@01@>4P0B310050hB01D?4`0G4AD0618F01@>4P0C3A40
5Q0D01LA5@0I4aL201LA5@0@01/E6@0H4QH06A@H01PC5`0F4AD05A0D01/F6P0Q72006QDI01D@500F
4AD06QDI01dH700J5AT081TP01hH7P806aHL02P071PN01/I7P0/:Rl08AlT01`K800F5AX07A`Q01TH
7@0J61d0920V01dK800K6R006aXQ02h^=P0W:S<08RH`01PL9`0B5R808BHb02<W<P0T9S80:B`e02@W
<00R9Bh09BPa02@W<00[;SL09BPa02P[=00V:C80<SDn02HZ<`0X;SH09B`d028Y<@0U;3@0:c8j02he
?@0/<c/0<CQ00P0^=Cd0>00c>T80=3]302hf?P0a>d@0<Sa503E2B`0hATl0=TA=0391B@0a?TH0<d54
03Q3AP0g@D80=3i003Y5CP0d@4`0=T9>03m;E`18E680G6Qf03e9E`0g@e<0>DEE03a8F00kAUP0>4ED
03a:E@17EF00CE]V041>F@0jB540?DaD03a;DP0hAdh0?4]A041?E00oCU<0?4Y@03i;D@10CE<0@e1F
049?E@11CU@0@4eC03a9C`0gA4X0=T=903]8CP0lBDl0?daC03a9D@0jAdl0>DI>03E2BP0hADd0>dQ@
0P0iATh0;@0kB500?4UA03e:D@0oBU00?dY>041;C`0oBTh0?DQ<03a7B`10Bdl0@TeA03i9C@0g@TH0
>DA803]6B@0oCDd0?Da903a:BP0kBDT0?4Y:03m=CP14DU<0?de>049@D`16E5L0@U1C04ABEP0kBE80
=dQB03a=E`0kC5H0=dQB04UJI02EY[00EVMa02dnB00mCUP0>T]E051QJP10CUL0>4M>03e<D`13DUT0
?TeD03a;DP0203Y9D00d03Q7CP0fAD`0=4=:0391AP0g@TH0>DA603M2A00e?d40=3i003Do@@0h@4<0
>D54034i?00b=c/0=3Tm02db=@0]<C@0:Bd^02hb<`0`=3D0;30a02T];P0e>CX0:bl`03e1@P0M8B80
7b<T038f=`0U:bT0:S0_02/a<@0^<cL0:Rhg028V;`0Y;CH0=c]403/oB00n@dP0<3Di02P]<`0b=T00
<SI102/_>P0_<c`0<CDn02T]=P0U:S007B8X020U:`0Z;c<0:2da028W:`809BX`01H08bP^02P]<@0W
;2l082DX024W9`0F71`06R0N01lU8P0P9R@09R`/02hc>P0S9Rl09BPa02<V;`0Z:S@092@_028R;P0T
8Rl0:BLe02/Y=`0W9C<08b4_0P0R82d08@0R82`08R0[020O9`0O7RD06QTO01DD6@0H61/07AdO01`L
7P0L6ah07adP01hL8@0O7280:2D/02LT:`0P7B@06aPO01`I800Q7bD071XO01XH6`0M6al07adR01hL
8@0K6Ah07adR024O900K6Ah05A<H01LE6P0K6Ah07Q`Q01dK800201TD6`0602<N9@0F4AP09b8Y01dH
7`0@2a805Q4H0P0K5Qd0100M61l06A@K01TB6P0J4a/201/D70<06Q<K00D06a@L01dF7P0M5Qh071DM
01/D700201/?6@0701X>600H31H05`/E01H:500I3AL06`lI01dA6`0201X>600@01`B6`0T6RD07aLR
05aEG014?dD07AXL01LF500E5A<03`l@01@E5`0H6Ah06QdT04i=E@0N5ah07Q<I01/@5P<06PlE00<0
7A8H01/@5P0H3A<00P0G318201H;4@1C01D:400D2@l050T?01H;4@0G318050T?01<83P0D2@l060dC
01/@5P0J3aD04@H<02XO9@0:00D04@L<01/@5P0C20h03`@:01D:400F2a406@hD01P=4`0U6Qh050d:
01<>2`0D3``05Q0@01<?400A3@h04@`B01`I800F4a`0;bdh0:bZ]@0h=Ch05Q4G01<>500N6Al06aHL
028M8`0G4QP061<I01TD6P0J5A/071LM01hI7`0M6b006a/S01XM900U:C409B`d02lf@00g@DX0<Sm8
03I4D@0mCEX0@59N04UKJ@1DIg<0HWB006alR`1cOi80PhjR09>K/P2NYKd0YJ_50:R^aP2QZ;d0RiJX
082;W@1bP980HW6405UZO01?H740@E9R03]=F`0hBED0<D9<02hkA00[=3h09B`f02<W<P0N82P00P0N
7BD09@0L6R8061DL01PC6@0E3QD071DL01L>500P5A/06@hD01/>5@0I3Q805``@01`A5@0O51P060dA
01H;3`0A1PX04PL;01@93@0E2Ph050T=01462P0F2`l04PL;01D:3P0I3Q805P/?01D:3P0@1@T06@hB
01062@0P5AT08AHJ01892`0I3@l04`L901P<3P0J3Q000P0A1@L01`0@10H060`>01dA4`0J3Q004`L9
00d10`0B0`H00P0F1`X301D62@0B01<41`0D1@P05@H901D62@0D1@P04`@701861P0A1@D06Ph>01/?
3`0M4A40;b<S00l30`0E2@T04PH600l30`0@10@03P821P0B1PH00`0C1`L04PH601451@0201861P0J
01881`0>1PP04@P;00L00@29P8<0[:>V01XA500B2@`04@P;00h5200I41<06a8E01482`0?0P/03P48
00d01`0>0@P05@T=01T=4@0@10P05PX<00h2100F2P`060`<01881`0A1`X201072P<04@H:00<04@D9
01@52P0F1``00P0H2@h01`0E1`l05PTC028E7P0L3aL040<:01D83`0C1`/00P0A1@L08@0A1@H04@D5
0146100H30d06@dA01@8300A1@T04PH:01452@0@10P03P8600/00`0@10P06@dA01L;3`0A1@P05@T;
00d10`0B1PP03@4301451`0>0`@04`L901@82P0A1@L03@4300h2100A1@P06@dA00h41P0<00@05`/?
01472@0901862P0<01452@0@10P040@800P0000:00803`<701@8300E2@d050P<00d11@0<00@050P<
0P0B1PX07`0A1@T03@4501D93@0C1`/060`@01H:3P0@10P04`P@00h32`0C210040D=00L0100@1@d0
4PL?00`22@0X7BD06PlG00d42P0F2a<04PD>01443@0?0P/040<<01<63`0F2A804@@=01L:4`0=00T0
5@PA01H94P0;00L05?ooool001_ooooo02D04`/901081P0?1`D06@l>00d51@0J41404`L901<6200E
1PT05PL:01P93@0I2Pl040@600l31@0C1`T03`<501hB500C1`T04PH801`@4P0F2P`04PH801451`0V
6Q`06@d=01451@0:00004PH601X>3P0:00009a/K06QLG01lL700:alO01451@0=0@40:AdO00804PH8
01D050P:02@H6P0C1`T05`/=02HJ700A1@L02`4201`@4P08000060`<00l30`0>0P804PH600P0000M
4A404PH600h20P0900009ATI00h20P0?1@D00P0E2@T00`0D20P04`L701<71`0201@8200:01<71`0F
2PX04`L701<71`0D2@P05@X801H:2P0C1`L040@401<72@804@D700D0710D024E6@0K3a<09QXN0146
200201@82P0401L;3@0D20X050P:01T=3`8060`>00`06Ph@01@82P0B1PP04@D:00l42P0H3A<04`P>
01/@5P0G31805@X@01H;4@0G318201H;4@0L01T?500H3a@02`D901PB5P1hLWH0SHN;01@>4P0E3a<0
4P`@01<=4@0?2@d04`dA01/E6@0D3Q805Q0D01PB5P0F41@05@lC01LA5@0F41@0618F01LA5@0H4QH0
71HJ01TC5`0I51P05a8F01HA5@8061<G03<04`hB03<^<P0K5QX061<G01dH700I51P05a8F01dF7@0N
61h07APN01hI7`0N6R007A/P01/I7P0D4QL05QDJ018A5P0K6Ql07A`Q01TG700Q7R@081dT02@S:@0K
6R4061PP018E7P0R9Bl08bDa02X^>@0O8bl0;c<n02d_>`0/;cP08RD^01hQ:P0S9Rl092L`02LZ<`0P
8b`09bXc02/^=`0]<3T08RH_02D[<`0X;cL0:c8j02`c>`0[<SX0:S4i02`c>`0b>D400P0_=Sh0=@0c
>T80=3]3038k@P0g@DX0<ce6030mAP0a?dX0;Ci80351B@0a?TH0<T1303M2A@0i@d@0=d9403a9DP0c
@D`0=dE@03Q6D@16E640JGN4049@G@0gA5@0>TMG03m<G00nBe`0?DYI03e;EP10CUT0AUAO041>F@0l
BU<0>DM?03U8C`0kBU40?4]A03]:C`0nCE80?4Y@03U6C00mBU00@DiD049?E@11CU@0@4eC03e:D00j
Add0=dA:03Q5B`0mBU00@DiE03U6CP0jAdl0@DiF0080=dA<00L0?T]C03U6CP0hADd0>4E=03Y7C`0m
BU40?T]A0080?Ta?00/0?D]>03a:C@0kBD`0?4Y=03Y8B`0kBD`0>DM:03M5B00mBdd0>dU903Y8B002
03Q6AP0L03Y8B00nC4d0@Dm@03]9BP11Ce80AU=I03m<DP0lBU40?TaE03Y;E@0oD5X0?DiH03M8DP13
E5h0bM[T07J7T@0jBeD0AeQR03E6D00^?dP0?deF03Y9D00kBU40>TU@03Q7CP0iB4l0=dI=03Q7CP80
=dI=01D0=DA;03=2A`0f@DD0=d9403E0@P0c?Cl0<S`n03<m?`0f?T40>D5403<k?P0a=SX0;c@h02/`
<`0Y;C00;30a038f=`0`=3D0:bl`030d=@0R9RL00P0T:2T0:@0L8240=3Pi02HZ:`0T:RP0:S0_02hd
=00`=CT0:Rhg02<W<00_<c`0=CU2034e?P0g?480<cPl02db>00^<C/0=CM3030b?P0_<S/0;C0i02LZ
<`0M82L07R4X028U;00X:c009BP]020S:00U:2d08bH[02@W;00[;S<0:Rha02<W:P0/<380<SHg01lS
900N8R80720Q02P/;`0N8RX06ahW00808RD^00@0;2`f02LW<P0S8bl09B<`0P0X9S<0:`0U8c008R0]
02DS<00W9C008AlZ01/I900O7RH09bH]02@S:@0M72406aXN01hN800O7b407A`P01/I7P0I5a`06aTN
028P9@0Q7RD07AXQ01/H7`0M6b0081hS01`J7`0J61d07A/P01hL8@0K6Ah05Q@I01`J7`0P7R<06aTN
01LE6P0J61d06aTN01`J7`0O7B809b8Y01@?5P0P6b8091lV04]6C@0M61l00P0P6b80100J5A`05A0G
01TD6`0I51/201XC6`<06a@L00<06Q<K01TB6P0I4QX00P0K51`0100J4a/06A8J01/@600N4a/201/@
6005020E7@0H3AD06@hF01/@600L4AT00P0J3aL06@0K4AX05P`G01L?6P0C31<07QTO01@A4`0I5aP0
4Q8B01@D5@0>3a405QLL04=4B`3PgnL091dT01hC6@0H3A<06@hD01X?5@0G31809AXP024F700J3aD0
5``B01T>500L4AL00P0F2a4201@93`0>01D:400F2a405P/A01<83P0F2a406a0F01dB600H3A<081DK
01<83P0U6R0081DK00L00P0I3Q@201lD6P1B01<83P0A1P`04PL=01T>4P0D30T04@`901<>2`0E3`l0
4`l@014=3P0G4QP02`P?01LD6`0M6R<0f]OR06eZL`0H4aT03PT?010;4@0=20h06A@J01LB600F4AL0
5a8H01TD6P0L5ad07aXP01lM8P0P82P07b8Y02HZ<P0S:S80;3<m03DoB00b?dP0=D=@03];F00oDEd0
BE]Y05EWM01OLGd0JGV807N3UP2=UJX0W::j0:^`b`2b]]<0/;K@0:J]a@2BWK40QY6U07J4U`1UM8L0
FV]m055RL`13E6@0?DmM03U:E`0b@dd0;ca502/d?P0U;3H08RHa01hP:00K72406aXP01TG7P0H5A`0
6QDL014:4@0Q6al06a8G01X?5@0L4AD06`lC01P=4@0G31006PlC01/@500G31005P/?01D:3P804`P<
0P0H3A402P0A1PX06@hB01872`0B1`/060dA01H;3`0C20`03P<701D:3P0C20`200`11@0E01482P0E
2@/040@601D92`0G2`d040@601451`0>0P@060`>01lC5@0M4A<050P:00d10`0A0PD05@H901H72P0C
10L04@8501@5200C10L050D800805@H900/050D801<41`0A1@D04`L701`@400K3`l05@T901dA4@0@
10@05PX:01@8200201861P0300h20P0B1PH04PH600@04PH600<04`L701861P0A1@D00P0B1PH08@0B
20L06Q0C00/21@0J4A@0@CPk04U0@`0<0`H03PD800l62@0A20/07aHI01dD5`0?1PT04PD>01H9400D
1`h03`8901862P0F2Ph04@D90186200=0@<05`/=01P<300B20L040H:01482`0B2@`04`P<01462P0@
1@T04@D901@52P0301D62`0:01@63P0F2A804`H?01853@0C1Pd04PH:01@8300@10P040@601451P80
4PH601<07Q8C020D600E2@d04@D901@8300B1PX06@dA01H:3P0=0@D05PX>01/?4`0D20`040@70104
1P0F2P`04@D701`@4P0@10H03P@5008050P:00T04PH800h2100>0P@03@8400P0000H3Q008QHJ0965
R@0H31001P0B1PX301452@080104200?0`L03`<701X>4P0F2Ph040@801452@0B1PX30104200H01<7
2`0B1PX04@D90104200>0PH05`/?01D93@0F2Ph040@800d21@0Z7bL09AXR03<X<00Y7RH05P/C030U
;@0_92`04`P@07mdO00m<SX050TA01<8400C1Pl04PD>0P0@0``0200C1Pl050L@04e0B@1;?TL04`H?
02@G800>0`X04PD>5?ooool001_ooooo03`04@T801<:2P0=1@D07A<C01@:2`0=1@D05@T;01D82P0F
1`X05@H901L82`0G20`04`L901H:300>0P@050P:01D92`0C1`T05PX<01<72@0?1@H05@T;00T0000A
1`P06@h>00d10@0D2PX06`l?04a0@00H30`03`@401dA4@0R5QH050P801T=3@0K3`l06@d?00l31@0F
2P`06@d?02TM7`0I3@l04`P902PL7P0M4A<04`L900h41@0O4aD05PX:01<71`0@10@05P`<01861P0F
2PX04PH601dA4@0B1`L0=b/[01X>3P0D20P201D92@0K01@8200C1`L04`L701<71`0F2PX04@D501@8
200A1@D07A4A01<9200F2`T050P801D92@0F2PX05@T;01<72@0L4180;R8V06YNHP0G2`l060`@01@8
2`0G2`d060`>01H:300D20X05@T;00805`/=01`05PX<01D92`0F2P`05`/=01H;3@0C20/060dA01@9
3P0M4QD05@X>01@93P0F30h05``@01<83@0D2@`06Q0D01<:3`0L5QX04`dA01hH700Q6al04`dA01LA
5@0?2@d05a4E014;3`0J51P09b4U0P0D3Q8301H@500;01D?4`0D3Q805Q0D01H@500G4AD071HJ01TC
5`0F4AD05a8F01TD600J5AT00P0K5QX0200`:bl06aHJ01`G6`0N6Ad05a8F01hI7@0L5A`07ALN0P0M
61h01@0L61h06ALL024O900J6Ah08b8W00807ahS0P0K6Ql08@0K6R008R0V028Q:00R8BT0C4aD05=E
GP12A4h0:2/e01PK9P0Q9C007b<^02DX<@0X:c@08B@]01lR:`0T9c009BPa02P[=00U:3409bXc02/^
=`0Y;3D09BTb02H]=P0S:c@0:30i02`d?@0]=Ch0<3Q002de?@0b>T<0<3Q002lg?`0203<k@`0C034j
@@0b?4D0<ce603Y7D@0iBU@0=4E?0311B@0a@4L0<Sm503I1A00jA4D0>dI803M5C@0iAe80>4IA03U7
DP0iAe@0AeER04ECH00304AAH@0@04AAHP10CE`0?D]F045?FP17EF00@DmJ041>E`0nCED0>dYA03e<
D`0mC580?4]@03e<D@0oCE80?T]A03e:D0<0>dQ>00`0>DI<03Q5B`0iAT`0=T=903Y7C@13D5H0C5UP
03U6CP0d@DT0AU=K03a9D@0gA4`503e:DP0K03m<E010CE<0?deA03i<D00mBTl0?4Y>03a9CP0lBTh0
=dA903]8C@0lBTh0=T=803a:C@0iAdP0>DM703Q6AP0iAdP0>dU:03i<C@0gADL0?D]=03a:CP0nBe40
AE9H03a:D@0mBe@0>T]E0080?TmI0100>T]E03e>F016Ef40@55K03Q9D`0nCeT0A5EO03i?F00iAe00
=dI=03U8C`0mC5<0?4]B03I5C00jBE00=dI=0P0eA4/01@0hAdh0>dY?03@o@`0g@T@0=T530080=T12
00P0>49402lg>P0c>ch0<SXm02ld>00[<3@0;34d02lc=P80;C4b00<0:bl`02L[;00[;c000P0Z;Rl0
4`0/<340:Rh_02T];P0_<c@0<3Hd02`b<@0V:bh09b`a02X^=`0/<3T0=3Q203Di@P0b=Sl0<SLm038g
>`0^<cT0:2/e030b?P0];c/00P0Y;3D0100W:S<08B@[02DX;`0Y;3<202/^<`0A02X]<P0V:B`071lS
01/O8`0S9RX09RX]02@X:`1?DeL0LWEi02hb=P0P8bL08bL[01hQ9`0S:300:2Xe02h`>`0S9S000P0Q
8B`0<@0W9c<0:2Hc02TW=00V93408b4^02<Q;@0T8Rh09B<^028P:P0P7bP092<[02XY<00X9bd08b8X
01lN8`0N7B407A`P01lN8`0O72806aTN01dK800N724071TO01/I7`0M6R007Q`Q01dK800L6Ql06aPN
01`J800P7B<07adS01/H7P0L6Al06aTO01XG7@0O72808QlU01`J800K61h081hT01lJ8@0N6B006aHM
01hI800k=Sd07APO01/F7@0L5ah00P0H4aX0100L5ah06aHM01XC6`0K51`301`E7@0301/D700H4AT0
614I00@0614I00H05`dE01lE6`0N51X08aTO02lU:`0T6R0501X@5P0@01T?5`0C2aH07QLP01D>5P0D
3aD04`lB01DC5@0F51H04Q4C00l>4`0G5Q`0@D5806m/M00O5Ad06@hD01H;4@806PlE00H050T?01`A
5`0L4AL06@hD01H;4@0G318401T>508060dC01@05``B01X?5@0M4QP0714G01X?5@0G31805@X@01P>
4`0E31006@hD048g?@0^8bT05``B03`a=`0m<SP06@hD01P=4`0P5A/04`P<01TA3`805@h=00@05@l?
01<>3`0A2`l040/A0P0C3aH02P0G51d09b@^01PE7P0D3aD04`hD01TD6P0H4aT06A@J01/F700I51X2
01PC6@0b01XE6`0M61h07A/P01lN9P0O8RT092P`02<Z<P0Z<C/0;cU302`i@P0a?d`0>d]H04AFHP1A
Hg40Ffej05m_O01XMHD0NhBH096G[`2PYL00];OD0<;3i032a>@0]K[G0:>Ya@2DV[H0OhVQ06YiS01N
Kh40EVMh04QIJ@10DV00>daH03=4CP0_?4D0:C<l02@[=@0Q9C008B<[01lP9@0K6b006APM01TH700K
5a/0618F01hH6`0O5QX060dA01L=3`0H3@l301L<400<01H;3`0E2Ph05@X>01L<400F2`l05@X>01H;
3`0H3A40714E02DJ7P0I3Q804@H:0P0F2`l0100D2@d04PL;00h31`0F2`l201@93@0301882`0F2P`0
4`L900805@T;0P0A1@L201H:300501@82P0B1PP04`L901H:300H2@`00P0G20/01@0C10L04@<501T:
3@0C10L050D800805@H900`050D801<41`0B1PH050P801P<300F2PX040D501861P0C1`L05@T90145
1@0B1PH201L;2`L04`L701804PH601451@0B1PH04PH601<71`0H3Q40E4Y>085gN`0]92H03`L801dC
5P0?1@P04@L;01472P0D2Ph04PP<00d21P0H2a@202HI800c01X=500C1`/050P<01<72`0G2`d04`L9
01@82P0F2PX04`T801472`0C2Pd050/>01@93@0@1@T03`@801@8300F1``05`P=01H7300C10T04P@;
01T<5@0?0PX040@:0185300=0@D05@T=0104200@10H04@D701861`0C1`L05PX<01D93@0A1@T03`<7
01452@0C1`/07Q8F01T=4@0A1@T060`@01@8300?0`L04@D800h2100N4Q@05@T;02hR900H30h04@D7
008040@60`0B1PP01P0D20/04@L901T=4@0@1PP050P<01D:3@H04PH:0P0@10P01P0A1@T04PH:01@8
300F2Ph0:1`P01lC5`8040@802H050P<01H:3P0E2@d05`/?00l31`0D20`04PH:01452@0E2@d05`/?
01<72`0J3Q8050P<01452@0D2A403P<;01T>5P0G31@02`8801/@600D2A4050XA01/B600<0`T06@lF
01463P0D1a004`H?01853P0A10d04PD>01<63`0R5ah09AXQ00`1200J3AH04@H=01H94QCooooo000K
ooooo`0801@;300A20T04@P901@:2`0E2``03`D601D92`0G2@`201L82`0501D62@0C10L04PH801L;
3@0A1@L00P0D20X0:`0M4A<08QHH01@92P0800004@H702`P8P0F2P`0300001X>3P0P51@03P@404e1
@@0`92@0710@00P0000:00004`L701X>3P0@10@040@60186200I3@l04@D701/?4@0<008060`>00P0
000;004060`>00d10`0J3Q0040@401<71`0I3@d08QHF01/?3`0@10@03`<301861P08000050T900l3
0`0D20P00P0E2@T0300D20P04`L701<71`0B1PH06@d=01451@0D20P04@D502dQ8@0A1PD04`P601<7
1`805PX:00l04PH801X>400:00007Q8F01472@0/82@0P7Ah01L;3P0J3Q00710B01D92`0D20X05PX<
0186200C1`T00P0G2`d02@0F2P`04PH800l41@0?1@H05@/<01882@0L4Q<060h?01D;300201H<3@80
50X;00@05P`=01482`0?2@d040X>0P0>20`02@0L5QX06A<G01H@500G4AD04P`@01D?4`0L5QX0618F
01H@500201@>4P<05@lC00H05a4E01D?4`0G4AD06aDI01PB5P0G4QH201TD600A01HA5@0G4QH06aHJ
01/F6P0H4aL07QTM01`G6`0H4aL08QdQ020I800O6B007QTO01dH7P0L6Ah06QPM02l]<P0G5AX00P0I
61d03`0P7b@08R4V01hM8`0H5ad081lU020O9`0U9Bd0I6A/020P:P0Z:cD0GF1Y03HhA00R9C005a/V
01XM9P03028U;P1602HY<P0U:3409RTb02/^=`0Q92d0:Rdf02LZ<`0T:3409Bdf02Xc?00h@DX0>dA=
02lh@@0^=d00<3U203<lA@0^=d00;CHo034j@`0b>d@0<Sa202`f?`0]>T<0>dUD03Q9D`0^?dT0<D9;
03A2B`0d@dP0=T9703Y4AP0kATP0>DM?03I4C`0_?DP0?D]F03]9EP0iAe@0>4IC04=@H012Cel0>dQH
03e:F`11Ced0@e5L04MEH016E5l0?4YE03e;E012D5P0?TeD03]:D@0mC580?TeB03]:C`0gAD/0>DI<
03i;D@12CeD0?DY@03M4BP0d@DL0=dA:03U6C00gA4X0>4E;03m<DP1CH6L0AE9J038oA`<0=dA<00<0
>dQ@03a9D@0lBE400P0mBU80100lBE40?4U?03]8CP0jAdd403Q5B`0803M4BP0iAT`0>4E;03A1A`0g
ADT0=dE603Q6AP0jB4P303]9BP0R03Q6B@11Ce80?DY@03m<DP1=FV00@TmF03a:D`0iBU@0>daF03e>
F00lCEL0>DYD03A5C`0fAe40>DYD03M8DP0fAe40>daE03=2B@0d@dX0>4M>041?EP11D5L0=4=:03I5
C00c@TT0;ci5030oAP0eA4/0>TM=03U4B00iA4H0=d9403@n@080<S`n0P0_=cX08P0`>3/0;c@h02/`
=00]<SH09b/^02T];P0_<c@0;C4b02<W:00P92D09b//03i2@`0N8R<0:Bd^03<g>00W:b`0<CLg02le
=00_=3L0;34f02/_>00_<c`0<cM2030d?@0f>T<0;C8i02P]<`0[<3H0;2hi02`^>P0Z;3P09bXc02HY
<P0W:S<202LZ<@0E02P[<P0[;S<0:bhc02/_<P0X;2d0720Q01/O800M8B@08bLZ02T]<01CEU/0BdiC
02DX;`0R9B`08RD^02<V;`0P92l06adY01lQ;@0N82`0:2Pd00809bLc01P0:BLd02LU<P0S8Bh08R0]
02DS;P0R82/07adX020N:00Q82P07ahV01/J8@0K6R007A`R01hM8`0M724071/P024O9@0P7B@071TP
01lM8P0N72406aTN01LE6P0F51T201LE6P0B01/I7P0L6B008AhU02PU;00S82L06aPO01hK8P0P7B@0
7AXQ01hK8P0P7B@06AHM01LD6`0L6B0061<J02PS:P0J5A`050lF0P0O6R401P0[9Rd0:B@[01lJ8@0L
5ah07aXQ01TD6`806a@L0`0L5Ad03P0K51`0614I01PA6@0G41P05PlG01L@600H4AT05@`A01XA5P0I
41D06a8G028I7P0K4QL06Q4F0P0H3a@04P0I41D06Q4F01L>4`0L5Ad030D=01PA6@0=20h05a8G01PC
5`0N71l01`D901LE6P0D4AP0;2/b02LT:`0H3QH060dC01X?5@807Q<I00P06@hD01D:400F2a406PlE
01`A5`0K41H05P/A01L<4P8060dC01405``B01H;4@0D2@l05@X@01lD6P0N4aT05P/A01@93`0L4AL0
2P0502XO9@0800<0;R<Y02dR:00H3A<050X?01@93`0201052`060146300N4aL05Ph=01@;300E30d0
5a4B0P0H4QH0D00E41H02PD<00X5300G51d0<2df02LT:`0M61h04PdC010;4@0E41H040/A01PC6@0K
5Q`061<I01LB600H4aT06aHL01/I7P0N7RH082<Z028U;@0Q:3009bhh02`f@00]>T<0<T1=03];F013
EF40CV1^05]]N01RL7/0JgN507f6VP2@U[00XjC20;bmg@3CdoL0f][n0<S:k@2^/]D0W:3308B>Y`1_
OY40HW>505UZN`1<GFd0@eES03]<F@0cA4h0;ca502Tb?00T:cD08bLb02@W;P0S92P071dQ01XJ7@0J
6Q`061HI01/G600D3Q006Q4D01@:2`0F30d060h?01D:3P0G31005P/?01@93@0F2`l05@X>01<8300D
2@d04`P<00l4200A1PX07Q<G028G6`0G31003`@80`0B1`/0500@1@T050T=01H;3`0=0PH02@0201L<
400H30h05`/=01H:300D20X04PH801451`0@10H04`L901@82P0C1`T04@D70186200H2@`04P<60P0F
1`X0100A0PD05PL:01<41`0D1@P201D62@0>01@5200C10L04PH601861P0C1`L050P801H:2P0H30`0
5PX:01<71`0<00003@4101<71`0@10@601861P0301<71`0B1PH04@D500804PH600h04`L701T>4@0V
6al081DI01H;3`0Q5QX02@0201052@0D2@d04@H:00h31`0A1PX05@X>01853@805`XA00X050L>01T=
4@0N4QH04PH:01D92`0G2`d04`L901861P0@1PD04`T=0P0C2Pd0100C20`040D900l4200E2@d201L8
3@0:01H7300C10T04P@:01L:4@0E20l04`H=01032P0>0PH04`L;01452@@04@D700L03`<60104200C
1`/04PH:00l31`0@10P04PH:00803`<701D040@800d11@0?0`L04PH900l31@0E2@/04@D701dA4`0A
1@L03@8300h2100=0@<03`<501041P0?0`D03P85028F6P2>PXH03P8602DI7@0<00@01P0B1PX30145
2@0301<72`0F2Ph06@dA008040@801@04PH:01P<400H31004`L;00P0000D20`04`L;02DI7@0N4QH0
40@801<72`0D20`06PhB02`P900Q5AT04PH:00l4300<0@T03PD;01<840804PL?00H06PlG00X11`0I
3QH05``D03/`>00A1Ph601853P0601D84@0D1a006`hG01<63`0D1a002`075?ooool001_ooooo00P0
5`hA00l62@0Y82<05`d>00l61P0L4Q<04PH801D82@806@/;02/05PP801<51@0=0@<04PH801L;3@0F
2P`04`L90186201>@T@0:1`N01862019?Cl0Og=e01X>400D2PX05`/;01451@0=0@4040@4028F5P0>
10@050P801lC4`0A1PH05PX:00h20P0F2P`050P:01T=3`0D20X08QHH01D92`1HC4h09QXL01hB500E
2``08aLI00/00@0G2`/06`l?01L;2`0900004@D500805PX:00D07A4A01L;2`0J3Ph05PX:01@82002
01D92@0X01@8200C1`L04`L701861P0I3@d040@401H:2P0I3@d0?S8b01<81`0B1`D06@d=01P<300A
1@D03`<500`20`0N4Q@04`L;01hB5P0A1@T07A4E01dA500K3a407A4C01D92`0D20X05PX<01L;3@0J
3Q006@d?01D92`0H30h06@d?01<82@0E2`X07Q@C01471P0H3Pd0718A01L=30<05P`;00H05@/:0189
2@0R6A`06A<G01XD600@2Ph2014;3`0801H@500L5QX050hB01@>4P0A2`l04P`@01lI7@0J51P201D?
4`805Q0D00L0618F01XD600H4QH0618F01`F6P0I4aL06A@H008061<G00@06A@H01PC5`0E41@06QDI
0P0M61`01@0J5AT06A@H01dH700N5ah07ALN00806aHL02H071TN01dK801GEEX0;bhc02DT:@0Q82D0
7QdR01LF6`0M7R<06ATQ01`L900W9bl08B4Y02HV;P0X:3809bLa03/kA@0Q92d06QdV02HY<P0L82T0
8RH_024U;P0P92d09BTb02@X<@0R9Rl0;30i01hR:`0c=d00;30i024U;P0T;3D0;SM0049;E014CEH0
<CY302`e?P80=3e601d0;CHo02/d?@0a>T<0<S]403I0B@0a>dD0;S]403I4C`0a@Dh09SQ403=5CP0i
Ae00>DQ=03M4B@0iA4H0>DM:03Y:DP0a@T`0<45;03]<EP0hB5D0?TiK03=3D00jBUT0>d]J03Y:F@0k
Be/0A5=Q04ABG@02041>F@0A03a:E@0oCEH0@U1H03i=E00kBU40>TU?03]:C`0jBDh0>4I;03U6C00o
C580@e1F03e:D00gA4X0=45703M4BP0iAT`00P0hAD/00`0kB4h0B5EL049?E`0203I3B`0;03Q5C@0i
ATh0?4UA03a9D@0kB500>DI>03Y7C`0mBU80?4]@03]:C`0iB4d00P0gAT/05P0hAd`0=dI;03]:C`0l
Be00>DQ=03Y9CP0kBTh0<d5203E3A00iAdP0>TQ903U7B00e@dH0?4Y=03U7BP0mBU00AeAL04ICF`0l
BE40?deF03i<E@0lBU<203m=EP0<03Y8D@0kBE80=dE>03]9DP0lBU<0=49;03=1BP0f@d/0>TM?03Q5
C@0jAdl0?DYB0`0d@DT0200c@4P0=45903E2BP0e@TP0=D1403I1@`0c?T00<C/m0P0^>3X0<P0g?d80
<3Pk030h>`0b=c/0;C8f02hc=`0V:Rd0;30c030d=`0[;c80:Rha03@h>`0Y;C00Oh>603Pl?`0K7b80
:blb03Lk?00]<c<0;C<d038g>P0^<cP0;C4j03<g@P0g>dH0;C4l03TmAP0[;cL09BX`034f?00f=d80
<c<o034a?@0];CL09bLa02DU;`0Z:S80:2P`02TY<@0[;340:BX_02HW:`0V9bP08B8T028S9@0P8B<0
9BHZ02h_<`0f=Sd092@/0P0R8R`0400T9300:B/g04M;E`0c=D80;S0m02@V<P0V9S808R8]02DU;`0W
9C00928]01lM:00P7RT08R0[020O9`0O7RH2024P:00I01lN900K6R0071/Q01hM8`0P7bD07ahT01hM
8`0O7BD06AHM01HC6P0M6b407A/P01/I700J61/06aTL01/I7P0G5A/06aPO01`I8P0M6R808b0W024N
9@0L6B007Q/R01lL8`0201/H7`0B01dJ8@0J5ah06QLN01dJ8@0T7bH07APO01PC6P0I51/0:bH]01`G
7P16@DP0?3Ln028M900F4AP06QDL01/F7@0K51`071DM0P0M5Qh201`E7@0901TB6P0H4AT05a0H01H?
5`0G41P06A8I01T@5@0I41<060lB00805`hA01L05Pd@01XA500H3a805`hA01T@4`0J4A@05PdB01@=
5@0G4QT08A`R01HA5`0A31806QDK00H11`0J5A/08b4V01PF6`0@3Q@07aXQ01L=5@0H3A<06@hD01/@
5P0201dB600301T>500G31806PlE008081DK01<05``B01P=4`0I3Q@06@hD01P=4`0E2Q004`P>01D:
400K41H06PlE01H;4@0G31807Q<I01P=4`0A1P`09AXP01L<4P0900@07Q<I00805P/A00D0714G01T>
500A1P`09Q/O01H<3@0201<:2`0@01P?4P0H4QH0618F01dF7@0T7bD061<I00l:4@0@2a802`H=03Td
>P0N6Al050lE01`G7@0H4aT08ahT01TD6P805Q4G02P061<I01dH7P0M6b009RH^02HY<00R9Rh07RD]
028Y<`0X<S/0;3U2034oC00jBUL0?e5M04UKJ@1GJ7<0H6ii06YfQ01lQ9P0Ri6[0:6R`02l_=h0emGl
0=oOo`3:bo40/;;H09nSb028TJd0LX6D06AeQ`1KK7d0CUm_04AFI00mCUX0=DI@030mAP0[=3h09bhh
02L[=P0T:2l07R8U0P0J6ad03P0L71h061HG01XF5`0E4A805a4A01892P0T6a`08aTI01@93@0H3A40
5``@01D:3P0G310050T=0P0E2Ph01@0D2@d04PL;01<8300G31005@X>00804@H:00D05@X>01<8300B
1`/03`@801/@500201D:3P0500h31`0Q5QX05@T;01H:300D20X00`0C1`T03P0?0`D050P:01L;3@0E
2@/04`L901451`0D1@P03P0201X;3P0N3a804`@70101100C10L050D80P0E1PT0100D1@P04`@701@8
200B1PH200l30`080104100?0`<050P801@8200@10@04PH601@8200=0@4601861P0301<71`0B1PH0
4@D500804PH600P04`L701<92P0800007Q@E018:2P0B20T04`T:014720804PP90P0A1`P0500D2@d0
40<;01032P0?0PT04@@;01P<400L41@04`L;01451`0I3@l07A4C01T=3@0@1PD05@/>01<:3@0B2@`0
4`P<01462P0@1@T050P<0P0F1``03`0E1P/04P<801@6300A10/050L>01<72`0A1@T050P<01862P0C
1`/04PH:01452@0@10H03`<50145200401862P8040@801L050P<01D93@0@10P040@801452@0@10L0
4`L900/00@0A1@L03P8401<72@0@10H04@D701041P0C1`T05PX<01D92`0D20/03P8603HZ;P0I3A40
200001/?4`0601862P0801<72`0B1PX04@D901452@0C1`/05`/?0104200B1PX201D93@0@01862P0>
0PH02`0301X>4P0B1PX09a/O01lC5`0A1@T04PH:01<72`0H31009ATM01X>4P0B1PX04`P@01@94@80
4PL?00/05P/C01P=5@0D2A407a@L01463P0700@0PgR0034V;P0@0``04@@=01853P0301<63`060185
3P0>0@X03P4:00d02@0E21406PdF5?ooool001_ooooo01@03PD901893@0j<C@09AXN01<:2`0D2P/0
4`L801H92P0J30`06@/:01H81`0B10@05PX<01872@0L4180F4a>02TM7`0:004040@601@92P806Ph@
00X0A3Pj02<G6@0G2`/04`L701H:2P0E2@T03P<301861P0K3`l02`410P0F2PX04@0G30`050P801L;
3@0A1@L05PX<01L;3@0P51H07A4C024F600H30h040H701dA4`1aIFL0?S8d01@8200@10@05@T90080
5PX:02404`L701461P0B1PH06Ph>0104100J3Ph05PX:01051@0F2PX050T901861P0J3Ph05@T901T=
3@0C1`L050T901D92@0Y7Ad050P701P=2`0Q5AD07Q8B00l4100D20X06Ph@01<92P0A1`T04PH:02<G
6`0H31004`L:01T=3`0J3Q000P0E2@/08@0F2P`05@T;01hB500C1`T04PH8024E5`1CAdT0<bPX01T?
3P0R61L0718A00h51@0M4a806@l>01<9200F30/04`T801P>3@0B2@T05@`?00h8300C3A404@/?01PB
5P0D3a803@L;01TC5`0@2Ph07ALK01D?4`0D3Q807QPL01/E6@0201PB5P0901TC5`0D3Q80618F01hH
700J51P091hR05UCE`0K5AT06aHJ008061<G01807APL01`G6`0E41@02`H:01/F6P0B3A4061<G01dH
700Q72006Q<J01XD6P0J5A/06aHL01dJ7`0O7B809bDZ01HE6P0K6Ql201lN8`0601hM8`0C4a/08R</
01XL900R8R/07QhW0P0O7bP02@0];CH07QhW01/M9@0Q8R/06QdU02<W<00T:C808bTa028X<002024W
;`0`02L/=@0[<3T09BXc03PmAP0c>D409bhf02/d?@0[=Ch092hg02li@P0^>440=3i703<lAP0a>T@0
;3Ho02/e?P0`>D<0<C]402hh@P0c@4X0=D5<03M6DP0cAE40>4YF03=5C`0eATh0=DA;03=1A@0e@4@0
=D9703Y:D@0_@4X0<dA>03Q9D`0eAE80?4aI03I6D`0iBEP0?dmN041@G`14E6@0?TeK03i<E`10CUT0
B5IQ04MEH00nC5D0>4I>0P0lBe802P0gAT`0>TU>03a;D00mBe40?4U?03]8CP0lBDl0>4E;03E2B00d
@DL203E2B00B03U6C00kB4h0>TM=03U6C@0gA4`0>4E=03e:DP0lBE40>TM?03a9D@0mBU80>dQ@03Y7
C`0oC5@0@TmG04=BF00mC580>TU?0P0kBU00M@0iB4h0?TeC05YYK`0oCU@0?TeC03Q7C@1;FUl0>DM:
03U7B00kBDX0?4Y<03]9B`0iAd/0?Ta@03Q5BP10CE@0BEIN041=E@0kB500>dYB03M5C@0gATh0>dYB
03Q6CP0d@d/0?4YB03M5C@0iB500;3]303a;D`0jB500=45903i9DP0f@TX0<Si603M3B`0e@DT0>4=<
03E1B@0hA4`0>DE=03A0B00b?T@0;STm03@o@@0^>C/0;CLi02hh>P0g@D<0>413034i?00e?D00<cPl
02`a=@0W;300;S8f02/^<P0_<SH0;C0d034d>017Bdl0<cHj03@g>`0W:Rh0=SXn02ha=@0g>ch0;S@d
02P^;`0X;C40;C8i02T]>00j?TT0=3Q303/oBP1JGVT0>cm802DZ<00]<SP0?cm;03@d@00[:cL0;2`f
02LW<@0V9S00:b/c02PX<00[:c<0:b`a02HW;00T9BT092DV01`M7`0Y:R`07QlR028S:00V9b`071`T
01TI8`0S8bd09bLc02PX=@0W:CD09RTg020R;`0T9S<09RPd02DU<@0Q8B`08R8/02PV<00f=Ch08R4Z
01LF7`0O7RH07ahU024P9`02028Q:003028Q9`0Q82H08B0V00807QdT00d06APO01PG7P0O7BD05a@M
01LD6`0T8RP09B<V02LU:00[:B/07Q`N01dK7`0I5Q`07AXQ00806AHO00l05Q<K01TF7P0P7BD07a`T
01TF7P0F4a/07AXR01`I8@0J5al081dU01hK8`0L5ah05A0G01hI800D3aH00P0N6B001`0f<CP0:bH]
01`G7P0K5Qd07APO01XE700I4QX00P0M5Qh0100J4a/06a@L01dF7P0F3aL201/D700M01<<500O6200
71DL02LO900N5aX06Q8F01L?4`0D3A006A4E01XB5P0H4A@0610D00l82`0J4aH030L:00h93`0K5Q`0
4PdC01LB600E41H06A@K01D?5P0E3aD050lD01D?5P0C3aD07aTO01P?500I3Q@00P0G3180400I3Q@0
714G01P=4`0D2@l04@H<01H;4@0I3Q@04`P>01/@5P0I3Q@0;b@Z034V;00J3aD05P/A01X?5@0I3Q@2
01H;4@0?01P=4`0I3Q@07A8H0146300E2Q004`P>01L<4P0H3A<050X?01H;4@0D2@l05@X@01<83P0G
318060d@00805@/>04D05`dB01P?500G3a@0=2dc07E_M@0D3aD061<I014<4`0N6Al06A@J01@?5@0J
5A/08A`R01<>500D3aD05a8H01HA5`0G4QP06aHL01dH7P0J61d092<[02lb>@0X:c<092/c02P_>@0X
<S`0;S]402/iAP0kBeP0?4iJ04UKJ@1CIG00Gfeh06McP@1eOY80QXbV09ZK^@2e]=L0cLcb0=GDnP38
bO00[[7G0:FYc`28TJh0Lh:E06MhRP1MKWl0D65a04IHIP0mCUX0=DI@03E2B`0_>480:c8l02/_>P0O
8RT08BDX01TL7P0F61X07AhP01LF600Q7Ql05Q8C01PB4`0M5QH081PI02LM7@0E2Ph00P0G3100100F
2`l05``@01H;3`0H3A4201H;3`8060dA0P0D2@d0100E2Ph06PlC01`A5@0I3Q8201L<400=01482P0F
30l04@P:01L<400B1`/04`L901H:300D20X040@601<72@0F2P`04PH801@82P020186200801L;3@0I
3@l05PL:01@5200N3a808Q<F01T:3@0B0`H601D62@0<01861P0C1`L04@D501861P0C1`L04PH600l3
0`0G2`/04@H601`@400H30`04@D51P0B1PH201<71`0P01861P0A1@D04PH601<71`0B1`T03P<400l4
1@0C20X07A8C01@92P0@1@L04PL801@92P0C20X04@H701052@0D1`l05PT@00l42@0D1`h05@T=0104
200E2@d04@D701T=3`0O4aD06`l?01@:2@0D2Ph04`X=0189300B1`/201462P0H01862P0F1``05PL<
01@52P0C10T05PT=00X00P0F2Ph050P<02HJ7P0J3Q8050P<00l41`0@10P05@T=00`2100B1PX040D8
01452@0@10P050P<01<72`0A1@T040@80P0A1@T03@0>0PH05PX>01L;3`0A1PP050P:0147200C20X0
5`/=01<82@0B1PP05`/=01T=3`0F2P`00P0J3Q000`0E2@`040@80105200301D93@0901862P0C1`/0
4`L;01862P0C1`/04PH:01H:3P0W6al040@800803`<70P0D20`0100C1`/04PH:0104200A1@T201@8
300702dQ9@0F2Ph06@dA01H:3P0B1PX04`L;01862P0201D93@0;00h21P0I3Q40Bd1801hC6`0B20l0
40H=00h32`0E2Q804PL?01053@0=0`X00P0G31@00`0D2A404@@=01853P0201<63`8050L@00H04@@=
01H94P0D1a005PTB00d02@0@0``Dooooo`006oooool0200800@05`hC00/21`0X7B409Q`N01lE5P0B
1PH050L70P0F20L02`0E1`H04`D40104100D20X02`0104Hj?00K3a404@D701<72@0F2P`040@60080
4PH800<03P8401@8200D20P00P0C1`L201861P0900h30`0S5aL04@D501<71`0E2@T05PX:0186200H
30h0710B008050P:00T06`lA01T=3`0A1@L06@d?00h2100R5QP0200001<71`0E2@T00P0H30`0400B
1PH03`<300l30`0X71`0=b/[01dA4@0D20P0300002XN7P1hK6`08QHF00h20P1BATH06@d=01861P0C
1`L201H:2P0:01L;2`0F2`X04@H401861P0D20P04PH602<G6@0n<S@05`/=01D93@8050P<00D02`03
01L;3P0E2@/05@T;01@82P0201D92`0l01/?4@090000300201D92`0F2P`081@F01461P0?1@@06@l>
02hT8`0?1@@06@l>01H<2`0H3Pd05`d<01061@0G3@`040L701P?4P0G4AD02P@801TC5`0?2@d050hB
01lI7@0T7R805@lC02DO8`070@D05a4E01PB5P0?2@d0618F00T31`0;1@T08adQ01TC5`0C3A403PP<
01XD600d;S806aDI01/F6P0H4aL05a8F01TD600J5AT05a8F02TT:00a;3007aXN024L800J5AT06A@H
01/D6`0K5A/06QDK01/F700L6Ah07A/P0P0J61d0500M724071/P01XI7P0O82D05APO01XM9P0I72D0
8R8/024Q:`0T92h07AdU02TY<@0T92`08R8Z02LW;`0O8RT09RXc02<Z<P0Y<3P0:S4i0P0V;CD2028Y
<@0:02@[<`0X;cL0:2lg02L`>@0T;CL092hh01lY<`0kADl0;cU303@nB0<0;CM101/0<3Y403<mA`0e
?dT0=T5;03A0C00Y=d80<T=?05a^NP0cAE40>deI03U:E00gB500=dE<03Q3A`0f@dT0=dM>03E6D00g
B580?DiH03Y:E`0dA540?DeJ03m?GP1UMH@0@U9Q03i>GP12DEl00P11CeX02P13DE`0AE=N03i<E@0i
Adl0@4mF03m>E@0hAdd0>DQ=03Q7C00gAD/203Y7C@80>DI<0140>4E;03E2B00b?dD0<Sm503Q5B`0k
B4h0>4E;03E2B@0d@DT0>DI>04QEG@15DUX0?4UA03]8D00oC5@0?T]C03m<E00204ICF`0=03Q7CP0g
ATd0>TU@041?EP0nCE@0>TU@03I5C01?GVD0>DQ?03M6C@0b@DP0A5=I03Q6B@0203Q6A`80=TA700@0
>DI<03a9C`0kB4h0>dQ@0P0lBE40800nBe<0EFA[04=BF@0eA4/0=TE<03A3BP0iB4l0=TE<03Q7CP1D
HfX0>4M>041?EP0c@DP0>TA=03a6C`0f@4T0=3i703M1BP0f@4T0>TA=03@nA`0h@T/0>TA=03DoB00d
?dD0=3m302dh>P0X<cD0=d53030j?00T;S00>D540P0^=ST07P0Y;S80;S<g02hc=`0Z;C80<cHk02P[
<00T9b`0;c8g030c>00[;S<0<3<h03<f>`0b=CX0;2ld02LZ;`0X;C0092T/02hc=`0a=Ch0WJ6/04U=
F00f>TH0<3A003@hA00K7bT09b/d02d`>@0e=D40;2`h02@T<0808R8/0100<C4k02HV;P0_;cL0>3Q0
03@e>P0X:Bh09bP]02<T9`0[;300=cPl02@U:P0[;3407QlT01hN9P0O7bT08R8/0P0U9C402P0T8c40
9RPg02<U=00T9S<09bTf02@T<00Q8B`06ATS01lN9P0Z:C42028Q:@04024P9P0M72807QdS01hM8`<0
7A`R00<07ahT01LF7P0K6R800P0Q82P0>P0U8b`09B8]02HS;00U8bT0=cDh03/i>P0X9RL05Q@E024O
8P0P7B<09B8[02dZ=@0b;cT06AHO01/H8@0N6b@06aPQ01`I8P0P7BH06AHO01LD7@0P7BH08AhW01dJ
8`0Q72<071LN01XE700K5Qd06QDL01dH7`0_:S409B0W01/F7@0J5A`061<J01XE700L5Ad07aPP01`E
7@0J4a/07QLO01/D700G41P030D=01@=5@0F3aL06A8J01PA6@0V7bH050hB01D?4`0@2Ph07aTM018<
400>20`04@/?01dG6`0Q6al201lI7@0<01TD6P0A3180Ee9H07UdNP0J5A`050lF01`E7@0Y8RX0=c0g
02DN9@0J4aX050XB0`0I3Q@301P=4`0?01873@0C20h06@hD01dB600J3aD04`P>01dB600C20h06PlE
01/@5P0E2Q007A8H01T>500H3A<05``B00805P/A00P05``B02PM8`0G318060dC01@93`0@1@/05@X@
01H;4@<050T?0P0F2a40A`0E2Ph050T=01<8300C20h04PT>01<:3`0B2`l0=2dd00/42`0>2@l01`88
01hI7`0D3aD05a8H01`G7@0J5A/05Q4G01TD6P0G4QP05Q4G01TD6P0M61h06QDK01HD6@0D51`0;S4h
020S:`0I82P0;cI002@^>00/>D807R`i03a<F@0gBED0AeUW05=UL01OL7X0I79o079lS`25RjD0TIFb
0:Z/c@2i^n40^k_Q0;>fg02QYLX0Yj_@08N@[01aP9<0IWN905]/O@1?H700AeUW03m@G@0cA4h0=45:
02`f?`0V;CL0:blj02DX;`0M8B@03Q4F028T:00M7R005QDI00L5200J61T06QDG01@>400H4Q808aXM
00805``@1@0F2`l01@0E2Ph050T=01H;3`0F2`l05@X>00@05P/?01005@X>01@93@0D2@d07A8F05=8
C00J3a<060dA01L<400K3a407a<E01/?4@0C1`T05@T;01P<3P0E2@/05PX<0P0A1@L02P0F2P`05@T;
01@5200D1@P05@H901L82`0F1`X04P<601L82`0F1`X201D62@0401H72P0G20/050P801@820804`L7
0P0B1PH01P0K3`l03@410104100<00003P@401@820H04`L70`0B1PH301<71`H04PH80P0C1`T201@8
2P0:0186200A1@T04@@<01T<4`0C1Pd05@P?01X>4P0K3a<04PH:018620804`L900D04`L701881`0A
1`/04@P;01072P0301052@0301452@0F1``05PL<008050D:01005PP<00T0000J3Q804PH:030T:00D
20`04@D901lC5`0>0PH03@<500l31`0G2Q4050L=0104200?0`L04@D90P0C1`/0100@10P050P<01T=
4@0C1`/200X00P0:01<72P0<0080200001T=3`14>3X08ADG0186200K3a407a<E01D92`805PX<0180
4`L:0104200=0@D04PH:01D93@0C1`/060`@01L;3`0C1`/04PH:01<72`0D20`03P8602<G6`0E2@d0
6@dA01862P0A1@T301<72`<04PH:00l04@D901lC5`0=0@D0710D01L;3`0B1PX06@dA020D600I3a40
5`/?01/?4`0L41@0U8VA03H[<`0>10/00P0@1@d00`0B1`l04@H>01463P0201053@804PL?1P0C1Pl0
100E214050L@01D84@0C1Pl201443ACooooo000Kooooo`0>01<94@0@1Pd01P0201T>500@1PP01`00
01P<300I30/060X901L9200D1P<04@<20104100K3a4200d10`0800l31@0I3@l04PH801@82P0A1@L0
4`L901D92`0C1`T201@820804`L70P0B1PH00`0a9BD0F4a<02<G5`0201D92@0C00X0000O4aD040@6
00P0000J3Q00ETY<07a`LP0<0@804PH801T=3`0E2@/06`lA0186200A1@D05`/;01X>3P0I3@d04PH6
00l30`0201X>3P0L01P<300D20P06Ph>01@92@0I3@d0Ac/k01`@400:0000:alO01451@0C1`L050P8
01H:2P0E2@T050P801L;2P0E2PP04`L701861P0A1@D081@F03X^<00F2P`04@D901X>4P0H31004PH:
01T=40805@T;01`050P:01D92`0E2@/0@SHh024E5`0N4Q@04`L902DI6`0B1PP06PlA00l51P0H3Pl0
<bTZ01T?400H3Pl04PP901hD5@0H3Pl050X;01<92P0B20T03PD801XD600A2`l0618F00P21P0M5a/0
2`D90P0@2Ph0500G4AD091hR03H`=00D3Q803PP<05E?D`0X8RH07aTM01XD600D3Q805@lC01XD600L
5QX030H:01hH700J5AT061<G01D@500G4QH06A@H0P0H4aL201LB5P0501XE6@0M61`06aHJ020I800N
61h00P0J5A/0100K61d071XO01/I7P0J61d201dL8@0F01/J7`0O82D06ahW01LJ9@0J72P05QTR01dN
:00M7BL08R8Z01lO9`0R8BT09bH/02TX;P0T92`08BD^01lV;P0U;3@09Rde02<Z<P0U;3@08RTa02H]
=@<09bhf02D09Rlh02/d?`1AFfL08R`h02D_>`0Y<cl08bdi02`f@P0]=d<0;SQ403<mB@0h@Th0>TA@
02llA@0d@4`0=dE@06YkR03OlOl0RYf[03]?FP0hBU@0>DYB03a;D@0hATT0<d9703E7CP0eAe40>TaF
03i@FP0iBeL0=4IB03mAG@10DV00JG^903i@GP0hBET0@E1N0080@DmJ00`0@4iI049@F`0lBU<0>4I>
03a;DP0kBU40>TU?03a;D00kBTl0>dU>049?E@10CE<203I3B@0A03E2B00a?T@0<Ci4034nA00gA4X0
>TM=03Q5B`0e@TT0=T=;03e:DP1:Eel0AU=K03e:DP0iATh0>TM?03U6CP0jAdl00P10CED01P0fA4d0
>T]C03Q9D@0fAdl0=dQ@03]<E080<4590180=dQ@0393B`0jBe<0=DE=03Q5B`0jB4/0>dU<03M5B00f
A4L0>dQ>03a9D@0jAdl0=T=;03E2B`0hADh0?DYC061]M@1:Eel303I3B`0<03U6CP0e@TX0>DI>04YG
G`0^>d<0>4E=038oA`13CEH0>dE>03Q2B`0g@DX0=3i70P0f@4T0200c?DH0=T1903Q2B`0d?TL0=3m5
02lj?P0^>C/09c8d0P0_>C/0:P0f@480<SXm03@l?`14C4l0?T=702db=P0L8BD08B@Y02ha=P0R9BX0
7B0U02/^<`0^<CH0<3<h03Dh?@0g>Sl0;C0e02/^<`0P8bP0:c0c02H[;P0Y;S80;C4j0;Bh``11AE40
>3]:02X^>P0]<Cd0:Rhh03Di@P0f>D80:bXg020N:`0U8c00:2Ha024O:P0`;ST08R4Y02l^=P0g=Sh0
;Rdc028Q9`808B0V00L0>CPn03Lf?00V9B`0<2lg01dL900Q82P09R@_00809bD`00<09R@_02DU<@0X
:cX00P0S9C@02`0T9S<08b<_01lO:P0L72H092<[01lN9@0T8bT0:2L]01`K8@0P7b@08B0U00808B0V
01/081lU020O9P0V9Bd08b8Z02HU;P0V92l06ALR01TF8P0W92l08b0Y030]<`2=Rhh0WI^L05MFE00^
;2d0<2ha01dK8@0F4a`05a@O02@Q:`0K62407Q/T01`I8P0H5Ah08QlX07IcO01bKgP00P0S82T01`0Q
7RL06AHO02LR:@0O6R407APO024L8`0O6R400P0M61l0:@0K5Qd07APO01dH7`0I51/071LN01dF7P0K
51`05a0H01XC6`0M5Qh05a0H028K8`0>1`l071DM02@M9@0D3AD07QLO02<L8`0H4AP07QLN00P1200E
3QD081TP02<L8`0J4aX040X@01H?5P0?2@l05PlF01LB5P0K5Q/0ZjJ/0<K1b00V82T03`LB02HN:@0d
;3@0:R0Y01D;4`0L4aT03P<900806@hD00h060dC01L<4P0G31805P/A01P=4`0C20h0714G01hC6@0D
2@l04@H<01@93`0K41H04@H<00h32@<05``B0P0H3A<201L<4P0:01D:400L4AL05@X@01T>500H3A<0
6a0F02<H7P0F2a405@X@01@93`805@X@04P05P/A01/>5@0H2a805PT@01@93`0B1`d04@P=01D<4@0C
3A403PP<01TC5`0D3Q8071HJ01@?5@0H4aT06QDK01@?5@0C3Q@06A@J01LB600F4AL061<I01/F700J
5A/05aDJ020O9`0I72<09b/c01<J8P0M92h0;CM102Tf?`0Z>4D0?dmL03U;E`15EfD0CEmZ05e^N01P
L7d0KWZ=07f4WP24RJH0V9bl0:^_dP2b]MP0][[M0:>Yb`2UZld0QI2Y0760T`1UMXP0FFYk04mPL017
FFL0@E9O0393C@0c@4T0<S]502D/=P0Y;CP09b/c02DZ;P0F6B007b8W03Xk?`0L6b407Q`Q02<Q900H
4aL04P`@01TC5@0b:Rh201P=4@0801L<400F2`l05P/?01D:3P0H3A405@X>01<8300D2@d301H;3`0C
01D:3P0D2@d04`P<01<8300D2@d03@8600l4200d:Bd02`0401052@0A1PX060`>01/?4@0G2`d04@D7
0186200D20X05@T;01H:300201041P0801@82P0B1PP05@H901D62@0F1`X060T<01L82`0C10L201H7
2P805@H90P0F1`X301<71`<04PH600H04`L701X>3P0G2`/0300001`@400F2PX601<71`0801861P0A
1@D04`L701P<300E2@T04PH601H8200E1`L201@61P804P@400d06`d=01@61P0B10@050H601<51@0A
0PD06PdE01<63@0B1@`05@P?01862P0:00804PH:00<04PH800<04@D501061@0@1PX00P0?1PT0100@
1@T03`@800l4200A1@T201D62`804`@901005@L;00/0000I3@l03P8402<G6@0?0`L0308401P<400<
00H060/B01D83`0F2A804`H<01862P0A1@T03@450P0E2@d0400A1@T03`<700d11@0B1PX060`@01X>
4P0F2Pd03P8400d10`0D20X0;B4S01P<3P0?0`D05PX<01X>400A1@L20186200700l31P0E2@d05`/?
01452@0=0@D02@0101D93@0201<72`0901D93@0F2Ph050P<01<72`0900403@850104200=0@D05`/?
00@04`L;0P0D20`04P0G2`l050P<00d31@0R5QX050P<01862P0;00<081@H01/A4`0@10P0200001hB
5P0V6b<02`0802DJ8P0Y7RH05``D00l430@040D=00<04PL?01<8400C1Pl01@0C1Pl01P0E214050L@
01@7400E21405PTB01<63aCooooo000Kooooo`0D01D;4`0E31<05PdC00`31`0G31406@l@01051@0B
1@D050H501@60`0E20@05PP601P<300@1@H060`>01@82P0H30h05@T;0186200C1`T20186200401D9
2`0G2`d050P801@820804`L70P0B1PH0300D2@T0;b<S01T=3@0C20P050P801H:2P0E2@/060`>01D9
2`0F2P`09ATK034U9`805@T;01L04@D70186200@10H0710B01P<300M4A405`/;01<71`0D20P04`L7
01D92@0@10@04@D501`@400@10@050P80104100C2@T04@L701861P0D2PX04PH601D92@0201H:2P0?
01@8200B1PH04PH501871@0D20P05PX:0104100C1`T06@d?01041P0B1PX05@T=01P<400K3a<05@T<
00805@T;02L050P:01D92`0E2@/07a<E00/10P0J3Q006`lA01hB500B20T06PlA01H;3P0F30l09a`Q
01L=3`0F2`l04@H;01X@4P0G31005@X?0106200G3A8040L<01<=4@0b;30050hB01TC5`0C3A4081XN
00P31P0H4QH03`T=01H@500H4QH0AT1402@N8P0j=3P04@/?01/E6@0N61`00P0I4aL03P0K5AT04P`@
01lI7@0D3Q8061<G01LB5P0F4AD05A0D01PC5`0J5AT06aHJ01PC5`0L5a/05A0D0P0J5AT01P0V7bH0
8A/R01`G7@0L5ad07AXO01lM8P806aTN01807QdR01dL8@0L6b00824V01PJ9@0L82/0:Rdi01`N:@0R
8bh07AlX02HV;P0M7B@08R4X02@R:00O7B<092DZ028W;@0N9Rd2028Z<@1:01lW;P0Q:C4092`d02/c
>P0/=3/0:30h02P`=`0Y<S/0=Cm:05YUL@0b?DT0:cI202hiA@0iA500;3M302dhA00^>DD0<ci:03Q3
C`0iA500>TMA030nBP0eAE40D65_0:6d`P1VNHL0=4QD0353C@0dAdh0?4]A03Q5B`0b@DH0=dU@03=5
C`0fB580>D]E03Q:EP0kCET0@UAP045CH@12E680?e5O04EFIP0lC5X0@e5L049@F`10CUT0@DmJ03e;
E00kBU80?4]B03Y9D00kBU00>dY?03Y9CP0iAd`0?T]A03]8CP0`?D<0=D9803Q5B`0c@4H0<Sm503A1
A`0hAD/0>TM=03U6C00jAdh0>TM?03Q5C@0iATh0>TM?03U6CP0gA4`203Q5C@0;03M4C00mBU80>TQ?
03I4C@0mCUH0=4E=0352BP0lCED0D65Y03Q9D@0a@TX00P0jBe<02P0iBU80=4E=03E2B00gADP0>DM:
03A2AP0c@4D0=T=:03Q5C@0f@d/203A1BP0303I3C00iATl0?T]C0080>DI=00l0>TM>03I3BP0d@DP0
=45803a9D00c@4L0:SLn03m<D`0d@DP0ADmH03M1BP0i@d`0>dA=03DoB00i@d`00P0e?dP01@0d?DH0
<ca5034j@`0_>Cl09c8f0080;cXl03T0<S`n02`f>00h@T@0?TI902Xb=@0]=CP0:c0d02`a=@0_=3P0
;c8h02P[<@0]<3H0<3<i02`_=@0a=3X0=cY002lb>00]<3H09RT_02`_=@0]<3D0;c@g02db=P0N8bT0
;c<m02hb?P0f>TH0;2ln02lc@00b=T809RXe01hR:`0Y;3D0;B`i02<Q;P0P7R/0;bdh02DS;P0O7BP0
9bH^02`[<`0Y:30081lU01hM8`0Q82L08b8[02h]=P0/:c@081lX02@R;00L6b@08b8Z02XY<P0[:S<0
9bH_02DT;@0U9C000P0T9SH0200U9cH09RPf02<S;`0O7bX08R8/01`K8`0K6R008b8W0P0Q82D0:00P
7b<07ahR024P900P7bD07QdS01`K8P0Q82P071XT01XH8P0N72L081hZ02DR;`0V8S00:BHa065OI03h
moP0oOgk07AcL00Z:BL09B<T01XH7@0P7BP06ADS01dJ9P0H5Al06aPR01`I8`0K62808b0Z05UFH01A
CUP06aPR01TF800J5b406QLP01dH7`0J5A`07APO01lJ8@0K5Qd201`G7P0501PC6P0I51/071LN01XE
700I51/00P0K51`08P0L5Ad07AHN01dF7P0N5al04``D018;4`0K51`06A8J028K8`0H4AT05@lG00d7
3P0J4a/0C4I?01/E700?2A4071DN06IPI`21Nh<071DN01TC6`0D3aH05A0D01dI7@1AC580=C0g010:
4`0K4al05@/H01hD7P0L4AX03`H<01X?5@0E2Pl201T>500:01L<4P0F2a405P/A01D:400M4QP05@X@
01`A5`0J3aD06a0F03<X;P80714G00H05@X@01H;4@0K41H05``B01H;4@0H3A<201T>500401H;4@0D
2@l050T?01D:40805``B00<07A8H02DJ800E2Q001@0E2Q00100K3QH060/C01L:4P0E2A4201@93`06
01L>4`0D3140<2P]01LA5@0=1`X0618F0`0D3aD0>@0F4AL05a8H01PC6@0F4AL05a8H01PC6@0I51X0
6QDK01TG700K6R807B0W02T]=@0O9Rh07RD_02Tc?00W=3d0<Cm<03U9EP0oDEd0AeUW04UKJ01GJWD0
Ffil06QgR@1bOI<0Lg^E08B<Z02EW;/0WJ?10:>/b02AW;H0Uj6l086?Y@1bPI@0IWN905UZN`1@HG40
BUaZ049CG`0`@D/0=dA=03i7D@0Y<3X09RXe02@X<P0T:3007R8/01@H800W:S004A0H01`J8@0G5A/0
5A0F01XD6`0H4aP05@hE01T>4`0201P=4@0501L<400F2`l05P/?01T>4P0F2`l00P0C20`03`0E2Ph0
5P/?01H;3`0E2Ph04`P<01462P0B1`/050T=01P=4@0@1PT05P/?00/2100F2`l050T=01<72@030186
200401<72@0E2@/04@D701@82P8040@600P050P:0186200F1`X05@H901L82`0I2Pd05`P;01<41`80
5PL:0P0D1@P201H72PH04PH600H06@l?01861P0I3@d05@T901D:2P0;0@4701861P050104100D20P0
6`l?01H:2P0A1@D01P0D1PH00`0L3Ph04@<300l10@0201D71`0801<41`0l<CL040H:01D83`0Y72<0
:AlQ01/?4`0E2@d201@82P0P01<72@0B1PH04@L601472`0?1PT040L:01<8300A1PX040D90104200E
1P/050D:01<42@0B0`P04`D800h20P0F2P/03@4301L;3@0?0`L05@T=00T00@0D1`h0@C@l024D700N
4AX04@D;01/?4`0Q5AT04PH:01<72`0E2@d201452@804`L;0P0=0`D02P0@1@P04`L901D92`0A1PL0
40D601461`0@10H04`L901D92`0@10H201451`0B01@82`0C1`/04@D901862P0A1@T050P<01452@0=
0PD04PH:01T=4@0E2@d04@D901X@4P0@10P05@T=01L;3`0A1@T04`L;0P0A1@T05`0B1PX04`L;01<7
2`0D20`04PH:01L;3`0B1PX05@T=00h31P0C1`/050X<01<72`0J3a807A4E01/?4`0B1`X05@`B00l6
300G31@04@H>01473P0@1@d04@H>008040D=00<04@H>01<8400D2A401`0B1@h01@0C1Pl03`8;0144
3@0E21404@@=01Cooooo000Kooooo`0H038X<@1XGVL06Q0H01H;4@0B1``04`T:01P<3P0H2`X05PP5
01D7100E20<05@L401P<300?1@H05@T;01`@4P0@1@H05`/=01451`0B1PP050P:0186200G2`d07a<E
0P0D20P201<71`804PH600X0710@01@8200M4A405`/;00T0000E2@T060`>01451`0<00804PH80P0L
4180:P0C1`T050P:01<72@0F2P`05@T;01`@4P0P51@0;20P02@H600G2`/04PH600h20P0E2@T05`/;
01P<300>0P805PX:01L=3@0@10@08QHF00l51@0=0@407Q8B0104100B1PH04`L701D92@0G2`/060`<
01L;2P0C20H04PH601<71`0D20P05`/=01P<3P0B1PP08QHJ04<g>`0F2Ph04PH:01@82`805@T;03/0
50P:01D92`0E2@/060`>01dA4`0800002`4200h2100N4Q@05`/@01/@5P0E2Q005P/A00l42P0D2@l0
5P/A01@93`0C20h03`@:02/P9P0E2a0030<802<M8@1/IVX04P`@01<=4@0D3Q8040X>01PB5P0F41@0
6A<G00P21P0?2@d06aDI00`62P0H4aH071HJ01lI7@0B31005@lC00X4200I4aL09b4U01LA5@0K5AT0
50lC01HA5@0H4aL05a8F01PC5`0J5AT03`X>01dH700D3a<04PdA01PC5`0K5QX081TP01hH7P0201XE
6`0401/H7@0L6Ql071XO01/J7`807QdR01H071/P020Q9P0M7b/07R8]02@X<`0O8Bd09BLb02@W<00R
8RX08R4X02HU:`0S82L081hT02`[<@0X;C<08R/b02@]=00S;3<082T`02</<`0R:c809Rlf0`0W<3L0
=P0V<3T0;CQ302/g@`0T<3`0?DUE030lB00g@dl0;SY602diA@0^>TH0<Ce903E1C@0g@dl0=D5=02hl
B@0eAE80<49@03E8EP0kCU`0<TIB0353C`0cATd0>DU@03U6C00fADX0=DM?03M9D`0oDE/0?DmI03M9
E@0jC5P0?e5M03]=F`0nD5h0>deK04=DI00lCE/0@e5L049@F`0nC5L0@4iI041>E`0nCED0?DaC03]:
D@0iB4h0=dI;03]:C`14DUL0@4eC03Q5B`0b?dD0<d1603A1A`80=D9800H0=dA:03U6C00iAT`0>4E;
03E2B@0f@d/203Q5C@0303]8D00jAdl0>DI>0080?4UA0100>dQ@03m<E00jB500;C]403I7C`0dADd0
<dA<03]<E00nCeL0<T=;03Q9D@0b@d/0>daD0352BP0kC5<0>DI<0P0iAdX01@0iAT`0>4E;03I3B`0f
@d/0=dA<00@0>DI?00P0<Sm703E2B00iAT`0=457034nA00e@TP0;3To03m<DP80<Ci403D0;3To03<o
A@0i@T/0=3e603HoB00h@DX0=Sm803M0B@0f?dP0>T=<03DnA`0a>T<0<3U202`e?00Z=CT0;cXl02/f
>00/=SP0<C/m05ANH011BD`0;SHi03Lo@P0e>Sh0;C8f02T^<P0M82L09BP_01lR:@0]<3L0@dI=02`_
=P0k?TD0BDaC02d`=`0[;SD0<3<j03@g?P0Y;S80;C8g03@i?`0U:C@0:Bdi034e@@0a=4<0N7^:04U<
F`0W:cL08bLb01lR:`0f=D80@T1=02PV<`02020N:@0o01hL9`0R8BT0:RTa02PW;`0U92X08b8X020O
9`0Q7b`08b4^034_?00]:cL07Q`W02<Q;00S8RX09bH^02PW;`0V9B`092<Y02<S:`0N8C4092Dg02LX
>P0V:3H08R4_01lO:P0U9Bd06aXR02DT:@0P7b@05A@I02DT:00N7R0071`N01hN8@0O7R<071/Q010?
5P0D4a/07A/V01lM:00G5B00;2Xg04U6E00Y9C<09R<^04A1AP2LViT0ZJRT059AC@0`;b/0=SDc020M
8P0J5b805Q8P028N;00J5b8061DP01XG8P0H5B005a@O01TF8@0N6bH07AXU00805a@O01<05Q<M01D?
6@0F4AP071LN01XE700F4AP071LN024L8`0I51/05Q4H01`G7P0M61l07QTP01H?5`0G41P071DM01XC
6`0G41P07QLO00807AHN01`05a0H02HO9`1@BE408AXR01TC7@0B31H07QPS07egP`0_:C<05Q0K00l9
5@1^J780OGN2014;5`0J51l071LN014?4P0P71l05Q4E02<N9@0H4Q`03`LD01dB800G31P08QLO01L<
500G3A007Q8F0P0J3aD00`0H3A<05``B01H;4@0201D:400601T>500N4aT05``B01L<4P0[82H091TO
0P0A1P`201H;4@0401X?5@0G318060dC01P=4`805``B00L05@X@01H;4@0G31805P/A01873@0C20h0
5P/A00805@X@0P0F2a400`0E2Q0050T?01P;500201L:4`0:01P;500H3A<060dC01dD6@0F3A80:1lT
01`F6P0J51H06aDG01LB608050lE00@07APN01lJ800J5A/05Q4G0`0G4QP0<`0I51X06QPM01dM9@0H
6b8082@/01<J8P0h?dT0QHnH03i;E00S<Ch0=4AA03I8E00jC5X0AeaX04mUL01CJGH0IGN707:1U01d
P9H0P8ZT08^E/02AVk@0VZJm08BCYP2:VJ`0NhZM0760T`1UMXP0FV]l055RLP1:G6X0A5EQ03=4CP0d
@DX0<S]502@[=@0W:cH06AdX01HJ9@0V:SD03a8M020S;00L72H0518M014@600R7RH06aHM00D01`0F
3aL05``B01L<400501P=4@0301D:3P0C20`050T=00805P/?00<05@X>01@93@0C20`00P0B1`/0200C
20`040D901L<400G31003P<700d21P0>0`L06`lA0P0F2P`02@0H30h05@T;01@82P0D20X05PX<0145
1`0@10H04PH800d10`0201D62@0401H72P0H2@`05`P;01<41`805@H90P0D1@P201D62@<04@D50`0B
1PH01P0h;2`06@d=00l30`0H30`0@SHf01`@40H04@D500X04PH601451@0C1`L060`<01D92@0B1PH0
4P@401<51@0D1PH05@L70P0F20P02P0G2@T04@<301430`0F20P05`T901H72P0F2A402P0400l22@0E
20l201T=4@0=01D93@0E2@/050P:01@82P0D20P04`T80188300>1@P040L:01D:3P0C20`04@H:0145
2@0201D62`804`@900X04P@60104100B1PH04@D60186200C1`/03`D701@8300800804@H<0P0<00P0
3`0=00P07A4E02LK7`0H31003`<701862P0T61`0710D00P0000@1@P06PhB01L;3`0E2@`04@D700X0
000201<72@0301`@4P0?0`D04@D700@04@D701803P8500`0100F2Ph03@4501<72`1REUX0:QhR01X>
4P0>0PH03`<700h21P0C1`/0200003T]<@0=0@D050P<01D93@0D20`2010420@04@D901@04PH:01H:
3P0<00@05PX>02/O8`0U6Ad0;20T01D93@0O4aL0Cd=709Z>TP0S5a/0200500h32`0C2100714I020E
7@0G31@04PL?01463P8040D=00<04@H>01873`0A10d01@0A10d01P0B1@h05`XC00h12P0;00L040<<
00h12QCooooo000Kooooo`0D01T?6019?dL03@<;00l42P0A1P/04@L802<G6@0P4a<06`d:01L91P0E
20804`D201@8200E2@/040@601D92`0A1@L05`/=00l31@0A1@L201H:300401hB500X71h050P801@8
20804`L70P0B1PH01P0=0`<040@401451@0E2@T03P8201H:2P805PX<0P0B1PP02`0@10H02P0002`P
8P0S5aT07A4C01@82P0A1@L02`0101/?3`0[7al08ADE008060`<00T05@T901061P0I3@d0;20P01H:
2P0D20P05PX:01@8200:00000P0L41000`0?0`<060`<01H:2P0201D92@0?01H:2P0H30`06a0?01T>
300E2@T04PH601D92@0F2P`04`L901041P0P51P0BSi201`@500H31005@T<00805@T;010050P:01D9
2`0E2@/06@d?02@H6P0B1PP06@d?01@82P0G2`d04@D:01/@600D2A404`P@01873`0D2A405@XB0P0D
2A40;@0C2100GU=K01`A6@0J4AH030H:02<M8@0D3Q8081XN018=400V82@04P`@010:3P0C3A409AlS
02`V:P0D3Q805@lC01@>4P0N61`0618F01dG6`0B3100:bDY01H@500R72003PP<01@>4P0B3A405Q4E
01/F6P0J5AT06A@H01XE6@0Z9BT0>SDi01`G6`0P6al07APL01HA5@0K51/06aDK01XE6`0K5Q`071TN
01dK800201`J7`0E01lN8`0N7B8071/P024R9`1?Deh0<SM301HJ9P0J7RT07B0Z01lR:`0O7bL08b<Z
02DT:P0S8BH09B8W02XY;`0U:S007bP_024Z<@0R:c8082T`00<08b`c00X092dd02Pa>00Y<ST09c4j
02Lb?@0g@dl06RHb02/g@`0U<Cd07RXf0P0_>dL05@0`?4P0=41<03Q4D00iAE40<cm;03M5DP0eAE80
<D=A02`oCP0gBUT0=DQE03A6DP0cATd0=DE=03M4BP0fADX0=4Q?03E9DP0mDEX0>TiG03E9E00203]?
FP0J03I9E`0oDV00=DQF03]>G@0iBUP0@DmJ041>F@0lBUD0?deH041>E`0lBe<0>4M>03U8C`0hAdd0
=dI;045@E@1@GV@0@DiD03A1A`0c@4H0;S]102dj@00c@4H0=T=903M4BP0hAD/203I3B@0703A1B00h
ADd0>dQ@03U6CP0lBE40>dQ@03M4C00203U6CP0B03Q5C@0kB500=TA<03=1BP0hBE40=DI>03A5C@0i
BU80<45903=4C00hBE40<dA<03Q9D@0gB500>DYB03m<DP0lBDl0>dQ>0P0nBe40100hADd0=T=;03I3
B`0gA4d203Q5CP1003Q5C`0i@d`0>TE;03Q3B@0c?T@0=3m503M2B00e@4H0>DA:03E0AP1?FV00:3<i
03E0AP0`>D80=Ci703@mAP0c?4D0=3e6038kA00a>T<0=d19034j@`0]=Sl0;SM002/d>`0X<cL0<3/m
02Pc=@0R;2h0<3Xl06QbM01IHF@0<SXm02Xb=@0V:bl0:Rlc03Hk?`0S9Rd0;S4h02T/<`0i?4<0F5]R
04U<D`1^LGP0V9^R0413BP0_<ST0<cHm02ha>00^<cL0:2db03<h?P0M8B`0<cM302DX=`1KGVd0h^Gd
08R;VP0Q9C409b/f0412CP0e=400?C]802TW=0808AlZ03P09bD`01dL900U92`09B@/02DT:P0Q82H0
6aXR028P;@0R82h0;2Xh02`Z=`0N72T09R@_028Q:@0Q82H08b8X02DT:P0T8bP08R8Z024S=00U9SP0
9RLi02<U<`0Q82h07QhY02@T;00[:S80<C0e028Q9P0D51H07QhP028R900O7b408R4U02<R9`0O7R@0
7ahU024P:00K6B@06aTU03Pf@`2:R9D0]K;0044mB`0U8Rd07adR02h]:`10?c/092<N01`K5`0Z:BL0
7Q/P01lL9`0L62H0920^01/H8`8061DP0P0D4A`0200N6bH06QLR00d:5@0E4Qd07a`W01dJ900M5b40
6QDL0P0M61l01@0J5A`07APO02<N9@0N6B0071LN00807APO00<08ahU01TB6P0F3aL00P0I4QX00`0E
3QH0614I01L@6002014:4P0`01/D700b:c<05PhH01<=6@0@2QH04`dJ034[>@0<1Q8050hK024K:@0i
<cl08Q`Y04m9E`0S7BX030H@01XH6`0D41<00`0201/F7@0D3AL06a<P028G9@0F2aL06@hF00h12P0D
20d07A4E01`A5`0K41H06@hD01P=4`0G31805@X@01L<4P0J3aD060dC01873@0?10X04PL=01H;4@0D
2@l0714G01lD6P0H3A<050T?01T>500H3A<05``B0P0F2a401@0G31804@H<01@93`0C20h050T?0080
5P/A00@050T?01H;4@0F2a405P/A0P0D2@l0100J3AH06@`E01P;500I31D201T>500=01P=4`0H3a@0
2`8701D=3`0E3a401@0101D@5P0G4QP050lE01TD6P0K5Q`05a8H01HA5`0201LB600d01HA5`0I51X0
6QPM01@D700K7RD0B4aD028Y<@0M92h0Mh6:03I3C00X=T<0<41=03E7D`0hBUP0A5UU04eUK`1@IW<0
HG>306mnT@1`Oi@0NhNN08JBZP2CWkD0XK3308JGY`24UJD0MHFF06imT01TMHL0FFYk04mPL018FVP0
@U=P03Q9D`0hADh0;cU202P_>@0/<3/0<SM202<Y=@0D62@092Ld08>5T@0[:cH07A/V01XH8`1@CEL0
E4iH020J900R6b@05P/A01H;3`8060dA00D06@hB01X?4`0F2`l05@X>01@93@0201H;3`0301D:3P0D
2@d050T=008050T=00H04`P<01872`0H3A406PlC00d21P0D2@d201T>4P0<01T=3`0C1`T050P:01P<
3P0D20X04PH801<72@0F2P`04PH801451`0C1`T03P840P0D1@P01P0E1PT05`P;01H72P0B0`H05@H9
01@520804`@700@050D801D62@0@10@040@40P0A1@D201861P0501P<300C1`L0200003<W9`11=CD0
1`0A1@D301861P<04`L71P0D1PD301D71P0:01H81`0E1`H050H60144300N4AP05PT@01L:4@0H3100
4@D901<72`804`L900X050P:01@8200C2@P04@L;00`31P0>1@P050T=01<8300@1@T04@D90P0F1``2
01@52P0Q01<51`0B1`D03`<301<7200@10H04`L901862P0Q51/040<:00h32@0@0``060/E01@73`0F
2Ph06PhB01@8300?0`L04@D903/_<`0e:Bd03P8600h41P0H31003`<700X00@0B1PP04@D701041P08
00005`/=01041P0>0P@03@4300<03`<501805@T<01862P0D20`0200001`@502fZZh0;20T01X>4P0>
0PH040@800h21P0B1PX0Ac/o0:6EV@0T61`04PH:01<72`0>10H401862P804@D900@05@T=01H:3P0?
0`L05@T=0P0]8BD03`0<00@0200000l51`0/82@0JUiR01L;3`0A1Ph06PlG01<8400<0@T040D=01X?
5`0D2A404`P@01463P0301053@H04@@=00@05PTB01lB6`0B1@h02P060P0@0``Dooooo`006oooool0
4`0B1`d040H<01D;400=10L04`T;0147200E2P`04PL701hC4P0F2@L05``:01061@0C20T05@/<044g
=`0E2P/05@/<00d20`0D2@/00P0B1`T01P0@1PL04PL901P=3P0E2@X050P901<720804PH702@04`L8
01451P0K3a004@D601861`0D20T060`=01D92`0H30h04`L901@82P0G2`d04`L901`@4P0M4A<050P:
01<72@0M4A<04`L901@82@0M4A8060`=01861`0I3@h081@E03L[;00?0`@05@T:00h30`0J3Pl05@T:
01X>3`0G2``060`=01H:2`0A1@H201/?400501<7200F2P/04PH700h4100H30d00P0E1`T06P0F20X0
60/<01L:300F20/05PT;0185200K3A404P@801X=400C1PT05PX<01P<3P0I3@l05`/=01@82P0F2P`0
5`/=01D92`0F2P`050P:0186200E2@d060dB01D:3`0C20d05@X?0P0G31403P0C20d05P/@01hC601D
BDh07A<H0107300E3Q@04``B014;400?2@h0@3Xo08IoQ@0F41D06a@J0P0D3Q<0D`0E3Q@040X?01dF
700H4AL06A8I00`62`0J4aX0ACi507=]LP0Q6R005a0G02LQ9P0N61h05Q4E01LB5@0J5AP06ADG01LC
5P0H4aL05a8F028M8@0H4aP0:bH[05]FF`0K5Q`071HM01`G700P6b008A`Q020L8@0Q7R<081dS01hK
8@0N72807a/Q01lL8`0K6B00FU]T03TlA@0F6R<07AhX01hQ:@0L7bL06ahV02@U;P0o@DP08R<[01lQ
:00R92`0720Z02@[=00L92d09Bdf028Z<`0V;SH09c0h02@]=@0V;cL0:C8j02`f?P0X<S/08Rdf02/g
@P0Y=T00<3a702Tf@00^>dH0<Ci903E2C@0/?4H0<T1=03]8E@0nBeL0=45@03]9F00d@e40=4A@03A6
D@0a@d`0>DYC03A5CP0c@dX0<d9:0080=49:01X0>D]D03=5C`0cAU00<dE?03M8D`0lCeT0@59M03a>
F@0kCET0>4]H03i?G@0iBUL0>T]F03e?FP10D5/0?diI03m>E`10D5P0?TiE03e<DP0hAdd0<d9703]:
CP18EU/0>4E;02dj@080<Ci400h0<Sm503]8CP0hAD/0C5UO04YGG@0`?D<0>4E;03E2B@0iAdh0>DM?
03E3B`0hATd0>DM>03U7C`80@U1H01T0>TQ@03]9D@0iAdh0>4M?03U9D@0iBE00>d]C041@F00nCUD0
=dM?03I6C@0dA4`0<d=:03Q8C`0eA4/0>dQ@03I3BP0lBE00>dQ?03M4B`0_?4@0<Ci603Y7C`0d@DX0
<d180080=D9;02d0<Sm70390A`0f@dX0=D5803<oAP0d@4L0?4M>03@nAP1GHFT0IFmf03a6C@0f@4P0
;SPo03<mA@0f@4L0;cQ0030i@@0^=cl0;3@l030h@00]=Ch0;3@l02dd?@0Y<CP0;3Dk02/e>P0/=SX0
;CDk02H_<`0d?400<STm02T_<`0^<SH0;C4e02/_<`0X;C409R`b01lU:`0R:2h0:C0d03@j?P0m@DH0
PhN=0;Vm`@13Ad/00P0_<cL02@0]<3H0<CDn024V<P0V:cL092Te024U<@0X;3T0;Blm04Q:F00202T/
>01i03Df@P1LGFP0;bdg02LS;@0P7RP09R<]028O:@0Z9c409R@]02HU;P0U8bd09B@]024Q:P0L6bL0
9B<b01XH9P0O7R`07ad[02@S<00n?DX08R4]020O:@0O7bT08b</02DT;@0T92l092He02DU=P0S8c80
8R8`02<R;P0O7RX071/V028P:@0P7RD07adS028P9P0N7B<07ahS01lN900Q82D08R4X020O9P0L6R@0
71XV01lM:`0R82l0:RPg05iKJ`1iMhH09b@a01HC7`0Q7RL08B0U02TX:`0T8bD06aXK01/J7@0M6b40
8b4Y01PF800K62<0510K01XF8@0H4ah05Q8L01TD7`0L5b806ADM028N9P0V8RX081`T01TE7@0N6B00
7QTO01PC6@0O6R406aHL01PC6P0F4AT08adV01/F7P0M5b0071HO01/E7`0S6b<060lH01lE7P0R5b00
7QDN01/A6P0M4Q/06Q4J01lF7`0J3aP04`XC01X@6P0N5b<05@lL01PB7`0D3Q/04P`I01<=6@0I4b00
5@lJ02LQ;02`Zk@0ACm9018<500D3a<04@`?01H@500L5Q/05a0H01TB6`0D31D05@`E01L=4`0>1@T0
5`dC0147300201T>500;01`A5`0K41H05P/A01D:400F2a405``B01D:400F2a4060dC01H;4@0?10T0
0P0H3A802@0E2Pl060dB01T>4`0G31406@hC01P=4P0F2a005``A01X?500201H;40805@X?00@050T>
01<83@0G31405``A0`0E2Pl04@0D2@h05PX@01863@0I3AD05@/C01<:4P0E31@04@TA01<;4`0H3aD0
5`hB00l52@0G3a@050dD01H@5`0C3A@04P`C00804`dD00<05Q0G01PB6@0I4aX00P0K5A`0<`0I5Q/0
71`P01PI7@0H6b408RH^020W;`0R;3D06RHb02dkB00/>dT0>DYI041AH011E6<0CF9`051TL`1KK7d0
I7F706UiS@1bPYL0N8RL07b<X@22TZH0N8VL07Z<WP1aPY@0J7V;061aP`1IJg`0CF9`04MII`0oDEd0
>daF04=AFP13CUL0;CDo02<Z=00Q9Bl06adX02<T;`0O82X0;2`f01LF7`0I5b0061HM01TE700C3Q@0
4@`C01TB6@0H4A@0610C01H?4@0201@<3`0401P@4P0G3A405P`@01D;3P805@X>0`0D2@d0200C20`0
50T=01D:3P0F2`l040D901H;3`0B1`/04`P<0P0A1PX01`0D20X040@60186200H30h05`/=01D92`0B
1PP00P0C1`T201@82P0901451`0C1@P04`D801@62@0D1`T050H901841`0E20X050L900804`D800d0
4`H801@62@0D20P05PX:01<71`0A1@D04`L701451@0E2@T03P@4024E5@1:?Sh050T900804`L701h0
4PH601451@0A1@D04@D501861P0E2@T04`L701861P0E2@T03@<302@H600H2`X050L80185100B1@D0
4`H701@71P0B1@D05@P901D8200D1`L04PD601041@0A1@T04@D;0148200B1P/06PlB01051`0B1`X3
01872@0:0187200B20T040H:00h21`0?0`T04PH<01452@0?0`L04@D901<62@8050H:01005@L;01@8
2@0G2``0304101@82`0A1@P050P;01452@0=0`H03@8601@73@0<0@L050L?01442`0@10P03`<70P0A
1@T09P0B1PX0710D01D93@0?10L04PH:00d31@0A1@T05PX=0145200B1PT04`L:00/10`0K3a804`L:
01041`0?0`H04`L:00d3100G2`h05@T<00l31P0R5AT07Q4E01X>4@0U6A`060/?0143200A10P06@/@
01H83@0@0`L081@H06AHG00G2`l050P<01H:3P0?10L050P<0P0F2Ph201452@0E01P<4@0O4aX04`L>
01863@0;0@H040@;01lC6P0=0PP06`lG01873P0E2A003@<90104300C20h050T>00l52P0E2Q404`P?
00h32P0F2a804@H>00804PL?00h03`<<00h3300B1@l04`D@00l2300@0`h060/E01T<5P0F2A@06`hI
01@74@0<00X050LA01853aCooooo000Kooooo`0J01@:2`0E2``05@/<01<92P0A1`P03`D60147200M
4a@0^:j_05=9BP0@20P0:AlP01dC500=0`@06@l@01lE5P0B20T0718C01X@4@0D2P/0308300l51P0>
10D02`4201L;3@0E2@/201<72@0S01@82P0E2@/08QHH00X0000>0P@06Ph@01<72@0;00404@D701<7
2@0?0`D04@D701@82P0A1@L05PX<020D5P0E2@/04`L901P<3P0B1PP05PX<01dA4`0Q5AL060`>01H:
300M4A<05@T;01041P0J3Q0050P:00h2100<0@803`<501451`0D20X00P0F2P`0100@1PL060`>01T=
3`0>0P@201@82P0301T;3P0E1PT05@H900<05@H900<05PL:01L82`0G20/00P0G20/02@0J2`h0:Q`O
01T=3`09000050X;01451`0E2@/06@d?01@82P0301H:300501@82P0@1@H040H70147200C2@X00P0J
41401`0B20T05P`=01H<3@0C2@X05`d>01`C5@0A20d00P0D3A@01@0N5ah04@XA01L@5`2<QH`0<2T`
008040T@00l05PlF01PA600K51`050dE014:4P0I4QX07aPP01hG7`0<1@d0;BH^00l8400E3QH08AXR
01TB6@0H4aL00`0I5AH02P0J5AP05a8F01TD600N6Ah061<I028M8`0d;cD071LM01hI7`0L5a/201lJ
7P0Y01`G700N6Al09b8Y01dH7`0G4QT081XT024K9@0L6B8081lU02<T:@0L7B8061PP01/L900K7RD0
6alX024U;P0f>T<06R4[01`S;@0Q:380ADUD04]?FP0W:cH0:c8l020W<@0S:S@09c0i02H_>00Z<c`0
:cDn02Pb>`0`>T<0:S@m02`i@@0^>d<0;S]402dkA00_?DH0;ce803A5C`0`@D/00P0`@4d02`0_?dh0
<d1C03I3EP0f@e<0<d5<0350A`0b@DH0=TE90391AP0a@4L0=D=<0080>DMB01<0>daF03a=E`0jBeD0
>T]E03i?F@11DU`0?4eG03Q9D`0jBeD0=dQB03Q9D`0lCUT0>4aG03Q:EP0jC5L0>D]E03]<E00nCeH0
>DYA0080>TU>00H0=4=803E3AP0mBTl0>TM=03=0AP0d@DL203U6C00;04QEF`0gA4X0@DiD04AAE`0e
@TP0?T]A034oA@0d@dX0=DA;03=2B@0fAD`00P0eA4/02@11D5L0@U5H03E4B`0gATd0>4M>03I5C00h
Adh0>dYA03U8C`0203Q7CP0K0391B00d@dX0>4M>03U8C`0gATd0<d9903a9D@0iATh0;S]303Q5C@0e
@TX0>DI>030mA@0hADd0<d1803M4C00c@4P0>4E=0391B00d@dX0>dYA03Q7CP0a@4L0=T=;03Q2B`0^
>440@deF0080;3Dn00@0<CY303E0AP0a?480>DA:0P0a>T40?@0c?4<0;C@l02`c>`0]=3`0<3@m02hb
>`0X;cL0;cHn02Xc>P0Y<ST0;SDm030g?P0/<cT0;C8h02lc>00Z;C80:2/`02/^<`0V:bl092/a01hW
;00S;340:30c02/c=P0`>3/0;c@g04=8B`0/<3<07B4R02X^;`0Y;S80:Bdi01hT=00V;3`08bTg02T]
>@0V:SH09bTf01/M:@0N82`0;blk028R;P19Ae80;BTa02/V;@0T7bH09B4X024N9`0^:c@09B<[02@R
;@0V92l09B@_02<S;`0Q8Bd09bHd02@S<@0/:cT0;B`j04I5D`1dLh400P0N7B/08P0O7R`08R4_028Q
;`0P7bd0828_02HU<`0S8S008R4_024O;00P7RX08AlZ020M:00N6bD06aPQ01`F800K624081lW028Q
:@0S8RX09RD]02@R;@0M6bP06QPV01hK;00Q7Rl07a`]028O<P0Z9cL09bDb02DS<00X9S80:BLb02DS
;P0L6b@201HE7@0;01XI800O7R@081lU01PE7P0W8Bd091hZ01lI900d;SP05@lI01TD700I51/00P0L
5ad0700J5A/05Q4G01hI7`0L5ad05A0F01PC6@0E41H06QDL02<M9`0E3aT06aDO010:5P0B31P06A8N
01P>6@0/82X06`lI01<74@0G2aD06@dG034U;`0]8B/091PR01dA6`0L41X06a0I01H>6`0H4Qh201<=
6@0D01TC7`0A2aD071HP01/E7`0@2a809R4W01<>500N6Al050hB01PB5P0C3A401P0401H@501;ADT0
50hB01dG6`0K5AT050hB018<400T7R8201@93`806PlE0P0D2@l00`0E2Q005``B01P=4`0201L<4P0=
01P=4`0O51P09Q/O020E6@0H3A405P/?01<8300E2Ph0714E01dB5P0H3A4050T=01D:3P0201H;3`80
5@X>0P0D2@d0100H3A405P/?01D:3P0F2`l201T>4P0=01X>4P0R5ad05`hC01L@600D3QP01`4;01<=
5`0B2a<05@hE01H<4`0E2@d05``B01H=5@0201<<500L01@=5@0E3QH05PlG01PA6@0I4QX06a@L01`E
7@0I4QX05Q4G01TH6`0I6Q`06Q`P01XO9@0N8R/07bLa01lY=@0Y=D<0;Ca<03I6EP0oD680@55R04UJ
JP1=GVh0E6Ef05]/OP1PLHD0J7V=0762UP80Lh>J0200MXJM07B4V`1_P9@0HgB605U/O@1CIgL0B5i/
045GI00oDel0=4I@03I4C@0g@d`08bdf020W<@0V:34092<[028Q:@0R8BP07ahT01`I800I5a`061HK
01HA5@0D3a<05A0D01TC5`0;1`P03PX;014=3P0B3Pl0510A01`F60<050/>00T05P/?01P=4@0J3a<0
5P/?01D:3P0B1`/04@H:01<8300G31000`0D2@d301<8300301451`0C1`T04`L9008040@600<05PX<
02@H6P0G2`d00P0:00000`0B1PP06@d?01862005018620<04`L901<050P:01H:300F2P`04@D501L;
2`0A1@D03`<301861P0@10@05PX:01051@0F2PX03@4101@8200F2PX050P801<71`0B1PH04@D50080
4PH600P04@D501D92@0D20P040D500P0000d:2P05`/=01<72@804@D700<04PH801@82P0C1`T00`0C
1`T201451`0701@:2`0@1PL06@l@00l51P0G3@h0308301<92P0301882@030147200A1PX04PD=0080
4@@;014040<:00l31`0?0`L03P8600l31@0@10H04@D701451@0@10H06`lC00l31`0F2Ph040@80186
2P0A1@T04PH:01452@03010420804@D90`0B1PX00`0C1`/08aLK024E6@0201<72`0G00h21P0=0@D0
4`L;00h21P0C1`/05@T=01<72`0E2@d03@4501862P09004040D801@8300=0@D0304301/<4@0F1``0
6``A04/l@@0K3A4060T>01H7300H2@h00P0N3a@0<@0G20d03`<701@8300;0@<03P860104200F2Ph0
4@D901@8300E2@d03`<70104200J3A<07Q<K00T01`0A1@l01`05028F800@10h05@TC00T01`0<00X0
4@D?01P<5P0@10d050T?01@93@0C20`04@H:01052P0>0`T05@X@00h32P0B1`l050TA00l3300>0P`0
3P0=0143400<00/03@0<01H85@0E1a@04P@A0143400B11403@0<01H85@0@0Pl05?ooool001_ooooo
00/04`T:01L=3P0G3@h050X;01<92P0E2``02P0101`B4`13>CX03P@501061`0200L0000601H>3P0=
0`@04`T:01492@0A1`P04`T:0P0B20T01@0M4a@0718C0147200E2@/050P:00<04`L900D050P:01`@
4P0@10H04PH801L;3@0201D92`0301L;3@0F2P`04PH800804PH801003`<501@82P0G2`d050P:01<7
2@0E2@/050P:0186200G2`d0710B01L;3@0B1PP050P:01041P0B1PP05@T;0P0C1`T01@0N4Q@04PH8
01D92`0D20X04`L900805`/=00H06`lA01X>400I3@l05@T;00l31@0A10H701D62@0;01@5200C10L0
5@H901T:3@0Q4aH02000040d=P1ODeD09ATK02LK7@0>10D00P0E2@/0:00F2P`05@T;01D92`0E2P/0
8ALH020F5`0D2P/060h?01H<3@0A1`P06a4B01@:2`0<0P<05P`=01T?4@0@1``04@/?00l93@0H4QH0
5@lC01XD601OFEd08A/O01<=4@0B31006A<G01H@500E3QD04@XA01TB6@0L5A`040T@00P120090PT0
7QLN01L@5`0F3aH07AHM01H?5P0A310201PD5@0;01HB4`0J5QP04`hB01dH700H4aP04PdC02@O9@0>
2A007APN01dK800J61/00P0K6A`0>P0H5QX06aTN02<P9`0J5ah05Q<J02/X<@0N6b@08QlX01lN900[
;3409BH[01/K8`0K72@08B@[01lS;00M8BX05QXS01/R;00P9c407B@^02@X<`0]<C`05a/V01lV<00Q
:380:S4k02H_>01;E5d0624Z030j@`14CUL09Blh02dg@00/>D40:cQ002Xg@00Z>440;3Y302/iA00Y
>DH0<T9?03A4D@0b@Tl0<d=B03A1E00f@eH0=45A034oBP0_?TD0;ci303A3B00c@TT0<T5803=1BP0g
AE00>TQC03=4CP0jBeD203a=E`0G03m@FP12Ded0>DYD03Q9D`0lCEL0=dQB03I7D@0kCEP0=TYE0394
D00fB5<0=TQB03M8D00iBU80=dQ?03Y9CP0mC540=dI;03=1A00f@dP0=D98034nA00c@4H00P0hAD/0
1`0oC580>DI<03U6C00c@4H0;ca203U6C00e@dX00P0eA4/0200b@DP0=DA;03I5C00b@DP0>4M>03Y9
D00b@DP0=4=:0P0fAD`03P0hAdh0>TU@03Q7CP0gATd0>4M>03=2B@0eA4/0>4M>03U8C`0gATd0=4=:
034nAP0gA4`0?4UA0P0]>T805`0_?4@0<Sm7038oA`0b?dL0>DI>02hk@`0hADd0<T5803=2B@0gATd0
=DA;02lnA@0c@4P0>49;038lA@0_>D80;3Dn03<lA@0b>d@0=3m502lj@00e@4H0;SLn0080;cPo02`0
;3<k02/b>P0[<SX0;S8k02da>P0X;cL09bhf02df?@0Z<cX0;3<k034h?`0X;cD0;c@j030d>P0Z;C@0
:B`c02`_=P0X;C<092/c01lX;P0T;C80:2le02H^<P0X<3<08bP/01lS9`0^<SD0;C4d02T];`0Z;c<0
:Bdh024W=@0Y;cd09BPg02DY=@0O8bl07b4^01lQ;@0W:CD0;Rhj01lO:@0Z:3<09b@/02/X<@809B8[
02008b0[02l]>00O7RT0820/024Q;@0R8bl08B<`028T<@0];3X0=SE300403P1NGF/0MgJ401hM:`0L
6bT07Qd[028Q;`0V9C<081l]01`K:@0Q8c00:RTg02LV=00R8Bl07adZ01dK9`0N72L07a`W020M9`0O
72D081XT01hK90807A/V01d07adX02@R;@0Q7b`06aTV01hL:@0P7R`07ad[020N;00K62T05Q@Q01PF
8`0L6RL07adY01hL9`0J62<06QTR01lN9P0P7bL071/R01XI7`0O7R@09R8[02LQ;@080Ph0:B<^06=M
I`0U7bT04`hF01PC6P0201XE6`0B01TD6P0G4QP071LM01LB600M61h05Q4G01@?5@0J5A`05Q0J028L
9P0F41X07aTU02LQ;@0J4ah0:AlZ05Y>F00e:C<09ATS0P0Y7BL0800a9Bl0:AdW01dA6`0J3QP06`lI
01P=5P0@21D06aDQ01H@700Q6bD0?3I002lY<`0500L04PdD01<>5@0A318061<I01@?5@0E3a<05a4E
01D?4`0<1PX04@/?02hX;00M5a/030L:014;3`0U7b<050hB00l93@0E2Q0050T?0P0G31800`0D2@l0
5@X@01H;4@0201H;4@0>01L<4P0I3Q@06@hD01X?4`0Q5QX0714E01L<400F2`l05@X>01L<400O51P0
8AHJ01dB5P0G310201H;3`<05@X>0P0D2@d05`0F2`l05@X>01D:3P0F2`l05``@01T>4P0G2`l03`@:
00H00P0E3QH0618L01LA6`0C3AL040TA018;4P0B20l04`L;01D:400D31@04P/C01<<500E3QH05PlG
00805a0H0P0J4a/0>`0H4AT05PlG01D@5P0J6A`06Q/O01TK800I7R@07B4Z024Y<`0T;SX0:SI402Xi
B@0b@U80?4]N03m?H@17F6P0BU][05AUMP1NKh40HG:406AeR01[O900KGjB06emT`1`P9L0KWjE06]l
T01SM8H0G6n005]_O`1@IW@0A5YW041DG`0^@4X0;C]402Hb>`0P:S<0:C0j02HX<@0V9Bd092<[02<R
:@0Q82H07AXQ01`J7`0I5a`05a8F01<>4P0D3a<06A<G01LC500H51D05a<D014=3P0=2@X03@L901P?
4P0F3A0050/>008050T=00T05@X>01P=4@0F2`l04`P<01462P0B1`/05@X>01@93@0E2Ph00P0F2`l0
3P0E2Ph04`P<01041P0I3@l07a<E01@82P0>0P@05@T;04@h>P0^8R@05@T;00h2100@10H050P:1P0B
1PP201D92`8050P:00h05@T;01H:300>0P804`L701861P0@10@04`L701451@0F2PX050P801P<300;
00005`/;01<71`8050P800<04PH601451@0B1PH00P0B1PH01`0?10@04@D501861P0900006`l?01H:
300D20X0100B1PP601<72@0701<92P0@1PL06@l@01<92P0O5AH04`T:0147200301882@0601<92P0C
20`050L?01<63@0B1@`04@@;0`0?0`L02@0A1@L04PH80186200?0`<0308201862P0:008050P<00h2
1P0201@8300301<72`0B1PX04@D900804@D900<04PH:01<72`0B1PX00P0B1PX05@0A1@T06@dA01H:
3P0@10P04PH:00d11@0>0PH03P@603P/<01`I6P0Ac/o00P0000=0@D06`lC01X>4P0C1`/050X<02LK
7`0A1@T040<701421`0201D62`0302TJ7`0G20d05@H;00804`@901`060T>01T:3`0E1P/04`L;01T=
4@0C1`/05`/?01P<400R5QX03`<701452@0B1PX040@801452@0E20h0PWMo02DJ8P0J3aL03P<;01H;
4`0J41L0;R<[00P01@0R5al03`@<02LL900900H04@H<0P0A1PX0400@1@T03`@900l42P0B1`d03`@;
01873`0C210040D>00l33@0>00d04`DB0143400B11404`DB00l13P0C1A8201844@0300X02@0@0Pl0
200701Cooooo000Kooooo`0900h41@0D2P/05P`=01<92P0E2``0718C01H=3@0?1PL05Pd>00805@/<
00d030<402PN7`0`9RL05`d>01H=3P0C2@X05@/<00`30`0C2@X05P`=02DK700P5QL030<400H04@D7
00D04`L901041P0D20X05@T;01451`0201<72@0301041P0A1@L050P:00805@T;01h04`L901451`0E
2@/050P:0186200E2@/04PH801451`0B1PP050P:0186200@10H05@T;01<72@0?0`D05@T;01L;3@0T
61X04PH801D92`0C1`T04PH801L;3@0B1PP03`D601D92`0C1`T04PH801P<3P0D1`T501@5200=01D6
2@0G20/060T<01P9300F1`X05`P;01P;3@0C2@X03P@502DI6`0F2P`0200001T=3`0501D92`0b01@9
2`0W7Ah0:1hO0147200B20T05@/<01`B4`0F30d050X;01D;300D2P/05`d>0107300D3Q805a4E010:
3P0>20`05@lC01@>4P0:10P06A<G00l93@0D3Q805Q0D01D>5@0C31<05PlF00l83`0J4aX0GeQO024J
8@0K51/06Q<J01<<4`0G41L0618G01@?4`0L61T061@E018>3`0I5AL05A0D01<>4P0J5AX081/Q01dH
7P0M61l061<I01`J7`0I5aX201/I700R01/I7@0Q7b@07a`S01dJ8@0O72<0>SM001/H8@0L6b<06aXP
02HW;00T9BX07AdU01dO9P0O8RT092Pa01TM9P0K7bP09B`f024X<P0J8B/06AdX02HZ=@0T:3<09bhh
028Y<`0P9c40?DI?071iPP0]=Sl09c4j03e7D00Q:c@0;CM102/h@080:CHo02/0;C]502lmA`0jB5<0
:CU603I6D`0gAe@0=TID03U9F00iAUP0>4EF03E2DP0a?d/0<3i70391B00iB4h0>DQ?03E4B`0_?DH0
<3i903A2C@0a@T`0=4E?03Y;E@11DU`0?TmI03Y;E@0kC5H0?DiH045BG00lCEL0>DYD03Y<EP0fBU@0
>TaG04EGHP12E5h0>T]C03Y;DP0kC5<0>dY@041?E00kBTl0=TA80080=dA:00<0=45703=0AP0d@DL0
0P0b?dD01P0lBDl0>DI<03I3B@0hAD/0<Ci40390A`80=DA;00<0=4=:03U8C`0lBe800P0hAdh01`0i
B4l0=DA;03M6C@0iB4l0=DA;03M6C@0hAdh00P0eA4/0700gATd0>TU@03Q7CP0d@dX0<d9903E4B`0h
Adh0?T]C04]HH01oS9@0>TM?03a9D@0`?DD0;ca403M4C00a?TH0=D9:03=0B00iATh0=TE<03E4B`0f
AD`0<d9902lnA@0c@4P0<3Y303]5CP0^>44203Y3C00:034j@`0d?dD0<ci403Q3B@0a>T40;cPo02L`
=`0^=Cd0;C@l02`c>`80;c<l00h0:S4i02H]=@10BE00=d1702Xa>@0]=3/0;3<j02`a>00`=3/0;2lg
02/^=P0/;cL09RXb02T`>0808BX`00@08bXa028Y;`0U;3409b`a0P0Z;S80?P15B4`09RX]034f>P0T
:3<08RPf02db@00/;cd0;S4m02DX=@0P8Rl08B8^02DV<P0Y:C@0;Rdg02HT;`0U8bd0<Rli02TY<P0X
9Rl08b8]02//=`0P8B`08B8_01lR;P0N8Bh08B@b02<U<`0Q82h0:RTg02@S<@0];3X0:bXh03@c@@0Q
82h07ah/02DT<P0W9S@08B0^020O;@0W:CH0;B`j02PW=@0S8S008R0]020N:P0P7RT08QlZ028O:@0R
7bP08adW028O:P0P7RX071XV01dK9`0S8Bd081h[01TG900P7RX07adY01HD800M6bL08Al[0`0L6RL0
4@0J62@071XU028P:`0T8R`07QdU01/J8P0F5A`05QDK01XI7`0P72D05@lK020J9P0O6B@07QPR01H@
6P0M5b006QDL00@06QDK038061<I01@?5@0[9R`07aXP01XE6`0J5A`06A<M01D?6@1cKGL0>C<o01TC
7`0P6BD03`D@02DJ900M4Q/05``E01hC700F2a@06@hG01P=5`0H3AH060dG01X?600M4Q/05`lL01/D
8@0C31P04P/F01hG8P0D3QL05a4H01D?5P0N61l02@<901D?5P0?2A006Q@H01@>4P0H4QH06aDI01@>
4P0>2@`03PP<01D?4`0N61`050hB01TC5`0@2Ph060dC01D:40805``B01405@X@01P=4`0J3aD05``B
01@93`0E2Q005P/A01D:400C20`060dA01D:3P0D2@d060dA01L<400C20`05P/?01L<400201H;3`03
01P=4@0E2Ph05@X>00@05@X>01<060dA01H;3`0I3Q805P/?01<8300E2Ph050T>01493P0F31@040XA
01`H801LF6405a<L018<500C31@04`X@01D:400I3Q@05@dE00H050dE01D06A8J01PA6@0E3QH05PlG
01PC6P0J6Ad06QXO01TK8@0I72<0720Y024X<`0S;CT0:CE502`iB@0gAUH0@U5T041@H@0oD600@eAT
059SL`1NKh000P1QLX@0801UMXT0J7V=06QhS@1ZNY00JGV@069cQ`1JJgd0FFam05mdP`1EJgT0AUaY
03]?F`0^@4X0>4I?02/g@00T;SL0;SDo024S;00S8RX08B0X020O9P0N7B<06aPO01XH7@0I5a`06QDI
01PC5`0F4AD05Q0D01HB4`0E4A80510A0P0C3a006P0G4A<06Q4D01P?4P0D2`h05@X>01T>4P0P5AT0
5P/?01D:3P0D2@d04`P<01@93@0F2`l050T=01D:3P0H3A405``@01H;3`0C20`040@601/?4@0Y7Al0
8ADG01D92`0>0P@050P:0P0B1PP00`0C1`T050P:01451`060186200F01P<3P0F2P`04`L901451`0@
10H03`<501451@0D20P05@T901<71`0B1PH04`L701861P0E2@T06@d=01@8200I3@d03`<301D92@0D
20P04`L701861P804`L700H03`<301D92@0G2`/04@D501@8200A1@D401@82P0>0186200A1@L04`L9
01<72@0B1PP04`L901@82P0E2@/05@/<0147200D2P/03`D601`B4`0?1@H20147200801882@0C2@X0
4`T:01@93@0E210050L>01<63@0B1@`20104200:00l31`0A1@L04PH801<72@0B1PH06`lA02TM8@0D
20`04`L;00d11@8050P<00D04`L;01862P0B1PX04@D901862P0301<72`0W01862P0A1@T04@D90104
200>0`H040@801@8300?0`L040@801H:3P0@10P04`L;01<82`0D20`060`@01<82`0<0P@05PX>00l4
1`0@1@P03`<701@72`0?0PD05@L;01421`0E2@/05@L;01<42@0A0PL040460183200C10T050D:00h3
1P0C1`/04@D901<72`0?0`L050P<00<040@80P0C1`/03P0A1@T0;b@/01873`0C2Q0040D=01@94@0D
2Q407a@L01H=4`0k<3P02`4801H;4`0D2Q003`@:0`0?10P0100?10T03`@:01052`0A1Pd201873`04
0187400A1@l0408>01443`804PD@00P04P@@01433`0A10l040<>01<64@0A0`l081<N020B7QCooooo
000Kooooo`0301882@0E2``04`T:008040H701@050X;00l51P0M4a@0718C00L0000G3@h07aDF01H<
3@0F3@h01`00020F5`0E2``050X;01H<3@0D2P/0200001L=3P0P5QL050X;01<72@8050P:00H05@T;
01@82P0D20X04`L901@82P0G2`d201D92`0C01/?4@0J3Q0040@60186200C1`T04@D70186200C1`T0
5PX<01P<3P0D20X04PH801@82P0F2P`04`L900l31@0C1`T05PX<01@82P0301041P0401@82P0?0`D0
50P:01`@4P805@T;00T05PX<01451`0P51H04PH800X0000K3a403`<500/00@0G2@`01@0E1PT03@0D
1@P05@H901L82`0F1`X050D801D62@0K3A003P84020D5P0C2@X0200001hB500D20X00P0E2@/0400D
20X05@T;01D92`0E2P`04PP901061`0H3Pl07A<D01<92P0E2``040H701T?400D2P/02`42038Y:P0U
71l200h8300501PB5P0M5a/05Q0D01PB5P0A2`l00P0C3A403`0L5QX04`dA00/42`0>1`h06Q<J01TB
6@0A2Q4071DL01L@5`0>1`h05@hE01XC6P0H4AP07QLM01@@4@0201HB4`0N018>3`0D3a806A@H01hI
7@0H4aP05Q4G01`G7@0C3Q@07QTO01HD6@0D4QD06ALJ01/I700K6Ad081hS02<P9`0L6B005Q<J02HS
;00G51d071/S01PI7P0N7b@07AhS01hN9P0O8BP06QdT02T]=P0F6R<08RH_0P0K8R`0>`0P9c4061`W
01`P:`0P92l07RD_02@[=@0W;SP0;cQ1034j@`0c?4D0:C<l02La>P0_>D80:S@n02Tf?`0X=Ch0:SM0
02hlA`0b@4/0=49=0351CP0lC5T0@E5N03a<F`0hB5L0?DYJ03Y7E`0fA540<d5<03A2B`0fA4d0=dI=
03I5C00eA4/0<d5:03=1C00d@Td0<T==0352C00fAe40?TmI03Y;E@0cA4h0>DYD03Y;E@0nCeT0>daF
03Y;E@0jC5H0=4QA03E7D@0mCeT0?4iH03U:DP0jBe<0=dQ?03M6C@0jBDl0=TE:0080=T=900<0=457
03=0AP0c@4H00P0d@DL00`0c@4H0>TM=03Q5B`0203=0AP0;030m@`0d@TP0=DA;03I5C00eA4/0>dYA
03e<D`0jBE00>DQ?03Q7CP0fAD`00P0gATd0200d@dX0=DA;03E4B`0c@TT0<T5803E4B`0d@dX0=DA;
0P0hAdh01P0eA4/0<D1703E2BP0b?dL0?daD02@a>@80;S]300P0:SLo03a9D@0b?dL0<d1803e:DP11
CUH0=dI=0391B080<D1700/0;Se403=0B00^>440>D=<02hh@@0e?TL0:c@m034j@`0b?D<0<ci403M2
B002038k@P0@02</<`0`=cl0;C@l02`c>`0_<c`0<3@m02`c>`0]=3`0<S]202df?@0^=Cd0<3Lo02D/
=00V:S<0:Rdf02LZ<`809RTb02807b</02`c>`0P:C007BH]01lV;P0Q:3009Rdc02<X;P0N8RP0;S4f
028U:P0b=CX09BP_02/_>P0Z;Sd0;S5002``?00`<Sl09BLd01`N:P0S8bl09BDa01hN:00U8bh08b4/
028Q:`0];CL092@^02<T;P0K7BT07b4]02HY=@0Y;CT09b/g0P0S9SD0>00V:CP092@b018A7`0C4R00
:2Le028Q;`0T8c408b8`01lN;00R8Bl07Qd[01/J:00Q82h08bDb02DT<P0P7bd08B0^02<Q;P0N72P0
6aTT01dJ9@0O72H08QlX02HP:P0W8Rl0928`01lM:`0L6RL081h[01lM:P0H5R4071XU01lM:00I6200
61LM01XI8@0K6B<07A/X01lM:P0L6RH061HQ01TG8P0R82X08B0X01TH800H5ah06aXP01XI7`0D3aT0
8A/W02/U<@0L5R40:B<]01TC7@0I51`061<J0P0G4QP03`0H4aT06aHL01`G7@0G4QP07aXP01TD6P0F
4AL06aHM01lI8`0@2Q@0IV1Z01D?6`0C3AT06aDP034W<P0201L=5P0H01D;500K4AX05`dF01L=5P0K
4AX07Q@M01P>5`0E2a@05`dF01@<5`0A2AH05`lJ01XB7@0F3QT08AXR01lH80080@T0614H01/D6`0H
4AP04``C014;3`0E3a<05a4E0P0D3Q802@0H4QH0=Blc01TC5`0U7b<0;BL[051:CP0>20`06@hD01H;
4@0201P=4`0501H;4@0I3Q@0714G01H;4@0D2@l00P0F2a400`0A1P`05P/?01T>4P0201@93@0901L<
400E2Ph06a0D01P=4@0C20`04PL;01@93@0E2Ph050T=00<05@X>0`0F2`l0600G31007a@H01dB5P0H
3A407A8F01X?5@0K4AT071DL01<>5@0;2140;2Tb01LD7@0C3AL04`hE01@<4`0G31806a8G01H>5P0F
3aL05@hF01@=5@0B2a<04@XB018;4`805@hF01H05PlG01PA6@0I51/061HM01XI7`0J6B006A`U01`P
:`0N93407RHc02D^?`0W<d@0<d1A03e<G`0lC5`0?e1P04=DI01=GVh0E6Ee05IWN@1HJG/0Gg220P1R
LhL0501TMHT0HW:9061aQ01HJG/0D6=d04aPL013FFL0?UAQ03a@F`0bA4h0>DM@02`h@@0S;CH0:S4k
02<U;`0T8b/08R4Y028Q:00O7R@071TP0P0H5Q/0400K5QX06QDI01PC5`0F41@0:BDV02<O800H51D0
40`=00d92P0=1`T05`hA01D<3`0B2@`050T=01P=4@0O51P301<8308050T=00<05P/?01@93@0E2Ph0
0P0F2`l03P0E2Ph04`P<01041P0B1PP05@T;01L;3@0F2P`05@T;02DI6`0P51H06`lA01P<3P0B1PP0
30021`0B1PP00`0A1@L040@601041P020186200501<71`0A1@D04`L701451@0?0`<00P0D20P01@0A
1@D02P0001hB4P0D20P06@d=00805@T9100C1`L01P0K3`l03`<300P0000B1PH07Q8B00l30`804`L9
0P0D20X20186200401dA4`0I3@l05PX<01<72@804PH800L060h?01@:2`0G3@h05`d>02/Q8P0M4a@0
4@L800<04PP900<04`T:01<8300B1@d00P0B1@`0100A10/04@D901452@0>0PH200h2100700l31@0@
10@09ATK03HZ;P0G2`l04PH:00h21P0201862P0301<72`0B1PX04@D900804@D900<04PH:01<72`0B
1PX00P0B1PX301452@0F01<72`0B1PX03`<700h21P0@10P03P8601@8300F2Ph03`<700X00P0;0@<0
2@0100P0000I3A4050P<01lC5`0?0`H0404601<42@0<00805PL<00l21@@050D:00P05@H;01H7300N
4QH06PhB01<72`0J3Q805`/?024E6@804@D901004PH:01<72`0C1`/04@D900d2200N4a/0GE9J04a1
B@0A1Ph04PT?00h32`0C21006PlG00L0100:00L06@hE100?10P0500?10T03`@:00l42P0D2A004PL?
01053@0B1a0040@>01853`0?0P`04@@>01853`0C1Q0060/E01T<5P0E21804PD?00h12`0K3QP06PdG
5?ooool001_ooooo00@05P`=01@:2`0B20T040H70P0A1`P0500F30d02`8300l51P0M4a@020000188
2@0A1`P0KF=T079XJ@0J41402P4202dS900C2@X050X;00L0000E2``08ALH01X@4@0C1`T050P:0P0F
2P`0300E2@/050P:01<72@0I3@l05`/=00l31@0K3a40;20R02@H6P0G2`d05PX<01@82P803`<500@0
50P:01dA4`0K3a405@T;0P0C1`T01`0B1PP050P:00l31@0A1@L050P:01451`0D20X00`0A1@L00`0I
3@l060`>02`P8P0201`@4P0901X>400900005`/=01/?4@0D20X05`/=01<72@0<00805`/=00D04`L9
0P0B1PP0300A1@L040@60186200G2`d05PX<0186200J3Q0091PJ028F600J3Q005@T;01H:30<050P:
03X05PX<01X?4@0D2P/04PP901`B4`0J414050X;01<92P0A1`P060h?01D;300A1`P0:R0Q04i5B00T
7R0050h@018<3P0A2`d02PD6014;3@0=1`T04`d?01/E5`0O6A/03`T;01/E6@0E3a<03`T=01<=4@0G
4AD0618F01LA5@0I4aL06aDI024K7`0G4AD09b4U014=3P0@30d06QHG01/G600D41807aXN028M8@0C
3Q<03`X@024L8P0H4aX07aXP01LE6P0E5AL06QXL01/K7@0J6Ad07A`Q024P9P0L6b405QDK0P0J6B40
6P0M72@071dR024R9`0O82D07QhV020R:@0M82L08BD^01dQ:P0O8b`06B0Z01dT;P0O9S00;30k02L[
=P0U:C@072<]024X<P0T:cD07RL`01`U;P0H8BX0:S@m03<mAP0Y<c`0:C<m0P0X=Ch01P0Y=D40;3Y5
02lmB00Y=d@0<41?03=3DP80?TiM00P0>DUH03e:F@0iAe@0=D=@03=1C00fA4d0>4I?03E3C080=49;
0P0gAE00:00fA4l0<45;0393C@0dADl0=DI@03I7D@0gB580>T]E03M8DP0jBeD0>DYD03Y;E@0kCEH0
<dM>03=6C@0fBE00<dI=03A5C@0fAdl0<dA<03M6C@0hAdh0<d9903A1B@0d@DP0<Sm5034nA00b?dD0
<d1603I3B@0d@DL0=T=903a9C`0b?dD0:3Dk03=0AP0jB4l0=DA;03I5C00eA4/203Q7CP0303M6C@0f
AD`0=DA;0080=dI=00@0>4M>03A3BP0d@dX0=4=:0P0a@4L06P0eA4/0<d9903A3BP0gATd0=TE<03A3
BP0_?TD0=D9:034nAP0oC5@0;CY2038oA`0f@d/0;ca403U6CP0a?TH0<Sm703=0B00jAdl0<d9902hm
A00/>d80;Ca302`k@P0`?DD0<C]40P0c?DH0700j@d`0:S<l03DnA`0^>Cl0;CPn02lj@00]=Sd0=3e4
02Pa>00`=cl0;3<k02Xa>@0]<CX0;S8k02/b>P0[<SP09Bhc02@]<P0Y<3P0:S4i02D/=00X;3L0:B`h
028T<00Q8bl09BLc028V<@0Y<3X2020Y<P0N028Y<`0R:C409Rde02T]=P0P92X0;c8i01hQ:00b=CX0
8RD/03@h@`0`=400;30l02PZ=`0/;SX08B<_01lO:`0W9c40:2Pb01dK9P0O7RH0;2/c01lP:P0X:c@0
7b8[028T<00K7BT06alZ02@X=00Z;C`09bdk0P0Q9cD00`0S:CL07Ql/01hM:`0202TX=P0c01`K:@0U
938092<a02<R<00V9C<06aXX01LF900Q82h07b4^020O;@0O7R`09B@b02@R;`0P7RX081hY020M:00P
7BL0924Z02TS;@0X8c409B4`024M;00J5RD071PV01dJ9@0N6bH07Q/T01lL9@0Q7RD071XO01XG7P0N
6b@0920^02LS<@0X93409B8]02<P:`0Y9S00:RL`028O:00N6b<07Q/R01/H7`0N6R<07QPT00d74`0U
7bX0Ee5K02LQ:`0D3aL06A@K00805a8H01@06A@J01`G7@0J5A/06QDK01D@5P0I51X05A0F01LB6@0>
21808Q`V01D?6@0A2aL09R0/01H@6`0n=3l0<2H_01/A6P0L4Q/06a4J01L=5P80718K00d06Q0I01H<
5@0D2Q<04`TB01dE800H41/05`lJ018;4`0;10`04@XB05YCFP0[92/03@H=00<04@/?00h04P`@01<=
4@0G4AD06aDI01@>4P0500<02P@801<=4@0M5a/02@<701lI7@0A2`l060dC01D:408060dC00D05@X@
01P=4`0J3aD05P/A01L<4P0201/@5P0901D:400A1PX04`P<01052@0B1`/060dA01H;3`0M4QH06PlC
00<05``@00@05P/?01@93@0D2@d05@X>0`0F2`l04`0D2@d05P/?020E6@0M4QH05``@01`A5@0G3180
2@0700/42`0F4AT030TD00<02`0A3QP03PPB010;4P0A2A0050T?01L>4`0E31D00`0E3QH00`0C31@0
4P/C01D>5P0201@=5@805a0H02d05Q4H01PE7@0I62006ATR01TL9@0L82/08BLd028Z=`0W<4409311
02TfA`0b?e00<d=C03i@GP14EV@0Bee/04mPL01BHg<0E6Ef05UZO01KK7h0Ffao05i_P`1LKH40G6f0
05Y[O@1CIWL0Bem_03mEH`0mDf00?U9M03=5C`0a?dP0;SY302La>P0V;CL09RPa02HU;@0T8b/08b8Y
024P9P0M6R406QPM01TG700H4aL00P0G4QH03@0J51P061@E01DA4P0B3Pl0510A01LC500H4Q@060lB
01L>4@0F3A0050T=01462P0?10P00P0E2Ph201@93@0301<8300D2@d050T=008050T=0`0C20`30145
1`0901041P0B1PP05`/=01<72@0?0`D03@4301041P0D20X05@T;00H04PH8100A1@L01@0C1`T050P:
01@8200@10@04PH600804@D500T06Ph>01<71`0C1`L03P8203L[:`0F2PX07Q8B01H:2P0E2@T00`0C
1`L01`0D20P07a<C01dA4@0B1PH05`/;01P<300:00001P0C1`T00`0K3a405PX<01@82P0301862007
01@:2`0C2@X05P`=01`B4`0e:b`09adN01<92P0301882@030147200A1PX040<;008040<:00D04@@;
01452@0A1@T05@T=0186200200l31@060104100E2@/07a<G00/00`0?0`L03@450P0C1`/00`0B1PX0
4@D901042002010420804@D90`0B1PX01@0C1`/03`@700/00`0<00@03P8600804@D901@04`L;00d1
1@0>0PH03P8601@8300O4aL04`T;02lS9`0800003P@600/00`0H3100308400h21P0D20`0200001L;
3`0>10H03`<7010420<04@D90P0B1PX01@0>0PH0308401/?4`0E2@d050P<00<04@D90P0@10P03@0A
1@T01`0201/@5P0c:2h03`@:01D:400B1`d05@X@01T>500A1P`02`060146300>10T00`0@1@T05@0?
10P03`@900l42P0?10X05P/B01873`0?10`04PH?00l33@0E21804@@>01D84P0F2A<050LA01P;5@0I
31H05PTC01853`0900H03`8<00P01@0Dooooo`006oooool06`0E2``04`T:01061`0A1`P04`T:01@:
2`0;0P<060h?01/A4P0L4Q<04`T:01882@0E2``08aTJ01lE5P0A1`P05@/<00d4100@1PL050X;00h4
1@0@1`L04@L800d4100B1PP04`L901@82P0301D92`0903T];`0;0@803@4301D92`0C1`T060`>01H:
300@10H04PH8008050P:00T05PX<01<82@0N4Q@06`lA048f>00E2@/05`/=01D92`0G2`d00P0D20X0
1@0C1`T04PH801451`0E2@/05PX<00805@T;02T040@601hB500D20X05`/=01lC5@0B20T05`/=075U
I`1lL78060d>01lC5@0K3a405P/=01<82P0@1@L05@X;01H;3@0?10D06@h?01@92`0C20T05P/=01T>
3`0L4A808ADG01T=3`0R5QP07a<E01D92`0G2`d06@d?01X>400G2`d04@D701@82P0G2`d05P/=01H<
3@0I3a005P`=0147200201P>3`0801D;300D2P/06@l@01T?400C2@X07aHI00h82P0E3a4201LA4`0?
01/E5`0D3Q005@lA01<=3`0@2P`05Q0B01D?4@0G4AD050hB03dg>`0J51P081XN01<=4@0@2Ph06A<G
0080618F02<04`dA028L800H51D0510A01lK700U8B807QTL02@O8`0@2`l07APM01D@5P0G4QP06QDK
01XH7@0L6Ql05aLI01hN800A4A<06a/N01hM8P0I61h08R4W02<R:00L6b<07QdU020O9`0N7b@0824V
01/L8@0I6B406a`T01XM900I7BH0:blh02L[=002020W<@0X02<Z=00Q9C008bLb02L[=P0R:C<09B`f
02L^>00/=Ch0:c@m02H_>00S;CH0:cDn02Xd?@0Z=3h0;3Q302/h@P0/>4@0<d5=03U7D`0e@U40<T9A
02dmC00a@E00<d=C03=3DP0kBE@0=TA@034oBP0d@Td0;ce703E3C@0kBE<0=49<03I4CP0jB5<0=D=>
03=1C00_@4X0=4E?03Y;E@80>DYD01D0?e1J03e>F00eAU00>DYD03Q9D`0lCEL0?e9J051UJ`2<WjD0
BEaS03=6C@0iBU80=dQ@03E6CP0iB500>TUA03E3B`0gA4`0BEIM049?E@0d@DL00P0iAT`03P0hAD/0
>dQ>034nA00a?T@0=dA:03E2B00gA4X0C5YP04MFG@0eA4/0=dI=03E4B`0c@TT0=TE<0P0eA4/01`0h
Adh0>DQ?03]:D@0c@TT0=4=:03I5C00b@DP00P0fAD`04`0eA4/0CeiU03m>E@0eA4/0>4M>030oAP0a
?TH0?4UA06]hP00lBE40>dQ@02llA00b?dL0<d1802llA00`?DD0:cQ0038oA`0c@TT00P0a@4L05P0b
@DP0<3m6030mA@0c?DH0;SQ102li@P0j@d`0:S<l03DnA`0`>d40<Se302/f?00X<CP0>D99034j@@0`
=cl0:C0h02Xa>@0]<CX0;30i02lf?P0[<SP202Tb=`809bhf02H0;3<l02/_>P0/;c/092Hb02T[=`0X
:SL08BDb02L]>P0T;3P08b`f02@Z=@0S:C@092/d028V<00R9Rl08RD]02T/=00R9Bd08bH^02X]>00W
:SL09bXf02/]>@0R8bl0=3E103loB@0K6R@08R4Z02HS;@0N72@06aXR02<U;P0V:C8082</02@V<@0O
8bh07B4/028V<@8092Xg030082Hc01`T<@0N93809BHc024P;P0U93807ah/01hM:`0S8S008R4_02HU
<`1;BUP09RDc01@C8@0U938071h[01dL:P0P7bd0:BPf028P;@0R82`0;2Xe02LT;`0T8B/0924Z024K
9@0U82d09b<c02DQ<00O6bX07QXX01lL9`0O72H06aPQ01/H7`0S82H071XO01TG6`0K62006aLU01`H
9P0L62D07Q/V01dJ9@0N6bD07a`U01hK900M6R8201hK8P0801lJ900I4al071HR024K9P0L5R0050hH
01dH800K5Qd201XE6`0301`G7@0N6Al05a8H00806A@J00d081/Q01PC6@0D3aH06Q@N01<=5`0G4A/0
7ALS014;5`0H4Qd05`lJ02LO9`0H3aP071@L00806Q8J01@071@L01<:4`0H41P06Q4J01L>5`0H41P0
6A0J01L>600F3AL05`hG01P?600K4QX07aHN01P@5`0H41H0610E01<<400H41@04`dA01LA5@<06A<G
00L05Q0D014;3`0F41@06aDI014;3`0B31005Q0D00805P/A00/05``B01P=4`0F2a405``B05A9C`0Y
7R@05P/A01dB600N4aT05@X@01T>4P0201L<400401lD600J3a<04PL;01<830805@X>0P0F2`l0100C
20`050T=01D:3P0E2Ph201H;3`0F01L<400B1`/050T=01/@500H3A404PL;01@93@0@1P`06Q<J01dF
7P0K5b008b0[01<@700B41/04@dF01@>600A2Q805P`D01L=5@0E3QH04``D018;4`805PlG03T030L=
01PA6@0E3QH05@hF01L@600E3QH050`F01LC7@0I5R806aTU01hM:P0P8Rl092Tg028Y>@0S;3d09Bm0
02`hB@0a?Tl0<41?03Q:E`0oDEl0A5ET04EGIP1:Ff/0Cf1a059SM01EIWP0EVMj05QYO01GJ7/0EFIh
05=TMP1AI7D0C65`041FI00kDEh0>DeI0394CP0`?TL0;c]402hh@@0/<cd09BLa02<R:P0Q82P081lV
01lN900N6b807A/P01HD6@0E41@06aHJ018=4@0_:Bd0IF5R03Da<P0G4a@00P0A3@h02`0D3Q005`hA
01P?4P0I41<06@hB01L<400E2Ph05P/?01D:3P0F2`l05@X>00804`P<01405P/?01D:3P0C20`04@H:
01872`0D2@d04`L901D92`0F2P`050P:0186200D20X06@d?01@82P0F2P`04`L90186200201451`07
01<72@0@10H040@601<72@0A1@L050P:01<72@040186200@01@8200B1PH04`L701<71`0D20P06Ph>
00l30`0L4100DdM7040d=00I3Ph07Q8B01<71`0E2@T04@D501X>3P804`L700h050P8040d=00`92@0
4`P801D92@0X71`04`L902LK7@0/82804@D701P<3P0?10D050P:01<72@804@D702d04`L901D92`0D
2P/040H701H<3@0=10@06@l@01H<3@0A20T04PP901L=3P0@1PL04`T:00`31@0B1Pd030460185300B
1P`04`L;00h31P0J3Q805@T;0186200C1`T040@400h41@0D20`03`<701862P0>0PH040@801452@0I
3A4030840105200>0PH03`<701<72`0G2`l04@D901862P0@10P04@D901@8300C1`/00P0B1PX201<7
2`0N01452@0?0`L050P<01@8300<0@@03P8601L<3`1ODeL0:alS01872P0<0P@05`/?01<72`0`9BT0
4PL;00d21P13>3`05`/?01<8300A1@T04`P<01@93@0@1@T04@H:00l31`0A1@T050P<024E6@0I3A40
40@80P0A1@T04@0B1PX040@80104200B1PX06@hD00d3200B1`d02@040146300@1@/030<701@93`0G
31804@H<01<83P0=0PP040D900804@H:01D040D901052P0@1@/04@H<069GGP0D2A4040D=0188400=
0@/04`H@01443P0E21405@PB01443@0@0`d04`H?01443P0B1@h040<=01D84P0A10d05?ooool001_o
oooo00@050X;01<92P0B20T04@L80P0B20T01@0?1@H05@/<01dC500I3a003`D600L04PP91P0A1`P0
200B1PP04@D701451`0B1PP05@T;01L;3@0S5aT04@D70P0E2@/00`0D20X06`lA01<72@020186200=
01<72@0D20X05@T;0186200H30h04PH804Lk?@0=0@<05`/=01H:300E2@/050P:01<72@0201862006
01H:300@10H06@d?01`@4P0C1`T060`>0P0F2P`02`0H30h09QXL02<G6@0H30h06Ph@01H:300<0P<0
4`L900l31@0V6ad03`D600804@L80100200001P>3`0=0`@05@/<01@:2`0:0@8050X;0147200?10H0
5PX<01@82P0E2@/05PX<01041P0?10D04@D70P0F2P`00`0J3Q005`/=01@92`0201L=3P0401H<3@0E
2``050X;01@:2`@05@/<01T050/<01<:3@0A2`d040X<014;3@0C3@l05Q0B014;3@0D3Q00618D01/E
5`0L5QP04`d?018<400C3A40=2hb01<=4@0I4aL05Q0D014;3`0G4AD05@lC010:3P0D3Q806A<G0080
5Q8C0P0K5aP08`0F4A@061<G014<400Q72405a8H01/F700G4QT08R0U00/:3`0T92H0:b/]030`<P0I
6A`071/P014@5P0M728081lU01`K8`0M72@09B@/01hO900M7R<071dR01dM9@0L7RD06ahU01`P:@0V
:S<09BTb01/R;00H7bT07bH`02@X<`0X;3L0:Bdh00809B`f00@09bhh02</=@0T;CH0:34j0P0U;cP0
2P0W<CX0:C<o02diA@0]>DD0;3Q40390C@0hAU<0=dAD0392D@0eAE@203E5E@0903Q8E`0d@T`0<T19
0390B@0d@Td0;C]603A2C@0mBeP0=TAA0080>TQC01D0<d5<0390B`0iBU@0=DI@03e>F00lCEL0=TMA
03]<EP11DU`0BEYT03I7D@0gB580>daF03Y=D`1CJ6d0X[Fk04mRJ00iC580?4eE03Q9D@0gB5000P0i
Ae004@0gADh0>4E>04eJH`16DeT0=45703]8CP0jAdd0>4E;03]8CP0d@DL0<d1603I3B@0e@TP0=dA:
05=QI`1>GF@0=DA;0080=4=:00`0=TE<03U8C`0eA4/0=DA;03I5C00gATd0>DQ?03I5C00a@4L0=dI=
03a;DP0b@DP203A3BP0<04UHG`0b@DP0;3]202Xi@00b@DP0?daD03E2BP0kB5008c0h02`i@@0f@d/0
<3e50P0^>d<01@0b?dL0=459038oA`0_?TD0<3m60080<T5801D0<D17030mA@0_>D8092hg030j@`1=
EUl0<ca502`e?P0/=cd0;cY003<nA00/=C`0;SLn02L`=`0[<SX09bhf02P_=`0/<3T0;c<l03@k@`0Z
<CL00P0Y<SL02P0Z<CT0:C0i02P_>@0[;cX0<CA002h`?@0_<D00:B/j02@W=P0Y;cd202H^>`0802X`
?P0Z<3`09R`h02T]>@0W:SD0:Rdf02LZ<`0O8R/2024S;`0>02la?P0Q8c009bTe01XJ9P0U9Bl0;Bdg
020O9`0T8b/07AXS02PU;P0c<SX08B8Z01lR:`0M82T202<V;`0;01dQ;00T:3<09BTd028X=00O9C40
6Al[01LM:@0L72X071/Y01lN;00K6RP00P0M72X08@0W9S@06aXX02h]>`0E52807ah/02d/>P0N82d0
?Ca:03`kB@0H5bD08R0]02<Q;@0W9C00924/028O:@0P7BH07aTS02<N:`0Q7B/07QXY01dI9`0N6bH0
81dX02@Q:P0P7BH07Q/R01hL8P0G5AX061HK01dJ8P0O6bT07QXX01/G900201hK9P0401`I8`0J5b00
61DN01LD70805a@K00/06A@N01PB7P0J52007aTT01`F800K5Al07QPQ01dH7`0L5ad06aHL01TD6P02
01PC6@0501D@5P0J5A/07QTO01TD6P0J5A`00P0F41X04@0E3aT04`dI01@>6P0D3QT07QHQ01D>5P0B
2a<06A8J01dF7P0E3QH091dU02TR:P0C31@07aPP01dF7P0H4AT05`dF008050XC00/05`dF01P>5`0I
3aL06a4I01XA5P0H3a@05PdB01P?4`0H3a805Q0D01LA5@0201XD600401H@500?2@d04P`@018<4080
4`dA0P0D3Q8301<83P<050T?00`0G55G02LL8P0A1P`06@hD01P=4`0D2@l06@hB01L<400J3a<09AXN
01X?4`0H3A4601H;3`0301D:3P0G31005P/?008050T=0P0F2`l201D:3P0E01H;3`0G31005``@01T@
600?21002@@;04i;E@2?SIX0G5YW028P;@0B3aX04a0I014;4`0G3AD04`TA00h73`0A2Q805a0H0109
4@0B2a<09AhV00804P/C01T04``D01D>5P0E3QH05PhI01TC800J5R@06QLU01TH9P0K6RX0828b020V
=P0N9CL09Bho02`hB00`>dd0<T5?03E7D`0iBeT0?e5O049DHP15EVH0BEYZ04aMK@1>Gg40DV=e0080
DfAf0240DF9d04eNL019G6d0A5UX03mEH`0kDEh0>DeI02doB@0_?DH0;SY302Xd?@0^=Cl0:2Xd02DT
;00S8RX081lV01`K8@0M6R407A/P024O900R7B4050lC00X52@1RG600n_Kg07IbL`0L61T06aLH01HB
4`0B30h060lB01L>4@0F3A000`0E2Ph0300H3A405``@01T>4P0E2Ph040D901D:3P0F2`l05@X>0187
2`0A1PX04PL;01@93@H050P:00<04PH800`00P0@10H00P0G2`d00`0?0`D05@T;01<72@0201/?4@03
01<72@0E2@/04PH800D04PH81P0B1PH02P0C1`L0200003da<@0P51@06Ph>00`0000B1PH050P800/0
000M4A4301<71`0;02XN7P0F2PX04PH601861P0N4Q8060`>03/_<@14>3X06Ph@01lC5@0@10H00P0F
2P`05`0E2@/04`L901<72@0E2@/040H701L=3P0E2``04`T:01L=3P0<0P<06Q0A00/10P0<0P<03`D6
00`20`0G31004@@<020C6P0G2Q402P0401T=4@0E2@d05`/?00804@D701L04PH800l30`0@10H04`L;
01862P0A1@T040@800l31`0D20`0200001/?4`0H31006`lC00P0000<0@@0200001452@0H310040@8
01lC5`0=0`D04@D90104200300l31`0C00d21@0C1`/05PX>00h21P0A1@T05@T=01452@0X72004`L;
00`1100;00<04PH:00/1100?10P02`8400d21P0R5a/03@@600L0000200T00P0900X00`0@1@T05@X>
00l31`0E2@d04@D901@8300@10P0304400H04@D900P02`0600`11`0A1P`04@H<01D:400B1`d040D;
014630<04PL=00h04@H<00l4200A1PX04PL;01052@0@1@X04PL=04Pm@`2ERY40:AhV01X?5`0B1Pl0
4@D?01D84@804PD>0P0C1Pl0100A10d03P4:00h12P0A10d201@7400300l22ooooooooooo01;ooooo
000Kooooo`@04`T:00P04PP901061`0B20T04@L801@:2`0C2@X040H7014720H04`T:0P0B20T40147
200=0186200@10H040@601451`0D20X05PX<00h41@0K3a405@T;01451`0D20X04PH801<72@020186
200901<72@0D20X05@T;0186200E2@/03`<501hB500<00805PX<00805@T;00H050P:01<72@0B1PP0
4PH801D92`0A1@L201H:300501451`0C1`T05PX<01H:300D20X00P0M4A<0400@1@H04PH801D92`0I
3@l0:AdO01L;3@0N4a@060h?01X@4@0C2@X01`0002LM7P0>10D05`d>01H<3@0>10D201L=3P0:0146
1`0D20X060`>01L;3@0B1PP04`L901T=3`0M4A<060`>01<72@8050P:00@050T;01H<3@0F30d05P`=
0P0E2``01`0A1`P04`T:01H<3@0F30d05@/<01882@0F3@h00`0D3Ph0>`0C3@d04P`<018<300A2`/0
5a4A01`F5P0H4Q8050h>010:300L5QP04@/=01PB500G4A<06A<E010:300E3a405Q0B018<3P0D3Q00
618D01HB4`0I5AH081`M01`H6@0E4A<06QDI01@?4`0K5Q/061<I01/F700F4AL081hS028Q9P0N7b40
<C8d01`M7`0H6A`04A8F01<D6@0I6Ql071dR01/K8`0M7BD08b<[01XK800L7B807QlT01lO9`0N82L0
7B0W028V;`0S9c008RH_01dT;P0K8R`06R4[028V<@0U:C@09RXe00808bXd00`092/e020Y<P0U;SL0
92df02Pb>`0S;CH0:38k02dg@`0_>dT0<3a:02lkB@0_?4`2034nCP0T0310D00eAED0=TIF03A4E00g
AeH0<3i602lnA@0gADh0<T1;03I4D@0gAE80?4UH03M5DP0kBEH0>dUD03=1C00a?dX0?TmI03M8DP0k
C5H0>DYD03I7D@0jBeD0=dQB04MHHP0hBE<0>T]E04AEG`0nDEL0<dQ;04ePI00eB4d0<TE;0352B@0a
@TX0=TM?0`0gAE00100g@dl0>dQA03Q5B`0c@4H303I3B@0903Q5B`0`?D<0;3To038oA@0d@DL0=T=9
03]9D00lBe80>4M>0080=4=:00T0=TE<03Q7CP0fAD`0=4=:03=2B@0eA4/0=dI=049AF01:FF000P10
CeH0100b@DP0;Se402hmA00gATd203=2B@0n02hmA00b@DP0:CHn034nAP0b?dL0<Ci603Q5C@0/>D40
<d1802llA00^>d<0=D9:03I3B`0^>d<0;3]202dl@`0_?TD0<3m60350A`0c@4P0>dE>02`f?`14CUL0
KWN004]DG@0f?dP0<Se302hi?`0lAdd0=3e402Xc>P0X<CP0:2lg02Xa>@0V;CD0:Bdf034e?P0_=Sh0
9bhd02`e>@0/=CX0:S4i02P_>00Z<C/0:Rhj02d`?P0^<3l09RLi02DV>00[;Sl0;39202@[>`0T;3T0
:S0n02P^?00O9C40:Bdi02X]>@0[;CT09RPd020R;P0S9C4205YLJ00;01XL:00N7RX0;2`f01lO:@0M
6bD08b0Y020M9P0M6R40:2D/03hk@P0O7b@00P0M7BD03P0W:3009bXa024T;@0S9Rl08RH_024U<00M
8B`061`W01HJ9P0I6RL081l]01lN;00N7B/07ah/0P0R8Bl0?@0];3X0:bXh02HU<`0R8Bl06aXX01TK
:01mO8X0Ogj<01lN;00X9S<0:RPd01`J9@0Q7RT08b0Z01TF7`0L5R008A/V024K9`0N62H071HR01hH
8P0Q6bD09b4[02<N9@0N6B007APO01XE6`0K5Q`07QTR024K:@0O6BL06aDR020J9P0R72P08adX020J
900K5Al06Q@M01/F7@0J5A`061<L01`F8P0N62@071HQ01hH8P0L5R006aDN01dH7`0M61h06aHL01XE
6`0H4aT06aHL01TD6P0K5Q`071LM01TD6P0J5A`06Q@N01TC7@0H4Q`00P0G4Ad07`0H4Qd06Q8M00l8
400S72@08AXR01dF7P0N5al0PGZ2089kP`0N5al04``D01094@0<1`d07A<L01X@6@0G3AH060hF01T?
5`0F31@05`hC01H=4P0D2`l04`X=01D<3`0F3A005Q0D01D?4`0F41@05a4E01D?4`0@2Ph00P0B3102
01<=4@8050hB0P0F2a4401D:400>02PM8`0E2Q004`P>01L<4P0E2Q005``B01H;3`0G31005P/?01dB
5P0F2`l0714E01L<400F2`l201D:3P0501H;3`0G31005``@01P=4@0F2`l00P0C20`06@0D2@d06a0D
01H;3`0D2@d05@X>01T>4P0K41@05@dD01H?5`0Q72<0X9fW0?omo`2g]l<0<C0m01<@6`0F4a`05Q4H
01PA600E3QD050dE01L@60090PX081TQ01@=5@0;10`00P0D3AD06@0E3QH06A8J01`E7@0N5R406aDT
01/G9P0J5RH05aHV01TH:00M7bl07R@d01lV>00U;Sl0:cM702hjBP0_?D`0;d5=0353C`0jC5P0@UAP
04=EH`13E6<0AUMW04UJJP1=GVl00P1@HG<07P1>Gg40BEY/04EHJ@12EfH0@5IT03iDH@0lD5`0:C]5
02/i@P0`?4D08bdf02H]=`0W:C<09bH^02HU;@0N7B@061LM01XG7P0G5AX05A<H01D@500D3a<04@`@
03Xd>02:QXL0>3@e00l;300C3a0040`=01@>40<05Pd@00<05P/?01D:3P0D2@d00P0F2`l02P0G3100
4@H:00d21P0D2@d05P/?01D:3P0B1`/04@H:01872`0D2@d601<72@0801T=3`0E2@/02P000186200D
20X05PX<01L;3@0B1PP202<G6@030186200G2`d04PH800D04PH81P0B1PH06`0G2`/06Q0@01H:2P0F
2PX050P801861P0C1`L050P800T0000L41004`L701D92@0=0@406`l?00l30`0D20P040@401861P0@
10H07a<E024E5`0?0`D040@600X0000E2@/05PX<01D92`0201<72@0P01D92`0>10D06Q0A00/10P0F
30d07aDF00X00@0>1@D0308300l51P0J414060h?04<h?00J3AD0QgZ1071SJP0K3QD03@4500X00P0C
1`/04@D701041P0A1@L04`L701@82P0C1`/04PH:01452@0@10P03`<700`2100E2@d200X00P0301/?
4`0D20`05`/?00806`lC00H040@800d11@0C1`/06`lC01@8300B1PX201452@0301862P0D20`04`L;
00<04PH:01T04@D900d21@0H3100300401452@0?0`L04`L;01872`0:00<04PL;01H;3`0D2@d02`84
01D:3P0N4aL05``@00h31`0D2@d03`@800l31`0F2Ph050P<01/?4`0H31005PX>00H04@D900/03@86
01462P0=0PH04`P<00d21P0=0`H0304500l4200B1`/03`@800d21P0201052@0?01872`0C20`04@H:
01462`0C20h08QLM034V;@0?10`05@XB00d32P0B1Q0050L@01442`0>0@P040<:00804`H=00H04@@;
01032P0@0`X04@@;01032P0=00LDooooo`006oooool01`0D2P/05@/<01D;300D2P/04PP900l51P0E
2``00P0B20T201D;300301061`0B20T04PP900@04PP900@050X;01<92P0B20T04PP90P0A1`P03@0A
1@L050P:01H:300F2P`04`L90186200F2P`04`L900l31@0D20X05@T;00l41@0C1`T00P0B1PP02`0C
1`T050P:01D92`0B1PP03P8401@82P0>0P@06Ph@01<72@0E2@/050P:00804`L90`0B1PP01@0J3Q00
5`/=0186200L41804`L900805PX<01l040@601451`0B1PP040@601dA4`0L418050X;01@82P0B1PP0
4PL901482@0<0P<04@P901/A4P0?1`P07A<D01@:2`0<0`@050/<00h41@0K4Q<05``>00l31@0D20X0
5PX<00d10`0C1`T050P:01451`0B1PP060`>00805@T;00H05P/=01@:2`0E2``05@/<01H<3@0G3@h6
01D;300301D<3@0C3@d04P`<00804@/;00`04P`<01/E5@0C3@d04`d=01H@400B30`06aDE01@>400G
4A<04`d?01/E5`0H4Q@2014;3@0601D?4@0K5AL0618D01H@4P0H4Q@071PI0P0G4a@04`0K5aP06ADG
01/F6P0O6Qh05Q4F01TD6P0M61h06QDL01PF6`0P7b@051DG01lP8P0D5AL07QlR01hO8`0O82D07QlT
01`M8P0K6b<00P0L72@02@0H6Ah06a`Q01`M8P0L72@07b0X024T:`0P92d08bL`028V;`0201lV<004
020W<@0Q9C008RHa02@X<`808RTc04008BPb02L`>@0T;CH092df02`f?`0X<S/0<3Y402hhA00[=dD0
;3Q602diA`0]>TX0;S];034nCP0b@U80>4QH03E5EP0_?e00<41?02hm@`0X=c`0<d99034oB@0oCEX0
>4ED03U6EP0hAED0?4YG03Y8E00b@4/0<Cm:03I7D@0b@dd0=TMA03Q9D`0fAe40>DYD03A5C`0^?dT0
?TmI03E6D00iBU@0AUUO03Y?D@0_@TH0=TU=03iAEP16Eeh0>T]B03M8D00iAe80=TA@03U7D`0hA540
<Ci703A1A`0gA4X0>TM=03i;D@0jAdd0>DI<03A1A`0]>T00<Ci40P0e@TP0800d@TT0<3m603A3BP0k
BU40<T5803A3BP0lBe80>DQ?03I5C00c@TT0=4=:03M6C@0`?dH0EFA[03]:D@0eA4/0>TU@02hmA00_
?TD0=TE<0350A`0_?TD0=4=:03=2B@0hADd0=459049?E`1LJG40>4E=034nAP0e@TX0=4590P0f@d/0
0`0e@TX0;ca402hmA00302dl@`1A02hmA00b?dL0<Sa502Xd?@0_>D80BE9K03HoB00]=Sl0=D1603@o
A@0f@DL0;SLn034j@@0^=ch0:S4i02lf?P0U;3@09b/d02lc?00W;S@092/a02/d>00/=CX0:2lg02L^
=`0[<S`0:2`h02P[>P0X:CX092Dh02//?`0c=TT0:2e002<Z>`0S:SX0:2hn02`b@@0^=480:2/j02/^
>`0X:SL08bDa020R;P0Q8c00J6Ue06EVLP0V9c<07alZ024P:`0P7bT0:2L_02HS:`0L6B409R8Y01hJ
8@0U8RT08R0U01lN8`0O7b@0:RT_02/[<00S9B/07b4W01lP:@0N8BT07B4Y01/O:@0K7RP06a/X02LV
=00O7R`08R4_01hM:`0R8Bl07A`Z02XY=`0Q82h09B@b02<R<00L6bT06adZ00808B0^00P07Qd[01XH
9@0O7BT04Q0K01hK9P0b;cT0:BH_02LQ:`808A/T01X07aXR01hH8@0L5Ql071LO01`G7P0K5Qd06aHN
01hI8@0P6R<07QPQ01XD7`0L5R@07ALU01`F8`0O6BD07QPT02@N:@0U7bT07QPR01`G7`0O6R4071LN
01hH8P0V82`08adY01TC7P807ALQ00<061<K01XE700L5ad00`0L5ad01P0Q72807aXP01/F700H4aT0
5a8H01PC6P806Q@N02806A<M01LA7@0G4Ad0618M04Y3CP0O6B4071HN01LA600K5Ad08A/S02LQ:00/
9Rh04`dD020J8@0D3QD050lE01@:4`0F31@05@XC01H;4`0J3aL05`dD01T?5@0H3Q@05`dA01H<400H
3Q406A0C018<400A2`l04P`@01@>4P0F41@050hB0P0B310201<=4@8050hB0P0F2a4401D:400701H;
4@0C20h05``B01P=4`0E2Q0060dC01@93@0201<8300501dB5P0E2Ph05P/?01D:3P0D2@d00P0C20`0
2P0D2@d05@X>01D:3P0G31005P/?01@93@0E2Ph05P/?01/@500G310201D:3P0E01L<400G3Q<050`D
020J8`0/9S00R8F@0=7Ae`2LVjP092@`00d;5P0C41/04P`E01H?5`0H4AP0GEIN01dF7P0N5al0EDiF
02@M9@0@2a405@hF00804``D01P05PlG01/D700L51l0610Q01/D9@0L5bT071T[01hM;P0P8S<082Hf
028W>P0U;Ch09c1102Hb@P0W=T@0:ce80312CP0fB5@0>deI03mAG`10DV00@E9Q04AEI@19FVX204aM
KP0=04aMK`19FV`0AEQY045FI@0oEF<0?UAQ03Q<F00]?dT0<3i702Pd?@0W<CX0:2li020R;00202DT
;00N01dL8`0G5Q`06aPO01`J7`0D4QL05Q4E01lJ7P0R7B405Q0D01LC500I5AH06aLH00h:2`0D4140
4`d?01D<3`0F3A005`hA01L<400F2`l04`P<01P=4@0E2Ph05``@01P=4@0D2@d05P/?01D:3P0D2@d0
4`P<0P0B1`/00`0C20`04`L901<72@0401<72@0800`10P0G2`d050P:01D92`0@10H05@T;01041P0A
1@L201L;3@0301451`0@10H04PH800D04PH81P0B1PH0700=0`<08aLG01@8200K3`l040@401T=3@0B
1PH05PX:00l30`0Q5AD05@T901<71`0B1PH05PX:01@8200G2`/06Ph>01L;2`0L41804PH800h2100E
2@/04`L901X>400E2@/060`>01L;3@0E2@/201@82P0H01@:2`0C2@X08QPI01882@0D2P/060h?01@:
2`0U6a`0:AlP0107200M4a@0@CHj01863@1@@dX0=RT`01452`0A1@T060`@01452@0@10H03P840104
1P0G2`/05`/=0P0B1PX201452@0@0104200L4A@0N6a`01/A4`0H31004`L;01862P0D2@`05`/?01X?
4P0B20X060`@00l51`0G2`l050P<01862P804@D900/04PH:01<72`0@1@P04@L901<72`0@10P03`<7
01@8300B1PX040@801@8300201862P0>01462@1?ADP050X=01<9300?1@P04PP<01L>4@0=0`L02`44
01<93@0D2Pd04@L:01P<400K3a<201452@0300h21P0=0PD04@D900D04@D900/04PL;01L<400;0P@0
50T=00/1100F2`l04@H:01D:3P0G31004@H:00d21P0201462P0G01872`0D2@d04@H:0187300C20h0
5@X@01<93`0F2a<03`H<01463`0?1@`04PD>01032P0A10/04`H=01@73P0B1@`05PT@0185300?0PT0
4`H=01hA600W6R405?ooool001_ooooo0P0F30d01@0E2``050X;01882@0@1PL03`D600804@L800<0
50X;01D;300<0P<01P0A1`P201@:2`0A01<92P0B20T04@L80147200A1@L05PX<01T=3`0H30h04PH8
01041P0C1`T050P:01T=3`0@10H03@4301H:300C1`T00P0B1PP02@0C1`T050P:01D92`0C1`T03@43
01D92`0C1`T05PX<00P0000201<72@@04PH801T050X;01041P0P51H03@<400l31@0@10H04`L901@8
2P0C1`T04PH801<72@0D20X030020186200j;S00710B01<72@0B20T06Q4B00d41@0E30d071<D00H0
000<10@060l@00803`H700P091/L04@k?00H3Pl03`<501P<3P0^8R@07A4C01041P805PX<00L06Ph@
01hB500A1@L04`L901T>400C2@X050X;00805@/<00d05P`=01T?400G3@h05@/<01@:2`0E2``060h?
01@;300A2`/040X:00l92@0B30`05@l?008040X:01D050h>01D?3`0C3@d05Q0@01XD5P0;1@L06aDG
00l92`0F41805@lA01PB500E3a4050h@01<=3`0G4A<09b4S02dY:P0P71d05Q8C01`H6@0L5aX00P0I
51P03`0O6Ql07QTO00l:400F4AP05A<H01TH7@0G61X071dO01PI6`0T9BP04a@H01LH7@0H6Ah06AXO
01TI8@0201XJ8P0701TJ7`0N7b@07QlT01`L900M7RH08B@[01PL9@02020T;@0601XQ:`0M92h09Rdg
02HZ=@0U:C@09RXe0P0V;CL02@0S:S@08b`e020Y<P0e?TL082Xc024[=00V<3X0:S=102Pd@P0202Lc
@@0I02XgA`0]>TX0?4UJ03a<G011DF40>dYM0391E00b@U40<41202ln@@0b@DP0=49<03a9F@0gA5@0
=D9C03E2DP0iAUH0=TAA030nB@0b@4/0=dQB03E6D00fAe40=dQB03I7D@0203E6D00I0352C00gB580
=TMA02dnB00lCe@0<TM80354B00gBTh0=TU=04AEG00dADd0?4eE041>F@0iAe<0>DMD03Y6E00e@D/0
=dA:03U6C00oC580@DiD03Y7C@0f@dT0=45702hk@@02034nA00:038oA@11CeH0>dYA030oAP0gATd0
<T5803]:D@13DUT0>DQ?03I5C080=DA;01L0=dI=02`k@P0eA4/0;Se403=2B@0[>T40;Ca303I5C00[
>T40<T5804UHG`0_?TD0=dI=03I3B`0lBE40<d1803U6CP0_?4@0?T]C03A1B@0gA4`0>DI>03A1B@02
034nAP030350A`0`?dH0;Se40080;3]202P0;ca402hh@@0c?DH0;3Ho03<lA@0]=Sl0;SM002Pc>@0`
>d40<Ca202Tb>@0`>D0092dd02D/=00Y<3P09bhf02X^=`0_<c`0;3<i02D/<P0X<SD0:34f02H]=@0W
;SL0:c8l02P[>P0d=TL08R<e02X[?`0`<DH0<SA902T^@@0Y<4809B`n02D[>`0Z<400<SQ802d`?`0]
<3h09RPe0P0T9S<03@0P8Rl06ATU02LW<`0W9c<08R8/010>6@0O7BP081lW02DR:@0M6R4071LN01/F
7@0R7B<00P0P7R40CP0N71l08R0S02<Q9P0N7B8071`Q01`M8P0N7b@07b4W01lR:@0P8b`07ah[02/Z
>00M72X0:bXh01lN;00P7bd09bHd02XY=`0E52808b8`03`kB@0F5B<03Q0M02XY=`0N7B/06aXX00D3
400a;c/0928]01lL9`0Z9c40:BH_02DO:@0L5ad06aHJ01dH7P0P6b407aXP01hI800M61l08A`S020J
900J51h071HP01hH8P0K5B807ALU020J:00P6RL08A/W01hH900O6B@08A/U01`F800K5Ah071LN01XE
700K5Ql07QPT01/E8@0F41/06A<M01`F800K5Qh071LN01`G7@0J5A/06A@J01LB600I51X06aHL01PC
6@0F4AL06QDK01XE700I4ad0618L01LA6`805Q0L01D05a4L03hh@P0I51/03PT@014<4`0G4QT050lF
01lJ8@0910/04`hE018=500?2Q408adT01P>5P0R5al081DM01L<500I3QH060dC01/@5P0J3aD00P0I
3Q80200K4A<071<D01L>4`0C3A404P`@01<=4@0B31003`T=0P0B310201<=4@8050hB00@050T?01D:
400E2Q005P/A0P0G31803@0I3Q@050T?01873@0D2@l05``B01P=4`0E2Ph050T=01P=4@0T6Ad06@hB
01<8300B1`/0100D2@d00`0B1`/04`P<01D:3P0201D:3P0301L<400H3A405@X>00<05P/?01D050T=
01<:3`0E3AD05a4K00d:4`0G5B40=CA202HU<`0@3ad03`dJ018@6`0?2a@06a@L01`E7@0h<CT03`P@
01@=5@0P6B401`0801PA6@0D3AD00P0B2a<0500C31@050dE01D=600G3R006A8T01TC9P0G52L06AHY
01PI:`0I72d0724d01lW>00R:c`08blo02@c@00Y>dD0<D=?03=5D@0dAU80>TaJ0P0nD5h08P11DV80
AEIV04MHJ018FFT0BEY[04IGJ@10Df@0>e1O03M=F`0dBUL0;D5<02i0BP0c@DX0930i03<mAP0h?dT0
9BLa02DT;00S8RX08B0W01lN900P7B@05A<H018@5@0K5QX04@`@01HA5@0D3Q806ADF00l;300<20T0
4@d>00d92P0G4A<301H=400401H;3`0E2Ph050T=01T>4P805@X>00<05P/?01<8300C20`00`0D2@d0
0`0C20`04PL;01872`0601@82P0803hb=00D20X04@D701041P0F2P`050P:00l31@0E2@/200d10`03
01D92`0?0`D04PH800D04PH81P0B1PH04`0<00003@<300h20P0E2@T04@D501861P0?0`<05`/;0186
1P0U6AT05@T901451@0I3@d05PX:01P<300@10@05PX:01451@0?0`D00P0=0@<0100D20X02`0100d1
0`0E2@/201P<3P0301D92`0D20X050P:00805@/<00@0Acdn01T?400700006Q0A0P0F30d0400Q5aP0
2`4201@:2`08004070lG0185300=00L06`hE00/00`0<00@06@dA0186200?0`D03P840104100B1PP5
01452@0=0104200=0@D0200001P<400D20`0200001P<400?0`L04@D901hB5P13=c/05`/?00l31`03
01862P804@D901h03P8603/_<`17>cl04`T;01452@0J3Q804PH:00P0000B1PX03P<601452@0?0`L0
6@hB08Z1Q00Q61/03`H901072P0<0`H0BD1302HM800@1`X05@`?00`31P0A20/0:QhR02/O8`0L41@0
60`@01@8300E2@d601452@0T00X00`0B1`/040H900l4200800404PT;01D:3P0G310060dA01872`0?
10P04@H:01052@0B1`/04`P<01462P0A1P/04`P>00T0100>1@X040D=00L0100D21407a@L01443@0B
1@`050L>01H9400D1`h040<:00d01`0A10/050L>01D83`0G2Q406@`C5?ooool001_ooooo00`060h?
01H<3@0D2P/04`T:01882@0A1`P03@<401882@0?1@H04@L801D;300>10D601882@805@/<00H04`T:
01882@0A1`P04@L80186200D20X201D92`090186200A1@L04`L901L;3@0I3@l040@600`00P0A1@L0
4`L900804PH800<04`L901@82P0E2@/00P0C1`T0100A1@L04`L900h2100?0`D60186200Z01<92P0?
0`D060`>01X>400U6A/03P8400l31@0A1@L050P:01<72@0B1PP05PX<01P<3P0900004PH800l31@0M
4A<03@<401@;300700002P8300P0000k<S<040P901XA4P0B2@X050/<02XQ8P1?ATL06@h@01H:300J
3Q00>bla02/O8@0A1@L05PX<00`00P0>0P@05PX<01L;3@0^8R@0<2DW100D2P/00`0E2``05P`=01D;
300301D;300301D<3@0F3P`050l<00<05A0=00h05Q4>00l:1`0D3``05A0=018=2P0F4@h06A<B01/E
5`0C3@l0618D01D?4@0H4Q@06aDG01TC5@805Q0B0P0E3a40:00S7Al0;BTZ028N7`0K5aP07ATJ01`G
6P0K5QX05Q4E01XE6P0I51X04PdC02HQ:00F51T06Q/O00lC500W:b`05QXK059FF00e>C`03a8G01@G
700H6b005aXQ01PK8P0J7B@06Q/P028S:00V9b`08R8Z01dO9P0M82L0720Y028V;`0Q9Bh072<]01lV
<00V;CL09RXe02@X<`0U:C@202H]=`04028Y<`0R:c@0<CY305YSK0808R`e03D09Bli02Pb?`0[=dD0
:SI402Da@@0V<d<0:SM703]8F@0kBe/0?TiN03U8F`0`?e80<41?0351@`12DE@0>TU>03Q6D00e@U80
>4EE03A1DP0c@540=T=C03=1CP0_?DP0<T1;03]<EP0eAU00<dA>03I7D@0hBE<0=dQB0393C@0cA4h0
=4E?03I7D@0nCeT0Kh:803]@D@0iC500>TeA03=6BP14EE`0=DI>041AF@16E5l0>dUE03Y8E@0lB5H0
>4A>03E2B00gA4X0?4U?03U6C00203A1A`0=034nA00`?D<0=457038oA@0d@DL0?deD03a;DP0c@TT0
=4=:03I5C00kBU40?DaC03I5C00303E4B`0303I5C00kBU40<d990080<d9900d0:CPo02/j@@0[>T40
;Ca303a;DP1QL7L0=TE<03=2B@0Q;SH0?4UA03A1B@0[>400>DI>0080=T=;00D0=D9:03A1B@0c@4P0
<Sm7030mA@02030oAP0402lnA@0^?D@0;Se402llA080;CM000L0:38k03<lA@0W<3T0;CHo03E0AP0a
?480=D160080;CHm00@0;3Dl02H]=@0U;3@0:C0h0P0]<CX0=@0_=S`0:C0f02La=00V;c@09bhf02Xa
>P0/<cd0;2ln04Y<G00T9CT0;c1502h_A00/;T<0;35402T`@P0V;Cl09b`o02H[?@0T:SX0;c9102`^
?@0S9C@092Hc02DW=00L7R/06QXV01/K9P0Q8B/071XU01hM9@0S8RX071TR020M900Q7RD06aHM02@O
9P0X8bT081`M02@P8@0P71d07a`M020N8@0O7B007A/O01`K800M72407alT020Q9P0Q8BT0820]02`[
>@0M72X0<S4o00808b8`01@0JfYh03@c@@0N7B/0:BPf061OK@0l>dT0828_01DD8P0<2aT06aXX01HD
8@0Y9c<09R@_01`I900M6R@081dV01`F800L5a`07ALI01hH708081XN014081TP020I8@0W7bX0:b<`
024I9P0M5B807QHS01dE900O5bH08ATX020H9P0P62D07QHS01dE8@0P62<07QHQ01dF7`0201dF7P04
01dF800I4al06A<O01`F8@80618L00`06aDN01/F7@0K5Q`06A@J01LB600F4AL05A0F01TD6P0G4QP0
5A0F01XE6`0J5A`201XD7P0801TC7@0H4Qh0618N01PB7@0=1a404PdD01/F7@0H4aX301D@5`0;00`7
3P0L5ah06QDL020K8P0?2A008ALO02lT;00/8BT06@hF01P=5@0H3A<00P0G31002P0F2`l05P`=01P>
3`0I41405`hC01@>4P0C3A4050hB018<400?2@d2018<40804`dA0P0D3Q80100G318060dC01T>500J
3aD201`A5`804`P>0P0B1`d201D:400401872`0F2`l06@hB024F6P805P/?00L04PL;01D:3P0H3A40
60dA01D:3P0B1`/050T=00805P/?00<050T=01D:3P0G31000P0E2Ph301H;3`0501D<4@0B2Q80618L
010=5P0A3a/00`0@3ad02`0E4b004a4L01@@6@0S72@07AHN01H?5`0N5al03`P@00d63P0A2Q803`P@
00<05@hF0P0F3aL05P0G3aX060lR01XB9`0I4RL05Q<V01LD9`0G62/06aha01dR=@0N9SP08BXk02D^
?`0V=4409cU302doB@0a@dh0<dEA03M9E@0kCEX0?4iL03m@H013E6@204AEI@0I04EFI`13E6H0?e9S
03Y?GP0dBUP0<4IC02a0B`0[?DL0;Sa502Da>P0_>D80=Se702PZ=00T8b/07ahV020O9P0Q82H07AXQ
02<Q9P0F51T08QdQ020K7`0U82@04`dA01XF5`0301PD5@0500X61`0@2P`060lB01L>4@0F3A000`0E
2Ph201<8300401D:3P0@1@T03P<701dB5P<050T=0P0C20`00`0B1`/05@T;01D92`0401D92`080555
A`0I3@l08aLI01041P0D20X05`/=01@82P0C1`T20186200301<72@0D20X04PH800D04PH81P0B1PH0
6@0C1`L08ADE01P<300?0`<03P<301D92@0?0`<050P800l30`0Q5AD050P80104100J3Ph04`L701dA
4@0E2@T06@d=00d10@0C1`T05@T;01L;3@0E2@/04`L90186200E2@/00P0I3@l06`0F2P`050P:01@8
2P0C2@X05`d>03`b<`0I3a00200001<92P0900402P0101061`0D2P/05@/<00d21P0@10/02`0500P0
0P0A10/05`/?034U:@0J3Q804@D700h2100@10H040@401041P0501452@0>01T=4@08000050P<00l5
1`0D20`0200001D93@0;00<0200005A8C02ZWZ80=2P/0104200D20`201H:3P0P01@8300B1PX04`L;
03/_<`13=c/050X<01862P0G2`l040D800P0000N4QH04@H901D93@0A1@T02`8402hU:00700402002
01482`0B2@`08APK00h5200700403@@700`31P0F3A0040@801@8300<0@@040@800h21P0?0`L60145
2@0I00d21P0A1PX04PL;00L0000<0@D07Q@G00l4200@1@T04@H:01052@0?10P03P<700l4200A1PX0
4PL;01052@0@1@X04PL=01<83P0A1Pd03`@<03/`>00E31<04@H>01<63`0201442`804PD<00L03`89
01442`0D1`h04`H=00l22@0:00@02@0301Cooooo000Kooooo`0l01/A5@0D2`h040P901<:2`0B2PT0
3@H401071@0B2PP03`P801482@0D2`l050X?01@9300E2Pd03PD601872P0C2@X050X;01H<3@0E2`/0
4`T901471`0B20P04`T901L<3@0B1`T04PL80146200A1PL04PL90146200C20X050T:01@92`0G30d0
4PL902dR8P0G30d05@X:01461`0A1PH0714B01461`0D2@T04@H601@92P0?10@060d=0187200D2@X0
4`P:01461`0D2@X040D601461`0G30h050T:02XO8@0j;c405P/=0P0C1`T0900F2P`05@T;01<72@0B
1PP05@T;00h2100E2P/0308301<72@0F2``05`d>01H<3@0E2``08ALH079YJP0`9bP040L700h41@0E
30d03`D602@K700?1PL0714B00d3100U6Q/07A8C01<82@0J3a005``=01P=3`0D2@X03@@501H;3@0L
4A<05@/=01H;3P805P`>00@05``?01882P0C20/05@/=0P0F30h0700F2`h04PP:01@;2`0H3Pl05`d?
01D<300D30`06Q0C028K6P0E3@h0614B01TB4@0e;c004`h@01PC500E41406QDF01HA4P0E41406A@F
01LB500L5aP05Q4B01<>400G4Q<07APK01PC5P0K5QP201D@4`3g01XE6@0N61`05a8G01XE6P0Q6b00
<2X_01dJ7`0G5a`07AhQ00`?4@0H61/08B8W01@E700E5A`06AXP01dO9`0L6bD06a/T028T:`0L7R<0
8B@Y02HZ;P0U:Bl0720V01/Q9`0N8b`07RD/01/S:`0J8R/072D^028Z<`0K8Rd08bPe02@Y=@0R:3D0
8RTe024Y<`0^=d80>T=?059LIP0X<S`09c8m02Pd?@0V<cd0;3U502/hA00X=D<0:3E502XgA`0b?e00
;Sa<03A3D@0b@Dl0;ci<02/jA@0_?dH0@51F03i>E@0kBU<0=4=>04EDG`0d@dl0<D1<0310BP0^?TP0
<T5;03I6C`0gB540=TM@03=4C@0b@d`0=dQA03Y;DP0iBU80>T]B03I7C`0`@DT0AUMM07F7S00jCU80
<DA903I9CP0]@4D0>TaB03U;DP10DUT0A5IM03a=EP0hB540=dM@03A4B@0oD540=dE:06=cMP0jBd`0
=dE903Q7BP0dADH0=TA903Q7BP0dA4H0>4I:03E6B`0c@d/0>DU@03A4C00c@d/0=4A<03=3BP0fATd0
<D5903=3BP0dA4`0<T990391B00a@4H0<T5702lnA00c@TP0<3m502He>`0a@4H0;ci403m>E00a@4H0
;ci403U6C@0`?D@0<Sm603A1B00`?D@0>TM>03I3BP0a?TD0;ca3038oAP0d@DP0<Ci502dk@@0^?D40
<Cm60390A`0a?dH0;ca3038mAP0[=Sl0:CDn03@oB00]>440=3m8041;E00a?D@0=417030j@P0_>400
>D9:02Ta>P0W;cL0;C@m02`a>`0W;CH0<3Lo02hh>P0X<c@09S0c02Xb=`0]=Cd0:c<l03<hAP13AeP0
;c55038dB@0_<4H0;C5501XS<`0Z=D80:CA103HoC@0_=dD0:2lk02P^>`0S9cD0>Sa:01TK:00W:3D0
6Q/W024Q;00O7bP09bL^01lO9`0Y:C007QhU028R:@0O7B<08b4W01lM8`0U8bT08b4V01hM700S8R<0
8B0Q01hM7`0P7R808b4W01hK8P0L6R<07A/S024N:00P7BT06aPU01lN:`0U9C805aLT02/[>00Q82d0
6ATV0450C@0O7R/09bLd020P;@0Z:CH051@Q01hK:@0P7B/08Ah/01lL:P0N6bT071PU020K:00O6RL0
8al[02@P:P0P6RL08A/U01`H7P0Y8bX08adU01HB6@0M5b00618L01hI900Y8Rl09Al[024M:00Q6RL0
61<Q020K:@0201`G9@10020K:00I520061<N01hI900J5Ql05A4I01lK8`0?2a806aLO01`G800P6bH0
81`T01/F7`0J5Ah06ADM01PD6`0J5Q`06ADK01LC6@0E4AP05Q4H01TD6`0H4aX04`hE01D@5`0H4aX0
5a8J01TD700E3aP050lG01<=5P0F41X0618I01/E700F3QH05`lG01TC6P0F3aH06A4I01PB6@0E3QD0
6A0H02LQ:00N5Qh040H?01hF7P0L4Q`06a0J01894@0J4AT05`dD01L?5@0G3A@05P/B01L>500J4QT0
5a0F01@=4`0?2@h05Q0E01D>4`0G4AD03PP<018<40804P`?03P050hA018<3`0E3A4050/?01D>4@0O
5AX081PL01@<400;0PH04`/>01D=4@0?1@T040P;01dC5`0B1`/05P/?01L<400H3A404`P<01L<400F
2`l05@X>01T>4P0J3a<05P/?01L<400C2`h05P`?01D>400@1`X04`T<018:3@0C2`h04@L:01H?4@0B
2P`05@/?01XB5`0M5Qd050hE014=5@0G4a`06ADO01@@6P0@3AL04PhG00l;500B3A@06a@L01D>5P0B
31<03`T@01D?5`0?2A004P`D01@>5P<04P`C01L050hE01D?5P0E3QT05Q4P01PC8`0I5RD06ALV01PG
9P0M7Bh06A/[02HX>00O8cD09B`m02@[?00V<D009cQ302LhA00/?DP0=DIB03I8E00hBUH0>D]H03Y=
FP02041CH00f041BH@12E6<0@U=R03U;G00kCE`0=TQE0353D00/?DP0;Ca7030lAP0X<S`09bli02hd
?`0/;ST08B0X020O9`0G5ah0820U01PF700L6Ql04A0E01LD5`0F4QH061@H01LB5P0E41<05A4C01@?
5@0M61d04@dC01L@600C2A407QDL01<9400F2a0040D901dB5@0F2`l06PlC01T>4P0E2Ph04PL;028G
6`0D2@d081DI01dB5P0@1@T04PL;01@93@0E2@/04PH801L;3@0L418060`>0P0F2P`01`0H3@l0?S8d
01lC5@0@1@H04`L901D92`0@10H00P0E2@/0600@10H05@T;0186200A1@L04PH801@82P0C1`T03`<5
01<71`0E2@P04@H50145100B1`H040@301<71P0N4a805``;01D:2@0D2@P03P8200l4100A1PH03@<3
01H;30804PL802<0714A01461`14>CT0;R<T01D;2`0F2`/04`P:01872@0A1PL03P@501@92P0D2@/0
4`P901H;3@0G30d05@X<01<82@0B1`T050X<01H;3@0H3A0050T<00`3100H3A005P/=01@92`0=0`D0
40D700h31@0H31005@T>00h3200H31403`@900h41P0201H:3P0k00d21@0?0`H050T<01<72P0?0`L0
4`L;0104200C1`/03@<50104200>0`H06`lC01P<400@1@P04`P<01X>4P0?10L03`@801X>4P0C20`0
81@H00h31`0@10P040D901D:3P0B1PX04PL;01<72`0>0PH040@801052@0A1`X05@T=00/2100Z7R80
3P<701L>400G30l05PX>03lc=`0E2`h02P8400l52@0@1PX040H900d31`0D2Ph0>c4d01L=4@0F30l0
30@601062@0A1@T050P<01862P0E2@d04`L;01862P0@10P00`0A1@T201862P8040D900@04@H:00d4
1P0M4QH0=2T]0P0?10P01@0A1PX04`P<01<8300C20`040D:00<04PL<01@03`@901H;4@0>0`T040D;
01<83`1MDUT07a@K01@9400D20l04`L=00l32P0B1Pd040@;01863@0C1`h050P>0186300@10/04@D<
01@83QCooooo000Kooooo`0K00l83`0>20/03`T900l92@0@2`L05Q4;00d80P0>2@D03`X7010:300A
2`h04P`@01462P0B1`/03P<701H;3`0A1PT040H701@:2`0D2PX04PP700l5100A1`D04`T701882@0>
10D04@L800804PP901l05P`=01lE5P0F30d03`D601D;300G3@h04`T:07U_KP17?C`091XI01H<2`0Z
81l01`0001881`0@1PD050X901<9200<0P402`4001@:2`0E2``04`T:00l51P0H3Pl04@L801H<3@0A
1`P03P@501061`0F30d05P/=00@04`L9024050P:01<72@0F2P`04PH801X>400K3a4060`>01/@4P0@
1PL04PP900d3100D2P/07Q@E01T?400B20T0718C00l51P0;0@805`d>00l51P0G3@h06a4B01hD5@0C
2@X060h?01<92P0=0`@03P@501H<3@0C2@X04@L800l41`0C20`00`0D2@d701D:3P0=01452@0C1`/0
50P<01<72`0B1PX04PL;01D:3P0H3A4071<F00d41`060000618D01DA4P0201<?40805Q8C00D04`l@
01DA4P0D41407ATJ01LC500201PD5@0601LA5@0A2`l071HJ01TC5`0G4AD05@lC0P0I4aL0=P0L5QX0
6aDI01TC5`0M61`03`dB024P9@0_;S<09bH/014@5`0S8RX061LO01XI8P0Q7bX081hY024O:P0];CD0
;2lf01hS9`0O92P08RT_01/R:00>5A/05b0W01/T:`0L9B`06B</01/U;P0O:C808RPf020V=00Q9cD0
92Xh02P_?00X<3d0:c=002@^>P0R;3P08Bdi02@`?00U<S/09SDm02lmAP0`?TT0:3I302PeA@0]>TX0
>DIF03m=FP0mBeP0@4iH04EDF`0a?dP0;3e702dnB080<45900T0:ca303]<D`0kC5<0>T]B03I7CP0c
A4/0=dQ@03Y;D`0`@DT00P0a@TX0300b@d/0<dA<03A5C00fAdh0?e1G03A6BP0_@DD0>D]?03U<D@0l
CeD0<4=902e0AP80?e9H0200=dY@03Y=D`0lCeD0>DaB03E8CP0fBDl0=dU<03I8B00hBTX0Z[bl049D
E00S=CD0=dU903=5A@0a@d<0=TQ803Y<C00hBTX0<T=80311B@0dADd0<dA<04AEG@17F600<4590352
BP0cA4`0=dQ@0352BP0jBe80=dI=03=2A`<0;Ca100P0:cXo02Th?@0[>Sl0;Se20350A@0b@DH0<d97
030m@`80<Sm501<0<d1603M4BP0d@DL0<Sm5030m@`0_?480<Ci403=0AP0b?dD0;S`o030n@@0e@dH0
=dA:03E2B00a?T@0;CY202/h@00Z=d00;3U20080;S]400P0<3e502/h@00/>D40;CM002`f?`0a>T<0
:C8k02L_>@80:c8l02<09bhh02Xc>P0U;c40930`02Lb=00[=3T0;CHn02`e?P0[<Cl09B/j034fB@0_
<DH0;S1702L^@@0[=d<08c@l04]IHP1PKGH09S4k03LoBP0^=400:Rlk08^?V`17AU@061LU020P;00S
8b/06Q/P02DV:`0W:2d08b@Y01hO900Q8RL07QlT01`M8P0201dN8`0501`M8@0J71X06adL01dO7P0P
82800P0O7R@0500V8b`09b<a02<O;@0U7Rh08Q/]01/G9P0H5b<07AdY02LW<`0K6bL05QHR02h^>P0P
82`08R8^02<S;`0Q8Bd07AdY01`J9`0P6bT081XX0`0O6BL0500Q6bT07ALU01dG9@0S7B/08Q`Z024K
:@0R7BX07Q/V02dZ=@0/:C@08AhY02dZ=@0a;ST0924/020M:00O72L06AHQ01hK9P0H5R804a4N0P0D
4Ql04@0N72T0928]01XH8`0Q7bX030/C01PG7`0>3AD07QdS01`J8@0K61l061DL01DB6@0J5ah061DL
01LD6`0B3aH03``C00<05Q<J01804`hE01HA600H4aX05Q4H01D@5`0H4aX0HeiU04E0A`0I51/081/R
01lJ8@0@2a805P`D01<94@0A1`l05@/C01T?5`0L4QX401L=5@0O01H<500E2a<04PXE01H>6@0L51l0
;RHa01XB7@0M5B0040PC01L?6P0M5B005`lJ01084`0>1Q403@H>01L@600N5ah04P/B00h73@0@2Ph0
5a4E01XD5`0D3Q004P`>01<=3`0A2`d04`d?018<3P0A2`d0618D01/E5`0200h82P0501<=3`0I4aD0
5Q0B01XD5P0c;Bl00P0G310201H;3`805@X>00L05P/?01872`0F2`l05``@01H;3`0J4A@04``>0080
4`d?01005@lA01LA4`0<1PP06A<E02hX:P12?3h050h@01D?4@0=1`T04``C00`5300I4QT04P/B01L@
5`0@2A0050dD0P0C31<02P0D3A@05@hE01D>5@0K5Qd01P4801D@5`0G4QT0:RD/014<4`0D3aH2014<
4`0<018=500E41L0514J014>6P0B41d05QDQ01HF8P0E52805ADS01@F8`0S9C@07b8b0P0W:S/02@0T
;C`09cE202LgA00Z>TL0<d=@03A6DP0eAe<0=TQD03E9E00203eAG00W03a@F`14Ef@0@eES03U;F@0i
BUL0<T9?03Q6D`0a?TX0;cU5030h@`0V;ST092`g02P^>P0S:3804A@K028R:P0N7RD0;Rld03Lf?00J
6Ah05aHK01/I700M6ah05aDH01D@500?2Ph07APN01lJ8@0H4Q`07QPT01H>7@0S62H0OWAo03D[=@0L
4AL06Q0A01D;2`0W72008aPL00804`P<01@04PL;01dB5P0C20`08aPL024F6P0?10P04`P<01P=4@0C
1`T03`<501<72@0H30h05PX<01<72@0D20X03P8400l31@0P51H04PL801041PH04@D700h0300202@H
6P0H30h02@0000/10P0=0@<04`L701D:200@1@<04PL501/@3P0J3`d04PL501@91`805@X801404`P6
0104100D2P/04`T:0147200@1PL03`D600h41@0900004@L801882@0D2``06a4B00L0000C2@X04PP9
0147200201882@0301<92P0D2P/05P`=00805`d>014050X;01<92P0E2@d0200000X00P0K3a<03`<7
00P0000B1PX04@D901@8300B1PX03P860104200<0`D05``@00T00P0300h31`0:00d41P0J3a<02001
00X10`0?10P060dA00d21P0O51P040D901L<408040D900P07a@H00/0100A20X050T=00P00@0G3100
4@H:01052@804PL;01D03`@801052@0A1PX05@X>00h41`0>0`L05P/?01872`0@1@T04`P<00l5200G
31002@0204i3A`0M4QH0714E00/2100;00@0@3Di01462P0@1@T00`0?10P01`0@1@T0;24U05]@E00H
3A405@X>01052@0^8bL00P0A1@T201862P804`L;0P0@10P301452@0;01862P0A1PX040D900h31`0?
10P04@H:01D:3P0>0`L03`@801462P0B1`/00P0A1PX0200A1P`03`@:0146300S61h060dC01873@0?
10X040D;0P0A1P`0200B1`d04`P>02@I7`0B1`d05P/A01T>500C20h05@X@0P0B1`d0100A1P`040D;
01052`0?10XDooooo`006oooool0:P0L5QX04`d@01<=3@0B30`03@P4018=1`0=20803@P400h91P0?
2@/040X=010:3P0E2Ph04`P<01X?4`0T6Ad05@/=01<92P0B20T050X:01<9200A1`H04@L501881P0E
2``04`T:01D;300B20T04@L801H<3@0O5AH08ALH01061`0F30d040H701@:2`0I41007aDD00L0000F
3@d04PP701P>3@803`D40P0E2`X201061@0<01882@0C2@X04`T:01H<3@0T6Q/07aDF01@:2`0B20T0
3@<400/10P0B20T05P/=0`0D20X0300C1`T04PH801041P0B1PP04@D701T=3`0J3Q0060`>01/@4@0I
3a005@/<00l51P804@L800/05P`=0147200I3a004`T:00l51P0G3@h040H701<92P0I3a006a8B02PN
7`0201X@4@0600d3100E2``07A<D01hD5@0Q5aP05P/>0P0G310301H;3`0401P=4@0G31005``@01@9
3@804`P<00<05PX>01D93@0E2@d00P0F2Ph05P0C20`06Q4D00T00`0K4QD05@lA01XD5P0B30h06ADF
01<?400@30d05Q8C01TE5P0C3a00510A014=3P0J5QL05Q8C01PD5@0L61T05Q4E00d8300G4QH201TD
600=01<>4P0H4aL061<G01/F6P0J5AT061<G01dH700`;S<01@@901DD6@0I61h04Q4G024P9P0201dL
900Z01hM9@0K6B@06ALR01lO9`0[;SD06QlS010E6@0?5Q`072<Y01PO9@0G82L072D/01lX;`0N:340
7bTb020Z<`12B5H09bdk028X=P0W;c`092`i024Y=P0X<Sh08bdi028/>00T<3`09S8n02Ld?@0^?DD0
;C]402/iA00U<d00>DIF051MK@16Df<0;ce:02Hd@@0[>D<0?4]B03Q7CP0`@DT0<D9:0P0]?TH0?@0Y
>T40<D9903Q:CP0iBdl0=dU=03=4B`0b@dX0<dA<02hoB@0[?4H0;Ci80393C00b@d/0<D9:03I7C`0m
CUD0>4U@02`mA00cA4/0;T1603mBF00mD5H0<TE;03M:D00dAdd0>DaB03Q;D@0fBDl0<DA:02m2B00d
Add0>Te@03Q:BP0[?Cd0E6IV0353@`0W>CT0=TQ803A6AP0cADD0=dU904=EE@0nD500=DI;0352BP0b
@d/0<dA<03Y;D`0lCED0<D9:03E6CP0dADd0<45902Xk@`1@HFT0A5=J03a;D00`?d@0;ci3030oA00^
?D800P0]?4401P0^?D80;ci3030oA00c@TL0;ca2038oA@80<d1600H0=D9802ll@P0a?T@0;ca202hk
@@0`?D<2038oA@0902dk?P0^?3l0<Cm2038oA@0a?T@0<3e3030mA@0^>d<0:cQ10080;3U20280:cQ1
02dj@`0Z=d00;3U202hh@P0Z=3h0;CM102Xb?@0U;CP0:30k02`b?P0Y;c/09Rlh024Z;`0T;c40:C@h
02`e>P0]=Sh0;3Dn02H/>P0T:ST0<SM:034dA`0_<DH08bXl02<_>`0]?DD0TInX0:Re_P0g@T`09Rhi
02`b?P0V:cL0ADUE0P0H5bD06`0[:cL07AdW01lO9`0U9Bd08R8Z01dM9@0N7RH08B4Y01XJ8P0K6b<0
7alW01dM9@0I6Ql06AXK01LI600K7A`08R<U020O9@0L6b408b8Z02HR<00P72X07aPX020I:@0M6BP0
9B@a028R;P02020P;00301/K9`0H62@07al[00807al[00<07QhZ01`L:00L6RL00`0M6BL201hJ:003
028N;00P72X07ATW00<081`Z00<07Q/W01HC7P0F4ah00P0H5B008`0O72L0=S<n02TV<@0O72L08QlZ
01HC7P0J5b807Q`X01XH9@0R82d07adZ01dK:00N72L06QPR01DD700[:S8081lV01lN900:2@l06aTO
01lL8`0N6b8071TP01hK8P0L6B005a@K01DB6@0K61l04PlF00d:4@0^:c807aXQ01`G7P0I51/061<J
00806A@K00`0B4=:038]=00B3A@04`hE010;4P0L5ah0;bD]020F7P0F31@060hF01H<500J41P201P>
5P0>01L=5@0E2a<05@/C01D;4`0K4ah04@TD018:5@0K4ah040PC01D=600@21<0610K020H8`0H41/2
01084`0H01PA6@0D3A@07aPO01<<4`0L5A/04`dA01XD600I4aH04@/=00l92`0B30h040X<014;3@0C
3@l040X<00l92`0B30h04@/=01H@4P0B30h03`T;018<3P0;1PL06Q@F0P0G310201H;3`805@X>01D0
5P/?01@93@0E2Ph05P/?01@93@0G3Q404P/=018<3P0<1PP04@/=01D?4@0<1PP04P`>03Xd=P1CCDl0
4`d?01`F600=1`T03PL>00P1200N5ah00P0A2Q400`0D3A@04P/B0109400301094008014:4@0?2Q40
1`8900h9400P6b80/jje030[<P0C3QD2014<4`05018=500D3aH04a0I010=600B41d00P0E4b003P0D
4b405QLT02PZ=`0R93<08bHe020S<P0T9cH08BXh02@b?`0X=T<0:cY70351CP0b@Tl0=4EA0P0dAU80
6`0kCUX0>TiI03Y>F@0lCe/0<49@0312CP0eAU80=DEB034oBP0X=D40;3I202Xb?@0T:cL08bTe020V
<P0P9Bh09bXa01hN9P0W:2h0XjBY075`MP0K6Ql06APM01lM800Q7b806aTL01LB5P0201LB600F01PC
6P0M5b40:bD_01H>6`0I3Q`0=2Xe01hD7@0@1@/05`d>01T?3`0H3A406PlC01D:3P0J3a<050T=01<8
300>0`L05P/?01P=4@0@1@T04@H:01@93@804`L90P0A1@L0200E2@/04`L901D92`0@10H02`0101dA
4`0E2@/040@61P0A1@L01P0E2@/0=BT[028F600?0`D05PX<01@82P8050P800D04@D501<71`0N4Q80
8ADE0104100501451@8050X;00/04`T:0147200?1@H03@<400l51P0D2P/0>Bl`01@:2`0I3a0050X;
01882@03014720804PP900`05@/<01H<3@0G3@h05`d>01D;300D2P/03P8601X>4P0H31002`43024E
6@0O4aL201862P0K01H:3P0B1PX0300400d11@0B1`/04@H:00`11@0C20`060dA00h31`0;0P@050T=
00`11@0H3A403`@801052@0>0`L03@8601052@0C20`050T=00d41P0?10P05``@01462P0?10P03P<7
00804PL;01@040D901462P0B1`/04@H:01052@0900803`@801@93@0@1@T04PL;01462P0=0PH04`P<
00h31`0B1`/03@8602LL800700007A8F00`11@805``@00<030<501462P0A1PX00`0A1PX01P0?10P0
91TM00`31@0<0@D03@8601X?4`804@D90P0B1PX201<72`804PH:0`0A1@T0100@10P04`P<01872`0?
10P300d21P803P<700T040D901462P0@1@T040D900l42P0@1@/04@H<02@I7`0I3Q@00`0@1@/40146
300601L<4P0L4AL02`0600l42P0j;cD050T?0`0B1`d3014631Cooooo000Kooooo`0H028L800B30l0
3`T901@>3P0@2`L02`H200d80`0=20D03PT600h82P0?2@`03`T=01L<400A1PX06a0D02HK7`0C2@/0
5@/<01061`0C2@T050X901881`0B20H04`T70P0@1PL04@0B20T040H70147200F30d0;B<T03hd=@0I
3a003`D601hD5@0o=CH04PP801L=300@1PD04PT801L=300F30/06a4@008050X900@04`T801061@0B
20L040H70`0B20T02P0I3a0040P801882@0M4a@07Q@E01H<3@0A1`P04`P901<72@0D20X401D92`80
4PH800H050P:01041P0B1PP05@X;024G600I3a0201@:2`0J00d3100C2@X05@`<01`B4`0D2P/030<3
01882@0C2@X06a4B01P>3`0`9RL0CdE601892P0I41004`T:01X@4@0@1`P040H701X@4@0C2@/05`dA
01L=400E2`l05@/>01@:3P0F310201H<3`0401@:3P0D2Pd050X=01L;3`805@T=00d06@hB01/?4`0G
31006Q4D018:300F3a404P`>01<=3`0F41805a<D01DA4P0C3a005A4B00805a<D00<061@E014=3P0J
5QL00P0F4Q<01@0L61T071LK01D@500N6Ad06A@H00@06QDI00H07APL01`G6`0J5AT07A/N06m]LP0U
92T201TH7@0M024P9P0N7B<06QTP01dL8`0M72@06aXS01`J900M7BD061/R02H[;`0R9b/072<Y01XQ
9`0I82H07RL^01lX;`0Q:S408R`e02H`>@0X<S/0B4iL02T_?@0W;S/0:c=0028Z=`0R:cL0:38n02<^
>P0T;c/00P0W<cl04@0T<CX0;C]302Xh@@0^?4D0:cU503A1D@13D600GFYj02Pf@`0d@Td0=TA=02ln
A@0d@dX0;T1603=4B`0Z?440<D980080;d1702@0;3i302i0A00`@TH0<TA903=4BP0cA4/0=DEB03E5
D`0dA500<T9?03A5D00gB540<D9;03M8D@0lCE@0;d1702m0B00fB4l0=DQ>02`oA@0jCE<0<DA:03mB
F01VNGl0AUUO03U<DP0cAT`0=4M=03=6C00aA4L0>Ta<03a>CP0a@d<0@59B03A6AP0cADD203a>CP0H
0394A00kCDd0>de=03E7B`0_@4P0<T=;03E6CP0dADd0>4UA03E6CP0b@d/0;Ci60352BP0Z>d<0?e1G
03a;DP0fADX0;ci30391AP0d@dP0<3m403=2A`0b@DH0;ci30P0]?4401`0_?T<0;ca2030m@`0_?480
<3e303A1A`0a?T@00P0_?480100^>d40;ca202ll@P0a?T@302lm@0<0;ca20300<3e502hk@`0/>D80
;3U202dj@`0[>440;CY302/h@@0^>d@0;cY402/f@00]=d40:S<m02Xb?@0W;cX09B`h02P^>P0[<cd0
:S<k02Pc>00/=ch0<S]302hg@00T;CH09bdi02H/>@0_=D@0;S51034dA00W;C`09C0k028`>@0/>T<0
>DA>02Tb?@0W;cX06b4]01lT<00K7b/051HS02HV=00J6RH07AdW024Q:P0O7bP08R8[01TI8P0N7RL2
01lO:0807QhW01<07AdV01dN900K7Qh07R4Q01dP800Q8RH092@Y020P9P0P7bL07a`W01dI9P0U82l0
:RDd02LS<@0O7RX071`X02@T<00Q8Bd09BDa00808R8^00<0820/01lO:`0P82`00P0P82`0100L62H0
7QXX01lK:@0P72X201lK:@0301XF900I5B<07QXX00807QXX00X0:2Da02/X<`0P7BP07a`W01`I900G
51l08AhY01TF8@0J5b807a`W0P0N6bH03@0Y9S80?C]801lM:P0E4b007Q`X01@B7@0/:c@0GUeU01dL
8`0J6B008R4W010?5@0I5ah00P0I5Qd03`0E4QT04PlF01DB6@0I5Qd0514H01XG7P0H5A`0514H034^
=@0V8BP07QTP01D@5`0F4AP06A@K01LB6@0201@?5P0<01LB6@0L5ah050lF02TT:`0e;SD08QTQ01P@
5`0M51`05@dD01H>5@0J4AT06A0H0P0H41L06P0J4AT07A@L01H?5`0G3aT05PhH01PA6P0L51h05`lI
01@=5P0H41X05a0I01094P0G3aT091dV01094@0J4aX050dD01L@5`0B2a403`T=01<=4@0E3a804`d?
01H@4P0K5AL05a4C1P0C3@l01P0@2P`050h@01@>400F41803`T;01XD5P805``@0P0F2`l201D:3P03
01P=4@0G31005@X>008050T=01H04`X=01<<3P0=20T040X<01LA4`0?2@/05Q0B018<3P0H4Q@08Q`N
00d72@0?2@/04`d?01@=500<1@`06a@K01<<4`0>1`h05PlF01D>5@0C31<04P/B0P0A2Q40200B2a80
3`XA018=500>2Q00:2<Z09:=U00b;C@04PdD0P0A31<0=@0B3A@050lF01@?5P0D4A`05aDQ01PF8P0G
5B805QHS02@S<@10@4h07Al]020R<00L7bh09BPg024Y=`0R;c`0934n02Le@P0Z>DH0;ci;03A4D@0b
@e00<dA@03U;E`0hBeH0=dYE03M9E@14EV<0EFIc02loC00]?4T0;ca702hiA@0[=D00:S8m02L^>@0Q
:3<07b@`01hQ:`0i?4<0:RXb028R:@0Z:c00<S4g01hM8P0I61d06QPK01/I700G5AP06A@H01/F700A
318061<J00805Q0J00`04`/G01X@700J4QX060lG01P=4`0B1`/06Q0A01@93@0F2`l050T=01`A5@0F
2`l301<830805@X>0P0D2@d0300A1@L060`>01D92`0A1@L05`/=01@82P0<00805PX<01lC5@0<0@80
40@601<72@L04PH800D04`P901041P0B1PP050P:00`20`0201@920804`P700X05@X901D:2P0A1PD0
40D500l40`0?10@04PL601@9200>10D03`D6100A1`P02P0?1@H05@/<044g>00D2`/05@/<00l61`0B
20T04@L801061`0A1`P201882@804@L80P0B20T0:@0A1`P040H701862P0A1@T05`/?01862P0B20X0
;bDW01P<400C1`/05@T=01452@0?0`L04PH:00l5200?1PP081DI00/2100D2@d030<501<8300O5QP0
BCi200l5200>0`L04`P<01P=4@0@1`T04`T<00/2100B20/05P`?00l4200=10H0FDiB040f>@0N5AL0
<RL[01<8300@1@T04@H:00804`P<00<0:1dQ01lD600?10P00P0@1@T02`0D2@d04@H:00d21P0D2@d0
4`P<01052@0C20`07A8F00h51`0N4aL03085008040D900<04`P<01052@0A1PX00P0A1PX01`0@1@T0
4@P:00T00P0F2`l04@H:01D:3P0?1@P00P0A1@T201862P<04`L;0P0B1PX00`0A1@T040@801042002
01462P804PL;0P0A1PX0100>0`L03`@801052@0@1@T200l4200800d2200F2a404`P>01873@0=0PP0
5@X@01873@0A1P`201052`803`@:00H03`D:01@:3`0A1``02`86038W;@0A1P`601873ACooooo000K
ooooo`0:00H0100A2`d02P@400D0000;1P<030L300h91@0>2@H03PP800l92@803`T;00d05P/?0187
2`0C20`06PlC00l51`0E2``040H701<92@0B20L04@L601881P0D2PP0718C00804`T:02D04@L800l5
1P0A1`P04`/;01`B4`0900002@0100d3100K4A80718A04Pn?@0B20L05P`;00L0000A1`H05P`;00d3
0P0>10<03`D401471P0E2`X03P@50147200D2P/05@/<01L=3P0:00404`T:01P>3`0G3@h04`T:0188
2@0C20T04PH801<72@0E2@/05PX<00805`/=01@040@601D92`0E2@/040@601H:300D2@X06@l@01L=
3P0D2P/05@/<01882@0D2P/0DdU:05iDE@0E2``040H701T?400K4A801`0001L=3P8060h?00P07Q@E
02<I6P0J4140308301dC500G3@h04PP901T@4P805@`?0`0D2`h05@0B2@`04`X=01@;3P0D2`h05@`?
01H=400F2`l05`/?01P<400J3a<06a0D01T?4P0G3Q407QDH02HP8P0M5aT08Q`N01<=3`0@30d04Ph?
01@@4@02014=3P0=01HB4`0G4a@04`l@02LS900U8B806aLH01HB4`0E41@05a8F02XU:@0R7B406A@H
01D@500201PC5`0G01/F6P0J5AT061<G01/I700S8RL09B@Y024P9@0E51T05QDJ010?5@0G5Q`071/R
01`K8`0M72@08B0Y01dM9@0V:Bh06b0T00`A5@0/<cT072<Y01/R:00O:2l00P0K92/07`0N:34092hg
02La>P0W;cX07bHc02<[>00U;CX08R/g02H`?00T;SX082`h02@`?00]>DD0;3Q402Tf?`0T<cX09cDn
02dkA00c@D`0:cU602@a@@0^?4X0<d5<03E3CP0`?dL0;3]201l^<`0^@4@0<D=702Xl@00`@TH00P0[
?4<0900Y>T40:ca30312AP0gBDd0>4Y>03Q9D00lC5X0?TiM03Y:F@0b@U40=TIE03e=FP0fAU80>DYD
04=DGP11DUX0>4UA041BF@0fBDl08C@j03A7C@12EE/0@EAJ051SJ@10DeT0=4M=03E8CP0jCE<0=4M=
03=6B@0/?Sh0;T1002do?`0`@T80<D=303a>CP80@UAD00l0<TA40312@P0dATH0=TQ<045BFP0oD5P0
>T]C06QiP@1TMGd0>4UA03I7C`0]?TH0=4E=0393B`0X>D400P0/>d00100_?T<0<d9703A3B00a@4D3
02hm@P0302ln@`0`?d@0<D150080<d1600D0;ca2030m@`0f@dT0=dA:02`i?`0202hk@@0302`i?`0]
>T00<3e300<0;ce00`0^>d40100]>T80:cQ002Xg@00/>D8202dj@`0]02hkA00[>440;CY302dj@`0Z
=Sl0;SQ202Tc?@0_>480:30k024Y=00W;SX0;cM202dg@@0[=Ch0;SQ103@mAP0`>D8092df02`c?@0X
;cX0:C0j02L[=P0`=3l09bhh01lY<`0S<3T07BLa01TS;@0R:cD08BTd02<Y=@0I7RX06al[01<E8P0E
5R<0<30l05=CG`0V9S00;Rhh05YJI00_;cT0:b/e01hN:00T92h08b<]00807QhX01H08R8Z028V9`0W
:b`07b<T01lP900U9R/092DZ02DT;00O72L07Q/V02XV=00/:3H09B<`01`K:00L72P0820/01PH900S
8bl05aLS020P;00O7b/07QhZ0P0O7b/09P0P82`07AXX020L:P0Q7B/08Qh/020L:P0L62H05a<Q01TE
8`0R7R`08Ad[01lK:@0N6bL06AHQ01XG8P0M6RD05Q<N018?6P0D4A`05A8M01TF8@0E4Qd07a`W02@Q
;00k>DD0HV1]02l]>P0H5R807Q`W00X84`0N7BD0GUeU00811`0B4AL08b8X01LF700h=S`0<c0g0P0G
51/0200R7bH07Q/R01`I800H5A`05Q<J01PE700F4aX061DL0P0G4QT02`0N6B009R4X02@O9P0I51/0
6aHM01HA600=20l061<J01D@5`0?2Q407AHM00804``C00<06a@K01L@5`0E3QD00P0D3A@08`0E3QD0
5PlF01PA600J4aX06Q<K02PQ:@0E3QH050dE00l8400>1`l050dE01L@600H4AT05@hF01L@600L5Ad0
5PlG01PA60080@P06A8I01/E6P0H4QH04P`@01D?4P0F41806Q@F01dG6@0D3Q005Q0B00l92`0B30h0
5a4C01@>400@2P`03`T;00805Q0B00<02P@601`F600E3a400P0G310201H;3`805@X>01X04PL;01D:
3P0C20`05@X>01X?4`0H3a807aLJ014;3@0R71h0?cTk01dG6@0H4Q@05Q0B00@000070@<07ALI00`6
200J51H03PL>01H?5P0;10/04@XA00l83`0B2a805@hE01@=50<04``C00D050dD01D@5`0I51/030L>
01<>5@0200`73P03010;4P0A31<04@`C00<04PdD01805Q<M01/I900J62@05aDR01PF8`0O7b`09RDc
010B7`0B52807R0_02LY>00T:ST07b/i020/>P0R;S`0938o02dkB00fA54202loC00G03I6D`0cAE40
<TA@03E7D`18FVH0F6Qe02dlB@0]>dH062@`02Pc?P0W<C/09blj02D/=`0M92h07R8]01TM9P0b=C`0
61PP01HF7@0L7B8061LM01lN8`0H5a`00P0C4A@07P0B41<061<G01D@5P0N6Al04PdD01hH8P1bK7H0
7QHP00`22`0M4a/04`X@01<8300K41@06a4B01T>4P0J3a<05P/?01lD600J3a<05@X>01@93@0E2Ph0
4PL;01462P0F2`l050T=00l31@0C1`T050P:01451`804`L900H06Ph@00`10P0<00808QHH01@82P0@
10H601<72@0601T=3`0E2@/07A4C01/?4@0C1`T07a<E0P0A1`H201L=30<04PP700L04@L600l5100@
1PD04PP701<9200A1`P040H700803`D600T040H70147200C2@X07aDF01882@0;0`<08ALH00d3100A
1`P00`0@1PL80147200701D93@0@10P0200000/10`0a9BT0TXJ:01T=4@0201862P0N0104200B1PX0
5`/?01H;3`0C20`01`0001H;3`0A1PX05@X>00h41`1<@DD0Vi2D01lD600<0@D0308502HK7`2SV9`0
6PlC00L0000<0@D06A0B01@93@0B1`/0JEiR05E:CP0=0PH0714E01462P0?10P04@H:0P0C20`0500P
5AT05@X>00/0100A1PX06PlC01/@500<0`D04PL;00d21P0B1`/03P<701D:3P0;0P@02@0200L0000F
2`l0304501L<400>0`L03`@80P0A1PX01`0@1@T03`@801<8300700003P<700P00@0>0`L00`0@1@T2
01462P804PL;0P0A1PX301052@0700l4200A1PX04@H:01462P0@1@T03`@800h31`0201052@0:0146
2P0@1@T03`@800h31`0>0`T04PL=00h32@0M4QP060dC00/01P804@H<00X040D;00l42P0?10X03P<9
01873@0=10P06@hD00d2200>0`T02@040`0A1P`301873ACooooo000Kooooo`0800`61`0C3@d02P@4
01TC4`0/9b@03`X7014<2@0@2`T3010:2P09010:2`0B1`/06PlC01872`0C20`03`D701@:2`0B20T0
4PP800804@L600H050X801L=2`0P5QL03`H701061`0E2``401<92P8050X;00h04`T:00`3100@1PD0
60h=01T?3P0D2PX050X901D;2P0@1PH03P@401<9200D2PT04@L601881`804PP900@050X;01L=3P0L
4Q<040H70`0A1`P201<92P0501@92P0E2@/05@T;01D92`0F2P`00P0E2@/0200?0`D0710B01lC5@0E
2@/060`>01<82@0@1PL05`d>0P0C2@X0500K4A804`T:03P^;`0h;Rl05Pd>01D;300C2@X05`d>01D<
3@0J4140;bDV01492@0H3Pl06@l@03/a<P0/8R<04PP901T?400A1`P05`d?0P0E30l201H=400301L>
4@0D2`h050/>008050/>0P0E30l06`0I3Q806a0D01`A5@0G310050X>01D<3`0>20T0@S`n075[K@0R
7Ql04`l@01@@4@0F4Q<05A4B01HB4`0K5aP071PI01PD5@0J5QL04Ph?024M7P0P71d05a<D01XF5`0H
5QT04@lB01/I700201PF6@0h01HD5`0G5AP05aDH01XH6`0I5aX05aDH01`K7@0D51H05aPJ01<D5P0M
7R8061TM01XK7`0I6Ql07b0U01`M8P0M7BD0820X01LI800G6Ql082DY02<X;01MI6X08RT_01dT:P0M
9Rd06b@[01dV;@0P:S<08bdf024[=00U;CP09Rhi028Z=@0Q:cD08bdg028/=P0U<S/08Rlh02Ld?@0^
?4D0:cU202Dc>`0S<SP0:CPo02Le?@0b@4/0<d5>02@b?`0^?4T0<d5<03=1B`0^?D@0>4M=0310A00^
@D8202i2@`0W03A7B`0[?T@0;d9902m2B@0cATd0>DaB03]>E00dAd`0;T5803M8E`0cA5@0<D9B0393
D`0eAeD0=dUG03]=FP0lCUX0A5IR04aNJ@0kCEL0=4M>03A7C@0fBDl0=DQ>03M:D00iC580=4M=03=6
C00dAdd0=dY@03I9C`0dAdd0<dE803M9B@0fB4P0=dU903=5A@0kCDd0<TA400<0=DM700H0<D=30312
@P0`@TD0;d1703E6C@0b@dX203U:D@0402dnA@0lCE@0=DI=02`mA080<T=:00X0;Ca10350A@0d@dP0
<D1502ln@`0b@DH0;Ca102hm@P0`?d@0<D150P0`?d@02@0`?D<0<Sm5030m@`0`?D<0<Sm502ll@P0[
>3h0;CY002hk@@0202/h?P0g030m@`0]>ch0;S`o02hl?`0^>d40;CY002/h?P0_?4@0;CY202/h@@0/
>D80;CY302`i@P0]>dH0:3I102Tg@P0Y=D40:3A002`hA00Z=400;cU502/e@@0Z<Sl0;3A102L_?00^
>4@0=Cm:03<mB00[<ch09Bdg02D^=`0Y<3T09bhg02H]=00S:2l0;30g020W;P0P:C408B/d024Z<`0I
8R/07BD_01TP:P0P92l07B4/020T;`0J72P092Hb02<U<@0[:cL07al[01dM:@0i>DD06ATU028R;P02
024Q;@0G02<S;`0T93008R8^020P:@0/<3809RX]01/O8P0N8RD09BH[01lP9@0L72@07A/V01XH8`0O
72L08QlZ01lM:00N7BX09BDa028R;P0[:cL0ATIB02DU<@0O7b/01@0P82`09P0Q7b`08b4^02@R;`0R
82d07adZ01dK:00H5R<06ALT01lM:P0M6bP06aTV01dK9`0F4ah0:2D`02LT;`0I5R408AhY01XG8P0D
4A`06aPS01lL9`0F4ah06aPS01`J9@0F51l06aTT01HD7`0H5R007QdU01XI8@0920h08R4W018A5`0O
7R<05A@I02`Z<00K61l04@hE0P0F4aX01`0D4AP05A8I01/H7`0I5Qd05Q<J01/H7`0F4aX00P0L5ah0
3`0O6R408QdT020K8P0J5A`050lF01lJ8@0F4AP05A0G01PC6P0F4AP0614H01TB6@0H4AP05a0G01TB
6@0301H?5P0;01L@5`0F3aH05@hE01<<4`0[92`0?SLo03Xc>`1:@d/05a0H01@=5@0H4AT00P0F3aL2
01L@608050dE00d0?3Hm059;DP0>20h05a0F01@>4P0E3a<04`d@014;3@0F418071HH01D?4@0O6A/0
50h@00804`d?00P04@/=01H@4P0B30h04@/=01PB500>20X0CdU;03Pb=0805``@0P0F2`l201D:3P0>
01T>4P0L4AD05@X>01D:3P0I3Q8050/>020I6`0V828030H801H@4P0<1PP04@/=01<=3`0?2@/301PB
500401D?4@0B2a80?3Dl014:4@805@hE00l04P/B014:4@0@2A0040T@018;4P0C31<050dD00h:400?
2Q403PT@010;4P0D3aH05a8I010;4P0A31<0100B3A@04P0B3aP06AHQ01HC7P0B3aX04a4N01/I9P0G
5b<0:bXh01hN;00T9S<0828_01lU<P0M9c<08B/g02D_>`0S;SX0:cI2038oB`80;3Y502L0<D1;02m0
BP0]?TP0;3e802XjA`0dADl0:SU402dkAP0U<S`0EV1Z02Ta?00R:C<09R`f02@X<`0O8bh08B@]01PK
8P0N7RH07AhT01XK800I61h07ahS01TH7@0G5AP061HI01HD5`0H4aL05Q4G01PC6@0N6B006aHM059=
D`0H4AP07Q@L01T?5P0D2a00714E01872`0F3@h00P0F2`l02`0C20`07Q<G01P=4@0?10P04PL;01`A
5@0D2@d03`@801dB5P0L4AD05`/=00<04`L900P040@601/?4@0F2P`05@T;03@X:P0f:R`05``=0186
20H04`L900P04PH801H:300B1PP03`<501451`0B1PP05@/<0147208050X;00D03`D601<92P0B20T0
4PP90147200301061`0?01882@0@1PL03`D60147200G3@h0718C00l51P0C2P/05@/<01lE5P0C2PX0
40H70147200@1PL03`D6008040H700<04@L801882@0@1PL00P0@1PL09P0A1`P04PP901452@0@1@P0
4PH:01462@0@1@P050P<01<72`0?0`L04@D90104200?0`L04`L;00h41`0c:2`0RWn301hC5`080040
4PL;01462P0@1@T07aDH01472P0A1PX040D900h51`0]8RH03`D801892`0@1`T040H901H;3`0>1@L0
5@/>01P=4@0?1PP04@H:0P0?10P04P0B1`/04`P<01872`0>10L03@@601462P0@1PT05P/?01/@500F
2`l0<BHZ01D:3P0B1`/02P0300l4200D2@d050X=00d21P8040D900<05``@01052@0A1PX00P0D2@d0
200C20`040D900T00P0F2`l04PL;01<8300>0`L04PL;0P0@1@T201462P804PL;0P0?10P201052@03
01462P0B1`/04@H:00804@H:00<040D901462P0A1PX0100B1`/0200A1PX040D901<83P0J3aD04@H<
01D:400F2a4050T?0P0@1@/400l42P804@L<00D04@H<01873@0@1P/04PL=00l42P0201052`030146
300B1`d04PL=01Cooooo000Kooooo`0Z01`G500C3P`02@<302LQ8@25Ogl050h>01/E5@0N61P02P@4
03<];@0E41003@L701@93@0B1`/07Q<G01@93@0D2P`02P0101D;300A1`L03`D401471P0A1`D040H4
00h41@0@1PL03P@50147200C2@X04@L801H<3@0700006a4B00l61`0K4A804PP901471P0D2PT04`T8
01@:2@0B20L03`D40P0B20L201<9200@01881`0A1`H04`T:01dC500:00405@/<01/A4P0=0`@050X;
01H<3@0K4A804@L801/A4P0C20X05@T;01<72@<04PH80P0C1`T01`0E2@/05PX<01D92`0C1`T04@H7
00l51P0B20T00P0G3@h201882@0;01P>3`0C2@X05@/<01L=3P0A1`P06@l@01X@4@0B20T07A<D01/A
4P0L4Q<00`0E2``01@0D2P/04`T:01882@0C2@/04P`>00<050h@00X04`d?01`F600600805@lA01@>
400I4aD0610C01X?4`0I3Q805Pd@0P0D2`h03@0E3A004@/=01lI6`0W8b@040`=01HB4`0I5AH04Ph?
01TE5P0B3Pl04`l@01HB4`0C3a000`0F4Q<02`0D41405Q8C01`H6@0C4A@06ALJ01@B5@0F51L09bDX
02<Q900J61/06ALJ00805Q@G01/061HI01PH6P0J6QX071hN024R900P8B<07AhQ01hO8`0B4aL071dR
024R9`0R8bP05AHK01hQ9P0L7b@07R<W01dR9P0N9B/08RT_01dT:P0N9bh07BH]028[<P0Q:c@06bD^
01TS;00V<3T00P0R;3D01`0U;cP09C0i024^=P0S<3P093<j02He?00W=Sd00P0T=C`0:00W=S/0;3]2
02Th?`0T<S/0;3Y5020^>@0^?4L0=D=>08FCW011D5L0<D150394AP0Y?3/0<TI703A8B@0/?d@0@eEO
059TKP0iBeD0?4iH0394CP0fBDl0=DQ>02Pk@P0dAUD0>T]K03]<G00iBUX0>4YH03Y<FP0iBeT0<TA@
03e?F`0a@dl0<dE?03M:D@0jCE<0>diD03Q;D@0bAD/20313B@0N03]>E00eB4h0;d98051SJ@1aQ8X0
?U1C03M9B@0bA4@0=4I603E7A`0a@d<0<TA403=5A@0`@T80<TA403E7A`0dATH0=DM:03M9C@0[?D40
;Cm303e?D`0eAd/0;T1402`n@P0[?D40;d550394B00cADT0<T560P0a@4D09P0eA4T0=4=802dl@@0Z
>Ch0;ci302hm@P0/>d00;ci302/j?`0^>d40<Ci4055NI011CU@0=45702`i?`0`?D<09c@j02Hc>@0a
?T@0@TmE03M4BP0d@TD0;ce002`j?@0[>3h09c@j02Xg?@0[>400;S]302hkA00[>440;3U202hkA00_
?DP0;3]602Tg@P0W=D00:3E10P0Z=T80>@0h@dl0EEm[04UCG`0V<3`0;CM302`eA00`>DL092hj02@/
=`0Z<S`07RL`028Y<@0V;C@092`_02<X;00R9bX082DY01dT;00Q:3007B@/01PO9`0J82P08RH_01dQ
:P0O8R/06ahW01dP:@0V:C809bXc028R;P0W9c<0:BTe02@T<00N7RX071`X02DU<@0Y:CD092@`01`L
:00Q8Bd0:2Pb01hR9P0R9bX06AhQ02T/<@0U:2d07b8W01/K8`0N7RH071`T01/J8P0N7BD08R0[020P
;00O7b/07QhZ01dM:@0201`L:00E01lO:`0P82`0820/01hN:P0K6bL06QXV02@R;`0E4b009R@a01dK
:00V93405A<P01`J9`0=2aP05A<P02DS<00I5b@07a`X01dJ9@0L6B@06aPS00<06QLR00h030TD02<P
:`0Y9S406QLR01@A700N72L07adX01dL900J6B405A@L01<B6P0H5ad06APN01PG70806QTN00@06APM
01LE6`0F4aX05a@K0P0H5A`201LD6`D05Q<J00H05a8I01TD6`0J5A`06A@K01LB6@0E41L601LB6@07
01PC6@0G4QP05Q4G01@?5@0C3Q@04PdC01@?5@02018=4`804`hD01D05a8H01L@5`0E3QD050dD01L@
5`0I4QT05PlF00`5300?20l050dD01H?5P0H4AP06A8I01094@0j<c/0D4U@01dF7@0E3a@08A/O014;
3`0B30l00P0C3@l0200B30h04@/=01XD5P0I4aD0618D01H@4P0C3@l04@/=0P0C3@l0100A2`d03`T;
01LA4`0@2P`401P=4@0@01D:3P0?10P06PlC01P=4@0E2Ph050T=01D:3P0D2`h04@T<01H@4P0A2`d0
5Q0B01LA4`0>20X05@lA01H@4P804@/=00T05@lA01<=3`0H4AP0=Bhe01<<4`0B2a804``C0109400F
3aH00`0C31<08@0A2Q403`P?014<4`0?2Q4050lF01<>5@0A31<05Q4H010;4P0B3A@050lF01D@5`0D
3aH04`hE01<=5`0A2aD04`lH01DB6`0D4A`04Q0L02LU<P1@D5`0G5]X02HU<`0K6RP09BTg01@L:@0L
9340;3A1028/>00V<3`0:C<o02/g@`02030lB00b02`jA@0]>dH0=49=030nB@0[>D@0:cQ202Ld?@0[
=Cl0;3Ho02</=@0Q:3808BL`024U;P0O8R/07B0X01/N9@0W9bl07AdT014B5`0K6R006aXO01dL8@0M
6ah05Q@G01DC5P0K5QX050lE01D@5`0E41H040/A010;3`0H4QH060lD01L>4@0D2`h04`P<01@93@0G
31004@H:01<8300N4aL06PlC01D:3P0j;c<05``@01<8300A1PX060dA01lD600T6Ad301@82P0d01<7
2@0B1PP04PH801<72@0G2`d060`>01D92`0B1PP040@600l31@0C1`T040@600d10`0>0P@04`L901@8
2P0T61X06Ph@02XN800@1PL03P8400h41@0H3a006a8C00/20`0A20T04PT:00h51P0A20T04PT:0107
200?1PL040L801<92P0@1PL0308301T?401WGEh0/jVZ01dC500>10D04`T:01D;300A1`P05P`=01<9
2P0<0P<04PP902TO800U6a`04`T:014720D040H700H05@T=01862P0@10P040@801862P0C1`/60145
2@0H00`31@0T6Ad0ACXn01`A5@0:00<04`P<00d41P0D2@d04`P<00l4200800404`P<00h31`0@1@T0
3@8601872`0E2Ph02@0201052@0E2Ph02`8400h31`0L4AD06@hB0P0?10P0100@1@T06a0D01P=4@0@
1@T201462P0E01052@0A1PX04@H:020E6@1[H6@05P/?01@93@0;00@05``@00`31@0F2`l0714E00h5
1`0=0PH04PL;00`21@0=0PH04@H:01T>4P0700003`@800<04@H:0`0?10P05@0>1@P04PT<01893007
00404@P;00l72@0>1@P07A@G01H=401HCe802P4401@;3P0C20`03`@801052@0A1PX040D901@93@0F
2`l050T=01<8300201@93@0801462P0C20h04`P>01873@0>0`T04@H<01D:400<0@L201@93`0?00`1
1`0D2@l02P0501<83P0O5QX06PlE01873@0?10X05P/A00h32@0B1`d040D;01@93`0E2Q0050T?01Co
oooo000Kooooo`0/00/60`0=1`L040X:00@0000U7al0208207egN@1KEED05@l?014;2`0@2`X030L4
00l51P0>1@L091TM08UnPP18?D005P`=01061`0C2@T050X901<9200C2@L050X801D;300F30d04`T:
01@:2`0E2``04PP901H<3@0A1`P050X;00l71`0k<C801`0001@:2@0?1@@0308100h40`0C2@P05@/:
01<9200D2PT201D;2P0?01<9200B20L060h?01X@4@0H3Pl04PP900d3100A1`P050X;01<92P0D2P/0
40H701`B4`0C20T050P:00804`L90`0B1PP03P0A1@L04`L901<72@0C1`T04@D701<82P0D2P/04`T:
0147200B20T050X;01<92P0?1@H04`T:0P0H3Pl01`0E2``04`T:01061`0G3@h04`T:00X00@0H3Pl0
0`0C2@X01@0E2``05P`=01H<3@0E30h04P`>00804`d?00/050h@01D?4@0A2`d07aTK01@>400I4aD0
2P@601XD5P0I41<06@hB01H=400201D<3`0601@>400C3@l040X<01@@4@0@30d07a/L0P0B3Pl01P06
0P<0510A01PD5@0F4Q<07a/L01HB4`805a<D00D05A4B01HB4`0J5QL04a4D01TG6P0201DC5P0401dK
7P0E4aH05aDH01LE60805A<F01/05aDH01LG6@0F61L06Q`L01dN800L7Al06Q/N01XK7`0P8BD07b0T
01/L8@0O82D05QLL01/N8`0I7R80724U01/P900L8bT082L]01/R:00N9bh072D/01dV;@0K9Bh08bdf
03<mAP0V<3T00P0R;3D0<00U;cP09C0i028_=`0R<3P093<j02Lf?@0Y>3l09cPo02Li?@0Y>3`0:cXo
02Xi@00W=Ch0<Cm:02Hd?`0/>TD08Blh05UWL00[>T00;3/n02Xl?00[?ch0;D520313A`0[?TD0@59N
04UKJ@0dAU@0<dEC03I8E00gBE80<dI=0353C@0iBeX0>daL03Y;F`0hBUT0>TaJ03e?G@0lCU/0<TA@
03M9E@0a@dd0=dUC03I9D00gBU00>DaB03Q;D@80=DQ>0P0fBDl03P0[?T@0;d9803mBF01EJ6h0>Ta?
03U;B`0fB4P0=4I60394A00_@D40<TA403=5A@0`@T80<TA40P0dATH02P0dATP0:C/o03e?D`11DeL0
:ce103E7B`0cADT0;Cm302`n@P0_@DD20394B080<3m401L0<D1503=2A`0c@TL0<3m402Xi?P0^?D80
<d9702`k@00Y>3d0=4=802ll@P0`?D<0@DiD038oA@0^>d40:cPn02Ld>P0c@4H0;ca2038oA@1FHfT0
B5EK030n@@0202dk?P0602dj@00Y=S`0:SLm02Xg?`0]>T80;S]40`0/>D80?@0V=3l09SE002Le@00W
=D00:cQ302hjAP0_>dL0;SU503]5D@0g@Dd09c4m02dg@`0_>DD0;CM302hh@P0^=T40:C8k02D^=@0S
:S809B`a028Z;@0R9bX08BHY024V:P0R:Bl08bXb020W;`0L8b/07B8[020T;@0R9Rl0:bhg02<V;`0J
7BH07B0Y02<V;`0O7b/08b<_02HV<P0T93008B4]020P;00N7RX08B4]02<S;`0T93008b<_024T;@0I
7R40;S<f01/P8`0M82D0=3Ll04U<D@0L72@07alW01hN9P0K6R8071/S01lN9P0P82/00P0P82`301lO
:`<08B4]0180820/01hN:P0M7BT09R@a01PF8`0F52407adZ02@R;`0H5R<05aDR01PF8`0S8Bh07Q`Y
01DC800H5R806QLR01TF8@0H5B0201LD7`0C02DR;@0O72L06AHQ018?6P0R7bX05Q<N01TG8P0N72L0
9RD]01DD700J6B406QTO01TH7P0H5ad05aHK01PG700I61d061LL01PF700301PE700301HC6P0E4QT0
5Q<J00805a@K00T05Q<J01DB6@0E4QT071LN01LB6@0C3QD05a8I01XE700K5Qd01P0G4QT02@0D3aD0
5A0F01TD6P0M61h081/Q02<N900G4QP05A0F01<>5002018=4`0601D@5P0I4QT05a0G01H?5P0H4AP0
5a0G0P0D3A@201D>5@0;018;4P0?20l03PL>01dF7P0E3QD07aPO01PA600L5A/030H:018<400C3A00
0`0C3@l07P0B30h05Q0B01H@4P0F41805@lA01@>400B30h04@/=018<3P0V82802@<5018<3P0J51H0
60dA01D:3P0D2@d05@X>01H;3`0D2@d05``@01H;3`0D2@d05@X>01L<400G3Q406A8D028L7P0I4aD0
4`d?01@>408040X<00`03`T;00d72@0?2@/04@/=010:300C31<04P/B01@=500M5Qd03`P?01PA600F
3aH301<<4`0:014:4@0@2A0050lF00l:4@0C3QD04@`C00d83`0?2Q406A@K01D@5`804PdD01<05A0G
01HA600C3AL04@/E01<?600E4Q/0514L01DB7P0G5B809B<`03Hf@`0U938071/Y01dQ;`0P:3D07RHc
02L_?00/=440:S8o0080;3I201`0;cU502diA@0[=d<0;3Q402lmB00Z>4<09S@o02Le?`0T<CX0:38l
02La>P0Q:S<08BPb028W<@0P92d07R4Z01lR:P0M82L0820X01`L8`0H6Ah06aXP01PG700J6Ah07A/N
01/I700J61/071LK0P0E41L05P0E41H04PdA01<>4P0G4A@06A0C01P?4P0E30l05@X>01H;3`0H3A40
7a@H01T>4P0B1`/04@H:01H;3`0W72005P/?01<8300A1PX05P/?01/@500N4aL301@82P804`L900H0
4PH801<72@0G2`d05`/=01D92`0B1PP201451`0B00d20`0K3a40710B01041P0C1`T03`<501L;3@0@
10H07A4C00h3100:00406@l@00X20`0600002`8301892P0>1@H04@P90P0D2``201892P0901@;300C
2@X040H700h41@0N51D0IUaM0:bRX`0O5AH040H700804PP901@03@<40147200@1PL03@<400h41@0H
3Pl05@/<00X00@0A1`P04PP901<92P0B20T040H700h41@0E2@d04PH:0104200A1@T04PH:01<72`H0
4@D900L04PL;01T>4P0S61`050T=01052@0D2@d06@hB00801`000`0E2Ph0200K41@0;24U01hC5`0<
0@D05@X>01T>4P0C20`040D90P0C20`01`0=0PH03`D801052@0?10P050T=00l4200=0PH00`0A1PX0
200@1@T04@H:01462P0=10H0<RL[00L0000C20`02P030P0D2@d02`0J3a<01`0001072@0M4QH02001
01@93@0?10P040D901L<400900804`P<00804@H:01D04PL;01462P0@1@T03`@801@;3P0?1PT040L:
00H0000D2`h05Pd@01/B5@060000ASe00;6XZ`0d:bh030<601<8300?10P040D901462P0@1@T00P0C
20`07@0A1PX040D901462P0B1`/040D900d2200>0`T04PL=01<83P0@1@/0304701/@5P0=10P07A8H
01lD6P0A1P`05``B06QMH`1TFEl03@8800h32@0>1@T081DK01T>5018?D<04PL=00h32@0B1`d040D;
01Cooooo000Kooooo`0J01PC3`0A30T050h=01<=3P0B30h03`T<00l93@0I51H05Q0@00T4100D40d0
30L400`3100h;C406@hB04Xo@`0R61X04`T:00l51P0B20P04PP701061@0?1@<040H401T?400H3Pl2
01@:2`0801<92P0?1@H04@L800d51@0F30d060h?04@j>`0C2P/201<9200301D;2P0D2PT04`T80080
4`T801405@/:01L=300F30/04`T801881`0F30d03PD501H<3@0Z8240:AlP01H<3@0E2``09A/L01lE
5P0@1PL050X;01882@0201@82P804`L91`0D20X04P0B1`T04`T:01D;300G3@h05P`=01@:2`0K4A80
5@/<01T?400D2`/050X;01hD5@0F30d04PP9020F5`0C2@X03`D601T?40H05P`=00@05@`>01<=3`0D
3Q0050h@0P0E3a401`0N61X02@@501dG6@0C3@l04@/=01<=3`0H3a800P0G3Q4201@>400@01D?4@0E
4A807ATJ028N7`0>30d09B<T01@B4`0I5AH04`l@01XF5`0H51D06ADF01LC500F4Q<061@E01XF5`80
61@E00<06ADF01<A500G5aT00P0G5aT0100H61X03Ph@01LG6@0G5aT201PH6P0;01XJ700K6ad06A/J
01`P7`0K7ah06AdL01TM7@0G6a`05a/N01hR9@0K7b800P0O8RL0400^<CH0724U01lT:00N8bL07bH/
02<Z<00N9B/07bP_028[<P0U;SD08R`e02Tc?00mAe0092hg02<]=P0T;SL302@a>@0302He?00V=Sd0
9SLn00809cPo03409cTm02Th?00X=c`0:cY002`j@`0e@dh0;3Y503A2C00V=3d0=D=;02Th?P0d@dH0
:3Xj02]0?P0Z?d40;dA90314CP13EVH0BUa^03Q;GP0cAUL0?E1P03U<FP0aADl0=d]E03e@GP0kCU`0
>DeI03Q;F@0jCEX0?51J05=WL012EUl0=DUA0396C@0gBe80<dM=03U<DP0kCU@0>TeC03M:D00fBDl0
=DQ>03Q;D@0bAD/0=TU?02i1A`0hBe40?4mB0080>D];00L0<dE502m1@@0a@d<0=4I603=5A@0bA4@0
<dE50080=4I60140=4I703=5B@0cADT0;Cm302i0A00cADT0<D=702m1A@0^@4@0<4960394B00a@dL0
<3m40350A@0b@DH0;ci3030oA00203E4B@0G02ln@`0Y>3d0<D1503E4B@0`?d@0<Sm503M4BP0_?480
934g02dj@00^>d40=45702@a=`0/>Cl0;ca202`i?`0_?480;C/n02/i?00/>Sd0;CY002Xg?@0/>Cl0
0P0]>T80;00^>d@0;CY302/h@@0]>d@0;Ca802dmBP0[>dP0:3Q502ThA@0]>dP0<Si<02/gA@0Y=D<0
;SM602lhA`0Z=400;SQ302La>`0^>480;cQ202@]=P0U;SD08RT`02@/<00U;C009BX]020U:00P9BT0
9R/a02<W<00R9Rl092Pa02<W<00N8R/0;2lh01hQ:P0K7RL0:Rdf02lb>`0L7bP07AdW01hN:00O7bT0
8R8/0P0S8bd0500`<3X08R8/01hN:00S8bd08R8/01dP:00T:Rh0@4E902hc=`0K82@06A`Q02@W;00P
8bP09bP]02HW;00R8bP08B0V02<R:P0N7RT07al[0P0P82`2024Q;@03028R;P0P82`07QhZ00807AdY
00h07QhZ01lO:`0Q8Bd07al[028R;P0Q8Bd0GUiZ01lO:`0A4Ad0820/01`L:00T93006aTU01dJ9@@0
71TT01005a@O01TF8@0Q7RT071TT01PE800R7bX0FeUS01`K8`0O7RH07A`S024P9P0F5A/06APN01XI
7P0K6Ql06QXM0P0J6Q`04@0K6Al06aPO01XG7P0H5A`05A8I01<@5`0F4aX06QLN01TF7@0F4aX05A8I
01@A600R7B@07APO01PC6P0K5Qd071LN00L05a8I0P0G5AX02P0F51T05A<H01DC600D4QL06ALL01PF
6`0C4AH040hC01<A5P0F4aT401PB5P0301H@500B31005@lC00805@lC00/05Q0D01PB5P0H4AL04``D
01@=500A2Q404``C018<4@0F41@050hB01D?4P0201H@4P0301D?4@0D3Q004`d?00@050h@00<04`d?
01D?4@0F41800P0C3@l01P0H4Q@03@L901X?4`0F2`l05@X>01L<40806PlC00l04`P<01@93@0E2Ph0
5P/?01T>4P0J4A@06A8D02DO8@0L5QP03`T;018<3P0E3a404P`>00l92`0B30h00P0C3@l0200E3a40
4P/B01lH7`0@2A004@XA01<<4`0@2A005@hE0P0C31<02P0D3A@04P/B0109400G4QT040/B018=500C
3QD03PT@00d83`0C3QD2014<4`0E018=500C3QD04`hE01<>5@0A31<050lG01LA6`0D4AX05A8L01HD
7`0D4Ql06QPU01lM:P0K6bL05aTV02DZ=P0M8bl08BLc02T`>`0L8bl09blj0080:34l00D0:38l02Pd
?@0X=3d0:3Dn02@b>`0202<`>@07020/=@0R;3D08RXc020W<@0T:3408RH_020S;002020S:P0S01hQ
:00G5al071`S020Q9P0G5Q`06aXO01TH7@0I5aX06QPK01PF6@0D3a@061<J01D@5`0E41H061<G01PD
5@0F4A006Q4A01T@400G3Pl05P/?01L<400I3Q803`@801X?4`0G3A005``@02XO8`0o=3P05@X>01@9
3@0C20`05@X>01H;3`0E2Ph00P0E2@/201@82P<04`L900T05PX<01L;3@0E2@/04PH801<72@0G2`d0
40@602DI6`0Y7Al00P0G2`d06P0C1`T04PH801@82P0B1PP05@T;01@:2`0A1`/03`L901T@4`0N5AP0
40L:00d41`0?1PT040L:00l62@0=10L03PD801482`0=0`@04`T:01061`0A1`P06@l@02TO800H3Pl0
3P@50P0A1`P01P0>10D04@L801882@0D2P/04@L801061`804PP900P04@L801<92P0D2P/04`T:00l5
1P0>10D05@T=01862P804@D900<04PH:01<72`0B1PX01@0B1PX0600D2@d04@H:00L0000F2`l04`P<
01462P0>10L05P/?01872`0A1PX0<2HY03`b=@0I3Q809Q/O02LL800=0PH03P@701H;3`0B2@/040L9
01872`0=10H03@<601<8308040D900@0308501462P0C20`04PL;0P0A1PX04@0@1@T04@H:01462P0B
20/03`@801072@0A1`X02@0201462P0B1`/03@@6038W:`0m<cH040D901472P0B20/040D900804@H:
00@04PL;01<8300@1@T04@H:0P0E2Ph05@0C20`040D901D<3`0=10L050/>00P00P0P5aX06A0C04e4
A`0G3Q4040L:020G6P0<10H04@T;01<8300?10P04@H:01872`0@1@T04`P<01872`0201462P0H0187
2`0D2@d04`P<01873@0A1P`03P<900d2200C20h060hC01D:400_92X060dC00l42P0F2a4050X?01X?
5@0K4QH081DK00T0100H3A<02P4500l42P0e:S001`020P0B1`d00`0G31;oooooooooo`0Booooo`00
6oooool09P0910005a8?00T40@0>20X03`T<00l93@0A2`l040/=00`61P0@2PX050l;02XU8@0B20T0
>2da01X?4`0800406@lA00`20`0H3Pl04PP801061@0D2PT05@/901<91`0D2P/05@/<0147200B20T0
4`T:00l51P0P5QL04PP901X@4@0H3Pl03@<401D;300E2`X030810P0=0`802`0A1`H060h=01471P0C
2@P05@/:01@:2@0A1`H040H501<92P0;0@802P0100808ALH00L01`0001`B4`0C2@X04@L801X@4@0F
30d04`P:008050P:00@04`L901@82P0E2@/05PX<1@0E2@/0200E2P`050X;01T?400X7Ql0:R0Q01dC
500I3a002`420P0A1`P02P0J4140;bDV01lE5P0@1PL03@<401H<3@0c:BX05P`=01D;300H3Pl201L=
3P805@/<00`04@X;014=3P0F4Q<05a<D01DA4P0A3@h0100102DQ8P0?2``02@D601HB4`0K5QL201L>
4@0K01D?4@0F41805Q0B01@@4@0L61T08AdN01TG600M6a`0C4Y;01`J6`0B3Pl0>SHg01TE5P0L61T0
=c<d01`H6@0G4a@06ADF01/G600J5QL06ADF01TF5`0F51L05aLI01HF600H61X06a/M00805aLI02@0
6ATK01XJ700K6ad07AdO01`M7`0L7Qd082@R01/O7P0I7A`0720P01TM7P0G6a`06QhP01TM800T:2/0
720S01@H6`0M8RH082DY01lT:00P9bd092/a01lV;00K92/07BH]02</<`0S;CH07bTb020Z<`0O;380
8Rle02@a=`0U<SP09C<h02@c>00U=3T202@f>P0/02Dg>`0U>3`09SPl02Th>`0T<cP0:STn02dl@`0b
@4T09cDn02lmAP0e@d`0:SU002`k@00`?d809CLg02Xo?P0`ADP0=DU@0395DP15Ef/0CEmg03a=I`0l
CVH0>deS03]=H00gBUT0<TEC03Y>FP0jCUT0>TiG03U=E`0eBE80=4Q?049FG@0jCUD0<TM<03I;D00l
DEH0=TY?03Y=D`0lCeD0>TeC03I9C`0eB4h203I9C`050313B@0cAT`0@EAJ03E8CP0dAdX00P0jC4`0
1@0bA4@0;3hn0312@P0dATH0<dE50080=4I60P0cADD01`0Z?3d0>D]=03Y<CP0]?d40;T1202m1@`0e
AdT00P0_@D<01P0a@dD0<TA602m1@`0d@dP0=DA90391AP80;3]003D0<T5602Lf>`17EU/0BEQM02Lf
>`0Z>Ch0<d9702dj@00kB4h0;CY002`i?`0b?dD0;S]102/h?P0^>d40<3e302Hc>@0a?T@0<Sm502hl
?`0Z>3/0:CLj02Xg?@0Y=S`0;S]103E2BP0_?4@0;CY302/h@@0Y=Sl0<d1902/kB00]?T/0:c]802Lg
A00Y>4D0<Cm<02/iAP0^>dT0:CE302Pd@P0Z=T@08Rhj02Pb>`0X<cX07RT_01lX;`0S;3<072D/02D/
<P0W;S@0;cLj02hc=`0202<X;00902DX;`0P8RT08B@[02P[<P0[;SD09RT`028U;00V:C007b8Y0080
6b0V01H061/R020P:00L72@071`T020P:00Q8BT0820X03Lg?`0W9bl07QhV01/K8`0O7bL082<Z01/Q
9`0L8bT05QdS028W;@0M8RP07b@Z01LJ7`0N8BH07b8W0P0N7b@02@0P82P07QhY01lO:`0P82`08R8^
02<S;`0T9300820/01dM:@0201/K9`8071`X00L07QhZ01/K9`0K6bL0820/03PhA02CTil0<S8n0080
5QHR00@04A4M028R;P0G5R406aPS0`0J5b802@0K62<08b0[01dJ9@0D4A`07Q/V028O:P0W92l0J6I`
024P:00201/J800901dL8P0K6Ql06QTN01XI7P0K6ad06ATK01PH6P0I6A/06APL00<061DL00h05a@K
01HC6P0H5A`06QLN01TF7@0F4aX05A8I01@A600N6B007aXQ01dH7`0I51/06QDL020K8PH05a8I00@0
4a4F01@B5`0D4QL05A<H0P0F51T06P0G5AX06ALL01DC600B41D06ALL01XH7@0D3Q805@lC01PB5P0G
4AD05Q0D01D?4`0F41@050hB018<400D3Q804`dA010:3P0F3aL050dE0109400I4QT04P`A00`62P0E
3a<05Q0C0`0F41803@0E3a405Q0B01H@4P0F41805@lA01<=3`0B30h040X<01D?4@040000<bd_00`6
200Q6ad00`0H3A401P0J3a<060dA01@93@0D2@d05@X>01H;3`805``@00T05Pd@01<<3P0G4A<050h@
014;3@0C3@l050h@010:300B30h0100A2`d01@0B2a801004018;4P0J4aX05@hE008050dD0P0B2a80
100D3A@04``C014:4@0A31<200l:4@8050lF01T04@`C01@?5P0A31<040/B018=500F4AP061<J01@=
5@0B2a<05@lF01LB6@0F41X050lJ020M:00R82/06aTU01/I9P0J62D071dZ01`P;00T:3@0=SY602L]
>@0M8bl08RPd00808RXe00<092`g02@^>00V<3X00P0V<c`04`0T<CX08Rdf020Z<`0O:34082P`024X
<00Q9Bh07b<[020S:P0U9Bd08B8Z02<V;@0Q8BT09RL]02DV:`0K6R009B@Y020O900I5aX00P0H5QT0
2P0G4QL061<J01D@5`0E41D06A@H01TE5P0F40l05`l=01H>2`0F3@d201H;3`0=01H;4@0>0`L081DI
01X?4`0;00@0304501D;3P0E2Ph05P/?01L<400D2@d04PL;01462P0301D92`8050P:0P0C1`T02@0F
2P`05@T;01@82P0C1`T050P:00l31@0E2@/04PH800l31@020186200O00d10`0B1PP0710B00T0000A
1@L04`T:01XA500I4aD03PP:00T31@0>20X040X<00l92`0A2`d040X<00h82P0?2@/050/>01P>3`0E
2``0308301061`0D2P/07Q@E0147200>10D03`D60147200@1PL04PP900l51P0200d3100:00l51P0A
1`P050X;01882@0@1PL03`D601061`0A1`P04PP901@830804PH:0`0A1@T601862P0I00l5200A1PX0
40D901T>4P0;00@050T=01D:3P0?10P0304501892`1bIf/0RGj201H;3`0700003P<701<8300H3A40
3`H800L0000=0PH04`P<01872`0/8BD0<RL[01@93@0201052@0301<8300B1`/04@H:00804@H:02`0
40D901462P0A1PX04`P<00L0000L4AD02@0201872`0J3a<030<501H;3`0>0`L06@hB01872`070000
50T=00h31`0B1`/03@8601X?4`0;0@@03`@801462P0D2@d05P/?01@93@0@1@T03PD8014;3@0=1`T0
208401`F600@2P`05Q0B00@0000E3a402P@601@>400G41804PL;01052@0B1`/04`P<00l420804@H:
01T040D901462P0C20`050T=01<8300@1@/04PL=0146300?10X091TO03ld>P0900@05`hB01873@08
00<01`0202<H7P0O51X060dC01D:400G31803P<901T>500H3A<0200300<04`P>00<03`@:oooooooo
ool04_ooool001_ooooo01H04@`601@?2`0C3P/05@lA00d72P0G4AD02`D901LA500>20P0618B00H1
000<1`<05`d>01482P070000714E01872P0<0P<04PP900l51@0?1@@050X90P0E2`T0400C2@X05@/<
01882@0D2P/05@/<01882@0>1PH0308300L0000E2``0200001P>3`0@1PD05`d<028H5`0M4a820106
1@D04PP700@04@L601P>3`0H3Pl07A<D0P0H3Pl01`0K4A8030@401<92P0B20T04@L801dC500Y7Ql0
0`0D20X0100E2@/05PX<01D92`0D20X301<72@0D01@82P0F2``04`T:01882@0L4Q<08QPI01`B4`0D
2P/02@000147200E2``06Q0A02<I6P0L4Q<05P`=0147200P5QL0C493020F5`0J414201@:2`0S01H<
3@0G3@h05`d>01<<3@0A3@h05Q8C01PD5@0F4Q<04Ph?04A0@@3?bl`0?3Pi02<O80070`@03`/<01@>
400G3Q405Q0B01LA4`0F41805A4B00h:2`0D41403@/<00L51P0[:BX030X;02LS9019ADH06ADF01<?
400Y9BH02`L801LC500I5AH00`0J5QL00`0L6AX06aTL01PH6P0201DE5`0501LG6@0F5QP05ADG01LG
6@0H61X00P0I6A/06`0H6QT05QXI01dR7`0G6aX05ATH01/O7`0G6a`092PY01dQ8`0U:B`0A4Q;0496
B@0V:Rd06QlS01dR9P0L8BD07B@Z024X;P0L8bT08R/b01hW;P0R:c808R`e020Z<`0S;CH07R/a02<`
=P0202Db>00W02Dc>00U=3T08c8g028d>00S=CT09CLk02Lj?P0X?3d0<D1202<b=@0Y>3d0;3]2030n
A`0V=3d0:SQ10391B00R<CP09C@h02Lg=`0Y>c/0;41003A9CP0hC5D0;d9B03e?I`14EFl0>daX03a=
I`0iBf<0?4iS03Y=GP0dAeH0>4aF03Q<E@0iCEH0>DeE03A8C`0aAD`0?51F0080=daA00@0=DY?03U>
D`0cAdd0=dY@0P0iC58203M:D00@03=6C00mD5H0Cf9X03I9C`0hBe40=TU?03Y=D00mCdl0>de=0394
A00[?Cd0;Clo0394A00cADD0=DM703A6AP80<TA400`0=DM802<e=`0dATP0DF=U03a>D00hBT`0<dE7
02i0@P0_@D<0<TA603A6B00`@T@203I5BP0G0391AP0]?440;Ca102ln@`0X=c`0AUEJ04MFF`0X=c`0
:STn02dl@@0W=3X0>DI<02dj@00b?dD0<3e302/h?P0W=3X08c0f02Tf?00T<CL0:3Dk02`i?`0^?3l0
0P0Y=cX06`0Z=cd0:3Dk02dj@00f@d/0;ca402`i@P0[>440:3Dn03=0B@0b@Tl0<dAA02loC00Z>TL0
<3m<03Y8E@0a?d`0<Ci<02XfA00W<d40:SI402/g@`0V<3T0:C@j01XU:`0K92/09Rlf01`U;002020W
;@0=02L^=00V:bl0724U01hS9`0V9Rh08R8Z02<S:`0Y;3<0;c8i02d`=`0/;cH0:Rdd028U;002020U
:`0401TN900Q8BT07AdU01`L9080820X01L07AdU028R:P0T92`08R8Z01hN9P0O7bL082<Z01XP9P0X
;cD09B`b028W;@0=4QP02a0F01HI7P0L7b@07B0U01hO900O82D08R8Z024Q;00R8Rh08b<_02DU<@02
02HV<P03024Q;@0O7b/07QhZ00<07AdY00`09bLc02<S;`0I6BD06a/W01TI9@0e=D403`lK00`<600D
52005ADQ02<S;`0M72P301`I900G01dJ9@0N6bH071TT01hK9P0P7BP09B8]03<`>`0I5R406QPR00d<
500H5ad07A`R01XI7`0V9BX06APM01LF6`0I6A/05aLI01@D5P0F5QP05aHJ01HC6P0G51/00`0H5A`0
300I5Qd06QLN01TF7@0G51/05Q<J01DB6@0G4QT06A@K01HA600B3A@06QDL02lZ<@H05a8I0P0C4AH0
200D4QL05A<H01HD6@0G5AX04a4F01PF6`0E4aP04a4F0P0J61d00`0D3Q805@lC01LA5@0201D?4`0?
01PB5P0D3Q804P`@01@>4P0J51P06A<G01@>4P0K51`04P/B00l83`0A2Q405@lD018<400D3Q805@lB
00805Q0B00<05@lA01@>400F41800P0F4180400E3a404`d?014;3@0G4A<04@/=030Z;02PVY`0;BLY
00L10`0E2Ph05P/?01L<400H3A405@X>01052@0F2`l301L<400301H;3`0D2`h05`lB00804`d?0100
50h@018<3P0A2`d05Q0B020J700E3a404@/=01D?4@0@2P`0614H01<<4`0B2a8050dD01`E700?20l0
50dD0P0B2a807`0D3A@04``C018;4P0>2A0040/B00h9400A31<04`hE014<4`0R7B@05Q4H010;4P0B
3A@071LN024L8`0D3AD04P/C01D?5P0G4QT05Q0J01HA700I5R40518M01HD800M6bP06ALT01/L:@0E
6BD082@`03LkA`0Y;CT00`0Q9c<08P0S:cH08RXe024Y=00S;CL09C0j02Db>`0S<3T07b/d020Z<`0O
:34082Pa020W;`0N8R/07R8Z024T:`0U9Bd07AhV01dP9`0R8RX08b@Z01dN8`0I61h071/P01PG700C
4A@04Q0C01@B5@0J5AX05a8I01D@5`0E41D05Q8C01LC4P0G4Ph201H>2`0701D=2`0F30d05@X>01D:
400C20`060dA01D:3P0201`A5@0501X?4`0E2Ph05``@01P=4@0D2@d00P0B1`/00`0F2P`05@T;01D9
2`0301@82P0301<72@0E2@/05@T;00804`L900D05@T;01451`0K3a403@4300P0000201D92`0I00d1
0`0D20X0710B00X0000?10D04@L800T00`0<1`P0100000L10`0W8B<01P0200d72@0@2P`04@/=010:
300?2@/040X<01T?400F30d0308300h41@0<0`@03@<401882@020147200501061`0>10D03P@50188
2@0=0`@00P0?1@H0200>10D040H701882@0?1@H03P@501061`0E2``05`d>0P0C1`/201862P804@D9
1P0C1`/0600?10P03P<701872`0@1@T02`0401X?4`0?10P02`0401@93@0B1`/07a@H02dR9P0:00<0
4@H:01hC5`0F2`l03P<701482P0E2Ph04`P<01462P0900803@8601D:3P801`0000@05@X>00T00P0:
00<05P/?0P0A1PX0500@1@T04@H:01462P0>10L02P0301X?4`0=0PH060dA01T>4P0B1`/0714E00T0
0P0?1PP0714E01462P0C20`0304501@93@0<0@D091TM0P0>0`L05P0@1@T04`P<01@93@0C20`040H:
00l62@0D3Q002@<501XD5P0A2`d03@L901lI6`0400003PP:00@0000>20X01P4201872`0@1@T04PL;
01<8300?10P201052@803P<701/040D901462P0@1@T03P<901<83P0E2Q0040D;01L<4P0V6b406@hD
0148300H3A<04PL=01T>500J3aD01`0201<83P0E2Q004`P>01P=4`0700805``B01873@0L4AL01`02
01L<4P0800<05?ooool001_ooooo02804@/5010:200?2PL040P:01@>400=1``0610F03H_<P0?2@T0
40T8014<2P0@2PP05@/<01<9300@1`T06a0D01`B4`0e:b`04PP901hE5@0P5aH050X901471@0E2`T0
50X;01D;300B20T04`T:01@:2`0A1`P05Pd=01`B4`0B20T04`T:0P0D2P/0600C2@P060h=02DK6P0O
5A@04@L601@:2@0E2`X04`T801881`0C2@P050X901H<2`0@1`H04`T:00/30`0C2PX06@l@01<92@0I
3`l04PT901H<300J4140;bDV03`a<P<050P:00@05PX<01L;3@0G2`d05PX<0`0D20X0500F2P`05@X;
01@:2`0E2``04PP901061`0B20T05P`=01L=3P0C2@X050X;01D;300C2@X05@/<01061`0P5QL04@P9
02`S900A1`P05`d>0`0D2P/0100D2``050X;01@=3P0D3a4201@?400;01D@4@0G4Q<061<E05=>D00I
51H04`h?01TD5@0F4A804`d?01@>400G4A<00P0H4Q@06`0F4Q<06ADF018>3`0I5aP03`h>014A4@0[
:BX0>SHg01PD5@0I5AH05a<D00l;300M6AX05a<D01PD5@0I5AH06ADG01`G6P0Q7Al071XM01PH6P0G
5aT061PJ01LG6@0F5QP05aLI01TI6P0201XJ6`0S01TI6P0F5aL04QHE01/P700C61D04QLE01XO7P0F
71/05Q/K01`R900F6ah07R<V01dR9P0I7R806QlS01dR9`0L8BH07B@Z024X;P0L8bT082T`02H_=P0[
=3/09S0i024[=00W<CX07BX`02<`=P0W=3X09S<i02Dc>@0V=CX0;3e102Ti?P0V>3`00P0T=SX0<`0T
=cX0AEAF02Lf>@0X=c`0:SU003A2BP0^?DD0;3]302hmA00X=cd0;Se1028a<`0`@T<0;4=50318C@0i
D5T0=T]M03a@J@0jCVX0@eId03a@J`15FG80?e=Y03A9FP0kDEh0>4iF03A9D00cBU00=TeC03E;D@0c
Bdl0>E1D0398C00hCe80;TI80357B@0dB4d0>DaB03Y=D`0hBe40=4M=03=6C00eB4h0<DA:05AWK@0l
CeD0=dY@03Q;D@0hBdh0=dU903E7A`020353@`80=4I600<0<dE503I8B00eAdL00P0bA4@0<@0cADH0
:C/m03U;C@1MKg40@E=E02do@@0_@D<0;Cm102m1@`0dATP0=TQ:0394AP0eADX0<T9702loA00a@4D0
<T56030oA00d@dP0;Se202ln@`0a@4D0:STn02Pg?00X=C/0>DI<02Xg?@0c@4H0:3Dk02dj@00^>d40
:3Dk02`i?`0W=3X0:cPn02dj@00Z=c/0:3Dj02hk?`0`?480:SLm02Pe?00`?DD0:CHn02dj@`0^>d@0
9c@l02dkA00U=D800P0Y>TH09P0Z>TL0>DUF04aLJ@0_?DX0:SQ502hkB@0`?4X0:cM602/g@`0S;CD0
7RP]024[<@0S;3<08R/b02@]=00X<3L07RH^020W;P0N92/06b0V02H[<@0R92/07QlW01dN9P0Q8R/0
:B/c02/_=P0X:c<07R4Y01PL8P0P92`09R/b01/P9P0O8BH071dR01dN8`0S92T08B8W0P0N7b@201lP
9@0B01hO900O7bH07B0V01XO9@0M8bT061hT01/Q9`0I7B<08BD/01dP9@0Q8bT0828W01lP900R8bL0
9BH[01lO:P0O7b/0820/0`0Q8Bd301lO:`0?01dM:@0K6bL06QXV01TK9`0C52006adY01XL9`0X:CD0
71dX01/M:00@4A`06a`W03<f@00W:3<07QdX00<07Q/V01D07a`W020M:00P7BP05Q<N01dJ9@0J5b80
9b@_01`I900J62807AdT01LF7@1=C5<04a<J01/J7`0I6Ah06QXO01dM800J6Qd05AHG01TH6`0J61d0
0P0G51/401PE70806AHM0`0H5A`301PC6P0301LB6@0I51/07APO00H05a8I00`05aDJ01HD6@0F51T0
518G01<A5P0B41D03`dB01LE6P0E4aP040hC01LE6P0C41D201TC5`0B01LA5@0B31004P`@01LA5@0H
4QH05a4E01/E6@0R72007QPL01D?4`0G41L06Q<J024J8@0:0`X05@hD01TC5`0D3Q805@lB0`0E3a40
100D3Q004@/=01<=3P0C3@h201@>400801<=3P0J51H040X;01D?400S7Al040X;01TC5@0H3Q4201H<
400;01T>4P0K4A@06Q0C01@93@0F2`l05`d@01P=4@0G31005@`?01@=3`0A2`d00P0B30h03`0A2`d0
4`d?01hH6P0b;2h06A<E014;3@0J51H03`T;02@L8P0X82H05PlE01<<4@0V7bD03@H<01@=4`02018;
4P0n01D>5@0D3A@04P/C01TD6`0N6B005Q4H00l:4@0A31<040/B01HA600D3aH04PdD01@?5P0E41L0
5Q4H01@>5@0B2a@05@lG01LB6P0F41X05Q4K01LD7@0I5R407Q/V01PF8@0F52407AdY028T<00H6BD0
71lZ028U<@0K7RT07b@_02DZ=@0Z<S/08b/e01XR:`0M9Bh07bTb01hZ<`0M:3806B</01hX<@0Q:C00
7bH^01dQ:P0J7B@08B<Z02HV;P0O7bL06Q/R01PJ800O7bL071`R01PH7P0J6Al05aHK01PG700G5AP0
4a4D018@4`0H4aP201D@5`0A01D@5@0A3@h04Ph=01PC400F3``05Q0;01P@3@0H3Pl05`d@01H<4P0I
3a8050X>01H<3`0E2Ph04PP;01/@500C20`00P0E2`h0100B1`/040H:01D:3P0F2``201H:300<01D9
2`0D20X050P:01<72@0E2@/050P:01<72@0D20X05PX<01D92`0A1PL04`L90P0E2@/06`0F2P`05@T;
01451`0B1PP04@D701@82P0A1`P06A0C014:300B30h0=blb085jO00F41803@D8018;3@0E3a4050d?
014:300?20X03PD601<92P0D2P/05P`=01<:2P0>10D03`D601882@04014720804`T:00X05P`=0106
1`0?1@H05@/<0147200B20T050X;01L=3P0J41406a4B100C1`/00`0A1@T040@801<72`0501<72`09
01872`0A1PX04`P<00h31`0G31004PL;01dB5P0Z7b<050T=00803`@800X04@H:01052@0D2@d03`D8
00h41`0D2@d03P<700l4200?1@P03`@80P0B1`/01`0A1PX09a`P02dR9P0B20/04PL;01H;3`0A1`X0
0P0A1PX0:`0@1@T04@H:01462P0B1`/06@hB00d41P0I3Q804PL;00h21P0C1`/03@@600l4200C2@d0
4@L<01883P0B2@`03P<701H;3`0>0`L0=BX^01dB5P0>0`L03`@801052@0A1PX04PL;01472P0>1@P0
4@/=024J701SFeh04@/=00d62@0>1PT02P@600l82`0>1PT04P`>00d6200B1`/040D901<8300D2@d0
0P0?10P00`0C20`04@H:01052@0201462P0I00l4200@1@/040D;01873@0F2a405@X@01052`0A1P`0
4`P>02hS:@0>1@T040H;0148300H3A<04@H<00l42P0D2`l04`T>0148300C20h050T?00d4200>1@T0
4`P>0146300Dooooo`006oooool07`0H3P`040L401081@0B20L04`X801H>300D2PT03PD401081P0L
4Q004`X801D=2P0:0P004``;00X50P0H3a006Q<A00@0000<10807ALD02<N6`0>1`H04PX801H>300D
2P/06@l@01061`0=10D06@l@00d3100H3Pl00P0D2P/00`0=0`@03`D601X@4@0201@:2`0500l51P0B
20T05@/<01<92P0B20T00P0A1`P03`0B20T04`T:01@:2@0F30X050X901<91`0B20H04@L601471@0G
3@`03P@300h40P0D2PP050X9018820020147200;01<92P0D2P/04PP901061`0C2@X05P`=01L=3P0D
2P/04`T:01`B4`0X7Ql00P0D2P/0500?1@H03@<402HL7@0B20T05`d>01H<3@0K4A804@L801L=3`06
00804@P;01/D5P0<1PP04`X=01@=3`0@2P`04`X=01D=400D3Q0050/>0P0F3A00600G3Q4060lB01D<
3`0H3a805@`?01P?4P0D2`h06A0C01@;3P0A20/06Q@F01DA4P0J5QL00`0002@P8@0E4A804Ph?01HB
4`0B3Pl04@d>01HD5@0J5QL05Q8C01LC50806ADF03X061@E01HA5@0P6al04@`@01/F6P0^:Bl091lU
01TD6P0K6A`06QPK01PF6@0F51D05aDF01PF5`0L6Q/071/J01dL6P0N7A/06aXH01@D4P0M7Ad06A/K
01LH6P0I6Q`06a`N01TM800R8bL07R4V01/N8`0L7b@07b<X024V;00O92X07R8Z01dQ:P0M92`07bH^
01hU;@0P:C00:C8i02`e?00V<CL08Rdc02D`=P0R;cD09C8h024^=00M:S008Rle02`i?`1KJFl0=T=9
02Dd>@0Q<3D0<T5601h]<P0T<cP09cHk0P0[>Sl08`0c@TL0;3]002hm@`0`?d@0;Se202ln@`0^?D80
:3Xn02i4BP0bB5<0<dUG03U>H`0fBVD0?4m]04QKN@1AIGh0Ig^C03M=G@0dBUL0<DMB03a@F@0lCUP0
>DeF03a?E`0lCeH0=TYA03=7C@0X>d40=4Q<0315B00_@TH0=dY?03a=E@0mCUH0>T]C0080=DI>00<0
=TM?03A5C@0dADd00P0gB500500dADd0<49503M:B00gBTP0;T4o03=6A00gBTP0<DA20395@`0gBTP0
=TU70395@`0dAdD0>T]<03Y9CP0gAT/0=TE:03=2A`0`?d@0<D150P0d@dP20350A@0@03=4B00U>3h0
<dI<03I9C`1=GVD093Dl0393BP0W>3l0;Ci502hmA00/>d80<D17030mA@0b@DH0;3]00350A@80:CPm
03h0:CHl02dh?P0^>Cl0<Ca2030k@@0_>T00;3Hm02`d?`0[=Cl0<S]4045:D`0/=Sl0:S@n02Tf?P0U
<SX082de02lnA@0]?440:CQ002lmBP0[>DL0:cU602dkAP0a?dX0>4IA02hoB@0^?TX0;3a902/hB00T
<d<08Rhn028Y<`0J82T08b/h02T`@00S;Ch08bi003Y5E`0V<40082Pc01lV<00P9BX07B8V038f?`0M
8B/0:Bdf01<G8P0Q9Bl05A`T01@H8`0N92d061lW00lF800O9Rl07B4Z02HY;P0Q8RH071dQ028S9`0S
92T07QlT01hN9P8071`T00/07alW020P:P0P82X07QhX028R;00Q8B/07AdW01@D7P0R8R`05aLP024O
:P0201hM9@0e024P:00N7BD071`V028R;00S8bd07QhX01/K9@0L72H0:2Pb014A6`0Y:C<08B4[01<C
7@0L72H06QXT01dK9P0N7RP09B@^02LU<00a<3P07QhV01TH7P0F5Q`06AXO01dL8P0P7RL06QPS01HD
7`0K6B@071XU01PF8@0G5B005Q@O01<A700E4ah06aTT01hL9`0P7bX04aHO01@D7P0I6R@09RTb01LG
8@0G6B804aHO01@D7P0I6b@051LN01XJ900H5ah05Q@I01DC600E4aT00P0D4AP00`0G51`061DN01LD
7@0201HC700@01LD7@0N6B006aHM01XE700N6B007APO01@?5P0J5A`05a8I01D@5`0H4aX06A@K01HA
600I51X061<I01HA5`8050lE00T05Q4G01@?5@0E41H05A0F01@?5@0C3Q@04PdC018<400C3A400P0F
41@01P0E3a<04`dA01D?4`0E3a<050hB01<=4@8050hB00<04P`@01XD600H4QH00P0F41@08`0B3100
50hB01@>4P0A2`l040X>01<=4@0G4A<04`d=01LA400H4a007ALG01<>300E40d06Q@D01PC4@0E40d0
50h>01<=300B30`04P`>01hG6@05004050/>01H?4@0@2P`071<F01L?4P0A2`d04`X=01H?4@0I4aD0
4@/?018<400C3A405Q0D00805a4E01@05Q0D00h8300?2@d04@/?01@>4P0K4QD05P/?01<8300F3A00
71<D01@;300K4Q<04@P;018<400C31<04`/E01084`0>1Q404@`B01@?5@8061<I00<04@`B00`73@0B
3A<00P0C3Q@0300A31804PdC01<>5@0L624050hJ01DB700=2QD040dH01TF8@0G51l061DP01XG8P80
6aPS00@06QPS01lO:@0D4Qd061PR0P0T92h0>@0L72H09RH`02XZ=00Z:S@09BD_024Q:`0M82T07b</
024U<00P92d06alX01TM9P0K7bP07B0Y01`O:00I72D06QdV01TL9@0K6b8071/P01XI7`0J61d05aDJ
01hL8@0I5a`05Q@I01DC600G5AX061HK01DC600H4aT040/A01LB5P0@2`l071PI01HB4`0D41404`l@
01<=3`0@2P`02@<701PB5P0J51H02@<501L?4P0D2`h08A/M01<<3P0A20/040X<018:3@0C2Pd040X<
0189300>10D040H701<92P0301D;300401H<3@0A1`P04`T:01D;30804`T:00<040H70147200C2@X0
0`0C2@X00`0@1PL04`T:01<92P020147200L01@:2`0900806Q0D00P00P0H3A4060hA00h5200F2`l0
50X>00d41`0>0`L04`T<00h31`0A1PX03@8602@I7@0;00@040D900/0100?10P05P/?01D:3P0F2`l0
=BX^02DJ7P0E2@d04@D9010420804PH:00<04@D901<72`0E2@d00P0G2`l06P0F2Ph05@T=00d21P0=
0PH03P<700l4200A1PX04PL;00l4200A1PX04`P<01D:3P0A1PX03`@800h31`0?10P04`P<00d31P0A
1PX0304500l4200C20`050T=01462P0>0`L03@860`0A1PX0100J3a<07Q<G01D:3P0@1@T201462P0P
01052@0?10P04@L<02dT:@0f;C805`dB0146300F2A004`H=01@73P0700804`T>00/21`0G3Q<030<8
01052`0B1@`05PP=01H72P0C10L0404401D93@0G31803PH>00L12`081A0040P@01872`0A1PX081DI
02XO8`0J3a<201462P0A00l4200<0@D03@8601052@0?10P040L:01@:3P0C20`040L:01472P0=0PH0
3@@701@:3@0D2@d040L:01052@0A1PX00P0?10P201872`0O00l4200B1`/04PL;01872`0A1PX040D9
01052P0=0PX04`P@01D:4P0A1Ph081DL00L00P0?10X04@H;01462P0N4aL02P4302@I7@0=0PP05@X@
01<83P0G31803P<900l42P0=0PP05@X@0146300=0PP040D;01@93`0Dooooo`006oooool09P0D2PP0
4`T701L=2`0F30X04@L501<91`0>108050X80106100<0P004@L500/3000B2PP02PD201PC400G4Pl0
4Pd:01XE4P0<1`@03PT800@0000D3``020<001D@3@0A1`P02`4200T0000E2``02`4201/A4P0O5AH0
2`4200l51P0I3a004`T:00l51P0B20T05@/<0P0F30d00`0C2@X04@L801@:2`0201<92P0?01@:2`0E
2``05P`=00/1000=0`4040H401H<2P0K4@l07A<A01<91`0F30X06a4?020F500H3P`04PP800804PP9
01`050X;01D;300D2P/04PP901@:2`0G3@h05P`=01<92P0B20T05P`=030V9`0Z82405`d>00T0000S
6AX0>2h_01T?400F30d04@L801@:2`0J41403PL701dG6@0L5QP01P42018<3P0?2@/040X<0P0D3Q02
01H@4P0I01@>400F3Q405P/?01H;3`0H3A405``@01T>4P0G31006a0D01T>4P0O51P06@hB01D;3`0D
3Q004`l@02/W:00H51D07a/L01<?400G4a@07ATJ01XF5`0C3a005A4B01LC500201HB4`<05a<D00/0
5Q4E01`G6`0C3Q8061<I02<N900M61h05a8I01PF6`0G5AP05Q@G01@B4`0201HD5@0C01/J600J6AL0
6aXH01`K5`0K6QH05aHD01/K6`0I6A/061PJ01XJ700L71l06a`P01hO900L7R<06QdR01/N9@0M8BL0
7R<Y01hR:`0201dQ:P0:01dT;00P9bl082L_01hW;P0U;SD0:34h02D`=P0S;S@092le01dZ<0808Rle
02X082dc024^=00U<SP0;ca2024^=00S<3H09c@j02dj@00U<SP0:3Ll02Th?@0[>Sl0:STn0350A@0Z
>Ch09cHk02He>P0Y>3d0:3Ll02Th?@0/?D@0>4eF049HI@17G6d0CF5h04AHL`18FgT0>dm[03a@J@1<
HGH0=DYI03Y@F`0fBU<0?4iH03U;E@0eAe40=dUC03Q;DP0dAdh0=4M=02m2B00fBDh203M:CP0703U;
D@0fAdl0<T=;0311B@0^?dL0;3e50393B`0303U:DP0/03Q9D@0iBU80=dQ<03E8AP0cAT@0;D0n0313
@@0cAT@0<TE303I9A`0jCD/0>Da:03Q;B@0kCT`0>T]<03A3B00c@TL0=TE:03E4B@0_?T<0;3]0030o
A00c@TL0=TE:03A3B00_?d@0:ci4051UJP0Z?D<0=TU?02Tl@P0a@TT0;d170393BP0b@DP0<3m60391
B00^>d<0;Ca102Lf>`0/>d009SDj02Pg?00Z=cd202dh?P0m02lj@00_>3l0;cPo02df?P0/=3l0<CU4
02Ta?00]=D00:S8m02Xd?P0S<3P0<3e503A1B@0Y>3l07Rdb02@b>P0^>TP0;c]:034mB`0a?dX0<Cm9
0390B@0[?4H0:SY602PhA@0V=TH08c=402@`@00R:3@082@`02H]?@0`=dT0=CiD03M3F@0/>4h07RPj
034kA`0P9c408BH/00X?4`0O8b`06B0Z01dT;P0T:cD0:2li01/R;00X;cT05ahX024X<P0M92h0<SU3
04a@F@0P8bP092DY028S9`0O82@071dR01TJ7`0O7bL07AdU01`L900201hN:00>01dM9`0R82/0518M
01LE8014@Td0>SQ301XH8`0L6RD08b4/020N:@0O7BP081hY01dK9P0N7RP2028R;00501lO:@0M7BL0
7QhX05EEG`0K6bD00P0P82X02@0D51h05aLQ014?6P0E4ah08AlZ028Q:@0H5al081lV01/J800201HE
6P0<01`K800O7R<081lV01dK9P0L6RD07Q`W01dK9P0L6RD06ALR01LE800K6B@07adX0P0P7RT03@0H
5b8030hJ00H8500L7RX04aDQ00/=6@0F62@0:2Xf01dO:`0C5B4051HR02<U<@0G5Qh00P0F51T01P0F
4aT05A8I01DB6@0G51`061DN01LD7@805Q<L00@05a@M01XE700H4aX06A@K0P0M61l201LB6@0;01HA
600G4QT06aHM01`G7P0I51/061<I01LB600F4AL050lE01D@5P0G4QP0100D3aD0100C3Q@04PdC01<=
4@0C3A4301D?4`0=01<=4@0I4aL0618F01@>4P0@2Ph03PP<00`62P0?2@d05a4E01H@500E3a<06A<G
01LA5@0201@>4P0:018<400@2Ph04`dA01H@4P0=1`L03`X700X50P0<1`@05a8?01TD4@<05A0=00/0
5Q4>01PC400J51@03PP:010;300O6A/071HH01dG6@0J51H03`T;018<3P0201D?4@0301<=3`0@2P`0
4@/?00804P`@0P0D3Q800`0E3a<050hB00l93@03014;3`0?01L>4`0D2@d05P/?01hE5P0E30/02@40
01491`0D2`d050hB01D>5@0E3AL04PXG0149500=20h03`X@008040/A00<03PT?00d83P0B3A<00P0C
3Q@01P0A31804PdC01<>5@1iMX007AXU00/84`805A8M00@0514L01HC7P0F4ah05a@O0P0H5B00400N
6bH06ALR01PF8@0S8B`020HA00h<5`0R82/0928]02DS;P0T8Rd08AlZ020N:@0O7RP07B0Y01lR:`0P
8b`201dP:@04020S;00N8BX071lX01/N9`806QdV00T07A`S01PF6`0E4aP061HK01LE6P0L6Ql06ALL
01LE6P0E4aP00P0G5AX04`0D4QL01P4501hI7@0N6Ad02`H:02@O8`0B3A40B4=701`G6`0?2Ph08QdQ
018=4@0D3a<0100001LA4`0K5AL02P@600@0000>20X01P0@2P`03P0F30d05@/<01D;300G3@h05P`=
0147200G3@h050X;01H<3@0D2P/040H701882@0@1PL04PP90`0C2@X0100B20T040H701<92P0C2@X2
0147200701@:2`0A1PX04@H:01@93@0B1`/05P/?01lD600201462P804PL;014050T=01D:3P0I3Q80
5P/?02XO8`0B1`/05@X>01052@0;00@04PL;01462P0=0PH08AHJ01052@0D20`040@800l31`030186
2P0601452@0B1PX04`L;01@8300C1`/04PH:0P0?10P01@0@1@T04@H:01<8300D2@d04@H:00<03`@8
00T03P<700d21P0G310060dA00T00P0D2`d01`0001lD600@1@T00P0C20`0200@1@T03`@801052@0D
2@d04`P<01052@0D2@d05@X>0P0A1PX201052@0K01462P0B1`/03@@801LA5@0N5AX03`D:01052`0C
1Pd05@P?01/>5@0G31802P4501H=4P0>20`040P>01052`0B1@`05@P;01L72P0D10D050D700h21P0:
00D030@=00X74P061140208;00803P<700<050T=01T>4P0B1`/00P0B1`/0100A1PX03`@800l4200A
1PX201052@<04@H:00P040D901872`0=0PH04@H:01H;3`0>0`L04PL;01052@803P<70P0B1`/07`0?
10P04PL;01872`0B1`/04@H:01052@0@1@X03`@<00X0200<0`T04@H>01883P0L4AL060dC01462`0;
00@05@X>01872`0800403`@:00/21P0800<04@H<01052`0B1`d03@8801<83P0?10X0304701052`0A
1P`05?ooool001_ooooo02/050X901<9200C2@P04@L601D;2P0R61L0ED]:01<92@0E2`X040H501D<
2`0I4@l05@`=018<300=1`L020<300l:2P0F4100618B00l92@0F41004@/;01PB4P0<1PH060l@04e3
A00k<C80718C03le=P0C2@X05`d>01D;300D2P/03`D601061`0D2P/04`T:01061`0I3a005@/<00l5
1P0F30d04`T:00804PP900L04`T:01@:2`0E2``050X901<9200B20L04`T8008050X900H04`T801D;
2P0J40l07aDD01`B4@0F30`201<92P0501H<3@0G3@h05P`=01882@0C2@X00P0F30d201@:2`0E01L=
3P0L4Q<04@L801H<3@0E2``03PD501H<3@0E2``081HG05aBD`0C2`/040H701XA4`16@480>C<e01<=
3`0D3Q002@@501@>400E3a404`d?008050h@00@04P`>01H>400F2`l050T=0`0H3A404`0E2Ph05``@
01T>4P0T6Ad0714E01H<3`0C3@l05Q8C01@@4@0C3a005Q8C01LC500=2@X04Ph?01HB4`0D41405Q8C
01XF5`0G4a@00P0F4Q<01P0E4A805Q8C01PC5`0F4AD07APL01dH7P805a8H00<05a8I01HD6@0F51L0
0P0F51L0;00H5QP061HG01TG600G5AD05aHD01TH500K6QH06QTG01XJ6P0H61X06ATK01`L7P0N7R40
7AhR01`M8P0L7R<07B0U01hQ:00N8RT07R<Y01dQ:P0N8R/07b</01dT;00P9bl08RTa01hW;P0O:2l0
8R/b028]<`0S;S@08B`b020]<`0S<3H0:3Dk02Tf?00X=C/0934g02Db>00X=C/09C8h02Xg?@0P;C<0
:SLm0P0Z>Ch09P0^?D80:CPm02ln@`0[>Sl09cHk02`k@00b@DH0;Se202dl@@0b@dX0<dI?041CH@16
FFX0C5if04=DK`17F7@0AUMb03M9HP0dAU`0=dYI049FH@0gBe@0>TaF03M9D`0cADl0=4I@03=6C@0_
@TT0<dI<03M:D00cAT/0?4mC03iAE@0kCE<0>DYB03E6CP0fAdl0=dQ@0P0eATh0200kC5@0?4eE03Q9
D@0fAdl0>DYB03mAE00eB4H0;T4o100bAD<08`0`@d40<DA20354@P0aA480=TU703M7B@0a@4D0<T56
03Q7C00iB4d0<T5603M6B`0lBe00=DA903=2A`0d@dP0<45503]>E01ZOh@0<TE;02m2B00eB4h0;d17
0311B00_@4L0<3m603=2B@0d@dX0;S]30391AP0[>Sl0;Ca102He>P0X=c`0;CY00080;3Lm00X0:cHl
02`e?00]=Sd0;cPo02/d?00[=3d0;3Dn03]5CP0_>D80:38k0P0]>T<0<@0Z=d009S@n02Xi@P0/>T@0
;SY903A0C`0f@U00=49=030nB00Y=d00:3Ho02Le@00T<Sl08c=202DeAP0Z=TH08BLc02@Y=00P9cH0
9bi003DnD`0c?U<0;3M<01LQ<P0Z<d005ahX02hc>@0V:bl06QhW01lV<00K8R`08RTc02<Z=00d>dD0
7RD_01`S;@0G7RP0:C0j07AkQ@1?De`071lT01lP900N7b<06AXN01`M8P0R8bP07QhV01dM9@0L72@0
0P0K6bD03@0L72H081lW024P:00R8BT0;B`d02DT;00K6R807ahV028Q:@0Q82P07ahV01hM9@0M72@0
0P0O7bT01`0M7BL071`V01dM9`0N7RP0JFUc020P:P0E5Al00P0N7RP03`0R8R`0EUAO07QfP@0S8B`0
8B0X01`K8`0b<CP07A`R01TH7@0H5a`06aXO01dL8@0M72<07Q`W020N:@0201hL9`03020N:@0J62<0
5aDP00<06QPS00h07adX024P;016AU807al[01`L:00A4Ad07AdY05=CG`3Gemh0Kfmk02d]>@0J6RH0
3PhJ01/J8`8061DL0P0G51/0100F4aX05a@L01PE7P0G51d301HC700301TD6`0H4aX061<J00806QDL
00@05Q4H01PC6P0G4QT061<J0P0I51/00`0H4aX05A0F01D@5P0201D@5P0401HA5`0G4QP050lE01@?
5@805A0F00@050lE01<>500D3Q8050hB0P0E3a<201@>4P<04`dA00L050hB01D?4`0F41@04`dA01LA
5@0B31003`T=00804`dA0P0D3Q802P0C3A404@/?018<400F41805a4B01HA4@0E3`l03PP801LA4@0@
2PX401<=3@0901D?3`0F41005@lA01<>3`0C3@l03PT:01@>400N61X04P`>00<04`d?00<04P`>014;
3@0B31000P0B3103014;3`0K018<400@2Ph04`dA018<400A2`l05@lC01D>500H4AH05@lC014;3@0H
4a@040X;014;3@0C3A4050dD01@<5@0A2AD04@TD018=500E41H04PdC010;4@0F4AL06aHL014<4P0C
3Q@04PdC00804@`B00L04`hE01lL9P0C41/05A8M010=600>2aH04PlJ0080514L0`0E4Qd01@0E4ah0
5Q@O020N:@0I5b807Q`W008081hY00H08AlZ020N:@0N72L07A/V020N:@0Q82/2020P:P0B01hN:00L
72H07AdW024Q:`0J6R@05aLQ01/K9@0H62807AdW02HU;00M6b005aDJ01XH7@0I5a`05aDJ01XH7@0H
5Q/05aDJ0P0F51T04`0D4QL05Q4E01dH700F4AD09B0T01<?4P0E41@0:RDY018=4@0D3a<04`hB00`7
2`0C3Q803@L902HP8P0<1PP06Q@F010:300D3Q000P0A2`d01@0@2P`03`T;010:300A2`d04`T:0080
4PP900D04`T:01@:2`0D2P/05P`=01061`030147200301D;300A1`P04PP900<04`T:0P0B20T201<9
2P804PP901d04`T:01@;3@0m<cH0YIZN01/B500C20`03@@601<8300@1@T05P/?01872`0;0@@060dA
00d21P0>10L06PlC00X10`0C20`050T=00d21P0C20`05@X>00h31`0G31002P4301862P0?0`L03P86
01452@0401862P<04`L;00D04PH:01872`0B1`/04PL;01<8300201D:3P0@01872`0@1@T03`@80105
2@0B1`/05@X>03P]<@0>0`L05P/?01472P0B20/05@X>01872`0C20`04@H:00l4208040D900@04@H:
01872`0A1PX04@H:0P0?10P201052@804@H:01X04`P<0148300=1`/03`H;01883P0C20h04PD<01<8
3@0@1@X03`D:01H<4@0=1PT05Q0D00d52P0@1PX04@D:01D82P0F20P05@H601D6200A1@P04@H;018;
4P0810h030TC01<=508050T=0P0@1@T00`0D2@d04PL;01872`0201<8300A01872`0@1@T05@X>0187
2`0A1PX05P/?01L<400A1PX050T=00X00`0F2`l0:AhR01872`0C20`060dA01H;3`0D2@d00P0C20`0
0`0A1PX04PL;01872`0301462P0I01462`0:0@L08QHP01053@0?10`04`T?01P?4`0A1P`040H:01H;
3`0;0@@04`X<01462P0A20`040H;01P=4`0E2Q003`@:01@93`0@1@/04`P>01052`0A1P`050T?00l4
2P0Dooooo`006oooool0:`0D2PT04@L601061@0>10<05P`;02TO7P1eJfX05`d=02@J6@0O5A@04@L6
01491`0G3Pl02@<300h8200O6AT030H600l92@0500004@/;028L702:Q8@07ALG00L10@0E3@d0=B//
05M=CP0<0`@09Q`M0147200C2@X02P0100`20`0E2``04PP900X00@0=0`@07A<D034W:00W7Ah03@<4
00`20`0B20T00P0A1`P0100B20T04`T:01@:2`0C2@P201881`0901<9200D2PT05@/:01H<2`0@1PD0
3P@301881`0F30/05P`<00804PP901d050X;01H<3@0E2``04`T:01D;300F30d05@/<01882@0C2@X0
6@l@01dC500D2P/04@L801L=3P0E2``05`d>028H6@07000060h?00L0000M4a@040L900`6200D3Q00
5@lA01@>400O6A/07ALI01@>4003018<3P0A010:300D3@l050/>01@;3P0I41<05`hA01H=400E30l0
50/>01T@4`0X7b807QDH01H=400D3Q006ADF01PD5@0K5aP00P0E4A800`0J5QL05a<D01@@4@0301DA
4P805Q8C0P0E4A80200F4Q<06A@H014<400Q72008ahT01HA5`0H4aT05a8I0P0E4aP09`0G5AX061HI
01PF6@0H5QT05aDF01DC4`0E518061LE01/J600J6AL06QXJ01XJ700L71h07alQ020P8`0N7b<071dR
01dO900M82D07R4X01lS:@0M8RP07b</024U<00P92l072<]01hU;`0Q:3808b`e024Z<`0P:C8082Xc
024[=00O:C807R/c01dZ<P0O;3@08Rlg02@a>@0202<`>00902llA00L:C409c@l02Hc>`0[>4009cHm
02Xi@00a@4L0:SU00080;ci500/0:SU00391B00[>T40;Se403A3BP0]?TD0;d9;0354DP0bAE@0>deR
03]<IP0204AEK`0703i@IP0dAUX0?U5P04YNJ@15FF80>TaF03]=E`0203U;E@2?03A7CP0]@4L0=DQ>
03a?E@0bADX0>diB03a?D`11DeT0DV=[05AUK@1:Ff<0?DiF03U:DP0eATh0=TM?03a=E@0jBe<0<dA<
03A5C@0lCE80<TA402Xl?00eAdL0=TQ803E7A`0fB4P0<dE50312@P0]?cl0;T100353@`0fAdP0=4=8
0391AP0eA4T0=dI;03=2A`0oCU<0A5=H03A3B00]?440<D1503A5B@0Q=3X08CHk02Tl@P0[?T@09cY0
03A5C00]?TD0:ca3030oAP0c@TT0<T5802dj@P0Y>3d093<h02/j?`0/>d00<d9703e:D00]>3h0;3Lm
02Td>P0Y<ST0:c@k02hg?P0e?TD07RL^03@oA@1WLWP0=T5702llA00H9Bh06bLc02lmB00T<Sl08Bll
02PhAP0a?Th0=D9B02lmBP0]>dH0;C]502Dc?00S<CX08c4k02@b?`0V<d<0:CI702`hB00N930092Te
01dS<@0O9SP0:314028Z?`0L93T07BDe01TQ;00O9S006R0U02DZ;P1fNh406alX01hR:`0X;3D0=SY3
02lc?00J7RL07b</02@X<@0E6B80?T9;014F700J7B805aPL01/L800L7B407QlT02<T:@0K6b<07AdU
01`L900J6R@07AdW01lO:@0L6b8071/Q01HE6`0Q82H06QTO020O9@0M728071/Q01hM8`0O7R@07QdS
01hM9@0P82X07AdW01/K9@0M7BL00`0N7RP03@0O7bT0:2Pb01hN:00>3QP04Q8L034_>P0i=d80:2Ha
01HE7@0Q82P07A`S020O9@0L6b000`0K6Ql02@0K6R4071XU01XH8`0L6RD0928]028P:`0J62<071XU
01dK9P0201TG8P0>024O:P0Y:3<0Fe]U028R;00B4Q`05ADO020P:P0/;3H0U9BN03loB@0a<C/0820Z
018B700H5R0201PE70805a@K00@05Q<J01LD6`0G51/05Q<J0P0E4QT0100F4aX05Q4H01D@5`0F4AP3
01PC6P0601TD6`0H4aX05Q4H01HA600H4aX07APO0P0C3Q@201D@5P805Q4G0P0E41H201LB60805Q4G
1P0D3Q80100F41@05@lC01<=4@0A2`l2010:3P8081XN00L05Q0D018<400D3Q8050hB018<400D3Q80
4`dA00804P`@00/05@lA02<M7`0?2@T03@L700X4100@2PX081XJ01D?3`0D3Ph04@/;010:2P0200l9
2@0501LA4`0<1PP071HH01/E5`0;1PL00P0H4Q@01@0E3a404@/=010:300A2`d04`d?008050hB00H0
4`dA018<400A2`l04@/?018<400@2Ph2018<400901PB5P0O6R005Q<M00/:4P0:2A403@/A010>4@0=
20`040/?00804@XA00X04`TB01<9500@21<03PT@01@?5@0C3Q@03`X@01<>500H4aT04@`B0P0B3A<0
1P0@2a404@`B018=500C41T04@hG01<@6@804PlH00@0514J01<@6@0D4AX0514J0P0E4Q/0200L6R<0
2PTA01lN9P0Q82P07QdU01/J8P0P7bL071/S0P0N7BD02@0L6b<07A`T01lN9P0P82P07alW01`L900I
6B406QXR01dM9@0201PH800901`L900K6b<08R8Z02`Z<P0Q7b@06aTN01dK800K6Ah05Q@I00<061HK
01H05A<H01@B5`0D4QL04`hB01`G6`0<1`/0=S4e01/F6P0B3A4050lC00T4200D3a<03PT=024L800D
3a<07QPJ02PR900G4A<07ALI028L7P0;1@L04@/=0P0@2P`0400?2@/040X<014;3@0B20T05@/<01H<
3@0A1`P050X;028H6@0a9bP06a4B01882@0D2P/04PP900h41@0A1`P301<92P0301882@0A1`P04PP9
00D04PP900T06@hB02LL800g;3004`P<00h31`0H3A4050T=00l4200G31000P0F2`l03P0/8BD0:AhR
02@I7@0K41@0304500l4200C20`03`@801052@0B1`/03P<701@93@0@1@T04`L;0P0?0`L0100A1@T0
4PH:01862P0D20`501<72`0301872`0A1PX04@H:00804PL;00@04`P<01462P0D2@d050T=0P0B1`/0
1`0D2@d02@0200`11@07000050T=00/0100B1`/00P0A1PX0<00?10P03@8600l4200?10P03@8600l4
200C20`04PL;01462P0?10P03@8600l4200B1`/04@H:01052@0@1`/030H:00d42@0B20h03@8800d0
1`0=0PL0300601D:400C2@l0;bH[00d72`0A2Pd040L:01052@0B1`P050P801871@0?10<03`<501<8
300?2@d01@0600`9400G41H040D900h31`0?10P040D901<8300A1PX040D901462P804`P<00d03P<7
01<8300B1`/05@X>01/@500J3a<040D901D:3P08004050T=02XO8`0@1@T04`P<00804PL;00<04@H:
00l4200?10P01P0A1PX06@0A1P/05@XB00L01@0S6200IEYR01463@0<0@L01`0201H;400;00@0>c0d
06EJGP070000=2T_01<83P0G31804@H<00h32@0A1P`040D;01873@0A1P`04PL=01@93`0>0`T05?oo
ool001_ooooo01T04@L601@:2@0H3Pd05P`;01<9200I3`h04@L600d4100X7Qd09Q`K020F5@0<1080
4@P900`61P0400003@L7020J6P0F41003@L701H@40060000@cdm00P20P0A2`/04`T:008050X;0100
4@L801<92P0:00404`T:01L=3P0D2P/04`T:01@:2`0B20T04@L801D;300O5AH06Q0A01061`0A1`P0
50X;0P0C2@X00`0D2P/05@/<01H<3@0301881`0301@:2@0E2`X05P`;00<050X900T04`T801881`0C
2@T04`T:01882@0D2P/05@/<01<92P0E2``00P0I3a00600D2P/03`D600l51P0D2P/060h?01@:2`0C
2@X06Q0A01H<3@0=0`@06Q0A00l51P0S6AX06@l@01lE5P0B2@/03PP:01D?4@0;1PL03@L901D?4@0>
2@X05Q0B01<=3`8050h@00D04`d?01D=400E30l06A0C01XA500201H=400B01<:3@0?1PT04`X=02DL
7`0I41<04@T<01TC5@0B3Pl06QHG01@@4@0;1`P0510A01DA4P0A3@h04Ph?01@@4@0B3Pl04`l@0`0F
4Q<02@0G4a@061@E01XE6@0?2Ph06aHJ01lJ800G4QP061<I01D@5`0201<A5P0:01DC600E4aH05A<F
01@B5@0F51D05A<D01LF500I61H06aXH01TH5P806QXL01H071`N01lO8@0O82<071dQ01`M8P0K7B80
6QdR01XM900K7bD06QlU01hR;@0R9S408BD`01`S;@0N9Bl08bXd02@]=P0S;3D082Tb01hX<@0P:S<0
8B/d0`0O;3@03P0P;CD0934i02Ld?00L:C40;S]301l/=00W=3`0:SLo02@a>@0U=3/0:cY103E4B`0[
>T40;Se40P0_?TD04`0`?dH0:SU00350A`0hAdh0<D9903=6C`0aA580;d9A03M:G00iBf<0@eE]045C
J`11DfL0>4]L03U=FP0kCeX0?E5J03Y<EP0lCUP00P0jC5H0700fBE00;d9903U<DP0lCeD0=4M<03]>
DP0iC500<49803M8D00nCeL0=TM?02Xk@`0[?4@0<45903E6CP0kC5@0?4eE03I7C`0dADd0=dQ=0312
@P0Z?3`0<TA403I8B00dATH0=DM703=5A@0`@T8202do?`0402m1@@0b@dD0<T560350A@80<T5606X0
<3m403I5BP0gAT/0<T560350A@0c@TL0<T97045DFP0S>3d0=dY@02i1A`0P<cT0<dA;0352B@0_@4L0
=DA;03A3BP0]?4<0:SLo02dl@@0W=S/0;Ca102Xi?P0^?D80=45702lj@00]>3h0:SDk02Tb>@0Z<cX0
;CHm03@m@P0J8bP09c8h05AOI@0Z=C/0;ca403M3C`0K9c<07bdj01`Z=`0Q;Sh0;cm?038oD00d@E40
:3I302Dc@00Z>480938k020^=`0S<C/09cE002Te@`0Y=DD0:S=201lU<@0T:CD08bTg02L]?@0^=DL0
;CE801/R=@0N9CD031@O02<Z=00Y;c@0CE9F08N<TP0T:3409BTb01lS;00X;3D0720Y01DI8P0J7RL0
5a/T02da>P1_Lg`08BH/01/L8@0H6Ad08R<W024R9P0J6b0071dR01/K8`0N7RH07AdU01/K9@0N7RP0
8R8Z01/J7`0T8bT02@P=02@S:@0W9R`07QdR01`K8@0I61h07A`Q01lN8`0M72807QdS02<S;00O7bT0
7QhX0`0P82X03`0I6B<06QXT01PH8P0>3QP05QHP02PX<P0I5b805A<N00L5400N7BD02`XB024P9`0L
6b406QTN01`K800201dL8@0801`K8P0M6bH06QPS01/I900W9C008b4/01LE800H5R4201dK9P0?01XH
8`0K6B@07QdW034a>`0>3QP071`V01PH8P0E5Al05QHP01lO:@0<31H07QhX01TI8`0d=3h05A8L00<0
5a@K0`0F4aX01@0G51/05Q<J01@A600D4AP05A8I00804PdD00D05A0G01PC6P0J5A`07APO01LB6@03
01PC6P0401/F7@0S7RD04`hD01<>50@05A0F00@050lE01D@5P0F4AL05a8H0P0F4AL01`0E3a<050hB
01@>4P0C3A4050hB01D?4`0G4AD00`0F41@01P0G4AD0618F01PB5P0J51P04`dA010:3P805@lC00`0
4P`@01@>4P0D3Q804P`@01<=4@0D3Q806Q@F01LA4@0E3`l06aDE00h8200F410201D?3`804`d=00l0
50h>01D?3`0<1PP06aDG01LA4`040000:bDW00`6200@2P`04P`>01@>400C3@l04@/=00l92`0D3Q80
0P0C3A401@0B31004@/?014;3`0B31004@/?00804P`@00T06Q@H028M8`0G62<05aTU01@D7P0?3aH0
1`H;01@B5@0A3Q400P0C31<0100E2a@05@/F01D;500=1`h2014<4P0600l:400@2a404PdC010;4@0B
3A<04@`B0P0@2a400`0B3A<020D>00/84@0201@A6P803@XC0P0C41T02`0E4Q/05Q<L01HC700F4a`0
3@`D02h]=@0A41P061LO01HE7@0E51`061LO008071/S00@061LO01LF7P0I62006a/S0P0L72@01@0J
6R8071`T01TI8@0G5al06ATQ008061PP02407AdU028P9P0J61d05Q@I01/I7P0J61d06ALL01HD6@0G
5AX061HK01DC600D4QL05Q@I028M8@030080>SDi0:bWZ`0I51P07aXN01dH70080`L05a8F00L21P0E
41@03PT=01/E5`0@2P`03`T;038/;P1<ATP0618D00l92`0@2P`00P0A2`d2010:300=01882@0E2``0
50X;00h41@0?1@H06Q0A02DK700B20T03@<401882@0C2@X04@L801882@0301<92P0501882@0@1PL0
4`T:01882@0A1`P00P0C2@X01@0A1`P01`0001@93@0C20`05``@00804@H:00<05``@01462P0B1`/0
0P0@1@T0200N4aL09Q/O02HK7`0H3A403@8601052@0F2`l05@X>0P0A1PX01P0>10L04@H:01872`0E
2@d04@D9010420804PH:00<04@D901<72`0B1PX0100A1@T0100A1PX040D900l4200@1@T201462P0?
01872`0E2Ph04`P<00h31`0=0PH03`@801@93@0<0@D0714E01D:3P0M4QH01`0001462P0B1`/04@H:
00803`@800P04@H:01052@0@1@T04`P<01052@0?10P04@H:00l420804@H:01d040D900l4200>1@T0
30H:00l62`0A1`d03P<901032P0I31<0200200T0100m<cT0j=oT02`V:P0?1`/040L:01061`0A1`L0
4PP701871@0C20L03`D400X10P0@2@`05Q4E01D@5P0A2Q003@8600`21@0201872`804`P<0P0@1@T0
0`0B1`/04`P<00h31`0200l4200@01<8300H3A405P/?00d31P0H3A402P0300`31@0H3A402@0201@9
3@0>0`L040D901872`0C20`05@X>01/@508040D90`0A1PX06@0B1``05@XB03<W<@0h;CD09a`T00`3
200L4AL03`@:01072P0@1@T0304501hE5`1eJVh0IEYP01`A5`0C20h03`@:01873@0<0@L03@880187
3@0A1P`040D;01873@0=0PP05?ooool001_ooooo00@04`T:01882@0G3@h060h?0P0B20T09@0E2``0
4PP900d41@0A2@T04@L801482@0E30l05Q4B07miN`1LEUP07ALI00h82P0D3Q0081XL01dG6@0=20T0
2`D700h82P0E2``04PT:0147200F30d04@L801<92P0H3Pl09adN01dC500@1PL04PP901H<3@0C2@X0
4PP901061`0A1`P04`T:01882@0C2@X00P0B20T00`0C2@X050X;01D;30020147200>01882@0D2P/0
5P`=01L=3P0D2P/05@/<01@:2`0C2@X04PP901H<3@0G3@h05P`=01L=3P0F30d201<92P805P`=01T0
50X;01882@0C2@X04PT:01hD5@0Z824060h?01@:2`0L4Q<05`d>0147200A20P05P`=01X@4@0F30d0
4@P:01LA4`0A2`d04`d?018<3P0<1`P05Q0B01@>400A2`d04P`>008050h@03004``>01H=400P5aX0
7A@G01D<3`0G3Q407A@G01H=400H3a80:R4T01hE600F3a405A0B01@@4@0F4Q<07a/L05QDE@0F4Q<0
3`/<01LC500T82407ATJ014=3P0H51D05A4B01HB4`0I5AH06QHG01/G600K5QX05Q4E01@?4`0E41H0
6A@J01XE6`0I51/05A<H01HD6@0G5AX05Q@I01DC5`0C4A@05aDH01PF5`0J61T071/J01/J600G5QD2
01TI6`3Q01/K7@0L71h071`O01PI7@0Q8RL07AlT01XM8P0I72<06QhU01/P9`0I7BP07b<^024U<00N
9Bl08RTc02T`>P0O:3408R/d020Y<P0K9Bh07bTb02La>P0M:S808c0h02Db>P0S<3P09S<k02/h@00W
=3`09S<k02/h@00R;cL0:cQ002Pe?@0V=C`0;ci503]:D@0/>d80:CPo02/j@@0V=C`0;3]204QGGP17
EUd0;ci50311B00a@dd0=4IC03=5E00gB5X0<T=F03M8G00oD6@0?4eP03m@H@0hBUP0<49=03U;E@0j
C5H0=TQB0394CP0eAe40=dYA03A7CP0fBDl0=4M=03A7C00hBdl0<dI:0312B00eATh0=TM?03=4C00b
@d/0=TM?03M8D00eATh0=TM?03U:DP0hBE40=DI>03A5BP0fB4P0<dE50353@`0gBDT0=4I602i0@00]
?cl0:cdm02Xl?00[?Cd0;3hn02`m@00`?d@0=DA903I5BP0b@DH0<d970391AP0a@4D0=4=803I5BP0c
@TL0<41502i1A`0Z?d@0;3m502Pk@@0/?dD0;d1702Tj@@0[?4<0=DA;0350A`0W=Sd0:SLo02ln@`0Y
>3d0;ci302Th?@0[>Sl0;3To034l@P0`>d40;CPn02`e?00Z<cX0:c@k02Xe>@0d?d409S4e028_=@0[
>3l0<Sm807Z8T`0lBUH0;ci<02dmC00X>4P0;Ca>02llCP0a?Th08S0m01l]>P0W=3h08Bhf01/X<00S
<3P0;3M202dg@`0W<Ch08BXh02P^>P0S9c8092Tf02<Y>00U:c`0<3M8024U=`0T:SP0:2lj028V<00L
8BH08BHZ028W;@0M8BX08BD^02<W<00Q9Bh07b</01HJ8`0L82T08BD^020T;@0M8BX061`S01hO900K
72007b0T01XK7`0Q8RL0<C8g01lO9`0R8RX0820X01/K9@0M7BL08B4Y01dN8@0X:B`05aPJ024R9@0O
82<07AhP024R900J6ah07QlQ01hO8P0K71l07AhR020P:@0L72H07AdW020P:P0M7BL06a/U01dM9`0I
6B<05ADO01dM9`0H62806ATS01LE800W9C00<c4l01`K8`0O7RH061LN01/J800I61d06QTN01TH7@0G
5Q/05A@K008071XU00<05Q@O01hL9`0N72L00P0I5b8401PF8@0=01TG8P0K6B@05Q@O01lM:00/:SD0
7adX020N:@0J62<0518M01LE800H5R40928]01@A6`0301HC70805A8K00<05Q<K01HC6P0E4QT00P0D
4QL0100E4aP06A@K01TD6`0I51/201LB6@0=01TD6`0D3aH05a8I01/F7@0G4QT05A0G01HA600D3aD0
5A0F01HA5`0E41H050lE01<>5002014<4P0601<>500D3aD050lE01@?5@0F41@05@lC0`0C3A402@0F
41@04P`@01<=4@0D3Q805@lC01PB5P0J51P04@/?01H@5002018<40805a4E00<04@/?01@>4P0E3a<0
0P0C3A401`0D3Q808QdN03H`<P0:10H071HH01<=3`0A2`d00P0D3Q0201<=3`0>01D?4@0F4180618D
018<3P0C3Pl05a4C040j?00E3a404@/=010:300?2@/04P`>01TC5@0N61X6014;3`0=01<=4@0D3Q80
5@lC014;3`0D3Q806AHM071cP@2CV:H08RLc014C700P8BL05QHK010>4`02018;4P0401@:4`0E2A<0
5@/D014;4P803`X@100@2a406P0B3A<04@`B00l:400@2a404@`B01<=5P0D3QP05Q0J01PB700G4A/0
4`dG018<5P0C3AL05Q0J01PB700I4ad05a@M02h[=01SH6T05a@M01/H8@0R7bP07Q/T01`I8P0M6R<0
71TR0P0H5Ah01@0I5al071/S01hM9@0M72@06QTQ00806APP00h092<[02PW;`0J6B4071/S01/J8P0G
5Q`05Q@I01LE6P0J61d05Q@I01PF6`0C4AH05Q@I01PF6`805A<H02D06ALL01D@500P6al04@`@01XE
6@0?2Ph071LK01D@500:1@T05a8F01D@5014?d<061<G01lI6`0R71h04`d?01LA4`0S7Al07aTK00d7
2@0?2@/04`d?01@>400B30h03PP:01D;300C2@X05@/<01X@4@0I3a004@L800h41@0@1PL05@/<01@:
2`0A1`P05@/<00@04`T:00<04PP901061`0D2P/00P0A1`P201<92P0301061`0D2`d04PL;00804PL;
0P0E2`h0500@1@T04@H:01052@0@1@T04PL;00l4200:0@<05`d@01462P0@1@T04`P<01L<400D2@d0
4@L:01<8300A1PX03P<701D:3P0I3A4050P<0P0C1`/0100B1PX04@D901L;3`0D20`201<72`8050P<
00@04PL;01462P0@1@T040D90P0A1PX05`0@1@T04PL;01052@0?10P05P/?01dB5P0V6al07Q<G01dB
5P0K41@03PD701T>4P0C20`05P/?01L<400D2@d04@H:01<8300?10P03P<701872`0>0`L03`@80080
5``@02T04`P<00l4200@1@T04`P<01<:3P0@2Ph03`H;00h42@0D2@l050L>00h3200I31<04@P<03L]
<`2@Qh`040X>01<<3`0@1`P03PD601071`0A2@L04@P800l71P0C2`X04@P900h7200L5QP06A<F0107
2`0>0`L04@H:01<8300@1@T04`P<01P=4@0C20`03`@801<8300E2Ph04PL;01462P0201872`804@H:
00d04PL;01052@0=0PH040H901<8300>0`L04@H:00l4200A1PX04PL;01052@0B1`/06@hB008040D9
0P0A1PX06P0B1`/04PL<01053@0H31H04@L>01@:4@0]8RT071<G01<83P0]8bL050T=01dB5P0S6A`0
4`X<02HK8@0B2@d0<RL]024F700C20h04@H<00l42P0I3Q@060dC01@93`0E2Q0050T?5?ooool001_o
oooo02/06@l@01<92P0B20T04@L800h41@0C2@X06a4B00d41@0P5QL03P@500l51P0C2P/04`X=01LA
4`10>S`0>C<e00`7200B30h02`D700h82P0P6Q`03PP:00X41P0;1@L04`T:00X00@0>10D04PP900d3
100A1`P040H700`20`0?1@H06@l@01L=3P0A1`P04PP901T?400B20T03`D601<92P0H3Pl040H70080
50X;01404@L800l51P0?1@H06Q0A00d3100@1PL0718C028H6@0800004PT:01<92P0L4Q<0308301X@
4@0>10D040H701882@0201L=3P0?01<92P0A1`P04`T:00P0000C2@X060h?00`20`0@1PL04PP901D;
300C2@X04@L801<92P0F30d05@/<00805P`=0P0G3@h04P0F3@l040X<01<=3`0F41802P@601@>400Q
6ad01`43020J700Z92H02`D701/E5`0H4Q@02`D701<=3`0E3a406aDG014;3@8040X<00X050h@024K
7@0H4Q@06A<E024M7P0:1PL061@E03Te=P1cKg007QXK0P0B3Pl0100O6a`05Q8C01<?400G4a@301PD
5@0:01HB4`0E4A804`hB01XE6@0I51P050lE028M8`0Q72805A0G01@A60806AHM00T05aDJ01/I7P0G
5AX030X=01LE600F51D07A/L01TG600F51D00P0M7Al02`0L71h06a/M01/L7`0K72007b0U01`N8`0N
8BH07B0W01XN900M8BX06alZ00807R8^01405Q`X03HlB02LXZh09blj02@/=`0I8B`0<3Y401dW<@0]
=d408c0i01l/=@0W=3d072Tb02Db>`0T<CX0:cQ103I3C00202Db>`0601l/=@0V<c`082hg028`>@0U
<c`0:3Ho0P0Y=d00BP0[>D80;Sa502`j@`0b@4T0;3Y30311B@0a@dd0=dUE03Y<FP0[?D`0=dQH041A
H@0lCEh0?e1P045CH@0fB5D0;d5;03E7D@0bA4h0;T1:03A6D00cADl0<DA;03A7CP0fBDl0;d9803A7
C00bADT0;d9602/m@`0`@DT0>DYB03M8D00`@DT0<D9:03U:DP0/?DD0<dA<03I7C`0_@4P0>4UA03Y<
D@0Q<cD0>D]=02do@@0mCe40;Cm10312A00bA4H0<dE702do@@0[?Cl0:3Xl02Hg>P0V=CX0>dY?03U8
C@0T<cP0;Ca103E4B@0fADX0;ci303=2A`0Z>Ch0<D5602Xm@`0R=c`0;d9802`oA@0`@dT09cPo0311
B00^?dH0;ci50P0a@4L0>P0/>D40;ci30350A@0c@TL0;Ca102Xi?P0/>Cl0;3Lm02Td>P0X<cT0:S<j
02`e?00c?4<0:3<g02Le>00^?3l08Rle038oA`0Z>440<3i902lmBP0]?D`0;ciA0311D`0a@UD0;Se@
02/iB@0Z>4D0:cU602Tf?`0S<3P0:cHl02@^=P0V;cP0:30k020X<`0E6bL06Al[01hS;`0M8Bd07b8a
028U=00N8C00:bdl02L[>00Q9C007b</02H/<P0T:Bd07b@Z01dP9`0P8bX07b8Y01/N9@0R9B`08bH]
01lR:@0N8BP2024T:`0^01`O9P0P8BH07QlS01TJ7P0H6Ad07AhS024R9`0S8b/08R8Z01lO9`0M7BL0
7alY024Q:@0Q8RD04Q<E024R900L7Al08R<U01PI6`0R8bD06a`N01dN800K71h05aPJ01TJ7P0K6b@0
6ATS01PH8P0I6B<06a/U01`L9P0I6B<05aLQ01/K9@0I6B<05aLQ01/K9@0L6RD0R8JA0?Oeo`0h=cl0
5QDM01LF7@0N7B<07A`Q01PG70805A@I00H06aXQ020N:@0G5B005Q@O02DS;P0@3QT201HD7`0<01DC
7P0G5B006ALR01/I900H5b008B0X01XI8@0L6b<05QDM01TH800P7bL06QTQ0`0H5al04`0F5Ad05A<M
01LD7`0B3aX06QLR00h;5P0K6240514I01PE700H5Q/05aDJ01HD6@0G5AT05A0G01PC6P0K5Qd061<J
01D@5`0D3aH00P0F4AP01P0B3A@050lF01TD6`0F4AP04`hD01HA5`806QDK01005a8H018=4`0@2a40
4`hD01HA5`0J5A/07aXP01hI7`0@2Ph05Q0D01LA5@0F41@0618F01<=4@0B31004`dA0P0F41@0100D
3Q804P`@01<=4@0C3A42018<400302<M8@10>Sh050hB00804@/?00h04`dA01D?4`0D3Q80GUQJ06eW
J@0B30h040X<00l92`0A2`d040X<01PB500J51H05Q0B01@>4080618D00/04`d?01TC5@0E3a405Q0B
00/51`0D3Q004P`>01<=3`0600805@lA01TC5@02014;3`0H018<400C3A404`dA01<=4@0E3a<03PP<
01LA5@0?2@d02`D901/H7`2KWjd0];[802L]>@0@4Q`08B4Y01<D6@0?3A804``C0109400L4Q/0?C4k
04m5CP0?2@l03PT?0P0?2Q02010;4@0D00l:400D3aD03`X@010;4@0M61h04@`B00d63P0B2a<0<BXb
05A=E@0P6B404@XB01<<500B2a<050dE01H?5`0E3QH04`lF01@A600E4QT401HC6P0S01LD6`0H5A`0
5a@K01@A600B3aH0518I018A5`0E51X06APN01HE6`0L6b405aHL01XI7`0L6b4051<I010?5@0I61h0
71/P01TG700G5AX04@lD01@B5`0B41D05Q@I01<A5P0B41D02PP=014?500F51T05a8F010;3`0E41@0
6A@H014<400C3Q800P0G4QH03@0@2`l061<G02@O8`0F4AD0JVAV03La<`0D3Q005a4C010:300H4Q@0
4P`>01<=3`0D3Q000P0A2`d0300D3Q003P@500l51P0G3@h0GeEF02PN7`0=0`@07aDF01@:2`0B20T0
6Q0A01061`804@L800H060h?01@:2`0D2P/04@T900l51P0D2P/201H<3@0700l51P0G3@h04`T:01P=
4@0F2`l050T=01<8300201872`0:01462P0F2`l05P/?00X00`0G31003P<701052@0>0`L05P/?00l4
20<04`P<00l050T=01D:3P0=0PH04`P<00h31`0D20`04@D901862P0E2@d05PX>01D93@0C1`/03`<7
01<72`0D20`00P0@10P0100A1PX05P/?01<8300@1@T200l4200=00h31`0B1`/08QLK00d31P0F2`l0
2`0401lD600T6Ad04@H:01/@500900804`P<00l4200201L<400301052@0=0PH040D900804@H:01l0
3`@800h31`0@1@T03`@800T00P0J3a<03PD702DJ7P0700005@`@018<400700<04`T?00l42P0G2Q40
4`H=01442`0<0@L06@lE01XA5P0E3a<020<400/51@0P6Q`02`D7018<300?2@/02`D600/51@0<1PH0
3@H600803PD600<03`D801052@0@1@T00`0@1@T03@0Y7R802`0400l4200;00@04`P<00l4200B1`/0
4@H:00l4200>0`L03`@801872`0H3A400P0@1@T0100B1`/0304501872`0@1@T200l4200;01462P0B
1`/04@H:01@93@0C20`040D900l4200@1@T04PL<01463P0A1@l00P0A1Ph01P0A1Pd04@H<00d2200C
20d040D900d21P8040D91P0B1`d601052aCooooo000Kooooo`0>01882@0A1`P04PP901D;300F30d0
4`T:00L0000H3Pl06a4B00`20`0J41401P0000h520080`@2028L7P0E00X41P0B30h030H801PB5008
0P@02`D701/E5`0=1`T040H701L=3P0R61T04PP901061`0G3@h05P`=02<I6P0O5AH040H700d3100A
1`P03`D600804`T:01`08QPI01@:2`0C2@X04`T:01D;300D2P/04PP90147200B20T04PX:01061`1R
F5T0B3ho00X00@0J41403`D60147200H3Pl04@L801L=3P0@1PL04`T:01882@0D2P/05@/<01@:2`0C
2@X0718C0P0E2``00`0I3a003`D601882@0201@:2`0601D;300G3@h05P`=01D;300D2P/05@/<0`0F
30d01`0D2`d02`D700T31@0<1PP050h@02XT9P0/9RP00P0<1PP030060@807QPJ04@n@00a:bd040X<
01@>400@2P`050h@00h82P0B30h05a4C018<3P803@L900X0=c4c00/7200?2``05a<D00D10P0T8240
3`/<01XF5`0E4A8071PI0P0F4Q<401LC500:01HB4`0E4A8050lC00l:3P0G4QH06aHL014<4P0B3A<0
5Q4H010=50805A8I02H04a4F01HD6@0C4AH05aDH01lM800I5aX07A/L01LE5P0D4Q<06ATK01/K7@0M
7Al07QhP01`M800K72008B8W01hP9@0O8RL07R4X01/O9@0N8R/07B4/01XN:P0S9c<09R`h01hT<00i
?d/08BTd01dU<00L92l08bdg01TS;@0W<C/07R/d02hkA00P;CH0:CHo030mAP808c0i00L0=T=<024^
=`0V<c`0:3Dn02Ld?@0U<c`09S@m00809cDn0P0X=Sl0500U<c`0<Cm802dkA00_?DH0;Sa503U7D00f
Ae40>deI03mAG@0a@e00>4YH03a>G00jC5/0>D]I03Y<F00iBeL0=dUC03U;E@0bA4h0;T1:0P0bA4h0
1@0bAD`0=TU@03E8CP0bAD/0<TE:0080;3m300T0<dE;03I7C`0eATh0<T=;03=4C00iBU80?e1H0311
B@0dADd00P0fAdl02`0mCUH0<D9802Xl?P12E5H0<TA602i0@P0W>C/0E6IX03Y<CP0[?Cl09cTk0080
9CLi01X093Dh02He>P0b@DH0=dI;02`k@00iB4d0;ci302hm@P0]?440=DA902hm@P0b@TL0<4=902Xo
A00]@4H0<DA:03Q;D@0lCE@0;d1702`mA00/>d80;ci50350A`0a?TH0:3Ll02Xi?P80:cXo00D0;Se2
02hk@@0/=cd0:SDk02Td>P0202`e?00:02dg?@0_>T009S@g02Ld>P0R;cL0<Sm703E3C@0a?d`0;Ce:
02hnCP80<D9D01/0;CiB02hmD00[>TX0;C]802lmBP0]>T<09c@l02Pc>@0S;C<09Bhg02/d?@0[<Cd0
8bTe01`R;P0P9C408BDa02HY>00[;C`09BLd02<U=00Z;3P08BD^01XN9`0N92X09BX^028U;00M82L0
0P0O8RT02P0K7RD07b8Y024T:`0O8RT07R4X01lR:@0P8bX07R4V01hO900N7b<201/L800F020Q9P0S
92T07alW01lO9`0N7RH07AdW01hN:00O7bL09RLZ01`M8@0P8B<07b0S024R9P0I6Q`07AhQ01XK7`0L
7Al06AXM01LH700J6al071`U01XJ90806ATS01/06QXT01/K9@0M7BL06QXT01`L9P0I6B<05ADO01TI
8`0J62<0BTQC09BBW@0`;cL061LO01`K8P0F5A/02PT>01dL8@0];3407QdR01DD6`0O7BP071XU01LE
800L6RD05aDP01lM:00H5R400P0G5B002P0H5R406ALR01XH8P0E51`05QDM01/J8P1GEUh0FEQP01DD
700J6B4301PG7`0>01HE7@0N72D03``G01HC7P0B3aX06aPS01`I8P0E4QX06QLN01`J7`0E4aP04a4D
01PF6@0J5A/201TD6`0301`G7P0K5Qd05a8I00805a8I01P05A0G01PC6P0M61l06aHM01D@5P0F4AL0
61<I01LB600F4AL05A0F01<>500F4AL05A0F01@?5@0G4QP04`hD01D?4`0I4aL05a4E01D?4`0I4aL0
5a4E018<400C3A4201H@500V01@>4P0B31005a4E01LA5@0H4QH05a4E020J7P0c;C4050hB018<400A
2`l04`dA01D?4`0D3Q804@/=01LA4`0S7Al0208401HA4P0V82803PP:00d72@0<1PP04P`>02dW:@16
@4803`T;018<3P0A2`d03PP:01@>40090`D0208401LA4`0R71h03`T;00h82P0;1@L2014;3`0G018<
400C3A404`dA01<=4@0A2`l03@L;01@>4P0E3a<03`T=01PE700/;c`0>Ca;01PL:00?41T061TN04A3
B00G51T04``C00l83`0C2A808aLQ02/Q:P0A2a400P0A3183018=4`07014<4P0G4QP050lE01LB600T
7bD06A@J00h73`0201D>5P0602HO9`0@2A404``D01<<500A2Q804``D0P0F3aL00`0F41L0514H01@A
600201HC6P<05A8I0P0F4aX0200E4QT0514H01PE700E51X06aXP01PG7@0J6Al05A@J0P0D4aT201PG
7@0F01/J800T8bT08R0V01XH7@0I5a`04a4F01HD6@0D4QL07A/P01LE6P0>31408R0U00`:3`0=3100
=2lc02<N8P0F4AD04`hB00d8300B3A404@`@01D@508040/?00D061<G014<400R71h04@/=018<3P02
014;3@05010:300;1@L03@L9010:300>20X00P0=1`T06`0L4Q<06a4B00d41@0`9RL060h?01D;3007
00005P`=01L=3P0700007Q@E00l51P0>10D02P4201/A4P07000060h?01T?400J41404PP900/10P0C
2@X0:1hO00/10P0E2Ph050T=01872`0401462P0700P00@0@1@T060dA01`A5@0@1@T08AHJ00d21P02
01D:3P0800l4200>0`L04@H:00h31`0?10P0308501L<400E2Ph201D93@8050P<00T05@T=01H:3P0B
1PX040@801<72`0A1@T040@801@8300@1@T00P0B1`/200l4200>01872`0K41@05@X>00L0000B1`/0
CT=701462P0J3a<01`0001hC5`0i;S806a0D00l4200@1@T201H;3`0301052@0?10P04@H:00804@H:
01`040D900h31`0@1@T0714E00T00P0700007Q<G0597B`0P5AT03@@8010:3P0?1P/060hC00P00`0A
10/02`4501L:4@0G318050X@00H00P0F41@04P`?00X41P0400005@lC00h93@0B3A402`H:0P0=1`T0
100>1`L03`H700l71@0@1PL501052@0602DJ7P0@1@T04`P<00X00`0?10P050T=0P0A1PX300l42003
01462P0D2@d04PL;008050T=00<04PL;01P=4@0A1PX00P0@1@T01P0B1`/04`P<01872`0D2@d04`P<
01872`804@H:00<04PL<01463P0A1@l00P0A1Ph0200A1Pd04@H<01<83P0H3A804PL;00h31`0?10P0
3P<71P0A1P`601873ACooooo000Kooooo`0U00h31`0G31004@H:01872`0G3100304501462P0B20/0
6a0D01D<3P0?10P04`X=01<:3`0>20`05a4E01TC5`0B31004@/?01D?4`0A2`l030L:02LQ9@0O6Ad0
30H801H;3@090@407Q@E00d4100C2@X04@L801882@0;0@8030830147200B20T04`T:01@:2`0201D;
30030516A`0a9bP06Q0A00805@/<00L050X;01882@0C2@X05@/<01H;3`0C20`04PT;0080714E00@0
200101@93@0C20`03`@80P0C20`04P0G30l05`d>01<92P0C2@X050X;01H<3@0A20P05@/<01@:2`0C
2@X05`d>01@:2`0E2``04`T:0147200E2``05`d>01H<3@<04`T:00@050X;01D;300E2``05@`>0P0F
41808`0@2P`03@L900h82P0@2P`05@lA01H@4P0H4Q@05@lA010:300A2`d040X<01D?4@0?2@/05@lA
01LA4`0B30h05Q0B01<=3`0F41806A<E03Pb=00G4a@06aLH01@@4@0F4Q<06QHG01dI6P0G4a@04Ph?
01HB4`0C3a0061@E01TE5P0E4A805Q8C00<05a<D03L05a8F01PC5`0E41@071LM00h93`0P6b408A`S
018?600F4a`061DL01DB6@0G51X05aDJ01@B5`0K6Ad0518E01XH6`0I5aT061HG01HF600J6Q`07AdO
01lO8@0M7R406a`P020Q9P0O8BH082<X01lR:@0M8BP08bL`02L[=`0Q93<07R4`02H/>P0N93807bDc
01hV<`0U;CX0?DEB02La?@0U;c/08bdi024]>@1KIg<0;SY602/g@`0T<3`0:SI202hjAP0W<cl08Bdi
04IBGP10C5P0930l00<09cE000L0:SQ302`jA@0]>dH0:SQ302`jA@0[>D@0?D]F0080>DMB0P0fAe40
2`0jBeD0=4E?03I6DP0a@Dd0=dMD03U9E@0fAe40>4UC03I7D@0`@D/0<D==0080;d5;00`0<49<03A7
CP0iC5<0=dY@03I9C`0dAd`0;T550395B@0gBDl0<T=;02hoA`0dADd203]<E01O03I7C`0b@d/0=dQ@
03Q9D@0jBe<0>4UA02hoA@0eAdT0>D]=0312A00cADL0>de?06eoP@0hBT`09cTk02i0@P0/?T00:S`n
02hn@P0hAd`0;ci303I5BP0X=c`0>TU>030oA00eA4T0;Se203=2A`0`?d@0?4eA02`oA@0`ADX0:Ca2
03A7C@0]@4H0<D9902dnA@0[?4<0:cY102hmA00a@4L0=T=;030oA00d@dP0<3m402dl@@0`?d@0:CHl
02Xe>`0Y=3X09c8h02/d>`0/=C`09Blf02Hb>@0P;CD0;3U202dlA00^?4H0<T1;02`lB@0^?T/0<45?
0352D@0_@500:ca>02/jC@0Z>DX0;CY902lmBP0]>T<09c8i02hg?@0Y<CL09B`c02T^=`0Z;SP08RHa
02P^>P0/<Cd0:2`h02HX=@0S93406a/W02<S<00S92l06ahW024V;@0R:2h082D[02HY<00O7bL07QhV
024Q:@0O7bL00P0K6b<01`0L72@06QXR01PH800K6b<07b0U01LH7@0J6al00P0K72000`0M7R<07b0U
01dM9@02024Q:@0C01lO:@0M7BL07AdV01hQ9P0Z;C806QhR01lR9`0J7B806QdQ01TM8@0J7B8071lS
01LJ7`0J7B808RD[01hN9`0L72H06a/U01XJ900201TI8`0I01lO:@0L72H06a/U01LG8@0D51h05ADO
01XH8`0F51l0928]028Q:@0K6R807A`S01dL8P0J6Ah0<c8g03`k@00R8BH061LN01`J9@0K6B@0:BLb
02<Q;00O7BP06ALR01XH8`0201PF8@805aDP00T06QLQ014>5`0R7bP0:RL`0<C1bP38aLh0924Z01XG
800H5Ah00P0I5Ql06@0G51d05A8M01HB800I5B<061@Q02@Q;00<2A8061DM01`I800N7200518E014?
4P0G5AL06QDK01HA600D3aH06QDL01`G7P0H4aX050lF01HA600E41L05Q4H01`G7P0K5Qd0100E41H0
200F4AL05a8H01LB600J5A/06A@J01D@5P0F4AL050lE0P0D3Q801P0C3A404@/?01@>4P0D3Q804`dA
01@>4P805Q0D00L05@lC01<=4@0F41@050hB01H@500E3a<04P`@00805@lC00X04P`@014;3`0C3A40
5@lC01<=4@0C3Q405Q0D01<=4@0<1PX05@lC0P0B310201H@508050hB00d05a4E018<3P0F41804`d?
018<3P0C3@l05@lA01TC5@0@2P`04@/=00l92`0F41805a4C00@04P`@0P0C3A4201@>4P0@014;3`0O
6Ad040X>00`73@0A41X05AHP010?600>31<04a4E01XG6P0E41@04P/B0109400A1a0040HA00l640<0
40/A00h04@`B018=4`0B3A<03PT?01@?5@0C3Q@04PdC01TD6P0?2Q005@hF01L@600>1`l04@XB01D>
5P804``D00L04P/C01@=5@0G41P0614I01H@5`0E41L05Q4H00<05a8I00<05Q4H01D@5`0F4AP00P0H
4aX0200G4QT05a@K01@A600O72<0514H028O9P0=2Q406aPO0`0H5A`201HC6P0401PF700J61d06ALL
01HD6@805aDJ01L04Q0E01dK800S8BH08R0U08V7S00a;c@0;RT]020K7`0D3a<04@`@00h93@0B3A40
3PT=01HA5@0E41@030L;00h93@0@2`l02`D7018<3P0V828050h@018<3P0200h82P0M010:300C3@l0
4P`>010:300A2`d03`D601H<3@0D2P/04@L801D;300@1PL04PP901D;300E3@d0:R0Q02HM7@0H3Pl0
3@D501<:2`0?1PL06Q0A01071`0G3@h03`D601@:2`0=0`@04PT902XP8@0C2@X00P0A1PX07P0@1@T0
3`@801462P0B1`/04@H:02`Q9@0E2Ph03P@701462P0@1@T04`P<01P=4@0A1PX040H901<8300A1PX0
5P/?01462P0F2`l04@H:01@93@0>0`L040@801<72`0A1@T03P8601452@0E2@d05PX>010420804@D9
00l04PH:01H:3P0E2Ph03`@801@93@0A1PX040D901T>4P0=0`H03@86028I6`0B2@/0AS/o01/@500?
1@P00P0B1`/01`0E2`h040L901<8300A1PX050T=01<8300A1PX00P0C20`0500A1PX04PL;01052@0?
10P04@H:01472P0;0P@060dA00l4200I3Q80200100l62P0@2Ph02`@701<93`0<0`L050L>01<73@0@
0`X03@@80P0B2@h03P0?2Pd03`T=01HA5P060PH04@dD014?5@0B41L03@/B00d9400>2@h040T;0148
2@0B1`L04@H81@0?10P01@0@1`T04@P:01L<400A1PX0308500804@H:100@1@T0100A1PX030<501H;
3`0H3A4200h41`0:00l4200B1`/04@H:01462P0C20`050T=01<8300B1`/04`P<01@93@804`P<00<0
4@H;01873`0B1Q000P0A1Ph0200A1Pd04@H<01<83P0H3A8050T=01872`0D2@d04PL;1P0@1@/60146
31Cooooo000Kooooo`0=01L<400U6Qh05``@00l4200G310050T=00L0000I3Q801`0001462P0D2@d0
3@@700d42@0201LA5@0D018<400>20`02`D901@>4P0;1@T05Q0D02@N8P0;1@T040X<0106200i;c00
DdU:01H<3@0B20T06@l@00X10P0F30d0718C01<92P0?1@H301H<3@0404<i>P3Ugn00WYBE02TO8080
50X;01404PP901061`0B20T050X;01D:3P0<0@D06PlC01H;3`0;00@04`P<01052@0D2@d04`P<0187
2`0?10P06@hA01H<3@0201D;300801H<3@0D2P/06Q0A01@:2`0B20T05`d>00h41@0@1PL201@:2`05
01D;300C2@X04@L801882@0C2@X00P0B20T201<92P0601@:2`0F3@l06A<E01PB500A2`d05@lA0P0I
4aD02@0F41804P`>01TC5@0@2P`04@/=01TD5P0?2``04`l@00X61`0200h:2`0;00/7200<20T02`L8
01XF5`0H51D03`/<00d92P0F4Q<04Ph?01`H6@050@800P0@30d0200D41407ATJ01<?400F4Q<05a<D
01<?400D41405Q8C0P0G4a@05@0G4QH07aXN018=4@0L5ad08ahT04I1A`11?4<03``E018?600F4a`0
4a0G018?5P0G51/09R@Y02PV:`0K6Ah071XM01LE600E4aH07AdO01/K7@0201TI6`0G01XK7P0K7200
6a`Q01/M8P0N8BH071lV01hR:00X;3D051PT02DX=`0Q93<07R@b01/Q;`0V;3X06B4^02<[>00oAe@0
82Xf02@^>P0N:3@09S8n02lkA`0M:CD00P0/>4@07`0R;SX08Bdi02Pd@00Z=T80:cM302Lc?`0/>4@0
9C<n02Hd?`0W=D00:cU402dkAP0_?DP0:3I102Xh@`0U<ch0=D=>034oBP0_?DP0=dQB0352C00dADl0
=dQ@03i?E`0eATh0>DYC03e>EP0gB500=DI@041AF`16Ef400P0bA4h01`0_@D/0<49<03I9D00iC5<0
=DQ>0354BP0gBTl00P0iC5003`0hBU00=4E=03E6CP11DUX0AEIN03i?E`0eATh0?4eE03e>EP0iBU80
=TM?0393B`0a@dP0:ce103M9C@020394B00K02do@`0[?D40:C/o02Pj?P0[?D40<49602do@`0/?440
=4=802Dd>@0d@dP09C@i03A3B00fADX0<d9702/j?`0d@dP0>4M<04aLH@0Z?D<0<dQ=02m2B00lCeD0
:Ca202m0A`0[?4<0;3e400<0<3m602X0<Ci602He>P0Z>Ch0;Ca102/j?`0Z>Ch0:CHl02Ha=`0W<SP0
8bhd02@]=00Y<ST09Blg02Pe?P0^?4L0AE=N03m=F00c@Dh0;Si;02De@P0/?4T0<49>02PlA`0W>TP0
<dED02hmD00Z>T/0:SY902dkB00Y=Ch08bhd028[<00T;3408bP^02LZ<@0[;SH08RHa01/Q;@0Z;c`0
9b/g01lQ;@0P7b/202<Q;00802HV<00J7B@09R/a020V;00K8RP092L/020Q9P0L7B8201lP9@0;01PI
7P0F5a`06AXO01LH7@0D5AX05QLL01/L8@0F5a/06Q/O01/L800I6Qh00P0H6Ah0600S8b/09bL_02LW
;`0Q8B/071`V01XJ900T9bh0?T5802LZ<@0R9B`06A`S01hQ:00L7bH06ahU01XM900G6R407b8Y02X]
=00N7RP07AdW01`L9P0K6bD06ATS01PH8P806ATS00`05aLQ01HF800F5R005ADO01dK9P0K6B@07A/V
01TH800P7bL06QTP01dL8P0F5AX200l>4`0701<B5`0J6B005A<N00l=600^;3L0;2Xe02d[=P0201LE
800M01PF8@0I5b806ALR01TG8P0K6B<03@XA02<P9`0G51/08b0W028O9P0J5ah061DL01LD6`0H5A`0
6AHM01LD6`0G51l07QXY01dI:00F4R000@0902h[=00F4a/061DL01HD600E4aH0518C014?4@0D3aD0
0`0E41L01P0F4AP061<J01<>5@0F4AP050lF014<4`8050lF00L04@`B01<>500F4AL05a8H01HA5`0E
41H03`X@00805A0F00<04@`B01<>500C3Q@00P0F41@0100I4aL06Q@H01PB5P0F41@601@>4P0401XD
600D3Q8050hB01D?4`804@/?01h05@lC018<400A2`l04`dA01@>4P0B31007aTM01H@500E3a<0:28V
00/62@0N61`05@lC01<=4@0@2Ph03`T=01<=4@0G4AD04P`>00`6200H4Q@07aTK00h82P0Y8bD03`T;
01H@4P0G4A<04@/=00P2100B30h7018<400B01D?4`0C3A40:B<W01hH700H4QH04@`C01<>500D3aD0
4@`?01PD5@0@2P`03@L9018<400B2a8040TA01<;5P0G3aX03`XA0P0@2a43014<4P0>018=4`0F4AL0
5Q4G014<4P0E41H030L=0148400B21006@lG01P>5P0O5Ad04@L?01@:4P0F31@201/A6@0401P>5P0C
3A@04`hD01@?5@805Q4G00<05A0F01HA5`0G4QP00P0F4AL201D@5P0>01HB600D4QL07adR01@B5`0Q
7b@04a4F01XH7@0G5AX05Q@I01XH7@0K6Ah06ALL01LE6P0F51T201DC600:01@B5`0F51T05A<H014?
500o?D801`D:04a:C`0M6b0030L;00d830804@`@00<03PT=014<400A31000P0D3a<0200A31004PdA
01<>4P0F41802P@6010:300?2@/020840P0C3@l04@0B30h040X<00h82P0A2`d0618D024G600D2P/0
4`X:00L0000D2P/05P`=01hD5@0@1`P07A<D06ILG@0H3Pl01`0000<05P`=00X03P@500h51P0L4Q<0
3@<401D;300I3a002`4200d3100@1PL04PL;0`0A1PX0;@0B1`/04`P<020E6@0T6Ad02P0301872`0D
2@d03@8601@93@0700005@X>02@I7@0<0`D06@hB01P=4@0:00<04@H:01052@0C20`03`@801862P0H
31005`/?01@8300I3A407Q8F01lC5`0>0PH040@801D93@0B1PX04@D901P=4@0?10P04PL;01052@0?
10P05P/?01/@500Z7b<0IU]O01L<400700006PlC01892`0200`11@0701<:300E2Ph0304501872`0A
1PX040D901462P0201@93@804PL;00@04@H:00l4200A1PX06@hB0P0?10P0500B1`/07a@H01P=4@1?
ATX0FeEI01`C600=0`P04@H<01T<4`0C1Pd05PT@01X?5@0<10P0DDQ=018<400R72403`XA00d83`0E
4Q`0BTQC0P11?dX01P0=2Q<03`XA01493P0B20T04PH8014520D03`@800D02@0201@93@0=0`H05@X>
00d21P0701052@0701462P0O51P08QLK01D:3P0D2@d04@H:01052@0200l4200501462P0B1`/04@H:
00l4200@1@T00P0B1`/01`0@1@T03P<801873`0B1Q004PL?01463P0@1@`00P0@1@/01@0C20d040D9
01462P0E2Ph04PL;00H04PL=1P0@1@/Dooooo`006oooool0:P0B1`/0714E01872`0<0@D04`P<01H;
3`0?10P04`P<00l4200U6Qh03P<701@;3P0C2Pl06A<G01D?4`0?2@d04`dA01TC5`0:10P06Q@H00D0
0`0;1@T0208601D?4`0A1`T0<RPY04Hl?@0G3@h040H701L=3P0J41402P0100`20`0?1@H04`T:01X@
4@0G3@h05P`=03T_<039_l00QWam01D;308050X;00X04`T:0147200B20T04`T:01882`0=0PH02@02
00l6200C20`060dA0P0@1@T0100K41@05@X>00l4200D2P`201@:2`0@01L=3P0F30d04`T:01@:2`0=
0`@04@L801<92P0:00404PP901H<3@0G3@h06@l@01D;300A1`P050X;01D;30804PP901T04`T:01@:
2`0D2P/06a8D028L7P0S7Al06aDG010:300?2@/03PP:01<=3`0J51H0618D018<3P0>20X03PT:010<
3@0E4A804Ph?01XF5`0O6a`0;2PY02dY:P0L61T0510A008030P900`05Q8C01/G600E4A8071PI00P4
1@0I5AH0510A01/G600T8240510A01HB4`0E4A8201@@4@<05a<D01D05a8F010;3`0>2@d05Q4G014<
4P0T7bD0:2<Z01<@6@0E4Q/06QLP01LD6`0D4AP071TP028P9@0V92T06QPM01dK7P0H5QT05aDH01lO
8@0L71h00P0G5aT0900I6Qd071dQ01/L8@0L7R<07R4V01/N9@0L82L0:2`e01dQ;@0S9SD082<b02@Z
>00Q9cD0:Blm01hV<`0P:3D09Bdj01HP;00N:3@092hj028^>P0K9c<07BTe02Pd@00/>4@09C4m02<_
>`0X=400:CE102Hb?P0P;3P0;CU502Pf@@0Y=d80:SQ302/iA080:SQ301@0:3I103a:E@0^?4L0:SQ3
02dkAP0gAE00<D9<02dnB00^?dT0=4E=03i?E`0eATh0?4eE03Y;D`0fAdl0=TMA04iOJ@1SM7h0=4I@
03I8DP80<D==00P0=TU@03Q;DP0aA4X0;D1603I9CP0iC500=dY>03M9C`80=DI>00D0>T]C03i?E`0l
CED0>T]C03a=E@0203A5C@0k0311B@0]?TH0=dQ?02do@`0cADT0:C/o03=5B@14EUX0<49602i0A00_
@DD0:C/o02m1A@0a@dL0<D56030oA00Z>Ch0;ci30350A@0[>Sl0<d9703A3B00a@4D0>4M<03=2A`0j
BTl0>4]A03I;D00aA4X0>4]A02Lj@00nCeH0:ca302dnA@0b@DP0<3m602hmA00_?4@0>TU>0391AP0_
?T<0;3]002Dd>@0V<cT09S4g02Xe>`0V<CL08b`c02Tb>@0X<CT0;c]703M5DP15DV40=dEB03A2C`0^
?T/093A102/kB00_@Dd00P0V>TD08P0dB5@0<d=C02hmC`0[>dX0;C]802Xf?`0U<3H08b`a02P^=00R
9bd092L^02/^=P0S9c807B<_02/a?P0X;3P08B4]028Q;00X9S409bD`03/jA00Y;3<0:bhe01/R:00V
;C<08B@Y020Q9P0K72407AhS01lP9@0I6Ql06Q/P01`M8P0K724301TJ7`0401XK7`0M7R807AhR01XK
7`806Q/P01809RH^02TY<@0W9bl08B4[01XJ900I6B<04QDL02DX;`0L7bH06QdT01/N9@0N8BP06ahU
01TL8`0J7B@061/R01`O9P0U:2l301dM9`0M01`L9P0J6R@06ATS01LG8@0H62805QHP01PH8P0I6B<0
5QHP028P:`0E4ah071XU01PG7`0R8BT051<J01`K8@0M72408b8W020O900G5Q/05A@K024O:P0@3QT0
61HQ00h<5`0N72L05A<N01HD7`0H5R400`0I5b80:@0E4a/061DL024N9@0K61l0:2D/00X73P0N6b80
5a@K01HC6P0H5A`06AHM01LD6`0J5R800@0<01hJ:@0/:3L0;R/f0;Fb_@18ADd05A<H018@500E4a@0
5Q@E010>400E41H05a8I01TD6`0G4QT05Q4H01TD6`0E41L06A@K01LB6@0B3A@050lF01D@5`0A3180
4`hD01HA5`0G4QP05Q4G008050lE0P0I51X2018=4`0701<>500E3a<050hB01TC5`0K5AT05a4E01D?
4`0601@>4P0301PB5P0A2`l04@/?00804P`@02005@lC01H@500C3A404P`@01<=4@0D3Q804P`@00d7
2`0G4AD07ALK00X4200D3Q804P`@020J7P0J51P04P`@010:3P0A2`l04`dA01TC5@0D3Q008A/M034[
;@0M5aT0>S@f02DO8@0@2P`030H801hH6P0K5AL06Q@F01<=4@<04P`@0P0A2`l0500C3A4040X>00l9
3@0J51P040X>014;3`0I41D060lD014;3@0;10D03`T900P20P0A2`d050hB018;4P0>1Q004@TF01D=
600B3A@04PdC0P0C3Q@201@?5@06014<4P0C3Q@05Q4G014<4P0F4AL040/A0P0D2Q801P0G3AD02`49
01X@600G3AD05@/C01L=5@806a4I00@05`dE01@;4`0C3Q@050lE0P0E41H01P0D3aD05Q4G01LB600F
4AL05A0F01@?5@805A0F00H04Q0E01HD6@0A3a@0518G01`J7`0A3a@201@B5`0?01LE6P0H5Q/05aDJ
01HD6@0C4AH04Q0E01@B5`0B41D05A<H010>4`0100@03P`A028P9@0O7B805A<H00804@`@00@04PdA
014<400@2`l040/?0P0A3100:P0@2`l04PdA01<>4P0A31007QPJ00`6200?2@/06Q@F01<=3`0L5QP0
5Q0B01D?4@0A2`d040X<01D?4@0O6A/0:AlP01P>3`0D2P/0308301<92P0D2P/03`D601T?400@1PL0
5`d>00T10@0R61T04PP900`30`0@1PL0=R`]01T?4007000060h?01061`0L4Q<05`d>01T?400L4Q<0
50T=01<830804PL;0P0C20`02@0P5AT03`@801462P0D2@d02@0201P=4@070000=BX^01T>4P020105
2@0501T>4P0d:Bd05@X>00h31`0<0@D00P0C20`0400B1PX05PX>01H:3P0E2@d06@dA01dA5@0P51P0
3`<70104200E2@d04PH:0104200E2Ph03`@800d21P0>0`L201052@0@00T00P0H3A409a`P01@93@07
00005``@01<8300;00@050T=01T@4P07000050T=01872`0@1@T03`@801052@<04PL;02<04`P<0146
2P0@1@T04PL;00h51`0<0@D06PlC00`21@0700004`P<07A[K`24OX80;2<X00P00`0>0`T070lF0144
2`0?0PT040D;02<I7P38_l@0NWAh03/e?00300L00P0805QFHP3hn?l0NGV501/J9P0=2aH03@XC0108
3P0A1PX04`@70145200501052@0801X?4`0X7B403P<701P=4@0=0PH03`D800l4200@1@T201462P80
40D900L0200101872`0G31004@H:00l4200<0@D040D900803`@800<04@H:01872`0A1PX0100@1@T0
3P0?10P03P<801<8400C1a404PL?01463P0@1@`03`@:01<83P0D2@h03`@801052@0B1`/03045300B
1`dDooooo`006oooool03P0C20`03P<701062P0D2@d04PP<00h4200C20`04`T<02/Q9@1@ADT04PT<
01@;3`0?1`d030D<0P0>1`h06`0=1Pd040T@00`5300E3QD03PP=030Z;`0E3a@03@L;01882P0;0@<0
4`T:01<92`0@1PP050X;03<Y:P0>10H03`D601D;3@0B1`X04PP90147200H3Pl050X;02dS900V71d0
4@L801D;300201L=3P0L01@:2`0C2@X04`T:01@93@0A1PX06PlC01L=400>0`L091TM03X_<`0=0PH0
714E01872`0F2`l050X<01482@0A1`P050X;01D<3@0E2``040H7028H6@0d:R/04`T:00`20`0I3a00
4`T:01@;308050X;00@050/<01<92P0C2@X04`T:0P0D2P/0:00D2``05@/<01<;3@0?2@`050hA01LB
5@0>20/05A4D02hZ;@0C3a4050lB01lI700A2`h06A<F020K7@0M6AX05Q8C01@@4@0Q7Ah0:2@U01<?
400I5AH04Ph?01HB500F4A@05A0C01HB4`0C3a0040`=01DA4P0?2``06ADF01<?400F4Q<06ADF014=
3P0K5aP061@E01DA4P0F4Q<301LC500301HA5@0D3a<06A@H008061<I00h06QDK01dH7`0G51`06AHN
020M9@0L6B405a@K028O9@0F51T07A/P01LE6P0M6ah06aTL01/J70<06ATK01l06QXL01/L7`0K7B40
8bDY02<V:`0Q9BT06QhT01TN900T:S808BHb01lS<P0P9C809B/h01dS;`0Y<C`08BXe02@]>00E7BT0
92hi01lY=00W<Cd08Bdi02Lc?`0R;SX0:CE102Hb?P0R;ST09c@n02Tf@00L:C<0;3Q30080:SM100T0
9cE002`jA@0_?DP0<Cm:02hlA`0/>TD0<3i903e;EP0_?DP00P0b@4/0:`0c@dd0;3e702hoA`0_@4P0
<T=;03]<D`0_@4L0=dQ?0393B`0kC5<0<T=:03=4C@15EUl0=dUB03a>F00fB580<dE>03I9D00fBDl0
<TE;03I9C`0jCE40=4M;03=6BP0bA4X0<dA<03Q9D@0gB4l0<dA;03E6CP0jBe<0=TM?0352BP1<GFD0
AEIN02hoA`0eATh0>deA02do@`0fB4`0;T1402<e>@0]?d<00P0Z?4008P0`@TH0:ce102`n@P0cA4P0
<T5603]:C`0^?D80HG1e03I5BP0`?d@0=DA90350A@0eA4T0;3]00352AP0`@dP093Pl0354B@0iBe00
<DA905Y/L@0]?T@0;T15030oA@0]?4<0;Ca203=0A`1WMW/0@E1E02Xi?P0_?T<08c8g02Db>00W<SP2
03<nA00e02Pb>00Z=3/0:C8j02PeA00_?Th0=dIF02`lC00mCE`09cM602LiAP0Y>dL0;Cm;02e0B`0]
@4X0;T5;0392DP0[>d/0:3M502XhA00[=cl0:C<i02<[<@0V:c006AdQ01/N9@0^;cL0;S4j02@Y=@0W
;3T092Pc02DV<P0];3L0;R`e02LU;P0`<3P07R4W02lc>@0N92/06b8X01`O900R8bP071dR01/L8@0P
8BH071dR01hO900M7R<07QlT01lP9@0K724051DJ01TJ7P0K72400P0K72005P0M7R<07alV024Q:@0S
8b/08B4Y01`L9P0H62805aPR02X^=P0D62406QlV01/N9`0P8b`05Q/R01/O9`0M82T08RH^01lS:`0I
72D06QdU01`L9@0M7BL201hN9`0K01`L9P0K6b@06a/U01dM9`0H62406QXT01`L9P0H6280:bTd01dK
9P0E4ah061LO01DD700G5Qd06aXP01HE6`0H5ad06QTN01LF6`0O7RD0@D1901dK9P0K6B@05aDP028P
:`0F51l06ALR00806QPS01/061HQ01HD7`0F51d06QHM01dH800f<CT0HEeT01/E7P0I5A`061@K01PB
6`0I51`06QHM01XE7@0J5R80510P01XF900H52405a@O04U6D00O72@05Q<I01DC5`0E4aD0518D01@B
4`0H4aT00P0F4AP0300J5A`06A@K01<>5@0C3QD061<J01LB6@0B3A@05A0G01LB6@0G4QP05Q4G01@?
5@804`hD00@05A0F01HA5`0L5ad07APN0P0D3aD01P0E41H05a0F018<4@0D3Q<05Q0E018<40805@lC
0P0D3Q801@0C3A4050hB01D?4`0E3a<04P`@00<050hB00@06aDI01H@500C3A404P`@0P0C3A406@0A
2`l06Q@I05eGG@13?D804@XA01H?5@0A2a003`P?014:4@0E3Q@05PlF01D>500A2`l03@L:01H@4P0<
1PP07aTK018<3P0G4A<05@lA020J700`:R`0>C<e01PB500>20X00P0C3A42018<40804@/?01D05Q0D
00d72`0B31003`T=00`72P0O5Q/060d@01D:3P0@1`P050/;01<;2P0E30`05@`>014;3`0C31<05@hG
01<;5`0@2A804@`C014<4P0B3A<0100C3Q@04`0A31804`hD00`73@0A31803@L>01T@600>1@d06a4I
00`42`0D2Q806Q4I01T@600G3AD05PdE01L?5@0H3aD05@dD01<<4`0D3A@01@0E3QD08P0D3A@05@hE
01L@5`0H4AP0618I01PC6@0F4AL08QdS01/F7016@DL06A@J01PC6@0G4QP05A0F01@?5@0E41H05a<I
018@500A3a@05A<H014?4`0E4aL040hC01TG6`0D4QL03@/@00h<400@3Q805Q4E01<>4P0F4AD08QdQ
02<N8P0A310201@?4`0:01D@500A31003PT=00l:3P0B30h03`T;018<3P0<1PP05@lA01<=3`803PP:
00T03`T;014;3@0E3a407QPJ0147200J414050X;00l51P0D2P/00P0@1PL0;00A20T05`d>00T00@0G
3@h04PP901061`0E2``050X;0516A`0Y7b0091XK01H<3@0D2P/03`D600X10P0P5QL09Q`M01H;3P0D
2@d04PP:01872`0A1PX04@L901872`0C2@`04@L901462P0R61/04PL;01482P15>Sh05@`>00`31@0C
20`05``@03L/<00F2`l04`P<01462P0C20`04@H:01@8300B1PX04@D90P0B1PX01`0A1@T05PX>01<7
2`0C1`/040@801452@0G2`l00P0C20`04@0<0@D05@X>01`A5@0B1`/050X=01882`0<0PD04PL;00h3
1`0@1@T050/=01<8300P5AT0A3Tm01072@0F2`l04@H:00803`@800<040D900l4200@1@T00P0C20`0
8P0A1PX040D901872`0E2Ph0308501052@0E2Ph03@8601P=4@0M4aL07QHK00/31`0C2@l040H;01H9
400@10X05`XA01<:3P0B2@h08a/O01@<4@0;1@/071HO00X7400/:3D0S8^G03XiAP0<31P03@XF00h9
4`0@1`h040D901441`0A1PT501872`0C030W:@10=CT04PL;01L<400;0P@05@X>00l4200?1@L04@L:
01872`0A1`T03`@801@93@0B20X06@hA01X?4`0A1`T040D901872`0201462P0E01<8300D2@d04`P<
01<8300B1`/040D900l4200@1@T04@H;01<8400C21404PL?01463P0@1@`03`@:01873@0B1``03`@8
01872`0E2Ph03`@900D040H<1`0A1P`Dooooo`006oooool0S00?1PT04@X<018<3P0C2Pd03`P:00/5
1`0G3Q403@D800H00P0>1@P05@d@014;3`0<1@d03PL?01094@0F3aL030D=01D>5@0E3a<03`T=00/5
1`0J51H07aTI01LA4@0G310060dC00`11@0C20d02@0402/P900D2@h04@H<01H;3`0E2Pl03`@:00l4
200B1`/040D901462P0G31007a@H01@93@0?1PP050T=01<8300H3A409a`P02PM8@0G31003`@801@9
3@0A1PX081DI01872`0E2Ph04PL;01<8300H3A405P/?01<9300@2P`04`X=018;3@0A2`d050/>018:
3@0B30h05Pd@018;3@0>20X04PT<01<;300A30T050`:010:1`0?2PL05@d;01D?300A30T04`/901<=
2P0C3P/05@d;01D>4P0=20l0514H01@C6@092Pl0;2ld0<74b@0i?440:R/`08:1Q`0H5A`01`8902PS
:00F4Q<040`=00h:2`0G4a@061<G01LB5P0<1`/06A@H03dh?P0L5ad06aHL00d;3P0E4a@03`d>018@
4@0C4A8040h?00X82@0K6AX04Q0A01LE5P0F51D05aDF018@4`0D4QD05aDH01DC5P0D4QD05Q@G01<A
500F51L06ALJ01PF6@0G5AP061HI01DC5P0E5AD05aLG01DE5`0F5QP061PJ01DE5`0H61/06QTN0P0K
6Ql06P0J6Q`05QPG01XM700H71/07R0O02@X:00N92@06AlO01`Q900K8bD06B4S01`T9`0P:Bh0624Z
01lW<@0R:c8082T^01hX:P0N:B/07BPZ020[;@0P:bl07BP^01hX<@0S;CT09S900P0R;S`0:P0W<cl0
:SM102Tf?P0Q;SD082dc020^<@0S<C<09cDf02Pf>@0W=ch09CHn02dnB00X>4@0;3a903A4D@0]?D/0
;Ce:02`mA`0[?4D0;Sm70311B@0/?TD0;3m60354B`0_@TP0<4=903I9C@0hBdh0<TI703I:B`0gBdX0
<TI503=7B00hBe80Zkk503iAF00cATd0@EAJ03=6BP0fBDd0>Da@0396A`80:cm00P0fBT/0=00gBd`0
>4]>03E8C00bADT0<dI<03E8CP0mD5L0Ffef04aNJ00bA4h0;T1703e?D`0W>Cd0;T140394B00V>3`0
<49602Hh?00^@4@09CLk02`n@P0^@4@0?e1F02`mA00]?TD0=dQ?03=4B`0eATd0;3e403E6C@0W>3l0
@eAK02dnA@0dAD/0:C/k02e0?P0dATH0>DU903E5A@0_?T40:cXm03M6B@0Z>C`08c8g0350@`0a@4@0
>DM:028`<`0/>Sd0:CLj01l]<00Y=cX202/i?00U02/h?P0W=3`0=dA<02Td?P0b@U8093E703=4EP0m
CV008S=30352DP0_?dl0:c]:02`lB`0^?Td0:c]802XkAP0gAE00<Cm802Pe?@0R;cD09Ble02/c=P0W
;c808RH[02@T;00K6bD0928]02PX=00O8Bd0:2`g02<W<00M8BX08B@[02<V;@0T9bh092L/024V:@02
01lT:003024V:P0L82<0720S008092P[00X06alS01/N8`0O8RT092L^01PK8P0C5Qd05aXR010C6P0J
7B@07B0W0P0P8bX0@`0L7bH06QdV01DH8@0G6R<061/T01LJ8`0E62404aHO02/^=00U9Bd07R4V01/L
8`0K6b<06A`Q020Q:00V9Rh082<X01DG7@0P82P071dR01`L8`0N7RH07AhS01/L8P0O7bL08R<X01/K
8P0F5Qh06Q/P01XJ8@0I6B407alW01lO:@0K6bD07alY01HF800?3aT06ATS014A6@0J6R808b<[024Q
:@0E5Ad06QTQ01`K8@0M72@061LO01DD700F5Ad08R0Z01hL9`0G5B006aTU01TG900E4b005aDP01TH
800H5B005Q@N01`K8`0O72L061HP00/:4P0O72L081hW065PJ00F4ah00P0G51d00`0F4a`05A8K01DB
6`0201DB6@0C01@A600G5A/0518G014?500D4QL06aHM010;4P0B3A@03@P?01D@5`0I51/04`hE00d8
3`0M61l03`XA00<01@0B3A@03@P>01<>5002014<4P0E01D@5P0Q72804@`B01<>500F4AL05a8H01D@
5P0C3Q@061<J00/63@0=20l05a8I010;4@0A31<03`X@010;4@0C3Q8050lC01<>4P0A31004P`@0080
3`T=01d04`dA01H@500D3Q805Q0D01@>4P0B31004@/?018<400C3A4040/?01PD5P0C3a003`X>01<?
4@0B3Pl05a8F01XF600K5aP06A@H01<>4@0=20`03@L;01@>4P0C3A405Q0D01TC5`0B31004@/?01@>
4P0201LA5@0P01@>4P0A2`l040X>014;3`0B310050hB01H@500G4AD04`dA00/52@0I4aL040X>03Tc
=`36`<@091/O01H=4P0>20X03`P:010:300?2@/05Q4C01PB5P0:10P071DL00D01@0J4aX04@/?00h8
300=1`/040X>01@>4P0G4AD5014;3`0=014:4@0L5B006A4L018;5@0>2A004@XB01PB6@0C3Q@07ALK
01@>4P0/:2T06aDG01@>4@05018<400501@>4P0G4AD0618F01PB5P0F41@00P0D3Q801P0F4AD061<G
01/F6P0J5AT06A@H01D@50805a8F03<050lC01XE6@0K5QX05Q4E01DA4P0E41@05Q8D01LC500G4aD0
71LK01DA4P0C3Q405A0D01<?400F4Q@03`T;010:300C3@l050h@01<=3`0B30h05@lA00X41P0D3Q00
3PP:01PB500B30h08A/M00@0000n>3X05a4C010:300H4Q@05@lA018<3P0?2@/04P`>01XD5P0V8280
5@/<01H<3@0?1@H03@<401D;300G3@h03`D601<92P070000718C01061`0K4A800P0C2@X201882@80
4@L803<040H700/20`0?1@H07aDF01@:2`0H3Pl06@l@00h4100G3@`04`T:01H<3011=cH0AC/l01<9
2@0G3@`05P`=01D;2`0>10D06@hB00l4200C20`0304500d21P0<0@D060dA01872`0M4QH0Bd1401hC
5`0<0@D03P<701052@0F2`l05@X>01462P0D2@d06PlC01D:3P0J3a<03`H801`A5@0700003`@80187
2`0M4QH03PD700d21P0D2@d040L901T>4P0?10P00`0D2@d07P0>0`L04@H:01462P0=0PH02`0400`1
1@0@1@T02`0401L<400J3a<0304500X00`0E2Ph04PL;00l4200D2@d040D901P=4@0J3a<050T=00d2
1P0>0`L040D900d31P0?10P04`P<01L<400C20`03P<701052@803P<700d050T=01<8300B1`/04PT=
00h52P0@1``05@/C00h73P0@2A004@XA00l53@0?1P/04@L;00804PL;00H04`P<01462P0A1PX040D9
01462P0B1`/601462P0B00d41@0D3``081TH01XA4P0@2`P03PL601T@4@0400006A8A00H0000=20D0
3`P801L<400G31805P/A01<83P0B1`d04@H<0`0B1`d02`0A1P`040D;01052`0G31803@8800l42P0E
2Q003P<901@93`0=0PP040D;00804PL=00/040D;00`3200;10/04``C00d63@0A2Q402@8800l62`0A
20d04@P<01482`0301872aCooooo000Kooooo`0O010:300A2`d04P`>018<3P0@2P`03PP:00H00P0E
3a406A<E014;3@090`D02086018;4`0E3AL040TA00l8400>1`h06Q<J00/52@0A2`h0:B<U01LA4@0:
1@801`4101P>4P0700806a0F01lD6P0B1`d03`@:01873@0301052`0J01/@5P0V6b406@hB01H;3`0G
31006@hB01462P0=0PH06PlC01H;3`07000030<5024F6P0F2`l03`@800/0100A1PX03P<701X?4`0:
00<05@X>01872`0D2@d05``@01H;3`0B2@`4010:300>014;3@0B30h040X<014;3@0F4180618D01@>
400@2P/04@`901@?300B3@X040/8018=2P0C3P/2014<2@0N018=2P0C3P/04`h;00l:3P0?2Q405a@M
018B6@082a004aPN07QoP`0Y;S802PdD020P9P040@P05@lI014<4P0<20T071PI00T51P0b;Rl03PT=
01LB5P0<1`/061<I03Pc>@0J5A/061<J00l=400H5QL040h?0P0C4A802@0@3Pl030X;01PF5`0A3a00
6QPI01TG600J61T05Q@G01DC5P0301@B5@0401<A500E4aH05A<F01PF6@806ALJ00T05aDG01@D500E
5A<05aLE01DE5@0F5QH061PH01LG6@0I6A`00`0L6b00200J6ad08B<R01dQ800G6aX06QhM01`Q8@0C
6AT0624P0P0K8bD0:P0I8b@06bDW01lX;@0I8b`07BL`01dX;00K9RP06RHV01/W9@0M:BL07RXY01hY
:`0M:2`07RTa024[=`0O:cT08Rhm02Pd@P0[=d<0:CHo028_=`0R<3@08S0c028`<@0U<c<09SDb02Hf
=@0`@4H0:CY203Y;D`0Z>TL0:3Q703Q8E`0^?Td0<41=0311B`0^?dP0;Ci502hoAP0[?TD0;D170395
C080<DA:0100=dY>03M:C@0bATL0=TY903U=B`0gBdT0>De<03A7CP1<GfH0=TU@03=6C00^@DD0>4]?
03I9C@0]@D80;d=40P0fBT/09P0hC4`0=DU803I:B@0fBTX0=4Q903=6BP0cAT/0>TeC03]>E@0eAe00
9CM102`nB00iBe80>4Y>02do@`0cADT0;3i202Pj?P0]?d<093Hj0394B00a@dL0>D]?0353A`1kSI80
MhR?03i?EP0W>3l0;Ci503Y;DP0oD5L0>DYA02Pi@00cA4/0<45802`m@`0/?3/0;Shk0P0a@D001@0_
?ch0;Cdm02`l?00]?Cd0<d950080<T5401H0;C`o03=1A00U<cH0<3i102/i?00T<SD09cDh02Pf>@0T
<SD09C8i04=@F00`?DH0:3I102dnCP0N<4@08SE603]<GP0dAEL0<45A0310D00Z>TX0:SY90P0e@U80
400fA500<T1902Pf?@0M:S007BP/02D^<P0/=3L092T]01PJ800L72@07A/V02TV<`0X9S<09bXc02/_
>00T:34201hS:@0701`Q9`0N8bL08BHY020U:00O92L082DX024V:@02020T9`809RX]00L07B4U01dP
9@0E61l06A`S01LJ8@0H6b@07B0Y00806QdV00D07R4Z024T;@0Q92d07R4Z01dP:@0401HI8P0501LJ
8`0G6R409BH[01lP9@0K72400P0I6Ql02P0J6b0092DZ00T:3`0F5a`09BH[02X[<0092Pl071dR020Q
9P0O82D201`M8P0701dN8`0L7B806AXO01`M8P0K72406AXO01hO900201TI8`0J01/K9@0G5b405ADO
01<C7@0P82X03`lI01HF800A4A/02@TC020P:00J6Al06aXP01PG7P0F5Ad061LO020N:00L6RD05aDP
01/I9@0I5b@061HS01PF8P0H5R405aDP01HD7`0I5b8201PF8@0;018@6`0J62<04@lJ03dkAP0>31L0
5Q@L01PE700G51/05Q<J01DB6@0F4aX0100G51/0500F4aX05A8I01<>5@0D3aH05a8I018=500R7B@0
5Q4H01D@5`0K5Qd040/B01dH7`0G4QT04@`C01/F700F4AL050lE01D@5P0C3Q@03PT?0P0B3A<02P0D
3aD05A0F01D@5P0B3A<05Q0J01D?6@0C3AL04@`C018=500@2a8201@?5@0<01@?4`0C3Q804PdA014<
400D3Q804@/?010:3P0C3A405@lC018<400F41@05@lC0P0C3A405P0D3Q805@lC014=3P0F4Q<04@d>
010<3@0C3a0040`=014=3P0D41405Q8C01DA4P0B3Pl03PX;00h8300C3A404@/?018<400E3a<03`T=
014;3`0C3A4201D?4`0601<=4@0A2`l050hB01<=4@0B31004`dA0P0D3Q8200`62P0F01<=4@0A2`l0
100203hh?00H4QH04@/?010:3P0B31004@/?010:3P0?2Pd01`45028L800;1@T0618F01XD600C3A40
40X>00l93@0@2Ph04P`@01<=4@D04@/?00d04@XA01D?6@0D3QX040XD00h9400A31<04@`B00d83P0J
5AT04@`@024M7P0A3@h040/=00D04P`@00<05@lC01LA5@0E3a<00P0D3Q801P0E3a<050hB01<>4P0E
41@05a8F01HA5@8050lC0P0G4QH0100D3a<06A@H01XE6@0F4Q@201DA4P805Q8C00L05a<D01HB4`0C
3a005Q8C01DA4P0@30d04`l@00804@/=0P0C3@l0400D3Q004`d?01<=3`0@2P`05@lA010:300I4aD0
4P`>00`6200V8280HE]M03D_<@0J51H04`d?018<3P0@2P`200d72@0@00l92`0D3Q00308301<92P0H
3Pl06@l@01/A4P0C2@X06a4B01P>3`0;0@806a4B00`20`0B20T050X;01<92P804PP900P04@L80106
1`0=0`@09A/L00L0000G3@h04@T901@:2`803`D40`0F30/06@0R61L06@l>00/20P0A1`H02`4000`2
0@0N51D01`0001X?4`0?10P050T=00l4200W720050T=01462P0I3Q80=b``01H;3`0E2Ph040D90146
2P0B1`/050T=01052@0=0PH00P0E2Ph03`07000040D901<8300K41@04PL;00/0100K41@05@X>0105
2@0?10P05P/?00P00@0<0@D03`@800P00@0201052@0301872`0C20`04`P<008050T=00T07a@H00L0
000K41@05`h@00X00`0C20`0304500L0000A1PX00P0?10P00`0D2`d02`0401462P0201T>4P8050T=
00X060dA00L0000=10H050T=00`11@0C20`04@H:01H;3`0N4aL060dA0P0A1PX01`0@1@T04@H:0187
2`0<0@D03@8601462P0@1@T00`0A1PX201872`804@H:00<040D901462P0B1`/01@0A1PX01@0A1`X0
2`8300l:1`0E40d04@`900<03@P500H04Pd:00l:1`0D3``04`h;014<2P0C20`301<83PD04PL=00/0
4@H<01052`0@1@/02P0501873@0c:2h0@3Dk01hC6@0800<03`@:0146300201873@0;0146300>1@X0
5@hF00X62`0J5A/02@@:01dG700>20`040L<01072`0@1`X00`0A1PXDooooo`006oooool00`0C3@l0
4P`>014;3@03014;3@804`d?00D04@/=00l92`0@2P`05Q0D014<4@02014:4P0@01<<4`0D3A@02088
014;3`0D3Q40<B/]018<300@2PX04@/<03P]<P1@AD/04@H<01883@0W728050T?01052`805@X@01P0
4@H<01/@5P0Y7R@08AHJ00`21@0900805``@01872`0Z7b<04PL;01H;3`0U6Qh05@X>01462P0>10L0
5P/?01872`0H3A404`P<01dB5P0<0PD050T=01<8300D2@d201H;3`0C01D<3`0C3@l04@/=018<3P0C
3@l050h@01D?4@0=1`T02`D701H@4P0L5QP050h@00h82@0B30`050h>01<=3@0A2`/03`T9014;2`04
018<300U01<=3@0@2Ph05A0E01@@5`0>3A403Q4C00@62`0D5QT030lA00lA5@0>3Q807ATN02LQ:00J
5AT06QHG01@@4@0h=3D0RhN801dH700E41@03`X>01HA5`0/9bd05A0F01@?5@0A3a806ALH01@B4`0I
5aP06aTJ01XH6@0H5QL06ALH01@B4`0F51D04Q0A01@B4`0301DC5P0A01@B5@0E4aH061HI01LE600E
4aH05Q@G01/I700L6Qd05Q@G01@D500E5A<05aLG01DE5@0F5QL061PJ01HF600H5a/00P0I61d08P0J
6Ah06AXN01DF6@0H71h06alQ01`P8P0N8RD06b0S01/S9@0L92P06b<W01XS9`0K92X07RL^01lY<P0N
:38072L/01/V:@0L9bP07RXZ01l[:`0L:2T072LZ01lZ;`0Q:c@07bTd028^?00S;cd09S8o02Lc?`0X
=Cd09C8j02@b=`0U<cH202Le=P0A02Hd=00U=CD0:3Pn02Tj@P0]?TH0:c]803M7EP0Z>TT0;cm>0310
C@0_@4X0;3e602/l@`0/?D@0:Sa602m1B`0cATh00P0dAdh0500gBTl0>4a?0395B00cAdT0<TI703=7
A`0fBT`0>4]A02Hi@00bAD`0?e9H03M:D00cAT`0<TE903=6BP0hBdh0>4a=03I:B`0dB4P0=DU80`0c
AdP0E`0eB4`0>4]@03mBF00lCeH0=TUA03=5C`0a@dd0=4I=0312AP0fB4`0<dE902`n@P0Y>cl0;Cm3
02m1A@0cADT0;3i203=5B@0Z?400FFY`04mPI`0iBU40>T]B02`mA00^?dH0?TmF02Pi@00iBU40<dA;
0352B@0bA4T0<d=30351@00_?ch0;3`k02dm?00^?Sh0=4A402@d=00eA4L0:CPm02dl@@0_?T80:STk
02Xj>P0a@D409cHi02Xi?00U=3L09cHk02Pg?@0X=Sh0BEMQ02Pf@@0a@4`0:S];02m2D`0aA5D0;d1@
02hoC`0c@e<0=TIE0310C`0`?Dd0<T1=02lmBP0]>dL0;3U202<`=`0O;3808bhb02D^<@0R:Rd08RL[
01HI7`0P82P0:RPc03Pf@P0Z:SH082</02HZ<`0R9Rl07R<Y020U:`0R9bd06QlS01lT9`02024V:@80
7b@W0P0M8B@2020T9`0:01`P900L7b@092L^01`O9P0P8bX08RD^01XM9P0F6B806A`S01/N9@807B0W
00X06QdT01TL8`0G6R405QTP01DH7`0G6R406QdT01`O9P0N7b@06a`Q0P0I6Ql02@0K724071dR01dN
8`0H6Ah0:b`a01lP9@0J6b008B8W01`M8P02020Q9P0701hO900J6b006AXO01hO900M7R<07QlT01`M
8P0201PI7P0<01dM9`0Q8B/06a/U01XJ900K6bD06ATS07=cO@15ADl0820Z01dM9`0D51h05ADM0P0I
61h0100H5ah061LO01XI8@0I5b4201DC7P0901LE8@0F52405aDR01LE8@0G5B005Q@O01DC7P0I5b80
5Q@O00805aDP01h06QPS01DC7P0F51l05A<N01LE7P0I5Qd061DL01LD6`0F4aX05a@K01DB6@0C41L0
4PlF01DB6@0G51/05A8I01PC6P0K5Qd05a8I010;4P0U82L04@`C01D@5`0K5Qd0IV5X01XE700H4aX0
6A@K01/F700:1@/201@?5@0501XE6`0D3aD061<I01D@5P0C3Q@00P0G4QP01`0D3aD030H@01H@6P0D
3QP04@`C01XE700G4QT00P0D3aD301<>4P04018=4@0G4AD050hB01<=4@8050hB01404`dA01@>4P0D
3Q8050hB01D?4`0F41@05a4E01<?400B3Pl040`=018>3`0C3a003PX;010<3@0B3Pl04`l@01@@4@02
01DA4P0501@>4P0F41@04`dA018<400D3Q800`0C3A42018<40804`dA00@05a4E01@>4P0C3A404P`@
0P0A2`l0100C3A4050hB014;3`0B3102014;3`0=00l93@0@2Ph04`dA01D?4`0C3A404@/?01<=4@0L
5QX050hB01LA5@1KEET06A<G01@>4P0201<=4@03018<400@2Ph03`T=00D04@/?00d04@/@00h93`0A
31@04@`C00l:4@0A31805Q4G01PC6@0J5A/03PT>01HA5@0D3a@050hB00D04P`@0P0E3a<0100C3A40
4@/?018<400E3a<301D@500701HA5@0D3a<04`hB01@?4`0G4QH05Q4E01@?4`0201LB5P0301HA500E
4A805A4B00805Q8C00D05a<D01<?400C3a0061@E01LC500201@@4@0B01D?4@0D3Q004`d?01<=3`0D
3Q005Q0B018<3P0O6A/050h@00l92`0E3a4040X<01`F600;1@L05A0A00d72@0F41803`T;0`0D3Q00
4P0B30h04@/=00l92`0I3a0060h?01882@0>10D04@L801D;300F30d04@P801<92P0I3a004PP901<9
2P0E2``050X;01<92P804@L800l03`D601<92P0C2@X0718C00`20`0E2``050X;01H<3@0D2P/04@L8
01D;300F30d03@<40147200G3@h00P0?1@H0200U6a`0HeUJ01`A5@0D2Pd040L901T>4P1UFUh07A@F
0P0A1PX0100D2@d06PlC00/1100Q5QX201<8300G00l4200K41@0714E00l4200C2@`0?34e04Ll@00E
2Ph02P4301/@500C20`03`@801`A5@0>10L04`P<01@93@0C2@`05@X>01872`0H3A407a@H01/@500B
1`/00P0?10P04P0B1`/04@H:01462P0A1`X040L901872`0F2`l040L901462P0B1`/05P/?01T>4P0A
1PX0?C8f04i3A`0F2`l04@H:01872`8050T=00L04PP;01H;3`0F2`l04PL;00d21P0=10H05@X>0080
40D900D05P/?01@93@0C20`04`P<01462P0201872`0300h31`0@1@T04`P<00804PL;0P0A1PX01`0@
1@T04@H:01462P0A1PX040D901462P0B1`/01@0A1PX01@0A1`X04@P900d71`0<1PH03@L700803`T9
00L081XJ0:ZTY01SGEd03PP801<=3@0<1`L04@H;00804@H<0P0B1`d01@0C20h04PL=01873@0B1`d0
4@H<008040D;00H05@X@00h32@0?10X04PL=00l42P0C20h501873@0:01483@0X8BT0N7=i0;2[/@0Z
9B/03@P=00d82`0@1``040L;01072P<04@H:5?ooool001_ooooo0P0A2`d06`0?2@/03PP:00l92`0?
2@/050h@00h82P0A2`d04P`>00`6200;1@T01@05018;4P0H4AP01`0701093`0D3Q805@lC014;3P0;
1@L03`T;01`F600<1PP040D;040e>`0?10X05``B00`11`0201873@0501D:400I3Q@050T?00l42P0A
1P`00P0A1PX0300L4AD0:AhR01872`0X7B406a0D01<8300Y7R803`@800d21P0N4aL050T=00h31`80
50T=00<08aPL01D:3P0C20`00`0D2@d01@0E2Ph050/>00l92`0<1PP03PP:00804@/=00T04`d?018<
3P0>20X040X<01<=3`0A2`d040X;014;2`0?2@T00`0>20P00`0A2`/04P`<018<3003018<300A01D=
3`0F41803`T=018?4@0?3`l03Ph@01HF5`0G5aL0410B00d:300@2P`05a4E01TD5@0[9bP04`l@020L
7@0X92D00P0B3A40600D3a<050lE01lJ800A31804@`C01dK7P0T8R<06QPI01PF5`0F51D040h?018@
4@0C4A805aDF01@B4`0G5AH06aTJ01@B5@0J61/07A/N01@B5@0B41<06QPK01PF6@805A<F00T06aTL
01`J7@0F51L051@D01DE5@0G5aL05ADE01HF5`0H61X00P0E51T0900F5AX05aHL01TH7P0H6Ah051DJ
02@W:`0X:c007B0U01<G700H7B<07RD[01dT:`0K8RX06b@[01/T;00K92d07bTc01`V<00K9R`072L[
024/;P0S;S008Rd_01hY;00N:Bd08Rdc02D_>00R;3H09S9002Hb?`0U<Cd09S8n02Pe?P0[>4009C8h
02Le>080:3Hg09X09S@e02@c=P0[>d40:ca403M8D00lC5T0CUi]03I6E@0c@e80;cm<02XkA@0Y>T<0
;Ci50352BP0[?DP0<49>0394D00cAE00=DMA03I9D00lCeH0=DQ?03E8CP0bAD/0<dI<03Q;D@0aA4/0
AUUP03E8C`12EE`0AUUO02`oA@0fBDl09CPl02m2AP10DeL0@eMH03E9BP0dB4T0<TI70395B00dAd/0
=dY>03I9CP0lCeD0>diD02e0A`0[?TD0<DA;03I8C`0[?D40=dU=02m1A@13EET0=dU=02Tk?`0U=c/0
=dU=03i@E00jC500:ce103=5BP0[?4<0;Ci50352B@0Y>T40A5EL08bMY01=GVD0=4E<02hoAP0dAD`0
;3e303A4A00dA4<0<d=20310@00^?Sh0;Cdm020_<P0V=CP0DF1U03I5BP13DUL0;Ca002Xj>P0]?C`0
9SHf020_<P0X=cX09SDk028a>00W=Ch0:3I202dkB016E640;Se<0352DP0X>DT0:CY:03Q9F@0lCEd0
=DED02LdA00Z>4D0<Cm<02lkB@0Y=D40:cM302dg@@0U<3L08bhd02L`=@0X<3@08RX]01lT:00P92T0
:B`c02h^>00f=D0092@`02T/=@0e>D80;30i01hS:@0K82H08RL]01dR9P0R9bX08bP[024V:@0N8bH0
7B8U01XN8@0K7b806QhQ01/O8P0M8BD07R4V024T:`0H6b808RD/02LZ<`0O8R/07B0Y01/N9@0K7R<0
6QdR01PK800D5a`04aHK01DH7@0H6b006A`Q0`0J7B800`0P8BH07AhS01/L8@0301/L8@0901PI7P0F
5a`09BH[05=DF@0[;3408b@Y01`M8P0J6b006a`Q00<07AhS0P0L7B801`0K72406AXO01DF6`0C51T0
8B4[02DU;`0L72H00P0J6R@0400@41X09BD_010@6P0`<3X02@TC01HF800N7BD06QTO01PG7@0G5Qd0
5aHN01HE7@0F5Ah06ALR01/I900K6BD201XH9@0?01dK9`0N72L06ALR01@B7@0H5R406ALR01DC7P0B
41/05aDP020N:@0?3AP081hY01PF7P0H5A`05a@K00<05Q<J02H05A8I01PE700H5A`05A8I01LD6`0E
4QT06A@K00l:4@0E41L05a8I01hI800H4aX07QTP01LB6@0Z9B`03@P?01lJ8@0@2a8071LM010;4@0I
51X01`8801XE6`0Z9B/06A@J01HA5`0C3Q@05A0F01HA5`0C3Q@06aDO01PB700G4A/06QDL01PC6P0C
3QD03`X@014<4P8050lC00<04@`@00h93@0B31000P0C3A40100D3Q805Q0D01PB5P0A2`l201<=4@04
01@>4P0E3a<05@lC01DA4P8040`=00<04`l@018>3`0>2P/00P0E4A8201<?400301DA4P0F4Q<050hB
00805Q0D00D050hB01D?4`0I4aL05Q0D01@>4P02018<400401@>4P0F41@050hB01<=4@804P`@0P0C
3A402P0>20`06aDI03Pb=P0<1PX04@/?01PB5P0E3a<050hB01<=4@0A2`l2010:3P0801XD60070@D0
1002018=400I4aL030H:014;3`0C3A4201@>4P03014;3`0@2Ph04@/?00D04@/?00`03`X>01<>500C
3Q@040/A00l:400R7B<0;RT_01dH7`0A31<03`X@014<4`0?2Pl7018<40@04`dA00D05@lC01LB5P0G
4QH05Q4E01D@500201@?4`<04`hB0P0B3A400`0D4180510A01@@4@0201DA4P0H01HB4`0D41404Ph?
014=3P0F4Q<06ADF01LC500F41805@lA01@>400B30h04`d?01H@4P0>20X081XL010:300<1PP03`T;
01D?4@0C3@l081XL01<=3`0Z92H01@010`0B30h02`0A2`d040X<010:300A2`d03P@501882@0H3Pl0
5`d>01882@0@1PL02@0000<04@L800@04PP90147200D2P/050X;0P0B20T02P0A1`P040H701X@4@0<
10@07aDF01882@0C2@X0:1hO01hE5P0A20T201<:2`0>00l61`0G3Pl0200001892P0:0@804PT:00h5
1P0O5QL06a0D01482P0G31001`0005iCE`0;00@201<8300401@93@0B1`/0200101dB5P804`P<0280
3P<701dB5P0Q5QX04PL;01@:3@2HSI40Y9VM01892`0X7B40L6EY024F6P0:00<04`P<00l4200T6Ad0
81DI01H;3`0C20`02`0401882`0S61`040D901H;3`0B1`/040D901462P0B1`/04@H:01P=4@0U6Qh0
<RL[04m4B007000040D90P0F2`l06`0M4QH04`P<00h31`0G310040D900l4200B1`/02`0400T00P0D
2@d03@8602dR9P0S61`03`@8024F6P0I41808AHJ01H;3`0@1@T0304500h31`0@1@T03`@801052@0?
10P03P<701052@0301872`0301462P0@1@T040D900<04@H:00<040D901462P0B1`/01@0A1PX03@0A
1`X05@`=010:2P0>20P04@/;018<300>20P02`D505I@D00b;2`030H600T30`0:10@00`0C20h60187
3@090146300@1@/040D;01<83P0B1`d05P/A01T>500D2@l04@H<00804`P>0P0A1P`02`0C20h04PT>
01TB6P1MF5l0O7Mm020K8@060PH04@/?00l62`0?1PX03`H900<040D95?ooool001_ooooo0P0@2P`2
00l92`803PP:01L030H8014;3@0D3Q003@L9010:300Z92P0:R<Z00`53@0C31<040T@01PB5`0600@0
4P`@01LA500<1PP05a4C01@>40090`D08AHL00/01P0F2a402`0601873@0201@93`0H00d2200@1@/0
4PL=01052`0A1P`03P@701462P0G3100714E00T00P0E2Ph04PL;01<8300G31004@H:01X?4`0G3100
6@hB01@93@0K41@07Q<G034V:P0U6Qh04PL;0P0D2@d02`0C20`050T=01H=400B30h040X<01@>400G
4A<05@lA01H@4P0G4A<04`d?00804@/=00<04P`>01<=3P0A2`/00P0=1`L0100?2@T040X:018<300C
3@d3018<300L014;2`0C2``05Pd>00l92`0I51D03@T801@@4@0>30/04`l>01LC500E41405Q0@01<:
3@060@80510A00T51P0O6a`01`<401PC5`0B3A405a8F01D@5P0I51X04PdC01<>500C4A@06aTJ01@B
4`805Q@E0`0B41402@0D4Q<03`d>01XH6@0A3a006QPK020N8@0R82<05Q@G014?4P0201HD5`0;01DC
5P0F51L06QPK01/I700F51L051@D01DE5@0G5aL05ADE01HF5`0H61X00`0H5a`06@0I61h06aXP01`M
8P0E61d09BP^02X]=00L7bH04ADK01XN9`0P9bl07B@/01/R;00K92d072D^01XR;@0L9S006B<]01PR
:`0L9bd082/_028]<@0Q;30082/_020[<@0S;CH00P0U;cT01`0Q;CT0:3A002diA@0/>D80:3Dn02Db
>P0U<SP00P0V=3L202Le=P0I02He>00^?T@08S<k02Lh@024U:40Z[[904IFI@0eAE@0;cm<02XkA@0Y
>T<0<45803E6CP0]?dX0<D=?02m1C@0a@dl0=DMC03E7D@0bA4h0<49<0395C00a@d`0=4M>03Y=E002
02`oAP0^03=6C@0gBU40=4M=03A7C@0`@dT0AeYN03iAE@0[?T80=4Q90396A`0dB4T0<dM803=6B@0f
BDd0>4]?03Y=DP0jCE<0=DQ>03Q;D@0iC5<0=4M>03=6B`0[?D40>4Y>02i0A01>H6@0@eEI04iPI00[
?D40;d5503E7B`0_@DD0:C/o03E7C00dAD`0:CY102Pi@00Y>T40?4eD07Z;TP1:Ff80;Ci50393BP0_
@4L0;3i30310@080<D5003/0<41002dm?@0Z>SX07B`_02/j?@19F5d0<D15045@E@0/>cl0:c/k02dm
?00S<c<0:3Lj02Th?@0X=Sh0;Sa502lmB00a?dd0?4UI06]hR00e@e<0:S];02HgA`0[?4`0<D9B0394
DP0^?T`0:cU602dkB00b@4`0;SY602Hb?P0W<ch0:38k01lY<@0I92X07RL/02P`=00/=3L06b0T024U
:`0V:C009BD_02`[=P0K6bL08B@]02hb>`0V:S<06AhT01PM8`0O92X07b@X028W:`0R9bX082DX01hS
9P0M8RD06QhQ01/O8P0201DI700H01XM8@0J7B806A`S01HI800L7bH082</01hQ:P0L7bH07R4V01hQ
9@0L82<06AdQ01HI7P0E6A`05QXN01TL8@0K7b8071lS01XM8P0H6b007QlT01`M8P0J6b006AXO0`0H
6Ah02@0P8BH07AhS02//<@2a/[L03PlD01/L8@0H6Ah06AXO01`M8P0201hO900901/L8@0L7B8061TN
01PI7P0F5a`04a@I01TI8`0L72H06ATS008061PR024071`V01DE7`0<31H0:BTc00X:500L72H07A`T
01XI7`0H5ad05aHM01LF7P0E51`051<L01LE800I5b806ALS01XH9@0H5R<07A/W02@R;@0L6RD04a4L
01DC7P0F51l05A<N014?6P0D4Qd05Q@O00d;5P0K6B@05Q@M01LD6`0F4aX00`0E4QT0600D4AP06AHM
01PE700E4QT061DL010=500H4aX02`H=01HA600G4QT03@P?010;4P0F4AP01@0701dH7`0@2a808A`S
01LB6@0C3Q@04PdC01`G7@0B3A<0;2L]04I1A`<04`hD01404@`B010;4@0@2a4040XD00d74@0A2aD0
5A0G018=500A31<04PdC01<>500E41@050lC010;3`0=20`040X>018<400201<=4@0401D?4`0I4aL0
4@/?01<=4@<050hB00D04`dA01DA4P0A3@h04Ph?01<?4002014=3P0301@@4@0C3a004Ph?00804Ph?
00T04`l@014;3`0C3A405Q0D01@>4P0B3100618F01H@500E3a<00P0C3A400`0E3a<05Q0D018<4002
018<400<01<=4@0E3a<05@lC01/E6@0M5a/0BTA801PB5P0>20`04P`@01PB5P0F41@04`dA0P0?2@d0
2@0A2`l03PP<00@00P0N61`04P`@020J7P0I4aL04P`@01<=4@0201@>4P03018<400A2`l04@/?00D0
4@/?00<04@`@01@?4`0C3Q<00P0?2Q001`0F4AL07APN010;4P0F4AP04PdD01H@6P0?2A001@0B3100
1P0A2`l04P`@01<=4@0E3a<050hB01<=4@D04`hB00P04PdA01<>4P0A31004@`@01<>4P0A31004PdA
01@@4P80510A0`0E4A801`0B3Pl04`l@010<3@0B3Pl05a<D01@@4@0E3a400P0D3Q0301<=3`0?00X4
1P0H4Q@050h@010:300?2@/06Q@F00T31@0=1`T02@@502@N800O6A/04`d?01H@4P0D3Q0040X<0080
3PP:00d040X<01061`0A1`P05`d>01P>3`0F30d0718C00L0000N51D03`D601061`0C2@X05@/<0080
4`T:0`0B20T06@0A1`P03`D603@Z:`1NE5D05`d>01@<300O5AH050/<00h51P0H3a005`h?00`3100E
30d04@P901892P0<0`@04`X;0108200:0@805@X>01872`0A1PX04`P<020E6@0E2Ph00P0D2@d00`0C
20`05@X>00`11@0201@93@0H01462P0>0`L05P/?01L<400>0`L03@8601lD600K41@05``@00`11@0L
4AD07Q<G00d21P0;00@050T=08AiO@2h[K40>Bhb00L0000B1`/050T=01H;3`0;00@03`@80P0A1PX0
300@1@T04PL;01D:3P0:0@<0DDI:0<Bi_@0A20X0:1dQ01462P0C20`02@0200X10`804`P<01<060dA
01@93@0A1PX040D900X00`0@1@T04PT;01D:3P1NDeL0A3Tm00L0000M4QH04`P<01H;3`0B1`/050T=
01052@0?10P04`P<00806@hB00D04`P<01872`0B1`/04@H:01872`0301462P0701052@0A1PX04@H:
01462P0@1@T04@H:01872`0501462P0401472P0C2P/03PP800h8208040X:00L030H600/51@0=1`L0
3PP801LA4@0C3@d05@l@008050T?00@04`P>01873@0B1`d04@H<0`0B1`d02P0A1P`040D;01052`0H
3A<04PL=00X01@0900@04@H<01H;4@0A1P`401873@0:0107300<1@d05A0F01PC6@0?2Q003`X?01@>
4P0@1``040L;01072P<04@H:5?ooool001_ooooo03`040X<018<3P0C3@l04P`>010:300=1`T04@/=
00h82P0B30h040X<01<=3`0Y8bH0DT]A01<>4`0B2a802`D901H@500?2@d02`H900l93@0A2`l03`T=
00h83019@dL09AXP01@:3`0H3A<04PP=00l62P0R5ad04`P>00d2200A1P`04PL=01052`0B1`d04PL;
01D:3P0D2@d04`P<01L<400D2@d09Q/O00l4200>0`L05``@01T>4P0@1@T05@X>01462P0G31004`P<
01hC5`0?1@P04PL;01D:3P0D2@d04PL;01@93@0E30l2014;3@0301H@4P0I4aD050h@00804P`>00D0
4@/=018<3P0D3Q004P`>014;3@02010:300401@>400E3a404`d?018<3P804`d?01P04P`>014;3@0A
2`d04@T:01TA3`0A20P050d;00l81P0O61L04@/900l81P0D3@`04``:01H>300M51@05a4A018>3`0D
41405a<D01<?400B3A404@`@01`G6`0G4QP201D@5P0801HA600@3Q406ALH01<A4P0H5QL06QPI01PF
5`0J61T201@B4`03020N7`10?Sl07adN00806ALJ00H071XM01hL7`0L6Qd05A<F01@B5@0F51L201TG
6P0G01PF6@0G5QP051@D01@F5@0F5aT051DG01DF6@0G61`06AXN01PI7@0G61d061TN01/L8@0M7B@0
61/S01XM9@0M82T06QdV01PL9@0S9c808bXd01hU;`0K8Bd00P0L92l0500I8Bd07bTc01`V<00L9Rl0
7bTb024/<`0O:C407RP`024[<`0Q:c@082Xc02<]=`0X<S`08blk02Pd?`0Z=d009c@m02Hc?00X=Cd0
8c0f0P0S<C@0:`0V=3L0:CLj02Th?00^?TD0;Sm702m0B01/O8T0UJFd03i>G@0^?Td0:SY702Lh@P0W
>440;Ci50352BP0`@Tl0<D=A02/mB`0]?dd0=4ID03=5DP0dAU80=DMC03Q:E@0eAe80=TQD03a>F@15
Ef40@UAN0312C00gBU40;d9903U<D`0dAdd0DVE[04QKH00`@dL0>TeA0354B00dAd/0=DQ<03I9C@0i
C5000P0kCU@0500iC580?4mE04mRJ012EE/0<4=903E7C00_@DD0?DmC02i0A00gBDd0>Ta@09Z//019
Fel0;3i20312AP0_@DD0=DM;02m1AP0eATd0;Ci50P0^?dH0800U=Sd0<45803I7CP0Y>T40=4E<02`m
A00b@dT0<3m20310@00_?cl0;Cdm02`l?00/>ch0:3Lj02Xi?00Z>Ch0;Se402/j@@0W=S`0:Sdk02/n
>`0Y>cX0@E=F0353B00W=d809CE302hnCP0W=dL0<D5A02loC`0Z>TX093I40P0dAU@0<00]?D/0?DeJ
034oC00hAU80;Sa702Pe@00Z=d40:3Dn02<_>@0K9Bh07RL_020Y<00Q:Rl08R/_02@/;`0R9b/08BD[
01lR:@0M82T0;Bhi01hO:`0L82T082@]01`P:@0K82H07B8X01/P9P0L8BD07b@W01hS9P0M8RD07R<V
020U:00/<3<0:Rha01hR9@0K7b807b<W01dP9@0G6R4071lV01LJ8@0G6R<071lX01TL8`0K7b806QhP
01/O80806QhP00P06QhO01/O800J7R006AdN01XN7`0J7R006alQ01`M8P806a`Q0`0J6b00300h>Ch0
5aPM01hO900G61d07b0U028S:00L7B806Q/P01`M8P0N7b@06a`Q01LH7@807AhS00X05aPM01PI7P0J
6b005aPM01@D7P0E5Al06QXT01PH8P0F5R0061PR0P0D51h07P0C4ad07AdW01XJ900I62005aHL01DD
6P0G5Qd06APP01PG7`0F51h06ALR01XH8`0L6RH08R0]01hL:@0H5R806aTT01LE800C4A`05aDP01HD
7`0C4A`05A<N028P:`0F51l05aDP01<A700F51`05Q<J01DB6@D0514H02l05a@K02TV;@0d<CP07a`S
01PC6P0C3QD05Q4H01D@5`0H4aX0?CPo03Ha>00M61l04`hE014<4`0C3QD05A4G01HA5`0J5A/04@`B
01<>500J5A/050lE018=4`0G4QP06QDK01@?5@0@2a404`hD00d84@0Q6bD08Q`V00h9400@2a804`hE
018=4`0A31804@`@01<>4P0K5QX07aXN014;3`0D3Q804`dA014;3`0B31005Q0D01@>4P0301H@500:
01@>4P0B310050lC01<>4P0F4AD050lC00l:3P0F4AD040/?014<40@04PdA00H050hB01LA5@0L5QX0
5a4E010:3P0F41@601<=4@0?01@>4P0C3A404P`@01<=4@0D3Q805@lC01<=4@0?2@d08adQ01<=4@0F
41@03@L;014;3`0C3A404P`@008040X>00/04P`@014;3`0C3A405Q0D010;3P0>2@`03`T=01H@500E
3a<050hB01<=4@02010:3PD04@/?00d04@/>010<3@0B3Pl04@d?00l:3P0@2a403`XA01LB6@0<1Q00
5Q0J00/5400K5B4050hF00D04P`@0P0D3Q8201<=4@0301@>4P0F41@050lC00804@`@0P0B3A402@0C
3Q805A0D018=4@0B3A405a8F01@?4`0E41@05a<E01<?400201@@4@805A4B00H04Ph?01hJ6`0Q7Ah0
510A014=3P0B3Pl201<=3`0@01@>400C3@l04P`>014;3@0C3@l05Q0B02DO8@0J51H030H8014;3@0>
20X040X<01<=3`0P6Q`0@cdo01<=3`8050h@01404`d?014;3@0A2`d04P`>01H<3@0E2``060h?01H<
3@0C2@X07A<D01L>3`17?Ch05P`=01D;300C2@X050X;0147200301882@8050X;01D04PX:0517B00j
<34040H701D;300>1PH03`H90189300@1`X04PT<01D<3`0>1@P04`X=01`C5P0J4A@02P840189300?
1PT040H901D:3P0>0`L00P0C2@`02P0=0`H040D901D:3P0=0PH04`P<01052@0<0@D04PL;00l4200A
1PX201872`0g01<8300G3A005@X>01072@0>10L05P/?01472P0@1PT03`@801<8300P5AT0VXnC0<:k
_`0`9BT0308501`A5@0A1PX05``@00l4200@1@T060dA01H;3`0?10P04@H:01H;3`0E2Ph040L901<9
300A1PX03PD701462P0H3A404`X<01<9300B1`/0304501052@0?1@P04PP;01@93@0>1@L06a0D028G
6`0C20`05P/?01D:3P0A1PX04`P<01062@0=0`H03P<701D:3P0C20`040D901872`0201T>4P050187
2`0C20`050T=01462P0@1@T00P0A1PX201872`0601<8300A1PX04@H:01052@0A1PX04PL;1@0A1PX0
3@0A1`X040L:00h82P0<1PP03PP:010:300B30h03`T;010:300=1`T030H801<=3`0:10H00P0?10X0
100@1@/04@H<01873@0C20h301873@0;0146300@1@/040D;00l42P0@1@/04`P>01D:400C20h03047
00h32@0A1P`00P0B1`d02`0A1P`03@@901@=5@0?2Q002PD;010;4@0@2Pl03PP<01483@0A20`04@P;
00<04PL;5?ooool001_ooooo00D050h@00l92`1WHF<0OGMi01@>400200l92`8040X<0P0A2`d01@0@
2P`05@lC01@>4P0B31004@/?008040X>01@05Q0D014;3`0600@050dD0109400C31<05``B01873@0A
1P`05@X@01@93`0C20h040D;0146300B1`d050T?00d2200F2a4050T=01872`@04@H:00<06PlC0146
2P0@1@T00P0D2@d0600A1PX04`P<00`11@0h;C404PL;01462P0@1@T05P/?01@93@0>0`L050T=00l4
200A20/04@/=01D?4@0B30h02P@600l92`0B30h07ALI00h82P0G4A<0MFma03li>`804P`>00@02`D7
01dG6@0<1PP03@L90P0@2P`03P0B30h04@/=00l92`0>20X04P/;01@<2P0C2`T050/901D;2P0F30/0
5`h<01H<2`0D2PT050/90P0F3P`01@0C3Pd04Ph?018>3`0@30d04@d>00805A0D01L07QTM00h93`0M
61h04@`B00l:400C4A@03P`=01TG600L6Q/03`d>014?400D4Q<05Q@E01hL7@0P7Ql0:RPY01lM7P0D
4QD05aDH01TG6P0D4QD04a4D01LE600301HD5`8061HI01T051<E01hN80082@/08R<U028S9`0F5a/0
4a@H014B5`0E5Q/05aPM01HF7P0G5al06ATQ01<F7`0G6R<061/T01TK9`0M82/07B4/01lU<@0L8Rl0
7bDc024Y=P0M9C805al/00808B/e01807bTc01hX<P0M9c806bD_01`V<P0P:SD0:S@n02/e?`0U;cT0
92hh01h[=00R;cP0:cQ102/h@00T<CT08c0h02<`=P0V<cT202Ld>P0O02Pe>`0X=c`0;3a303A5C@0i
BU80<D5>03Y:F@0]?D`0=4AC02dmBP0[?4H09cQ103=4B`0a@TX0=TQE0394DP0]?dd0<D=A03I8EP0d
AU@0>TaJ03=5D`0hBUP0;3i<02/lC00jC5X0B5YV051RK00bA4h0=DMA04AGGP020313BP0303E8CP0j
CE<0;d980080=4M=0200<dI<02m2B00iC580?E1F03=6C00gBU00>4]A03A7B`0^@DD0;d9603=6BP0g
BTh0;d550312AP0a@dL0=DM;03Q:CP0mCe<06B/_041BEP0a@dL0<TA802i0A00Z>d40=DI=02Xk@P0/
?D@08S<j02Tj@@0/?D@0;Ci502m0A`80<D9904@0:ca202`k?P0]?Cd0<D5102ln@@0[>Sd0<d9702dl
@@0_?T<0;3]202Pg?P0[>T409C@j02@f=P0[?S`0:C/l0311B010DET0=TID03=3D`0K:Sd07bi102dm
C@0^?Th0:c]:02loCP0dA540;cm<02`jA`0kBE@0=TA?03e9E@0K:3408Rlg02<]=P0R;3D0:C<l01lX
<@0O9Rl06B0X024X;P0M92T06R8U01DJ7P0L8BH06AhT01/N9`0V:3<09bTe01dQ:P0O8b`08RH_02@Y
;`0R9bd07R<Y020U:@0S:2`06AhQ02@Y;00J7b8051TL01hR9@1;Ce8092P[01`P8`0L7b<05QTN018E
70809BP_01H02`hG01DH8@0N8BP06QhQ01PL7@0F6Q/061`M01/O800M8B806alP01LK700L82405a/L
01lS900E6AX05aPM01HG700:2a005aPM024R9`0@4AH05aPM0P0J6b005@0H6Ah06Q/P01dN8`0F5a`0
71dR01/L8@0M7R<07b0U01dN8`0N7b@06a`Q01XK800K72407QlT01lP9@0I6B<04a<M018B700F5R00
5aLQ01PH8P0201TI8`0401PH8P0F5R0051@N01HF7P805QDK00@06APO01DD700E51`061HP0P0F51l0
4P0K6BD07Q`Y01/I9P0H5R806ALR01/I900M6bH06aTT01TG8P0G5B005Q@O01XH8`0K6B@04@lJ018@
6`0E4a`04PlF01<@5`<05A8I00L05a@K010=500W92/05A8I01<@5`0F4aX07APO008061<J00@06aHM
01XE701AC5<05a8I0P0F4AP0100E41L050lF01@?5P0A3182010;4@0E01@?5@0F4AL05Q4G00X52`0C
3Q@07QTO01PC6@0E41H061<I00l94`0_:C<0DTaF01D@5`0F4AP04PdD00h93`0K5Q`02PD902DP901G
DUH071LK00804`dA0P0D3Q800`0E3a<05Q0D01<=4@02018<400;01<=4@0B310040X>01@?4`0@2`l0
5A0D01LB5P0@2`l04@`@010;3`0B3A400P0E41@06@0D3a<04PdA01PB5P0@2Ph0618F01LA5@0I4aL0
5@lC018<400E3a<050hB014;3`0@2Ph04P`@00h8300@2Ph04@/?018<400@2Ph03`T=018<400Q6al0
=2hb03li?@0C3A400`0B310201<=4@1G018<400A2`l04@/?01TC5`090`L05@lC018<400D3Q805@lC
018<400A2`l040X>014;3`0B310050hB00l93@0@2Ph050hB01<=4@0A2`d04Ph>01dI6P0B3A0030L;
00h93`0@2a804`hE018<5P0B31L040XF065KI`0o>4401@0300d72`0B3100208601XD600B31004`dA
01LA5@0C3A4050hB01D?4`0A2`l030L;01LB5P0F4AD03PT=01LB5P0E41@05Q4E018=4@0A310030L;
02HQ9@0G4aD03@T:018>3`0F4Q<05a<D00h:2`0A3@h05Q8C01LC500E4A806QHG01PD5@0J51H03PP:
01LB4`0H4Q@05a4C010:300I4aD04P`>00d72@0K5AL02P@600d72@0H4Q@03`T;01H@4P0M5aT04@/=
01D?4@0>20X03`T;00804P`>00<04@/=00l92`0A1`P00P0F30d01@0C2@X05P`=01L=3P0F30d05@/<
008050X;00@04`T:01882@0C2@X04PP90P0@1PL00`0B20T04`T:00h41@0200l51P0701061`0A1`P0
4PP900l62@0F4180208400T31@02010:300<018<3P0H4Q@06aDG00h82P0:10H06a8E01P=4@0A1PX0
40D901462P0M4QH050T=0P0B1`/200h31`0701<8300F2`l04@H:00/0100@1@T03`@801462P0201/@
500400l4200700004`P<01872`804`P<01005@X>01872`0@1@T060dA01lD600C20`05P/?01D:3P0@
1@T03`@801872`0J3a<06@hB01L<400C20`04@H:0P0B1`/0100>0`L04`P<01H;3`0@1@T601462P04
01872`0F2`l060dA01H;3`804@H:00@04`P<01872`0B1`/04@H:0P0B1`/02P0C20`040D901462P0C
20`03@8600h31`0E2Ph05P/?01@93@0C20`201462P8040D901H050T=01L<400D2@d040D900X10`0@
1@T05P/?00d21P0N4aL04@H:01@93@0C20`05@X>00`11@0800409A/O01P?4P0<1PP04@/=00T31@0=
1`T02@<50P0>20X200l92`0D00h82P0=1`T04PL=0146300D2@l04`P>00l42P0A1P`04`P>0146300?
10X040D;01<83P0H3A<050T?00/01P0>0`T04PL=01L<4P0900@501873@0301483@0=1Ph03@P>0080
3PT?00P040/@014;3`0B2@h03PD900l62@0D2@d04`P<00d21QCooooo000Kooooo`0=00@0000>20X0
:B<U03H`<P0>20X0208401@>400A2`d03`T;00h82P0@2P`04P`>018<400301@>4P03010:3P0=1`/0
3PP<00804@/?00@04@XA00X32P0D3A@05``B0P0B1`d02P0E2Q0050T?01<83P0G31804@H<01052`0F
2a404PL=01`A5`0B1`/201462P0B01872`0C20`050T=01P=4@0E2Ph04`P<01462P0C20`050T=01P=
4@0G3100=R/_01T>4P0E2Ph05P/?01@93@0G31004PL;0P0G31009@0I41<03`T;010:300C3@l040X<
018<3P0D3Q0030H800L10`0;1@L0:bDW00l92`0A2`d050h@018<3P0C3@l091hP00X41P0D3Q005Q0B
01PB500F41804@/=010:300B30d05@d;01@<2P0D2`X050X901D;2P0J40l06a4@01P>3@0G3P`05Ph<
01D=2`0B3Pd00P0C3a005P0A3@h04Ph?01HA5@0=20`05Q4E01<>500S7R@07APN01LB6@0J61/0518C
01/I6P0R82406aTJ01LE5P0D4Q<05Q@E01TG600A3a005aDF014?400F51L201LE600R01<A500B41<0
4a4D01PF6@0F51L0518E01HD5`0G5AP05aHH01PI6`0@4A<051DG00l@500E5QX061TM01@E6P0H6Ah0
6Q/P01TI8@0J6R806a/S01<F7`0F6B804aHO018D800F6B@06alZ01TO:`0I7b`0728`01`T<@0J8Rl0
5al/01XT;P806bD_01T072Hb01dW<`0M9c<08b`k02H`?00`>TH0<ce902`f@00X<S`07b`e024^=`0Y
=Sl0:CHn02Hc>`0W=3`082dc02Db>00V<cT0:3Dk02Xg?@0[>Sl0;3a302hoA`0a@TX0;3a90080=4AC
01`0<D5@02dmBP0/?DL0:S]403A5C00b@d/0<dEA03A6E00bA580=TQF03Q:F00eAeD0EFMe02/mB`0Z
?4X0=DIF04=DI01AHg40<D=@02XlAP0cADl0>TaF03E7D@0_@TT0;D1702i1A`0cAT`0<4=90P0bAD/0
E00lCeD0>diD03iAE`0mD5H0=4M=03E8CP0fBDl0=dY>02m2AP0[?T80;d9603Y<D00cADT0=4I:0353
A`0[?D40;d5502do@`12E5P0O8jB02m1A@0R=3P0:ce103]=DP1FIfh0?e1G02Xk@P0U=Sd0;d1702`m
A00]?TD0;3e402/l@`0/?D@0;T150350@`0]?Cd0:c/k030o@P0nCE00I7=h02dl@@0_?T<0;Ca302/j
@@0^?D@0:CPn02@f>00Y>c/0:S`o0393B`0kC5H0<41?02PgBP0S<TD0<d9E03I6EP0dA5<0<d=A02Ph
A@0kBeP0>daG028`>`0/>TD0?D]E038oB00Y=Sh0;3U102<]=P0W<CX0=Ci703@kA@0/<c`0:2lg020W
;@0F7R8051`O01LL800O92T07B8X01hQ:P0S9S008R@`01dQ:P806QhW02P0724W01dR:00M8RP0:Bhb
024V:@0G71l092T/01`Q900H7B002@d@02<W:P0H71l05ATL02P[;`0U:2d0:B`c01@G7P0Z;C@09BPa
01/N9`0T9bh05a/N01DI6`0C5aP05ATK01PL7`0I7Ah05ATK01HJ7@0G6a`05ATK018F6@0I7B00824V
028S:00P8BH06AXO01DF6`0O82D05QLL0P0I6Ql0400G61d061TN01XK800M7R<0824V01dN8`0L7B80
6a`Q01TJ7`0N7b@06a`Q01TJ7`0J6b006a`Q01`M8P0J6R@201DE7`806ATS0P0H62804P0I6B<061PR
01DE7`0E5Al05aLO01DD6P0F5A/06QTP01LF7P0H5al06QPR01HD7`0E4ah05aDQ01PF8`0E4b005A<O
01PF8@<06ALR01T061HQ01LE800?3AP03@/F01LE800F51l04@lJ01<A6P0G51/05Q<J01DB6@0F4aX0
61DL01XG7P0P7B@0<2dd014>5@0;20l06QLN014<4`0:1@`07APO00h9400=20l08A`S00<050lF00L0
4`hE018=500B3A@05A0F01<>500B3A<04`hD008050lE01806A@J00X52`0F4AL04@`B00/6301IE5X0
B49<01<=5`0H4Q`061<J01<>5@0A3A<040/A01dH7P0A31003PT=02<N8P0910P2014;3`804P`@0P0C
3A40300B31004`dA01D?4`0F41@05@lC01<=4@0D3a<04`hB01HA5@0E41@040/?01@?4`<04PdA00l0
4`hB01@?4`0E41@06Q@H01hH700U7b<05Q0D018<400G4AD04@/?01<=4@0B310040X>018<400F41@0
0P0A2`l01@0B31004`dA018<400B31003PP<008050hB00<07QPL00`62P0>20`00P0B310201<=4@09
018<400A2`l03@L;01XD600F41@06Q@H00/52@0?2@d04@/?008040X>0P0A2`l2018<400<00h8300?
2@d04P`@014;3`0@2Ph0510A01TE5P0D41804`hB010;4@0;1Pd061<J0P0B31H02@0M5b40OgV508Z4
S00b;3004P`@014;3`0D3Q80618F00h9300201`F6P0401<=4@0>20`030H:01<>4P803`X>024050lC
00d8300<1`/04PdA02HQ9@2PVil0<B``010;3`0E41@04`lA01DA4P0C3a005Q8C01<?400?2``04@d>
01DA4P0D41404@d>01DA4P0C3a003@L901D?4@0K5AL071HH010:300C3@l0=S0b01dG6@0910D07QPJ
01PB500E3a400P0B30h01P0[9BL0=Bla028L7P0D3Q0040X<014;3@804`d?00T04P`>014;3@0C2@X0
5P`=01D;300C2@X05@/<0147200E2``0100D2P/201<92P0501D;300F30d05P`=01D;300C2@X00`0B
20T201<92P0/01892P0B2@`01`83034[;@070@<04@/=00X41P0>20X07ALI020J700>20X05@lA00@0
000C20`06@hB00h31`0F2`l07a@H00T00P0>0`L04@H:01@93@0E2Ph04PL;01052@0?10P05@X>00l4
200@1@T05@X>01872`0E2Ph040D900h31`0C20`02`0400h31`0A1PX04`P<01872`0?10P04PL;01D:
3P0@1@T301872`0301<8300E2Ph04@H:00<040D900P03`@800h31`0@1@T03`@801@93@0C20`03P<7
01052@D04@H:00@04`P<01L<400I3Q805``@0`0B1`/501462P0601<8300?10P03P<701@93@0B1`/0
4@H:0P0E2Ph0100C20`04PL;01462P0A1PX201052@0:01<8300F2`l04`P<01052@0?10P02@0200/0
100C20`04@H:00h51`80304500X050T=01872`0A1PX0:b4U020G6P0;1@L03`T;01LA4`0C3@l06Q@F
0P0>20X400l92`0:01<83P0@1@/04@H<01873@0?10X040D;00X01@0@1@/05P/A00l42P80200300H0
6@hD01X?5@0E2Q002@0400d3200G318501873@0301483@0?21003PT@00803PT?00D03`T>00h8300?
1P/04@P<01482`0301462QCooooo000Kooooo`0A00d72@0H4Q@03@L900h82P0E3a407ALI01D?4@0A
2`d03@L900`6200@2P`04`d?010:300C3@l05Q0B01D?4@0A2`h00P0=1`/01P0?2@h04P/B00d63@07
0@P0614H01H;4P@050T?00L04`P>01873@0?10X050T?01`A5`0?10X04PL=00<04PL;01D04`P<01@9
3@0E2Ph05@X>01L<400D2@d040D901872`0F2`l03P@701T>4P0L4AD050T=00h31`0C20`05P/?00l4
200@1@T060dA01<8300H3a800P0?2@/03P0D3Q004P`>010:300A2`d03@L901H@4P0B30h040X<00l9
2`0E3a807ALK00l93@0B31002`H90P0D3Q80500I4aL06Q@H01H@500A2`l040X>01<=3P0C3``04Ph<
01@<2`0E2`X05PX;01T=3P0H3@d05P`<01D=300E40d050l=01<?3P0D41405A4B0P0C3a00500F4AD0
5A0D01@?4`0E41H05Q4G01/F700G4QT04a4D018@4@0C4A806QPI01`J6`0C4A8040h?01DC500L6Q/0
3P`=018@4@0H5QL05aDH0P0E4aH05`0I5aX06QPK01PF6@0I5aX05Q@G01<A500E4aH061HI01XI6`0E
5QX03a<F014E600K7b804QDI01`O900D5a`05aXP01PK8P0G6R4061/S01TL9@0H6b@06A`U00806ahW
00H061`V01PL9`0H7bT07RD`020V<P0M9C4201lW=00>01XT;P0K9C007BLc01lX=`0R:c/092dm024Z
?00P:CT0:SA102hhA00X<Sd08B/e024^=P0N:c<202<`>00E01l/=00P;CD07b`d02<`>00V<c/0:3Dm
02/h@00/>d80:c]202Pi@@0Z>d<0;cm<0310C`16EVD0;Si=02dmBP0_@4X0:S]40352B@0/?DD0;d5:
0080=TQC00X0>D]F03U;E`0eAe<0@E=Q03]=F`0mCed0=4EE03Y;F`1:FfX0@UAQ0P0jC5P05P0fB5<0
=4I@03=5C`0_@TT0<TE<03A7C@0oDUP0A5MM03M:D00mD5L0>TeD03Y=D`0fBDl0<4=903A7C00eB4`0
>Da@0395B00[?d00;T9305=VJ017FEd302`n@P0J0353A`0cADT09CLk03=5B@0^@4@0>4Y>02Pj?P0a
@TP0AeQO03A5C00U=Sd0;3e403Q9D00a@TT0=4E<03Q9D00fAdh0;Ci502`n@`0/>cl0:cXm02dl?`0[
>Sd0:CPk03=2A`0Y>3l202Xi@01A02`j@`0_?DH0:cY302/m@P0W>Sl0;3m703E7E00cA5<0;3eA03M8
G@19FFl0FFYk03]=FP0a@dh0:ce60311BP0gB580<3i702<a>P0a?dP0<d1802Xg?`0Z=ch08B/b01TT
:P0L9bd0EEiU065VL@0]<C/0;C4j02@Y;`0U:Rl06b0T01`Q9@0R9b`08BH/01lS;00O8bd07B4/01lS
;00Q9Bh092Pa02H[<@0S:2h07R<Y024V:P0N8bL07R<V01`Q900F6ah0:2d`02/_<P0L82<082@W01LK
7P0Q9BT06QdR01LJ8@0T9bh07B0W01DH8@0P8b`05aXR01PK8@0G6Ql05QXN01LJ7`0I72406AdQ02DX
;@0D5a`051PL01HI7@0?4QL05QTN01PI7P0L7B805AHK02TZ;`0J6b006a`Q00806AXO00h061TN01LH
7@0F5a`05QLL01LH7@0K724061TN01TJ7`0K72406AXO01dN8`0J6b006AXO01LH7@8061TN0P0H6280
0`0I6B<071`V01`L9P0201PH8P0501XJ900H628051@N01LG8@0I62000P0E51X0600K6R406APP01TH
800N7BH071XU01XH8`0H5R805aDR01HD8@0G5B405Q@O01DC7P0D4Qd05A<N01HD7`0E4ah05Q@O01/I
900J62<04@lJ010>6@0G5Ad06AHM01HC6P80514H00d05a@K01dJ8@0R7bH05a@K01PE700G51/040dD
02@O9P0K5Qd0;bXa01HA600J5A`04`hE00805A0G100D3aH00`0G4QP05Q4G01@?5@0201@?5@0=010;
4@0H4aT03@P>01PC6@0E41H030L=03Ha=`0S7BL07aTS01<=5`0:1@`07QTP01<>5@0201@?5@0401<>
4P0A310040/?014<40@04`dA0P0D3Q801`0B31005Q0D01TC5`0H4QH05a4E01D?4`0E41H00P0D3aD0
300B3A<040/A01D@5P0B3A<04@`B010;4@0A31805A0F01PC6@27PHD0C4I:028L808050hB00<03PP<
00l93@0A2`l00P0B31000`0E3a<0618F01@>4P0201<=4@0901@>4P0E3a<05Q0D01LA5@0E3a<03PP<
010:3P0?2@d04`dA00804P`@0P0C3A40200B31004@/?014;3`0D3Q804@/?010:3P0<1PX04`dA0`0B
3100100@2Ph03PP<00d72`0B310200l93@804@/?02h040X>018=4@0<1``061<H02LR:00Q728050lE
01TD6P0;1Pd0>3<j01XF700Q6b@0=S0f018<400C3A405@lC00`62P0C3A404@/?01H@500H4QH05@lC
01LA5@0H4QH040X>01<>4P0J5AT03PT=00l:3P0G4QH04@`@00L31P11?4004PhA01D@500@2`l05A0C
01TE5P0=2@X04`l@00l;300M6AX05A4B01HB4`0C3a0040`=0P0B3Pl00`0O6A/0QGn101TC5@0201D?
4@0?018<3P0E3a404P`>01PB500I4aD03PP:014;3@0F41803PP:010:300D3Q003@L901@>400A2`d0
4P`>00<04`d?00L04P`>01882@0C2@X050X;01T?400M4a@05@/<00<04`T:00D050X;01D;300E2``0
4PP901D;300201L=3P0401D;300B20T050X;01@:2`804`T:00P04PP901482@0?20/08A/O08R2QP0O
6Ad03`T=01<=4@806A<G01`05@lC018<400<1PX050hB01H<400I3Q8040D901872`0E2`h0FDiB01H;
3`0A1PX040D901D:3P0D2@d04@H:01872`0:00<02001034V:P0`9BT0304501<8300=0PH04@H:01<8
300B1`/09AXN0`0B1`/0100C20`040D900l4200E2Ph200l420804`P<00d04PL;01<8300?10P04@H:
01P=4@0F2`l04`P<01462P0E2Ph06@hB01@93@0@1@T04PL;00D04@H:00@04PL;01@93@0E2Ph04`P<
0P0A1PX02@0@1@T03`@801462P0B1`/04@H:00l4200A1PX040D900l4200201<8300301872`0C20`0
4`P<00804@H:0P0@1@T201462P<04PL;0P0A1PX04@0I3Q8040D901T>4P0:0@<04@H:01872`0?10P0
4PL;01052@0;0@@04`T<00h52P0E3a<03@L;00/52@0A2`l030H:00803PP<00P03`T=010:3P0A2`l0
4P`@01/@5P0C20h040D;01@93`804`P>00`04PP=00l42P0C20h040D;01893@0B20d040D;01@93`0?
1PX05P/A01052`0C20h501873@0=01483@0@2A403`XA00h93`0=20h03@P=00d72`0?1P/04PT=0148
2`0?10P040D901D:3P0Dooooo`006oooool01P0A2`d03`T;01D?4@0C3@l050h@01TC5@803@L90P0>
20X00`0?2@/040X<014;2`02014;2`0:014;3@0@2Pd040X>018;4P0A2Q403`P?01`E7@0A2Q8040T@
01D:4@805@X@00<050T?01<83P0C20h00P0E2Q00200M4QP091TO01873@0B1`d05``@01@93@0C20`0
4PL;0P0A1PX01@0E2Ph04@H:01462P0D2@d04`P<00804@H:01/05``@01052@0E2Ph04`P<01L<400A
1PX05P/?01<8300>0`L0:QlS038Y;00=1`T03`T;014;3@0=1`T03PP:00l92`0A2`d06A<E00`7200=
1`T0618D00@00@0B31005a4E01<=4@0T7R800P0D3Q80500C3A4050hB018<400@2Ph04P`@010=3`0>
3@/040`=01@<3P0F3@h06@hB01P=400D2P/04`P<01@=3P0E4A004Q0A014>3`0B3Pl04`l@0P0B3Pl2
01@?4`0V014<400F4AL04PdC01TD6P0K5Q`03`d@01@B4`0E4a@04a4B01HD5@0E4a@0518C01TG600Q
7b003`d>00`:2`0@3Pl05Q@G01@B5@0E4aH06aTL01hL7`0L6Qd05A<F01@B5@0F51L06ALJ01XH6`0H
5aX06a`P01HJ7@0A5AP06ahS01PK800K7R<04aHM01HI800G6R4201HI8P0;01LJ8`0a=3/07R4X01XM
900N8BP06ahV01LK900C6R8072</01/R;00H8BX00P0N9S406@0I8bd06B<^01TS;`0I8S406B8d01TQ
=00R:Sl082Pj02H_?P0Z=40092hi024[=@0T<CT082dc02Db>00V<cT08Bhd01l/<P0Q;SH09C8j02Hc
>`0U<SX09c@l02Lf?@0]?D@00P0Z>d<05`0`@4d0:c]:045AH00/?4/0;Ce:02hoB@0W>440:S]202<d
>`0_@TP0=4M>0354B`0bA4d0=DMA03A6D00kCET0<49@03E7E@0gBEL0<T=C03=4E00lCU`0?e5M0080
:C]702D0>4YD02`nB00^@4X0=dYA0395C00kCUD0@eIM03M9DP0cADl0;3i80354B`0hBe80=4M=03M:
C`0bADT0;T9302a0@@0]@D80;D500395B00L;S806R``03E7B`0a@dL0:3Xn028d>00cADT0>4Y>02Dg
>`0Z?400:3Xn02hoA@0_@4L08c@k02dnA@0V=ch0;3e40080:ca30200=dQ?03m@E`0fAdh0>DY@03E4
B@0]?3l0:cXm0391AP0c@TL0=4=:02Th?`0W=Sd0:SQ102hlA@0_?DH0;Ca50352BP0W>D<0:ce:03=4
EP0^?e<0<41H0351FP13DfX0B5YZ02PjA00W>T409CPl024b>P0_?DH0;3Y301dZ<P80:3Dm02X06bH/
02`g?@0R;C80;SLl02Tb=`0d?D<0HVIa02L[=@0Y;CH07R<Y024V:`0I7R807RHY01dU:@0M92X06b8Z
01`S;00P9c407B4Z01lS;00R9Rl08bP^020U:`0J7bD09R/_01LL7`0N8bH08BHY01dR9@0I7R407b<V
01HJ7@0M8B@08RHY024T:00O8RL07b8Y014D6`0I72<09bXc02<V;`0J7BH201`O9P@06ahU01T04A@K
01HI800V:C0061/R01hQ:00B5A`06Q/P020Q9P0F5a`0?3e202l`=@0T9BX071dR01XK800I6Ql061TN
01HG700E5Q/061TN01/L8@0F5a`05AHK01HG700D5AX061TN00<05aPM0P0H6Ah00`0F5R0061PR01TI
8`0201XJ900701TI8`0G5b4061PR01HF800E5Al061PR01XI8@0201DD6P0F01PG7P0D4a/051<K01PF
800G5B005Q@O01@B7P0C4Ah0518O01PF8P0H5R405A<N01<A700E4ah061HQ014?6P0E4ah07adX01LE
800<2QD04@lJ01LE7P<05Q<J00@0514H01<@5`0A3QD08AhU0P0H5A`01`0?31<0514H01PC6P0L5ah0
4PdD014<4`0?2Q401`0E41L00`0E41H050lE01D@5P0201HA5`0C01<>500L5ad06A@J00l:400B3A<0
7QTO00/6300L5R006Q@N00/63`0@2a804PdD01D@5`0G4QP050lE010;3`0F4AD05a8F00h93@0601@>
4P0;018<400G4AD0618F01D?4`0C3A404P`@01LB600B3A<03PT?010;4@0B3A<00P0>2@l01P0@2a40
4`hD01@?5@0D3aD04`hD01LA5@805@lC00X01`4500d72`0K5AT040X>01<=4@0F41@05a4E01@>4P0@
2Ph04`dA0P0A2`l02@0B310050hB01D?4`0I4aL03PP<01/E6@0H4QH02P@8014;3`02018<40804`dA
00T04P`@014;3`0A2`l05Q0D018<400A2`l04`dA00T31`0A2`l00`0C3A40100A2`l040X>018<400B
3102014;3`0G018<400C3A40:2<Y00l:4@0F4AP08A`S01PC6@0?2Q004`hD03Lb>03Pfn40X9^O02@O
9@0E41@03PP<00/52@0D3Q804P`@014;3`0?2@d04P`@014;3`0=1`/00P0@2Ph04`0D3Q804`hB01<>
4P0E41@04`hB01@?4`0L5a/04`hB00<00P1:ADT0<B``02@O8`0<20X071PI00h:2`0G4a@05Q8C02`X
:@0D41400`0C3a000`0B3Pl0510A01XD5P0201TC5@0501@>400:10H05a4C01XD5P0:10H00P0=1`T0
2@0C3@l04P`>01LA4`0A2`d04P`>01@>400A2`d05Q0B014;3@04010:3008014;3@0@1PL04@L801@:
2`0K4A8081HG01L=3P0A1`P201882@0301<92P0D2P/050X;00804`T:0P0B20T201<92P0P01D;300D
2P/04`T:0147200@1PL03PD6014;3`050@@09b8V00h93@0<1`/06A@H07]fNP2RWJ402PD900d8300E
41@0208600`31P0>0`L050T=01P=4@0R5a/0Uhb@01dB5P0A1PX02`0401052@0B1`/040D901872`0F
2`l201<8300901D:3P0C20`04`P<00h31`0C20`050T=01P=4@0b9b/04PL;008040D900H04`P<01@9
3@0C20`05``@00l4200>0`L201872`0=01052@0B1`/03@8600l4200E2Ph04`P<00h31`0A1PX05``@
01X?4`0D2@d04@H:01<8300501462P804`P<100B1`/201462P0:01<8300D2@d04`P<01462P0?10P0
4`P<01D:3P0@1@T03@8600l420804@H:00@040D900l4200?10P03`@80`0A1PX05P0@1@T04@H:0146
2P0?10P050T=01462P0Y7R802P0301@93@0B1`/040D901<8300F2`l050T=01882`0<0`P04@/?00h8
30080PH04@/?00d82`0?2@d200h83006010:3P0A2`l050hB01dB600D2@l040D;0P0E2Q003@0D2@l0
6a0F00L00P0G31803@8801L<4P0F2a406@hD00l42P0900@050T?01<83P0D2@l01@0A1P`00`0@1``0
3@H>00`73P0200d83P0800h93P0?2@d04PT>00l62P0>1@P04PL;01<8300@1@TDooooo`006oooool0
200=1`T03`T;00l92`0;1@L0618D00`6200=1`T03PP:0`0?2@/03P0>20X04@/;014;2`0@2PX040X<
014;3P0A2`l03`P?01<<4`0F3aH0:24Y01@=5@090PX050T@0P0F2a40=00C20h04PL=01<83P0G3180
4@H<01<83P0K41H04`P>01T>500H3A405P/?01@93@0B1`/04@H:01052@0D2@d03`@801052@0E2Ph0
4`P<00l4200F2`l02P0300d21P0?10P04PL;00l4200B1`/04@H:01X?4`0G310040D901T@4`0;1@L0
3@L9010:300=1`T04@/=01@>400A2`d05@lA018<3P0600807aTK02LQ900A2`l0100202TS9`30^[h0
;RP/00/62@0B310301<=4@0O01D?4`0C41803Ph>00l=3P0B3@l05`hA01T>4P0J3a<060dA01L>4@0F
4A804a4B010@400>3@d04@d>01<?400B3Pl04@d>01<>4P0?2Ph04PdA01PC6@0F4AL040/A018=500C
4A@05A<D01HD5@0C4A804Q0A01DC500201<A4P0501dK700C4A804@l@01<A4P0F51L00P0E4aH00`0F
51L05aDH01HD5`0201DC5P0_01LE600J61/06aTL01LF6@0;310051PK01<G6P082a005aXO00H93P0E
61l061/R01TL8`0H6b@05aXS01PK8P14Adh09BP^01TL8`0M82L07R8Z024U;P0F7BD07RD^01XQ:`0I
8R/08BXd01hV<@0L9S0072Ha01/T<`0K93D06R8f01TQ=P0R:Sl08BTm02@]?P0U;Sd08R`g02D_>00R
;cL07BX`020]<`0T<CL08Bhd020]<`0S<3P00P0V<c/202@a>@0D02@c>P0^?TD0:ca402Pi@@0/?4T0
:SY90351D00/?4/0;3a902hoB@0W>440:CY1028c>P0_@TP0<TE;02e0AP0]@4L0<dE?03A6D00hBUH2
03E7E@040353D@0`@E40=DIF03M9E`80;T1<06D0=4IB0353C@0W>D<0<TA>03Y=E00dAdh0<dI=03Y=
E00fB540=DMA02i0BP0fBE40@5=J03]>E00iC540;T5502Lk?00X?3d0:cm002Xn?@0gBT/0=TQ<03E7
B`0_@DD07c4e02Li?@0X>Sh0838f01d_<`0[?D40=4I:02/m@@0/?D<0;d1701l`=`0/?D@0834h02Lh
?`0a@TT0;Sm60352B@0eATd0;Sm603E6C@0hAd`0;C`o02He>00Z>Ch0:CPm02He?00_?TD0;3]202hl
A@0c@DX0<Cm8030oB@0`@T`0:C]702XlB`0`@ED0;CeD0351FP0iBF80?dmV03i@H00W>D<0;3m502i2
@`0R<cX0:3Ho02@b>`0R;cL0<3e502@a>00nBDl0GVU_03<n@P0H8BH07bP]02D]<P0S9c0061`V02P/
=@0L8BL08RL/02ld>00N9RT06b8W01/R:00J8BT06b8[028Y<`0R9Rl0720Y01PL9@0I7R@0724W01hS
:@0A5QX06b0T020U:002018G6P0:01LL7`0O8bH07b<V01dQ900P92L07b<W014D6@0I72<08bH]01HI
80806ahW00@03a8K01/N9@0K7RD06ahU0P0J7B@0200I72<05QTP01PK8P0K7RD03Q4H01dP9`0O8RT0
4a@I0P0H6Ah0100N7b@04Q<H020Q9P0L7B8301TJ7`0601LH7@0F5a`051DJ01TJ7`0G61d06a`Q0P0R
8bP00`0F5a`05aPM01LH7@0301PI7P0?01HF800H628061PR01LG8@0H62806QXT01PH8P0F5R005ADO
01HF800G5b4061PP01DD6P0D4aT05aHM00804a8J02@05Q@N01HD7`0G5B005Q@P01DC800F52406ALS
01PF8@0F51l05A<N01HD7`0H5R405A<N018@6`0C4A`05Q@O01dK9P0K6B@05Q@L01HC6P0G51/061DL
01HC6P0E4QT04a0G01`I800C41L06AHM00l<4`0C41L05a8I028M900D3aH07aXQ01@?5P0K5Qd2018=
50<04`hE01T050lF01<>500B3A<050lE01LB600H4aT050lE01/F700C3Q@04@`B01HA5`0I51X050lE
01`F800D3QP03@LA01D@5`0>2A004`hE00l:400F4AL05A0D010;3`0C3Q804@`@00804`dA0P0B3103
014;3`805Q0D00/04P`@014;3`0D3Q805Q4G01D@5P0?2Q0040/A018=4`0=20h03PT?014<4P0201@?
5@0?018=4`0@2a40:28V010:3P0?2@d040X>01PB5P0C3A4050hB01D?4`0F41@05a4E01<=4@0=1`/0
4@/?008040X>0P0B31001`0C3A405Q0D00@00P0D3Q805a4E00T31`0C3A400P0B310201<=4@03018<
400A2`l04`dA0080208600L02`D901D?4`0<1PX03PP<010:3P0B31005@lC00805Q0D0P0C3A40:P0B
31004@/?018<400D3A@09b8Y010:500D3aH061<J01@?5P0A31808ahT069MH`3`kO00XijR02dX;00H
4aL0208600@00P0>20`05@lC010:3P0A2`l050hB018<400@2Ph050hB01<=4@0A31001@0400d8300I
51P02PD9010;3`0?2`h05A0D01`G6`0^:Bd081/O00T4200H51H05a<D00d92P804`l@00D081`M014=
3P0?2``04Ph?01<?4002010<3@0>010:300400005Q0B01dG6@0C3@l05@lA01<=3`0<1PP06aDG00X4
1P0>20X030H801H@4P0?2@/200X41P0400/51`0E3a404@/=010:30<03`T;00L04@/=0147200C2@X0
4`T:01D;300H3Pl04@L800<04PP90`0C2@X01@0F30d050X;01882@0B20T050X;00<05P`=01L050X;
01<92P0B20T040L:01H@500>2@d00`0201@?4`0B3A408QdQ0:JQY@2m^[d03PT=014<400<20/03`T=
00`31P0C20`02P0300`11@0;00@0;R<W01H;3`0201872`0@01@93@0A1PX03P<701052@0?10P04PL;
00X10`0:00<05@X>01462P0C20`05P/?01D:3P0?10P07Q<G01052@803`@800@040D901872`0D2@d0
4PL;0P0?10P03`0C20`050T=01@93@0B1`/03P<700l4200B1`/040D900d21P0@1@T04PL;01D:3P0B
1`/03`@801872`0501462P0?01@93@0E2Ph04`P<01@93@0F2`l05@X>01<8300B1`/04`P<01@93@0C
20`04PL;01052@0C20`05@X>008040D90P0A1PX201052@803`@800<040D901462P0@1@T0100@1@T0
4P0F2`l03@8601D:3P0k<3@050T=01L<400@1@T03`@801052@0C20`050T=0188300800@04P`@014;
3`0g<CD0OgUm01HA50803`T=0P0>20`01P0@2Ph04`dA01P=4`0A1P`03`@:01<83P804@H<00`05P/A
00L00P0c:2h04PL=01D:400=0`P0304700L00P0P5A/08aPN01P=4`0;00H501052`0=00l62`0;10`0
2`H=00`73@0=20h03`T>010:3P0B2@h03PD900l62@0D2@d04`P<00d21P0Dooooo`006oooool09`0B
30h03`X;01H@4P0:10H04`d?00l92`0H4Q@05@lA010:300>20X03`T;010:300>20P040/:01<=3P0C
3A004@/?00h83@0=1Pd03@L>014:4P0F3aL030@?01<<500C2A0060dC01L=4P0C2@h04PL=01<93P0B
20d03`@:00l52`0C20h03P<901L=4P0F2`l05@X>01<93@0201<8300401<9300A1`X050T=01<93080
4PL;00l04`P<034V:P0:0@<07a@H01<8300K41@03`@801H;3`0@1@T05``@01@93@0J4A<0;B@W01@>
400>20X00`0A2`d05`0@2P`04`d?00P3100C3@l030L801PB500=20X03`P>00l83`0F3aH0=c0f00h7
3P0C31804P/A01<<4`0B2a404P`A01D>5@0E4Q@04Q8B018@4@0C3a0050`?00805@/?05H05@/>01@<
3`0E4A80518C014A4@0?3Ph04`l@01HB4`0E4A80510A01D@500@2`l05Q4E014=4`0O6R005A4G03<_
=00O7Al04a8A01<A4P0H5QL04Q0A01<A4P0G5AH03P`=01@B4`0D4Q@05aDG01PF600C4A@05A<F01LE
600E4aL0518E01LE6@0K6Ad061HI01HD600G5AT06ALJ01PG6`0E6A`04QLJ04eBEP0g?4006QlT01@I
7`0C61h05QXR01HJ8`0E6B8051PQ01DJ800O8RP05aXO01dP9@0N8BH061`R01lT:P0K8RP082L^01TP
:00K92/092de01`U;P0J92h072Ha01hW=P0P:CX08b/o02@/@P0Q:Cl08RXn028Z?00N9cL07RPe02Xd
?P0iATh0:3Dl024^=00R;cH08c0f02Db>@0S<3P09S<k02Dc>`80934j04<0938k02Lh?`0X>D409CHo
02dmBP0oCeh0;cm>02/kBP0/?4T0;Sm:02XkA@0`@DP0:S]302Xm@P0aA4T0;T5602i1B00dAdh0=TU@
03A6D00dAU40<D=?02XlB@0bA540?4iK03e?G@0eAeD0=dUG03M9E@0jC5P0?4mK0395C`0dAdh0>diE
03M:D@0jCE@0=4I?03Q:E00iBeD0?e5J03a?EP0dAdd0<TE:02i1A@0^@T<0;D1102Xm?@0Y?3`0:C/m
02@e>@0Z>cl0:ca002Hh?00Z>Sl09SPl02Tk?`0Q<cL0;3i204mQI@1@HVL0;3e303A5C00U=Sd0:CY1
02Hf?@0Y>D00;Ce40080:ca304/0=4E<02/mA00]?dD0;cm502ho@`0_@4@0;Ci202Xj@00b@TT0<d=;
02hnAP0`@4T0=4==02loB00^?TX0=DME03A7E`0dAeP0=4IL03=5G@0a@U/0:ceD02TjC`0Y>dX06blf
01da=00M<C407bld02<a>@0N;3<07R/c02ll@`0X=3X07bX_02<^<P0M9RX0;CLi02D_<@0M9RT0:2`e
02<V<00L7bP06b0V01TO900O9RT072@W01XR9P0N9B/072<[01LN9`0L8b`06b0W01`P:00M8RT07b<X
01/P9@0F6b005AXN01HK7P0L8B@07R<V03<h>`0N8bH061`O01/O8P0Q9BP07R8U04A7B`0L7b@05APO
03Hi@00L7bH06A`U01/N9`0B5Ah00`0L7bP03P0K7RL06QdV01TL9@0J7BH05QTR02<V;`1KGVL05aXS
01LJ8P0L7B8071dS01HG700J6b007AhT0P0J6b002`0F5ad05aPM01TJ800G61h05AHK01HG7@0J6b40
61TN01dM8`0T92/092DZ00806AXP00@06AXO01PI7`0F5ad05QHM0P0I6B<02P0G5b405ADO01PH8P0N
7RP06ATS01<C7@0E5Al06ATS01LG8@0F5Ad201@C6@0301PG7P0F5Ad05aHN00805aHO00h06QPS01PF
8P0D4Qh05A<O01PF8@0G5Al05QDN01DD7@0F5Ah05aDO01HE7P0G5B005Q@O01<@6`806AHQ00D05A8J
01<@5`0B3aH04PlF01<@5`0201DB6@0501HC6P0C41L06aPO014>5@0T8BP00P0D3aH201HA6004018=
500D3aH04`hE01<>5@8050lF00D05A0G01HA5`0D3aD050lE01HA5`0201PC6@0301@?5@0B3A<04@`B
00805Q4G010050lE014<4P0A2a@05@lH01H@6@0:1@`06A@J014<4`0D3aD03PT?010;3`0G4QH04PdA
01<>4P0E3a<050hB0P0C3A42018<400<00h8300C3A404`dA014;3`0E3a<07AHL010;4@0N6B006A@K
010;4P0B3A<050lF0P0C3QD0100A318040/B010;4P0A318201<=4@0<01`F6P0C3A404@/?01<=4@0J
51P050hC014;400C31805@hD01<<4P0@2Ph04P`@0P0C3A43018<400300l93@0@2Ph06aDI008050hB
0P0B310201<=4@0W018<400A2`l04P`@00/62@0b;300:28V018<400=1`/04@/?010:3`0@2Ph04@X?
018<4@0B31004@/@01<<4P0B31003`P=014:400D3A@04`hG00h84`0B3AH03`XA010;4P0E41H02@@:
024L801GDUH0@cm001TE5P0D3a40618F01D?4`0C3A403PP<00`62P0C3A404P`@008040X>01X0618F
01TC5`0D3a<05@lC00X52@0J5QT0MW5e06IQI@0E41@05a8F00`72`0@2`h06QDH018<3`0B30h040`=
00l;3@0B3Pl04`l@014<3P0E41<04Ph?01LC500H51H04@d>00h:3080618D00@04@`=01PB500@2P`0
50h@0P0A2`d0600/9RP03`T;01<=3`0C3@l040X<014;3@0F41806A<E01D?4@0B30h04`d?018<3P0A
2`d040X<014;3@0C3@l040H701@:2`0C2P/04@L801<:2`0B20T050X;01<92P<04PP900<040L80106
1`0A20T00P0C2@X05P0B20T03`H701<92P0B20T04@P90147200@1`P03`H900d72`0@2Q002P@;010:
4@0>20l03`T>01XD6P0b;34030P<01TD6@0:1@X04`dA0189300@1PT201872`804`P<00/050T=01<8
300B1`/05P/?01`A5@0O51P040D900d41P0@1@T04`P<01462P0201872`0:01<8300>10L04PL;00h3
1`0D2@d04PP;01T>4P0G3A404@L;01052@804@L;00H050T=01<93@0A1``04@H;01@93P0A1PX40187
2`804`P<00D03P<701462P0C20`04@H:01872`0301462P804@L;00L04`T=0147300?1@T04@H:01@9
3@0C20`04PL;00804@H:040040D901462P0A1PX04`P<01872`0>0`L04`P<01lD600K41@04@L;0147
2P0@1PX040H901462P0B1`/04@H:01052@0A1PX04PL;01862P0@1@T03`@802lU:00d:Rh05P/?00/2
1@0A1`/040D901062@0>10L03@8600l5200A1`X0FE5G02@M900@2A00E4eD0;Zc^P0U7bD04@XA00l8
3`0=1Pd030D<00h73@0@2A004PP>0106300B20h04`P>00l52P0A1P`040D;02XP9P2j/;H0>Bhd00T0
1@0@1P/05@X@01D<4011=cd06a0F01<93P0=10T040D;0P0@1P/01@0@1@/040H;00l6300>1`l03PP?
00803@L=00P030H<00h62`0<0`P04@P<01@;3P0D2@d04@H:00l421Cooooo000Kooooo`@03`T;0P0@
2P`2018<3P07010:300?2@/04@/=01@>400@2Ph040T@01L@5`0200h73P0M018;4`0@2A4030H=01D>
5P0@2Q403@H>01D>5P0B2a405@`A01<=4@0C2a004@P=00h8300B2Pl050/@01TC5`0B2`l04PT>01`F
6P0>1`/050/@00`62P0?20`05PdB014;3`0B2Pl030<800h8300A2Ph00P0>1@X00`0D2@d04@H:01<8
300201872`0801H;3`0J3a<05``@00h31`0C20`0:AhR04e4A`0J51H200l92`1<01D?4@0C3@l0618D
01@>400<1PP05@lA01PB500A2`d03PP:010:300@2Ph04@/>018<3P0C3A405@lB00d72@0D3Q8040X=
01D?4@0;1@T050l@00X82@0>2P/0510A010<3@0B30h06A<E01PB500?2``04Ph?01@@4@0B41407QXL
01H@500B3A404`hB014<400C4A@03@/>01dK7P0D4aD030X=01<C5@0C4QD06QXH01PI500C4a404A4?
01<C4@0F5QH04A4C00`<3P0G5QX00`8702@S:00D4aP07A`Q01PG700C4QL00`8802d/<@0/:c404A0F
01HE6P0J6Ah04a8H00l>4`0A41H02`hC02LZ;`2HVj80PHB;01/N9@0D5ah04A@K01@G7P8061/R06<0
5QTP01<F7@0G6Ql05aXP01hQ:00D5ah0:Bde01`P:@0N9Bd07B@]01`S;@0M9Rl092df02Tb>`0K9Bl0
8B/f02<]>@0P:CP08BXj02Pa@P0b>Td0:C5401PP<`0T;3l082Pk07N0T@3Pj_H0<3]401/X<00D8BX0
934j020^=`0T<S/082hg01X[<`0U=Cd0938k02`mA@0W>D40;d5;02/mA`0R=3h0:Sa803E7D`0X>TH0
:C]902HhAP0/?TX0=DME02Dg@`0X>T@0<49<0353C@0_@D/0<TA>02Dg@@0bA4h0;d5;02`nB00bA4h0
>diE03a>F00hCE/0>DaK03Q>F`0fBeP0;D5<03I<E`0iCeL0=DU@0357C@0lE5P0?eAI0396C00hC5<0
=dYA03A7CP0aA4/0<D9902i0A@0jC500@E=G0310@`0T<cH09cHi02dl?`0O;C009C<f02Le>00lBdh0
C5UO02hm@P0]?440;Ca302hnA@0dAD`0=DI>0311A`0]?d<00P0]?440:00[>3h09c@l02Tf?P0_?TD0
;Sm702doAP0aAD`0<TM=02`oA@0W>T00:Se302m2B00]@4L0:Se503Y<EP0gBED0<dEC02/mB`0Y>dT0
:3Y;02XoDP0Z?e@0;T=G03=5F`0a@eL0:ca?02@eA@0V=TD0834k01/Y<P0Q<3L07R/`01dX;P0Z=C/0
6RD[02dh?P0I92X0:C8h02</<@0Z<cP202<];`0Q01dW:00T;Rl06b8X04E<DP0Z<CL06B0V01TQ9P0I
8RL05b0U01hW;00J8bP05b0U01/T:@0N9B/04QDJ02DX:`0O8bH07QlS02<W:P0I72406b0T014F6P0K
82@06B4T04=;C`0F7R4092T]01TN8P0D6Ad06b0T01hS:@0>4aT04aLP00806AdV05T05QXU01PL9`0N
8Rd07B0Y01`O:00H6b@05QTR01PK900K7RL082</03Hi@P0Y;3D0C4mH01dP:@0E62405APP01LJ8`0G
6R405QTQ01DH8@0F6B005APP01DH8@0H6b806QdU01PK900F6B007alX02PX<P0Q8BT05QHO01LG8@0I
6B4061PQ01`L9P0J6R805QHO01@D7P0C4ad07b8[020S;00F6B804QDN01XJ900I6B<051@N01DC7P0H
5R405A<N01HD7`0I620051<I01<B600F5A/05A@J01LF700F5A/06aXP01PG7`0G5Qh061LO018A6@0N
7B80;bla01dM7`0E51P061LL01lL8`0I5Qd05Q<L01DB6`0O6b@050hH01PB7P0E4AT04a4F00l=4P0B
41D040hC01HD6@0P7R<05Q@I01<A5P0G5AX05A<H014>500F4aX05A8K01@A6P03018?5P80518G00/0
518F014?500A3a80518G00d83P0H4aT03PT?014<4P0J5A/04`hD01@?5@0201<>500?018=4`0A3180
4@`B01XE6`0?2Q004@`B00h93`0;1PX0>C@i02LR9P0N6Ad04PdA014<400C3Q804PdA00804`hD03P0
;RT_01HA5`0A31805Q4G020K8@0>2Pl07QTO00<0100C3Q@050lE018=4`0?2Pl03PT=00l:400?2Pl0
3`X>01HA5`0E41D04`hB018=4`0B3A804PdA02<N8P0S7b004@d>00`72`0D3a@03PT?034/<P0?2Q40
40/B01`G7P0U82P02PD<01<>4`0A31004PdA00l:3P0A31005a8F00h93@0910P04PdA01D@500B3A40
4@`@018<400C3A4050hB01<=4@0A2`l03`T=010:3P0D3Q805Q0D01D?4`804`dA048040T@00l8400C
31<04PdC01L@600>1`h05@hE014:4P0700L050dD018;4`0B2a8040T?00l93@0A2`l04P`@01<=4@0B
31004@/?014:4@0B2a805@hE01@=500B2a404@/?00l93@0A2`l05Q0D01/E6@0F41@04P`@01D?4`0B
31003PP<010:3P0B2`h071<F00H0100R7200[ZV]08n=T00E4aD05A4B00/51`0A20T07a<E01h@400B
20/05@lC01@=500D3A<050hB01@=4`0;10/06A<G01PB5`0D3A@03PP<01@=4`0J51H0100001PC500P
6Q`07ALI00l92`0B30h2014;3@0Y010:300A2`d04P`>00d72@0>20X05@lA010:30080P@03@L901/E
5`0:10H03@L900X41P0?2@/04@/=018<30090`<04`/<01<:2`0@2PX04@T:01<:2`0B2`/04@/;01<:
2`0B2`/04@/;038Y;00C2`h02@<500/21@0D3@l03PP:01/B5@0?20X03@L901072P0>1`T05@`?01<:
3`0E2a800`0F3A803P0E30l030<801@;3P0B2@`05Pd@00h51`0@1`P060dA0146300J3aD04`P>00l5
2P0?10X04`P>0P0A1P`00`0C20h0;R<Y04Hk@@0601462P0H01H;3`0A1PX06@hB00`21@0/8BD03@86
014:300H3a8030H801TB500K4QL01P0401493P0=10T050hB01@;4`0>10`04`TA00/11@0B1`/05``@
01872`0<0@D03`@80P0>0`L04P0?10P04@H:01<8300D2@`01`0001<:3@0>1@T02P<:010;4@0>2@l0
5A0F01D>5@0@1`/04`X=00T0000F30h03`@800`11@805P/?00l04`P<01872`0A1PX05P/?01052@0E
2Ph06@hB00T21@0M5a/01@0100d5200E30l04`X=00l51`0A1`P00P0B1PP201@5200l00`3100H4Q@0
3@L80189300@2P`02`D600l62@0=1`T03PL900l62@0=1`T03PL900X32P0>1`h030D<00d63@0D3A@0
3PP<00X4200>20`04P`@014;3`0?2@/03@L;00H010090`L04@T>00`3200A2`l04@X>00l62`0=1`/0
9b0T01483@0=1`/03`P<01063P0>1`h060lG01/A6@0@20l040T@01063P0?1`h03PL>01063P0?1`h0
40H>01D;500@1Ph04@L?00P01P0F31<06a0F00P00`0H3A801`0001<8300H3A401`005?ooool001_o
oooo00T04`d?014;3@0>20X03@L9010:300B30h03PP:010:300?2@/00P0=1`T03`0@2Ph05@hE00P2
2@0400D030D=014:4P0C31@02P<;00d63P0L5Ad06Q<K014:4P0C31<03PP<00l93@02010:3P0;00d7
2`0<1PX03`T=010:3P0F41@03`T=00h8300I4aL05Q0D01D?4`0A2`l00P0?2@d08P0>20`030H:014;
3`0E3a<04P`@014;3`0G4AD04`P<01872`0E2Ph050T=01462P0D2@d05@X>00`11@0>0`L06@hB01L<
400[8RD050h@00`6200=1`T04`d?018<3P0=1`T03PP:01<=3`0A2`d02P@6014;3@0H4Q@04P`>014;
3@0@2P`200l92`0400X51P0D3Q0030H801LA4`803`T;01/061<D01<?400C3a004`l@00h:2`0<20T0
3PX;01DA4P0F4Q<061@E014=3P070`@03@P;00l93@0A31004`hB014<400B41<040hA00`:3@0F5QP0
4A4C01/K7@0E5AH05ADC01@E400C4a000P0B4Q00400B4Q8092@V00`<3P0C4QL07A`R00l>500@3aD0
@D1601TH7P0F5A/040lE01HE6`0K6R004A0F01DD6P0H5ad201DD6P0901/K800L72@010L>03`oAP0T
9bh03A0G024T:`0G6R4061/R00<06A`S02H06A`Q02d`=@0F6Al07B0W01@G7P0K7RH07b</01dT;00L
8b`06R4[01TR:`0L9Bh07RL`01TS;@0O:C@08B/g01hX=00P:CL09Bhm01<L;@0O9cT06b<f03<kD00^
=T/0>D5D05eWL`0M:C80:cQ102@a>P0^?4D09cDn02Hd?@0W>400;3e5020a>@0Z>d<06b`d02<f?@<0
9CM10800:ce902m1C@0Y>dL0:3Y802DgA@0a@e40AeQX041BH00]?d`0;Cm;02`nBP0]?d/0<dE?02Li
@`0a@dd0;d9902/nA@0aA4/0>DaB03Y=E00iCU`0<DME02m5DP0dBUL0=D]F04=II00jDET0>U5G03Q?
E00]ADT0<TY>03]AE`0hC5<0=TU@03E8C`0bAD`0<T=:02/m@P0^@4@0=4=802`k?`0Z>C`0;3Xm02`h
?00O:Rh09c8f02@`=00`?T40>dQ>02@b>00/>d00<D1703A4B`0eATh0;d1802Xl@@0/?T00;3]002dk
@00[>3h0:S@m02Pd?00]?4<0<3i702m2B@0_@dX0:D1602]0A@0X?D80:Ci302a0A`0Z?TD0;T9;02Tm
B00Y?4X0<dIE02i1D00Z?D`0;T5C02i3F00^A5/0<TML03=5F@0`@e@0;3e=02LgAP0R<cd08c4k02<`
>00L:C4082/a024Z<@0R:c808BXa01DN9@0S;3<0:C8g02D^<`0Y<SL07bT[01lY:P0K9BH09S0a038k
@02ma//0CEIK01@M8P0]=S/04AXO01TR9`0L9BX06R<X01`U:P0P:Bh07RHY01TM800U9RP0824S01hO
8@0N8B<05QXM010E6@0F6al07b@X01<J800U;38072<Y01TN8P8082DY01T07B8X01PM8`0>4aT04aLP
01LK900H72D05a/V01XN:@0M8B`07B0Y01`O:00I72D05QTR01PK900K7RL07B0Y024T;@0D5b00:Rdf
01<F7`0E62406QdV01`O:00K7RL061/T00805aXS00X061/T01HI8P0G6R<06A`U01LJ8`0E62406ATS
024Q:`0K6bD05ADO0P0F5R003`0I6B<06QXT01XJ900L72H07AdW01`O:00>4Q/06QdV02DX<@0O8R/0
4a<M01HF800E5Al05Q@O01TG8P0201HD7`0T01TH800E51X04a8H01DD6P0B4AL04a8H01PG7@0B4AL0
3`hD01XI7`0A41H061LM07elP02_[jl0?3`l01<C500B4Q@0928W01TG7@0>2a803PPB018<5P0D3QP0
81PU01LA6P0@3Q<061HK01HD6@0=2a0071XO02LU:P0E4aP04Q0E01HD6@0C4AH040hC0P0C41T0400B
3aP04PlF01<@5`0D4AP040hC018@5@0D4QD04Q0C014?4P0B41<06A@J00h93`0T7bD01@0601LB600C
3Q@2014<4P<04`hD01l04PdC018=4@0@2`l06A@H01@?4`0:1@T07APL01/F6P0E41@03`X>014<400B
3A403PT=01LB600A31806aHL00d83P0@2a405a8H00l:400K5Q`05a8H014<4P0@2a404@`B01TD600;
1PX04@`@01/F6P0I51P05Q4E00804PdA0P0A3100500B3A404`hB02@P8@0T82404`l@00l:3P0C3Q<0
3@P>01D@5`0B3AD04@/E00h84P0O6B@04`dG00l:3`0C3Q805a8F01<>4P0?2Ph04@`@0P0@2`l01@16
@DD02PD901LB5P0D3a<04P`@00<04`dA00<040X>00l93@0B31000`0C3A407`0D3Q805@lC018;4P0>
1`l02049028K8`0?210091dU00`63@0<1@d03`P@01XC6`0<1@d03@H=01<=400A2`d03`T;00h82P0>
20`03@L;00l93@0B2a805@hE01@=500A2Q803`P?010:3P0A2`l04P`@01<=4@0D3Q800P0F41@04@0C
3A4040X>00l93@0B31004`T>01<8300A20d05a8F034/<00R82<02`T;00`82@0<1PH06Q0A00X0000;
000060`@008040T@01004@XA01@=500E3QD0:b@[03</<`0<1P`030D<014:4@0B2a4040X<04Do@@1?
BD/04P`>02DO8@0K5AL04P`>0P0A2`d0100@2P`04@/=018<3P0D3Q0201dG6@0?01<=3`0B30h04@/=
014;3@090`D081XL01/E5`0600804P`>01PB4P0<1PH03`T900`61P0>20P04P`<00H04@/;02@04P`>
01<=3`0H4Q@03`T;00X41P080P@07aTK014;3@0=1`T03`T;01H@4P0Q6ad04PL?01L<4`0L4AL06a0F
01D:3`0>0`L050T=01@:300<0P<04@L800`20`0@1PL01`0001<83P0800<02P0502TN900A1P`03`@:
01873@0D2@l02`4601052`0L4AL201872`@04`P<01P02`4401052@0M4QH07Q<G04@i?@0[8RD03PH9
01<=3`0@2P`07aTK02@N8P0G4AD03PP<00h73P0D3A@03`P?01094@0K51/05@X?01T>4P0M4QH05``@
01872`0D2@d300l4200/01462P0B1`/05@X=00`20`0E30l04@T>014<4P0300D04@hE00401@0?20l0
2`@801@;3P0<0P<06Q0B01462P0>0`L05@X>01<8300@1@T04PL;00/0100=0PH03P<700d21P0C20`0
4`/?00<00P0F41804@/=018<3P0A20/040H80147200B1PP04`H801@5200E1@H050P;00P2100?2@/0
4@/=00`6200A2`d600d72@0N00l83`0B2a8040T@014:4@0G41L04P`@00l93@040080:28V03Pb=00C
3@l02`H701<=4@0@2Ph04`dA00/52@0>20`040X>014;3`040080618F01D?4`0=1`/040X>00`53009
0PT04``C01lH7`0F3aH030D<1P0>1`h0300@10h03P<<01<8400T6B40>Bhe00L00P0>0`T0<bP]01hC
5`0=0PH02`8401T>4QCooooo000Kooooo`0701H@4P0B30h03PP:00d72@0?2@/04P`>00h82P02014;
3@0A00l92`0<1PP03@L:00h83P0A2Q406A8I03D^=@0M5Qd02`D;00d63@0@2A004@XA01PA600A2Q40
3`P?00h8300?2@d0100@2Ph200h83006018<400>20`030H:01@>4P0B31003@L;0P0@2Ph0400>20`0
4@/?00h8300@2Ph04`dA014;3`0@2Ph050hB01@93@0B1`/050T=01<8300B1`/05@X>01872`0A1PX3
01@93@0>01072P0@2P`03`T;010:300A2`d04P`>04M1@`1?BD/07aTK00d72@0D3Q004P`>010:300A
2`d3010:3008014;3@0D3Q00618D010:300J51H030H801LA4`0@2``2018>3`04010<3@0D41404`l@
018>3`805A4B01L040`=018>3`0G4a@05Q4D01<=4@0B3A404@`@01@?4`0Q7b809R@W00X82`0D51H0
3`lA01LG6@0=3@l04a<B01@D4`0E5AD05ADF01@D5@0C4QD04Q4F01LF6`02018A5`0400d<4P0J6B40
?ci401XI7P805A@I05T04A0E01<B5`0D4aP05A@I01HE6P0D4aP05A@I01/K7`0T9BX06A`P01LJ7`0E
61d07B4U00lB5P0C5Q/04QHJ018E6@0B5AX051LK01DI7@0H6al06A`P01HI7P0N8BH0:Bdc01hS:@0J
8BL06b8Y01`S:`0J8bX06R<[01XS;00G8BX072H`01hX<P0L9S007BLb020Z=P0V<3d082Th01hW>00X
<D<09Bdo020Y>P10BUH0?dYD02Db>`0M:S<0:3Ho01l]=P0L:S<0D65Y05]/M00N;cL0=DI>02Hg?`0U
>3l07c4k024c?@0[?DL0;T1<02doB`0/?TX0;T1>02TkB@0V>4H0=TMG0394DP0bA540<TA@0353C`0/
?TX0<TA>02XlAP0a@dd0<4=:02e0A`0aA4/0=dY@03I9D00hBeP0=TUG03A8E00jCET0?51K04YNJ00k
CeP0HgMn03A8CP0203A9CP1F03U>E00gBe80=4M>03E8C`0dAdh0<45802m1AP0_@DD0;Ca102/j?P0/
>ch0:SPk02Pd>00V<CD0;cXn02/g?00]>T00=45702Le>`0]?4<0;Ci502m0B00cA4`0<45902Xk@@0V
>3`09SDj02Hd>P0X=C/09c@l02Hc?00]>d@0<d=;03E7D00bATl09Se502XnA00Y?4<0:Sa302Li@`0V
>480=4IB04mPKP0cAE@0<45A03=3E@0eAUP0<41E02m2F@0/@5P0:d1E02i0E00/?e009cQ802DeA00O
;ST08c0k02Ld?00K:3008B`b02H_=P0X<CP0A4eD01dV:`0O:2d0624V01hX:P0T;S0082X/02<];P0L
9RL07bTZ024Z;P1MIV/0:C8g01LP9@0B6b006B8W01PQ9P0K92T072DZ020Y;P0T;C8072@W02@X:`0O
828201`M7`0301LJ700D61/04QLK008061dQ00`05ahT010G7@0N9B/06QlS01dR9P0J7b<06b0V01XO
9@0B5ad06AdV01PL9@0J7RL201hR;@0701XN:@0K7RL06ahW01PK900F6B805aXS01TL9@0201LJ8`05
01dP:@0B5Ah051LP01TL9@0K7RL00P0L7bP301PK900901/N9`0G6R<05QTR01PK900G6R<05QTR01/K
9@0M7BL06QXT00806a/U00@061PR01LG8@0C4ad051@N0P0F5R00<@0D5b005ATR01LJ8`0U:3407b8[
01<C7@0I6B<05aLQ01TG8P0L6RD05Q@O01DC7P0J6B406APN01LF700H5ad04a8H01@C6@0I61h071/Q
01PG7@0D4aT040lE01hM8`1XIf/0VIVI030`<00H61T03@d?01XH7@0I5ad06aPO01dG8@0G4A/071HP
01TA7P0N6240518G00d;400F51T05aDJ01DC600H5Q/04a4F014?500D4QL04Q0E014?500C41T00P0B
3aP02@0C41L0514H01HC6P0>31404@lD01DC5P0C4A@04@lB018@4`0201LB600X00h93`0S7R@04@`B
01<>500@2a404@`B01@?5@0E41H050lE01<>500B3A405a8F01`G6`0G4QH04PdA00l:3P0@2`l03`X>
010;3`0D3a<04`hB00h93@0D3aD040/A00d83P0A318050lE00l:400M61h0=2le01XE6`0@2a4030L=
01/F700=20`04PdA01<>4P0>2@d03`X>01PC5`<040/?01`04@`@01<>4P0D3a<04`l@01HB4`0?2``0
3PT=018=4P0>2@l03PT@01D?600D3QP02P@>01H@6`0<1Q004`hC014<400B3A403`X>014<400F4AD0
4@`@018=4@0a;3004@`@01D@500>2@d04@/?0`0B31001P0@2Ph03`T=01@>4P0A2`l040X>018<4080
5@lC01<03PP>01D>5@0U7RD0BT=:00`7300m=Sd06A<I01H?5P0E3QD02`H;02<L8`1IDeP06Q@G01LA
4`0D3Q004`d?018<400D3Q804`dA00<04P/B00H050dE01<<4`0?2@d04P`@01<=4@0A2`l200h8300B
00l93@0@2Ph04P`@018<400@2Ph050X>01L<400F30l040X<00l;300D4A80518C00`92P0C3Q0040L9
01D:3@0H2Ph04`P<0`0@2Ph03@0A2`l04`dA04I0A01VH6@050lB00`62P13?D40<2X^01H@4P0I51D0
9AlQ01D?4@0@2P`01`0A2`d03`0<1PP06A<E01H@4P0=1`T05@lA010:300>20X04P`>014<3@0?2@/0
5@lA030Z;00J51@03`T901D?3`09014;2`05018<3P0=1`T03`T;014;3@0?2@/00P0D3Q007@0>20X0
3@L900l92`0@2P`04P`>01T>5P0H3A@05P/A01@93`0B1``040D901@93@0H3A0060h?028H6@0J4100
4`T:00l4200G31803`@:0146300Z7bD05``B00l42P0B1`d05P/A01<83P0B1`d050T?00@04@H:0P0@
1@T01`0B1`/04@H:01872`0;0P@07A8F00/21@0C2`h00P0>20X04@0A2`d040X>00d72`0<1PX04P/B
01@=500<1@`050dE028K8P0D2@h050T=01H;3`0B1`/03P<701462P0B1`/04@H:008040D901004@H:
01472@0;0P<04@P;00l8300=20h05Q4H01@A600W92/08Q/R00l8300E30l04PP901882P0@1@T03P<7
0P0C20`04@0A1PX04`P<00X10`0?10P050T=00d21P0A1PX08Q/N05iIG@0F41803PP:018<3P0:0`@0
50X=01462P0B1PP04`H8008050D800D04`T;00`6200@2P`0208400T31@0700h82P0N00h83@0>1`h0
3@H=00h73P0?20l03PP<01H@500910L05a4E01hH700;1@T04@/=01LA5@0<1PX040X>00`62P0;1@T0
3`T=00d72`0A2`l030H:00l93@0@2Ph030H:00X32P0K51/0;2D/01PA600:10X05PlF1P0>1`h0300?
0`d05@TB01L<500=10X05PdB01@93`0B1`d050/>00h51`0@1@T03`D801<831Cooooo000Kooooo`<0
40X<00l03PP:00`6200;1@L03@L9014;3@0B30h040X<00h82P0=1`T02P<:00h73P0400@06A8I00l8
3`0O61l00P0=1Pd010080@P05PlF01@=500K51/200l93@0H010:3P0A2`l04P`@018<400@2Ph03`T=
014;3`0?2@d03PP<014;3`0E3a<040X>014;3`0@2Ph03@L;00h8300F41@050hB00`62P070PD091hR
03li?@0F2`l040D90P0A1PX02`0C20`060dA01052@0H3A405``@00`31@0O51P04@P;014;3@0C3@l0
4P`>00803`T;00L06aDG01LA4`0<1PP040X<01@>400B30h04@/=00804P`>00`04`d?01@>400E3a40
6Q@F01lI6`2=QhT0GEMI01XD5P0O6A/061<E01PD5@0F4Q<2010<3@15014=3P0@30d020@5014=3P0F
4Q<0510A01LC500A30l04`dA018=4@0?2Ph040/?01dK7P0N71l05aDH010@4P0F5QP05aLI018B500E
5AL051@F01<C5@0C4QL051<H01DD6P0920h03@`B018A6@0A41P0BdYB01dL9@0B4AL051<H01<B5`0@
3a@06aXO01XI7P0E51T05QDJ01LF6`0E51T04a8G018B5P0F5a/07b<T01<G6@0K7b8041@F01dQ8P0C
5aX05QXL01PL7@0I7B005a/M01DI6P0J7Ql07R8S00<72P0J7R409b/_01XO8`0I8B@072@X01hU:`0N
9b`07BH[01/T:`0H8R/072H_00807RPa0P0M9c403@0T;SP08B/g02H_?P0S;3/06R<b02H_?P19Del0
AU5K024^=`0U<S/08Bhg018P:@0R<3T00`0L;CD00`0W>4009SLo02Hi@00202@f@00a02TkA@0]?d/0
;T1<02LiA@0`@U00;T1>02DgA@0_@500;Cm=02i0C@0mCe/0@59N02m1C@0_@D/0;Cm903=5C`0dAdh0
<DA;03A7CP0hBe40=TU@03I:E00mDE`0=d]F03=7D@0`A4d0>dmH05AXL02calh0BUmU03eBE`13F5d0
?E5G03E9D00cATd0<TE<0313BP0/?D@0:C]002Tk?`0[>Sl0;Ca002hm@00a?d80;3Xm02Dc=P0Y=S`0
9S<i02Tf?00202hmA00c0350A`0]?TH0;3e50311B@0]@4L0:3]102@g?@0R<cX093@k02Lf?@0X=Ch0
9c@n02`jA@0_@4X0<TA?03A8D`0]@dd0<D==0393C@0b@T`0;3Y702TiAP0kBET0D5e^02dmC@0/>Th0
;CU?03U8G@0jAel0BE]c03]?I`0bA5X0>4YN03M:F`0X>4T0:cQ802@b?@0B7bT0218K01lY<P0Y=3X0
82T`030g?`0X;cD08RT_03U0AP0R:Rd07bLZ02<[;P0N9RP08b/]00806b<U00L07BDX01LO8P0E7B00
4a/N01PP8`0I8B@051`O00807BDX01h06b<V01`T9`0K82@08BDX01PI6`0G61X06AXL01HI6`0G6ah0
5AXN01PM8@0A5QX05ahT01hU:`0R:Bl07B8V028W:`0L8BD061dS01/P9P0J7bD06AdV01DI8P0G6b@0
6alZ01LK9P0=4A`05QTR01LJ8`0E624201<F7`0901@G800H6b@08RD^03XmAP0I72D061/T01DH8@0F
6B806A`U00806QdV00<06ahW01`O:00I72D00P0E62402@0I72D06QdV01XM9P0L72H06ATS01DE7`0G
5b405QHP010@6P0200h>600H01DE7`0H628061PR01TL9@0D62405QTR014D7@0?4Q/05QHP01TI8`0G
5b406ALR01`J9@0F51l04a4L01DD700B4AL04A0F01<B600A41H04Q4G01<B600H5ad05QDK0P0C4QP0
3P0=318051@G01@D5P0O7b404a<E018B500H5Q/04a0F01DB6@0S7RD05A0H01/E7`0?1a807QPQ0P0E
4aP0100F51T03@/@014?500J61d201<A5P0601DC600B41D0518G01DB6`0D4AX04a0I0P0B3aH03P0C
41L0518G01@B5`0C4A@04@lB018@4`0H5QT050lE01HA5`0O6R000`0400`73@0B3A<050lE0P0E41H0
2P0D3aD04PdC010;4@0@2`l04PdA00h93@0<1`/04PdA010;3`0D3a<2018=4@804`hB00@04PdA010;
4@0@2a4030L=0P0E41H03`0:1@/03`X@00/7300300@0GEQN028M8`0>2@l05Q4E010;3`080`L08QdQ
03/f>P0G4QH05A0D01@?4`04018=4@0H00h93@0B3A404PdA01@?4`0H4aP05a8H01<>5@0@2a807aXQ
01LA6`0F41X05Q4H01hI7P0G4QH05Q4E01D@500J5AT08QdQ01D@500500@071LK010;3`0;1PX061<G
0P0B3102014;3`8040X>01H04@/?010:3P0B31005@lC018<400@2Ph06Q<J01/D6`0400@06A8I018;
4P0<1@`0;RL^00H01P0@2A006A8I00h73P0T7R803`T<00l92`0@2P`04P`>0P0C3A401P0>20`03`P?
0109400;10/03@H>018;4P8040X>0`0A2`l05`0@2Ph04P`@01H@500F41@04P`@01<=4@0M4aP05@T;
01061`0I4A808QhM065MGP1[J6T00`4201@?4`0J51P05@`A00h52P0E3A804P`@01<=4@0A2`l040X>
00804`dA00d0208601D?4`0M5a/05a4E00X4200H4Q@03@L9014;3@0B30h03`T;01@>400@2P`04@/=
00804P`>0P0A2`d0100@2P`03@L9010:300C3@l2014;3@09010:300?2@/06A<E00/51`0500407ALI
01dG5`0C3@d05a4A00804`d=00<050h>010:2P0@2PX0100@2PX01`0B30h03`T;018<3P0L5QP02PD6
00`6200@2P`00P0B30h01@0C3@l040X<00X41P0I3QH050T@00803`@:01404`P=01L<400900803`D7
01D;300Q5aP05`d=00d3100G310040D;01`A5`0A1P`02P4500/01P0D2@l04`P>01052`0201463004
01052`0@1@T03`@800l420803P<701D03@8601052@0C20`04@H:01872`0G310050/>014:300;1@L0
3PP:00l92`0>20`04`dA00`62P0?20l04@XA00l83`0?21004``C01462`0?10P00`0B1`/0100E2Ph0
50T=01872`0A1PX201052@0=0105200;0@804PT<01D=4P0Q7280ThjE06m/L`3XiN`0Mg1g01@=4@09
00<07aDF0105200200l4200@01462P0C20`04`P<01052@0B1`/05``@01462P0M4QH08aPL02HO8@2B
S8h03`T;00`6200C3@l01P0001@:3P804@H:0`0B1PX01P0<0`D05Q0B00d72@0B30h02P@600l92`H0
3PP:00l03PP<00X4200?2@d040X>00X4200<1PX01@03014;3`0@2Ph02P@8014;3`0=1`/04`dA00X4
200A2`l00P0@2Ph0300?2@d01@0301D?4`0B310030H:00T31`0C3A402`@;00d63@0B2a8050dD01<<
4`L03PL>00`04PH@00/1200O51`05P/C00l42`0F2a4050T?01@93P0G31003`@801052@0N4aLDoooo
o`006oooool02@0<1PP03`T;010:300?2@/030H800T31@0;1@L03PP:00l92`0200d72@0>00h82P0C
3A405@hE00P1200A2Q405PlF03</<`0@2A003`P?00d63@0A2Q4010040109400?2@d200h8300;00l9
3@0@2Ph04@/?014;3`0@2Ph04@/?010:3P0?2@d040X>00d72`0@2Ph00P0=1`/02@0A2`l040X>01@>
4P0K5AT04`dA01XD601TGV80ViFI01H;3`0301052@0G01<8300I3Q803`D800l4200D2@d04@H:01T>
4P0<10H040X<018<3P0A2`d03@L900`6200B30h05@lA01<=3`0>20X02P@6010:300I4aD05Q0B01D?
4@0D3Q000P0C3@l01`0O6A/0BD=50??]k`2HTY@05a4C00h82P0D3a400P0D41405`0A3@h03PX;01HB
4`0R7Ql02@D600/7200E4A804`l@01dI6P0E41804P`@01TD600J5AT050lC01@B5@0@3Q406ALJ014A
4`0D51H03@d?00h>400B4AH04A0E008040lE01`04A0F01@C6@0J6Al092<Y00T8400i>400d<oG0450
B@0@3aD04A0E01@C600E51T04a8G01PG700C4QL051<H01PG700I61d05aHK01DE600D5AL05QXK00dA
4P0>4Q<06ahO00P<3@0E6AX06AdN0P0L8240400J7Ql05a/L01DI6P0B5QL05ATJ03Hj?@0G6al04QLK
01`T9`0M92T07B@Z01/T:@0H8BH05QlT01TT:P0L9Rl201lY<P1i01hX<@0K9Bl09Bli02Tc?@0L9S00
9Blk02Pb?P0V<3`06bD_02D`>P0K:34082df01l/=@0O;CH0938k02`mA@0Y>T80;Ci601//=00Y>T80
9CPo02Dg@@0T=T009SQ202/mB@0^@4`0;Cm;02i0CP0/?T`093I40352DP0bA580:Sa903a>FP12E600
;d5=02m1B`0`@T`0<TA>03A7CP0cATd0=TU@03U<DP0gBU40=TYD03M;EP0_@d`0<4A=02m3C00fBU<0
<TI=06MkPP0hC580;T=802a1AP0`A4X0=DU@03I9D00cATd0;D1702/l@`0Y>T00:3Xn02`k@00]?400
9cHi02Xh>`0]>ch0:cTl02Pe>`0U<SP09c@j02Th?`0^?D@0<D9903A5C@0cA4`0<D9:02Pk@P0U>3l0
:3]102Lh?`0Y>D00:cY102/h@@0X=Cl0:SQ302/lAP0[?TT0;dE@02i5D00_?d`0<Cm:034oB`0Y=d@0
9S=303=0D00_?4d09C9503M3F@0P;480;CUA03E2F`13EFd0=DUQ0312F00mCf<0@eAV03Q7F00K:3P0
;C]604MCGP13CEH0C5IO02H`=P0L8b/0=Se502/b>00i@4H0JG1f01`T9`0202<[;P0501LO8@0L92H0
6R8T024Y:`0E7B000P0G7b80>`0L92L0>T9501PP8`0C6ah072@W01/S9P0F7R40620S01XO8P0I7B00
5aPJ01@E5`0F5aT06A`N01XN8@0A5QX06b0T024V:P0<4aT07bH/02H]<`0E6Qh0<3Di02db=P0J7bD0
4aPN01`Q9`0L82T06QhW01dQ:P0P92l06alZ010D7`0E62405aXS01DH8@0C5Ql04QDN01<F7`0J7BH0
7B0Y030c?00D5b004A@M00hA6P0F6B806QdV01`O:00M82T07b8[020S;00H6b@05QTR01LJ8`0J7BH0
6ahW01XM9P0P82X07AdW00805aLQ01X05QHP014A6`0C4ad04Q8L01LG8@0B4Q`04A4K01HI8P0?4Q/0
61/T01HI8P0I72D06a/U01HF800E5Al05aDP01XH8`0E4ah04a4L01LF7P0D4aT04a8H01LF700F5A/0
61LM01TH7P803@`B01<09RD[01PG7@0;2Q0071/P00@41P0S8bD04a<E01XJ700F51T061HL014>5@0C
3QD07aTR03`f@00N5R40:RD[01/I7P0E4aP05aDJ008040hC02005Q@I018@5@0C4AH0518G018@5@0E
4aP05Q<L01DB6`0D4AX04PlF014>5@0B3aH05Q@I01DC600B41<040hA01<A500J61/07APN00`73@0A
3180>cHl01TD6P0K5Q`061<I01LB600E41H04`hD014<4P0@2a404@`@018=4@804@`@00T04`hB00l:
3P0D3a<04`hB010;3`0?2Ph04@`@018=4@0C3Q@00P0>2@l04P0=20h04@`B010;4@0500H08QdS038]
<`1<Add04`hD018=4`0D3a<04PdA00H11@0M61`0=S4e018=4@0F4AD05A0D01<>4P<04PdA01X04@`@
018=4@0B3A404PdA01@?500D3aD03PT@018=500M61l030H@00X43P0>2A005A0E01LB5P0J5AT05a8F
01@?4`0G4QH04@`@01PC5`1iM7P07QTM00L21P0C3Q8050hB018<40804@/?0P0B31002`0@2Ph03`T=
018<400F41@04P`@00h8300=20d0100401@=500<1@`04P/B00807AHM01T04@XA01<<4`0=1Pd01004
01D?4`0=1`T03PP:010:300C3@l05Q0D018<400>20`05PlF01dF7@0@2A0030D=014:4@0@2Ph03`T=
010:3P0A2`l04`dA01H@500E3a<04P`@00803`T=00l04@/?00l62P0F30d08ALH01H>3`080P807QXK
02TV9`0100007aXN00/72P0@2A002P<:00/52P0@2Ph00`0B31001`0I4aL071HJ00@00P0A2`l030H:
00T31`0I4aL00P0>20X01P0B30h050h@014;3@0=1`T03`T;010:30804`d?01@04P`>010:300G4A<0
3PP:00l92`0E3a4040X<00l92`0A2`d050h@010:30070@<0@3Xl030Z;00R71`050h>018<300=1`L0
40X:01TC4`H03`T900h0208401<=3`0C3@l06A<E010:300d;S004@/=010:300;1@L03@L901@>400C
3@l03`@<01873P805@X@00l050T>01872`0A1PX040D800X00@0C2@X03`D501061`0B1`/07A8H020E
6`0D2@l05@X@0146300;00H00`0B1`d01P0>0`T02P0501@93@0C20`04PL;01462P8040D900P050T=
01H;3`0<0@D0304500L0000800804@T<00d72@803`T;020040X>01@>4P0>20`030D<00l83`0A2Q40
3PL?00X32P0?10T03@8601872`0D2@d04`P<01D:3P0D2@d04PL;01462P0@1@T04@H:01L<3`0B20T0
3PD800h62`0Y92X0/Zfd085nQ@3floX0OWMn01`E6@0700406Q0A00l41`8050T=01004@H:01872`0A
1PX04PL;01/@500L4AD03`@802PM8@0f:bl06a8E00h82P090`D02P@6014;3@0=10L04`T<100A1PX0
1`0B1@`04PP;018<3P0<1`P05@lA00L10`0>20X01P0?2@/07@0<1PX01`45010:3P0B31001`4500T4
1`0;1@T03@L;014;3`0?2@d03@L;00h8300=1`/02@<700h8300<1PX040X>00X5200A2`l030H:018<
40090`L0100200`72P0=1Pd03PL>00d63@0>1`h04P/B00L03PL>00`03P8<00h5300@1@d0304901L<
4`0<0@L03P<901H;400I3Q802@0200h31`0N4aLDooooo`006oooool600l92`0D00h82P0?2@/03`T;
00h82P0A2`d05@lA018<400<1PX040X>00l93@0>20`040X>01@>4P0=20/04@/?01LA5@0B3A00=2hb
01@>4P0B3102014;3`804P`@01804@/?010:3P0?2@d040X>00l93@0=1`/07ALK02HP900C3A4030H:
018<400;1@T040X>018=400B310030L:00h8300G4AD201872`0<01H;3`0D2@d04@H:01<8300?1@P0
4PL;01P=4@0D2@d04`P<01<:3@0A2`d040X<0P0C3@l0200A2`d040X<00d72@0=1`T050h@01<=3`0A
2`d04`d?0P0D3Q00<@0C3@l050h@01@>400G4A<06A<E05iHFP0o>C/04`d?014;3@0C3Pl03PX;018>
3`0E4A802PH701XF5`14@4406QHG00h:2`0F4Q<020@501<?400E41<050hB01D@500G4QH05Q4E01HD
5`0D4QD040hA01DE5`0<30h04Q8D03`l?`0?3Q@040lF01@C6`0E51`051<K018A6@0_;SH0<C0h01PF
8@081Q40:BLb01TG8@0G5Q/06QXL014A4`0D51H00P0G5aT03@0C4aD04Q8D018B500C4aD05ADG01DF
600B4a@08bLV018F5@0W:bX0;30_01`P7`0F6QT00`0G6aX201PL6`0901XN7`0I7Ah061`M04=7B00O
8bD0724T01XR9@0K8bH072@W00<06b@Y02P06B@Z01/V;00N:Bl07bTb01dW<00I8b`05b4Z01lY<P0P
:S<0=T1902La>P19Ded08bdf02Lb>`0S<3P082de02Xh@00R<CP0:SU0020a>00M;SD09SLn020a>00V
=ch09SU002@f@00U=d40;Cm90353C`0bA500;T1<03=5D`0fB5H0;d5?0393D`0^@4h0:ce:02/mB@0b
A500;Cm;0P0cADl0R`0^@4X0<dI=03=6C@0gBU40>DaB03I9D00bADd0<D==03I8D@1=H6P0@5=J03I9
D00jCE@0=4M>03Q;DP0dAdh0=dYA03E9D00iCE@0?E1G03I9D00/?dH0;3e402`n@`0W>Cd0:STn02ln
@P0X=cX09S@g02Xh?00^>d409c@j02Tg?@0Y>3l09SDl02`lA00`@DT0<D=:0353C00cADl0<49<02Tl
A00X>d80:CY202/j@`0[>D<0:CM202Pf@P0/>dP0;Ci:02/oC00^AE80;TEA02hnC00_?D/0<3e=02Xg
A`0S<4809S=6038oD`0/>4l0>dMO020/A@0jAV40>DEP03e=IP0gBF40<D=I03=4F00dAEL0<T9C02/h
B00V<ch092hi01hX<@0V<3T09c0g02L^=00K8RP0:2le01<K7P0/=3L06B4T01DM7`0J8R@06B4S02H_
;P0S;2/092d]01dU9`0A6A`04QXM02D]<00_=cX06b<V01DM800G7b805AdP01LO8P0L92L06QlR010D
5P0K71h04Q<E014B500L7b406QhQ02H[;`0H7B40A4U=00lF700K8RP061lU01PM8@0Q9RX07R<W01TN
900H7B<05Q/Q01PL9@0L82T08RH_02DY=00P92l061`W01LJ8`0I72D061/T01DH8@0D5b005APQ01HI
8P0B5Ah06ahW01PK900E624051LP01HI8P0I72D00P0J7BH02`0K7RL07B0Y01XM9P0I72D06QdV01/N
9`0H6b@05QTR028R;00Q8B/06QXT008061PR01005QHP01TI8`0G5b406ATS01<C7@0L72H0;2lh03<f
?`0C5Ql04A@M01@G800C4ad05ADO01<C7@0D4Qd05aDP0P0D4Qd0800H5al051<I01@C6@0G5Q`05A@J
01LF700M72806APN01<B600M72806APN010?5@0F5AX05A@I018A5P0G5Q/05A@I01DC600D4QL04Q0E
02<N9@0B3A@06A@K01TC6P12?D<06QPM018@5@0D4QL040hC014?500E4aP03`dB0P0B41D00`0@3Q<0
5A<H01<@6@0201<@6@804a0G01D05A8I018@5@0C4AH04a4D018@4`0C4A@061HI01<>500?2Q0061<I
05IAE`0V8BL04PdC01TD6P0G4QP04`hD014<4P0B3A<05A0F01LB5P0C3Q800P0D3a<0100A31004`hB
010;3`0A3103018=4@0601<>4P0@2a4040/A02HQ9`0C3Q@03PT?0P0B3A<01`0@3140GEQN02dX;P0B
3Q<0CDQ>01<>4P0B3A400P0A3104018=4@804@`@01<04`hB01@?4`0@2a403PT?00l:400@2a404PdC
01D@5P0>2@l061<I018=500D3aH0;BP_00h93`0A31404@`@01@?4`0A31003`X>00<050lC00H0D4]?
01PC5`0:1@T04@`@01LA5@0D3Q8201<=4@0701@>4P0E3a<04P`@00d72`0>20`050hB01<=4@02010:
3P0501dG6`0?2@d04@/?01H@500>2@`00P0A2`l0200;1@T04P`@00d72`0B31004`d?018<3P0A2`d0
4P`>0P0B31001P0@2Ph05@hE01XC6P0<1@`030D=01<<4`804@/?02T040X>014;3`0A2`l04P`@00l9
3@0>20`07QPL02LQ9@0K5AT04PX>01L=4P0F31004@/<01<=3@0A3@`04@d=01lL701?CE003`dA00d9
400?2a<03PT?014;3@0D3Q004P`>014;3@0H4Q@03@P901XD5P0E41402`D701`F600@2P`04@/=01@>
400A2`d05@lA01H@4P0E3a403`T;010:300201<=3`0B018<3P0@2P`04`d?01@>400?2@/04`d?01/E
5`0D3Q004@/=010:3014?T009AlQ04Y4AP0O6A/05@l?00/51@0C3@d04P`<0P0A2`/600l92@0>00`6
200@2P`02`D701XD5P0@2P`0=c4c00h82P0?2@/02P@600`6200A2`d030H801463P0B1`h201<83P0A
01<83@0B1`/04PL;01@9300=0`@04PP901471`0G3@h03PD701<83P0D2@l03@<801@93`0<0PL03`D:
01P=4`0D2@l00P0B1`d01@0?10X05@X>01<8300C20`04PL;008040D901H03`@801H;3`0=0PH060dA
00`31@0J4A@040T;014;3@0<1PP03@L900h8300<1PX04@/?00h73P0=1Pd04@XA018;4`0?20l04@H;
00h31`0C20`05@X>0P0@1@T00`0C20`04PL;01462P0201872`0I01472@0B20T04PT<01083@0C3Q@0
7ATO010=500/:C007aPO01P@5@0A20/03@D501<82`0E2Ph05P/?01462P0D2@d05@X>01872`0>0`L0
4PL;00h51`0D2@d06a0D01@:3@02014<3@0400l92`0D3Q005@`A01483@8040L<0P0@1`d01`0A1Ph0
4@X>00X41P0C3@l02P@604Q2A016@4801P0?2@/01P0A2`d030H801TC5@0M5a/03@L;00h830803@L;
00X03@H=00/42`0:10X03PL>00/42`0?20l03@H=00/42`0M5Qd05a4G0P0?20l02P0>1`h02`@;034Z
<@0e;cD040T@01<<4`0?20l030D<014:4@0<1@`600h73P0<00h2300B1a00:QlW01hD6`0A1`d04PL=
00h32@0?1@T04@H:00L0000D2@d03`@85?ooool001_ooooo1P0?2@/0700G4A<02P@601H@4P0=1`T0
618D065KG@0C3A404@/?00l93@0>20`03`T=010:3P080PH03PP<00P21P0B3100618F010:3P0B3100
3@L;010:3P0B31004`dA01H@500C3A4040X>00h8300=1`/200h8300C05I@E012?4003`T=01H@500I
4aL040X>00l93@0500<07aTM00h9300@2Ph03`T=01462P0B1`/040D901872`0A1PX03@8601872`02
01462P0301872`0C20`04@P;00803PP:00<03`T;010:300@2P`00`0@2P`01@0A2`d04P`>01<=3`0C
3@l04@/=008040X<00D04@/=018<3P0?2@/071HH00L10`0201@>400?01PB500@2`d03`/<00l;300C
3a002`L800`82@0C3a004@d>010<3@0?2``040`=018>3`0D3a805Q0D008061<G00@05a8F01<A500A
3a804Q0C0P0B4Q@01@0C4aD04a<F014@600C4A`05A<N0080518M00P05A@L08:1R@1OGVH08b8Z00l>
5P0D4a/061LN01@C60805QHH0P0?3a403`0G5aT061PJ01LG6@0G5aT03`lA00d=3`0P8B<071hM00lC
4P0I7A`0720O00lC4P0J7Qd08BDT01TM700201DI600R01HJ6@0H71/051PI01lS9@0H71l051PK01/O
8`0J7b<06R8U01XQ9P0Q:2h07bP]01LP9@0J8bP06B@Z01hX<@0P:S<07BL`01`V;`0N:3408B/d02@^
=`0]=d00;CPn02@_=@0Q;38092le03]7C@0^>d409C8h01TW;@0K:Rl08C0e02<e>@8093Hj02009CLk
02Hg?P0U>3l0:ce702<e?`0Z?4H0=4IB02i0C00X>TH0?U1N03a>G00eAeD0=TMG0312D00Z?4T0<TA@
02doB`0/?TX0=DMA03U;E@0]?dT0:Ca302/nA@0aA4/0<DA:0313B@0]@4H0<TE<03]>E014Eed0?e9H
03Q;D@80>TeD04/0;T5803E8C`0lCeH0;d=:02Lk@P0dAdh0=dYA02Tl@`0]?TD093Hk02@f>P0Z>Ch0
:STm02Th>`0]>ch0:3Hj02dl@`0U=3/09SDl03Y9D00V=cl0<T=;02m2B@0^@4X0=4MA03I:D`0`A4l0
:cm802@h@@0P<S`09cQ202XjA`0]>dP0<3m=02/kBP0fB5H0:Ci<03mFI00`AeD0;Si>03=0D@0b?e40
;CY=02`hCP0V<TT0:3A<02TeC`0_>UD0=D1L03E0GP0g@f40BEUc03e?I`0gAeh0:3M<02`kCP0hAEH0
@4aL02Da?@0X<Sd08b`e01@M9P0N9Bd08RL]028W:`0P9BT07B8V01`Q9@0L8B@04aPK00hC5P0D6QX0
7R@T03Pn?P0J81l00P0K82<201dR9@0b01PM800F6ah06b0S018G6P0C61/03Q<F01hS9P0[<3<04aLH
01@E5`0F5aT061TK01TL7P0G6ah09b``01XO8`0D6Ad03aHL01DL8P0B6Al05a`P01@I7@0H7B405a`R
01HK8@0O92X05a/T01`P:@0I7BH092Pc02lc?P0K7bX08RD^024T;@0H6b@07b8[02X]=P0F6B8071lX
01/N9`0H6b@05aXS01dP:@0R9Bh05QTR010C700B5Ah071lX01HI8P0I72D201PK900D01/N9`0G6R<0
51LP01TL9@0J6R@05QHP01hN:00I6B<04Q8L01PH8P0D51h05aLQ020P:P0G5b407alY03@g@01JGVL0
:Rdf01PK900C5Ql2018B700801@D7P0F51l05Q@O01DC7P0D4Qd061LO01/J800I61h201PG7@0301TH
7P0K6R006QTO00805QDK02d061LM01TH7P0D4aT0:BP^014@5P0P7bD04Q4G020N8`0B41D04a4F01D@
5P0F4AL05a8H01PA600E41H04a4F01@B5`0G5AX061HK01HD6@0E4aP040hC01LE6P0A3a@03P`A01LE
6P0=2Q<04@hG00d:4`0O72<03@XA01@A600>31401`D:010>4@0X9RT040hA00h<3`0A318040/A01HA
5`0B3A<030L=01<>500I51X00P0>2@l0300D3aD040/A01D@5P0E41@05a8F014=400<1`/05A0D04U4
B00F4AD03PT=01PC5`8030L;00P09R4U00/6300Q72805a8H00l:400E41H03PT?01<>508040/A00D0
50lE01D@5P0>2@l040/?014<4002018=4@0>014<400@2`l06aHJ00h93@080`L04PdA00d8300C3Q80
6aHL018=500I51/06QDL014<4`0E41H200l:400:00`73@0K5Q`0:RD[01@?5@0A310040/?00/62P0G
4QH06A@H00d830H04@`@00P04@/?01<=4@0E3a<050hB014;3`0@2Ph04@/?00h830804@/?00<040X>
01@>4P0@2Ph00P0>20`00`0@2Ph03`T=00h83006018<400<01<=3`0D3Q003PP:018<3P0C3A4071HJ
00@00P0H4AP03PT>00X32P0<1@d04P/B0`0B31006@0A2`l040X>00d72`0@2Ph04P`@014;3`0E3a<0
4@/?010:3`0?20l04``C014;3P0=1`T06aDE01@?3`0>2P/04`hB00T62P0>2a805A@L00P52P0@2P`0
4P`>01<=3`0B30h00P0@2P`00`0A2`d04P`>018<3P02014;3@0O00h82P0Q6ad03PP:014;3@060080
4`d?018<3P0G4A<03@L901<=3`0H4Q@05Q0B00T31@0B30h04`d?00`6200@2P`05@lA00/51`0@2P`0
5Q0B01@>400B30h04`d?00h8200:10@03PP800l92@0H4Q803`T901@>3P02010:2P803`T900<05a4A
010:300@2P`00P0?2@/300h82P0B00/51`0?2@/04@/=010:30080P@05P/C00l42`0;00H03P<90146
2`0?10P04PL;01462@0@1PL04PP90188200@1PL040D91@0@1@/01P0;00H0A3To01<83P0:0@D05P/A
014630803`@800L08QLK00d41P0C20`04PL;00h31`0@1@T04@H:00804`P<00P04@P;014:300<1PP0
2`D700`6200?2@d04@/?00h830<03PL>00/03PL?00h73P0A1P/04`P<01X?4`0?1PP05P/?00l4200B
1`/01`0001L<400201462P0/0106200A1`P03`H900h62`0;1P`02`H=00D32@0I5Qd03`P?014:3P06
00004`T:00d31@0A1PX07A8F00l5200>0`L05``@01462P0D2@d0304500/2100O51P08aPL01D;3P0=
10D030<600d6200>20X03@L;01<<4P0D3A@030D<00h73`0?2100100501H?5@0<1PP040X<00l92`0E
3a406Q@F00/51`0<1PP400h82P0301<=3@0?2@T02`D500803PP:01002P@80109400@2A003`P?00h7
3`0=1Ph030D=00X32`0?21001@0601<<500D3AD04P/C00`53@0>1`l03@H>0P0?2100100L5Ad040T@
00l83`0>1`h300d63@0>059;DP0Y8RT02@8900X32P0A2Q403PL>01L;5@0D2Q40ACY203hc>`0<0`P0
6PlE00l42P0@1@X201462P0301052@0?10Sooooo01?ooooo000Kooooo`H03`T;00P02`D7010:300B
30h040X<018<3P0K5AL04@/>010:3@803`T<0P0A2`h0200C3A0071HI018<3`0>20/04@/>00h82`0@
2Ph03PP<0P0C3A401@0?2@d04@/?01<=4@0@2Ph03`T=00<03PP<00d050lB00X5200C3A402`H901@>
4P0A2`l03PP<01dG6`0:1@P05Q0D00h9300?2@d050T=00804`P<00D06a0D01X?4`0D2@d05@X>0187
2`0201462P0401872`0A20/03`T;00l92`<040X<00@04@/=018<3P0B30h04@/=0P0?2@/00`0A2`d0
4`d?018<3P02018<3P0E01<=3`0G4A<0618D014;3@0F41802@@501D?4@0C3Pl0510A01HB4`0D4140
40`=014=3P0E4A805Q8C01DA4P0D41404`l@01@@4@0E41805@lC00805Q4E00D05A0D018@4`0C4A@0
518E01<C5@0201@D5P0@01@D5`0@3aL04Q0K01@B700C4A/04Q4I01@C6P0H5ah051<J014@5P0C4QT0
51<H014@5`0D51H05QHG01LG60804a<D00l06QXK01TI6P0F5QL04a<D014A4P0C4a@08R<T01@F5P0L
8200Jfm_02<W9`0E6AT051PH014E5@0I7Ad00P0J7Qh0600O8b<07R8S01HJ700L82@06alS01`O8`0M
8BL05a`Q01hU:P0J8BP07B@[01dV;00O:2l09Rlg01PR;00M9c8082Xc01lY=00P:S<08R`f01lY<`0O
:C809Blh02D`=`808B`c00L07bX`020/<P0N:c407R/a02Dc>@0D8bP08S4f00<08S@h00X09CLk02Pj
?P0^@DP08cDo02doB@0[?DL0;3i:03a>FP0hBUH0?4iL0P0`@U002@0iBUX0:ce;0353D00^@4`0;3i:
0353C`0bA4h0;Cm90312C0020354B`0@0313BP0_@TP0;T5702i0A@0Y>d00:ci303E7C00jC580>D]B
02m1B00fB500<TA<03U;DP0lCUH0;d9902a0A`80;d9904H09SU002Hg?P0U=c`08cDi02Lf>`0V=CT0
93<f02Pf>@0V=CX0;3]202Xj@@0X>3l0<D9902`mA@0]?dL0;D1802i1B`0bAE00<dMA0314C`0_@dh0
;41:02XlA`0W>4D093A202XiA`0[>dX0<TAC04QIJP0[@500:D1?03A<F`17FFT0@E5U030nD`0W=D/0
:CU@02LeC`0lBF@0;3YF03U7I00lB6L0<CmP03Y7IP12DV`0?DiW04mOMP0gAU/0<D1C03=0D@0Y=DD0
9S4m02H_>P0I8B/06b<]01`S:P0K82H07B4V020T:00N8RH06QhR01<H6`0I7R004AHF01DJ6P0J7al0
9b`[01HK6P0M8R806QlQ0P0H71h0100K7b407R8T01/P8P0@51H201/O8@0801TN800@51H06Q/M01LH
6P0E5QP061TK01TL7P0H71l201HK7`0J01LL800K8RP0D5MM05ELHP0O92P061dQ01XO8`0L8BL06QlU
01`Q9`0P92d06alX024U;P0[;cX0;30k01HJ9@0R9Bh07R4Z01XM9P0D5b007R4Z01LJ8`0K7RL07R4Z
01dP:@0I72D201LJ8`0602d`>@0a=3d05aXS01LJ8`0M82T06ahW0P0J7BH07P0S9Rl06ahW018E7P0J
7BH051@N01TI8`0E5Al06a/U020P:P0K6bD08B4[028R;00G5b404a<M01TI8`0F6B806A`U00d@6@0?
4Q/04aHO01LG8@0F5R0051@N01DC7P0F51l0518M01<A700F5Ad061LM01HE6`805A@J00<05QDK01PG
7@0H5ad00P0F5A/02`0H5ad05aHL030_=@15A4/05QDL01TH7`0>3A<07AXP01HD6@0E4aP05a8G0080
5Q4F00D05a0F01PC600@3Q<03`dB01LE6P02018@5@0K01DC600K6Ah04a4F03Tg?00@3Q<071XO00X8
400D4AX04@hG00d:4@0K61l04PlF010>4`0?3A8071XM034_<P0K6A`04a4D01LB600C3Q@040/A00h9
3`0A31808ahT03Pc>@0R7B<04@`B00804`hD00L05Q4G00l:3P0E41@04`hB00`72`0;1PX05a<F0080
50lC00H04`hB01HA5@0W8RH050lC018=4`0D3aD200l:400:01<>500B3A<04`hD01<>500A318040/A
01@?5@0I51X040/?014<40804PdA01X04@`@010;3`0;1PX04@`@01/F6P0U82@05Q4E00l:400B3A@0
4PdE010;4`0B3A@050lF00l:4@0@2a404`hC010;400B3A805A0E010;400I51P07QTM01D@500A3100
50lC014<40H03`X>0P0A2`l2018<400>014;3`0@2Ph04P`@010:3P0D3Q804`dA018<400E3a<04P`?
010:3@0A2`h04P`?010:3@0?2@`6010:3@805Q0B00X04@/=01<=3`0B31003`T=00T41`0H4AP030D<
01PA600C31@04@XA0`0B31006@0A2`l040X>01<=4@0F41@04P`@00`62P0@2Ph04P`@014<500B4A/0
30XC010<4P0C3A0071HG018=300=20L05A0@01hI7@0;1`h030LA010;4@0@2P/04P`=01<=3P0B30d0
0P0@2P/00`0A2``04P`=018<3@02014;300>01XD5P0S7Al08adO02`V:00>20X04@/=010:300D3Q00
4P`>01D?4@0@2P`05Q0B00d72@0@2P`200l92`0D018<3P0?2@/03`T;014;3@0B30h03`T;00h82P0A
2`d040X:014;2`0@2PX02P@400l92@0D3Ph03@L7018<300?2@T03PP8018<300A2`/2018<3P804@/=
0P0@2P`0200N61X04@/=00/61`0C3@l02P@601@>400D2A4050T@0P0D2@l02@0C20d04PL;01@93@0C
20/04PP901@:2`0D2PX04PP901462P050146300901@93`0k<3H03@8801X?5@0A20`04PT=01H;3`0@
1@T04@H:00803`@80P0C20`201872`0:01@93@0F2`l05Pd@018:3@0?2@/03PP:00l92`0@2Ph04@/?
00h830<03PL>02803PL?00h73P0H3A803`@801<8300F2`l05P`?01<8300n<cL0:AhR01072@0G3100
5P/?0106200B20T04@P;01083@0=20h03@P?00X73P0>2a801`4701493P0F3A0030<401882P0P5AT0
<RL[01L<400800405@X>01@93@0@1@T04@H:0P0D2@d05@0@1@T03P@600h51P0=10H03PH800h82P0>
20`03PP=00/5300;10d04`hF00l:5@0M5R403@H=00h82P0?2@/02PD601@>400?2@/02`D700`62004
00h82P0600X4100=1`H040X:00h82@0<1PP03PP<0P0=1Pd02@0>1`l03PL@00l74@0?214050dE00/6
300D3AD0208900X32`02014:4P05038[<`0D3AD04P/C01<>500>1`l00P0@2A004P0>1`h030D<00`5
300<1@`0<BXa01`E700=1Pd03`P?0109400<1@`040@>01X>5`0C2Q0040L=01D:4@0?10X04@H<0187
30<04PL;00<04@H:ooooooooool04_ooool001_ooooo1P0?2@/01P0>20X04@/=00X41P0=1`T04`d?
00D00@803PP:0P0?2@/2014;3@0400h82P0F41803`T;00`620803`T;00D030H:00X4200?2@d04@/?
010:3P02014;3`8040X>0`0?2@d01`0A2`l06A<G01LA5@0?2@d05a4E00H0100C3A400P0@2Ph0100;
1PT040X>01<=4@0G310201872`0501T>4P0F2`l03P<701L<400C20`00P0@1@T0100B1`/04PT<00l9
2`0?2@/2010:3004014;3@0?2@/03PP:00l92`<04@/=00<04`d?01@>400C3@l00P0B30h04@0C3@l0
40X<02PR900@2P`03`X;02LQ8`0J51H03`X<014=3P0C3a004@d>01TE5P0F4Q<040`=01<?400B3Pl0
4@d>008040`=00<04Pd@01D?4`0E41@00P0E41@00`0B41<05A<F01DC5P0301@D5P0@01@D5`0?3QH0
4A0H01@C6`0C4QX04Q4G01@C6@0J6Al06APM01@D5`0?3Q<0410B01LG6@0@41004Q8B01<C4`804Q8B
00@061PH01XJ6P0F5QH04Q8B0P0A4A406`0B4a<06a`N02lc=02<T9809RX]01@H6P0P92D05QXM01/O
8@0@51D03a<F01TM7`0E6A`07B0U01/N900I72<05aXQ01<G7`0C5b008RTa01/R;00G7RP05b0Y01TR
;00M9C006R<b01`U=00201dV=@0401hX=00N:3808R`f01hX<P807bTb07/072H_020Z<`0E82H09C4g
02/h?P0L:Bl08S0e01l^<`0R<CH0838f01la=@0P<SH09CLk02Pj?P0Y?4<0:C]5028d?P0V>480<dEA
03Q:EP0gBED07c4o03A6E01<GV`06R/k03M9E`0`@Tl0;Cm;02`nBP0dAU80<dE?02/mA`0Z?4H0<DA;
0395C00_@TT0;d980313A`0^@480;3i202do@`0`@TH0<45802hoAP0b@dX0<T=;02hoA`0hBE40@U=K
03U<D`0fBU40:Se402`oAP0]@4L09SLn02Hh?@0S=CT09cHk02@c=`0Q<3<0938e02<a=`0X=ch0:CY1
02Pi@00Y>T80=DQ?02XmA@0[?DL0;D5<02m3CP0`A4l0<DE@03I:E@0cAe80<49>02`mB`0[>dX0<D5@
03E5E@0W>4P08cI702ToD00lEVD0<4]I03aAI00lCV80<45G02XjD@0a@e/0>daV03Y9IP1cQ:00PI6_
03Y9JP0iBFX0<D1P01h^B00c@e`0Jg^B03e<H@0X=dX0<3e>049;G00X<Sh09Rhj024X<P0E72H061hU
01LJ7`0J7B808B@Y02<W:P0P92L06alR020T9@0G6a`06QhM01`P7`0I7A`06QhM01dQ8P0L82400P0F
6Q/01@0K7b00720Q010D5@0J7Ql092PY00805QXK00h07B4R01lP8P0I6Q`05AHH01HG6@0H6ad061`O
01DJ7P0L8BD06AhR01LN900Z<CL08bX`024V:P806QlS0P0O92X0<P0J7bD061`U01hR:`0T:3405a/V
018F8@0J7RT06ahW01HI8P0S9Rl06QdV01PK900G6R<05QTR01XM9P0L7bP06ahW01PK900G6R<06QdV
01LJ8`0L7bP07b8[014D7@0F6B8061/T01`O:00M82T06ahW01TL9@0H6b@061PR01TI8`0C4ad05aLQ
01`L9P0H62808R8/01@D7P0L72H05QHP00h>600G6R<04QHO018E7P0I72D06QdV01HF800E5Al061PR
0P0I5b80100H5R405aDP01HE7@0E51X401@C6@805QDK04h05A@J01HE6`0F5A/04a8H010?5P0E51`0
20L?01TH7`081`d05Q<J01`J800F51T061<G01HA5@0D3a<05@lC01HA5P0=2a004a4F02LU:P0I5a`0
4a4F03Le>P2<RXl06aTN01TG700A3a@06aTN02@Q:P0>2a@02PL@03`i@01iMWd06aPO014?500?3A80
3@/>01PF6@0@3Q404@lB014<4P0B3A<04`hD018=4`0A31805Q4G01lJ800D3aD03`X@01D@5P0D3aD0
4@`B01<>4P0F4AD04`hB014<400H4aL050lC00l:3P0C3Q804@`@01/F6P0e<3@05A0D01<>500@2a40
5a8H01HA5`0>2@l04PdC01@?5@0C3Q@05A0F01@?5@0?2Q003PT?010;3`0A3102018=4@0J014<400@
2`l030L;014<400D3a<07APL01HA5@0D3aD02@@;01@>600L5R007QTP01PC6P0:1@`03`X@00l:3`0C
3Q8040/?00h93@0F4AD040/?01XE6@0D3a<03@P<018=4@0E41@6014<400801<=4@0A2`l04@/?014;
3`0B31004`dA010:3P0?2@d201<=4@03014;3`0C3A404`d?008040X<00<04@/=00l92`0>20X0200@
2P`02`0A2`d050h@01D?4`0B31005Q0D018;4P090`T05@hE014:4P0B2a804P`@00804@/?0P0@2Ph2
00h8300B010:3P0A2`l040X>00l93@0<2aD04QDT0000300>3QH00@0200h:2`0A2`X03@P501TC4`0a
:bd05A0F00H1200A2`l040X:0`0A2`/2010:2P03014;2`0B30`04P`<00804@/;00H03PP:00l92`0?
2@/06Q@F00/51`0G4A<2014;3@08010:300C3@l04@/=038/;P0H4Q@05a4C01<=3`0B30h201<=3`80
40X<01004@/=010:300@2P`04@/=00l92@0>20P02P@401D?3`0F41002@<301<=3@0K5AD03@L700P2
0P0@2PX020821P0@2P`04`070@<040X<00H00P0>20X05Q0B00H00P0@1@d05@XA01@93`0A1P`040D:
01<8300D2@d04PL:01882@0C2@X050X:01882@0B1`/01@0B1`d0500?10X0DDI<01`A5`0@1@/05@X@
01L<4P0B1`/05P/?00d21P0L4AD02P0300`11@0E2Ph04PL;01462P0C20`05P/?01L>4@0A2@`04@/=
0P0B30h00`0@2Ph03`T=00h8300300h73P0i00h73`0>1`h04@H;01T>4P0C20`05`h@06iSI`0K41@0
7aDH01872`0>0`L02P4300d21P0A1PT04`T:0189300@20d03PT?00d83`0F4aX03@XA00H01P0_:2`0
GeII01hD5@0?1@L03@8600X00`0C20`08QLK01/@500@1@T03P<700l4200C20`03P<701<8300F30h0
3@@500h51P0=1PL03PP:014;3`0F41L04@`C048lAP1gM7h03``G02<P:`0:1``0@3Xl05MAD`0H4Q@0
100000`6200;1@L030H800<03PP:00@03PP900`7100>2@H040X:0P0<1PH01@0?2@`03@H=00d63@0>
1`l03PHA00803`LB00`05`lJ00d63P0B2a<04@XB018;4`0:10/01005020I8@0;10`03PL?00d63P09
0PX200l83`803PL>0P0?20l03P090PT02P<:00`5300?20l040T@00l83`0D218040@=00l4300A1Ph0
40D<00h32@0A1P`04PL<0P0C20`00`0B1`/04@H:ooooo`0Cooooo`006oooool600l92`04018<3P0>
20X03@L900l92`804@/=00@03@L900h82P0?2@/03`T;0P0@2P`0300;1@L03@L900/51`0?2@/04P`>
010:300E3a<03PP<00l93@0@2Ph04@/?01@>4P<04@/?00`040X>00l93@0?2@d030H:01PB5P0500<0
3`T=00d72`0<1PX040X>00l93@1QFel201H@500>00L11@0E2Ph04PL;01462P0G310050T=00d21P0G
310050T=01872`0A1PX04PL;0189300?2@/2010:30804@/=00<040X<00h82P0?2@/00`0A2`d0100C
3@l05@lA01@>400C3@l2018<3P0<010:300;1@L0618D01<=3`080P@03PP:01D@4@0C3a004@d>01HB
4`0U8B807a/L100A3@h0100@30d03`/<01<>400F41@301HA5@0301<A500E4aH05A<F00<051@F00l0
51@G014@5P0C4QX05A@K01@C6@0C4QP05A@I010?500@418051@E01LG6@0E5AD03`l?01@D500E5AD0
0P0F5QH0800G5aL06QXJ018B4P0C4a<05ADE01TI6@0L71`061TJ020Q9@0?4aH092P/00hA5P0@4aL0
6alR01LJ7`0H72004aLJ01LJ7`0P92P061/P01LJ8@0J7BD092L`028U;P0I7BL07B4/01lV<00L8Rh0
61hZ01PP:`0I8Bd05Qh[0P0M9SL01@0N9cP082Tj028[>P0R;3P09S0l00808B/e00H07bTc01/U;`0N
:3407BP^01l[;`0G9BP201PV:@0302dl?`0S<SD08C<e0080838d01D09CLi02Tk?`0V>D00=dUC0353
C@0[?DL0:C]702@f@P0_@Dd0;T1>03E7E@16F6H0C5e]03i@GP0]?d`0<D=?02i0C00`@Th0=4I@03=5
C`0/?TP00P0cATd01@0`@dX0;d980354B00a@d@0;T120080;Cm102T0:ce102Tk?`0cA4/0<45902dn
AP0dADd0?TmI03M:DP0dB4l09SU002Lj@@0^@DP093Dl02@f>`0U=c/0:CPm02He>@0R<C@09C<f02Hd
>P0_@4P0:ca402Pi@@0Q<SX0=4I@02PkA@0/@4T0;T9=02i3CP0_AE00<TQE03E;F00^A540:Ca:02do
CP0b@e<0=dMG03M7F00a@U@0:Sa@02]1D`0202e7F00K0315FP0iCV<0=dYR02XlE00X?5D0=DMR03a=
J`0iC6X0@E=c03U9J`0cAVL0?dm`0392G00kBf@0FfZ103Q4FP0a?U40AU5S034jB`0O:CD0<c]70417
D@0b>D<082@/01DH7@0F6Qd06AdP00806QhQ02h06AdN01/O800F6Q/05a/J01XN7@0A5A@06AdK01HJ
6`0J7Ql05a/L01PL7@0N8R<06QhO01LK700Z;Rl0V9bM08N;S00K7b0051PI020Q8`0J6ad05AHH01HG
6@0H6Qd05a/N00462P0F6al0:2da038i?`0L8bT04aXP01`Q9@0H7B406AhR01lT:P0Q9R`06QlU02L[
=00J7RL06alX01XN:@0L82/07B4/02DX<@0F6B808B@]0P0M82T0100K7RL061/T01PK900I72D201XM
9P0P01TL9@0H6b@09RTb02LZ<`0F6B802`hG01dP:@0L7bP092L`01PK900N8BX0:2/d01hQ:P0J6R@0
51@N01LG8@0E5Al04a<M01PH8P0O7bT04A4K01/K9@0J6R@04a<M01TL9@0D5b002`hG018E7P0H6b@0
5aLQ01DE7`0H628201TG8P0301PF8@0G5B005QDM00805A@J0P0F5A/0<00E51X05QDK01HE6`0E51X0
5QDK01DD6P0C4QP05A@K01PF8@0B4AT0<2lg024P:00@3A@03``B01LE6P0I51P05Q8D01<?400D3Q00
7QTN01<A5P0=2a0061HK010>4`0D4QL0LFmd0?[ho@1<BTl01@<800h<4@0=2a002PL@01<@6@0I5Ql0
3P/B03Ld>`0E4QT02`T>01@B5`0H5QT081hQ01XH6`0?3A003PT?014<4P0E41H04`hD014<4P803PT?
00D03@P>014<4P0D3aD04@`B010;4@0201PC5`05014<400?2Ph050lC00d8300D3a<00P0C3Q804@0=
20`061<G00l:3P0C3Q@04PdC01TD6P0E41H040/A020K8@0M61h03`X@014<4P0G4QP05A0F01@?5@0@
2`l04@`@00804PdA01H04@`@010;3`0A31004`hB00`72`0D3a<04`hB01LB600E3aT03@PB0:VS[@2[
YJl03`XB01HA600A318030L<00l:3P0@30d03`/<01@@4@0=20`04PdA0P0?2Ph00`0B3A404`hB014<
4005014<4004014;3`0@2Ph03`T=010:3P@04@/?00D05@lC01@>4P0B310050hB014;3@0200l92`03
010:300>20X03@L900H040X<00h03PP:00d72@0@2P`04@/=01<=4@0B31004`dA00/42`0B2a8050dD
01<<500E3QD04P`@014;3`8040X>0P0A2`l00`0C3A4050hB01<=4@0200d72`0=01<E7`11B5X0728b
00d?6@030PL04`l@014<2P0B2PL03PH401<;300@2Ph03PL>018;4006010:2P03014;2`0B30`04P`<
00804@/;00`05@lA01LA4`0<1PP02P@600/51`0C3@l05@lA01@>400>20X03@L900H00P0T7R02018<
3P0F014;3@0<1PP03PP:01XD5P0=1`T03PP:010:300B30h04@/=00l92`0?2@T04`d=00`61P0H4Q80
50h>00`61P0K5AD08A/K010:2P0;1@D050h>00h820H03PP:00@01@0101TC5@0K5AL02`D70P0A2`d0
3@0C210050T@01873@0>0`T040D:01H;3`0B1`/04@H90147200B20T04`T901061`0B1`/01@0B1`d0
500>0`T02`8601<83P0C20h04@H<01hC6@0D2@d06PlC01<8300S61`04@H:01<8300D2@d04@H:0105
2@0A1PX050T=01D<3`0@20/04@/=0P0B30h00`0?2@d03PP<00h8300300h73P0J00h73`0>1`h050T>
01`A5@0E2Ph06Q0C079WJ`0O51P04PT;01462P0700007Q<G00L0000N51H04`T:0189300@20d03PT?
00d83`0610X01P<:01PA600D3140:b8U00X00@0@1@P201L<40805@X>0P0B1`/200l4200=01872`0>
0`L05P/?01`B5@0D2``04`X;00h6200:10H030H:00X42`0U82L0RhRA0<K2b`02018@7@0801@@5P1L
EUP0LVa^02dW:@090`D050h@00/51`0<1PP300h82P0700h82@0E40d04@`800/60`0<1PH03PP800h8
2`0200l83`0@00l8400>1Q403@D@00d54@0800/06a<N00X33@0E3AP040PC01L?6P0C2aH03`LB01<=
5P0600T02P8=01PA6P<03PL>014040T@018;4P0D3A@04P/B01@=500C31<040T@00h73P0<1@`05PXD
00/02@0G31@06a0H00h32P0?10X04@H<0187300201<8300301872`0A1P[ooooo01?ooooo000Koooo
o`H03`T;00T03PP:00d72@0D3Q004P`>00/51`0@2P`03@L900l92`0@2P`00P0?2@/01@0=1`T040X<
00h82P0?2@/04@/=00804P`>00P07ALK01<=4@0B310040X>00l93@0B310040X>014;3`804P`@0P0@
2Ph04P0B310040X>00h8300B310020<601D?4`0C3A402P@805aFFP0J51P05a4E00d72`0A1PX05@X>
01<8300F2`l060dA01H;3`805@X>0P0D2@d0100C20`04PT<010:300@2P`2014;3@04018<3P0D3Q00
50h@018<3P8040X<00D04@/=01@>400D3Q004`d?018<3P02014;3@0?010:300F41801P4201D?4@1C
CDl09AlQ01<>3`0?2``03@T:01DA4P0K5aP05a<D018>3`0C3a00510A00805Q8C00<05A4B01HA4`0G
4AD00`0F4AD0100D4QD05A<F01DC5P0D51H201<C5@0401<B5P0A41H04a8I01HE6`8051<H00X05ADH
01LG6@0D51@04Q8A01HF5@0H61D05ADC01@D500C4a<051@D0`0E5AD01`0B4Q805QHF01LG5`0E5AD0
5aLG018C500H6Ah00P0E61h01@0I728051LM01/N900H6b405aXP008071lU02406QdS020S:P0L7bP0
51LQ02@V<P0X:SL07R4/020S<@0I7b`06R0^01/Q<00O9cD09Bdk01hU=P0L93L06R8f01XR=@0M9CP0
7bPi01hW=P0T;C`08bdi02H`>`0T;ST07RPb01dW<00R;C<07b`_03]9C02?WJ00@U5D028a=00S<SD0
0P0S=CL01`0T=SP09cTk02Tk?`0lCeD0;d5;02TkA@0]?dT00P0bA5003@0U=d<0:ce;02@fA01HJWP0
aMKV055SL@0dAU<0>4YF0312CP0Z?4P0<49<03A6D00cADl00P0cATd02P0aA4/0;T5702i1A@0`@T<0
:cdn02Pj>`0W>C/0:C/o02Xl@00]?TD302hoA`1A03=4CP0/?dL0;d=:02m2B@0W>T409CPo02Hg?P0T
=C/09cTm02`k@00Y>3`09SDh02Tg>P0V=C/0>DYB02@e?@0[?4@09cU003a>F00dAe40<DE?02m3CP0a
AU40=4YF03I<F@0eBeT0:d5?02LjB@0Z?4`0;Ci>0350DP0a@E<0;d9C02<eB@0/@eD0:D=D035<GP0U
?580=DaR03eCJ`0_A5`0;4=K03]@K01CIhD0BEmm03M<K013EgT0=Ta]03mBM00`?e`0<D1I0350E`0l
B5h0>TMJ02diB`0V;d0092hj02D]>@0V;CL0<CQ202<W;`0O8RL07R8U01`P8`0J7R406AdP01TM7P0L
820082@T01/O7P0O8b4051TF01dR7P0>4Q<06AdN01PL7@0J7Ql08BDV01TM7P0O8b@03Q8C0080=3Pi
01l061`M01HJ6`0L7Al061TK01HG6@0G61X05aXL01HJ7@0O92P061dQ00hC5`0P9bd05A/Q024X;P0H
7B406b0T01XO8`0M8RP08BH/01XO9@0K7bP0:2`e020T;@0B5R406QhY02P/=`0a=3d071lX01PK900G
6R<08B@]00807b8[01X06QdV01TL9@0I72D06A`U01LJ8`0K7RL071lX01DH8@0S9Rl07b8[01LJ8`0I
72D07R4Z01@G800I72D08B@]01/N9`0I6B<05QHP01XJ900G5b4051@N01TI8`0M7BL06ATS01<C7@80
6QXT00D041<L01XN9`0@4a`04QDN01DH8@0201<C7@0801DE7`0G5B005aDP01HD7`0E4ah051<K01DD
6P0F5A/201LF700301HE6`0I61h061LM00<05A@J00<051<I01<A6P0G5B000P0E51`04@0B4AT040dD
01LE6`0F51T06QDI01HB500B3Pl05Q0B01dH700H5Q/05aDJ01hL8@0E4aP04@lD02HT:@1KFEh0;B/`
00805aDJ01<040hC03Xg@00W92d04a0I01HC6P0J5ah03``C010>4`0G5AX030X=00/9300C4A@04@lB
014<4P0C3Q@04PdC014<4P0E41H05Q4G008061<I00D05A0F014<4P0@2a404PdC014<400201<>4P09
01D@500C3Q8040/?014<400@2`l05Q4E00T4200@2`l06A@H00804PdC00`04@`B00h93`0E41H09b8X
03Ha=`0J5A/03`X@018=4`0@2a404`hD010;3`0A3102018=4@0E014<400@2`l03`X>01LB5P0A3100
5Q4E01@?4`0B3A<040XD01D?6P0]9c40;bTc01LA6P0>2A006aHL01TD6@0C3Q80510A01PD5@0C3a00
4`hB00<04@`@00<040/?00l:3P0?2Ph01@0?2Ph0100?2@d040X>010:3P0@2Ph200l93@09018<400C
3A405a4E01H@500B31005@lC00l92`0=1`T03`T;00804@/=00<03`T;010:300@2P`0100@2P`04P0A
2`d03PP:014;3@0=1`T03PP<014;3`0@2Ph02@8901<<4`0?20l06Q<K00l83`0C3A404@/?00l93@0@
2Ph04@/?018<40803`T=010040X>014;3`0K5AT0HFAb0=gYmP1lQIL04AHR00d=4P0Q7b003@L40108
100G3@/04@L801@:3@0H3Q<03`P:100?2PP00`0@2PT040/9014<2P02018=2`0>014<2P0A2`X03@L9
010:300A2`d03`T;018<3P0?2@/02`D7014;3@0B30h05Q0B010:300D3Q02010:30804P`>00@04`d?
024K7@0E3a404P`>0P0?2@/01`0@2P`03`T;00P20P0F41003PP801TC4`0>20P00P0@2PX00`0C3@d0
3PP800`61P02010:2P803@L90P0>20X200l92`0401@>400G4A<02`D701@>40803`T;00d05``D01@9
400A1P`04@H<01<83@0E2Ph04`P<01462@0A1`P04`T:01<92@0A1`P04@H:00D04@H<00d06PlE0147
300E2Q0050X?01P=4`0?1PX04`P<01462P0D2@d04`P<01872`0E2Ph04PL;00<040D900<04@H:0107
2P0@20/00`0@2P`00`0?2@d03PP<00h8300300h73P0Q00h73`0>1`h04`P=00/1100@1@T04`P<01D<
3P0A1PX03@@6024F6P0A1PX060hA01P=4@0C2P/04PP901482`0@20d03@P>00d83`0<2A0040dD01D>
5@0?20`050`>01<92P0A1`T050T=00l4200B20/04`T<00`31@0?10P040D900804`P<0P0A1PX0500>
10L03PD50107200>1`P03`T;01D?5P0B3Q@040dF02h[=P15@dl040hK010>700=2A803`T;01D?4@0>
20X0618D00d72@0;1@L030H80`0>20X01`0>20T05A0=014<200=20D03PP800l92@0>20X00P0?20l0
900?21003PHB00h64P0=1A801`0:01D=600B2aD0EDeH04]3CP0@2A<03`TB014;500[8bh05Q0I018:
5@0<1Ph03PL?00d63@0>1`h03`P?014:4@0B2a803@H=00h73P0?20l03PL>00l83`0@2A004@D?0146
3`0>0`/040D=01@9400>0`T04@H<018730<04PL;00<04@H:ooooooooool04_ooool001_ooooo1P0?
2@/01`0<1PP040X<00h82P0>20X04P`>010:300>20X00P0@2P`04@0?2@/03@L900/51`0;1@L040X<
014;3@0<1PP03`T;01D?4@0@2Ph02`D900d72`0>20`03@L;00l93@0@2Ph04@/?00804`dA01X04@/?
010:3P0@2Pd03PP:01LA5@0@2Ph07ALK00@00P0A30l02P@800@00P0F3aH02`@;01@>4P0A20/06@hB
01<:3@0@1PT04PL;0189300B20/05@X>01D<3`0F30l04`P<0149308040X<00P04@/=018<3P0B30h0
50h@01<=3`0@2P`03`T;01<=3`805a4C00<04`d?018<3P0A2`d00P0?2@/01`0>20X03`T;01LA4`0A
2`d09b4S00d72@0D41800P0C3Q801`0F4A@030P900h:2`0C3a004Ph?01@@4@0G4QD00P0G4QH01P0F
4AL04Q0E018@5@0A3a@04Q0E01<A5080518E00L04a8C018B4P0A4A404A4A00l?4@0A41D04a8G0080
4Q8D00T04a<D01@D500D51@05QHD01DF4@0C50l04A4>01LG5`0F5QH00`0G5aL08@0E5AH0410B01LG
6@0F5QP04a<E01XJ700M7R403a8G01DH7@0L7bH01@P?01DH7`0H6b806QdT01DH8@0J7BH05QTR028U
;P1>DEX0DeEQ024S<00E5b@071h[01PK:00M8Bd061h/01TO;@0H7R`082Hd02Xa?`0S:S`0<CQ;02T`
@`02028Z?@0@01lX>@0J8c@072Dd01lY=P0X<Sh0:C<o024[=`0N:3808Rdc02Pe>01QKg80kogo069a
M00M;3408c8g02Dg>`809SPl01L09cTm02Tk?`0Y?480:Se401`_=P18FV@0DfE_02XlAP0W>D<09cU5
02i0C00[?DT0AeUW03E7D`10DUd0?4iJ02m1B`0V>4<0:3Y402XmA00]@4L0:3]202Tl@P0202e0AP0R
02/n@P0T>3T0;T120355AP0_@TD0:C/o02Hi?@0a@dX0:S]302Li@@0Y?4<0=4E=0313BP0fBE00B5]R
03=6C@0T=ch0<DA:02Tl@P0V>Cd0:C/o02Ti?P0W=ST0:cPn02loA@1CI6/0:ca302doA`0T=ch0<TA>
03E9D`0dB5<0;d=>0357DP80>DmJ02H0=TaJ0398EP0aA5<0;3i=02@eA@0V=dT0:ca>0313E00R=DH0
9ce>01/bA00Y@e@093eA02m8G00bBF009SaC02HnEP0dBfH0?E9_04eTP`0`AVH0?U9e03A;K@11EGH0
<d=L041?I00/>Th0>DII030mCP0X=4@09Bhm01TS;`0S:cD08BPb01/R;00R:2l07R<Y01hS9`807b@X
00l07R<V01lS9@0J7Ql09BTZ01/O7`0M8B0051TE01TN6`0G6a`07b<T01LK700F6Q/06alP014E5P0B
5QL00P0F6Q/06`0>4Q<05a/L01<G600F6Qd05ALK01@H6`0H6Ad05QTM01@G700D6Ad05AXO00`A5`0M
92X07RD[00lF700I7R@08BH/01dR9P0K82H07R<W01TN8P0U:Rh0<SLm02<X;P0J7bD06QhW00lC7002
01`O:00W01dP:@0G6R<082</01/N9`0K7RP061XV01XL:00N82`071hZ01XL:00D5b006QdV02P[=00W
:S<04aHO01hQ:P0H6b@05QTR01lR:`0G6R804A@M01/N9`0M7BL08B4[01TI8`0J6R@06ATS010@6P0H
62803PhJ01XJ9P0G5b<0410L01PJ9P0K7bX0720[01lS;P0I72L05ALS00805aLQ0P0H5R401@0H5B00
5a@O01@B6P0C4QP05A@J00805aHL00@05QDK01TH7P0J6Al05QDK0`0D4aT0400C4QT04a8J018A6@0B
4AT07ahV01<@5`0B3aD0518G01LE6P0E4QD04`hB01HA5@0F4aH04@lB010>4@0B41D201DC600D01@B
5`0610T04PlE01@A600A3QD07Q/R018?5P050PT05a@L04=0A`0L6B005a@K00`:3`0J61d04a4D00h<
3`0H5QT03`d@00d83P0B3A<201<>500R01HA5`0A31803PT?00h93`0@2a405Q4G01TD6P0B3A<06QDI
01PC5`0B3A403`X>00X52@0F4AD04PdA01<>4P0D3a<02PD901@?4`0>2@d03@P>01<>500E41H050lE
014<4P0:1@/07APN014<4P0F4AL05a8H010;4@0D3aD040/?014<40804PdA04H04@`@010;3`0;1PX0
5A0D00d8300B3A404`hB01<>500E41L05@lH00X5300<1@d05@hF014:4@0@2A006A<G00`62P091@H0
510A00h:2`0@2`l04@`B018=4@0>2@h03PT?014<400A31404@`B014<400A31404@`B014<400C3A40
5@lC01LA5@0F41@04`dA018<400<1PX03PP<018<400A2`l03@L;00l93@0?2@/03PP:010:300C3@l0
5Pd@01D<3`0@1`X040L<00h82P0>20/03PP<00h82P0@2P`03@L901<=3`0>2P/04@/?01@>4P0B3A<0
2PD;00`73@0X8bX0CdYA024K8P0C3A404@/?0P0?2@d0500A2`l04P`@010:3P0C3A404P`@00T31`0;
1@T07AlY07AmSP0Z<D4020/E00X93P0J5QL04P`900`2000J40h03`D500P0000L4AD050`=0P0?2PL0
1@0>2@H03`X7010;200@2`P04@`900804Pd:02@04@`9014;2P0E3`l02@<501D?4@0I4aD03`T;00`6
200>20X05@lA00d72@0D3Q005Q0B010:300F418040X<014;3@0D3Q003`T;00h82P0X8R@07aTK018<
3P0?2@/04@/=01D?4@0C3@d0618B01D?3`10>SX0=2h^00`61P0?2@T04P`<01TC4`0F410200d71`80
3PP:0P0?2@/3010:300S06mYJ`0L5QP04`d?00d72@0?2@/04@P=00l52P0?1P/04PL=01062`0:0@@0
50T=01892`0A20T050X;01<:2`0A20T040D901062`0?1P/040D;01062`0?1P/04PL=00l52P0G3Q<0
3`H;00d2200A1P`04`P<01D:3P0X7B4040D901462P0>0`L00P0A1PX201872`0301052@0?1PT03`P:
00<03PP:0`0>20`500h73P0`00h52@0B1`/060lB01082@0I3Q804@P;01T?4`0K41@05@`?01@;3@0I
3Q803P@70107200?1PT03PL:00`5300;1P`040`B00@01@0700L0=blc01L>4@0I41402`<501<:3@0;
00@04@P;0189300800403@<701<:3@0D2@d03@<701@;3P0E2Ph040L901D<3@0E30l03PL900/52@0?
2Ph03`XA00d:4@0<2A803@XC01<@6`0000T040`C0P0<1PP01@090`D03PP:01<=3`0;1@L030H800<0
3PP:01003PP900P3000=20D050h=014;2`0>20X03PP;00`5300<1@d03PHA00h64`0?1a@040PE018:
5@0A2A@03PHA0P0E3AP03@0>1Q401P0901dF7P0E3QH01P07014:4P0@2A403`P?00h73P0<1@`02`@;
00X32P0;10/00P0>1`h0400?20l040T@00l83`0=1Pd040H>00h4300F31@05``D00h42`0A20d03`@:
01062P0@1`X04@H:01062@0>1@PDooooo`006oooool0?00J5QL03PX;00`82@0?2``03PX;00d92P0;
1`P05A4B00l;300B3Pl02`L801DA4P0?2Ph030L;00/62P0=20`03PT=00d8300G4QH02`H:00X52@0>
2@d030L;01PC5`0?2Q004@`B00X52`0=2@h05A0F018=4`0@2a4050lE01D@5P0A318030L=00/62P0B
30d04`d=00d72@0?2@/04@/?00d72`0@2A004``C01TB6@16?dL02`@<01@=500@2P/060l@00d71`0A
2@X01P0001/E5@0F3Pl040L800l92@0@20T04@P901`F60<04P`@00D040X>00l93@0:1@P05Q0D01<=
4@0200d72`0800/52@0J5AP05A4B01HB4`0D41408AdN01LC500E4A82018>3`0X01<?400D4140510A
014<4@0B3aH01`@;04E3A`081PL05A<D010?3@0@3Pl0De5B01/I7@1NFf807AXQ018@6P0>3QP05QHO
00d<500A3QD04`lD01<>4P0?2``071XG00X;1P0B4`d04Q@>01DG500:30/03a4@010B4@0B51<0418@
00lA3P0E5a@04A<@010B3`0H6QL0418?01DG5P806adL010051DG01DF600G61/051DI01HG6`0J6b00
6a`Q01PI7P0D51/041<H01<G6P0G6Ql05QTN01LJ800K7RD06ahW0`0H6RH05P0P8Rl0;c4n02hb?@0G
6bH05QXU01/O:P0J7RT07b<^01TM:@0P93007R8^01dQ;@0O9300728`02<Y>@0R:3X061la02@[?@0N
9CD0;CA401PQ<00T;Sd201`X=P0E02Hb@00F8Rh072H_02Xf?00[>3h0BEIL06]iOP1CHVT0:CPo01h_
=P0U=Sd09CHn020a>@0U=Sh09CHm03I7CP0jBe80G6ee03E6CP0a@TX0:S]300<0;d180;D0=TM?03]<
E00gBU40;3i802`oAP0[?TH0<4=:02Pk@@0^@DL0<4=902`o@`0[?T80;D1402/n@P0[?d80<DA802m4
A`0R=SX0@UEK02Pm@P1aQH/0;d9802a0A@10EEX09cY002/mA@0Z>dD0:ca603M9DP0jCUD0<4A;02e1
B00X?D8083<i03E7CP0W>Cd07bhe02dm@P0Q=3P08SDi02Tl@P0X>d80;4190396DP0`AU<0;dE@0316
D@0fCeH0=e1G03I<F010Df80=dYI02i1D00R=D@08cI503Q;FP0_@U40:Ca;02LkB`0Y?Tl0;45B02Pn
C00lDf40>e5S02@iC00Y?e@0>4eU03E9I00`AF80>Te^0394J00nDWD0>da_06IeRP1SL800935001hZ
>00K9cD082Xf02<]=`0L9S005b0Y02L`>@0R:c806b<[01dT;00K8RX072<[01`S:@0J8BL08BH[01TN
8P0I7R406alQ01dQ8P0K7ah05a/J01TJ701=CU007b0R01dN800R8bD07b0R01/L7P0G61X06AXL01<D
5P0I6Q`051PK01<F6`0N8RT082D[01@G7P0b=cd041DK01DJ800I7BD07R8[01TM9P0R9Rl07R8[01DI
8P0O8b`06b0V01`Q9@0T:B/07R@T01dS8`0R:2P04QPH02<Y:@0L8B@04aPL01<H7P0L8BL06AhT01HJ
8`0O8bh06AdX01HJ9P0E6BD07b<_03@gAP0a=4<092Pd01LI9@0I6bL05aTU01XM9P0L7bP05aXS01HI
800G6R406QdT01XM8`0D5ah041<J01DH8@0D5b007R4Z01PJ9P0B5200418N01XL:00B5240=3I301<E
8P0F62D03Q0M028X=P0[<Cl0O8:@04M<F00L7R/04A4M01@B7`0E4Qd05Q<M01XD7P0F41X0510H00H0
5A@J02<03@`B01dL8P16AD/08B0V00L6300G5Q`03@`B01LF700O7R@061LM01TH7P0G5Q`02`X@01/J
800<2a004@lD02PV:`0<2Pd04@l@00T7200G5AP04@lB01DC600<2@l05a@K01LD700A3QL06QLP03ll
A@0D4AP05Q@I01TF700_;C802`T>01<A5P03018@5@0Y014?500@3Q<040hC00H41`0@3Q404Q0C00l=
400C4A@030X=00h<3`0;2@`04a4D00l=400A3a805A4E018=4@0C3A405@lC01LA5@0F41@04P`@00/5
2@0F41@04P`@01D?4`0H4QH06A<G00d83P0A31<04`hE014<4`0D3aH030L>01<>5@0E41L081/R00X5
300L5ah040/A01@?4`0B3A400P0@2`l09@0B3A4050lC014<400?2Ph040/?018=4@0C3Q804PdA01<>
4P0B3A404P`@01H=4P0F31805@X@01052`0B20`01`01014;3@0G4Q@03`X>014<4P0C3QD04PdC010;
4@0@2a804PdC014<4`0=20l04@`B00`73P0A31<04@`B01<=4@0F41@03PP<02@N8P0B31001P0@2Ph0
1P0@2P`04@d<014=300A2`/050`?01<83P803`@:01P040D=01L>4`0J4AL03PL>01@>4P0?2``05a<D
018=400K6A`05A0F01@@5P0100D04PlF00h;4`0W92d0c<WB02dY<@0<1@`02`@;01@=500>1`h03`T=
01<=4@0=1`/200h82P0;00/51`0>20X04PhC00`;4@0:2@h030X>014=3P0D3Ph04@`:01491`0B2PP0
0`0C2P/01P0B30`040X:00l92@0A2`/03@L700l92@8071HF00<06A<C01D?3`0C3@d01`0B30`200X4
100@01D?3`0@2PX04P`<01<=3@0A2`/050h>018<300F410071HF010:2P0/9RH08A/K01H@400?2@T0
2P@4014;2`<04Ph?0P0A3@h2010<3@1@014=3P0P71d05a<D00`82@0[9bP02P@6014;3@0?2@/0C4I8
01`F600@2P`071HH05E?D@0E3a4030H801D?4@090`D03@L901<;3P0A2`d02P4401082`0?2@/04@P;
00l72P0>20X04PT<018:3@0?2@/060lB00d5200?2@/04PT<00/41P0@2P`03`H90149300C3@l02P@5
01`C5P0B2@`03P<701lD600[82@050T=00d21P0@1@T040H901L<400<0@D03`@801@93@0900<04`/@
00l93@0:10P02`D900L11@0>20`03@L;00l93@0@2Ph04@/?010:3P0?2@d030L:01H=4P0>20`050dA
00l62`0<1PX03`P<0107300>20`03`P<0107300A2@`03`T;00d72@0>20X300h8300K00l93@0600@0
71HH04@n@00400005PhA00l92`0?1PT03@H800d72@0A20/03`P:00d72@0?1PT03`P:00d72@0?1PT0
20<501L@5`0K5AT02`D900X4200>20`03`P>00`73@0<1`/02`H:008030L=00D03PP;00l92`0?2@/0
3`T;00h82P0200d72@0F014;3@0@2P`03PP:00@0000E3a401`4100d71`0=1`P02`D7010:300@2@l0
4``C00l8400:0Pd02P8?00d54P0A2AH03`LB00d5400C2aH02@8:01<<50803`P@0P0?20l01@0>1`h0
3@H=00d63@0=1`/03`T=00804`dA01@03PP<00T31`0D3Q803`T=00`62P0>20`04@/?018<400=1`/0
3PL;00d72`0?1P/03PL;00d72`0F3A802`<800h8300A20d02`@801@>4QCooooo000Kooooo`0401dI
6P0A3@h03`/<010<3@803PX;01T05A4B00/7200>2P/06QHG00d92P0;1`P03PT=00`72`0;1PX030L;
00d8300<1`/040/?00h:3@0C3Q80HeiR03lj?P0;1PX03PT?00`73@0A31807APN010;4@0400D03PT?
00<040/A02X03`X@00l:3P0@2PX04@/;00h8200@2P`04P`@00l93@0A2Q4030L=01XC6P1@BE405@dG
00/4300<1PP040X;01PB4`0>20T04P`=00`61`0B30d02PD600`61`0S7Ah03`T:014;3P0?2@d040X>
014;3`0@2Ph03`T=018<400<1PX02P@801<=4@0B310040X>018=3`0X92D0HUiO00h:2`0H51D201<?
40804@d>0P0B3Pl0;P0C3a005Q8H018?600C41T0:RP]020N8@0<2P/03P`<010>3`0F51L02PP=01/H
7`0C41/03@dH01DI8`0O7bT04a8J018?5P0H4aP071LK01@@4@0F514030d701lR6P0>4@/04aDB018D
4P0G6AL03Q0>01@F500H6QP05ALE020R800N81h0418@014C4@0B51805QPG01LI600F61L05aPJ01TJ
700D5AT04A8G01<D6@0F5Qh201PH800901LG800E61d05aXN01TL8@0F6Al05APO01HI800K7RL061/U
00806adZ00P061XW01XL:@0O8bh05QXU01lS;P0T:3<06alZ01PL9`807B4/01T06AdX01dQ;00T:3<0
8BDa01hT<P0M8c8082He01hV=00O9cD09blm02/d@P0I8c405b<`028^>`0H9340:3A002Pb>`0L9bl0
;3U002Ld>`2:V9l0Z[S0030nB00R<c`09CHo008093A000P0:ca602`mA@0]?TD0B5UQ0<3Af00kC5@0
;d1802Xk@P80=DI>0P0^?dL0<@0b@d/0:Se403a?EP0kCUD09CPo02/nA00]@4H0:Se102`o@`0[?T80
<4A502m3A00Z?Sl0;T9702m3B@0`A4T0;D5704EIG`0aADX0;T9702m3B@0Y?D<0<dM<02Tm@`0lCUD0
<d5;0352B`0eB4l0<dM>02]2B00W?T@08cY002a1AP0oDUP0<dA;02Xi@00Z?4009c/l02Pk?`0^@DP0
<dE?03Y>F@0jCe/0<dUF0398D`0bBU<0=e1G03QAEP0fC5H00P0eB5H07`0eAeH0;3m=02XmB`0_@U00
<TAC0353DP0^@4l0;3i=02m1D00]@e40<4EE02i3E00/@E@0<dQK03Y>IP16FW<0>4aW0355HP0cAVH0
AEQh041BLP0[>TX0<Sm:020/>00T<3`072Pd01lY<`0@6R<07bTb01hW<00R:S400P0V;SH01P0Y<S/0
7BH_01dV;`0b>D40<3Lo01PO9@806AhR03d0720S020T9@0Q9BH07R8Q01PI6`0O82803a0B020Q8`0K
71h07AhP01lP8P0H6A/071dO01@E5`0E5QP05QXM01/N9@0C5b0051PQ01LK9019CEH07B4Z01`P:@0S
9c0092Pa01TM9P0Q9Bh08bL`02lc?P0I7BL08BH/02DZ;P0P9BL0:S0^06abL02RZ:D0ATa:02D[:P0M
8b<05a`O01TN8P0J7b@07R<X01HJ8P0I7BL061`V01TM:00N8Bl07R8_028U=00P8c<06Qd/01LI9P0E
5b<06adY01dP:@0H6b@05aXS01`O9P0S9Rd082<Z00805QTN01T06ahS02<V;P0I72@06QdU01DH8@0E
5b805QTS01DG900V:3D0Q8JC028T<P0?4Al06al/00hE8`0T:ST0OhJC04iCG`0;3AX05QHS01@B7@0E
4Qd05Q8K01TC700K4ad061@L00D051<I01X05QDK01LF700A41H05QDK01DD6P0A41H06APN00l>500E
51X05aHL014@5P0E51X040lE01HE6`0L6b405QDK00l>500B4AL06ALK010>400A3a405A<F018@500B
41D06QPM00`:40804PlG00P02@H>01LD7@0B41H04Q0E00`:3`0R82D05A<H014?50<04Q0E00D04@lD
010>4`0@3Q<030X=00h<3`02018@4`06014?4P0@3Q404@lB00`:3@0D4QD03`d@0P0@3Q42014<400H
01<>4P0F4AD05a4E01<=4@0F41@03PT=018=4@0A31005a8F00l:3P0B3A<0AD17024L8P0>2A007QTO
04U4BP0W8RP0G5MM02@O9P0D3aD04`hD01@?5@0B3A404@`@0P0?2Ph05@0A31004PdA014<400A3100
4PdA01<>4P0B3A403`X>010<3@0B3@l04`d?01<:3@0E2Ph05`/?00l51`0F2Ph05@`?00h82P0G4Q<0
DdiB01LB6002014<4`0501D@5P0@2a803@P>01HA5`0D3aH00P0F4AP0200;1Pd04`hD01<=4@0F41@0
1P0401@>4P0C3A405@lC1@0A2`l0:00@30h04@h>014=3@0C3`l05`hB01@93`0B1P`050L@01463@0I
3QD03PL<00d6300Z92P04`l@014=3P0?30h03P/>02DQ9`0@3A<07AXQ00h<500=2a<04Q0H01PG8@0P
6bD05a0H00h73P0D3A@04P/B010:3P0B31003`T=00l92`0B30h03PP:00`7200C3@h04`d=010:2P0?
2@T2014;2`803`T900D040X:014;2`0A2`/04@/;018<300200l92@03014;2`0?2@T04@/;00<040X:
0`0?2@T6014;2`0;01@>3P0>20P040X:00X4100A2`/071HF010:2P0B30`03`T900h8200C3@d00P0@
2PX01@0?2@T05@l?01LA4@0A2`/03`T900803`/<0P0>2P/200l;300I018>3`0=2@X04`l@018>3`0=
2@X05Q8C01<=3`0B30h05A0A03Tc=@0K5AL04P`>00/51`0X8R@05Q0B00/61`0<1PP04`d?014;3@0G
4A<03@L9014;3@0>20X03@L900l92`0200h82P04010:300A2`d03`T;00d72@803`T;00h03PP:00l9
2`0A2`d050h@010:300K5AL05@lA00/51`0A2`d05P`?00/1100D2@d04@H:01@93@804PL;00/04@H:
01872`0@1@T04@H:01@;3P0A2@h06A<G01XD600=1`/04@/?00h8300600l93@0601PB5P0D3Q806Q@H
01<>4@0J51P0=S0d1@0>20`00`0@2Pd03`T;00d72@0400h82P0:01PB500=1`T04P`>04M1@`0I4aD0
7ALI00l92`0>20X03@L900h82P<03`T;0`0@2P`02@0?2@/04P/A014:4P070PL0>c@k03@]=0060@@0
40X>00d72`0300h82P0400d72@0?2@/040X<014;3@8040X<01T03`T;00`7200?2@/03PP:01D?4@0>
20X03`T;00/51@0>20P030H800X41P0?2@/03PL>00h73`0?21005@dH01P@7@0E3AX03PHC00l74P0@
21<03PLA00d63P0>2@l04@XB00803`P?00<03`T=00h8300=1`/00P0=1`/02`0>20`04@/?014;3`0?
2@d03@L;01TC5`0E3a<04@/?010:3P0>20`030H:00H03PP<00H02P@8010:3P0C3A402`D901PB5P11
>clDooooo`006oooool00`0A3@h02PH700`82@0200h:2`0i010<3@1IEEH07ATJ00@00@0A3@h04Ph?
014=3P0?2Ph03@P<00`72`0=20`03`X>00d8300;1PX04@`@00P31`0e<3@09R4U00d8300?2Q001005
01@?5@0m>3h081/Q00h93`0A318040/A014<4P0B3A<040/A00h93@0E3a0050h>018<300A2`d03PP<
00d72`0>1`h030D<00H01P0;10`0100501D>5@0C3A003PP<018<3P080`D05Q0D01@>400<1PT0618F
00`6200I4aH03PP<01D?4`0>20`040X>00<04@/?00l05@lC00h8300E3a<03`T=00d72`0K5AT05A0B
00/7200f<S<03PX;00`82@050@803PX;010<3@0A3@h00`0B3Pl01P0F4QT061DN010=50040PP02`T<
00D31P805aDF01d020H901HC6@0:1`h05a@M010?6@0F5Qh04Q4G01TF7@0M6b006aHK01<>4P091`P0
61LF00h@3@0F6aL0314=010B4@0H6QT07AlN00/=300A4a805ALF010B4@0K7A`07R0O018D4`0C5A@0
61XI01@F5@0201LI600301PI6`0K71h05AHJ008051DJ00L051@L01DE7@0F5Qh061PQ010C6P0B5A`0
51LN00<05APO00<0:Rdf01`O:00G6R<00P0H6b@0?`0J7BH092Pc01TM:00K7bX07b<^024U<00S9c80
7R8]01dQ;00F6RD061`W024U<00R9S408RPd02H/>P0i?dd0:30m028Z=`0G7b`05b4]03<nBP0D82`0
7b/g01dY=@0H9Bh06R@^01dY<@0O;3@0:cQ002hkA00_?DH0938m02@e?`0/?DL0;3a902Hf@`0X>4D0
:CY303=4C00`@DT0@eAL02Lh@00^?dL0:S]30311B@0b@d/0;d1802Xk@`0Y>T80:ci502XmA00/?dH0
:3]202e0AP0W>T00:Ca002Xm@@0/?d<0<dM80314A@0W>c`0=TU?0354BP0202i1A`2S02e0AP0O<SP0
;3m502Pk@@0`@dT0?e9H01lb>00Z>d80<T190352BP0aA4/0;d=:02e4BP0`Add093]102Dj?`0T=cd0
:CY103=2B@0Z?4409cXn02Xm@`0_@DT0=DMA03]?FP0kD5`0=deJ03E;EP0bBE@0=DiE039;DP0_ADh0
9CM502doC@0/?T`09SQ602`nC00Y>dT0<TAB02m1C`0W>DL09CM50312D@0^@E80:d1A02]0D`0T>D`0
8CI;02e2F00W>e<0:cmH02a0F@0W>eH0<4AO03e?JP0e@U80<3a801XV<P0C7b/08Bdi01dW<@0L9Rl0
92hg01hW<00P9bl06b8Z00/B6P0C72D04Q/T01`U;P0T:c<07RD]01LN900K82@06QlS01XN8@0L8240
7B4R01/O7P0J6ad06AXL01PI6`0O828061TK02X[;@0O82805aPJ024R900K71h07AhP01lS9P0E61l0
4QHO01<G800Q9Bh03A0I01TM9P0E6B806AdV01XN9`0B5Ql07R8[024U;P0l@4/06QhX01/P9P0P9B/0
92T/0498B02]/k40jNk]05YPGP0Q9bL06AhP01DJ7@0H7B406QlS02db=P0Q9R`05Q/Q01@H8@0C5b40
6alZ01TM:00G6bL061`X01LK9`0T9S8071hZ024S;`0G6R<04QDN01hQ:P0M82L0;2lf02X]=00I7240
3a8G010C600A51T051LN01PK8P0G6R4051LN01<F7`0C5R00@dEA01LI9@0R93008bDb00D95@0H7bX0
6Al[010G8@0B5R805aTU01PJ8`0E51`05a@M01LC6P0D3aH05PlG01LC6P0501<B600T010?5@0H5ad0
5aHL01PG7@0K6R004Q4G01HE6`0J6Al061LM01@C6@0?3Q@04A0F018A5`030PP03@`B02HU:`0Q82H0
61LM010>500?3A0071XO01HD6@0G5AX03P`A02HT:@0I5a`04a0G01DB6@0C4AH04@hD00l=4P0;2@h0
518G01`J7`0D4QL061HK0`0B41D04P0A3a@040hC010>4`0<2Pd02`T<01<A500A3a8030X=01hL7`0I
5aX04@lB01<A500=2`h040hA014?4P0C3Q804PdA01<>4P8050lC01@04@`@01<>4P0@2`l04@`@01lJ
7P1IE5P06QDI01TD6P0K5Q`00`04018=4`0F4AL020<902/V;00:1P/05a8H01hI7`0A3A8061<I014<
40@040/?01@04@`@00l:3P0@2`l04PdA01@?4`0C3Q803PT=00h:2`0E41405@lA0189300C2@d06PhB
01L;3`0I3a809ahQ024K7@050@8061@E01D@5P8040/A00`050lE010;4@0<1`d03`/@06mZL03FdML0
;2L]00`73@0D3aD03`T=01TC5`0?2@d201@>4P0300d72`0B31004P`@00<04P`@01d04@`@014>4@0>
2@d040/?01@;400D2@l05@X@01@8400K41H03@@901LB5P0@2`l00`0200l;300=2@X07APK01@?4`18
@dT09R4W00/83`0500T030PA01LD7@0300T091hW01094@0:0`X040T@014:4@02014;3`0800l93@0A
2`d04`d?01PB500U7b408adN014;2`0?2@T3010:2P803`T900<040X:014;2`0A2`/00P0A2`/200d7
1`03014;2`0?2@T04P`<00804@/;00@04P`<01<=3@0C3@d050h>1P0?2@T04P0A2`/030H601LA4@0@
2PX030H600/51@0D3Ph04P`<010:2P0=1`L03PP801@>3P0I4a<05a4A01<=3@0?2@T03@L700`61P80
30P90P0=2@X200h:2`0I00d92P0<20T02`L8010<3@0F4Q<04@d>00h82P080P@040X<01<=3`0=1`T0
1`4300X41P0B30h08A/M014;3@0<1`P04P`>00l92`0:1@H040X<04M1@`0e;c401`4300h82P0200d7
2@0900l92`0@2P`03PP:00H00P0E3a4040X<00`6200A2`d03`T;00<03PP:00@050h@00L10`0J51H0
:R0T0P0A1PX06`0B1`/050T=00`11@0D2@d04@H:01052@0=0PH03P<70189300A2`l0?cTm048l@00?
2@d05@lC014;3`0B31003`T=00h8300=1`/03PP<00l93@070PD03`T=00T31`070PD05Q0D01TC5`05
00h83003010:3@0?2@/03@L900<03PP:00L02`D700`6200<1PP03@L9018<3P0400006aDG00L03PP:
00l03`T;010:300?2@/03PP:00T4200?2100100401L@5`0N5ah0100200T31`0=1`/03`T;010:300?
2@/00P0=1`T03@0?2@/040X<010:300?2@/03PP:01D?4@040000>S@f06MQH`0P6Q`030H800h8200=
1`L00P0<1PP03P0=1`T030D<014:4P0?21003@D@00l7500@21D03`LD0149500@21<02@<<01D>5P0A
2Q805@hF0P0?20l00`0?2@d03PP<00d72`0400d72`0900h8300@2Ph040X>00X4200;1@T040X>01<=
4@0E3a<04`dA00H03`T=00H04@/?00d72`0>20`03@L;00`62P0C3A4Dooooo`006oooool09@0>2P/0
2PH700`82@0>2P/03@T:010<3@1QGEh08QhO00H20`0>2P/04`l@00X61`0A31003PT=00d8300?2Ph0
40/?00h93@0;1PX04PdA00P31`070`H02`H:010;3`0:1@/05a8H01<>500K5Q`01`88018=4`0=20h0
3PT?014<4P0C3Q@040/A00d8300F41800P0E3a401`0C3@l03`T=00l93@090`L01`07014:4@0M5Qd0
0P0>1`l03P0A2Q0030D<00`62P0I4QP030D<014;3`0;10X07AHM00l93@0=1``02`@;014;3`0@2Ph0
4@/?0`0C3A40300B31003`T=01PB5P0A2`l06A<G02@N8P0F4A<02`L800D10P0G4a@0510A01DA4P<0
4Ph?0P0C3a00?`0D41404@dB01DB6`0<2A005aDK00`:3@0A3a804a4D010>4@0B41D04Q0F01HC6P0C
41T0518I01lN8`0@3Q<04@`B010;3`0C3A40:B@X00X82`0@4A803a<B01<I5`0L8b402`l>01@F5@0L
7Qd03@l>010B4@0B51<03a4@01@F5@0F61L051HE01HH5`0G6AP03a0B01DF600G61X051DG01HG6@0G
61`061TN01LH7@0F5a`05ADM01HF7P0H620051LN01@G800F6B805aXS01PK8`0F6B009BP_01TL8`0E
61l05aXQ01HI800H6b80;S8k024U;P0201TM9P0b01XN9`0M8BX0720Y020T;@0I7BH05ATR01dQ:P0R
9S406R0/01dS;`0a=d<08b/f028Z=@0K8bh05R0Z05QTK@0Z=d0072Tb01/X<@0N:c@05b4[02Da>P0U
<S/08Rlh01`Y=00X=T408Bll02@d@@0Z>TL0:SY902DeA00V=T<09SM002m0B00`@DT08C8j0393B`0X
>D40:ca402Lh@00Z>d<0;d1802dnAP0Y>T80:Ca3028e?00W>T40:Se402`oA@0Q=3X202`o@`0502e0
A00dB4T0<4A502Hj>`0Y?4800P0/?dD0=00bAD/0:3]102Lj@00U>3h0;D1602`oA@0`@dT07S4g02`m
A00a?dP0<45902i1B00/@4L0;DA:02m6C00Y@4H0<DE<03A6CP0dADd0=49;02Pi?`0^@DD0<dI<03M9
D@0kCEL0?51K03]?G@0hCU/0=TaI0358D`0aBU40;DI=02a2B`0W>DL0;Cm=02<e@`0Q<d40;T1>02Pj
B00Z?4X0:ce;02HhAP0R=480:S]:03=5F@0]?e<0;3iD02doE@0[?E<0<49H02<eB`0]?eL203=5G@0G
03A6GP0gBEl06bPh030lB00[=d<03QPT01`V<P0N:38082Tb01lX<@0P9c409B`d01XQ:@0V;CD05AhW
01HO:00I8R/061lW01@K8`0J8BL08RL[01lT:00K7b800P0I7Ah0100G6aX05aPJ01/L7P0G61X201TJ
700<020Q8`0S92H0414C01PI6`0O82808b@V010D5`0L7bH05QXS010D7@093AH092Pa0P0L82T201TM
9P0o01HJ8`0R9Rl07B4Z01XN:@0L82X08BH/020U:`0O92L09R`/05AJF026S8/0:c4a01HK7P0M8RD0
724U01TN8@0G71l0:Bha024V:P0I7R8061dS01@H800G6b@05ATR01PL9`0I7BP05QXU01@F8P0=3a/0
4aDQ01/N9`0m@4T0GF1Y02DX;`0M82L05QTP018E6P0G6Ql06ahS01`P900D5a`03Q4F00lB5`0F6Ah0
6A`S01HI8@0W:S<092L`00022`0Q8bl06alZ00/B700B6B<05ahV01<G8@021@h051DM01HE6`0H5A`0
71TP01HD6@0H4aT06ADL00L05A@J00T03PdC01<B600B4AL03PdC01LF700F5A/04Q4G010?5@0B4AL0
0P0A41H05`0V9B/06aXP07EdNP22PHL09B@Z01HD6`0D4QL0514H00P5300>2a804a4F024O900F51T0
3`dB00h<4@0L6Qd040hC02XX;@091``03P`A010>4`0610T030X?00<04Q0E01404@lD010>4`0@3Q<0
6ALJ01DC5P0B41<02`T<014?4P0l>Sd08AlR01LE600E4aH040hA01DC5P0I5aX05A0D01@?4`03018=
4@0D00h93@0E41@05A0D01<>4P0E41@0BDA800h93@0910X050lE01/F700H4aT05a8H01`G7@0N6Al0
5a8H01/F700:1@/05Q4G014<4P0A3104018=4@04014<400>2@d03`X>014<408050lC00d04@`@00d;
300D4A805Q0B01<:3@0D2Ph06PlC01H;3`0=10H02@03018<3P0A3@h061HG00D040/A00P04@`B00d8
3P0`:c40PWf3010<4@0J5A/061<I014;3`@050hB00<02P@8018<400B31000`0B3100:P0A31004@dC
00/6300>2@l04PP@01<83P0G31804`T>00l42P0=10T04@/?00/7200F4Q<02`H901H@500X8RH02`D9
02`U;00C31<02@@;00T22P0E3QL02P@>00L02P080`X030D=00h73P0@2A003PL>00l93@0B31005@lC
01LA4`0<1PP0100000L10`0C3@h03`T900h8200?2@T04P`<014;2`803`T900<040X:014;2`0A2`/0
0P0A2`/200d71`03014;2`0?2@T04P`<00@040X:200?2@T04P0B30`02@<3010:2P0;1@D030H601D?
3`0A2`/03@L700l92@0>20P02P@4010:2P0C3@d04P`<00h8200=1`L040X:01@>3P<03PX;0`0?2``0
4P0;1`P040`=00d92P0>2P/05A4B01<?400G4A<040X<01PB500>20X04P`>00l92`0@2P`03`T;01D?
4@090`D030L8010:30804`d?00<0;BLY06aVJ01@BT`00P0>20X200d72@0A00l92`0@2P`03PP:00`6
200J51H050h@00l92`0C3@l040X<00/51`0G4A<030H8014;3@070@<04@/=01P?4P0=10L00P0A20/0
100E30l03`H901/B5@0L4aH201072P0C01D<3`0?1PT04P`@03La=@0k=CT03`T=01H@500>20`04P`@
00l93@0>20`03@L;00h8300?2@d06A<G00d72`0N61`030L:00L11@0600h83003010:3@0?2@/03@L9
00<03PP:00L03@L901LA4`0?2@/0208402<M7`0=1`T02@@500D03PP:0P0=1`T300h82P0<00d72@0=
1P`05PlG01/D6`090`T03`P?01`F6P0?2@d03@L;00l92`0A2`d03`T;0P0=1`T300h82P0;00d72@0<
1PP03PP:00X41P0;1PL050h@00H00P0A2`d03`T900d71`0=1`T00P0?2@/03@0<1@`04P/C00h73`09
0@`02P8?00d54P0@21D02`<>018:5@0@21<02P<;00L0200=1Ph00P0?20l00`0?2@d03PP<00d72`03
00d72`0400`62P0=1`/03`T=014;3`803PP<00@03`T=014;3`0?2@d02P@81P0?2@d01P0@2Ph02@<7
00h8300D3Q8040X>00T31aCooooo000Kooooo`0A01<?400?2``040`=00h:2`0:1PL03@T:018>3`09
1@H030P901DA4P0U8B803@T:010;3`0=20`030L;00h93@0?2Ph00P0=20`01P0@2`l04`hB00d9300D
3a<030L;014<4P803`X@00/04`hD00X62`0@2a4040/A00/6300<1`d04PdC014<4P0?2Q003`T=014;
3P0201H@4`0M01<=4@0E3a<04`dA00`62`0F41D06A<I01@=5@0>1`l040TA02dV;P0L5Q`04@/B00P1
200D3A@040TA018;4`0A2Q804@XA02PQ:00D3A<04P`@01<=4@0D3Q804`dA018<400C3A404P`@014;
3`0B31000P0A2`l0200@30h06ADF00l<300@30d04@d>01hJ6`0@30d04Ph?0P0C3a0201@@4@0U014>
4`0=2Q405Q<J00l=4`0?3A806ALK014?4`0<2Ph0518G00h;4@0J5ad04@hF01<A5@0/9bL08A/N01/F
6@0H4QD09b8V03hi?P0I6A`05ALJ018I700A6Q`092h^01/O8@0A4a<051HG014B5@0B4a@05AHH01DF
6@0C51D04Q@E01HG6P0G61T04a@G00l@4`0201@E6003014B5@0E5QT06AXN00<05aPM0P0G5ah01`0G
61l07R4[01`O:@0K7RP071lX01XM9@0E61l00P0J7B<201lS9`0k01XN8@0J7R806AhT01PL9@0J7RL0
720Y01lS;00M8BX0720Y01lS;00N8R/082@]02@X<@0P92d09Rdg01dT;`0M8bh07BH`01`U;`0N9c40
82Xc02Hb>P0G92d082de020]=P0L:C40:cDo01LR;00W<ch05B4]038oB`0O;CT0:3I302De@`0R<T00
8C5002@dA00W=dD09SM102Pi@P0Y>T<0:3U202Lh@@0X>D80:CY302Df?`0V=d00:ca502dnA`0[?4D0
9SU002i1B00aA4/0:3]202Tl@P0T=cd0:ci202`o@`0[?T800P0_@d@0D@0Z?Sl0:C]203A6C@0^@4H0
<TA;02Li?`0mCeH0<dE;02Xl@P0]?dD0:Sa302Tk@P0]?D@0;ci602dnAP0/?dD0:cm502U0AP0X?dD0
93]102@h?`0^@DT0;Sm802Pf@00W>400;T5503A7C@0eB500>D]G03U<FP0fBeP0=deK03M=FP0bBED0
<TYD02i7CP0X?DL0:S]902HgA@0L;C/07Rlm028c@@0P<Cl08S=002PiA`0/?DX0:3U602<d@`0_@5@0
;3eE02TjD00a@UP0=TMN02hoE00_@5D0<49E02XkCP0mCV00=dUK024b@`0[>4D09S4m01/V<P0oBED0
>D=?01TR;@0K92d072D^01`S;@0I7bL04QPP03a2B`0_>4408b`e01/T;@0P9bl07bH^01`S:@0T:Bd0
82DY01XN8@0201TM7P1E01TM700I71d06Q`O01`O8@0L7R407B0R01<F600A51H0<38e02d`<P0F6A/0
7B0R01hQ9@0K82H04QDN01PL9@0S9c005a/T01dQ:P0P92d0720Y01/O:00H72D082@]01LK900K7bX0
92Pb01/P9P0E6Qh06b0S01/Q8@0F71/0:c0a01dS900M8RH092T^01XO900K82@05AXM01LL7`0F6ah0
724T01TN8@0I7R<05a`Q01@I7P0H7B<06AhU01@I800H6RD07Al[01hP;00I72D071lX02HY<P0G6R40
5APO01LJ8@0K7R<06A`Q01HI7P0F6Qd07R8T01`P8P0O8bL0720T01XN8P0G6R005QTO01DH800L7bL0
2@`D010C6`0F6b404QPO014G700D5ah05QTO01`N8`0C51P03`hD01LE6P0D4QL0510F01HE6P0601DD
6P0<01<B600@3aD07A`R01DD6P0=318051<I01HE6`0@3aD06APN02DT:P0M72805aHL0P0D4aT04P0b
<CL0<2le01PG7@0B41L06AHN01PE7`13@4P05Q<J01LD6`0A3Q@040hC01@B5@0=2`h071XL00h<3P1D
DUH071XO01XH7@805Q@I100B41D0200A3a@040hC010>4`0=2`h04Q0C01DC5P0?3A003P`?0P0F51L0
0`0=2`h040hA00l=400201DC5P0301<@4`0B3Q8040`@00804@dA01@03``?010=400=2Pd04a0C00`8
300A3Q403``?00l:3`0B3A805a8G01<>4`0B3Q8050lD014<4@0F4QH02PH:00l:3`0C3Q<061<H014<
40@04`hB01@04@`@01<>4P0@2`l03`X>014<400B3A404@`@00h<3P0B3Q404Ph@018<3`0D2Pl05P/@
01062P0L4QL03`T<018>400@3@l03@/>00l:3P<040/@00`04@`A018=4P0D3a@050lD00X62P0K5Q/0
61<H00X62P0D3Q803@L;01/E6@0?2@d2018<40D04@/?01h04@XA010;4`0=1a005@hF01H<500C20h0
5``B01P?4`0n=CT06A<F00l<3`0?3@l02PP:01D@5@0@2Pl04P/A00D0100C31<03`P?01/C6`0:0@X0
5PdG01484P0B2A<040PA014:4P0D3A@04P/B00h73P0?2@d2014;3`0500l92`0<1PP05a4C038/;P0]
9bP00P0>20P00`0@2PX04P`<014;2`0200l92@05010:2P0A2`/04@/;014;2`0B30`00P0?2@T00`0A
2`/03`T9014;2`03018<3003014;2`0@2PX040X:00H040X:01804P`<00`61P0L5QH0618B00l92@0<
1PH05@l?00d71`0H4Q8081XJ01@>3P0@2PX04P`<01D?3`0C3@d03`T9010:2P0<1PH2018>3`0>014=
3P0@30d03`/<00h:2`0?2``040`=00l;300<20T03@T:010<3@0A2`d040X<01D?4@0<1`P300h82P0<
00d72@0A2`d050h@00d72@0B30h040/<00h92P0:1@H06Q@F01/E5`0B30h03PP:0P0<1PP01P0>20X0
3`T;00d72@0>20X03`T;00h82P8030H800@03@L9018=3P0>20X02P@60P0?2@/03`0;1@L03`H901<:
3@0E30l040L:01@;3P0?1PT05Pd@01XA500>1@P03`H90189300;0PD040X>00`62P0200l93@0301<=
4@0:1@P03`T=00D03`T=00H02`H900d82`0>20`07ALK03La=@0J51P500h83003010:3@0?2@/03@L9
00<03PP:00P03PT:00`6200?2@/05@lA00h92P0<1PP04@/=00h82P<03`T;00d03PP:00d72@0=1`T0
3PP:00l92`0>20X03@L9010:3`070@P03@H=00h73P0:0`X05Q0D00803`T=00L03`T;010:300?2@/0
3`T;00h82P0=1`T03PP:00803@L901T030H800P3100D3Q0040X<00h82P0<1`P03PT:00l92@0;1@D0
40X<01LA4`0D3Q003@H=00h73`0=1Ph040PC018:5`0A2AH03@DB01@<5`0;1@h040TC01XC6`0k=3`0
614I00803`P?00@03`T=00h8300=1`/03@L;0`0>20`0100=1`/03PP<00h8300>20`200d72`0300l9
3@0>20`02P@800L03PP<00D040X>00h8300;1@T03@L;014;3`0Dooooo`006oooool04`0<20T02PH7
00d92P0<20T02@D600d92P0A3@h05a<D00h:2`091@H0920Q00l;300=20`02PD900T4200;1PX030L;
00X52@0?2Ph00P0;1PX03`0D3a<030L;010;3`0>2@l02@@:01<>50080`T03@P>00h93`0S7R@04`hD
00d83P0?2Q0040/A00l:400200h8300F01@>4P0B31003PP<014;3`0H4QH02@<701@>4P0>1`h04P/B
00/42`0>1`l0WIJN08R1R@0E3QH030D=01<<500H4AT040TA01<<500A2Q80FeAL030Y<0<04P`@00<0
40X>00l93@0?2@d00P0B31002@0F41@01@0302@N8P14?d403@T:02HR8`0C3a003@T:018>3`03010<
3@0U014=3P0B3Pl04Ph?018>4`0O72<0IVAY01XH7@0H5Q/04a4F010>4`0?3A803@/@01lM8P0@3Q<0
40dD010<3`0N61P030H6020J700O6A/05Q0D01/F700F5AX051LK014I7013CDl0]/3403Xm@P0L7B40
4A8F018C5`0?41@04a@H01DF6P0C51P05QLK01PI7@0201LH700C01XK7`0H6Ad04a@H01LH700O82@0
7QlS014B5P0B4aL05AHK01HG700G61d05aPN01TK9`0G6BH05aTU01XM9P0J7BD05QTP01PK800201HJ
7@0501@H6@0E6AX07b<V01lT:P0N8R/00P0I7BH201`P:@0601lS;00K7bP082@]02hb>`0b=Sl07b</
0P0H7bT08`0F7BL0:34j01dV;`0M9Rl051hW02@_>00R;cL06bP`024^=P0S<3P05AlY02/f@@0O:cL0
82`h02<`?00V=4408S0m02LgAP0V=TD093A302DeA@0U=D@09SI202XkA@0dADl08c@n02`mA`0K;3H0
9cQ202`mA`0Z>dD093Do02Lh@P0]?TP0<TE<0080:Se402L0:Ca30313B@0Z?D<093Lk02Tl@00W>Sh0
:Sho02m3A00^@T<0:S]203M8C`0Z>d80;d1702Xk@P1EIVd0?TmF02Tj@@0/?D@07c0g02/l@`0V=Sd0
9cHm02Hg?P0Z?D<0;T=802a3B@0W?T@09Se3020d>`0dAdl0=4E?02Hd?`0/?D@0;3m50313BP0_@T/0
=TQD03U<FP0eBEL00P0eBeT0F00eC5P0=dmI03A<EP0Z?TP0<41=02Hf@`0U=D80:c]801`/>@0Q<Ch0
9CE202<c@00U=D80:c]802hnC00]?540A5A[04EEK00X=dh08cA802TiC@0W=TT0;Sm?02@eA00_?dh0
9CM301`/>@0O:cL04adY02dg@`2MYk<0I6ij028Z=@0I8R/06R</014H8P0L82T07b</01hS;00Q:380
7BH_01hW<00N9Bd06B0X01LN900I7R805Q/O01<G6P0E6AX06AdN01dQ8@0F6Qd092P[038f>@0K7b80
3A4D01XN8@0D61/0;C4d02HZ;@0O8bH0;S8e014D6@0C61h06alX01lS;0072a@07R8[01dQ:P0I7BH0
7R8[024U;P0J7RL08RH_01hR:`0H72L06alW01`Q9`0L8BD06AhQ01@J6P0L8R806R0Q01/P900<4AD0
6alW01TN900E6Qh401TN8@0J00/@4`0F6al061dQ01@I7@0F6al06b0T01XO9@0J72L061XV01@F8P0J
7BH071lX01PK900K7RD05QTP01@G7P0E61d05QTN01HJ7@0M8B<07b<T01@H6@0F6Qd051PK01<G6P0B
5AX201dP9@803a8I00d04A@K01LL800?51P04AHJ018E6P0K7R<09RP]02DV:P0F5AX06ALL01DC600C
4AH05A@I00D04a8H02@051<I01LF700B4AL051<I01HE6`0A41H051<I01TH7P0@3aD071/Q02/Z<00I
61h04A0F018A5`0;2Q004a8H01HE6`0;2Q004Q0I01DB7@0=2QD0LVmi010=5P0C41L061DK01LE6P0J
61/02`T:018@4@0F51@05A<F0040100R82D02`T>018@5@0C4AH3018@5@0@014?500@3Q<040hC01<A
500B41<030X=01@B5@0U8bH0928U00d;3P081PT0518E01TG6P0L6Qd0518E00d;3P8030X=01L040hA
018@4`0B41<03`d@01<A50091`X04Q0C01<A500:20/03`X>018=4@0300807QTM01TD600300805a8F
01<>4P0;1PX050lC01D@500=20`03PT=010;3`02018=4@04010;3`0>2@d06QDI01@?4`803PT=0200
3`X>00h93@0=2`h030T<00d8300@2Ph04@T>0146300F2a404P/?00X4200B3A404@lB01DC5P0D3a<0
3@P<00l:3P0D3a<04@`@00`72`0=2@`01`8601@?4`0=20`02`H:00l:3P0A2`l05Q0D038/<00B3100
3`T=01H@50D040X>01X040T@00d74P0C2aH08AXR01lE7P0B1`d04PT>00h62@0R71h01`8600T8300@
3a@05QDJ00X7300@2a405@hE01@=500:0`X05PhE00/12@0F31D06A0H01P>5`0F31D050`D01094@80
30D<00/04@XA014;3`0=1`/02`D900l92`0E3a403`T;00`6200?2@X040X:00l92@02010:2P803@L7
00<03`T9010:2P0A2`/00P0A2`/01@0B30`040X:00l92@0A2`/03@L700<03`T90`0@2PX00`0A2`/0
40X:010:2P04010:2P0@01D?3`080P804P`<00l92@0;1@D05@l?018<30090`<06aDE02XT900H4Q80
2`D501`F5P0N61P05@l?00d71`804@/;0P0C3a007@0A3@h03PX;00d92P0<20T04@d>00/7200@30d0
4Ph?00l;300D41403@L901<=3`0D3Q002`D700l92`0@2P`02`D701PB500h<S@0B49401H@4P0@2P`0
1`4301<=3`0I4aD030H800d72@080P@03@L9008030H801003PP:00l92`0=1`T050h@00/51`0A2`d0
4`d?00l92`0F4180EDmA01XD5P0@2P`02`D701<=3`0>20X03`H90P0A20/02`0=10L05@`?01482`0@
1`X04@P;01D<3`0A20/03PD801@;3P0<1PX040X>00803PP<00X0208600h8300=1`/03`T=010:3P0A
2`l040X>00l93@0=1`/04@/?0P0F41@00`0S7B40100200h8300400h83003010:3@0?2@/03@L900<0
3PP:00/03`T;010:300=1`T02P@600l92`0L5QP030H800d72@0?2@/040X<00l92`0200d72@803`T;
00d040X<00l92`0?2@/02`@:01<<500?20l04@XA018;4P070@D03@L;00l93@0?2@/03PP:00H03`T;
00@03PP:00d72@0@2P`0618D0P0@2P`0500=1`T040X<00h820090`<04P`>01dG6@0G4A<03PL>00l8
400>1`l03@D@00h64`0?1a@03PHC00T1300E3AP0<RXe00`53@0e;SH07QLO0P0?20l0100?2@d03PP<
00d72`0=1`/400h8300500`62P0:10P04@/?00h8300=1`/00P0>20`00`0;1@T03@L;00d72`0500d7
2`0500`62P0=1`/04P`@018<40080PH05?ooool001_ooooo01805Q8C048n?`0D4140510A010<3@03
000020@500d92P0?2``02`L800`82@0H51D03PT=018=4@0I51P05a8F00`82`0<1`/200l:3P0D00<0
0P0C3Q8040/?00/62P0<1`d02PD;00/6300?2Q004PdC01<>500f<CL07APN00l:400910X06QDK00X5
2`0C31<04@XA0109400?2@d200h8300B01D?4`0?2@d03PP<018<400D3Q804``C01@=5@0R6b<07QLO
01094@0>1`l05@hF01@=5@0<1@d05@hF00d63P0A2Q8040T@0P0F41@200l93@14018<400C3A405a4E
01TC5`0>20`071HJ02hX;01:ADP05a<D01<?400<20T04Ph?01DA4P0A3@h03`/<00h:2`0@30d0510A
01LC500D4AD03@/@01/I7P0P7R<030X?00d:4@0B3aH0514H01HD6@0E4aP03P`A00l=4P0C3a005a8?
01PC400B30`040X:01D?4P0G4QP07ahS01DH700R:Bl0MGj30>K`m011A4T03PlD01/L8@0>3a@02``A
01DF6`0>3a@02``A01DF6`0D5AX0414F01XK800B4aP04a@I01PI7P0E5Q/0414F01LH700B4aL06a`P
01dN8P0D5AT06a`P01DF6`0H6b@201LI9@0:01HI8P0G6R8061/R01hQ9P0K7b80720Q00hB4`0M8B40
6alP01XO8`D06QlU03<061dS01TN900J7bD0<cPn05eRJ00J7bD05A`T01/R:P0P9bl08BXa01lX;`0K
92/05B0V01TU:`0J9bd072T_01dZ<00I9Rh08bdg02Ha>`0R;cP07RXf020]>@0W=D009SA1024a?P0O
;c`0830o02@d@`0U=D@0:3Q4020a>`0R<cd0:3U302<d?P0M;SP0:ca603=4CP0eAU00;Ci803=4CP0[
?4H0:ci502m2B@0Z?D@0:3]202Lj@00S=S`07c8f03Q;C`0Y?4000P0_@d@00`0X?3d0;Sm602`mA003
02Xk@P0U02/l@`0mCUD0;Ci502Pi@00R<cX08c@k02De>`0Z>Ch0<49602`oA00[@4D0<d]?03I=DP0U
?4809c]402XlA`1_Oh`0EfEb02XkA00Z?D<0EfYa02`nB00mCe/0>DaJ03U=G@0nE680=TaJ03Q?G00a
BE<0=DeG02XnB@0]?DX0;cm<02XjA`0R<Sl0830m028b?`0202<c@01/024a?P0S<d00;3a:03E4F@0_
?UD0=dEK04mKL@0]?4l0;Sa>03I3E00^?Td093<o01l]>00`@D/09S@o020/>00/=T807bTe03@lB@0W
;c`07B<_01lV<00C6R@06AdX02da>P0N8R/0JVmh02lf@00T;CH07RL`01lV;P0K8RX072<Y01lT:00N
8bL06QhQ01PL7@0L82406alO01HK7P0G72005Q/O01@I7@0C61`051TM01HK7`0J7b<0314E02X_<`0c
>3`05Q/O00X?5@0I7BH05a/T02@X<@0K7bP0RXjG01hR:`0G6b@08BD^02DY<P0M8BX07b</020T;@0N
8RX05AXP01HK7`0M8RH051TL010E600J7b<051TM01lT:P0H72D06AdV01DJ800I7R80724U01PM8@0B
5a/04AHJ01PM800F6ah06AhQ01LL7`0D6A`05a`P01LJ900H6RH05ALS01@G800N8BX05QTR01LJ8@0C
5Qd04QDL018E6P0D5a`05ATL01`P8P0>4Q<03A4B01/O8P0;3a8092P[01HI7P0B5AX010L<0P0I72<0
4`0@4aX061`P020T9`0G6ah03A4D00l@500K72003PlD01/L8@0I6Al04Q4G01PG7@0;2Q005QDK00X9
3`0D4aT05A@J01hM8`0B4AL00P0I61h02`0<2a4071/Q010?5@0G5Q`051<I018A5`0Y:2h03`hD010?
5@0D4aT05A@J00803`hD01d06QTO01LF700>31D06AHQ01PE800F4ad05a@M018?5P0C41H07A/P01LE
600B414061HG00`;2P0<2Pd05A<H010>4`0N72408R0U00h<4@0G5AX02PP=01DC600W9BX0;2X_00h<
4@0<2Pd03@/>00l=4003010>4@0300`:3@0=2`h03`d@00<040hA00h02@L:00h<3`0G5AP01@<601`J
7@0>30l030X=00l=400A3a8040hA01@B5@0K6A`04@`@01<>4P8050lC02h05A0D01@?4`0@2`l040/?
00l:3P0>2@d040/?01@?4`0I51P04@`@00T4200O6Qh02PD9010;3`0K5QX05a8F00X52@0J5AT07aXN
00d830071@P0410B01TD600<1PX06A4F01@;400A20d05@hB00h8300A31005A<F01HD5`0;1PX08ahR
014<400o>Sh02`H:01<>4P0@2`l03PT=01HA5@0>2@d050lC00/62P0C3A404@/?0`0@2Ph2014;3`80
4P`@02`040X>014;3`0B2a8040XF018:5@0C31@05@/D01D<4@0E30l04P/=01<=4@0B3A403@dB00l@
5@041@X02@H=01<@5`0A31<03@P?00X52`0H4QT07AHM00H01017?4@0;24Y06]PJ00E31@05@hF01<<
4`0A2Q40204800P21P0D3Q8030H:00d72@0D3Q003PP:00/51`0>20T04@/;018<300@2PX03PP800l9
2@804P`<00H03`T900d71`0=1`L03PP8014;2`0=1`L2010:2P04018<300H4Q802@<301<=3@<03`T9
01L03@L701<=3@0E3`l04@/;00h8200A2`/040X:00X4100A2`/04P`<00X4100<1PH04P`<010:2P0?
2@T03@L700`61P0=1`L040X:018<300?2@T03@L700h82002010:2P0D018>3`0K5aP02@D600P41@0A
3@h04Ph?00D10P0:1PL04@d>00`82@0A3@h020@501/E5`0@2P`03`T;018<3P0@2P`03@L900/51`0D
3Q0203Tc=@1501@>400;1@L04@/=00d72@0A2`d0100002dW:@0A2`d03`T;00h82P0@2P`03@L900T3
1@0=1`T03PP:018<3P0C3@l03PP:00X41P0C3@l081XL01@>400=1`T040X<00l92`0<1PP03`T;00L1
0`0>20X04P`>014;3@0H4Q@04P`>01TC5@080P@03@L9020J700;1@L02`H9018<400:10P03`T=00T3
1`0?2@d04@/?00H0100:10P02`D900d72`0D3Q803`T=00h8300?2@d04@/?00l93@0=1`/04@/?00`6
2P080PH06A<G01lI7@0@2Pd03`T;00@0000b;2h01000014;3@0?2@/03@L900803`T;0P0>20X02P0A
2`d01P0200P2100A2`d030H8010:300A2`d03`T;00h82P0=1`T200/51`0=00X32@0;10`03PL>0109
400?20l03`T=00h8300=1`/03`T;00d72@0:10H030H800h82P0200l92`0900d72@0>20X04P`>00/5
1`0:10H03@L901@>400C3@l03PP:00802P@40P0?2@/0400;1@L03@H=00h73`090PX06Q8M00@02@0@
21D04PXG00X23@0>1Q4050`G00X32`0600L0:B8Z01dF7@0H4AP2014;3`0:018<400A2`l02P@801/E
6@0<1PX04P`@024K7`0400803@L;00h830803`T=00P03PP<00d72`0>20`04P`@00T31`0<1PX05@lC
00d72`8030H:0P0=1`/200h831Cooooo000Kooooo`0I00h:2`0n>S/03`/<018>3`0>2P/04@d>00h:
2`0<20T03`/<01<?400?2``01P8300h93@0>2Pd03`/>00X52@0D3a<020<7010;3`0=20`061<G01@?
4`0C3Q804PhA014<4P0200d83P0I010;4@0?2Q003@P>010;4@0<1`d04PdC014<4P0I51X03`X@0109
4@0?20l03PL>00h83@0>20`03`T=014;3`0?2@`04@/>01<=400A2`h03`T=0109400B2a<04``C018;
4`0201094@06014:4@070PP07aPP00l84019@TX05a0F0P0D3Q803`0@2Ph04`dA018<400A2`l03PP<
014;3`0C3A405a4E00/62@0J5AP061@E01DA4P0@30d05A4B01HB4`0201DA4P1101@@4@0B3Pl04`l@
01@@4@0D4A<05Q@H00l=4P0?31805A8H010=5@0C41P040dD00h;4P0@3Q@040hC01@B5P0G5AD061@A
01TE4`0C3Pl04@`=01D?4`0D3aD04A0E01HH7@0?5AX08BX^04YCF00H6b805QHM01LG7P0G61h03`lF
01@D6`0U9B`0NWZ101HF7@0L7B<06Q/Q014B600F5Qd06ATP01HG7@0D5AX061TN01LH7@0H6Ad0824U
01lP8`0E5QT06a`O01@E6@0H6b<05aXR01LI8`0F6B405aXP01PK800L82<07b<U01LK7@0D61T06AdM
01XN800H7B400P0I7R@0300J7bD06b0V01/P9P0H7B<07R<Y028W;@0F6b407R<Y028W;@0J8BP07B@[
020W;P8082T_00l07bP^01hY;P0M:Bh06bT]01`Y;P0M:Rl07BX`01XU;00P;3@08Bhg01l/=00N:cD0
82hh028`>`0Q<Sd00P0R<Sh0L00P<3h07bll02@d@00R<ch0:3Q40352C@0_?d/0:CY502/kA`0S=3l0
9CE102hoBP10DE`0?TmI02XmA00]@4L0:Ca302Pk@P0W>T0093Lm024d>00]@4@083<g0314A@0T>3T0
<dM802Ph?`0Z>T40;3a302Xj@@0U=C`08c<j02Ph?`0Y>D00;3a302De?00S<cX09SDk04iMH@1UMgX0
AeYN02i3A`0]ADT0:T970358CP0/@4T0?e5L0;g=e`2AWZd0;Si802Dh?P15F5l0;d5<03E7E@0aA5<0
>DeN03aAHP0cBEP0=diK03YBGP0lE5h0:Ca702lnBP0b@Dd0;ci:02Lf@P0U=4008c8n024`?00P;c/0
7Rdi01l^>P0V=D80;3Q:02TeBP0_>dl0?d]N024^?P0S<400;3Q7024^>P0T<C/082df028`>00K:340
6R@`05YSL00lAE804QXW01hV<`0H7RX08BLa020U<00N8Rd09RTb08F9TP2RYZl0:S4k024Z<`0J8b`0
6R4Y01PO9`0I82H07B8V01lT:00K7b804aLH01@H6@0F6QX061dP01TN8P0H7B4501LL800901hS9`0T
:Bd04QLK01/P900J7RL06alX01<G800S9c005a/T00808bL`03405a/T01XN9`0K7bP05a/T01dQ:P0S
9c007B8Y06ebN00K82@06AhQ01dR9@0L8BD06b0U01hS:@0K7bP04aLS01@H8`0C61l0724W01HK800E
6R006b0U01XO8`0I7R405a`P01/P8`0H7B005AXM01PM8@0H6bD07R0/01/M:@0D5b007B0Y01LJ8`0I
72<05QTP01DH7`0E61d05aXO01PK800J7R4061`N00lC5@0@51P06QhR04A7B`0R9B/05QTO00<05QTQ
03T071lV014D600B5AP041<F01LJ7P0A4QL05ADK01DF700B4QT051@L01HE700@41T06APN00D42P0M
72804a8H014@5P0I61h05QDK00d<4P0E51X04a8H01LF700?3Q@05aHL01TH7P0E51X04Q4G00d<4P0M
72804A0F01@C6@0A41H061LM028Q9`0L6b404a4H028O9`0P7BL061DM01@A600?31<04a4F010>4`0B
41<02@L:01HD5P0A3a4040hB01<A5P0@3Q<03P`A00d;400C4AH03P`A01HD6@0A3a@00P0E4aP01`0>
31404a4D01<A500B41<04@lB010>4@0?3A000P0@3Q404@0A3a8040hA00l=400>30l02`X<01`K7@0;
2Pd04Q4D01DD5P0=30h04Q4D00l>400<2`d03Pd@010?4P0?3A003PX<008040/>02l040`>00l;3@0?
2Pd04`lA01@?4P0A30l03PT<00h:300@30h03PT=01@?4`0I51P02PD902@O8`0=20`01P8501<>4P0B
3A403@T<024L800C4A@051<G02TW:`0?3A405Q4F014;400E3A<03PH<010:3`0L5a`05A<G081oPP2<
S8h06aPJ00T51`060P@05A0C00T41`0M61/030P:01<?4@0B3Q003PX<010<3P0?2`d04`dA014;3`03
010:3P0`014;3`0C3A4050hB01@>4P0B31004`dA01@=500?2A@04@TD018;4`0E2a8050/>01@;3@0B
30h04PlC00X83P0<3QH02PhH03i2C00U9Rh030/B010?5P0A3aD02@L=018=500F41H03PH<01093@0I
3aH09adT018:4P080PT02`@;014:4@0=20d04`dA01@>4P0A2`l04@/=01H@4P0A2`d03PP:00l92P0A
2`/04P`<010:2P0>20P03`T90P0B30`0200?2@T03PP800d71`0>20P040X:00`61P0A2`/040X:0P0>
20P04P0E3`l03PP800h92@0;1@D04@/;00l92@0D3Ph03`T9010:2P0E3`l04P`<00h8200A2`/040X:
00d71`0A2`/05Q0@018<30804@/;00D040X:00l92@0@2PX04@/;010:2P0200l92@0@010:2P0A2`/0
3`T901<?400710@04`l@00/7200B3Pl0:BDV055=CP0T82402`L801<?400=2@X0510A01PB50804@/=
00D04P`>010:300A2`d050h@00d72@0201<=3`0H00d72@0D3Q002@@501XD5P0H4Q@030H801XD5P09
10D04@/=00l92`0A2`d03`T;00h82P0D3Q004`d?00`6200@2P`050h@018<3P0>20X04`d?00h82P0:
10H03@L90P0?2@/0500B30h040X<014;3@1:A4H0V9:D03D_<@0A2`d04@`=018<3P0=1`T06Q@F010;
301RG6006aDI018<400>20`02P@8014;3`0>20`04`dA0P0=1`/00`0A2`l03PT<00h8300200d72`0=
00l93@0>20`030H:010:3P0>20`02P@801@>4P0J51P04P`?00L10`0T7R00SXR:02dW:@0200`62003
00d72@0?2@/03`T;00803PP:00X03@L9010:300C3@l02`D701/E5`0P6Q`040X<014;3@0@2P`03`T;
0P0>20X0300<1P/03@H>00l83`0?20l03PL>00h8300?2@d03@L;00d72@0A2`d04`d?00l92`8030H8
00@03`T;010:300?2@/03PP:0P0@2P`06@0>20X020<4010:300?2@/06aDE018<300<1PP03`T;00h8
2P0>1`h040/A01<=500=1a0030DA01D=6P0=1A805@dH01L?6P0E3AP02`@<00T32P0@2A404@XA0109
400>20`0100=1`/01`0f<3@0;bT]00l93@1<ATX050hB00d72`0>20`00P0?2@d02@0>20`03@L;00l9
3@0Y8bL07ALK00H1100910L0618F00h8300300l93@8040X>5?ooool001_ooooo02D081`M00H20`0K
5aP0JVIW03Da<P0C3a002`L801<?400=2@X020@500h:2`0H51D02`H:018=4@0k=SX07QTM00P41`0;
1PX04PdA010;3`0X8bL0F5=G05iIG@0E41@03`X@00`73@0>2@l04PdC014<4P0?2Q0050lE00l:400C
3Q@040/A01<>500G4QP03`P@00803PL>00@03`P?010:3P0@2Ph03`T=0P0?2@/06`0@2P`03`T;00h8
2P0?2@d03@H=00l93@0C31804P/B010:3P0A2a00204801H@50090`P0=2dd018<400C3A404P`@014;
3`0D3Q8040X>00P21P0<1PX05@lC010:3P0;1@T01`4500d82`0201DA4P80510A03L05A4B01LC500F
4Q<0510A01<?400B3Pl04`l@00h;3@0C4A@08AlT05AAE`0a;SD01@8;00d:4`0;21404PlF01@B600;
2@`03`d@01DD500C4a405QDC01DA4P0D4140618F01/F700<2Pl04a<I01<F6`0D6Ad041LK01/N9@0G
5al030`D00L73`0H62005ADM01HF7P0a<CT05ADM01PH800A4AT06a/S01@D700I6B40410H014B5`0N
7b@061TN018C5`0H6Ad06AXL01<D5P0K71h05AHH00805aXO00/05QTN01DH7@0G6Ql05aXO01HJ7@0O
8bH04QHI01`P8`0I7Al07R8U01TN8P0301TN908061dS00H04QLM020U:`0M8RP09b`b01dR:00I7R@2
01`S:@0A01dT:P0M9R/07bP]020Y;P0T;c<06bL[01LU:00J:2/07R`_02<a=00J9BT07RX_01h[<@0M
:S006bT`01`[<P0R<3P00P0R<c/01P0R<c`07c0j01h_>@0S<d00830m02@d@@80:SY700/09SI301d]
>P0W=d@0:CU602PhA@0eAE80?DiH02XmA@0[?TD0:3]202<f?@02024d>P0=02<f>P0Q=3P09CPl02i2
@`0U>CX0:Cdn03=2B@0/>d80:CPo02Pg?P0/>d80;ci502Lf?@02020_=P11028a>00S<ST08c8f02Lf
>@0S=CL093Pj03M<C`0dC500;TI;02i5B`0^@T/0=DMB03i>F`0e@U80;Si901ha>00X>T@0838n02`n
C00^@E80?e=T03E:F`0fBe`0EF]j02e5D@0T?4P0:3a6034oBP0fA4l0=49=02`jA@0Z>4<09C<n020^
>@0N;3L072Xe01d[=P0P;SX08blo02Da@@0[=dL0=41@01dY=`0R;S/0;CU504UEH@18EEh06RL_02<`
>00R;SH08BTf01`T<@0B6RL07bLd01LO;00D6RH01PXE02@X<`0X;3L0:Rdf01XM9P0[;SL08bXd01dV
;`0G82T00P0E72@0200G7R@06b0T020U:@0M8B@04QHG01<G600H71`05Q/N0P0E6Qh01P0F6al05a`P
01DJ7P0K82@07B8V01PM8@80724U00P04aPN01HJ8`0M8BX06AdV01HJ8`0P92d061`U01dQ:P805QXS
01`05a/T01PL9@0O8b`051PQ01TM9@0_=3X01``@01@I700L8B@07b@X01DJ7`0P92d04aLR01<G900K
7Rd06AdX01/O:P0J7RL05ATS01HJ8`0K82H06AhS01PM8@0K82@06AhQ01HK7P0H7B405QTS0P0P8Rh0
1`0B5Ah05aXS01DH8@0I72<05aXQ01HI800F6Ah00P0G6Ql0A00H6al02PdB014D6@0Q92T02PdB00H9
400B5Ad03Q4J01<F7`0F6B8051HR01LJ8`0M7R<0@dA801@E6@0A4QL06AXO018B6P0J6R@0410J01<C
7P0D52003`lK01<C700R8BL06APN01@C6@0F5A/0LG1f020O9@0`;cD0BdY@01HE6`0D4aT06aXP01DD
6P0>3A<04Q4G01XI7`081`d06QTO00h=4`0D4aT06APN01@C6@0=318040lE01<A5`0I5a`05Q<J01<@
5`0E4QT04@lD01DC600=2a0081hS00X83@0E4aH05A<H01LE6P0<2Pl05A<H01`J7`0E4aP03@/@0040
100K6Ah01`D:0P0:20d01`0H5Q/03@/>00d;3P0>30l03`d@010>4@0A3a800P0@3Q403@0A3a8040hA
00l=400>30l05ADG01LG6@0;2`d020P:00D51`0>3Q0010@600`<3P0C4aD00P0>3Q00200E5AL05A4B
01DA4P0E4A80510A01<?400A3@h03`/<0P0A3@h0500@30d04@d>01<?400J5AT03@P<00l:3P0;1PX0
>C@h01PC5`0G4QH04`hB00l:3P0;1PX040/?010>4@0A41D0Bd]@00l=4P0=20h04P`B0P0D3A@02@0C
3A<06QDK00`:3`22PXL0UiNI01LD5P0B3Pl06QHG014=3P0200d92P0801LC50060P<0510A00h:2`0X
92D04`l@01<=4@0A2`l3010:3P0W014;3`0B31004`dA01<=4@0A2`l04P`@01<<4`0>218040TA014:
4@0C2Ph04PT:01482@0;1PP00@0500P8400I6bT0?dEE0=oUm@22QXl000D;00P;4@0000D01@H;01/I
7`0B3A<05Q4E01H@500b:Bh050/@01@<4P0?21007AHM00h83P0E3QD0:R@X01D?4`0>20`03PP:0080
4@/=00L03`T;00l92P0A2`/04P`<010:2P0>20P03`T900804@/;00H03`T900h8200>20P03PP8010:
2P0;1@D200l92@0?00h8200@2PX03@L700d71`0D3Ph01`4101H@400>20P0<2XZ01/E5@0@2PX05@l?
010:2P0D3Ph03@L700805Q0@0P090`<4010:2P0300l92@0@2PX040X:00803PP801P03`T9018<300A
2`/03PP801HB4`0300009B4R00h:2`0G4a@03PX;00H20`0@30d02PH701XF5`0B3Pl0<2`]018<3P0?
2@/040X<00h82P0=1`T04`d?00X41P0C3@l201D?4@0B01<=3`0:10H0C4I804Y4AP0M5aT03`T;00/6
1`0=1`T030H800/51`0@2P`04@/=01@>400M5aT09AlQ014;3@0;1@L040X<0P0B30h03`0>20X03`T;
00l92`0?2@/04P`>01@>400@2P`05Q0B010:3025Oh40ooWk05eGF@0@2``05@lA00L10`0200h82P05
00`6201fL7@07ALK01TC5`0=1`/00P0@2Ph01`070PD040X>014;3`0@2Ph02`D900H0100?2@d00P0=
1`/200l93@0>00d72`0?2@d04@/?00`62P0>20`04P`@00d72P0?2@/01@0101@?400<1PP04P`>00P3
100=1`T200l92`803PP:00T02`D7014;3@0F41803@L902@N800[9BL050h@010:300?2@/00`0>20X0
2@0?20h040TA018;4P0@2A003@H=00h8300@2Ph03PP<00`6200200/51`0400X41P0<1PP03@L900h8
2P8040X<00X03PP:014;3@0>20X040X<00X41P0;1@L05@lA01hH600D3Ph03@L90P0?2@/06`0?20l0
3`P@00@01@0J4Qd0100900/3400E3QX02P8=01084`0>1Q403@H>01@=5@0?21002`@;00h73P0B3100
3PP<00`62P0?2@d0100201H@500<1PX05Q0D00H1100E3a<03@L;00h8300200l93@0900h8300=1`/0
40X>00T31`0500<03`T=01D?4`0600@03PP<00D03`T=5?ooool001_ooooo01<01P83010<3@0A3@h0
BTI702PT9@0400404`l@00d92P060P<030P901<?400:1PL05a8F00@00`0Q72004`hB00l:3P0B3A40
1P4500802PD900<08AdP044l@00B3A400`0@2a42014<4P08010;4@0>2@l03@P>00d83P0>2@l04@`B
01/F700A2Q8201094@0E014:4@0B2a804P/B010:3P0>20X03@L900d71`0?2@T04@/=00l92`0B3100
4@/=00h82`0>20`040X<014;3P0?2@d02P@600l9300500<04P`@008050hB0100618F01lI7@0M5a/0
5a4E010:3P0:10P050hB01TC5`0G4AD030L900h:2`0@30d03`/<00h:2`0@30d04`l@0`0B3Pl201<?
400b01@A4P0>30d00@0201XG7@091Pd00@0702<P:`0C41T030T@01LE6`0E4aH040hA00h?3`0@4Q40
4a<C01@B5@0E4aH06QDI02HQ9@0E4aH03`hC01<D600P92L04QDI01/K8`0D51h0=SI001DE7`0V9S00
4A4K01`L9P0000T07QhX01`L9P0=3AL06ATS01<C7@0G5b40410H01<C6`0R8RX071dR018C5`0G61`0
5QLI018D4`0L7Qd05AHG01LK700F6Qd201DI700E01HJ7@0G6ah051PK01`P900@4aP071lT01LJ7P0I
7240724U01/P900J7b<06AhR01LL800F6al092T]059GF`0K82@05Q/O01LL800S:2`072@W00806b<V
01006R@V01dW:@0N:2X0@Da>01h[;00D8R<07bd^01d[;00@7Ql062<U01TV:00K:B`07B/^028a=@0W
=S/09C@j0P0R<cX3024b>P0=02<d?`0N;S/07Rhk02<c@00U=D8093A102LgA00X>4D09cM402@d@@0O
;c`0834k02Hi@@0202Hi@00o028e?00R=C/093Lm024d>00L;c<0;T5502e1@P0cAdP07c<d02lnA@0X
=ch093<j02<b>@0W=Sd0:CPo02Xi@00K:S4072/b02He?00U=3/09cHj0310@00gBD/0>Te@0315B00]
ADT0<DQ=03=:DP0^@Td0=TQE041@G`0kB5T0:ca802`oAP0_@D/09cU502m1C`0W>T/0;41B02m4E`0f
Be`0CfEe02DmB@0R>TH0:3a602hlA`0b@4/0<3i902Tg@P0W=D009C<n020^>@0N;3L07B/f01h/=`0P
;ST06bLe028[>P0V;ch0;cQ701lY=@0T;ST051hX0080:cDo05@02A<L01PR:`0G8BX06B4^01lW=00J
8Rl05ad[01HL:P0L82`09RXe02da?00E5b<05aXS020S;00E6B807RD_01`U;P0H8BX05A`T01HM9@0H
7bD061dQ01hS9`0L82<04QHG01<G600I7Ad05Q/O018I7`0C6R005A`R01LN900D6b4072<Y01dT:P0E
728051/Q01dT:P0D6b406QhW01`P:@0N8R/03Q8K01HJ8`0M8BX06AdV01PL9@0K7bP06QhW01TM9P0K
7bP05a`R01hS:@011P`05AXN01/P900S:2/0724U01@I7P0N8R/04QHQ01/O;00X:cX0GF1_02T]>@0E
6B@051PS018F8@0K7bP06AdU01LL8P0J7b<061dQ01DJ7P0H7B<05aTT024S;`0S9C4051LP01LJ8`0F
6B805aXQ01HI800E61l301DH7@0E01LJ7`0B5A`041<J018E700C5Qd071lX00lA700G6BD051HR02DW
<`0N82d04aDQ02<S:P1=CU<071dR018B6P0K6b<04a<M00l?6`0A4al06A/X00802`dJ01D05A@N024P
9P0F5A/03PdC00L6301LFf404a8H02`[<@17AT`04a8H014@5P0G5Q`051<I00D42P0[:S00NGQn028Q
9`0=31805aHL01<B600B4AL00P0A41H05`0E51X06aXO020N8@0G5AX04a4F01LE6P0@3Q<04a4F01DC
600`;C@04a0G01DC600E4aT08b4V00l=4P0D4QL04Q0E014?500G5AX0>CLl04]9CP0T8RL05aDJ0080
3@/@0P0>30l01P0=2`h03P`?00l=400B41<03P`?00l=40@04@lB00d07QhP00h>400Y:B/02`/=00d=
3`0E5AL051@F018B500<30h020P:00h>400D51H04@d>00804Ph?00@04@d>010<3@0>2P/03`/<0P0B
3Pl2014=3P0O01<?400@2`l05A0D00/62P0=20`04PdA01HA5@0B3A403`X>024L800j=CT05Q4E00l=
400F5AX04A4E00d;400J5A/030H=01D>5@0?20l05Q0F018=4`030@H07QhS024Q8`0C41805A4B00l;
300;1`P05Q8C00d92P02014=3P0600h:2`0A3@h03`/<00<0000C3A404@/?0`0@2Ph02`0A2`l040X>
014;3`0A2`l03`T=010:3P0A2Q4040TA0109400A2`l04`X<00804@P902<04P`?01DB6@0V9S809bTj
00hC9`1[LX@0;C<m00@;4@093Q@06QdT038e>P0R8RL05A<H020N8@0V8B@03@L900H00P0;1PX04``D
01`E700@2A00J65X07egN`0U7b<03@L;00h82P0A2`d050h@01<=3`0A2``04@/;018<300@2PX03PP8
00l92@02010:2P803`T901X03PP800l92@0C3@d03`T9010:2P0<1PH02`D500l92@090`<05@l?01<=
3@0400005Q0@01<=3@0Z92@05@l?00/51@0@2PX02`D5010:2P0G4A404P`<00/51@0A2`/05Q0@00`6
1P803PP80P0?2@T400h8200F00l92@0B30`04@/;00h820050@809B4R06UUIP0E4A8020@500l;300M
6AX0<2`]00/720091@H00`0001HB4`0C3@l040X<014;3@0@2P`03PP:01@>40804@/=0P080P@2014;
3@0600@0000B3@h01`4301<=3`0A2`d05@lA0P0<1PP01P0?2@/040X<014;3@0H4Q@06Q@F00h82P80
2`D700<02P@600d72@0?2@/00P0A2`d06P0@2P`04@/=01<=3`0>2P/02PH701@@4@0]:BX0IV9S02hZ
:`0A3@h0?c/l018>3`0D41400`0000l;300F4A@01002018<400A2`l04`dA00H0100I4aL02P@8014;
3`0@2Ph02`D90P0A2`l200h830804@/?00`040X>00h8300A2`l03PP<00d72`0?2@d040X=00h82P0=
1`T05Q0B00X41P0@2P`200d72@803`T;0P0>20X0200A2`d03`T;014;3@0=1`T040X<01<=3`0<1PP0
3PP:100=1`T0400@2@l04``D01<<4`0A2Q403PL>00l93@0B310050hB01@>400>20X03@L901@>400H
4Q@04@/=00d72@0>20X2014;3@0800`6200;1@L03@P9018<3P0400005@lA018<300?2@T2010:3005
00`6200?20l03@H>01H?5`0400L00P0A2AH05@0K4b003@D@01@<5`0@21<02P<;01094@0?21002P<:
00h73P0C3A4040X>00h8300@2Ph06aDI00d72`0J51P01`45010:3P0400803@L;00h8300200l93@04
00h8300=1`/04@/?014;3`803PP<00@040X>00/52@0>20`03PP<100=1`/Dooooo`006oooool02P0>
2P/03@X:00d92P0G4a@01`<401XF5`0810D081`M01`H6@0@30d200h:2`0A00X52@0Q72005a8F00@0
0`0@2`l03`X>014<400=2@`050lC00h:3@0@2`l03@P<01@?5@0J5A/05a8H00d83P0<1`d00P0@2a40
200M61h04PdC014<4P0:1@/03`X@01@<5@0B2a<04@XB0`0A2Q402@0A2`l040X<00h82P0=1`L040/9
01<>300E3a007ALH01/E5P02018<3@0I01H@4@0@2P/05@l@00`61`0J51D01P4101TC5P0J51P06A<G
01<=4@0D3Q804P`@00l93@0O6Ad06aDI02PR9P0@2Ph04P`@01D@4`0B3Pl04`l@01@@4@0@30d05Q8C
01LC5002014=3P0W01<?400D4140510A01<@400I5aP05A<F014?500E4QT05A8M05EBG@1DDEX06aPQ
00h<4@0D4QD04Q0A00lA400=4Q40418B01<C5@0E4aH061<G01dH700D3a<04Q0D01HF6@0Q8RD051DI
014A6@0D51h0?Si800l?6@0F5R0051@N01PH8P0A4A/05ADO01lO:@0B4Q`04a<M00805QHP00`051@L
01TI8@0O7bL071dR01PI7@0K72005aPJ01<E500L7Qd04aDD01HJ6@0F6QP201DI6@0801HJ6`0F6Q`0
5QXM01TL800G6Ql06A`R01`O9@0E61h201`Q9@806b0T0P0J7b<01P0B5a/0?D9601PM8@0K82@082DY
01TN8P<06b<V01T06bDW01`V:00L9RP06B@V01dY:`0P;Rl06BLX020^;`0oCDh09c<d02<`<@0O;Bh0
7R`]01h/;P0M;2h09SDi02<e>00S=3X08S<i020b=`0O<3P08C8m020`?@0R<Sl09CE200809cM403X0
<T9?024a?P0T=440=4AA02XjA`0V=d408C@l024d>`0S=Sd08SDl02<f?00X>d40;3m302<f>P0X>cl0
9c/l02/o@00R=3H09cHm02Tg?`0Z>3l09S@l024_=P0N;3@08S0h024_=P0S<CT0;3Y102Xh@00T<cL0
830`028d=@0/@440;45402i6BP18H6H0DfYb03E9E00eAe@0<T9A03M4E@0_@4`0;d99024c?@0S=D40
:ce;02e0D@0bAUP0BEia04IKK00`AUH0:3m=0318E00U>D<0<3e7034oB@0]>dD09S@n0P0V<cd02@0Q
;cT07b`f020]=`0R<3X08Rli024[=P0U;cP09Bli02hh@`0202Pb?00C02li@`0I8bd07RPb02@^>00S
;CL072H_020X=@0H7b`06b8`01XP;P0E6bT06al[01XN:@0T:3<0EUQT020S;00B5Ah07AlY01LN:002
01XS;00J01HM9@0G7RH05QdS01LL800J7b<05QXM010D5@0C5aP05AXI01PM8@0C6R005A`R01XQ9`0L
8bT061lU01XQ9`0H7bD07bH/01DL8P0I82H07B@Z01`P:@0J7RL07b</01`P:@0K7bP201XN9`807b</
02806alX01LK900E6B805a`R01TN900J7bD08bP/01@I7@0L8B@04QLK01TN9@0E6B@04QHR01PK:`0O
8S<05aX[01PK:`0H72T041@P01lS;`0e>D@05a/U01HJ8`0I7R@05a`R01@I7P0F6b4061/U01dO:`0R
93005aXS01XM9P0I72D05APO0P0D5ah0>`0D5a`04aHK01<F6`0E61l05aXR01DH800?4Q/051HQ01DH
8P0H6RH071hZ01@F8`0S9C<06Q`Z00h@7@0B4AT06QXP01LG7@0E5Ah03@dH01LG8`0C4Ql04aDS02LY
=`0D5BH09RPh04E5D00;2Q007QdS01XI7`0@3aD051<I01<B600>3A<061LM01LF700J6Al03`hD01<B
600T8bT071/Q01dL8P0?3Q@040lE02LV;00U92X04Q4G01DD6P0I61h04a8H01<A5@0N71h05Q@F010>
4@0D4QH040hC014?500A3aD081dU00803``D01003``E01HC6@081P/05Q@I00`:3`0A3a@04a4F018@
5@0G5AX030X?014?500C4AH040hC01DC5P0D4QD04@lB0P0?3A000`0A3a803`d@00l=4004018@4`0>
018B50061PP0;bla010@4P0E5AL04A4C051@DP0h>3X05QHH00l?4@0@41801`L9010<3@0A3@h2018>
3`03014=3P0@30d04Ph?00805A4B02T04Ph?00l;300?2``04PdA01@?4`0B3A40<Rda01HA5@0B3A40
6A@H010;3`0C3Q80<B``018=4@0B41<030/@014A5P0=31803`dC01@>500A2Q805@hF01@>5@091P`0
30/A00X:3P0K6Ql03P/=01LC500@30d05A4B01HB4`0=2@X04`l@06YVI`0i=CH04@d>00<0000e<C80
4`dA014;3`03010:3P0V014;3`0@2Ph04@/?014;3`0?2@d040X>014;3`0B2a804P`@01<=3`0D2`/0
4@X800l:1`0@3@h030/C00/<600O8SH0Uiff0=7GhP1XLWX03QPL010H7@052a404AHJ01DG700A4AD0
2`/=020N800>2``050l@01D?500?21003PL>00l93`0@2Q005@lC018=400C3A42018<3P805a4C00L0
4P`=014;2`0B30`040X:00h8200?2@T040X:00803`T900d040X:00l92@0?2@T04P`<00d71`0@2PX0
4P`<01TC4`0R71`02@<3018<300:1@D07QPH00803`T900h04@/;00`61P0>20P050h>018<300?2@T0
2@@400l92@0B30`03`T901@>3P0I4a<03@L700h8208040X:00<03`T900h8200@2PX00P0?2@T05@0@
2PX04@/;00l92@0A3@h03PX;00l<30060P<06QHG00h:2`0810D05A4B00P41@0=2@X04@d>00d:2P0I
4aD04`d?018<3P0C3@l04@/=01<=3`02014;3@803`T;100A2`d0400>20X05Q0B014<3@0>20X040X<
00l92`0B30h040X<00/51`0>20X02`D700d72@0D3Q004`d?00d72@0>20X200d72@0A00h82P0A2`d0
3PP:00`6200?2``02@D600/7200?2``05a<D00h;2`0@30d0Cd]<02HR8`0C3a001@82018?3`0A2`l0
0`0>20`03P0M5a/03`T=02XT:00;1@T03PP<00l93@0@2Ph07ALK01<=4@0?2@d03PP<014;3`0B3100
4@/?100?2@d02@0>20`03PP;00`6200@2P`030H800/61`0=1`T030H800d72@0200l92`803PP:00P0
4P`>00P2100:10H04@/=00d72@0A2`d040X<00h82P<03@L901403PP:01093`0B2a<04P/B00l83`0>
1`h040X>00l93@0@2Ph04`d?00l92`0>20X05a4C01`F600C3@l03@L900l92`02018<3P0J00T31@0V
828030H801H@4P05004040X<00`61P0;1@D040X<018<3P0>20X03`P?03Tb>P0J51/03`LB01085@0M
5b80<b/h00h64@0?1a8040PC00h73`0?21004P/C00d63@0>1`h300l93@0900h8300@2`h04`dA00`6
2P0H4QH02`H9014;3`0=1`/03PP<00803`T=00D03PP<00d72`0?2@d03PP<00l93@02014;3`803`T=
0`0>20`200d72aCooooo000Kooooo`0X00D10P0C3a002@D600T51P0D41400`0000D10P0F4Q<03`/<
00P41@0<20T02`L8018=4@0K5QX05A0D01<>4P0B3A405A0D00l:3P0F4AD01@0400X62@0;1PX03`X>
010;4@0M61h06A@J00`73@0>2@l05Q4G010;4@0Q72802`H<00l:400>2@l04PdC01<<500A2Q8040TA
00l840803PL>01h03`T=01<=4@0C3@l03`T;00l92@0A2`/03@L701D<3`0D3Ph03`T:00`6200=1`L0
4P`=01@>400E3`l03`T:028L7P0:10L04P`@01@>4P0?2@d04P`@01LA5@0A2`l05Q0D00D00`0Z92P0
50hB00/52@0A30l200l;3006010<3@0<20T0510A01TE5P0C3a00510A0P0E4A807`0D41405a@D00`;
2@0?3@h05aDI010>4`0D4AP071TR014>5@0;20l05aDI00h<3`0:20T04A8C00lC500@4A<04A4C018@
4`0@3Q406A@H00h<3`0H5QT05QHH00d>400B4aH02`/C018B700C4ad05ADO01<C7@0@41X00P0D51h0
200C4ad061PR00T94`0F5R0051@L010@600C4aX05QHN0P0B4aP0800B4aL051DI018C5@0@4A<071hM
01@F5P0F6QT05AXF01DI600D61L05ATI01HJ6`0F6Qd05QTM02<V:`0O8RT0;c8j02@W<00I7BH06QhV
01`Q9`0M8BX07b@Z020U:`0Y;S@06AhT01XO9@0K82H07b@Z01hS:@0K8RP07B@Z0P0N9B/05P0M9R/0
72DZ02df>`0H8bD05R@U01`W:@0J:2T08S0a01d[:`0N;2`08Bl_02<a<@0R<C407bl_024`<`0S=CL0
9CLi028d>00L;S806BXa020a>P0U=T0202Pi@`1l02<d?P0P<3d09cM402hnB`0[>dP09SI301XZ=`0U
=D809cQ102<d?00S=Sd07S0g01/^=00Q=3X0EVU]04EHG00X>cl0<4A501/_<00hC4d0:3Lm02Hc>`0R
<CH08Bld020]<`0O;S<08c4g02Tf?P0P;SH08c4j02Xg@00W=S`09cHi02Dg>@0W>Sd0<dQ;0397C00[
?dH0@eMP03=7D00]?T/09SI303E2DP0W=dD0:Sa602XjA`1:FfP0<45A028cA@0Z?4l0?E1Q03Q;G00/
@Tl0:T1=0357DP0S=3l09c@m02Hc?00O;3D06BH_01XW<00P;CD082df01h[=00Q;SL0934j028_>00P
;CH08bdf01lY<P0X<S/09c4j024[=@0K9Bl0628/020Z=00M9c408bdf01hW<P0L93406R0^028X=P0L
8S007R@b02DY=@0P92l04ADP02X/>00G6R<051LP01hP:@0@5b405b0Y01XS;00E72H05QdU01<J8@0N
8bT07B8V01LK7`0C5aX05ATL01<G6@0F6b4041LO018I8@0H7bL06R4W01HM8`0D6b4072<X01LO8P0O
9bX0?dM:014I700B6B4082La01<J900D6bD061lY01XQ:@0F6RD0720Y01/O:08061`U01T06AhT01LL
8P0I7R807b@X01<H700F6ah05a`O01LL800`=3`07B4/01hR;@0I72X04QDT014E8@0D62@02@dI02@X
<`0a=D007b<^01HJ8`0D62405a/T01DJ800B5ad051PQ00804aDQ00/06Q`X01@G800F6B805APQ01@G
7`0E62405APO01@G7P0C5Qd04QDL018E7P0201LJ8`10018D800L7RX06A/W01/M:@0?4Ah04aDR010B
7`0?4Ah061PT01PG800L6b<06QTQ01PH8@0C4ad08R8]024Q;@040a4061PV01LI9P17AUH0Lg=m028Q
9`0920h05A@J00h=4`0F5A/03`hD01HE6`0H5ad03@`B01/J800<2a405QDK0450A@0X9b`06APM01DD
6@0@3a@081lT01dL8@0F5AX04a8G00h>400B4AH07ahO02d[;00X9RL0518E00/9300<2Pl05Q@I01@A
600=2Q404@hG01LD7@0K6200@T1501XH7@0>314061HK03Hd>@0W9BX03`dB00P62`804Q0E00@05A<H
00/:3P0?3A003P`?0P0=2`h00`0?3A004Q0C018@4`02018@4`0j014?4P0@3Q403`d@00h<3`0?3a40
3PdA00`:3`0C4aD04a8F00h<4@0@418040lB00P62`0920`04@lB00l;300@2`d04@d>01<=3`0C3Pl0
4Ph?00l92`0C3Q00510A01@>400C3Pl04Ph?00`72`0B3A4040/?01dH700C3a804@`@00P31`0G4QP0
4PdC01LB600E41H03`dB018A5`061P/01`@;01TF7@0A31<03`P?014:4P0A31804Q0E00d;400=3140
1PD:01@A4`0810D02`L8018>3`0=2@X05Q8C01@@4@803@T:00D02`L801lK700=2@X04`dA014;3`03
010:3P804@/?0P0B3100:`0@2Ph04@/?018<400C31<04`dA01<=3`0C3@d04@`9010:2P0?30l01@@<
02PX=00U9cP0aLON0>_`o`1WKgH010/A00X@5@0731002`hC00H8300=3Q804Q8D00/9300A3a0030L;
00d73@0D3A@040T@00h73@0D3Q8030H:00d72`0E3a<04`d?00h82P0C3@l04P`>00h82@0A2`/04P`<
010:2P0>20P00P0?2@T0200>20P03`T9010:2P0@2PX03`T9014;2`0=1`L040X:0P0?2@T01P0B30`0
4`d=014;2`0M5aL0HE]K024K6`803PP800d040X:00h8200<1PH040X:014;2`0B30`04@/;00l92@0G
4A407QPH01XD500>20P03`T900804P`<00H04@/;00l92@0B30`03`T900d71`0>20P2010:2P0500P4
1@0E4A804@d>018>3`0>2P/00P0?2``03@0=2@X04Ph?00T51P0>2P/05Q8C01PC5`0=20`030L;00l:
3P0>20`02`D7018<400<1PP00P0A20/0100>1@P050/>00`6200:10H201@>40805@lA00T02P@600d7
2@0D3Q004`d?00h82P0@2P`05@lA00/51`090`D00P0;1@L02`0@2P`030H800X41P0=1`T050h@014;
3@0;1@L02@H600/7200A3@h02`L800804@d>01H030P900L3100:1PL02`L801LC500<1PP04P`@00T0
1@0:10P04@X>01lF6`0>20`030@900h52P0>20`04@T>01483@0=1`/04P`@00d72`0<1PX03PP<0P0@
2Ph02`0?2@d03@L;00l93@0B31003`T=01@>4@0500402`D701<=3`0>20X02@<500803@L90P0?2@/2
00h82P08010:30090`D030H800d72@0>20X04`d?00h82P0?2@/200h82P0:00l92`0@2P`03`T>00l8
400?20l03@H=00`5300>20`03`T=00h830803`T;00l030H800/51`0@2P`040X<00d72@0A2`d04P`>
00d72@0B30h0D4Y<018=3P0F41803@L900h82P0D3Q000P0<1PP07@0C3@l04P`@00d63@0;10`04``D
00h74@0<11400`0901`D8@0E3AX03@D@00l74P0D3AD030D=00P12@0C31<040X>00h8300@2Ph04@/?
00h830090`L01`45010:3P0600@05@lC00X4200=1`/03PP<00803`T=00P03PP<00d72`0:10P03`T=
010:3P0<1PX020<600d72`8040X>0P0?2@d200h831Cooooo000Kooooo`0600`6200D3Q006Q@F01TC
5@0C3@l03PP:0P0=1`T200h82P803`T;00@03`X>01D@500F4AD04@`@0`0>2@d01@0B3A405Q4E00`7
2`0A31004`hB00L03`X>01d03@P<00`72`0>2@d040/?014<4P0I51X02@@:014<4P0C3Q@02PD;00`7
3@0@2a404@`B018=4@0@2`l030L;00/52@0C2Ph050T?00`31P0F3A404PT>01072P0@2Pd061<G01@@
4@0=20/03@P<00l:3P0300h93@0P00l:3P0@2`l03PT=00d8300G4QH03@P<01TD600R7B403`X>018=
4@0A31003`X>018=4@0E41@04`hB01LB5P0I51P04PdA010;3`0E41@0514A014@300B4@l04Q0@018@
4@0C4A804Q0C010>4@0A3a804Q0C014?4P0@3Q4201<A500A010@4P0C4A@05A<F01DD5`0<2Pd0:RX/
02<S9@0J6ad03a0B01@G6@0=3Q<03PhF01HF7P0E5Ad0410H01XJ8P0H62000P0A4AT0:00Q8BT092@/
01@D700E5Q/05QLL01LH700C51T04A8F018C5`0>3a<05AHJ01`M8@0F5a/04a@F01/L7`0K7b007b<R
01DI6P0J7Ql051PJ01`P8`0M8B@051PL02<V:`0G6Ql06A`R01hQ:P0K7b/05adZ01@J9P0D6RP05adY
01TO:`0H7RX07R@_01hU;`0J8B/06B0Y01/R;00P92l201dQ;00J020T;`0N9Bh061lW02/b>P0R:c00
72L[01`V:00J9BL06BLX01TW9`0M;BX08c<`014Q800V=SH08S8b028a=00S<SL09SDj02Th?`0T<cX0
82lf02@e?00/?DD06b`d02/lA00X>D4202Df@0808c=00440<41?01l_?P0U=D@08Blk01l]>00R<cd0
7Rdf01d^=@0X>D00=4I:0314A@0^@T<09CTj02<i=`0bATL07Blc02<b=`0P<S@072d_01`[;P0K;Bl0
834d02Pg?P0W=Sh07c0j02lmBP0T=Ch09CHm02Pi@00W>3l0<DA:03Q;DP0[?TD0;d990313BP0V=d40
:CY402hoB@0X>4H08C51038oD01;FF/0>4MJ02hmDP0dAEP0;Ci@02LhB00Y?4T09CU2028f?@0P<3T0
:3I101PV<@0C8BX06BP_01l^=@0O;S@07bhe02Dd>`0X=Sl07B/f028`>`0T<Sd09S<l01/X<@02024^
=`0h028/=@0K9Bh07RPa01hW;`0I8R/072D/01/T;@0?5b@08BPh01dT=00T:SP0:Blm028X=00C5b80
6alZ01TL9@0H6b@08RD^01hQ:@0C72D041XT01DO:@0K92d05QlX01<J8`0H72D02a0F00hA5`0F5a`0
3a0E01LI7`0V:SD03A@O020W<@0M92h07B@[028Y;`0F7R40620S018J700C71/03aPF01hV:00H8BX0
6B4/014I900J8Rd072@_01/T;@1DFVH0:2li01TP:P0K8R`051TS01DJ800H71l301PL7@1G01PL7`0I
7B00:blb04U<D@0N8BP01PT@01@G7`0D5ah07R4V00`@50082a003a8G01hQ9P0G6Ql061/R01LJ8@0N
8BP05APQ01LJ8`0J72P05QPT01TK9`0H6RH05QPT01LI9@0J72P061XU01<E8@0C5Ql05aXS01DH8@0B
5Ah0820Z07IfP00I6B<051@N010@6P0G5b405ADO01LG8`0Q8Bd06QXV018B7P0I6B<061LN01dL8P0G
5Q`05A@K00d<500F5Ad05aHN01PG7`0E51`04a<K01TG8P0O7RD051<I01<B600S8RP051<I00l>500H
5ad040lE014@5P0R8BL051<I01XI7`0C4AD06ALJ01LE600@3Q006ALH00P61`0V92@05aHD01TH5P0E
51804a8>00h=2`0L71`08R4V01HE6P0B4AH05aHK014?4P0C4A@040hA00<04`hB00T050lC01PF6`0?
3A80518G014?500D4QL04a4F00l=4P0@3Q<00P0A3a@2010>4`804a4D00@04Q0C00l=400>30l03@/>
0P0C4A@0100B41<04@lB018@4`0C4A@2018@5@0T010=4`0J5A`05A<H00`93`0;1Pd030X?014>500:
1@`04@hD00L2200B31004P/=010:300B2@`04P/=018<3P0E30l04`/>010:300B2@`04@X<014;3@0@
30d04`l@01@@4@0C3Q804@`A014<4P0J5A/030P>02XU;00D3QP07ALQ010:500A3QD04Q0F0`0B3A<0
200?2Ph06QDK00h93@0A31004`hB014?4P0P7R4040`=0P0<20T00`0>2P/040`=018>3`06018>3`08
00l;300C3a001P8301PD5@0A3@h03@T:018>3`0?2``200d92P0P00h:2`0?2Ph050lE00h93`0E41@0
30L;03Td>00:1@T040/@01<@5`0D4AP05Q<M04A2C@1_KGP0=SDk010?5@0?3Q<04Q4F00/93P071@X0
40hC018@5@0>2@l03PT=014<4P0>2@d02PD901hI7@0:1@P040`=00H20`0B3Pl200h:2`0@00l;300@
30d040`=00l:2`0?2@/040X<00h82P0;1@L03PP:010:300;1@L03PP:00/51`0<1PP03PP:00X51@80
4P`<0P0@2PX01`0>20P050h>01<=3@0J51@0GeUI01<=3@0@2PX00P0?2`X0400=2@P02`L600`81`0A
3@`03PX900L30P0@30/0510?051<B`0D40l03@T8010<2`0B3Pd01@4000d9200C3`h200d9200:00l;
2P0@30/04@d<018>3@0:1PL0100101<?40030000510A014=3P805a<D01T04Ph?00h:2`0<20T02`T<
01@B5`17AT/02@L<00h<4@0?2Q004`dA0109400B2@h04PL=01<63@0D20d050T=01072P0>20X05a4C
00D00@0_:B/08adO00d72@0A2`d040X<008030H801003`T;00`6200?2P/03@L900T31@0B3@h01000
00d72@0?2@/040X<00l92`0<1PP02`D7018<3P0C3@l04P`>0P0@2P`0100B30h03@L900d72@0>20X3
00l92`0B01483@0G31806A0E01X@5@0F2a404`X?01<93`0E2Q004`X?01473@0B1`d04PT>014;3`0=
1`/02`D901H@500K5AT05a4E0P0;1@T300`62P0400d72`0?2@d030H:00/52@804@/?00<02@@7028L
800400800P0?2@d01@0400804`dA00l93@0?2@d03PP<00803@L;00/03`T=00d72`0:10P03PP<018<
400?2@d03`P>018;4`0A2Q403PL>00d63@02010:3P0W00h8300=1`T03PP:010:300B30h04`d@010;
3`0=20`02PD900d8300>2@d04PdA00L21P0:1@T04PdA00H11@0=20`030H:00/21`0@1``04@/?00h8
300@2A004@`C018=500?2a802`D?00X7400@2QD02P@@01<=6@080P`06A@K00`73@0>2@h02`H:018=
4@0A31002PD;00803@P>00`04`dA00@00P0I4aL03PP<014;3`0>20`04@/?00d72`0?2@d03PP<00/5
2@0B310<00d72aCooooo000Kooooo`0300d72@0?2@/040X<00803PP:00<03`T;00d72@0>20X00P0>
20X200l92`0<00h93@0@2`l04@`@014<400>2@d030L;01@?4`0=20`02`H:00l;3P0?2Ph040/?1P0?
2Ph02P0>2@d03@P<00d8300>2@d03`X>010;3`0C3Q@050lE00/6300@2a4202XU:`0=00d83P0?2Q00
4@`B018=4`0@2a4040T@01883P0B1`d040D;01L>4`0C2Pl03`L;010:3P0200P31`05010;3`0C3Q80
4PdA014<400@2`l00P0A31001P0B3A4050lC00T4200A31005Q4E00h93@8050lC02T04PdA014<400B
3A404`hB010;3`0A310050lC01<>4P0F4AD07APL01/F6P0D4A404Q4=014@300@3``04A0>018A400C
4Q804Q0A014?4@0?3A004@lB018@4`0F4QH05Q4F018@5@0D4AL05Q@H01DE6@0K6R007ahR01/L800G
61`04Q<F01HI7@0N7RD05aLO01DE7@0I6B405QHN018B6P0201DE7@0=01LG7`0I6B4061PP01@E6`0E
5Q/05aPL01XK7`0F5a/051DI01<D600S92P07b0T01TJ7P0201PI7@0?01HG6`0K7b4051PJ01/O8@0;
3a40:Rda01HJ7P0G6Qh0;C0f01<F700M82H07B0X01`P:P0K7Rd06Al_008061h^02X06Al^01TO;@0K
8Bl06b4^01XP;00K8Bd07RD`020W<@0K7Rd07b<`020T<00O8bl07B<^01hU;`0M9B`07bL]01dV:`0O
:Rd08bh`01/Y:P0J:2P0830^06moO@0gAdH072`/02<b=00R<CD08C0e02<b=`0V=C`08c8i024`=`0[
?D807c0g02Df?@0Z>d80:3U102Xk@`0V=d406b/h01`/>@0]?D`202<c@P0?02Lc@@0T<Sh0:cU402/i
A00^?dP0>4UA028c>@0Y?440:C`o02i2A00X?Cl09CXl02<e>@0S=CL08C<e00807S0`05L0838b02Hh
>P0T=C`0:3U102@e?`0O;ch09cM302@e?@0V=cl08S<k02Hg?`0Z>d<08c@l0352BP0fAdl0;d180311
B@0_@4P0;Ca9020]?`0K:3X09395024_@`0U=4T0:cY>020`@00O<4009CM2028e?00N<CP08S8k02Hd
@@0Q;cX09S@m01/Z<@0E92T07Rdb02Dd>@0O;SD093<l02/iA00P;S/07R/f02Hc?@0Q;SL08c0i01l/
=@0S;CH09c4j01LQ:P0N9bh0<SY101`T:`0I8BT051`Y02H]?@0R:CT09bdk02`b@00^=4006AdX018F
8@0I72D061/T018E7P0/<3P0@daE030jA00K92d051dV01<L900H7bL0720X01<H7P0Q92X0<C4h028S
:@0C51`05QXV02X`?@0Y;c/0/[W3065XL00J8BL06B4T01@L7P0M9RD00P0G81d03P0F82004a`T018L
9`0S;CP072Ha04mHHP1SK7H0HFUc03@kA00G7RL06QlY01LM900@5AX05a/M0P0G6a/0400G6a`05a/M
01LK7P0O8bH0<SDi01dP9@0=41D05QTN01@H700A5AL05ATI01LK700A5AL05QXN01LK7`0M82H201PK
8P0401dP:@0G6B@05aXT01TK9`8061XV00@05aTU01DG8`0D5R805aTU0P0E5b<06P0D5R805ALS01DG
8`0B4Q`09BD_00d=5`0S8bd06ATS01HF800E5Al05aLQ01hN:00I6B<04a<M01TI8@0I61l04a8H01TH
7P0D4aT07ahT01@C6@0E51X04a8H018A5`0C4QP05A@J0P0D4aT0700E51X061LM01DD6P0@3aD04Q4G
010?5@0A41H05aHL01DD6P071P`07QdQ01DC500H5QL04@l@01dL6`0@3`d04A0=03dl>027QX80IVEQ
02PW8P0H5a804Q4A01<B600B4AH040lD01DD6@0F51L201@B5@0:01DA4P0D41404`l@01@?400<1`d0
5Q@I010>4`0H5Q/03@/@01<A5P804@lD0`0B41D00`0A3a@040hA014?4P02018@4`804a4D01@04Q0C
014?4P0A3a8040hA014?4P0B41<050lE00l:400@2a4050lE00`83@0E41H050lE01PC6@0M61l02`H=
010;4@0A31805@`A01D<3`8050/>0`0E30l201@;3P804`X=01l04@/=010:300@30h03`X=00h93@0B
3A805Q4G03@`=P0L5al0DD]E01LA700F4A`05@lI00l94`0A31<04`hD01@?5@0C3Q<04PdA01LB5P0>
2P`04Ph?01<?400B3Pl06aLH01HB4`0A3@h040`=00l;300<20T02`L800H040`=00H03@T:010<3@0C
3a003`/<00d92P0@30d601<?400N018=4@0S7R<061<H01dH7@1NFEh050lD00l:3`0@2a005Q4F010;
400C3Q<07aXO01PC600D3a@03`X?010;400N6Ah07APM00`7300?2Pl04`hC00h93P0?2Pl04Pd@00d9
2P0<2@T0:2@U01LC500C3a0030P90P0>2P/0100?2``040`=010<3@0@2``2014;3@0<00l92`0>20X0
40X<018<3P0=1`T04@/=00h82P0A2`d05@lA00l92P0A2`/03`T90P0>20P01`0?2@T030H601D?3`0I
51@06Q@D014;2`0?2@T00P0?2`X0400>2PT02`L600`81`0@30/0Ddm>01@@3`0<20L040`;01@@3`0@
30/03``;01PD4`0@30`04`l>01TE500F4Q43010<2`0<00h:2@0=2@P030P701PD5@1GDe@08alP05=?
D00T82405A4B01<?400D41404@d>0P0>2P/04@0=2`h03`lD02PX;`0N7B@02@L?010=4`0=2@l04``C
0189400@1@`040@;01@63@0D2@h04`X=00`6200D3Q002P@6008040X<00P03`T;018<3P0A2`d03`T;
00h82P0@2P`05@lA00`620804P`>00T03`T;014;3@0>20X03`T;010:300?2@/03@L900`6200>20X0
0`0@2P`00`0B30h050h@00d72@0200h82P<03`T;00T04`P>01D:400E2Q0050T?0146300@1@/04@H<
01873@0A1P`00P0?10X00`0?1P/03PL;00l93@0201<=4@803@L;00H03`T=00h8300>20`03PP<00`6
2P0=1`/2010:3P0:00d72`0@2Ph04P`@010:3P070@D03@L;01D?4`0B310040X>00l93@8040X>0P0?
2@d02@0>20`03`T=00h8300=1`/03`T=010:3P0>20`03@L=01094@0201<<4`0400l83`0=1`/03@L;
00d72`803PP:0P0?2@/0100>20/02`L:00`82`0<1`/200d8300@00h93@0?2Ph04`hB00h93@0B3A40
3@T<00l62`0A20d040L<00`62P0@2Ph03`P?00h9400=20l03P/B00l<5@802`PA00X030HD014;5`0@
2a@0510F00`73@0@2`l02`L800l;300>2@d030L=0P0@2a402`0?20l06A<G010:3P0B31003PT<010:
3P0I4aL03PP<00l93@0C3A4040X>00L03`T=1P0>20`Dooooo`006oooool2010:300400h82P0<1PP0
3`T;018<3PH03PP:00<040/?00h93@0@2`l00P0C3Q801`0>2@d030L;00h93@0R7B4040/?014<4009
10P01P0?2Ph300d8300900h93@0?2Ph03`X>01D@5P0I51X05Q4G010;4@0f<CL0<2/a00803PT?00l0
3`X@00h93`0<1`d030D<01lE6`0F2a4050T?0107300C2Pl040L<00h8300@2`l04`hB010;3`0;1PX0
100>2@d01P0?2Ph040/?00l:3P0E41@05Q4E00P31`803@P<00d02@D800h93@0?2Ph04@`@00l:3P0@
2`l04`hB00l:3P0<1`/050lC02<N8P0Q72005Q<C00804A0<01X04Q4>014@3P0@3Pl04@l@018@4@0@
3Q403`d@010>4@0B41<05Q<I01HA600B3aH0514H01HC6P0F5A/07ahT00h=4`0F5a`04Q<H01<D6@0G
6Ql071`T01DE7@0B4QX06ATQ01/K8`804a<K0P0F5Qh07@0B4QX0410H01DE700C51T05QLK01XK7`0G
61`05AHJ01<D600N7b<05aPL014B5P0F5a/061TM01@E6@0C5aX041@G01hQ9P0H6b00=STo02<V;@0N
8BP0CE1H02<V;`0Q92d05QPS02<W<P0K7Rd06R0`00806b4a01d06R0_01TO;@0M8c406Al/01XP;00N
930082Ha01`S;@0J7RX07b8`020T<00O8bl07b@_020W<@0K92/092dd01XS:00F8BD07RT]01PV9`0Z
>3T07Rh]03e=C@096AT05bLX01h]<00P;c@07bhc020_=003024`=`0403m@E`0Q<ST09SLn01TZ<P80
834i05<06b`f01/[>00Q<Ch0;3a;02LgAP0S<d809C4o02Hd@@0]>dP0<3i:02m0BP0eAU00;3e603A7
CP0dAdd0L8>802Dj?`0S>3/08C<g01h`=00K;Bl07Bl`028d=00U=cL09CLi02Hg?P0/?DH0:CY401/[
>00W>4<07Rlg020a>@0O<3P08S<k02Hg?`0Q<SX0;Sm703E6CP0`@DT0<D9:02dnAP0X>4<08Bll01`Y
>@0S<D8093=602DdA`0U=4P072/n01XZ>P0L;CX06R`f01h`>P0U=Cl09S@o02Pf@@0V=3`09C@k01h]
<P0V=CX093<h01PW;P0/>d<0<T1;02Pf@P0O;3D0:SM002Ld?@0S<3T07R/d02<]=P0O:C8041/Q02@]
=011B4h08RT_01DL8`0?5b@082Lg01TP<00D6RP04ALU01@J9P0201<G8P0Y02@W<00G6R<02@`E0413
B`0h@DP09S4g01DN9P0E7RD05AhS01@K8@0H7B<03a@H01PK800U9R/07QlS01LI7`0Q9C00=ce902L^
>010Ae40=3]204U@EP0a>C`0620R01lX9`0@6AP07RLT01DO800`>D0082Xd01@N9`084Q/0=T1805EN
I@0;4QX04aXQ014H7P0B5ad05a`Q01PM8@0G6ah00`0F6Q/05@0E6A/05ATL00dA500@51P04QDJ00hA
5P0F6Al05aXO01TM800A5AH03A4B01DI700B5AX05QTN01<F7@0I72<08B@[00d@6@0X:c@03a8K01XL
:00201DG8`0O01PJ9P0E5b<04Q@P01HH900H6RH05QPT018D800D5R805aXS01LG8@0E5Al0820Z00d=
5`0@41X07QhX01DE7`0F5R006a/U01LG8@0D51h061PP014@5P0H5ad0SHbB02h]<`0;2Q0071/Q01@C
6@0@3aD04A0F01@C6@02018A5`0O014@5P0>3A<03`hD018A5`0E51X061LM014@5P0G5Q`04a8H01hM
8`0Q82H0L6mc01lM7P0I5aP04a4B01PF5`0M71X0:bXW08n>RP3ooo/0a<>o03Dd;`0L6aH051<D01@C
6@0O7R<051<H00d<4@0F51L04@lB018@4`0301<?400901@?400K5Q`0DDmD01PF6`0=2a005A<H01TG
700A3a@04Q0E00804a4F0P0B41D200l=4005014?4P0B41<04a4D01DC5P0@3Q400P0?3A001@0>30l0
3`d@010>4@0300@09b8X00803@P>00X00`0401LB600C3Q@03@P>01D@5P0?2Q0050lE018=4@0D3Q80
5@`?0P0D2`h0100E30l05Pd@01@;3P0E30l201@;3P0C01<:3@0@2P`03`/<010<3P0@2`l03`X>014<
4@0D3aD04`hE01D@600Q6bD01@0900d74P0:10h040/B00h9400@2a404@`B010;4002018=4@0800l:
3@0C3a004Ph?00h:2`0B3Pl040`=00l;300@30d201DA4P03014=3P0@30d040`=00@040`=00X04@d>
00L3100F4Q<03@T:00l;300A3@h03@T:010<3@0A3@h04Ph?0P0@30d01@0F4AD01P4500d8300A3A00
100300803`X>01L02@@8010;3`0F4AD04`hB01@?4`0@2`l02PD900l:3P0B3A4061<G020K7`0>2@d0
1P45018=4@0>2@d02`H:00l:3@0=2@X01`<401/G600?2``05a<D00d92P0200h:2`0400l;300@30d0
40`=010;3@8040X<0P0?2@/0500@2P`04@/=00h82P0C3@l03@L900X41P0=1`T02@@400`61P0=1`L0
40X:00d71`0<1PH040X:00H0000K5AD030H600P20P0A2`/03PX90P0?2`X200`81`0500l;2P0V8R40
2`L6010<2`0;1`H00P0<20L04`0L61L0LFe/048n?@0@30/0=30_01/G5P0A3@`040`;00l;2P0<20L0
2`L600X61@0B3Pl07a/L02dY:P0e<C8030P901@A4@0>2P/00P0?2``05`0=2@X03`/<010>4@0;3140
71dU0492BP071Ph06ALO00T63@0A31<03`P?01063P0B21006PlE020E6`0B2@`05@lA010:300E3a40
2`D7014;3@0?2@/040X<00@03`T;00H01@0100@000070@<03@L900`6200C3@l300l92`0400h82P0=
1`T03@L900`620<03PP:00<040X<014;3@0>20X01@0>20X00`0D2Q004`P>01<83P0301873@0301@9
3`0E2Q0050T?00804`P>00/04`X?00/52@080PH01P04018<400I4aL050hB018<400@2Ph03`T=00h8
300200d72`0<00h8300<1PX030H:018<400A2`l04P`@01TC5`0H4QH05a4E01XD600400804P`@0P0@
2Ph300l93@803PP<00T03`T=00h8300=1`/03PP<00d6300>1`l04``C01@=500?20l00P0<1PX0;P0=
1`/03PP:00l92`0=1`T030H8014;3P0B3A404@`@010;3`0>2@d03`X>00P31`0@2`l07aXN06YUJ@1?
BTh030L;00P0100B2@h04@P=010:3P0P6Qh08Q/R00T42`0J5A`04a0G00P53P0C41T03``E024K:@0<
1Q805@lI02lZ<@0@2a405a8F00h:2`0<20T02`H:00l:400A31803PT?00`5300N61`03PT<018<400<
1PX201<=4@803@L;00<040X>014;3`0@2Ph0300?2@dDooooo`006oooool00`0;1@L03PP:00h82P02
00`620L03PP:00`040/?00d8300>2@d04PdA01<>4P0?2Ph03@P<01`G6`2WXZH0D4]?00T4200D3a<6
00l:3P0300d8300>2@d03PT=00<03`X>00H06QDL010;4P0O6R402@@;01LB6@0=20l400l:4@0>00h9
400?20l02`4601P=4`0N4aT02P8601@;400K4QL08adQ00d8300<1`/04@`@01@?4`0C3Q8300h93@08
00l:3P0@2`l06QDI00l:3P0500@06QDI01TD600=20`200l:3P08018=4@0C3Q8040/?01PC5`0P6al0
6QDI01@?4`0?2Ph201@?4`03010>3@0?3P`04A0>00805A@B00D03`d>010>400E4aH05A<F01HD6002
01DC600L01LC6@0G4A/04a0I01DB6`0G51d05QDM01XI8@0?3QH071`T01<C6`0F5Qh06ahU01@E6P0C
51T04Q<H01DF6`0H6Ah05AHK01@E6P0C51T04Q<H01<D6@0D5AX05QLL018C600D5AX05aPM01HG70@0
4a@I00T051DJ01DF6`0E5Q/051DJ018E6P0F6Ah05aXQ020S:P0J7BD00P0I72D01P0R9Bl061XV02<U
<@0J72P05ATU01/N;@<06b4a01/06b4`01TO;@0L8S006b4^01`R;P0O9C407R@_01LN:00M8Bd0720/
01hR;P0P9S808BLb01dT;P0F7bP09c4g02@_=@0M:2h07bX^01/Y:P0P;Rl08C4a02/j?@0N;C00:CPl
010O900O;S<00P0O;SD2020_=P0;024`=`0Y>T40834i02<d?00K;3@093Do01//=P0M;SP07bll020`
?@0M;CX00P0R<Sl0M`0Q;Cd0935102/hB00/>DP09CE202@e?`0P<C/08S@n02@g?P0iC580:Ce401@Y
;P0Z?4408S@h01la<`0Q<cD09SPj02Pj?00V>3X0:ca302Lh@@0L;CL06RXg01d^>@0I:S8072de01l`
>00P<CT093Dm020a>@0[?4@0;Sm702Xk@`0]?TH0:S]3020a>P0M;SP0830m02TiA`0[>d/09SE8024`
@`0M;3l07blo01l_?P0H:3D06RXg020_>P0d@Td0A59M02Hd?00V=C`07bhc02@c>00^?D804R4X020_
=`1XMWl0=49=01TV;`0P;CH06bPa01/U;P0F82T0628[01hW;P0C72<04aXQ01XQ9`0F7B<06B0W00TA
700J8Rl06b<`01`R<00I7bd06b4]02<W<P0F6RD051HR01TL9@0G6R<08RD^02L^=P0I8RL04AXP01PO
9@0G7b803aLJ01DJ7P0@5AP04AHI01@H6`0@51D05a/O02T]=P2Z/K/082La02H]=`0F7B@0OHB:030h
>`0F7R407RLV010I600M9R@04adL00hG700I8b/02QDK01XS:P0H8BL08b`a020W;@0O9RX04aPL00lD
600E6Qh06AhQ00805a/L00D05QXK01HJ7@0E6A`05ATL024T:@0201PK800a018E700E61l05QTN01@H
6`0E6A`051PK01/N8`0A51T06ahS04E8C`0L7bH06A`S01TL9@0M82T04QDN01LJ8`0C5Ql051LP01PK
900F6B8051LP01HI8P0H6b@05QTR018E7P0D5b005aXS01`L9@0821006QXR01HF7P0I6B404a<K01DE
7@0F5Qh061PP01DE7@0D51`061PP01DD6P0:2@l0EEAJ01DD6P0[:S00:BP^01@C6@0A41H04a8H01DD
6P0201<B60802`X@01X05aHL00`;4@0=31805A@J00d<4P0D4aT04Q4G01dL8P12@DL0eM?G05YHF`0X
9RL06aTJ01HD5@0K6QP0:2LU06ASH@3=c<P0W9^G02@S7`0E51005A@E01LF700U92T05A@I00P73080
518E00d05A<F01HB4`0D41404`l@018=3`0O6R00EE=H01/I7P0>31405A<H01PF6`0A3a@04Q0E0080
4a4F0P0B41D4010>4@804@lB0P0?3A0300h<3`0?00l=400U82H0P7^1038]<`0D3aD05a8H010<4@07
0PP061<I03Lb>00L5ad03@P>01@?4`0D3Q804`d?00804P`>01`04`d?01@>400B30h04`d?01@>400C
3@l04P`>010:300?2``050lB01D@500C3Q8040/@00l:400B3A<03PX?024L8`0300D07ALP01TC7@0G
4QT04@`C01<>500B3A<040/@01D@500@2`l03`X=0P0B3Pl200h:2`06010<3@0>2P/030P9018>3`0A
3@h02@D61P0@30d05`0A3@h020@500`82@0?2``04@d>00d92P0<20T03PX;00l;300@30d03`/<00h:
2`0=20`05A0D01XE6@0B3A40:bHZ00l:3P0C3Q8030L;00h93@0@2`l04@`@00804`hB00H02`H:014<
400?2Ph02`H:02dX;00Z9BT200X52@0900d8300>2@d04Pd@01<?400V8R<02PH700/7200>2P/04`l@
00803PX;00H03`/<010<3@0@30d040/=00l92`0=1`T200h82P803`T;02<03@L900l92`0;1@L050h@
028L7P0G4A8030H6010:2P0H4Q804@/;00h8200@2PX0100000l92@0C3@d01@0001@>3P0=2@P03PX9
00l;2P0=2@P030P700l;2P03000020@301HB4@030000510?00d9200<20L0?c/j02DQ800:1PD030P7
00P40`0300h:2@0300d9200<20L030P7008040`=00D030P9014=3P0400404@d>00`82@0300h:2`0D
010<3@0A3a8030lF02DX<@2PXj`0CdmI00/:4P0K624040dF00l:4@0>1`l040TA01T?5`0N5AX05Q0B
02<M7`0;1@L04P`>00`6200:10H400d72@0800h82P0=1`T030H801XD5P090`D040X<014;3@0=1`T2
00l92`0700h82P0=1`T03@L900d72@0>20X03`T;00h82P0200d72@0300l92`0>20X03PP:00@03PP:
00L03PD:00`3200<0`P03PD:00l62`0@1``04`X?00805@`A01P04`X?01@;400E31405@lC01H@500@
2Ph0;bT]03hh?00/9RX04P`@014;3`0@2Ph03`T=00d72`0@2Ph03`T=00/52@0?2@d0618F01<=4@07
0PD0100200d72`0B310201H@500300X5200?2@d03`T=00<03`T=0P0>20`02@0?2@d03PP<00d72`0>
20`03PP>00l8400B2a804@XA00h73P0300d72`0I00h82P0?2@/03@L900`620070`D02@@801XE6@0@
2`l00`0200/62P070PH04PdA044l@03el?@0[JR/01PC5`0>1@X05PdB010730090`L05@lC01@=500=
20l040/B018?5P0201LD7@0I00P63P0<1Q@00`09010;500G4QT03@P>05eHG00A3@h03@T:00/62P0?
2Q003PT?00/63@0:0`X040X>00h8300?2@d04`dA01LA5@0>20`040X>00`62P080PH02@<700`62P06
00d72`H03`T=5?ooool001_ooooo00H03PP:014;3@0B30h04@/=00l92`0@2P`200l92`<03PP:00<0
3@L900d8300=20`00P0=20`0200>2@d03`X>00`72`0L5a/0LFa`03D`=00B3A404`hB1P0?2Ph07@0=
20`03PT=00l:3P0@2`l03`X>00h93@0A31<01`<901`G7P0E41L04@`C00d83`0>2A003`XA010;4P0C
3QD05A0G01H?5P0n=3/03`@:01D:400D2a007QDJ01893P1HDUH06QDI00d8300A310040/?00804@`@
01l040/?014<400A31004PdA014=400f<CD0>C@h01<>4P0@2`l04@`@01<>4P0=20`030L;010;3`0<
1`/04PdA01TD600E41@050lC00l:3P0A31004`hB018?400?3P`040l=01LE500I5aL0518D010>400A
3a804Q0D00804Q0E01404@lD01DA6@0G4A`04a0J01DB700G51h05aDO01DD7@0L6R@06ATR00h>5`0E
5Ah04aHM01<D6@0G61d05AHK018C600201DF6`0;01HG700D5AX04a@I01DF6`0F5a`05AHK01@E6P0E
5Q/05QLL01@E6P0C51T00P0E5Q/04`0H6Ah06Q/P01HG700E5Q/05aPN010C6`0B5Ad05APR01/O:@0B
5R0071l[01@G8`0G6RL082<a020R<00F62L06ah^01/Q<@0J83000P0I7bl0100J82l06b4_01/Q;`0K
8Bh201XP;01Z01/Q;00K8R`07b@`01dR;P0N8bl082Hb020W<P0K92h072D^01`V;P0S;SD0930g01dY
<00J9b`06bX^01h]<@0G9RX08c8h024`=P0K:S007B`b024`=`0R<CP082lg020^=P0Q;cL07Rlg02Lh
@00Y>T80;d1902Hg@@0G:3809CI002@e@00R<ch072dh03=4C`0gAe@0931002LdA00]>TX0<3e=02Xj
B00W=dD0:SY703=5DP0T=T40:ce7028f@00_@d/0<dE=02Tk@P0U=c`09SPl02Pk?@0Y?3h08SDi02Tk
@@0W>440;Cm905]/N00V=d4062Xb01/]=@0O<CT072he01la>00M;cL09cU102Tk@`0U=cl0:Sa402Li
@@0O<CP09SPn02Tk@P0W>D<0:ca902dmC@0W=TT0:3M:0350D@0a?e008C0o01h/?00W=D40:3E103A1
BP0e@TX0FFM/02hl@@0Q<3@09C<g01DS:P0M:S<0>4E>02<`?00H8bd06RH_01LR:`0T;SL08R`e01PQ
:@0C72<05b0W01PO9@805adR04X05QdS00hG8@0J8Rh0620/01`R;`0F72T05A/W01DI9@0F6RD06A/W
01PJ9@0G6R@06QdW02P_=@0L9BT04a`O01@L7`0B6Qd04ALJ01LL7`0F6ad06AhO01HK6`0A5QH05AXK
01TP9`0b>D8092/d01`S:`0E72<04QTO01TQ900B6Qd07BDW01/S900J8b804Q/J018L7P0L9R/02A@G
028/;`0G82@07BHX01TO8P0B61X051XK01PL7P0E6Q/051TI01TM7P0I7Al061`N01LK7P0F6Qd05ATM
01/N8`0F6Al05aXP01<F7@0H6b<06A`S01HI7`0D5a`030lE01XM8`0F6Al0<3<i0;Zma00f>D0061/R
024T;@041a007b8[01DH8@D05QTR00@05aXS01DH8@0E624051LP0P0E62401P0J6R805ADM01TI8@0D
51`04Q8J00l?5`805QHN00X051@L01<C6`0E5Ad05aLO01HE6`0A41H0=C@j02DT:P0N7B<071/Q0P0D
4aT0;@0E51X051<I01@C6@0F5A/040lE01TH7P0X9bd05A@J00h=4`0A41H05aHL018A5`0G5Q`06aXP
040oA@32`<D0G5YM01hL7P0H5QP06aTJ01DC500I61H05A@B03Lf<`0^;BX05aHB018A3@0A41805A@J
01PG700B4AH040lD018@4`0F51L06ALJ01TE5P0E4A804Ph?014<3P0B3A<06aTN01<A5P0I5a`030X?
010>4`02014?50<04Q0E00@04@lD018@4`0B41<04@lB0P0@3Q400`0?3A0040hA010>4@0300l=400=
010>4@0?2`l0:B@Y01@?500G4QL02@@901D@5@0D3a@03@P=01HA5P0@2a004PdB01@?4`0201<=3`80
4P`>0P0C3@l06P0B30h050h@01D?4@0E3a404P`>010:300@2`h05A0C01LB5P0D3a<040/?00d83@0B
3A<03PT?01PC6P0L5ah03PT?00l:4@0A31<03PT@01LB600F4AL03@P=00l:3P0>2@d040/>0P0A3@h0
200@30d03PX;010<3@0?2``03@T:01/G600O6a`05Q8C1`0@30d00`0e<C802@D6018>3`0200d92PH0
40`=00d04@`?00l:3@0B3Q004@d?00/72@0D3a803PT<014=3`0B3A0040`>010;3P0@30h03@P;0080
4`hA00l02@D700`72P0L5aX05Q8D00/72@0E4A<06QDH01<>4@0>2@/06aLH034];P0B3`l03@T:00X6
1`0@30d00P0>2P/0200?2``040`=010<3@0A30d03`T;00`6200>20X040X<0P0?2@/02P0<1PP03PP:
00d72@0Q6ad0>C<e02PR8`0>20P04P`<01/E5@0C3@d3018<300C00d71`0?2@T05Q0@01`F5P0=2@P0
3PX9010<2`0>2PT03@T800l;2P0B3Pd040`;01<?3P0710<040`<010<2`0=2@P04Ph=00`81`02010<
2`H03PX901`03`/:010<3@0810D040`=00`82@0E4A8040d=00d92P0?2``040`=00l;300B3Pl04a4D
018E701AE5h0loOn0=kPj@1KG6D05QDN01<A6P0@3QD03@TA00`83`0>2A0040XA00/52@0K5AL02`D7
0P0A2`d200d72@802`D700/03PP:00l92`0<1PP05Q0B02PR900<1`P04P`>00h82P0;1PL040X<00l9
2`0200d72@803PP:00<03`T;010:300?2@/00P0>20X300l92`803PP:0P0=1`T30107300401483@0B
2@h04PT>010730804@P=00T040L<01483@0C2Pl03PT<010:3P0<1PX0618F01H@50070@D00P0@2Ph2
00l93@0>00h8300A2`l04`dA018<400D3Q806Q@H01H@500K5AT0FeEI01LA5@0;1PT04`dA00/62@0A
2`l200d72`803PP<0P0?2@d03@0>20`03@L;00l93@0@2Ph03PP<00h73@0@2A4040T@00l83`0<1@`0
3@L;00h8300=1`/00P0>20X200l92`0`02HP8`0M61`01P85014<400E41@03`X>00X52@0D3a<08A`P
07agN`1<Ad/05Q4E0107300C2Pl040L<00`62P0?2@d03`P?00`73P0:1@`04PlF00`94P0=2Q<0BdQA
01D?7@0E3a/05A0I06AOIP0D41D04`lB010<3@0<20T03@P<00h93`0:1@/030L=014:4@0<1PX03PP<
00@00P0E3a<01@0301TC5`0N61`05@lC00d72`0>20`03`T=300>20`Dooooo`006oooool01@0=1`T0
3PP:00d72@0;1@L030H800<03`T;0P0>20X200d72@0<00h93@0A310040/?00d8300>2@d04PdA010;
3`0<1`/03@P<010;3`0?2Ph02PD91P0?2Ph03@0<1`/03PT=00l:3P0@2`l03PT=00d83P0?2Q4030L>
00T42`0F4AP04@`C01@?5P0=20l00P0<1`h02`0=20l03PT@00l8400G3Q<03P<9020E6`0A20d07QDJ
01XA5P0=1`/030L;00805A0D00<061<G01TD600>2@d00P0>2@d06P0?2Ph040/?010;3`0W8RH07aXN
00l:3P0I51P040/?01XE6@0G4QH040/?01TD600E41@03`X>014<400B3A404`hB01@?4`0F4AD04PdA
010=3`0A40h03Pd;01<B4@0J61T06ALJ0P0G5AP05`0D4QL04Q0E01@B5`0G5AX06ADM01PB7P0C41/0
5A8M01LD7`0G5B009B<^03Hd?`0L72H051@N020P:P0C5Qh051DJ01LH7@0D5AX05AHK01/L8@0G61d0
5QLL008061TN00<05AHK018C600B4aP00P0G61d0600E5Q/04a@I01@E6P0I6Ql061TN01HG700D5AX0
5AHK01LH7@0J72806alX00hB7@0O8bh00`LB01`P:`0E6BD061/Z01HI:00D5bH08bHg01XM;P0C5RL0
6b4a01TO;`805Q`/00T06Al^01/Q;`0J82h06Al/01@J9P0B62@06B0[02@[=@0K8Bd00P0Q9c<0700M
8bl06b<^01hV<@1EGfP09Blh01TS;00O;3@072Tb01l/=00M:c@0@e9J02@c>P0L:S<082lf024`=`0L
:c808c8i02Dd>`0Q;cP07bdf020^=`0N;cL04b@/01PY<@0a@T`08C8l028c?@0]?TP202/lAP0:01`]
=`0S=3h05bPb01/W=P0K:3P07b`l02XgA`0/?4/0:SY902dmC080<49@0380;d5=03Y>F@0O<ch09CM2
01`^>00K;SD08C@i02Hi?@0V>S/09STm028e>`0S=Sd0?U1J09:T/00/?TP06B`c01d`=`0S=Sd083<j
02<f?@0O<ST09SU002XmA00X>d80;3m602Lj@@0M<3D0:3`m02`o@`0Q=3X08SA002PhA`0X=dT0:CQ;
02`iC00U<T<06BHg01h[>`0T<Cd04QlX02Db>`0R;cH0=T=9018P8`0O;C007R`_01XW;@0E8RT07R/d
01dZ=080628[01d072H_03M1BP0g@TP07bP_01XS:P0J8bP05QdS01`Q9@0A5QX05Q`Q01`S;@0O9c80
5alZ01/Q;@0E6bL04aTU01dQ;@0E6BD06Q`X01lQ;@0F62@051LQ01/P9P0C6ah04QXM01@L7P0B6Q`0
51TL01LM7@02018H60805Q`J01<05adL01TP9P0G7RH092/c00T@600E72<061lU01`T9`0I8B@05alQ
01dU9`0F7al06b<U01PR900I8bD0628T01LQ8`0L9BH05QhP00807B<S01l0728R00lC4P0G6aX0ATY9
01/O8P0J7R406AdP01PL7`0G6Qh05QTN014D6@0G6R005APO014D6`0C5Qh03a8K01DH7`0A51/09RT`
04iAF00L7bH051LN034d>`0E61l0AdYA01<F7`0M82T03a8K01LJ8`0I72D05aXS00804QDN00d051LP
01PK900C5Ql04aHO01LJ8`0E62404QDL00h>5P0H62006ATQ01XJ8P0@41P06QXR00805ADM00H04Q8J
014A6@0E5Ad05aLO01<B600F5A/2010?5@0@00d<4P0D4aT04Q4G01DD6P0D4aT04Q4G01@C6@0A41H0
3PdC01<B600D4aT05QDK01TH7P0@3aD07ahT00X93`804a8H01<03`hD02XY;P0C4A@061HI01TG6P0D
4QD03P`=018@4@0C4Q0081lM014@3@0K6QH05QDA01HE5`0H5ad02`X?014@5@0L6b0040hA00803@/>
00`040`=014=3P0B3Pl04`h@01LB600<2Pl04Q0E00l=4P0B41D04@lD00l=4P0@3Q<2014?508040hC
1P0B41<03P0A3a8040hA010>4@0?3A0040hA014?4P0G4QH00`0201<>4P0300806A@H01D@500@2`l0
2`H:0P0H4aL0100@2`l01003018<3P0A2`d2010:3009014;3@0B30h04P`>01@>400F41805@lA018<
3P0@2P`03PT=00804@`@0P0@2`l03`0A31002PD;01LB600:1@/02@@:01LB5`0?2Q003`XA01@?5@0W
8RP0:2<Y01LB5`0C3Q803@P<010<3P02010<3@08018>3`0@30d04`l@00d92P070`@04`l@01LC500<
20T600h:2`0801<?401`K6d061@E01DA4P0;1`P05Q8C018>3`0?2``200d92P0800h:2`0?2``03P/;
00h:2`0S7b002@H601<?400?2``200h:2`8030P90P0>2P/0100D41403PX;018>3`0A3@h3010<3@0;
00l;300<20T04`l@01DA4P0?2``04Ph?00<0000E4A8020@501@@4@0<20T00P0>2P/02@0?2``040`=
010<3@0B3@h040X<00d72@0@2P`04P`>014;3@0200h82P0501D?4@0>20X03@L901@>400@2P/00P09
0`<0600A2`/02`D5010:2P0?2@T01`4101PB4P0>20P05Q0@00d8200<20L03PX9010<2`0>2PT03@T8
00h:2@0;1`H02@D400h:2@0I5A@0510?014=3@0=2@P01`<2010<2`802PH500D05a<B010<2`0@30/0
40`;00l;2P0200h:2@05018>3`060P<040`=00L3100H51D00P0>2P/05@0@30d04@d>010<3@0C3a00
518E01TL8`1VJWD0m?So0>obn`19BU@05QHP014@600@3aL03PdE00h;4P0=2Q403@/@01D@500H4Q@0
7QPJ01XD5P0200d72@0>00l92`0<1PP030H8010:300A2`d03@L900L10`0C3@l01@0101H@4P0>20X0
81XL014;3@0?2@/200d72@0300h82P0?2@/030H800<03`T;00@04@/=01<=3`0?2@/03`T;0P0>20X2
00d72@<040L<01003`H;00d42@0<0`P03PD:01483@0@1``03`H;01483@0C2Pl02`D900L11@0@2Ph0
2@@700X4200K5AT03@L;100>20`03@0;1@T04@/?01H@500@2Ph03PP<014;3`0;1PT0FE=G00P21P0?
2Pd05@lC018<40080PH00P0;1@T0@@0<1PX03@L;00d72`0?2@d03@L;00X4200>20`04P`@00l93@0<
1@/03PL?014:4@0@2A003@H=00`62P0=1`/03PP<00d72@0>20X040X<018<3P0F4A@030L;00X52@0<
1`/020<700l:3P0:1@T03PT=01D@50080`L06A@H00d8300B2@h03`H;01483@0@2Ph030H:00`5300C
3QD06QDL00X73P0C41T0>SM004a9DP0W8Bl01@0;01LA6`0300D06QDK00d8300:1PL02@D600d8300=
20h020<900l:400;10/040X>00l93@0C3A40?SPl02<M8@0@2Ph04@/?00802P@800<03`T=00X4200?
2@d01@0?2@d600d72aCooooo000Kooooo`0>010:300?2@/03PP:00h82P0?2@/040X<01`F600E3a40
3@L900/51`0>20X04@/=014<400?2Ph200d8300400l:3P0A310040/?010;3`803`X>0P0>2@d06@0A
31005Q4E010;3`0>2@d04PdA00/62P0@2`l03@P<01dH700D3a<01`8601<>500@2a<02`D?01TC7@0J
51h02`D?014;5@1=Ae407QPR01PB700E3aT0100801D>5P0C2A000P0B1`d01P0B2@h05@`A01H=4P0B
31003`X>00L21P805Q4E00@0I5mS018=4@0;1PX04`hB0P0:1@T02@0A310030L;00l:3P0C3Q8040/?
018=4@0J5AT06A@H01D@5002010;3`0I018=4@0;1`X05a8F01<>4P0E41@02PD9018=4@0G4aH05Q@E
01@B4`0C4A<04Q0C010>4@0?3A4040hC014?500C4AL05A8I01LD6`0I51d0618N01<@6`0B3aX0514L
01HD7`0201@B7@0B01<C7@0D51h05ADO01DH800C51T030dA01TJ7P0K72007QlS01LH700H6Ad07b0T
01XK7`0?41@05AHJ01XK800D5AX05ADM0P0H62008`0E5Ad04Q8J00X:4P0G5al06a/S01DE7@0G5al0
4Q@K014E7P0D6bD06Al[01<I9@0C6BH06Al]01@J:00H7Rd06Al_01LM;@0F72`06Al_01lU=@0R:3P0
8BLg01hT=00K8C006b4_02@Z>00C6BH06b4]01@J9P0L8bh0=Se701dS;`0Q:3<07bLb00806R8]01D0
7bTc03]5C`0Q;CH0:3Dn01`Y<P0Q;CP0934j02Dc?P0N;3H08Blh00dK9P0P;SL09C<l02<a>P0O;CH0
7B/d01`Z<`0N;3D07bdf020a>`0Q<S`00P0R<cd01@0Q<S`0834k02XkA@0a@T`08c@n0080;3e50140
5bPb02Te@`0B82d07bdj02Db@P0^?Td0;Ce<02/kBP0a@e40;d5?03=5D`0jCE/0:ci<02i0C@0W>D<0
9SU002/nA00202e0A01N0395B@0]@4H08SDk01d_>@0Q<cl093I002@g?P0`@dX0>4]B02<f?@0K;SD0
7S4h01lb>@0R=C`09CPo02Pk@P0[?TD08cLl024f=`0T>C`07c<i02Dg@`0]?D`0:CU802LgA`0[>4T0
9c=4028^?P0T<4008bhk02D_>@0K9Bl07BL_02Ha=`0M:2`082/]01hY;@0M:2h06RD/01LQ:P0T;SP0
?dUB02La>P0H8R/05b0W01<L8`0a>3l072<Y01lV;00R9b`07B8V01/P900K8BH0=ci601lX<@0C72D0
8RTc014H8P0F72P041@P01<G8`0F62D06Q`Y01lQ;P0K7BT04aPN020U:@0K82@03a@G00P=400D6A`0
6R0P00hD500D7A`03aPE01<L6@0@6AL051`O01@K8@0U;3805ahT01<J800L8bT041PK01dU:00S:bh0
6B4S01XR900O9bT05R0R01DN800>5QP08BT[014H6P805adM01P0724P01/O7P0G6aX06AdL020T8`0F
6Qd06alR00X>4@0Q92T05QTN01XM8P0>4AP04aHN018E7P0>4AX03a8K01DH8@0<3aP05aXS02T/=@1?
DU/071lX00/>5`0K7RL201HI8P0801dP9`0@4aX03a8I010C6P0B5A`06QdT01HI800@4aX201HI8009
00/>5@0C5Qd0CU5H02X]=00B5A`0=3@k02DV:`0@4AH04a@I00805QLL00<05aPM01@E6P0D5AX00`0C
51T0500G5Q`020L=01`K8@0C4QP06aXP010?5@0F5A/051<I01<B600D4aT05QDK01LF700I61h040lE
01LF700>3A<01`H<01XI7`0F5A/051<I0P0B4AL04P0D4aT04Q0F010>4`0B41D04a4E01@B5@0F51L0
518C018@4@0F5A<06QTG01TH5P0G5Q@051<F014@5P0A41D040lD014@5@804Q0C00P0518E014=3P0>
2P/04`l@01<>3`0I51X05Q@I01<A5P804@lD00L04Q0E00h<4@0>31404Q0E014?500<2Pl03P`A00H0
3P`?00X01@<601DC5P0C4A@02@L:01<A500A3a805A0D00l:3P0G4QH071LK0P0A31004`0E41@050lC
01@?4`0B3A404@`@010;3`0@30d04`l@00d92P0?2``0510A00l;300E4A8040`=014=3P0=2@X0510A
010<3@0@2`l00`0A3102018=4@805A0D00@04PdA00l:3P0>2@`03`X>0P0;1P`01P0B3A<06QDK00`7
300B3A404@`@014=3`@04@d>00H04Ph?00l;300>2P/03`/<014=3P0B3Pl2010<3@803`/<0P0>2P/0
3@0C3a00<Bd^01`H6@0C3a003PX;00X61`0<20T0510A01<?400=2@X03PX;00/7200@30d0100?2``0
2`0>2P/03@T:00d92P0=2@X04`l@00<0000B3Pl040`=00/7200>2P/040`=00803PX;00D04Ph?014=
3P0?2``05A4B01<?400200l;30803@T:00X040`=01@@4@0C3a0040`=018>3`0C3a0040`=00h:2`0<
1`T020840P0?2@/0100>20X04`d?010:300<1PP2014;3@0400l92`0A2`d03PP9010:2P803PP800h0
40X:01<=3@0B30`04@/;00l92@0=1`L03PP8010:2P091@@05A4@00h:2@0A3@`05A4@018>3@804@d<
00@030T800P40`0810<05a<C0P0>2PT200d9208030P700l03PX9014=300=2@P02@D400d9200<20L0
4@d>018>3`050@805Q8C018>3`0C3a002PH701DA4P0810D00P0>2P/01P0M6ah061PP02DX<@1cMWl0
MgN102TY<P80410H00L02PXA018A5`0000D05QDK0040100>2@d04@/=00804`d?00<03`T;00`6200>
20X01P0>20X01P0@2P`04`d?01D?4@0A2`d02`D700l92`8040X<0`0A2`d06`0;1@L03`T;00d72@0m
=cT03@L9014;3@0C3@l040X<00l92`0@2P`04P`>01@>400A2`l0100201`F6P0@2Ph0100201PB5P0>
20`03@L;00h8300@2Ph03PP<00`62P0C3A404@/?010:3P0300l93@0<00h8300<1PX03`T=010:3P0=
1`/03PP<014;3`0G4AD0HeeQ00l93@070@D05@lC0P0@2Ph00`0?2@d03PP<00h8300200d72`0@00l9
3@0C3A404`dA014;3`0?2@d040X>014;3`0C3A404P`@00l93@0?2@l02`@<00@0100Y8RT0100401@>
4P803`T=02X04P`>00h82P0:10H03@L901@?4P0=20`02`L:010;3`0?2Ph03PT=00L21P0M61`040/?
00l:3P060@D030L;01483@0B2@h04`X?010:3P0?2@d03@H=01<>5@0300D03``C024N9`2>Ri@0gmcU
04Q2D00A2aL050lH00L22@080`T03`X>00L3100810D040/?020K8@0=20h03@P?00l83`0?2@d200h8
308040X>00h02`D900h8300@2Ph04@/?00h8300<1PX05@lC00h8300:10P02`D901D?4`0500<03`T=
00h830<030H:00<03@L;ooooooooool04_ooool001_ooooo00X040X<00l92`0>20X03PP:00l92`0@
2P`03@L900h82P0?2@/040X<0P0A2`d01P0?2Ph03PT=00`72`0<1`/03PT=00l:3P804PdA0P0A3102
010;3`0C01/G6P1]J6`0HEaP01D@50080`L04PdA00l:3P0F4AD08QdQ01/F6P0=20`03@P>00h84@0@
2Q@02P@>00l94`0D3QP05Q0J05]EG`0201D?6@0700l94`0J51h03`P@01P=500E2Q0050T?01893P02
01<:3`0<00l93@080`L06aHJ02@O8`2?RXh06QDI010;3`0>2@d04`hB014<400@2`l04`hB0P0B3A40
1@0C3Q803@P<00h93@0D3a<05A0D00805Q4E00h04`hB014<400F4AD04PdA00`72`0E41@0H5]O02DQ
900S828061HG01`J700K6A/05A<F018@50804@lD00X04@lE01<@5`0D4AP0514I01LC700H4Qd04a0J
018?6@0D4A/05QDN0P0C4A/02P0C4a`051@M01DE7P0E61l06a`P018C5P0D5AP0@T=606]/K`0e=ST2
01TJ7@0701DF6@0F5aX06Q/N01@E600H6Ah05aLO01DE7@0201@D700@01HF7P0P82P06ATQ01`L900G
5al04Q8J03Dg?P0M8B`05QdW010G8P0F72L06b8^01/Q;P0C6BL061h/01TO;P8061h^02D06R0`01lU
=@0W;Cd08BLg01DK:`0A5bH06R0^01dS<@0X;S/06Al[01hT<00S:C@07bH`01hV<00M9C0072@^01XS
;P0J92h06bD_028]>00G8bh07b/f01PU<P0N:cL06bPd028`?00N;3T07R`h01PV<P0M:cL07R`f02@b
?00Q;cT082hh020^=`0Q;cP08S0i00808c@o018093A002<c?`0Q<S`08C8l028c?@0U=Sl0;Sm802`m
A@0V=ch0:CY202@a>`0J:3@07B/g028`?00[>dT09SI402LgA@0_@Dl203E7E@1503A7E@0`@e40<4=A
02TkB00W>T@0:ci702m3B00`A4P09c/o02Hj@00hBe409c]201ha>`0Q=Cd08SHm02`oAP0dAdh093Ln
01hb>@0U>3l0:3a302Pk@P0R=Sd08CDl02Lj@@0W?4009C`m02Lm@@0U>T00:3]502XkB@0U=DD09cE5
02TeAP0T;cl07RTf01lZ=`0N:CD0628/02@^=`0X<SX07RT]01lZ;00L9bT07RT[02<^<P0U<3L082Xc
02D_>@0P:C8072D]028/=00R:c80624X01DL8P0C6Ah05adR01`Q9@0J7b8061dP01LL800B6B405AhV
01<L900F7BL06R4[01LN:@0S9c<061`X00<05QPV01@0<39001dQ:00Q9BX05QXO01@I7@0A5QX04QLJ
01HM7`0C6Q/05QlN01DN7@0G81h0624P020X:`0Q:2d072<X010G700M9BT06R4V024Y;080620S00`0
4QXL02<[;@11BD`07BHX01DM800B6Qd082HY014G6P0F6ad05AXK01PL7@0F6QX2018E500:01LJ6`0M
8B@05a/O02DY;@0>4AH07B0U01LJ800C5Qh05aXR01DH8@8041<M01405ALR01HH8`0I6bH03Q4K01lQ
;00>41/05QTS018E7P0H6b@03a8K01@G7P0F6B006ahU01@G7P0H6b804A@K01@G7P0201dP9`0>01<F
7@0I72<02`hE01dP9`0B5A`04aHM01DF6`0F5a`04Q<H01LH7@0K72404A8G018C600C51T2014B5`0<
01@E6P0G61d04a8H01TH7P0=318071/Q00/:400J6Al05QDK01@C6@0B4AL04a8H0P0D4aT0200C4QP0
51<I01DD6P0D4aT04a8H01DD6P0F5A/051<I0P0B4AL02P0D4aT05A@I01HD6@0G5AX05A<H01<A5@0D
4QD0518D01<A4P0D4Q<201HD500601@C4@0C4QD04A0F014@5@0@3a@04A0E0P0B41<01P0D4QD05Q8C
01@@4@0G4a@05A0A01@?5@804Q0E00T04a4F01@B5`0G5AX08R0U01LE6P0=2a003`dB010>4`0C4AH0
1P0@3Q40500H5QT03@/>01HD5`0U8bH06aTL010>4@0B3A003PX<01LB5@0L5aX05A0C01HA500B3Q00
4Pd@014=3`0@2`h03`/=00h:300=2P/04@h?0P0>2``0300C41403``=01@A4P0E4Q<02PL800h;300B
3a004@h?014<400B3A804`hC01@?4`805A0D00h040/>01<>4@0B3Ph040`<00h:2P0>2P`05A0F02XU
:`0C3Q@03PT?018=4P0B3A4040/?010<3P@040`=00@04@d>010<3@0?2``040`=0P0A3@h3010<3@@0
3`/<00/0510A01<?400>2P/03`/<00l<300>2P/04@d>00L4100C3a002PH7014=3P0300l;2`<040`<
00H04@d=00H20P0B3Ph030P8010<300@3@d200h:2P0>00l;2`0>2PX03PX:00l;2`0@30`04@d=01DA
4@0J5QH0510@00d92@0?2``04@d>01<?400B3Pl3014=3P0=00h:2`0=2@X03@T:00l;300A30h03@L9
014;3@0>20X030H8018<3P0A2`d030H8010:3002018<3P0:01@>400=1`P030H600d71`0@2PX05@l?
01XD500A2`/040X:00l92@803PP800d03`T9014=300@30/03@T801@@3`0>2PT04Ph=00@1000K5aH0
4`l>00d9200Y9B@0;b/Z00<040`;0P0?2`X200h:2@03010<2`0?2`X03PX900804Ph=01X02`L8018>
3`0B3Pl071PI01<?400>2P/04@d>010<3@0D41405A4B01<?40081PT02PT@00d>5P0O7bP081lX00h>
5@092@h03PhE020P9@0820/071/Q01LG6P0D4QD03`/<010:30@03PP:1`0@2P`200l92`8040X<0P0>
20X200l92`8040X<00X04@/=00l92`0B30h02`D7024K7@0>20X040X<014;3@0@2P`03`T;0P0@2P`0
3@0A2`d03@L;01/E6@0910L040/>01dG6`060@@03PP<00d72`0>20`040X>00h8300<1PX00P0>20`0
1P0=1`/03PP<00h8300>20`040X>00h830803@L;00P03PP<00l93@0B31003@L;02PR9P0500<050hB
00h830D03`T=00X04@/?018<400A2`l040X>00h8300=1`/03`T=00h8300;1@T03PP<0P0B3100600B
2a405@hF01@=500d;C@03`X?01TC5`0=20/04`dA01D?4@0A2`d02`D700`6200?2@`020@7010;3`0<
1`/03`X>00d8300?2Ph040`?03dh?00E41@03@T<00h:3@804PT>01`050/@018<400A2`l040T@00h9
400D3aH0924X02/X<@2;R940c<WA04DoC@0@2QH03`TC01TD6`0>2@l03PX=01dI6P0D41403@P<01`G
7@0?2Q004@`B00d63@0=1`/03PP<00l93@0B310050hB0P0?2@d02P0@2Ph03`T=00h8300=1`/05@lC
00d72`0@2Ph0;2HZ02XT:00>20`2014;3`0400l93@0>20`03`T=00l93ACooooo000Kooooo`803`T;
0P0=1`T200l92`0700d72@0@2P`04P`>018<3P0?2@/030H800h93@0400d8300300h93@0@2`l040/?
00@040/?02@0@3/o01HA5@0=20`03`/>014<40080`L03@P<010;3`0>2@d03`X>00h93@0;1P`03@L@
01TC7@090`d03`TC01PB700<1Q00618L010:50070@/0M6ih00<01`0D3AD04@H=01873@0C20h05PdB
01XA5P0L4aP04`dA00T4200@2`l04PdA00l:3P0E41@2018=4@0300d8300C3Q804PdA00803@P<01P0
40/?01<>4P0=20`03@P<010;3`0A310050lC01LB5P0E41@04`hB00h93@0E41@05Q4E024L802MV9`0
?3Lk01<@4P0E4a@06QPK01LE600@3Q404@lD01<A5P0B41D3018?5P0:014>5`0E4AX0618L01@A6P0C
41T0514J01HE7@0I620061LO01HF7P805ADM00L051LM014B5P0J6ad08b@V09ZKW@3nool0N7Uk0080
7AhP04006AXL00h?4@0<3@l05aPK01PI7P0G5al05ADM01@D700E5Ad05aLO01@D700>3QH071`T01/K
8`0?3aL0;2hf02/_>00O9S005A`V01XQ:`0N92l06Al[01@J9P0F72X06Al]01XP;P0K8C40728b01XP
<00@5RH03aDU01LM;@0L8S405ad[03HlBP0m@e004QPT020V<P0Q:3<06B0Z02</=@0M9Rl072D^01lY
<`0P:S@06bD_01DQ;@0T<3`08blk01DS<00L:SL0;S];01HS<`0I9SH0524a01`Y>@0N;3T09cE2028`
?00Q;cX082hi024_>00R<3T08c4l0`0U=D80=P0T=4408S<m024b?00P<C/05bP`028c>`0N;cL09CHm
03a=E01oS9@08c4j024_>00L:S@06b`f02dnB00U=D809cU502HhAP0cAE<0;3m=02@gA@0`@e80;3m>
02/nC00Z?TP0:Si502Tn@`0Z?d<08cPm0314BP0X?4<09SY302a0B00V>T4093Po02Lk@P0Y?D@0<dM>
03I:D@0_@dX0;T9902Hj@@0Q=C`09c]202m5BP0/A4P0:41402ToAP0[?dX09cU702@c@P0W=4@0:3A4
02@_?0<082Xd01405b4Z02H`>@0c?T<08B``01lZ;00R;Bl07bX/01`W:`0I92T051hW01`V;`0S;3<0
8R/b01XS:P0H8BP072DZ01lV;00201/P901i01TN8P0F6Qd051PK01<G6`0I82H08BXa020Y<00?5R00
72<]01/R;00R9S80720/01/M;00H6RT051HU028T<P0J7BH06ahU00lB6P0E61l04QLK00lD600B6Qd0
72@V01DM7`0F82404Q`K01DO800A6A`05QhQ01DM80094A@05QhQ01DM800A6A`09Bd`06adM`0W;c80
72@W010H6`0C6ah05AdP02@/;`0S:2`05Q/O01@I700E6A`05a/L01DI6P0D5AL051HE01HG6@0C5aX0
3Q4F020S:00E61d06A`R00lB6@0?4Q/04QDN01<F7`0C5B405QPT01XL:0092aP07b4^020R;`0K7BX0
3@lK01HH900N8BX051LP014D7@0A51/010L>00X=500@4aX03a8I00d@5`0C5Qd05QTP01<F7@0E61l0
4A@K00`?5P082a806QdT01`O900K72405aPM01@E6P0B4aP06AXO00d>4`0B4aP051DJ014B5`0?41D0
51DJ01TJ7`0H5ad04A0F010?5@1NGF<051<I01/J800D4aT05A@J01HE6`0I61h06aXP01XI7`0D4aT0
6aXP014@5P0G5Q`07A`R00l>500D4aT04a8H018A5`0201<B600601DD6@0G5AX061HK01DC600B41D0
4Q0C0P0E4aH02P0D4Q<04Q0A018@4@0C4Q004a8E014@5P0A41D040lD014@5@0B41<2014?4P0@01@@
4@0E4A805Q8C01HA4`0?2Q003@/@00l=4P0A3a@04a4F01DC600e<cP09bDZ01DC600B41D0518G01TG
70H040hA00`020H900/9300`;S40>SPk01`J7@0?3A004Ph?00l;300B3Pl0510A00l;300@30d301<?
4007018>3`0A3@h04@d>00h<3@0@3Pl03P`=00d;300200h<3@0600/92P0F51D03@/<014?400@3Pl0
518C0P0B3A<04P0C3Q@04`hB01<>4P0C3a0030P9014=3@0C3`h04Ph=010<2`0?2``061<I030[<P0B
3A<02PD;018=4P0A310050lC01@@4P@0510A2`0@30d0200?2``061@E018>3`091@H040`=00l;300a
;Bh08AdN0P0G4a@0100>2P/01`<400d92P0=2@P200h:2@08010<2`0A3@`04Ph=014=300E4A001P81
00h:2@0K5aH200h:2@0X014=300?2`X030P700l;2P0A3@`03`/:00h:2@0<20L03@T800h:2@0=2@T0
30P900h:2`0@30d03@T:00/7200<20T04Ph?01HB4`0J5QL05Q8C014=3P0>2@/02P@6010:300?2@/0
3@L901<=3`0<1PP05Q0B02dW:@0V82803`T;010:300@2P/040X:00l92@0@2PX04P`<01@>3P8040X:
01003`T900h8200>20P03PP800d9200>2PT01`<200d9200:1PD03`/:01lK6P091@@04@d=01LC4P03
00004@d<0`0=2@P200`81`0300/71P0<20L03@T800803@T800L03`/:010<2`0D41404Ph?00`82@0=
2@X03PX;00804`l@01<05A4B00h:2`0D41402PH700h93@0300L04PlF01HC6P0C41L04@lD00X:3001
00@05QDH00H61P071`T0V9RI00h<3@0>2P/03`T;00<03PP:00<03`T;010:300@2P`0100@2P`01@0>
20X03@L900d72@0?2@/040X<00<03@L90P0>20X200l92`8030H800@02P@600X51P0E3a403@L90P0>
20X200l92`0A00h82P0=1`T03`T=00@00P0Y8bL01`8500P21P0G4AD03PP<00d72`0>20`040X>00h8
300<1PX03PP<00l93@0@2Ph00`0A2`l0300?2@d040X>00h8300B31006A<G018<400E3a<02`D900d7
2`0;1@T05a4E00T41`803PP<00D03`T=010:3P0@2Ph03`T=00h8300200l93@0P00h8300?2@d03PP<
00`62P0=1`/030H:00/52@0>20`050dC018;4`0600H030D<00D01@0F41@03PP<018<400C3@l040X<
00`6200=1`T04Pd@01@?4`0>2Pd02PD900@00`0@2`l06aHJ00<00P0Q72002PD901<>4P0B3A420148
3@0K01<:3`0A2`l04P`@018;4P0J5A`02PD<014>5@040@X03``E030]=P0@2QP06A<O01<>5`0>2A00
40/A014<400E4A804@d>00/62P0E41H02PD;010;4P0=1Pd03@L;00h8300?2@d04@/?00804P`@00<0
4@/?00h8300=1`/00P0=1`/01@0;1@T04`dA01TC5`0i<cL08A/O00<04@/?00@03`T=00h8300?2@d0
3`T=5?ooool001_ooooo00H03`T;00h82P0=1`T03@L900h82P0?2@/201<=3`05018<3P0A2`d03`T;
00d72@0>2@d0100?2Ph700h93@0d01LB5P080`L04@`@00d8300?2Ph06A@H010;3`0C3Q803`X>014<
400C3Q803PT?00`64@0D3QX02P@@00l95@0L5R803PPD00X5400C3AT06aDQ09fGX`0B31P04PXE0187
3P0C20h05P/A01XA5P0P5a`08QTN018=400C3Q8030L;00d830070PH05A0D01XE6@0H4aL03@P<01<>
4P0D3a<03`X>014<400F4AD06aHJ01@?4`0A31004PdA014<400B3A404`hB01@?4`805A0D00`061<G
01<>4P0A310091lS00P31`0A3A40518E01HD5`0A3a<03@/@014?500E4QP201<@5`05018?5`0B3aP0
4@hG01DA6@0H4aX00`0D4AP301DD6P0A01<D6@0D5AX05AHK01DH7@0>3a<07QlQ01`M7`1FEeT0XjBV
051AD`0G61X04a@F01DF600D5AL04A8D01XK7P0F5Qh00P0F5R0201LG8@0901HF800C4ad05QHP01dM
9`0H62803`lI00lA6P0R:C407BH]00806B8Y00H06B8Z01HO:00@6B804QXU01@L9`0F7RT201LO;00O
02D[>`0H7Rh051XZ01XP<00L8S4051XX01TO;@0U:cP05Q`X02`b?P0O9S406B0Z028[=00K92d06R@]
01lY<`0O:SD062@`01/W=@0K:3D06bTf024^?P0M:SX062De01DR<`0M:S/072Tj01l/?@0L:CT08Bll
020^>`02020^>@808Blh03d08S0k02De@`0U=D@09CE402De@P0S=3h08S<m01h_=`0H:C406BXb01X[
<P0U=Sd0<dA;06IcNP0O;SD0:3Ln02<a>@0F9bl08S<k02/lAP0`@T`0;Cm;02Dg@`0L<3/0;d9@02e0
C`0_@U40;d9@02XnB00T>3l08SLl02e2A`0[@4D08cPn02Lk@P0]@DX0;T9:02Di@00P=3/08CDl02Pl
@`0cAdh0<TI=02XnA@0/@4L0:3a302Di@00Y?D@0<TM>02i7C00Y@4H0:d5902e1C00Y>dT09CE302Le
@P0X=4809S4l02D_>00U;SL092df00807bPa05X0<CY002Pa=P0M9bT09c4b028/;P0O:2d07BH/01TR
:@0N9c007BH]020Y<00N9bh07RD[028Y;`0L8BH08RL[01hS9`0J7R405QXM01LK7P0H7B00:C0f01DN
8`0@6B002Q4I01/R:P0K8R`06AdY01hR;P0K7B`05aPZ01/L;P0F5bP05aLS01/K9@0B51h051LP01<F
7@0D6Al031<I028Z;@0C7Al06bDW01@N7`0K9BL041PK01LO8P0X<3<0620S01DM800K8bH041LM020W
;@1TJg408bX`01`S:@0B6Al072<Y01lU:`0X;C<05AXP01<G6`0<3a@04aHK01HH700G61`05QLK01HG
6@0G61X02`lB014D6@0>4AH0=3Ln01PK8P0C5Qd04aHO01DG8P0E5b<05QPT01PJ9P0K7BT04A<P01XL
:`0G6BH051HS018D800I6bL05aXS00/>5`0D5b0201<F7@0?034d>`0R9BX03A0E01@G700F6Ah03a8G
01<F6`0I72403Q4F01LJ7`0K7R<07B0U00hA5P0E5Q/051DI00804a@H01/06AXN01DF6P0F5a/05QLK
01<D600@4AD04a@H01LH700P7bD05QDK01/J800J6Al07A`R01LF700M72806QTO01LF700D4aT04Q4G
01<B600B4AL06APN01<B600S8RP0;Rdc01HE6`0C4QP00P0B4AL201<B600901<A600D4AP05A8I01<A
5`0B41D04a4F01HD600G5AP05A<D00804a4B00X0518C01@B5P0A41H04A0E010?500A41D04Q0C014?
4P0>30l04@d>0P0B3Pl0100E41405Q4G01@B5`0E4aP301HD6@0601/I7P0E4aP040hC010>4`0B41D0
7Q`Q1P0@3Q40300K6A`06ALJ01/I700E4aH03P`?01@B5@0B3Pl040`=014=3P0B3Pl03`/<010<3@<0
4`l@0P0B3Pl0100A3@h04@l@014?400@3Pl200d;3003014?40091`P03P`=00803P`=01H020H700l=
3P0C3Q@04`hD018=4`0A310040`>010<3@0=2@X04Ph=01DA400D40d04Ph;014=30060@L04PdC00/6
300?2Q004@`A01HA5@0@2`l040`>3`0@30d03P0A3@h030P900h:2`0J5QL03`/<034];P3@c<d0FEEF
00H20`0A3@h040`=01@@4@0300003@T80P0>2PT01`0@30/04@d<018>3@0810<03@T800P40`0/:2L0
0P0<20L0300>2PT04@d<00l;2P0=2@P040`;014=300@30/04@d<00l;2P0E4A00920O024M7@<040`=
0P0?2``200`82@06014=3P0D41404@d>00d92P0=20T03@L90P0D3Q00300@2P`050h@00l92`0B30h0
7QPJ01D?4@0;1@L05Q0B01D?400A2`/040X:00l92@803PP80`0@2PX200l92@0700h8200C3`h07QXI
00l;2P0;1`H04Ph=00h:2@02018>3@0400l;2P0=2@P02`L600h:2@804@d<0P0@30/300l;2P<03PX9
00h03@T800l;2P0;1`P02PH700l;300B3Pl04`l@00/7200:1PL04Ph?00`82@0S7b002PH700h93@80
3@P>00`03`X@00`73@0;20/04a4B01XE6@0>2``05A@B00`:2`0J6AP00@0000`82@0@2P`2018<3P03
010:300>20X03PP:00D03PP:00H02`D700`6200@2P`04P`>010:300;1@L200d72@803PP:0`0?2@/0
1`0<1PP04`d?018<3P0U7b404@/=00d72@0>20X00P0?2@/200d72@0@00h:3@0a;300P7]o01hI7@03
00804`hB00d8300<1`/03@P<00l:3P0=20`02`H:00X4200<1PX03@L;00h830<03@L;00X040X>00/5
2@0?2@d05Q0D014;3`0G4AD02@<7018<400C3A403`T=0`0>20`01@0?2@d040X>010:3P0>20`03@L;
00804@/?01003`T=010:3P0>20`04P`@01PB5P0A2`l02@<700d72`0A2Q0040TA0109400D3A@04@XA
01LA5@0;1@T03PP<0P0?2@/03P0>20X03`T;018<3`080`L03`X>010;3`0C3Q803PT=00l:3P030080
4PdA00<00P0B3A40@3/o0P0@1``06P0A20d03`T=010:3P0A2Q4061<J00T42`0A3QD04PlH00H3300B
3aP05a4O01XD800500T020<:01<>500?2Ph02`L801<?400E41@06A@J00T42P0?2Q0040T@010:3P0?
2@d03PP<0P0?2@d0100C3A404@/?00l93@0>20`200d72`0600l93@0F41@02`D901PB5P0:1@P06A<G
0P0@2Ph400h831Cooooo000Kooooo`803PP:0P0=1`T200h82P<040X<00@04@/=018<3P0C3@l03PT=
100@2`l0100>2@d03@P<00d8300>2@d300l:3P0I01<>4P070`H040/?010<3`0@2`l04@`@00`72`0B
3A405A0D01@?4`0?2Ph030L=00d84P0A2aL07aTU00`64P0I4al06aDQ010<5P0B31P05@lK00h8500H
4Qh03@D@01873P020146300D01893P0E31405PdB01@?4P0<1`/050lC010;3`0E41@05Q4E01dH700K
5QX04`hB018=4@0C3Q804@`@018=4@0F4AD06A@H014<400>2@d4014<400401<>4P0E41@04@`@01dH
70804`hB00<03PT=01dH700C3a<00P0D4QD01P0B41@04Q0E01DC600F51X0514H01@A6@<0514J01/0
5Q8I01LB5`0E4aP05A8H01DC5`0E51T03`hC00l?4P0@4AD04a@H01DF6@0F6Qd061TK00h?4@0F5aT0
8B8T02//;P0I6Q`07AhP010A4`0D5AL07QlQ01HG6@0E5QT05QHN01LG8@0F5R000P0G5b400`0I6B<0
5QHP01TI8`0201HF800401dM9`0I6b@05A`S01DN90805b0V01D05QlV01HO9`0I8R/0620Z01TR;00L
92l07BD`01XR;`0G7Bd07B<c01/Q<@0E6b/05A/Z01dS<@0I7bd05Q`Y01DK9`0Q9c<07RD`02<Z=00M
9Rl00P0G8BX0400J92h06bHa01LS;`0M:CL06bPf01@R<00H9SH093=305QWM`0Y=TT07R/n024^@00M
:S/08c1101XW=`0R<3d2028`>`2>024_>@0P;SL082hi02<c@@0T=4<09CE402De@P0U=T0093Do01LX
<00K;3@07Rlg024b>@0P<SL0838f028_=00M;3007Rda01/Z;`0Q<cP07Bhf059SJ`1cQHh0=TQA02@f
@@0X?4L09SU702XnCP0^@U40;T=@02XnBP0V?4@09S]202U0A00_ATX0:3i402a1B00^@d`0:Ci602Hk
@P0U>d4093Y002@i@00S>3l08CLm024f?@0R=ch09C]102ToA@0/@DP0;dM=02]4BP0Z@T/0<TMB02m3
C`0[?D/0:3Q602Le@P0V<Sh09S8j02H`=P0V;cD08b`c028[=00O:2l09c0f02D_<@0L9RL082X[01hX
:@0Q:bd09c0f028[<P0P:C808RXb01dU;00G7bH05ahT01PO9@0F6al06QlS01LL800E6A`061`O01/O
8P0M82<04a/N01/T:@17D5L082L_01<J8P0E72H05QXV01dQ;@0H6RT05AHX01lP<P0M7bl07A`Z028R
;`0K6RL06A/W01LI900I7BH06B0W03]2B00K9BT082X]00lI700D7b406B4T01`T9P0^=SP08b/^01dU
:00L92L07B@Z01PO9@0T:c407bH/01LN900F7B<06b0X01TN9@0M8BT02a0G02hb>@0I72804A@I01<E
6@0E5QX05QHJ01DE6@0B4aL04A@I01PK8@0@4aT0>ci501TL8`0N8BT071lX01/M:0806A/W02/061XV
01PJ9`0G6BP05QPX01TK:P0G6BH051HS00h@700D5R804QDN01@G800?4QT082<Y04Q;D@0Y;3403a8G
01<F6`0@4aP02`hC01@G700A51T04aHK024T:@0d=c`082<X018E6P0@4AD05AHJ00l@500F5a/02``@
01dN8P0E5QX04a@H01@E6@0E5QX04a@H014B5P0/:c4081lU01HE6`0C4QP04Q4G00@05A@J0P0D4aT0
1`0C4QP05QDK01@C6@0B4AL071/Q01XI7`0A41H00P0B4AL301<B600A018@5`0C41L0514H01@A5`0C
4AH0518G01LE6@0F51L0518D01<A4`0C4A80518C01<B5P0A41H04A0E010?500A41D00P0B41<0200?
3A005A4B01LC500C3a004`h?01@?5@0C4AH05A<H0P0D4QL00`0C4AH0518G014?5002014?500300l=
4P0C4AH040hA00D040hA00H0:2HY01lM800?3A003`d@01@B5@0@3Q43018>3`0301<?400E4A8061@E
00H040`=00`04a4B010>3`0@3Pl03@/<014?400M6a`0AdE6010>3`0E4a@03@/<00h<3@0?3@h2018=
4`0?014<4P0A31004@d?014=3P0A3@`0510?01@@3@0C3``04Ph:01<?3P0B3A<03`XA018=4`0H4aT0
3@P=00804PdA00<04Ph@018>3`0B3Pl00P0B3Pl01P0@30d04@d>014=3P0A3@h040`=00l;308040`=
01004@d>018>3`0B3Pl04Ph?02/W:00I5AH040`=014=3P0R7Ql0PGen03Lc=00;1`P061@E014=3P0>
2P/040`=0`0?2`T3010<2P0:014=2`0;20L06aLF03hj>@0:1PD040`:00h:200?2`T040`:014=2`80
4Ph<00d03PX800d91`0;1`D02`L501DA3`0H51@03PX;00`82@0=2@X03PX;00l;300@30d03PX;0080
30P900l03@T:00l;300@2`d02`D7010:300?2@/03@L901<=3`0B30h030H800d72@0?2@/04@/=01@>
400=1`P00P0>20P400l92@0A010:2P0A2`/040X:00l92@0>20P06aLF02TU900H51<04@d<01LC4P0?
2`X040`;01DA400B3Pd040`;014=300=2@P00`0>2PT300d9200D01<?3P0?2`X04@d<018>3@0@30/0
4`l>01@@4@0A3@h05Q8C00P41@0=2@X04Ph?01<?400?2``071PI00d92P0>2P/0510A010:3@0>1`X2
01H>4P0=00d82P0@2`/02`L7014=2`0@30X03P`900l=2P0A3@/03@L800l92`0B30h04`d?014;3@07
00l92`0700/51`0=1`T04@/=01@>400B30h03@L900h82P0200l92`8040X<00<04@/=00l92`080P@0
0P0C3@l00`0Q6ad030H800l92`0300h82P803`T;00h030L;00X52@0F4QD03@T<00l:3P0>2@d03@P<
00`72`0=20`03`X>00d8300;1PX040X>018<40804`dA00L040X>00l93@0E3a<06Q@H014;3`0?2@d0
4`dA00804@/?00D02086010:3P0B31002P@801@>4P0600l93@0P014;3`0C3A4040X>00h8300B3100
4`dA01H@500K5AT05@lC00h8300@2Ph04P/A00`53@0B2a803`P?00`5300A2`l03`T=00d72`0>20X0
3`T;010:300?2@/03`X=01LB5P1>BDd04`hB00h93@0A31004PdA00d8300?2Ph2018=4@0M00/72P0C
2Pl04PT>01483@0>20`03`T=0109400:1@`04PdD00d:4@0G51d04a0I00h;500@2QP04`dI02TT;@0Q
72<01P4700d8300;1`P06QHG01hI7@0L5ad02PD;00h9400A2Q404@/?010:3P0>20`00P0?2@d00`0@
2Ph04@/?014;3`02010:3P0700h8300G4AD03`T=014;3`0F41@02`D901PB5P02014;3`0400l93@0>
20`03`T=00l93ACooooo000Kooooo`0>00h8300=20X02`L800`62P0=20X03@T:00`62P0>2@/040`=
014;3`0@2`d03@P<00/62P0=20`200l:3P0600d8300;1PX03PT=00h93@0?2Ph040/?0P0A2`l02@0:
10D07A@G01H@500<1`X05@lC00`72`0@2a402@L<00h<4@0200`;400N01@A600?2A<091hX04]5C`0C
3AL02`D?01LA6`0D3QP05@lI00H02P0E3aT02@<=01094@0F3A4050/>01<:3@0D31005PdB01D?4`0B
31000`0400P32@0D3aD04PdC010;4@0B3A<05A0F01@?5@0;1P`02@@:0P0?2Q001@0A318050lE018=
4`0E41H05A0E00804@`@0`0C3Q803P0D3a<04`hB00/62P0G4aL02@L:00d8300C4A@040hA014?4P0D
4QD05Q@I01@B5`0C4AL0514H0P0E4Q/201HC700401LC6@0G4QP05Q<H01DC608051<H01@06QTN01TH
7@0G61X05QHH01HF5P0E5aL06Q/M01@E5`0E5QT04A8F01`M7`0D5AP03a0D00l@4P0I6Qd04a@H00h?
4@0i>Sh06QXR01PH8P804a<M03805QHP01`L9P0N7RP06a/U01HF800D51h061PR01`N9`0M92`06B8Y
01PP9`0I82P0620Y01DN9`0G7RP05A`W01DM:00I7b/061l[01@J:00O9C<06b4a01TO;@0L8S806b4_
01DK9`0A5bD06R0/02@[=@0Q9c<092/e01<L9@0J92d06B</01PR:`0J92h06bHa01TU<@0I9C<062Dd
01dZ>P0R;cl0528b04EBH`1AGVl08Bi0020]?P0Q;Sl0CU][04YGI`809C=002X0938o02<a?P0P;ST0
82hk020`@00R<T808c=202De@`0U=D809CI001TZ<`0D9Bd0834h02<d>`0O<CD09CLk01h]<00F9BP0
9C@g01l_=00N<3@07Blc02Xl@`0[?TD0:3]202PkA@0C9c80:d5<02LmB`0Z@4h0:Cm<02ToB@0^ADd0
<DQ>02Y1AP0T>d40<4M=02i5B`0]A4`0<DMA0316D@0]@dh202Y1B@0X02U0B00W?TH08STo01dd>P0T
>d40;dI<03A8C`0]A4/09Ce702e3CP0iCUT0<TIA02/mB@0X>DD09C<n028`>@0R;SD08B``01hY:`0N
:Bh082Xc02/f?00S;S<07BPZ028];`0R;2h09S0b02<];`0U;S<08b`c02H_=P0O:2d0624V01XS:00R
:Bl072@W01PM8@0A5QX041DI01<F6`805QTN024041@I010G7@063aH07RD]00894@0A62003aHP018I
8`0F6RD06al[01PK:P0D5bH07R4_028T<@0T9S8061XV01XL:00G6bH051PS00`C6`0h?dL05b0W028[
<P0@6b4072D[01/R:00J8RD072@W01dU:00^=ST072@W01dU:00E72800P0D6b40200J8BL05QdU01TM
:00I7BP092Pc01hR;@1>DEX05APQ0P0D5ah04P0F5Qh05QLL01<D6@0?41D05APO018E7@0O8R/05APQ
018E7P0K7RL05QPT01@F8P0C5B405ALS01HH900E5b@07Al/01<E8`805ALT01@071hZ01DG8`0F6B<0
4QDN00`?600K7RD04QDJ00X=4P0@4aP05aXO01TL8@0G6Ql04aHK018E6P0E61d03A0E018E6P0C5Q/0
1@P=00L:3`805AHJ01001`P<01/L800C51P0?d14010A5@0=3Q804A8F01TJ7P0C51P03@hB01<B600M
728010<901LF700>3A<061LM0`0F5A/02`0D4aT04a8H010?5@0I61h04a8H01`K8@0O7R@040lE014@
5P0@3aD04A0F00@04a8H00H05Q@I01LD6`0E4QT04a0G01DB6@0E4AP2018@5@04018@4P0B41404Q4?
018A50804A0E00`040lD014A4`0B41<04Q0C018@4@0O6a`08alP01TE5P0A3@h040hC014>5@0D4AP2
01DC600801@B5`0E4aP03P`A00h<4@0E4aP04a4F00h<4@0B41D5018@4`0600d;3P0>30d0518D01<A
4P0>30d0518C0P0D4140100A3@h03`/<014=3P0C3a05018>3`03014?400@3Q4030X=00803P`?01`0
5Q@F02XX:@2>S8d0518C01<A4P071@H04Q0A00h:2`0?2Ph040/@018=4@0D3a<05a8E01LC500B3Pd0
4`l>014=2P0?2`P040`9018>3@0=20`04@`B00d8300C3Q@040/?01D@500?2Ph03`/=1@0?2``0600A
31004Ph?018=400?2Ph03PX;010<3P0@2`l04@d>018=400B3A404Ph?059>C`0I5AH04`l@010<3@0>
2P/03`/<014=3P0@30d01P8301LC500300005Q8A010<2P@03`/800H03PX702LS800Z9R<04Ph;00D1
000O6aP200l;200500`81@0@30T0510=01<?300A3@X00P0;1`@01`0D40d04Ph;00d91P0=2@T03PX;
00l;300A3@h00P0B3Pl00`0?2``030P900h:2`02010<3@0?00h:2`0@2``030H800l92`0A2`d06A<E
02HP8P0L5QP040X<01H@4P0?2@/06A<E03Pb=00]9bP040X:00804@/;010040X:00l92@0>20P03`T9
014;2`0@2PX03`T900d71`0<20L04@d<00`81`0B3Pd03`/:00h:2@091@@040`;0P0>2PT00`0A3@`0
30P7010<2`02010<2`803`/:0P0>2PT08`091@@03@T8014=300?2`X0510?00d92P0H51D0;b//014=
3P0<20T03@T:00T51P0b;Rl0P7am010<3@0B3Pl030P901H@4P0D30l02`D701072P0D3Pl03PP800d7
1`0?2PP04Ph;01<?300=2@H030P500h8200=1`T030H800d72@0?2@/04@/=00H040X<00L03`T;00h8
2P0>20X04@/=01<=3`0B30h03`T;008040X<0`0A2`d0:P0C3@l02`D7018<3P0=1`T05Q0B00L10`0A
2`d03PP:00d72@0>20X040X<018<3P0?2Ph04`hB00d830080`L02@@801TD600=20`030L;00d8300?
2Ph03@P<00/62P0@2Ph04P`@01<=4@0A2`l03PP<00`62P0A2`l06A<G010:3P0=1`/040X>00l93@06
00@04@/?00l93@0B31003`T=00h8308040X>00d03`T=00h8300>20`03PP<010:3P0?2@d02`D900l9
3@0K5AT071HJ00l93@0;1@T030H:008040X>00P04@X@00`5300F3aH03PP>00L01`0:10P04`dA014;
3`<040X<01003`T;00`72P0<1`/03PT=014<400;1PX02`L:00/62P0400<05A0D00<00P0910P05A0D
01@>4P0E31404`X?0P0?2@d0500A2Q4040/B00d83`070`X06aDO00<02@0@2Q@03PPF00d74`0K5Ql0
2`H=00T42P0C3Q801P83010<3@0=2@`04PdC00P32@0>1`l03PL>0`0>20`0400@2Ph04@/?00d72`0@
2Ph04P`@01<=4@0@2Ph03PP<07QbMP0X8RH030H:00l93@0C3A404@/?01<=4@0B3102010:3P804@/?
5?ooool001_ooooo01H02`H<010=4@0?3A004PdC00X72`0:20/05Q4G00/8300=2`h03@P>00l;4002
00D030X?010>4`0A3a@0108700d93P0E41@03@L;00h82`0?2@/040X<0P0B2@`06@0C1PP050D80186
2P0B1``04`X?014:4@0>2Q402@P@00X:4P0F6B80000900T<5@0=2A004`hD01@?5@0C3Q@05a8H01XE
6`0N6Al020<900<0100J5A/02@@:01/F6P0C3P`00P0B30`01`0B3@d04@/=010;3`0C3Q<03`XA00d8
3`0=1a400`0@2Q@00`0?2A<03PPB01<=5`0201<=5`0:01/E7`0A2aD03PPB010:500<1Q004`dC01D?
4@0D41404Ph?01DA4P<04a4D03404@lD010>4`0@3a@04Q0E01DD5`0@41003Ph>01<C4`0@41804A4C
01DD600C4QL04Q4G014@5`0C4QX05A@L01LC6`0F4AP04`lF01XG800E51`07AdU01LH7@0E5Q/05ADH
018@4@0?3P`061DE01/L800B5QT051PL01/N8`0F6Qd04QDI00lB5`0B5QT04aHJ01PK800K7b8041<H
01HI8P0D5R80418N00lA7@0B52006adY01`N:P0A4al0418N00806adY02h05aTU01DI9@0D6RH05AXV
01@H900H7BT07bDa01LK9`0L8Bh07R@b01lR<@0K7bh061h/00X@7P0B62H0728^02@Z>00F72P07B@^
01HL:00E72H0;C@l05ELIP0]=3`0624X01`V;`0G92`0524Y01DR:`0L:C808Bhg028^>P0G8c006BDc
020/>P0Q;Sd0RiNU0<GAg`0Q;C/082`j02XfA00Q;S`0938o02@a@@0N;Sd07Bdl0P0N;Sd06P0N;Sh0
7bi102HeB00W=TT09CE502PhA`0[>dP07c0i018S:`0K;3<06b`b024c=`0_@DD093Hj024c=`0P<SH0
9cPo02Df?@0M<3H07C0g02XmA00Q=C`0<4A=02Di@P0S>T809Se70P0V?TP0?P0Y@TT0:dA;02]4B`0`
BDl0E6ed0319D00lEE`0:D9903=;E`0aB5P083M702e4DP0/A5009ce:03I;EP0R=Sl07S8i02Tm@`0/
@DH0;3m50315C@0_AE006Rhi02i2C@0X>T@09cU302<e?00O<3L07Bhe01`[;`0K:B`072X]024_<`0T
<cX08c8i01d[<P0J9bd07BX`01dY;@0U<3@0;CPl02<^<P0I92P062<W01TW:P0D8RD05R4S00lI6`0C
6ad051TL00X?4P0X;C404AHK01TM9P0<4a/05ahV01PO:@001@d05Q/T00@;4`0Z<CT05A`T0P0C6R80
5`0F7BD06B8Y01/T:`0K92/06B0X01`P:@0G6b@05ATR01PO9`0K8RX05ahX01TP:P0G7RP05A`V01PQ
:P0I82X072<]01XN:@0S9c009RXc04aAEP0M8RH06b0T00806AhR00D0724W01XO9P0D62<082@`01`P
;@0201LK9`0601PL:00@51l051PS01<G8@0P8b`041<L0P0E62403P0B5R404aLR00dA700<41/05QXU
01XN:@0K7b/06QhZ01/O:`0L82`06al[01HJ9@0I6bL061/T100F6B800`0H6b<05APO01<F7@0201DH
7`0901DH7@0E5QX06AXN01PI7@0B4aL051DI01/L800H6Ad05AHJ008051DI01L05AHJ01HG6`0F5a/0
4a@H014B5P0B4aL05AHJ01LH700B4aL051DI014B5P0B4aL04a@H00l@500C51P0414E014B5P0F5a/0
51DI014B5P0E5QX05QLK01<D600201TJ7P0301<C600A41H04Q4G00@04Q4G1@0A41H0<P0D51L04Q8D
01HE6P0A3QH040XF01LA7@0G41`05Q0J01`F800B41@02@T701HG4P0D51@05A<H01<A5P0A3a8040hA
014?4P0D4Q<03`d>01`K6P0S8R004a8@010>3P0B3aH05A8M00`:4P0I5Qd020H;010>4@091`X05aDH
00l=400?3A805aDJ018?5P0=2Q403`dB018@5@0D4QD04a4D014?4P0D4Q<03`h<00d;2`0E518061LE
00l>2`0<2P/02`T<0P0C4A@01P0=2`h06aTL01XH6`0C4A@040hA014?4P803P`?03/03P`A01<B5`0@
3a@02PT>01<B5P040PD03`d@010=400B3A404Ph?01<?400D41404`l@018@4P0B4140518C00/92P0J
61T040h?00l=3P0?3P`040l=00l>300<2P/040`=01D@500;1`P061<G00X61`0F4Q<0510A00h:2`0B
3Pl02`L800h:2`0<20T03PT=00T42P0<1`/030L<01HA5`0;1PX030L<01@?5@0A310040/@00d83P07
0PH05A4A00h:2@050@006ADD00d9200C3`h040d<01<?3P0D40l04@d<00/71P0200h:2@0@00`81`0=
2@P03`/:00h:2@0=2@P0?3Pg05mKFP0E4A003PX:01DA40070`803PX9018>3@0A3@`03PX900d920H0
3`/:00T040`<00T51P0;1`P04Ph?00h:2`0I5AH030P900X61`070`@00P0?2``03P0;1`P03PX:01@@
3`0G4a804`l>00d9200<20L03PX901LC4P0810<0510?01dI602MVIP0FEED0P0>2PT06@0<20L02`L6
00h:2@0;1`H02@D401LC4P070`803@T801@@3`0=2@P03`/:01@@3`0300009b<R01TE500?2`X03PX9
00`81`0;1`H030P700l;2P0;1`H020@301@@3`0H51<00P0=2@P0100@30/02`L600h:2@0C3`h200l;
2P<03PX900<03@T800`81`0<20L00P0@30/201TE508040`;01D0:BDV01lJ700C3a0040X<00l;300>
2P/04`l@00X61`0D40l0=30_018>3@0<20L04@d>018>3`091@H05a<D00H30`0D414030P900X61`0;
1`P00P0A3@h02`060P<03@T:00h:2`0:1PL04@d>00`82@0:1PL03PX;01TE5P0K5aP04@d>00803PX;
0P0>20X200l92`0500h82P0=1`T040X<014;3@0?2@/00P0B30h0100=1`T03PP:00h82P0?2@/3010:
3003014;3@0@2P`03PP:00<03PP:0P0A20/201072P803`H900H03PD80189300A20/03PD801072P0B
2@`401482`0801483@0C2Pl02`8701hD700=1@/02@07024G7`0=1@/;00l93@0=010:3P0?2Ph02`H:
010;3`080`L01`8601D@500B3A401`8600d8300>2@d04@`@00/62@0500h:2`0<014=3P0<20T030P9
01`H6@0;1`P03@T:018<401:A4P08A/O01D?4`0D3Q802@<90P0?21004P0?2A4040PC010:500A2Q@0
5@lM00P5400610`04@hE00D3200E41@040X<00/51`0<1PX03`P?00`5300A21003PL>00h93@803`X>
00@04PdA01D@500@2`l03PT=0P0<1`/03P0@2`l04`hB07E`M00U82@01@0400X52@0D3a<03PT=00<0
0P0D3a<01P4501D@500810L04PdA5?ooool001_ooooo00h05Q@J00T7300:20h04a4G00T7300?3A<0
20H<00h;4@0B41H02PP>00/93P0E4aT05a@K00`93`803`dB00D03P/?00`72`0@2Ph04@/>014;3@02
01@;3P0>01D:3P0E1PT05@H901@5200C20`04PP@014:4@0?31@03@dG00hA6P1hO8@0NGj:02HY<P0@
3A46014<400b02HQ9@0@2`l0:2<W01<>4P0@30d040d9010<2@0A3@X04Ph=018>3`0C3a005A0F018=
500A2a@04@/F018<600C3AP05@lH01@>6@0C3AL0618K01LA700A2aD04`hF01`F8@0M5b405Q0I01@>
6@0E41D05Q0B014=3P0D414071PI01HD5`0C4A@05aDH01DD6@0D4aP04Q4F014@5P0C4QD04Q8A018B
4`0C4a@03`l@014A500E51T051<I01@C6P0E51`201HD7P0I01PD7@0F41T06A@O01TG8`0>3QT0;Bdh
010B6`0?4AP051@I01HD5P0E4Q806aLG02h_<`0M82D03Q4F010C600B5AX05APM01XM8P0B5AX041<H
01@G700E61d05QTO01LJ8`0401LI9@0P01TK9`0A4al05QPT01HH900D5R805aTU01HH900G6bL06ah/
01lS<00M8Bh06al/01`O;@0D62D06AdZ01dQ;P0O8S0082@a02<W=00I7b`05A/W02H/>00D6RH05adX
01/R;00W;SP08BPa01<J8P0T:c8061lV01lX;`0I8b`201LT;00601LT;@0I9Rh06BH_01@Q:`0I9C40
6RHc0P0L:3D0B@0hA580@4YF02Lb?P0J9S805B4^024^>`0J:3D07b`k01`/>`0M;C`07blo01h^?P0M
;Cd09SE:024`A00Q<4<09SI602LgAP0V=T<0834l01d^=P0]?TH07Bhd02Li?@0V>3`09CLj024c>00N
;cD093Hk02Tl@P0X>d4093Ln024e?@0[?dL09c]501/b>`0W?DL0:45802M0A`0X@DP0;4E<035:D@0c
C5<09d1703I?EP0X@DP0>U=J02Y3BP0`B5D0:T5C02DlCP0dBUX0=TeK02ToC00Z?d/09c]402<g?P0X
>d80:3]102Tl@00Z?DD09CU302PlAP0V>D80:3Y302Li@@0U=Sd0:3U001l_=P0O;S@072/_01PW;@0Q
<CL00P0O;cH0C00O;SD07Rdd028_=@0O;C808Blc02Ha=@0P:bh06bHY01/U:00E8bL07bhb01HT9`0E
7b405b4R01PM800B5QT06QlR01PM8P0F7B@04aXS01PQ:@0>4Q`061`V01PL9@0G7RH09Rde01XQ:@0K
92T06R<X01/T:@0K9RX072L[01TT9`0M92X07bH/01`S:@0J8BT07B@/01hU;@0M92h06B0Z01TO:`0J
82`05adY01TO:`0H6bX08B@b01HJ9@0T:3<07R<Y01dR9P0I7R406QlR01TN8P0I7R@05Q/R01DI900D
62D06al/01hR;`0G6bP041@Q01HJ9P0@52005QXV01LK9`0A5B005QXV01PL9`0C5b<0720/01/O:`0I
7BT06QhZ01LK9`0J7RX201TM:@0401XN:P0I7BT05ATT01LJ8`805QTQ010061/S01TL900J7BD051LO
018E7@0C5Qh05QTQ01<F7P0@4aX061TM018C5`0D5AT05AHJ01LH700K72005QLK0`0E5QX301@E6@<0
4Q<G00D04a@H01@E6@0D5AT05QLK01<D600201DF6P804Q<G0P0C51P201@E6@0401<D600E5QX05AHJ
01<D608061TM00D05ADJ01DD6P0F5AX05QDJ01DD6@0701<B600W01DE6@0A4QD04a8G01@A600E3aT0
7ADP020H8P0K51d07QTO01DC5P0U9B<06adH01<C4P0D4QL0518E01<A500B41<04@l@018@4@0@3Pl0
4A0>018A3`0@3`d0518A01@A6@1<BE@071TR01HD6@0;2@`04Q4A018@400A40l05A@D00h<3P0=2`l0
4a0E014>500A3aD04Q0E00804Q0C00T04@l@01<A4P0E51<05QDC018A3@0@3`/04A0=01LE5P0@3Q40
0P0P7R407@0N71l0K6Y]01/I700D4QD03`d@010>4@0=2`h040hA00P83@0Z:Bl0=C@j01LF6`0:2@h0
518G00h<3`0?30l040`>010<3@0A30d040`=01TE5P0@3Pl020H7020N7`0T8R<02@L800l=3P0>30d0
3`d>00804Q0A00@040h?01<?400>2P/05a<D0P0A3@h0800>2P/040`=00l;300E4A8040`=01DA4P0A
3@h071LL014<4@0I51T0=2ld014<4@0:1PX04@`A00h93P0<1``050lD01/F6`0I51P04Ph>01<?3P0F
4Q402`L6010<2`0=2@P03`/:01DA400=2PT0:RHU00h:2@0I5A@0510?0`0A3@`03@0?2`X03@T801<?
3P0=2@T04Ph=01@@3`0:1PD05A4@00l;2P0B3Pd040`;00h:2@0=2@P01P0?2`X03@0>2`X02PH701HB
4`0B3Pl05Q8C00`82@0?2``08alP02TU9P0?2``04@d>01DA4P0@30`00P0@30/03P0?2`X03@T800d9
200?2`X03@T800X61@0A3@`01`@302`X9`0C3`h04@d<00l;2P0<20L03@T80P0E4A00300=2@P04`l>
01PD4`0?2`X04`l?020L6`060`804Ph=00h;2P0<20L03@T800h:2@<03`/:00d03PX900l;2P0=2@P0
2PH5018>3@0E4A003@T800h:2@0B3Pd03@T800l;2P0B3Pd03`/:00@03PX90`0=2@P01`0?2`X03PX9
01<?3P0C3`h03PX900l;2P0>2P/00P0=2@X04P0?2``04Ph?018>3`0>2P/03@T:00l;300A3@h030P9
010<3@0D414030P901TE5P0b;Rl05A4B014=3P0>2P/04@d>01<?40803`/<00/071PI010<3@0E4A80
6ADF00d92P0>2P/03`/<014=3P0h=3D0IF5R01LC500200h:2`0400l92`0@2P`040X<010:30<03`T;
00D04@/=00l92`0@2P`04@/=00d72@0200h82P0600l92`0@2P`040X<010:300B30h04@/=100@2P`3
01482`8040L:00D03`H901D<3`0A20/04@P;0189300200l62@@04@P;00P04@P=01893P0A20d040L>
01@:4P0<0PX0308;01<:4P/03`T=00d04PdA01HA5@0@2`l03PT=00/62P0G4QH0:bHZ00X52@0C3Q80
4@`@00`72`060@D03PX<00D03PX;00`02@H601@@4@0K5aP01@4201LC500>2P/02PD801TC5`0=1`/0
5Q0D014;3`0?20l200l8400:01094@0@21<04@TD014:500:11803P/F014>5`0B3aH030X?028M8@80
4P`>00D05a4E01T?5`0D2Q8050/C0109400200h93@<030L;01807APL01LB5P0@2`l03@P<00h93@0@
2`l03`X>00d8300C3Q802PD900d8300@2`l04@`@00/62P0K5QX0=c8f01LB5P0>2@dDooooo`006ooo
ool03P0B3aH02`P?018?5P0<2A002`P?00X73P0D4AP02PL>00/83`0B3aH04a0G02DR:@0B3aH04PlE
0P0B41D01@0:1`/05A0D00l93@0?2@`03`T;00804@P;00h04PL;01@82P0C1`T04`L90188300@2Ph0
4@XA00`83`0?3QH06a/U08:3S`1nP8`02@TC01DA5P804@`@00X050lC014<400>2@d05Q4E01LB5P0?
2Ph030L;00L21P0@30d04@h:0P0A3@X0100A3@`04@d>014<400@2a42010;4P0D00l94`0>21@03`XB
018=4`0A31<040/B01D@5P0D3aH04`hE01PC6@0[9Rd09b8X01LB600L5ah05A0E01D?4@0A3@h04`l@
01`H6@0F51L200d;3P0Y00l>4`0C4QL051<H01@C6@0B4AD04a<E01HF600B4QD03@`A014@5@0D4aT0
4a8H01DD700G5Al05Q@O01DC7P0B41X0>CHo03djA@0D52003@lK01lR;@0D5R804QDN01HH7P0H5a`0
5A<F01LE5`0:2`l02PdB01@G700K7R<06A`Q01<F6`0E61d03A0E01TL8@0R9BX05QTN018E6`0D5b00
0P0D5R800`0E5b<051HR018D800201TK9`0M01<E8@0S9C40<cE101lQ;@0D62@05a/W01`P;00M8Bd0
6AdY01HJ9P0G6bL061`X01LK9`0F6RH061`X01`P;00I7b/0=C]706E[M`0W;CT07bHa01TP:P0A6280
92/c01/R:P0O9R`06R4W01TR9`0G8RP00P0G92`08`0H9Bd06BH^01TV;`0K:3406RHa01/W<`0H9300
8Bdj01LS;`0P:SH092lk01dY=@0O:cL06RLc01TW=00T<Sl0:SY902PhA`0O;cl072`l01l_?`0V=DT0
7bi101d/?`0R<T809cM602LgA00L;CP0=DI>09^/]010DEP05bT]02`n@P0[?Cl0:3Xl00808C<g00T0
9cY002Pk@@0V>D00:3a502a0B@0/@4/0738m02Y0B`0V?dH00P0S?4<0E`0W@4L0:dA;02i7CP0/AD`0
:T=:02]4B`0bBe809d1702i6D`1ZPI40NY6Q02LnC00]@e00>e5N02HkA@0Y?DH09c]202Dh?`0U>3h0
:3/o02i1B00U>D00;D5:020d>`0S=Sd07Rlg028c>`0U=Sh06bXa02<b>@0R<CP06RPa02Lf?@0Q<3L0
8S4h024`=`0N;C@07R/a01h[<00N;2l07RT]01XU:00N:B/072LZ028_=`1IJ6l0=D58014J7`0L92L0
5AXM02<W:P0H71l092T]01@L7`0F7B<04Q/P028V;`0I7BH0;c<l02T`>0083aL08RTa01/T:@0I8RL0
624V01PS9`0G8RH051lS01HM8`0J8BL06B0V01TP:00M92`072<[01XQ:`0G7RP0:Blk02le@@0N9300
51XV00D85`0k?d`0T9BO01`P:`0E6R0082DY01@I700201PM8@0H01DJ800D6B005a/T014E800J7RT0
5a/V01PL9`0K7b/041@P00lC7`0F6RH06al[01LK9`0C5b@08RHb014E8@0/<3`0:Bdi01HJ9P0>4Qh0
5a/W01TM:@0H72P05a/W0P0H72P0100E6BD061XV01LJ8`0D5b0301<F7`0=01@G800C5Ql04A@M01<F
7`0I72D07R4X01<D6@0?41@04a@H010A5@0:2`l03PlC01@E6@0201HG6`0401DF6P0C51P04A8F01<D
60<051DI00h04a@H018C5`0A4QH04Q<G00l@500A4QH051DI014B5P0B4aL05AHJ01@E6@0B4aL04a@H
01@E6@<04a@H0P0E5QX01@0E5AX05QDJ01LF6`0H5a`051<H00804Q4F1@0C4QL09`0E5AX051DI018A
5P0L6A`07ATJ02HP800Y8b<0;RPX00H20@0G5Q@01@D301/M6P0B4Q804a4F01@B5@0E4aH04a4D014?
400>30d0518C01@C4@0C4Q005aHD01<A400C41L0CdaE02DR:00D4QD04Q0A01DD4@0R8Al05aHB028Q
7`0J6AL04@l@01<A4`0D4QL04a4F014?5002010>4@8040h?01T05A<D01PG5@0@3`/03@`8018A3P0C
4A803@/>00X82`0E4aH06QPK01<A500<2Pd02`T<014?4P0D4QD030X=00X82`0E51T020L=01@C6@0?
3Q<03`dB01LE6P0B41<04PlA00804Ph?00T04Pd>014=3P0@30d05A<D00/92P0J61T07adN00`:2`0?
3@h00P0=2``01P0>30d03`d>00h<3@0C3a00920Q04<o@0804Ph?03003`/<01<?400A3@h04Ph?00`8
2@0E4A804@d>01dH700>2@d030L;03<^<P0=20`050lC00d8300@2`l04@`@018=4@0A31003`/<00/7
1`0<20L03PX9018>3@0D40l04Ph=01<?3P0;1`H01@4001XF5@0300001P81014=300@30/04@d<01@@
3`0C3`h04Ph=01<?3P0L61L03PX900d9200F4Q400`00010<2`0A3@`03`/:00d9200>2PT600l;2P09
01TE5@050@803PX;03`h>@1_Jf`08alP010<3@0`;2d0=30a008040`=00D04`l@00d92@0=2@P02PH5
00`81`0200l;2P0?01@@3`0810<030P700d9200D40l05A4@00d9200@30/03`/:00h:2@0@30/05Q8A
01PD4`0K5aH04@d<00800`0000T0BDE406eYJ00S7ah01000010<2`050@006aLF00h:2@0?2`X00P0B
3Pd0100A3@`03`/:00l;2P0=2@P2010<2`0500`81`0A3@`03PX900`81`0>2PT00P0A3@`00`0?2`X0
3PX900h:2@0500h:2@@03@T800@03PX9018>3`0?2``03PX;0P0?2``04@0=2@X04@d>00l;30030000
30P901HB4`0810D03PX;018>3`0>2P/04`l@00X61`0C3a003`/<00T51P0G4a@07ATJ0080510A00`0
0`0005A@D@1fLW<09R8S00L4100O6a`06ADF085mOP3UhN80>3@e01PD5@0L61T2010:30804@/=00@0
40X<00l92`0A2`d050h@0`0A2`d0100?2@/03PP:00h82P0?2@/3010:300400h82P0=1`T030H800`6
20803@L900@04PT<01482`0A20/04@P;0P0@1`X0100G3Q404PT<0189300B2@`200l62@@04@P;00T0
4@P=01<:3`0F3A802`4901@:4P0B21002`4:01H=5@0>20`00`0?2@d2010:3PD03`T=00d03@L;014<
400@2`l03`X>00T4200;1PX061<G00@00`0E41@06A@H00P31`0Z9BT0;BT[00D03PX;00`05a<D00@0
0@1?Bd`0AD52024M7P0=2@X06aDI00d72`0A2`l050hB00h8300>1`h200l8400R01094@0@21<04@TD
014:500D3Q`05A8M00T63`0>2a803`dB00X52@0>20X04@/=01H@500D2Q8040H>01494@0D3A@04PdA
014<400@2`l03PT=00`72`0E41@050lC014<400@2`l03`X>00h93@03008020<701LB5P0B3A4040/?
00<00P8030L;00@061<G028M8@0=20`05a8F5?ooool001_ooooo01D03``E01<@6@0B3aP0104:010=
5P0=2Q<02@H?00P53P0=2Q<05A8K00h;500[:340Hf1W03Le>`0@3Q<06ALL014>4P0;1PX03`T=00l9
300?2@/00`0A20/03@0D2P/04`T:01482@0A2@`040X>014:4@0B3QD01P<<00P73`0M6bH0=C<n01HE
7@0C3a@00P0@2`l02`0D3a<04PdA00l:3P0C3Q80<2/_00d8300F4AD05a8F00X61`0B3P`04Ph=0080
4@d<00<040`=010;3`0D3aD00P0C3QD05P0C3AL04P`F014;4`0A310040/A00l:3`0D3a<04`hD014<
4@0A310081/Q01TD6@0=20`05a8H018=400E3a404`l@018>3`0F4Q<0518E014?4P0C4A@201<B5`0;
014@5@0?3Q@03PdB01<B5`0G5Q/04Q4G00h=4`0A41H04a8J018A6@0C4A`00P0E4ah201<A700>01dK
9P0>3AX051HS02T]>@0U:SH051PT014E800C5al05aPM01@C600C4QL061TN01TL8`0G6R42010C6P0[
01TL8`0H6b804QDL024T:`0Z;C@071lV01HI800I72D05aXS01@G800F6B805aXS01HI8P0J7BH06A`U
01@G800T9c00<cHo01lR:`0C5b8051PS01HJ9@0I7BP06QhY01TM:00K7bX06QhY01LK9P0D62<05ATT
01PL9`0G7BT082Hb04E;E`0>5Al04aXT018I8`0K8RX08bXb01DL8P0G7R@082L]020Y;P0301PS:@07
01XU:`0N:C008B/d024[=@0J92h082Xd01dW<`02020Z=P0H02@^>P0N:C<072Tb02Da?@0K:3<07B/f
02<a?P0_?dh0;3a;01h^?@0M;C`093A402<bA@0R<D@07bi101l_?`0U=D@0:SY70392CP0>7bL0D65Y
01h_=P0C92/0838f0P0R=3@0400N<3807Blb020c>@0O<SP0:3]302m3CP0S=d808CA2024gA00]@e00
;TA>02]2BP0Z@DT0:d9:02e4C00_ATh202i5C@0j0399D@0]A4`09ci602e4D00Z@E40=daM0357E@0M
<d00;T5?03I:E00X?4D0:3]202Dh?P0V>Cl0:ca302`oA@0S=S`09SU002e0AP0Y?4808c@l02Th@@0Y
=d007bdf020]=P0N:c@05B4]01l]=@0Q<3L082lf020^=@0O;3807BX`01hZ;`0O:Rh06bHX01PS9@0N
:2X072HY01TV;P12D5T08blf01@M8P0N9RT061dP01HJ6`0C5aP0724S010H6P0C6ah04A/M01LL8P0Z
;cD0UY^Q06ieN`0T:c406B0V01LP9`805QlV0P0F8BL09P0C7R@04APN01DL8P0F7B<061lW01`S:`0M
92`07RD_01/R;00/<Sh0<cU5028X=00H7RX08RDd01`P;@1VJWD05QXU01lT:P0>4aL04QLJ01HK7`0G
720051TO01HJ8P0J7RL04aLP02da>P0I7BH04QHO024U<00A5B002`lK01@H9@0/;ch08bHe00lB8P0B
5B@05a/W0P0I7BT01P0L82`07B4]01<G8`0K7b/06AdY01PL:0806AdY00D05a/W01TK9`0H6RH05ALS
01@F8P0201<E8@0D01HH900N82`06adY01<E8@0H6RH082</01@E6@0A4QH05QLK018C5`0H6Ad09RL[
01@E6@0E5QX05QLK01DF6P0B4aL04A8F01@E6@0F5a/201LH700>01@E6@0C51P05AHJ01DF6P0B4aL0
5AHJ01PI7@0F5a/04Q<G01DF6P0D5AT04Q<G01<D600D5AT2018C5`<04a@H00L05ADI01DD6@0E51T0
5A@I018A5P0@3a@04A0E00D04a8G02L0410E018C5`0G5aT09R@S01`I500L5a40A40f06APE`0h=Bh0
6aXF028R800I6aP04a<D01<A5P0D4QD05A<F01@B5@0B41403`d>01DC500C4Q003`h<01DD4P0?3P/0
1`D:01XH7@0F51P03`d>014@3P0E510051<?010?2P0D4`l05A@@01@C4@0B4A00518E01<A5P0A3a80
0P0@3Q42010>3`0I014?400B4@l04Q4?014@3P0A40d0108300`:3@0A3a804Q0C01DC5P0?3A0030X=
00/9300?3A004Q0C014?4P0E4aH04Q4F01dL8@0c<SL08B0U00h=4@0H5QT04Q0C018?4@02018>3`06
018=3@0A3@`03@T:010>3`0:20T03`d>0P0<2P/0100?3@h03@/<00d;300@3Pl201<A4P0C00X61`0J
5QL0>CDf00d92P0B3Pl04`l@014=3P0@30d04@d>00l;300S7b00920Q014<400>2@d00`0201D@5005
00@03`X>00`72`02018=4@0B00d8300;1PX03@T:040l?01ZIVD07a/J010<2`0?2`X04`l>01PD4`0K
5aH04@d<00h:2@0:1PD081`K00l;2P0>2PT03`/:0P0C3`h0300B3Pd03@T8014=300F4Q402`L600l;
2P0A3@`040`;014=300?2`X03@T800h:2@H03`/:00X02@H500D10P0N6Q/04`l@024M7P0300005A4B
01@@4@0E4A803PX;0P0B3Pl03`0?2`/03PX900/71P0=2@P04@d<010<2`0=2@P01@4001<?3P0@30/0
4`l>00H20@0:1PD03@T800l;2P02010<2`0?018>3@0;1`H04@d<024M700^:RT04@d<01XF5@0W8b80
2PH501DA400^:RT061@C00X71P0?2`X040`;00804Ph=00P04@d<010<2`0?2`X03PX900l;2P0>2PT0
3@T8018>3@803PX900@040`;01@@3`0F4Q40510?1@0>2PT300l;2P803@T80P0?2`X04P0A3@h03@T:
00d92P0@30d05A4B01LC500<20T06QHG00@00@0D41404@d>00<0000B3Pl0510A00L3100B3Pl05Q8C
00<000804@d>010040`=00P41@0?2``0;2PY02DQ8P0I5AH06aLH00<0000B3Pl04@d>00H20`1mNGX0
hMgN02dZ:P070`@03PX;0P0@2P`2014;3@05010:300?2@/03@L9014;3@0=1`T00P0<1PP0100;1@L0
3PP:00h82P0?2@/3010:300300d72@0<1PP030H800803@L900<03PP:010:300@2P`00P0?2@/200h8
2P06014;3@0C3@l04P`>00h82P0?2@/040X<100?2@/0200?2@d040X>018<400F3aH05a0G018;4P0:
0`/02@@90P0>20`0100?2@d040X>010:3P0@2Ph500l93@0800h8300A31003`X>01<>4P0?2Ph020<7
014<400B3A4200X52@0300@00`1ED5@0BdM900D03PX;00`05a<D00H20`0F4Q<00`0000P41@0?2``0
3`T=00T31`0A2`l02`D900l93@0B2a8200l8400=01094@0@21<04@TD014:500300/0514L01<@6@0:
1`h02@L<01@?4`0=1`T040X<010:3P0200h430090148400@2A003PT=00h93@0@2`l03`X>00/62P0>
2@d04PdA00805A0D00h04@`@00d8300R7B405A0D018=4@0;1PX04@`@00l:3P0:1@T04@`@00l:3P0=
20`02PD901<>4QCooooo000Kooooo`0500/84P0<2A<01P<=02PU;`0@3AL00P0<2A<07`0A3QP01`@>
00`94`0X9Bl0SX^D0>o]l@2/ZZl0<Bld01XH7@0?2a0040/?018<400B30l04@/=01<:3@0B2@`04@X<
018=3@0A30`040/;010;300@2Ph040/?03hi?`0B31D0510H00l:4`0>2Q@03PXB00l:3`0?2Ph0100@
2`l2018=4@0401D@500?2Ph04PdA018>3`<04@d<01X04@d>018=4@0B3A404`hD014<4P0?2Q403`TB
010;4`0B3A404`l?018=400A3@h05Q8B01HA500@2`d03`/;018>400A3@h040`<01HB500G4Q<05@lA
01@@4@0C3a005Q8C01@B5@804Q0C00d04Q4F01@C600E51T05QDK01<B600C4QT05QDL018A600C4QT0
4a8J018A6@0C4A/04a4L00<0518M00X05A<N01@F7`0E5b<061dY018I9@0S:cT05Qd[014H8`0@5b40
5QTQ0P0E5ad01`0@4aX05QTQ01HI8@0A51`051LO01HI8@0I72@00P0E6200200F6B405APP01TL900F
6B8051LP01<F7`0H6b@06A`U0P0E624201TL9@0401HI8P0G6R<05QTR01PL9P805QXT02X06QhX01dQ
:`0K7bT06QhX01/O:@0J7RP061`V01TM9`0L82X08bTd01@J9@0W;ST07RD_024X<P0J8BX092/c020W
;P0J8BL05alS01dT:@0E7b80624W01PS:00I92T06bH[01lZ<00R;3@06B@[01dW<@0Q:c@09Blh01LQ
;00M9c80628/01`W<@0N:c@06RHa028`>P0N;3L06bTe028b@00S<d4201l_?P0J028b@@0S<d@09CE6
02<c@`0P<400830o028b?`0[?4L0:CY4020a>@0O<3P0;3e401PY;`0M<2l0838a020b<P0V>3X09STo
028e>`0/?TP093Q303eAG@1KKWd0@eUX02@jA`0[@T/302]2BP80:D1803h0:3m702]2BP0`Adl0:T59
02]2BP0`AU80:T5>02m5D`15FVL0;T=?02m3CP0kCeT0:Ca602Pk@P0V>Cl0:ce302Xk@P0T=S`08SDh
020c>00Z?D808SDj04EEG@0W=Sh0:3Ho02/h@P0S<3/0<Si;03Q4D@0T<CX07R`c01`Z<00M:S407R/a
01hZ;`0M:Bd07RT/01`W:@0G8R@06bDV01/T:00Q;CH0930l01PR;00J8BT06B4T01/P8P0Q8bD0?T92
02<X:00O9B@05QlM01LO800P9BT06AhS02db>00J8BL05A`R01/R:00H8BP05b0W01PQ:0806B@Z01<0
5R4X01@K8@0G7R@05A`R01HM9@0L8b/07RD]01`S;@0I82X06Al[01XP;00F72P06Al[01XM;00G6bP0
3a<N01lS;P0B5ad05a`P00805a`O01h05AXN01HK8@0G6b<061dT01DJ7`0c>3`07b@Y00`A5P0G72@0
6QhY02T]>@0F6BL05aXY010C900c=TP06A`]01HJ9P0M8Bd061`X01<G8P0F6RD05a/W01`P:`0I7BP0
5QXV01PL9`0I7BP05a/V01TK9`0H6RH201LI9@0:01PJ9P0H6RL061XW02@V<`0T9S8061XV014C800B
51l04a@H010A5@8061TM00<08b@X03Hg>`0E5QX00P0D5AT301<D600601DF6P0F5a/05aPL01LH700E
5QX051DI0P0B4aL01@0?41@04Q<G01HG6`0E5QX04Q<G00804a@H0`0D5AT2010A5@0601<D600@4AD0
414E01@D600C4aH04Q8E0P0A41@00`0A4A@04a8F01<C5P0401<C5P0>01<C600E5Q/03@d?01TH4P0P
7Q00>cPW0;2_V`3YimH0^[RY0492>01LGEP06A/J01@D5`0D4QL301@B5@0C01@B4`0F51D06ALH01<B
400?3P`051<A01HE4P0H5QP03P`?018A4@0F5A803@`701`L5P1cLf`0PH5j03hm=`0G5Q806QTD018A
3`02014?4P<04Q0B00T04@l@018@4@0A3a004@l?01@B4P0D4a404A0>01@B4`0A3a800P0I5aX0400>
30l04a4D01PF6@0B41<03P`?00d;3P0E4aH08b4T01@C600C4QL08B0U01LG6P0?3A403P`?00h<3P0?
30d2010<300D014<300@30/06ADF01/I6P0=2``04@l@010>3`0?3@h040h?00h<3@0?3@h04a4B01PF
5`0J61T07ATJ00l;300C3a0040`=014=3P0;1`P2018>3`0=00h:2`091@H06QHG01HB4`0D3a805a<E
01@@4P0>2P`02`L900d92`0A30l03@T;014=3`0201<?4@0I01HB4`1dL6l0_k^j044m?00<20L040`;
01HB4@0S7ah03PX900P40`0E4A00510?00d9200A3@`03PX900l;2P0@30/03`/:00d9200B3Pd020@4
00/71P0E4A003PX901HB4@02014=300400h:2@0=2@P03PX9010<2`D03`/:00`040`<00/71`0C3`l0
3PX:01DA4@0<20P0510@00l;2`0=2@T0510@01<?3`0@30`6010<2`0300h:2@0E4A003`/:00803PX9
00<020D400l;2P0=2@P00P0@30/00`0>2PT040`;01@@3`02010<2`06018>3@0>2PT030P700T51@0A
3@`040`;0P0=2@P7010<2`<03`/:00@03@T800h:2@0B3Pd040`;0P0C3`h00`0D40l061@C01DA4002
00h:2@803`/:0P0@30/02P0>2PT04@d<00d9200=2@P04@d<00h:2@0B3Pl03PX;00`82@0>2P/2014=
3P0800d92P0/:2T05A4B01@@4@0<20T04Ph?01<?400B3Pl200d92P0301@@4@0=2@X040`=00803PX;
01005Q8C01/G600C3a004@d>018>3`0G4a@03PX;010<3@0=2@X0510A01DA4P0^:R/0510A01HB4`0<
20T03`T;0`0@2P`200l92`04018<3P0G4A<04`d?00l92`8040X<0P0>20X00`0?2@/040X<010:3004
010:3004014;3@0B30h04P`>014;3@<040X<0P0?2@/01P0>20X04@/=010:300>20X040X<014;3@@0
3`T;00h03`T=018<40070PD040T@010:400C31<08Q/S01@=500=1`/03PP<00l93@0@2Ph04@/?010:
3PD03`T=00d03@P<010;3`0;1PX03@P<010;3`0<1`/03`X>00d8300@2`l04@`@01PC5`0>2Pd04@`?
00D03PX;0P0:1PL02P0B3Pl030P9018>3`0@30d03`T=01@>4P0C3A402`D900l93@0?20l200l8400H
01094@0@21<04@TD014:500=2AD03``G00/84@0C41L040hC00X52@0?2@/04@/=00h8300B21005`dE
01@<500B2a803`X>010;3`0F4AD050lC00h93@0@2`l050lC0P0F4AD03P0A31003@P<00X52@0@30l0
71LK010;3`0`:bl0KFQ/01`G6`0B3A404@`@018=4@0C3Q803@P<5?ooool001_ooooo00H04@hI00d;
5@0H5B00P7f801hK9P0>2aH200`9500B00@1300@3AP09R<^08^8T@3RgnH0UiFK01<A5P0?3A804a0D
00H11@0@2Ph040X=00l92`0A20/040L:00d72@0A3`d04@d>0P0?2``200l:3P0Q010;4@0B2a802@8:
018;4`0C31@02P<;018=4P0E41@04`hB00h93@0?2Ph04PdA01D@500D3a<03PT=014<400G4QH03@P<
00`8200>2PT040`;01<?400F4AD05a8F01HA5`0A31803`X@010;4P0C3QD04`hB018>3@0A3@`040`;
00805A4@01X03`/:01DA400B3Pd05Q8A01LC4P0A3@`05a8C01D?4@0@30d0510A01dI6P0G5AP04Q0C
01DC5P0B4AH040lD00l>4`0?3Q@040lF01<B6P0D4a/04Q4I01HE7@0D4a/04Q0J01DC7P80518M00h0
5A@L01LE800A4Q`051PQ010F800L92l0>D5>06M`O`0V<3`07RPd01TQ;@0I82X061`U01PK8`8061/T
00d051LP01TL9@0O8R/05APQ01LJ8`0J7BH05QTR018E7P0H6b@06ahW01HI8P0E62406QdV00808RD^
00@061/T020S;00F6B804aHO0P0L7bP0500F6B8061`U01LK900G6b@06alX01XN9`0E6B806AdV01XN
9`0I7BH05a/T01HJ8`0G6b@092/e01hU;`0G7RP06b8/01LN9P0/<c/092/c0P0H7bD0200C6ah07bLZ
02D]<00D7R005b8V01/V:P0L9b/06bH[0P0I92X0:`0W<ST05b4Z02Pb>`0O:C808R`f04UCG@0S;cP0
;3U201l/=@0P;SP07R`g01l]>00F9S<06RXg02@d@`0O;ch05RHe02HfAP0T=4@09CE502<c@P0I:CH0
4R8_04YJI`0C92h08c@n020a>@0L;CD07c0g028d=00N<Bl07S0`02Li>`0W>T008C@j02PjA00P=3l0
:Se;02/nC@0M<T<0:3i<02@kA00W?TH00P0Y@4P0500W?TH09Ca402a3B`0X?dL0:d9:02Y1B@0]A4`0
:3m80357E00U>dP0;dA?0355D00Y?DP0=4M@02`nB00X>d809cU002`mA00V=ch07Rle0P0R=SL0:P0M
<380;T1409^Z/@10CeL0:3Ho034mB@0M:CH0=d=A04eIJ@0W=3l08Rle01`Y;`0I9R`06BLZ01TT:00I
92L07RT[01hX:P0G8B<05b4R01TR9@0N:380@TiJ03]5CP022A404QLK024U9`0=3`h0Bde<01<H500L
8R003Q@B01<L6@0:3a808BHZ01TN900T:c4020lE01HM8`0I8RT0624X01LP9`805b8X00/04adV01LN
9P0I82H051/Q014H800F7BD06B0X01/R;00N9Bl06b4]01TO:`0201hT<00X01TL:`0L82d06alZ0002
3@0J7bD05a`P01lT9`0I7R405AXN01HK8@0F6b804QLM01PM800=4a@041DH01HK7`0D6Ah051PQ028V
<@0G6bP05QTX01`O<01`LhH061//01PL:00I7BP05QXU01PL9`0L82/061`W01XN:@0F6RD051PS01DI
900F6RD05ATT01PJ9`0F62D04aDR014C80803a4N01406A/X018D8@0B52405ALT01LI9P0F62@06Q/O
01`M8@0/;C408b@X00h?4`0@4AD05QLK01<D600A4QH04Q<G01<D600801@E6@0;01<D600@4AD051DI
01TJ7P0H6Ad04a@H010A5@0A4QH05QLK01@E6@0C51P00P0?41@02P0C51P03PlC00h?4`0D5AP04a<E
010@4P0?3a404A4C01@D5P0F5QP501DE5`0Q014A5P0F5a`04A4C01hM5P0P7`d0?S`W0:n]U03oonX0
VIR404a<@00=3PT04aDD01LG6P0D4QL04a4D018@4`0D4QD05A<D018@4@0>30d05A@B01LF500D4a40
4A0=00h<3@0I5aP02`X7020O6`0F5A00?clf0>[Zh03oooH0N7Q`00806QTD00L051<?00d;300?3@h0
4Q0A01@B4`0C4A804@l@00<05A<D00H04a4B014?400@3Pl03@/>02DS9P0W9BP200l=400?00d;3P0@
3Q403`d@018@4`0A3a803`d@01HD5`0M72403PdB00l>4`0?3a404A0C00D3100?3@h040d=00804Ph=
04@050l>01@@3`0:1PL0:RPY00h<3@050`@04Q0A01DC500D4Q<040h?00`:2`0=2``03`d>00h<3@0;
1`P03`/<00`82@0O6a`040`=01<?400=2@X04Ph?010<3@0;1`P061@E00d92P0D41401@42010<3@0B
3Pl0510A01<?400@30d02PH701PD5@0R7Ql04Ph?00T51P0J5QD0:RHU01DA400@30/03PX9010<2`0@
30`05Q8A01LC4P0;1`H06aLF00l;2P0>2PT03@T800h:2@0B3Pd04`l>018>3@0?2`X02PH500`81`0C
3`h020@302`X9`0A3@`040`;00d9200<20L03`/:010<2`D03`/:00T04`l>010<2`0A3@`04Ph=00X6
1@0G4a801`<200d9200B3Pd00P0>2PT0300A3@`040`;010<2`0C3`h04@d<00`81`0=2@P030P701TE
500300005Q8A01LC4P803`/:01P04@d<010<2`0=2@P030P7014=300@30/03@T800l;2P050@005a<B
01<?3P0D40l06ADD00T5100=2@P07ATH00l;2P0A3@`040`;00h:2@0=2@P03PX9014=300=2@P200l;
2P0900d9200?2`X04@d<00d9200@30/03@T800`81`0?2`X02PH500803PX90P0?2`X2010<2`0900/7
1P0A3@`03@T800d9200A3@`02`L600/7200<20T03`/<00804@d>01l03@T:00l;300D41402`L800H2
0`0@30d04@d>08^7R00g<c@040`=00d92P0<20T040`=00H20`0A3@h01`<400X61`0H51D03@T:00H2
0`0?2``040`=01DA4P0>2P/040`=00D10P0H51D02`L8014=3P0=2@X03PX;00803PP:0P0?2@/01P0>
20X03@L901<=3`0I4aD050h@00l92`8040X<0P0>20X0100?2@/040X<010:300@2P`300h82P0300l9
2`0A2`d04@/=00804@/=0P0@2P`300l92`0500/51`0<1PP04@/=00l92`0=1`T0100?2@/03P0?2@d0
4@/?00H0100L5A`0<b`c01XC6P0H4AT04``C00d72`0>20`03`T=010:3P0A2`l040X>1@0?2@d03@0;
1PX04`hB01D@500C3Q8040/?00`72`0B3A400`0201PC5`0V8BD0S8N;020K7`0?2`d01@0>2P/0300=
2@X061@E018>3`0:1PL03PX;00T61P0>20`03`T=00/52@0C3A403`T=00h73P803`P@01H040TA0108
4`0A2A@04@XD00L13`0=2QD04PlH01<@5`081P/03@P<00d72@0>20X03`T=01P>5P0O5Ad04`XB0109
400<1`/03@P<018=4@0@2`l020<7100>2@d2010;3`0900h93@0:1PT04`hB00T42014?d<0[jZ^02LR
9P0>2@d050lC00802`H:00<081/Oooooooooool04_ooool001_ooooo00P03@XC00h;500>2a@08AhW
01LD7@0>2a@04a0I014>5`8040dF02H04a0I01HC701GE5/0@3i401TG700;2@h03`/@014<400C3A40
40X=00d72@0@1`X04`X=01<=3`0O7Ql0GE]L01TG600>30d06QDI00/62P0>20`02P@801hG7P0>10`0
3`D=01H?5P0F4AD02`H:01dH700A310071LK00H11@0A31003`X>00h93@0@2`l04PdA01<>4P<04Ph?
01404PdA01<>4P0C3Q803`X>00h93`0D3aD05a8H01HA5`0C3a40510?00P40`0E4A001@4000l;2P0B
3Pd030P700h:2@0201@@3`0>014=300C3Pl050h@014=3P0F4Q<06ADF01@B5@0B41<05A<F01<B5`0?
3Q<051<H01LF700D4aX501<B6P8061LO01L0>cY205MFGP0F5A/02@P@01/L900=4QP06R0Y01<K9P1^
MX40g>Kb09jW]P15Ce/0:30l02he?`0H7bL03Q8K01PJ9P072AD061XV018D800L7RX0418N018D8002
014C7`804aDQ00@051HQ01@G800D5ah05QTP0`0G6R40>00H6b805aXQ01LJ8@0I72<06QdT01TL8`0G
72806QlU01TN900J7bD07B8X01PM8`0F6b406AhT01`Q9`0E6R00724W01XN9`0E72H072<]01TP:P0D
6b<06b8Z02/b>00E72805ahT01LO8P0F7R405alR01/S9P0M9bT06R@V01dW:@0L9RP05b0T01TR9`0T
;C8082T_01/T:`0J8bX07BH]020Y<P1DGVL092lh01PU;@0R;cP0938k01/Y<P0M:cH08S<m01TZ=00K
:cP08c=001l_?00M;C`07bln0P0U=D@201l_?00301XZ=`0N;cT08C8l00808c@n01008S<j02Tk?00b
A4@09SPh020b=00W>T009STo02<e?`0Q=D009c]602/nC00Q=dD0738o02TmA`0V>T<08cM00P0hC5D0
400R=Sl0;d=<02e1BP0]@DX0:3a501``>@0U>D<0:Ce802/oBP0]@DX0:Si702PjA00U=d4093Ln02Tj
@P0[>d<202@b>`0@02@f>`0O<C<07Bla01l_<`0U=3T0:3Ln02Le?@0S<3T08blk02<^>`0T;C`08b`m
028]>00[>3h08c4d01PT:0806RDY01807bT[01hX:P0O9bT08RX/020X:P0H8B@072H`03I2CP1[M7h0
5QdU010E6@0J7Al06Q`K01XL6@0J7QX06R0L01dS7`0P9R<201/P8`1?01XO8`0G7b80620S01hU:`0I
8RT05QlV03U2B`002Q<06bD^01TS;00J8BT041LM01<J800I82P04QTQ01HM9@0N9Bl06R4[01TO:`0N
930082Hb01PN:P0M82l07B4^01hR;@0E6B@04AHL01LL800B5aX06b0S01/P900O92X04aPO01DJ800E
6Qd04ALG01PM800;41@03a@I00T=5P0M8B`07b8`010C8P0H6b`06A`^03LjB`1AEF007B4Z01@H8@0E
6B807R8[00dA6P0N8R/0720Y014E7P0G6b@04aLP01DI8P0?4Ad071hZ010B7P0A4al05QPT00T;5`0D
5R806A/W00/=6@0?4Ad0O7j:03Hi@P0m?T<02``@034b=P1LGF404Q<G01@E6@0C51P03a0D01XK7`02
01@E6@0:010A5@0C51P020T=02TZ;P092Ph06Q/O018C5`0G61`05AHJ01@E6@<04a@H0P0B4aL04P0E
5QX04Q<G00d>4P0?41@05QLK01/L800E5QX0414E01PI7@0M7R4061PJ01HF600C4aD04Q8D01@D5P0B
4Q@0410B018B50<04a<E02D04A4F018C600D51H04Q4:01XI1`0V90l0AdD/07ekI01AD3`0?d0d01dN
6@0<3Pd061PK00X83@0F51L04a4D00l=400L6Q/04Q0A01@B4`0?3P`03@`:00h=2`0B4@h03`d>014?
400B4@h04Q4=01/J5@0c<bX0Xj>I0=[JcP1GEdd03@d501PH400?3PT04Q4?00804Q0A00<04@l@010>
3`0@3Pl00P0I5aP03@0D4Q<03P`=01TG600@3Q003@/>010>4@0D4QD05A<F01<A500>30l04@lB00P6
2@0>30l00P0A3a804@0[:B`06ATK00/;3@0=3@l01@D7024P8@0;2@X030X;014>3@0C3`h061@A00h9
1P0@30/061@E014?400I5aP04Q0A008030X;00T03@/<00h<3@0100006QPI00h<3@040P<04`l@014=
3P0@30d00P0B3Pl00`0?2``04`l@018>3`02014=3P03018>3`0C3a004Ph?0080510A01/04`l@01@@
4@0E4A804Ph?01XF5`0G4a@07a/L00H20`0C3a005a<B00/71P0810<040`;018>3@0=2@P03PX900d9
200B3Pd03`/:01<?3P0>2PT030P700l;2P0>2PT030P700D1000C3`h00P0A3@`2010<2`803`/:0P0>
2PT0300?2`X040`;014=300F4Q402PH500<0000M6AP02PH501XF5@0:1PD030P700l;2P80510?0140
4@d<00h:2@0B3Pd0510?00d920070`802PH500d9200<20L03@T800l;2P0A3@`04Ph=014=300@30/0
3`/:00h:2@0200l;2P0901@@3`0C3`h03`/:014=300D40l02PL600/71P0B3Pd03PX900805A4@0100
3PX901`H5`0F4Q404Ph=014=300?2`X04`l>010<2`0810<040`;00d9200<20L03@T8010<2`0?2`X0
3PX90P0@30/00`0?2`X03@T800h:2@0200l;2P0@010<2`0A3@`03PX901<?3P0A3@`06ADD00<0000G
4a804@d<00l;2P0>2PT03`/:00d920091@@03@T:00h:2`@040`=01@030P900l;300B3Pl04Ph?00l;
300<20T0;BTZ01lK700?2``02@D600`82@0A3@h03`/<018>3`0>2P/03@T:010<3@0<20T02`L800d9
2P<03`/<00P03PX;01@@4@0<20T03PX;018>3`0?2``03PX;00d72@804P`>0P0>20X03P0?2@/04@/=
01XD5P0F41802P@600h82P0E3a403@L900l92`0=1`T04P`>01<=3`0<1PP04P`>0P0@2P`300l92`06
01<?400=2@X02`L800l;300B3Pl04`l@0`0@30d00`0=2@X02`L800d92P03010<3@0?00d92P0;1PX0
3PT=00T4200?2Q007aXP00P32@0500L04@/B018<400?2@d02`D9014;3`0H4QH02PD800802`D90240
3PP<00d72`0>20`040X>014<400@2`l02@@800`72`0@2`l02`H:01@?4`0@2`l06QDI08n:SP0F4AD0
3@P;00l;300<20T02PH700/7200>2P/05A4B00P41@0F4Q<01P8301lK700<2@T05@lC01@>4P0@2Ph0
3PP<00l93@0B2a800P0C31@04P0B2a<04@TD01084`0?218040XH02dZ=@1FDe`0L6ed01LE6P0C3Q80
1P0201PB500?2@d05@/C00l53@0<10`03PL>00d830803PT=0P0?2Ph01P0;1PX020<7014<400F4AD0
3`X>00L21P803PT=0P0<1`/0200E41@07aXN01PC5`0F4AD04`hB018=4@0A310040/?5?ooool001_o
oooo02H03@XB02LT:`0l>Cl05A8J010=500?3A<040dE00h<4`0=2a403@XB010=500B3aH061DL01HC
6@0<2Pl02`T>014>4P0A31004@/?014;3P0?2@/04PT<01<:3@0A2`d03@/;01PF5`050`@04@h?00h:
300;1`T040/>01TC5P0=1`X040P<01/C6@0=1`/040`?03`g>`804@`@00<02`H:01HA5@0@2`l00P0?
2Ph0100A31004PdA01<>4P0B3Q02018=4005014<400@2`l040/?01<>4P0?2Pl00P0C3Q<01@0?2Pl0
3@T;014=300G4a804@d<008061@C01@04Ph=01<?3P0A3@`04@d<01<?3P0D40l05Q4A01@>400B3Pl0
5a<D01/G600F51L0518E01LE600D4aP040lD01@C600E51X051<J01<B6P@04a8I01l051<I014@5P0I
61d06APN01LG6P0G5Q/0418G024V:`0_=C/0@daD09bT[P3Wl?D0WjRf03<mB@0k@dl0FV5[01`R;00E
6B8071hZ01XL:@0@4Ql06adY028T<00V:3@05ALT01@F8P0E5b<06Q`X01/M:P0H6RH05QTR00805aXQ
00@051LN01<F7@0F6B0061/R0P0G6R40900I72<06QdT01TL8`0D6Ah05AXO01HK800K82D082DZ01TN
8`0O92T06AhS01hS:00J7b@07R<X01DJ800C6R806R4Z01`S;00J8BT06b8Y01lV;00I8BD06R8V01TQ
900G7b80620S01/S9@0M9bP06B<S01hX:@0O:B/06R@U01LQ900L9BT072DZ01`U:`807BH/03807RL]
01lY<@0I9B`08c0h020]=@0S<3T05B</01l]=`0G:3804b@^02<c?`0Y>DH08C4n02HfA00T=4809CE3
028b@00T=440:CU6024a?P0S<cl093A002<d?`0Q<Cd07c0i02@f>P0W>C`0:3Xm02Pj?P0V>Cl09CPn
02Pj@P0K;cL09CU302PlA`0P=T809C]702LjA00Y?4D0:3]402/nB00/?dT0:3]402TlA@0Q=3h093M0
02XmA`0[?TP0:Ce602PlA080:Ce508@09SY202Dg@00X>T809SQ002Hf?P0X=cl09cDn02Tg@00V=Sd0
7Blb01d^<`0P;cD093<i02Le?@0U<S/07b`e020[=P0X<Sh09c4n01lX=P0H8R/082`a01`X;00H92L0
9c8e02D_<@0L9RP06b@V01`T9P0O9RP08BPY01`T9P0H8BT03ALQ01TR:`0N8bP051TL01@E5P0J6aP0
6AXH01TK600F6aP05AXG01@J600E6a/05A/L01DJ7P0C6ah05AdP01XQ9`0C72<07BH]03m8D@0K9Bl0
7BL`01HP:P0M92`061lU01XQ9`0I82P04QTQ01LN9P0a>4809B`f01TO:`0H7RX06Al[01lU<@0_<T40
5aXX01/O:P0A5B00724W01<H700C61/06AhQ010E6@0D6Al051TP01PM8`0?51L06AlP01PM800G7200
3Q<H01<H7P0A5Ah08RHa00X>6`0H6bT030lO01hQ<00J7RT04QHO01LK900M8BX06QhW01LK900F6R<0
61`U01<G800J7RL05QXS01LK900N8BX04A<M01LJ8P0B5Ah0828]018E7@0E5b4061XU010C6`0M82T0
JFaf04a?E`0F5a/071dQ01@E6@0E5QX07AhR00l@500B4aL06AXN010A5@0C51P04Q<G01DF6P0c=3P0
4a@H00/<400K720201DF6P<04A8F02h04a@H01DF6P0F5a/04a@H014B5P0D5AT04Q<G00h?4`0@4AD0
4a@H01DF6P0C51P04A8F01DF6P0G61/051@E018B4`0A4A804Q8C01@D5@0G5aP05ADF01<C500D51D0
5ADF01@D5@0C4aL051DI01DE5`0D4Pd04a4401HC0P0J5`<0<BhL01/J2P0L6a<0414<00h@3`0E5AP0
6ALL03@b=@0U8bH02`T<01PF5`0C4A804Q0A0`0C4Q005P0D4a004a4B01DC500D4a004A0<018A300F
5Pd0820G03Ph;@0K6a405QH>00`<1@0H5a<04Q4=018A3P0B41004A0?014?3`0@3Pl04Q0A01DC500A
3a4200d;3@0301@B5P0@3Q403`d@00803`d@02P040hA018@4`0F51L04a4D014?4P0?3A0040hA01TG
6P0B4Q@04A4C010@4@0A4A808B0Q01LE5@0G5Q@040h<00`81P0D40d03`/801<?300@30d05A<D00l=
3P0A3a003@/<01@B4`0B41403P`=014?400:20T03`d>00d;300@30d03`/<010<3@0A3@h04Ph?010<
3@0C3a004Ph?0P0A3@h00`0B3Pl04`l@00d92@02010<300400l;2`0A3@d04Ph>010<30803`/;00T0
5A4A07=_K`0F4Q8030P701TE500@30/02`L6014=300C3`h00P0@30/02`0D40l040`;01<?3P0;1`H0
510?00l;2P091@@04`l>00d9200?2`X040`;00<03`/:1@0>2PT0300?2`X040`;01DA400?30/081`K
01HC4P0:1PD071PG01LC4P0F4Q004@d;00l;2@8040`:00T04`l=00h:200:1P@06ADC028N700H5180
3@T800l;2P0@30/00`0?2`X00`0@30/03`/:00h:2@0200h:2@803`/:01@06QHE01HB4P0=2@P040`;
01<?3P0>2PT02`L600h:2P0L61L02@H500l;2`0A3@`03PX900l;2P0A3@`03`/:018>3@0H51<03`/:
00d9208030P700@040`;018>3@0A3@`03`/:0P0@30/00`0?2`X040`;010<2`04010<2`0601<?3P0<
20L03@T801`H5`0d<2l040`<0P0?2`X01P0B3Pd0510?01DA400C3`h03@T:00l;30<040`=00<03`/<
010<3@0@30d00P0>2P/2010<3@0>00`82@0?2``04Ph?014=3P0?2``03@T:00h:2`0A3@h030P900d9
2P0B3Pl03`/<014=3P0?2``200d92P0Q010<3@0C3a004@d>00`82@0B3Pl04`l@00`82@0:1PL04@/=
01<=3`0B30h040X<014;3@0B30h03`T;00d72@0?2@/04P`>010:300=1`T03PP:00l92`0;1@L03PP:
018<3P0@2P`04@/=00/51`0:10H04P`>01hH6P0T7R004Ph?00804@h?01L040d>00h;300>2``03@X;
010=3P0C41404Pl@00l<3@0>2``03``=018?400C41404@h?00h:3P0>2`h04`lC00l;4@0:1``05A4G
01<?5P0?2Q003`T=00X4200300l93@0:010:3P0=1`/03PP<018<400>20`03@L;014;3`0?2Ph040/?
01@?4`803`X>00L03PT=00T4200A31004@d@00H21@0=2@`03`/=00803`/<00l04Ph?01DA4P0I5AH0
4`l@00X61`0<2@T05A4B00T51P0@30d04P`@014;3`0?2@d03PP<00l93@0B2a800P0?21004P0@2A40
4@TD018:5@0C31H0?3I403llA`0V8b`08b0W00X83@0>2Pd0<B/]038/;P0@2Ph04@L?01063P0F3AD0
40T@00l:3P8040/?0P0A31002@0@2`l04@`@01D@500B3A403@P<010;3`0>2@d04@`@010;3`0200d8
300400l:3P0C3Q804PdA010;3`<03`X>5?ooool001_ooooo02L01P@900h<400K6A`00@0400L52@04
0PD03@/@00d;3`0;2@`030X?00d;3`0>314040dD01<@5P0B41D040hC00h:3`0:1@T03`T=010:3@0A
2`d04`X=0189300?2@/03``=00/7200D41403`/<00P41@0L61T03`/<01dG6@0D3Q003`T;01LA4`0>
20X09b8V0<:m`@12?D400P0D3a<01@0E41@040/?010;3`0@2`l04@`@00<04PdA02@04@`@010;3`0?
2Ph03PT=00d8300B3A403PT=014<400B3A404@`@01LC500:1PD06ADF01DA4@0F4Q404`l@01<?3`0?
2`X04@d>01DA4@0D40l03`/<00h92P0?2@/03PX;01<?400F4Q<04a4D018@4`0E4aH04a8G014@5@0E
51T05QDK01<B600B4AL201<B600J01<B5`0D4aP040lD00l?4@0>3Q0051@D00D51@0<30`0:2PY01hR
9@0I7B405A`R02D^=@1YLg`0AU1J01dW<@0?5b4061`W01TM9P0J7BH0418O02X/>@0N82d0008?04i@
G@1ADf0201`N:`0501XL:@0E5b@05ALT01PJ9P0H6b@00P0I72<201<F7@0701XM900H6b805aXQ01HI
800H6b806A`S01LJ800201`Q9@0801/P900T:Bd0:Rlc024V:P0O92P051TM01HK7`0@5AT201DJ7P07
01HM8`0H7bL06R4Y01/R:P0I82H05A`R01PP8`0201TQ900Q01LO8@0H82806b<U02@^;@0H8R405R0O
01XT9@0N:2T08bd^01/U9`0K9BP072DZ01dV:`0N9b`07bP]01hY;`0V<ST0;3U101h[<`0/>T808S0i
02<a>P0P<C/06BXd01X[=@0L;3T06RXg01h^>`0Q<Ch093A102De@P0`@4d0?4aI00<093A100/08c=0
024a?P0P<C/0:S]201`]=00V=ch09SLo01T/<P0J;C<08SDl020d>`02028f?@0501lf?00P=cd0:C]5
02TkA@0]?dT00P0W>D<00`0`@T`0?U1J02i0BP0202PjA00402doB@0Q=3d093Po02@h?`<09CPo00/0
;3i602/lA00U<c`09C<l02<a>P0Q;cP08S0i01l`=`0R<3T08S4h024`=`0202@a>P0<01l/=@0N:380
7BLa01hX<P0N9S<06B<[018M8@0I92P08B`_020[;@0S;Bl07BHX0P0G7b402@0I82406R0P01TP8@0B
6b009c8h01/S:@0A5QT041@E01/M700201LG5@0j01LI5P0E6AP051PI018H600@5QH04ALG01<H6`0A
6A`04QXM01LN900M9Rd04a`S00`E7P0G8B/0628/01HP:`0K8RX06b8X01hU:`0H7bL04QTQ01XQ:@0_
=T008bXd01PN:P0G7BT05Q`X028X=00P8c805APV01HJ9@0S9c8061dS00dB5P0I7R4041DH01/P900H
7B<0=S]20:jc^@0f>cl01PX>01<H700Q9RX082DZ01LL8P0N8R/0ADUC00dA700J7RT061`X00/?6`0A
5Ah06QhW014E7P0H72D03Q8K01/O:0806QhW02<04aLP01XN9`0F6R<05a`R01TL8`0E61h061/P020S
:@0B5A`04QDJ010C6@0O8RT082<X01`O9@0E61l04QDJ00l@500E5QX071dQ02DV:P0A4QH06AXN01@E
6@0000@07AhR010A5@0S92P08R<W0493A`0K720051DI01PI7@0720`0414E018C5`0201<D600901HG
6`0H6Ad06AXN01<D600A4QH051DI018C5`0?41@04Q<G0080414E00D04A8F01<D600C51P04a@F01<C
4`03018B4P0501<C4`0F5QH04a<C00h>3P0@41000P0C4a<0500?41<030dA00d=3`0E4a805a@?01PC
3@0J5P`07QXA01TF3`0E51003`l=014C400C4a@040hC01PF6@0D4QD03`d@01DC500B41404a4B0`0B
4@l03@0B4@h04a4B01<A500D4a805aHB01DD3`0=3@H05QH>024Q5`0I6A0040l:00l>2@0C4Ph00P0A
40`3014@3P0a014?400@3Pl04Q0A00h<3`0E4aH06ALJ04I4B@0@3Q403`d@00h<3`0?3A0040hA01<A
500@3Q40518E014?4P0@3Q405Q@G00l=400@41805aLH00d=3@0?3`l030`;00/:200B4@l04Pl=01PD
4@0U8Ah061<@00h:1`0<20L01@<401@B4`0d<S<05A<D01TG600>30d02@L801@B4`0C4A804@l@00L5
1P0B3Pl04@d>01<?400E4A805a<D01DA4P02018>3`8040`=0P0B3Pl07P0>2PT04@d<018>3@0B3Pd0
510?01HB4@0810<0510?01LC4P0L61L02`L601<?3P0H51<01P8101XF5@0T81l0CDU801@@3`0<20L0
3`/:018>3@0A3@`05A4@00/71P0?2`X0:2@S01HB4@0<20L040`;01`H5`<03`/:00@03PX900d9200=
2@P03PX90`0=2@P200h:2@0:010<2`11?C`071PG01@@3`0C3`h06ADC02@P7@0I5A8040`900d91P80
3PX700H040`901DA3P0G4a004`l<00l;200?2`T2010<2`0400l;2P0>2PT03PX900h:2@<03@T80240
3PX900l;2P091PD08AdL09VEU010?3/061@C01@@3`0A3@`03@T800`8200F4Q401P81014=300=2@P0
30P7014=300D40l04@d<018>3@0?2`X03PX900d9200F4Q405A4@01XF5@0E4A004`l>010<2`0?2`X0
40`;00l;2P0>2PT00P0=2@P00`0<20L02`L600/71P0200`81`0700X61@0D40l0?CTh01LC4P0?2`X0
3PX900l;2P02014=300300h:2@0>2P/03`/<00<040`=00<03PX;010<3@0?2``00P0>2P/0200?2``0
40`=00h:2`0=2@X030P900d92P0?2``040`=0P0H51D01P0?2``03@T:00l;300<20T04Ph?010<3@80
3PX;01L040`=01<?400C3a0040`=01DA4P0D41403@T:00`82@0B30h040X<00l92`0@2P`04@/=01<=
3`0B30h07ALI01TC5@0;1@L02P@6010:300A2`d04P`>00l92`0200/51`0@00`6200A2`d04P`>018<
3P0A2`d03PP:00/7200:1`P03P`=00l=3P0>30d040h?014?400Z:2T071XK018@4@802`T:00l030X;
00d;300A3a00518C018@4@0?3A0030X=00<110071@X04Q0E00H42@081@`091lU01H@50080PH00P0D
3Q801@0500<04@/?00`62P0<1PX03`T=00803@L;00d02PH9018=4@0F4AD01`<600`72`0C3Q804PdA
01TD600H4aL02PH902<N8P0C3Q802`L900803`/<00H03PX;00l;300A3@h00`0000`82@0?2``200P4
1@0300`82@0>20`03@L;00803@L;01H03PP<014:4@0<1@d03@H>00l8400A2A@04PXE01<<5`0:1180
:2D`02dZ<`081@`01@<800d8300[9BL0;RPZ018<400E2a<03P@<01494@0>1`h03@P<0P0>2@d200l:
3P0800X52@0=20`04@`@00h93@0:1@T040/?00X52@0=20`200l:3P0400h93@0=20`04@`@014<4080
40/?00<04@`@018=4Oooool04oooool001_ooooo00H02@L900l=3P0:20T04Q0B00h<3@0D4Q<200h<
3P0>00h<3@0=2`d03@/=00d;3P0>31402`T?00/93P0<2Pl03@T>014<400@2Ph040X=014;3@0C2Pd2
01893005014;3`0?2@/050h@014<3@091@H00P0B3Pl03`0G4a80;b/Z018>3@0<20L06aLG018=400W
8RH050lC018=4@0@2`l04PhA010;3`0A31004PdA01<>4P02018=4@08018=4`0A31804@`B010;4@0?
2Ph03PT=01HA5@0A310201<>4P0E014=3P0C3a40510B01<>4P0N6Qd05Q8D01<>4P0B3A0040/>010;
3`0D3a805Q4D01D@500C3Q004`d?01@@4@0F4Q<061@E01HD5`0C4A@04Q0C00804Q4F00<05aHK01PG
7@0D4aT00P0B4AH03`0C4aH051@F01DE5`0E5AH06QXI00/;2P0F5Q<05aLC024R7P0h>CH061/I010D
5@0G7B0051dQ01XS:P0201XS;00B01DL9@0@51h061/S01/K900F62D08bDd01DG9@0P8S40=3I503/m
C00@4R405QPW01/M;00G6BP06ad/030b@00G6R405aXO0P0H6b001@0I72407b8W01PK800G6Ql05QTN
008061/P01@05QTN01/P900L8B@0724T01lT9`0R9bX06b0S01TN8@0O92L0;C8e028W:P0K82<07R<W
01`S:@0H7bL05QdU01LN900H7bD05alR01@L7`805alQ00/05QhP01TQ8`0L92D07bPV01TR800J8b80
6b@S01PQ8@0J8R@08b/]020X:P0201`T9`0E01lW:P0R:bl07BL^020/<P0N:c407R/c028`>00H9bh0
82hg01TZ<P0S=3`0>4UC03E6D00Y>T@07c0j020a>`0Q<S`072`i01h^>`0U=D808S8o00808c=002X0
93A302DeA00U=D<0<dA@020a?00X>D80:CY4024d?00U>3l08cHl02]0A@0S>3`093Tm02@l?`0K<cH0
9cY2028d?P0Y>dD0:Sa602Hh@P0/?TP0:ce702Dg@@0X>T@0:Sa602doB@0Q=3/08C@j02<f?00U>3h0
9cY002Tj@@0X>D008C8j024_>00V<c`08Bhg01dZ<`0O;CL09C<m02Le@00T<S`2020]=P0H020[=@0U
;cP0:C<l02</=@0J8b/07BH`04E?E@0]>3`04ahP01dW:@0G8B<06bDV01`U9P0L92H07R@T01`R8P0I
7al061lP01<M7P0?6A/05AhO01PM700J7Q`06AXH0P0I6AL0E@0I6QX05aXK01LK7@0G6al04aTI01DK
6`0G7Ad05AdO01DM800H7bD05b0W01`U;00I8B/07BLc01LQ;@0K9C005ahV01TP9P0J8BL05ahV01@K
8`0K8RX06R4[01TP:P0F72P06Al[01dS;`0I7b/05QTX01HI9`0M8B`0HfMb03XoA@0D6Ad04AHI01PM
8@0J7b<04aPN02L[<`1lP8T0JFid01PM8`0[<3H061dS01DJ80083A<05a`R01LL8`0>4aX06alX00dA
6P0S9bl03a@K01LL8P0?51X061dS01DJ800H7B<09BX`01lT:P0B5ad05Q/Q01<H7P0G72405QTM01XM
8@0G6ah0F5aO01TL800@51L05ATM01@G6`0?4aH041@H00lB5P0I7B004a@H02DV:P092Ph0@45501<D
600E5QX0:BX^08Z;S`0W:2`00`0B4aL00`0L7B4061TM0452AP0201XK7`0301DF6P0D5AT04a@H0080
4A8F0P0B4aL0400D5AT04A8F01@E6@0B4aL04A8F01@E6@0B4aL04A8F01@E6@0E5QX04a@H01HF600I
6AT061PH01LG5`0E5AD201@D500C018B4P0@41004A4A01DE5@0F5QH06a/M01HG6`0C4QL05Q<H01<>
4P0E3a<06aDH01D?4P0I5AH04a8B01LG5@0B510051@D018@5@02018@4`0D01<A500E4a@05A<D01<A
4P0A40h04a8@01HE4`0L6aP04@lB00l=4@0?3@l04a8?01@C3P0?3`T03`l801<C2`0E50h04A0<00l>
2P0G5Q@3014@30804A0>01@04Q0A010>3`0D4Q<04@lB014?500@3Q<0;2X_00l=400A3a805A<F01HD
5`0D4QD04@lB00h<3`0D4QD04a4D010>4@0F51L03P`?00P820803`l?01X0410@018A400D4a403@`8
00l=2@0F4Pl08b0K01PD400B3P/04@d<02@R8`0C4A807A/L01@B4`0>30d04a4B02LU9P0;2@X05A<D
00P61`0F51D040`=00l;300@30d04Ph?01<?40804Ph?00H04@d>010<3@0@30d04@d>018>3`0@30/2
01<?3P08018>3@0D40l05A4@014>3@0B3Pd02`L603@`;`0<20L2010<2`0A018>3@0E4A00E51?04]7
AP0=2@P03`/:018>3@0@30/03`/:01@@3`070`8040`;00d:2@0;1`L09b<R01XF5@0;1`L00P0A3@`2
010<2`803`/:00d040`;00l;2P0>2PT03PX900l;2P0A3@`05a<B02@P7`0L61L08alN00h:2@0B3P`0
40`900803PX700T04@d:018>2`0@30T040`9018>2`0?2`P02`L400`81@0?2`T00P0>2PT0100?2`X0
40`;010<2`0?2`X200h:2@803`/:02004@d<01DA40060`80;b/Z01HB4P0@30/04@d<01`H5`050@00
8QhM04]7AP0E4A003@T800l;2P0=2@P04@d<018>3@0>2PT03@T800/71P0C3`h03PX901HB4@0A3@d0
4@d<01LC4P0D40l03`/:00d9200>2PT03@T8014=308040`;0P0?2`X03P0>2PT01P<201XF5@0Q7A`0
6ADD00H20@0?2`X03PX900d9200?2`X04@d<018>3@0@30/03`/<0`0@30d0100?2``03PX;00d92P0?
2``2018>3`0500l;300=2@X04@d>00l;300=2@X00P0<20T00`0=2@X030P900l;300200/7200300l;
300<20T040`=00<04@d>00@040`=00h:2`0A3@h03@T:0P0?2``01@0<20T03`/<014;3@0>20X03@L9
00<040X<00H03PP:018<3P0B30h03`T;014;3@0D3Q02014;3@0;01@>400C3@l040X<010:300=1`T0
4@/=01@>400E3a404@/=00h:2`0>2``00P0;2@X01@0<2P/03P`=00l=3P0A3a0030X;00802PP902P0
3P`=00d;300<2P/03P`=014?400@3Pl03`d@00d;3P0B41<04@lD00T7300A3a@04a0G01`G7@0;1PT0
3PP<00l93@0J51P02`D901PB5P0D3Q803`T=00h8300=1`/04@/?02LR9P0G4QH01`<601dH700D3a<0
2@@8010;3`1aK70091lS00d9300B3A4050lC01@@4P0>2P/03@T:0`0<20T01P0D414040`=010<3@0A
3@h0Ddm@01<?40803@L;0`0>20`0100@2A003`P@01094@0@2A4201084`0?01094`0H4R002`PC00h;
500=2Q4061HK00/62P0;1PL0618D010:3P0E2a<02`4901H>5P0?20l03PT=00803`X>0P0@2`l0300A
31003`X>018=4@0B3A4030L;00d8300B3A403`X>00`72`0>2@d04@`@018=4@803PT=0P0=20`00`0?
2Ph040/?ooooo`0Cooooo`006oooool0100<2`T03Pd;018A3`0>3@/200l>30<03Pd;02<03@`:00`;
2@0;2@X04Q0E00h<4P0A3a@040hC00/7300>2@d04P`@010:3@0>20X04@P;01<:3@0D2`h05@`A0148
2`0C2Pd05Q0B010:300F41804@d<014@3P0O7Q`04A0>010?2`0E51803PX<018=4@0<1`/04`hB00h9
3@03008040/?018=4@0201<>4P804PdA0`0B3A<05P0A31804@`@014<400G4QH040/?014<400A3@h0
40`=01<?4@0Q72804@`B07A_M@0i=3X06A@J01LB600C3Q@04@`B018=4`0E41H05Q4G01D?4P0C3@l3
01@@4@804Q0C03805A<F01@C600B4AH05A@I01DD6P0B4AH04A4C018B500C4aD051@D01DE5@0H61H0
6a`G01PI500D5@l05aP@01PI4`0D5A005aTF01@G5@0:3a8041PK01TP9P0=51`04aXR01TM9P0F6B80
5ADM00l?600G6BH02``N01dN<00>3b40;c1202d^@00F5bT061T[01LH:P0B4bD04a@V01/L;00H6b80
5APM01@G700J7B8071lT01XM8P0I72405aXO01HI7P805aXO00H05APM01<H6`0H7Qh06AlO01HL700I
7al301LM7@0_02D[:`0J82004QPH01LL7`0K8RP06R4W01LN900F7B<0620T01XR9@0I8B@06R8U01PP
8P0F7R005QlO01PQ800F7a`06B8O01dV8`0L9B807BHT02H_;P0O9bT07BDW01`T9P0L92L082P[024[
;@0M9Rd08Rhd02@a=`0hAD/08c4g01`[<P0Y=d006b`d024b>P0/?DL0834k01<T;P0M;SP06R/e01d^
>00N;cT07bll02@d@@0Q<Ch00P0Q<D004@0S<d8093A302DeA00U=D@07bln028b?`0S=3l08S@n02Lj
@@0aA4X0734d01ld=@0Y?ch09clo02Hn@00W>T809SQ20080:3Y400@09CM102@f@00V>4809CM10P0Y
>dD0:`0S=Cl08C@k020c=`0R=CT09CLl02@e?00S=3/07Rhf01/Y<P0N;3D08c0i01h[=00M:S<07R/g
020^>`0T<Sl08c0k01dY=@0M:S<07BTb028/=@0Z<c`092dd01TR9`0J8bX0;3Hj018M7`0@6Q`06bDW
01LQ8`0M9BL04a/M01XR900O9BD07R@S01TO7@0H81h07RPW01<M700K92806QhM00lD400I6AH00P0E
5A<0500H61T07AhR02@U:P0Y;3406AlO01XP7P0L8R80620R01LO8@0I82H07RL^01/T:`0K8bh08R`h
02La?@0D7B/06B0X01TP9P0H7bD05ahV0P0H7bL07P0>5Al05ahX01DK9`0P9S80=3Y602H/>00Q93<0
720]00lC7P0P92l05a`R02<X;00A5QT06QlR00P=4@0=4QP06AhU01lS;00X;3D05a/T01<G800?4a`0
5a/S01XO9@0B5ad07B8X010E6@0<4AL07B8W018G7@805Q/Q02d05a`R01<H7P0H7B<0314G01hS:@0J
7bD03a@J01HK8@0D6Al06AhR01<G6P0H71d020`=01<G60072``06AdN01@H6@0F6Q/04ADF00hB4`0F
6Q/01@T:020Q9@0000@07QlS00d>4P0J6al020T=01lP901nOh<05AHJ01lP900C51P02P/?01dN8P0_
<3@0][Nk038c=`0000@06a`P01PI7@0F5a/05AHJ01@E6@0C51P00P0D5AT01P0A4QH04a@H018C5`0B
4aL051DI01<D608051DI00<04a@H018C5`0B4aD00`0B4Q83010@400g01@D500G5aL051@D014A4@0D
51@05QLG010A4`0A41D05Q<K01<=6@0J4Ql08a/X01D=600I51/040hB01XJ60082PD03Ph=01HD6@0G
5AP0518E00h<3`0=2``0518C018@4@0B4@l04a8@01HE4`0J6AH05A<H01@B5`0C4A<051<A01@C3`0C
4Pd05aHA01TH4`0T8al0:RTW00h=2`0C4A4040l;010?2P0A40`04A0>018A3`0B4A001@<400`:3@0C
4A@04Q0E01<A5P0<2Q0040hA018@4`0201HD5`0301<A500>30l04@lB00805A<F0P0@3Q406P0A3a80
61PH010@400H61P03@d;01@C4@0>3@/04Q4=00l=2@0=2@H05A8=014=2@0G4a0030P7020N7`0>30d0
20H701LE5P0E4a@081hO03@b<`0?3@h04@l@01DC500?3@h04`l@0P0B3Pl01@0C3a00510A018>3`0A
3@h040`=00803`/<00D040`=014=3P0A3@/04Ph;014=2P0200l;200I010<2@0;1`D01@4001<?3008
10<0510=01LC400:1PH06aLF014=300i=C@05A4@00l;2P0B3Pd04`l>00h:2@0@30/06QHE00d9200@
30/04`l>00l;2P0>2PT0100000/71P02010<2`803`/:0P0>2PT0400B3Pd04@d<010<2`0?2`X040`;
014=30030000510?020L6`0400006aLF01DA3`0C40/04@h9018?2P0A3PT200l<1`0700d:1@0:1`80
3P/6018?2P0A3PT03`/9010<2`0300l;2P0E00h:2@0?2`X03`/:00l;2P0@30/04@d<01<?3P0E4A00
5Q8A00<0000D40l02`L600h:2@0;1`H05a<B00h:2@0B3Pd04`l>00d9200@30/03PX9008040`;0P0=
2@P02@0A3@`0510?01<?3P17@d80@3`k014=300N6QT06QHE01<?3P03014=30<03@T80`0>2PT01P0C
3`h0100000l;2P0W8b804`l>00/71P803`/:00D040`;01<?3P0D40l04@d<00l;3003010<3@0400l;
300=2@X03PX;00l;308040`=00@03`/<00h:2`0;1`P03@T:0P0@30d0200=2@X02`L8018>3`0F4Q<0
4Ph?010<3@0?2``02@D60P0@30d400h:2`804Ph?01@05a<D01DA4P0D41405a<D010:300>20X03`T;
018<3P0@2P`03@L901<=3`0=1`T030H800l92`0>20X03@L901<=3`080P@030H8014;3@803PP:00<0
4P`>00l92`0=1`T00P0<1PP02`0;1`P04a0A00/92P0=2``04Q0A00d;30071@H02PP900d;300>30d0
3`d>008030X;100=2``06@0>30l030X=00X82`0:20d04a4F020N8`0J5ah02PH<00P21P0k=CT040X>
00/52@0<1PX040X>00`62P0:10P03`T=01@>4P0L5QX0@Se102XU:@080`L06A@H00l:3P0:1@T00P0?
2Ph01`0G4QH040`?024L800300804`hA00d92P0?2``00`0@30d01P04004030P900l;30030000:RHW
00l;30@03`T=00<03PP<00h73P0?21000P0?210200l74P0?00l84P0:11800`0;00l<5@0?31<05A<H
014<40080P@04P`>00/52@0E2a<02`4901P@600@2A003`X>008040/?0P0A3100200?2Ph03@P<00`7
2`0:1@T03@P<01TD600H4aL04PdA0P0=20`0100>2@d03@P<01<>4P0B3A42014<40804PdA5?ooool0
01_ooooo00H06APF00@30P0@3`d00@0001DD4P061@<400d<2P0M00/:200:20T02`T>00/93P0D4QD0
518G00`9300=20`04PdA010:3@0=1`T03PP:014;3@0C3@l04P`>01H@4P0D3Q003@P900/51`0P71d0
3@T800l>30071P@03P`<01DE4`0920H02PP:024L800>2@d00P0B3A402`0I51P040/?018=4@0C3Q80
50lC018=4@0A31004PdA018=4`0B3A404PdB00804`hB01H04@`@00`72`0?2Ph04@d>018>3`0D3a80
71XM02XU:@3WiNL0IfEX01LB5P0B3Q803`d@01<>4P0E4AD04Q0C010;3`0A31005a8F01PC5`0H51P0
5A<F0P0E4aP09@0G5AX05QDJ01<B5`0C4QL04Q4G010?4`0@4Q404Q8B01<D4`0C5A@051HC01PJ5`07
2@@04aD@01@F400E6140=CPa02X]9`092`H06A`I02/_<00T:Bd051XQ00lC700L82T04aLQ018E7P0S
8b/07AdV01LI9P0K72h04Q<U01hO<@0R8cD05QLY01dN<00J6bd00P0H6RT0A@0F62D04A<P01TL8@0D
61/051HJ01XN8@0L82<051PK01TM800G6ah05ATL01HJ7@0G6ah051PK018G6`0J7b<07B8V01LL800K
82<07B8U02ld=`0M8RD07R<V01DJ7@0H7B008RX]01PO9@0J8RP06B8W01PO9@0H82D06R@V01hU:`0M
9RT06B<U01HN8@0E7R005QhP01PQ800G81l0624P01TR8@0Y<C80@TY<01PP8`0J8RD07BDX01hU:`0P
9bd082T^01`W:`0R;S<082ha03]8CP0L:S007bhe01TX;`0O<3L08S<k020a>@0S=3`0:CY202Hg?`0O
<3P0834i028c?00S=3h09cM4028b?`02024a@00l028b@@0S<d<08c=302@d@`0U=D@09SI302@d@@0T
=T809cU305U/M00S>3d0:Ci102a1@`0P=CH09S/n02XnAP0_@D/0:cm802PkA@0V>4808SHo028e?`0R
=3h09SU202Di@P0M;cT08SDk020d=@0R=CT093Lk024b>@0N;cH072/c01d[=00P;SL08Blj01TW<P0K
9c<06RPd01/Y=P0Q;cX08Bhi01`Y<P0M:S<07b/c01lZ<00O:2l0624U01@N800G8B806RDU01<O7`0Y
<c@07BLX01HP8@0/=SL06b@U01@L7P0I8B<06B8Q0P0E7Qd0@P0N9bH072HU00`E4P0A5aD061dI01<E
4P0I6aP05aTH01<D5P0A5AP051LL01TM8P0H82806R<R01`T9P0H8R@05b4S01PQ9`0B6b@0628[01hW
=00;52<05Ql^01dV=P0L9Bh06b@Y01PP:00H7bL0624X01HN9P0I82X08BXc018I9@0F72P0;3@o01TO
:`0T:3@051PT01PL9`0@51d05Q/P01@I7@0<4A@05AXM01LL800M8RP04QLM014F700@51d092T`0005
2`0D624051TO014F700I7R@04QLL020U:@0E6Qh061dQ01DJ7P0H7B<051TO01LL8P0>4aT082D[01PM
8`8051TO02@03a@J01LL8P0F6b406QlS01DI700B5QL082@U00lC500D61T05ATJ00lC500D61T04ADF
01LK700f>S/0720Q010A4`0G61`030d?01<D5`0=3Q8051DG01@E600E5QX07QlQ00/<3`0D5AT06a`P
00l@500P8BD0:BX^01HG6`0N7b<02``@01@E6@0B4aL4014B5P0401@E6@0A4QH04a@H018C5`804a@H
00<04Q<G01DF6P0D5AT00P0A4QH00`0C51D051@D01DE5@0301HF5P0I018B4P0D51@061PH01<C4`0<
30`03`l?01<C500>3a404A0E01HD6`0?2AD050hJ01lI9@0C3AL061<J018A4`0Q8Al02P`701HF5@0F
51T03P`?014?4P0E4aH04Q0A01DC500201<B400=014@3P0?3P`03Pd:00h<3`0?3A004@lA014?400A
40h040l=00H50@0G5Q807QdJ02@S8@0200l>308040l;03404A0=014@3P0B4@l04Q4@01DC500I5aX0
6QPK01LE600M6b003@/@010?500A4A<04a<E01<A500@3Q4030X=010>4@0B41<05A<E010>4@0?3@h0
5Q@E01PF5`0820P05ADE00H6100B4Q0020L501<B3P0C4@d04@d:01HB3`0?30P05A4>01`H5`071@D0
61LE01TG600@3`d03`h<00h:2@0G51<04Ph=01lK6P0m>CP03`/:010<3@0?2``03PX;00803`/<00<0
3@T:014=3P0@30d00P0?2``0800@30d04@d<01<?2`0D40d04Ph;010<2@0?2`P040`901@@3@0E4@h0
3`/801LC400>2PL030P501DA400810<0510?00d:2@0;1`H05Q8A00h:2@0@30/03@T801@@3`0S7ah0
5a<B00d9200C3`h04Ph=00l;2P0<20L07a/J0P0?2`X200h:2@803@T800<04`l>018>3@0A3@`00P0@
30/06@0C3`h06ADD00@0000b;Rd0510?00L30P0?2`T02`P300/60`0>2PH040d8014<2@0>2PH03P/6
018=2P0?2`L02`P300h91P0A3@X04Ph=014=300?2`X03@T800`81`0>2PT00P0?2`X07P0A3@`04Ph=
01@@3`0C3`h04@d<00d9200?2`X07ATH00T51@0;1`H05Q8A018>3@0?2`X030P700l;2P0C3`h040`;
018>3@0C3`h040`;018>3@060P40510?00P40`0K5aH040`;00/71`0I5A@05A4@00h:2@<02`L60P0@
30/0400A3@`04Ph=018>3@0C3`h06aLD00L3000H5140510=00T50P0B3Pd04`l>014=300@30d04@d>
00l;300;1`P4010<3@0400h:2`0=2@X040`=00l;30803PX;06d03`/<010<3@0B3Pl040`=00h:2`0=
2@X03`/<014=3P070`@03PX;010<3@0A3@h04`l@00d92P0B3Pl03`X=00/7200;1PX03@T;00l;300=
20`040`>01PD5@0F4Q@04PdA01DA4P0A2`d03`T;014;3@0D3Q004@/=00`82@0<1PP050h@014;3@0;
1@L05Q0B020J700S7Ql03`T;00h:2`0C3Q004@/=010<3@0?2P`04P`>018>3`0D3a004`d?014=3P0A
3Pl02`T:010>3`0H5QL040h?00L51P0=2``02PP900T7200;2@X03@/<010>3`0?3@h03@/<00`:2`0=
2``03P`?010>4@0G5AP02@L<034_=02HUY/0L6ed00l:4@0R6b80KFI]024J8@080PH040X>01@>4P0@
2Ph03@L;00h8300=1`T040X>018=400?2``03`X>00h9300A3@h04PdA01@@4P0=2@X00`02018?4003
00005Q4E00X6200?2``040/>010;3`0?2``03PX<018=4@0G4a@04`lA00d8300:1PL040/?00@040X>
00@03`T=00d63@0>1`h03PL>0P0?2100400@2A4040TB010=600=2QD03P/C00P5300A3a@03PT>00`7
2`0C3Q803@L<01TB6@0<1@`040T@00d83P0=20`200h93@803`X>00T03@P<00l:3P0>2@d02`H:01HA
5@0^:Bd05A0D010;3`0=20`00P0?2Ph00`0<1`/04@`@010;3`0300h93@0300l:3_oooooooooo01;o
oooo000Kooooo`0300d;30091`P03P`=00803`d>030030X;00/92P0;2@X02`T:00`:2`0>30d03`d>
00`:300@3Q003`d>01@B500A3a002@L800`:2`0>30d03``=00d:2`0>2``03``<018?3@0>30X03@/9
00h=2`0A3Pl03@/<01<A4P0;2@/05A<E00h<3`0C4AD02`X=010>4@0>30l030X=00h<3`0A3a804a4D
00l=400C4A@0518E01<A500B41<04a0C01@?4@0D3Q404`d?01<=400B30h201<=3`0<018<3P090`D0
71HH018<3P0E4Q802``902`/:@1GF5@0<S8_01PH5@0>3P/04A8>0P0B4Ph0G`0A4Ph04Q8>018@500B
3aT0514K01@B6`0C4QT04A0G00l>500E51X04A0F010?500E5AP04Q4F01@E5@0?50l041@@014E4@0@
5A4041@C00hC4P0I7Qd082HU00lF5@0H7ah0@T]:0498A00=4P/04aPC010D5@0M82D04QDN01PJ9`0N
82`08B<`01/N:00I72@06QdV01TK9`0G6BL05QPW01PI:`0I6R`061T/01PI:`0J72/061XU01@G7`0F
6Ah05APJ01DG5`0F5QL071`M01LH6@0C5AD05ATI01HJ6P0C5aL05Q`K01LM7@0B61P051XK01/P:P0J
82`06B0/03<iA@0L8bd05ahX024W<@0K8RX05QdT01DL8`0G7RD06B4W01PQ:00G8BL051lU01lY;`0G
8RP082/`01/U:`0G8BH06B@Y01/U:`0I92T072H[01XT9`0L9RT06bDX01dV;00F7bD082T_01TR:P0J
8b`07bLa00808RXd03D07RL_02@_<`0N:R`06bTZ01d[;@0N;Bl06bX^01d/<00S=CT08S@i01`]<`0N
;cH08cDj01la=@0S=3X07c4f01l`=`0N;cL062Tb02<c@00Q<D008310028aA00R<DD08S9202TkA@0V
>4808S@o07V;V@0]?Td06bdl028c@P0R=440;d5<02`nB00R=C/09c]102XoB00_A4d0;TE=02Dk@`0N
=3`07SDm02<j@P0M<S/083Hn02<j@P0O=Cd07c<h02Dg=`0V>3X08cDg020b=P02020a>00K01`]=`0N
;cX0<41=02HfA00F93@08S4l028a>@0P;cL07B`d01XX<@0J9c007BT`01lZ;P0X<cD082/Y01LR7@0_
>S<0520J02hj=`0R;R/072PV014M700K9bL06RHV018M7P0G8R<05b4S0080628T02T06R<S01XS8P0J
8b806B8Q01PP7P0G7ad05A`K01lW9P0G7Qh03aLF01lV9`0L92D051lQ01HR9@0M:Bh07b/b01dY<00I
92d05b8_01LS<00O:CX07RTl01TT=`0K9CT06bD`01HQ:00D7BH06B8[01/U;P0I8b`06R</01PR:`0I
8R/072H_01/U;P0F7bL04QTP01XO900B5a`061dR01LL800201HK7`0301<H700G720061dQ008051TM
01h05AXO01@I7@0H7B403Q<H01dR9P0?51P092T]01PM8@0P9BT0DEIJ01TN8P0G720051TO01LL8P0B
5ad051TO01hS:@0M8RP061dS01TN900G72805AXP01HK8@0H7B406QhQ01LK700M8B8051PI01<G600?
4a@601<G600601<E5@0F61P05aTH01HG5`0E5aL05aTH0P0D5QH01`0D5QD051HF01@F5P0D5QH03a<D
01HJ6`0?4a@00P0B5QL06@0@51D04QHG014E5P0C5aP04ADF018F5`0I7Ah05QLI01@E5`0:2`d05QLI
00d>400E5QP06Q/M01PI6`0B4aD05AHH01<D5P0E5QL030h=01LI600H6QT071hM00h@3`0E5aH00P0B
51<03@0A4a803a4@018D4`0I6A`05A@I01TH7@0F5AX04Q0E01LE6P0E51H05A@D01<B4P0A4Ph00P0A
4Pd06@0A4@l07alQ02<S9@0C4a@03`l?018B4P0B4Q404A4?014B3@0@4@`04A8=018C3P0@4@/03a0<
01DE4P0C4a<03`l?01LG601JFU/04a<D014A400>3P`06Q/F018C3P0A4@l00P0@40l03P0?3`l0410@
014A4@0?3`l04Q8B01PH600E5AD04Q8C014B4P0@4AD061/N00l@4P0@4A<05ADG0P0<30`01@0>3Ph0
51<B00/:2@0E4a404@l<00804A0>0P0?3P`2014@3P0>00/:2@0A40h051<A00h=2`0S8Ql02`T7010>
300D40d05Q8?00d91`0C3`d040`801@?300E3``201H@2`0801PA300G4@`040`:00d<2P0?3P`04A0>
018A3`0@3`d200l>300X00`;2@0@3`d051<A00T81@0>3@L02`/400`;1@0?3PT040l:00l>2@0=30P0
40l=018A3`0:2@L04A0>00l>300@3`d030/901@C4@0=30X04a8@00h=2`0?3P`0FEQF01TH5P0=30X0
1PD300h=2`0?2`T0510=00`91`0R7Q`03@T601`H5@0@30T04@d:00h:1`0A3@X0510=018>2`804Q4?
02803Pd;00X91`0;2PP03@`:00d<2`0?3P`051<B061OG@1fMG<05A0@01D>3@0E30d04PX:01/D4`0Q
61T0610@00l81`0A20T04PX:014:2@0B2@X04@`:01@C3`0U920071/G00X91`0A40`03@`901@C3`0@
3``040l;01<B3P0S8Qh03P/80`0B3@X00`0A30T040/8010;2005010;200300l=2@0>3@T03Pd900<0
3Pd900<03@`800h=2@0=30P00P0:2@D00`0<2`L040`9010<2@04010<2@804@d:01h040`9014=2P0A
3@X04`l;01@C3@17Ach030`400h>1`0E50l03`h;00`;2P0B41402`T<00h<400I5a`0N7Ij01XH6@0?
3P`04A0>028Q7`0E51802@P6014@3P0G5Q@04Q4?00h=2`0?3P`03@`:040o?@0F5A<200`;2@0500l>
300=30X030/900h=2`0?3P`00P0>3@/03P0<2P/04a4D018@50020@@05A<H00d;3`0?3A403P`A010>
4`0>31002`T>00`:3`0A31404PT>0P0=1`/05@0>2@d03PX>00d;3P0?2`l03PT=010;3`0=1`/07QDJ
03D/<@0X9BH0514B00H51@0>2``040d>00/92P0?3@h03P/<00d;300@3Pl04Pl@014>3`0600d92P80
3`/<0P0>2P/0F00=2@X02`L8010<3@0=2@X04@`?00P31`0D3a<07APM00`73@0?2Q00?3Pn0;Rc^P1]
J6l091hV01PB6`0P6b<04PdE00`83P0:1P/03@P=00/62P0<20T03`/;014=300?2`/02`L601PD4`0?
2`/03@T901<?3P0J5QH03@T800l;2P0?2`/03PX:00d9200=2@T03``>00L52@0C4AH01P@9034_<`13
@DH02`T>00/93@0;2@h03@/@00d;3`0;2@d040/?00l:3P0>2@d03@P<00h93@0@2`l03PT=018=4@0F
4AH040/@00d83@0A31403`dC00l<500?31<03P/B00d:4@0=2a403`dC00T73@0B3Q@03@T@014=500=
2A006ALK00h<3`0=2`h04@lB00/9300?3A0030X=018@4`0A3a802`T<00h<3`0H5QT02PP900d;300>
30d200d;300700l=3P0>30d03`d>018@4@0=2``04a4B00`:2`0Dooooo`006oooool04`0=2``061HG
00T7200A3a003`d>010>3`091`P02PP900/92P0=2``040h?018@4@0C4A803`d>00P61`091`P01P@5
00X82@0=2``00P0?3@h03`0=2``03P`=00l>300b<Bh0:BPV01<B400>3@/03`d>0040000N71d020H9
010>4@0D4QD04a4F00d;400200h<3`0500l=400@3Q4040hA010>4@0A3a800P0D4QD01@0A3a8040hA
014?4P0D41404@d>008040`=00h04@d>018>3`060P<0;RX[01`H6@1HE5D04`l@00X81`0H61H051@B
00X:200?3`d03@d;00l?3@D04A4?02@04A4D018@6`0B4AT04a8J018A6@0B4AL04A0F01PG700D4aP0
4Q8D01LG5`0D51H05aLF01@F4@0B5140418?00dB3P0>4Q4041@C02T_;@0j@4006R0P00L=3@0Y;S40
=3Xh01HK5@0C5aD06alR00`?500F62<05QPU02T[>00T9S<0418N01DH8@0G6R<201HH900;01PJ9`0K
7B`06ad/01TK:P0Q8c805QPU01PK900M82D05QXM01/O7`0R92400P0J71T07@0>40l08B<R028V9@0W
:b`05a/L020V9P0/<C@0724T01HN8P0221@0728b01XP;`0D6RP06R0^01`R;P0E6bL06B0Z01HM9`0I
82X072<]010I8P0D7B@06RD[06ehOP1TKgD062<Y01HQ9`0M:2h06B@Z00806RD[07l062<Y01`W;@0?
61d06B8W01@M8P0?61l04AXQ01LP9`0O:34072D_01`T;`0N9S407bLb01lX<@0U<3@07BX[01LU9P0I
9bP08C0b02He>00N;C807Blc01`^<P0L;C@07c0g028d>00O<C@08S@h020b=P0Q<ST0834i01`]=@0Q
<Ch08c=202DeA00T=4@08C13020`@00K;CH08cDo01HX<P0bA5806R/k02/lC00O<4007S0n02Dg@`0O
<C`08C@k02m2B@0]@DX0<dM@02XnA`0T>4408cM001hb>`0Q=Ch09CU2024e?P0N<S/08CDn02Lj@00Z
?3h0:C/o02@f>P0O<3L07Rlf01l`=`0E9Rh0;3e70;K7d@26UZ<0>d]H01HV;`0N;C807Rdd01`[<P0H
9bh05R<[01TU;00Z=CT09c8d030l>@0K9R007bXR01/V800Q;B/06BDS01LS8@0>6QP08Rh^020/;00K
9bL06bHX01LR900=61X062<V01TQ8`0J8b807RLV01dV9@0K92<05QlN02L`;`0Z<c804a`K01TR8@0M
9RD0628R01`W:@0I9bX06BH/01PU;@0I9Rh06RL`01XV=00I9C<072Ph01/V>00G8S@06BDg01dW<@0H
8bT04QdS01DP9P0I92X06bH/00806RD[02h06bH/01dX;P0L9bd06B<Y01TP9P0A5QX0724U02X_<`0G
72004QLK01<H700E6Qh06QlS01PM8@0A5QX04QLK01XO8`0P9BT0;S<g00H;3`0G72005Q/O03a1A@0K
82@03a@H01TN8P0@5AT051TM01LL8P0J7bD05Q/Q01DJ800H7B<05AXP01HK8@0H7B<05a`R01DJ800C
61h04aPL010D5`0;3a009b//01/O800<41402Ph?1P0D61T01P0D5QD05ALF01DG5P0C5A@05ALF01LI
60H051HE02D05ATJ00P<3@0=4A8041@E018F5`0>4Q<04ADF00hB4`0@51D04QHG01PL7@0P92D05AHH
01XK7@0E5QP03a0B01PI6`0K71h01@H800`=3`0N7b4051DG01HG6@0C5AD06adL01DG5P0C5A@03Q0?
01DG5P0@4Q4051HE01DG5P0B51<0418A01<E500C51D02`/=00803`lA00<0410B01@D5P0?3`l00`0@
40h02P0A4@l04Q8@018B4@0C4aD0410@00`<300E5AD051@B00l?3@0@40h300l@2`0>010A300A4P`0
4A8<01<D3`0?3`l02@T900`<3P0M7Al03Ph@01XJ6@0410804A8=00L80P0@40h5010@400D01HF5P0A
4A402@T900P8200=3@d02@X900h?4`021PT02P/=010A4`0B4aD05ADE00P8200<30`051<A00X91`0C
40h030P5018A3`0A40h2010?3@0=014@3P0B4@l08b8P00D40P0D4a406APF010?3@0M71X04Q4?00H5
0`0M71X02`X801dJ5`0201<?300301@@2`0D3`/05A0<00805A0<00<04@d:00h=2`0?3P`00P0A40h0
:@0>3@/051<A00l>300?3P`06APF01XI5`0:2@D05A@>01dM5@0>3PH03@`701<B3@0;2PD03`h:00`;
2@0=30X02PT701@C4@0@3`d03@`;00`;2@0:2@L04Q4?010?3@0?3P`02`X802/Z:00=30X030/9018A
3`0<2`T061@A00/7100M6AH0X9bI010<2@0300004@d:010<2@0>2PL0510=00806aLD00H02`X800`;
2@0<2`T02`X800d<2P0<2`T200l>300501LF500g=S@0@d9001<>300E3@/00P0B2PP01@0M5A<09AdK
01`D4P0A2@L04PX800<04`/900L030P500X91@0J6AD06aXF010?2`0=30P030/700804a8>00@00P40
00<200061@405Q@@0`0A3@X00`0@30T03`/8014=2P05014=2PH03Pd900H03@`800h=2@0>3@T02`X6
00X91@0=30P6010<2@@03`/801l040`9014>2P0:2P8092@J00X:0P0?3PT03Pd801DD400A3a002@L9
00X82`0E4aP01087028P9@0F51D03@`:00`;2@071P@03@`:01DD4P0:2@L051<A01DD4P0D4a404Q4?
00/:200G5Q@02@P600h=2`081`D02@P600@03@`:01003Pd;010?3@0A3a002@L:00h<3`0;2@`061HI
00h<3`0E4aH03P`?00l=400>30l030X=00d;3P0A31004P/?0P0A2`l05@0@2`l03P`?00h>400@3a40
40/?014<400B31003@@900L11@091PL040h?00l=3P0B41403@/<01/I6P0<2P/03@/<00h<3@0A3a00
518C01DC500600h:2`03014=3P0@30d040`=00803`/<01l04`l@00T51P0=2@X03PX;00X61`0=20`0
8A`Q00h93`0E41H030L=02DP9`0>2A005@lH00@0200>2A001`<901PC6P0n>Cl03@P=00`72`0>2P/0
3@T900`81`0?2`X0510?00d92003000030P700<0000?2`X0510?00803`/:00T03PX900d9200=2@P0
1`D600h<3`081`T00@0200X82`0X9RT00P0<2Pd0100=2`h02PP;00X82`0=2`h200l:3P<040/?00@0
3`X>00h93@0A31004PdA0P0>2@d00`0C3Q803@/@00d;400200h<4@803`dB00T0518G00H42@0C4AH0
40hC00d;400K6Ah09B<V01@B5@091`X00P0?3A00300A3a803`d@00l=400<2Pd02PP;00/9300?3A00
2PP900`:2`0=2``02`T:00`:2`803P`=0P0<2P/00`091`P07Q`M02DS900Dooooo`006oooool02@0E
4a@0:2HW00X82@0C4A8030X;00h<3@0B41404@l@00l=3P0300h<3@09010>3`0<2P/01@<400X82@0?
3@h07Q`M00d;300?3@h03P`=00803@/<01403`h<01<B3`0?3P`01`H400`;2@0C4A8030X;00d;3005
0`H03`d@00`:3@0;2@h05Q@I00h<3`0?3A0040hA014?4P0200l=400801@B5@0E4aH0518E018@4`0A
3a804Q0C01LC500D4142018>3`0?01@@4@0E4A807QXK00L3100300008QhO010<3@0H5QH03Ph<00T9
1`0O7ad03Ph<0041000F5Q@0410>00<04A4?00<04Q8@018B5@0B41/00P0B4AT2018A5`0Q014@5@0G
5aT04a<E018B4@0H61H05ADC01PH5@0F5a804a<A014B3`0A4a004Q@C010D4`0;3`h02Ph?014G5`0G
7Ad04aPK018H5P0=4Ph020`<010C600A51/05ALR01@F8`0G6BH04Q@Q01<E8@0L7RX05aTT01DG8`0F
62@06A/X00807Al/06X06Q`Z01LI9P0D5R805aXR01HJ7@0?4a@051PF02<U8P0>40d061XG018D4`0L
7Qd07R8Q01`P8@0D61/0724U02<X;00H7B4051/R02@Z>00T:SX061h^01TO;`0Q9cD082Hd01<I9`0M
8bl05QdW01DL9P0L8bd04a`U01XS:P0=61h0F6=Y04YEF`0E82H09S4g01@O9@0F8BL07BP^01hY;`0J
9B/072L]01LP9@0O:2d07BH[01HO9P0Q:S4092dd02</=@0P:C<07bLb020X<`0N9S406b@]01`W:`0M
:B/07R`]01l];P0O;S007B`_01d/<@0N<3@072hb01TZ<@0K;3<07c0g01h`<`0P<SH08C<g028c>P0Q
<SX0834i02<c?`0U=D@09SI502@dA00S<TD08c=302Li@P0^@4X08S@n01h`?P0H:CT0;Ci>01`]?@0Q
<d40:Sa802@f@@0M<3L093Ln02a0B@0cAe009c]402Di@P0Y?DH08SHo024e?P0T>4407c<l01T]=P0J
;SL07c8i028c>P0S=3/0834h0P0N;cH06P0T=C`07Bhf020a>@2R/k`0OHjH04UJI00F9Rh06RT^01/Z
<@0J:C005RD/01@Q:@0D82L06bHZ01XU9`0S;b`05R4K01dX800N:B@000T702`h=P0D81h07RXX024]
;@1]NGT09C4a0P0B7Al0100A71h06RDX01LQ8P0I8R4201XS8P0F01PQ800F7ah08R/Z02H_;P0B6aX0
7BHU01TR8@0I8R806bHX01TW:P0I9R`06RL_01`Y<@0O;3D06bLc01PT<P0I9CD06B@f01DP<P0G8cD0
7bTc01/V;0805R4W02D05b8X01HQ9`0E82H05B0V01HQ9`0G8RP05R4W01DO9@0D71l04QLK01/P900Y
;S806b0T01<H700B5a/051TM01XO8`0I7R805Q/O01XO8`0<4AD0@TM;079gN`0[<3@06QlS01@I7@0X
;C4061dQ01`Q9@0D6Ad06b0T018G6`0G72806AhT01PM8`0G72805AXP00804QLM00/05AXP01HK8@0D
6Al04aPN01<H700N8RD06QhO01DI6P0@51D061`M010D5@06018F5`805ALF00@04aDD018D4`0E5aH0
5aTH1P0F61L0200h?3d03a<D00hB4`0<41404aLH018F5`0D61T04ADF0P0B5QL0800C5aP061`M01HG
6@000@<03@h@01XK7@0I6Q`0EEIH02<T9P0720X04Q<E00`=3`0E5QP05ALG02/];00J71/05QPG00/=
300L7Qd04Q@C01DG5P0C5A@04A<B01<E500B51<04a@D00l?3`0@418051@E01/K6`0J6QX0410@0P0B
4Q802`0C4a8051@B01@D500I6AT071`N01HF5P0A4A4061PH01LG5@0B4Q004A4?00<04Q<>00h04A8=
00`=1`0>3`T051D@01HF5P0E5AD06ATK01HF60020P@051@C01LG5@0F5a804Q<>010@3PD0410@0P0>
3Ph0400A4A4061PH01dM7@0A4Q806Q/O010D5`0M7R003@h@00<41P0O7al07QhN00d=3@0@3`d03Pd;
00l=2P0@30T600l>300;00d<2P0G5Q@02PT701@C4@0;2PP02@P600X:2P0@41001@D303`j>`0B4@l0
0`0C3``301@?2`0@01@@3@0A40h040l=010?3@0A40h040l=00d<2P0B4@l03`h<018A3`0I61H061LE
00d<200P81T08R8J01@D308040l:01l02@P3018A3@061@<030/901@C4@0F5A<02@P601DD4P0A40h0
1PD301<B400?3P`040l=00T81P071P@00P4000d<2P0H5aD01PD300`81P0I5A802PH301LC400=2@H0
8QhK00`81@0C3``0510=01LC400F4Pl04Ph;00804a8@018040l=00d<2P0>3@/04a8@010?3@010000
2`X8014@3P0J6AL040`:01@<2P0A2@L03`L5018:200F3P`050`:018:200C2`T301@<2P0400h:1`09
20@03@`8010?2`804A0<00L03`h:00@3000;2PH06APD02PW8`040`004@h;00<04@d:00<040`900l;
200@30T01@0@30T600h=2@0600d<200>3@T03Pd900/:1P0:2@D03@`81P0@30T06`0?2`P03PX700h:
1`0>2PL03`/8014=2@071`003@d300P80@0=30L010<0014@300>3@/02PP:01XH6`0Y9b`04Q0F018@
5@0:20T02`X801<B40071P@04A0>01@C4@030P0030/900h=2`0200l>300700X91`0;2PP01PD300h=
2`0920H02`X800l>300200h=2`0:00d<2P0>3@/04A0>01@C4@0B41<03P`?010>4@0;2@`0:RP[01TG
6P<030X=00@03@/>00h<3`0A31004PX?0P0C3A403`0@3A003Ph@00l?4@0?3a4030X=00/62P0D3Q80
5PdB00d72`0B3a0030X;00<10P0>30d0108301/I6P0200l=3P803P`=00<040h?014?400?2``01@0?
2``00`0A3@h040`=010<3@0200l;300G014=3P0810D04Ph?00l;300=2@X01@04018=4P0500H04@`B
01@?5@0G4QT020<:00X6300K5Qd050lF010;4P0:1@/0>3<i00P4200;1PX03@T:014=3@0?2`X00P0>
2PT01P0?2`X02@D401HB4@070`8040`;014=30803`/:00P03PX900d9200=2@P04@h?01<A500610L0
9B<V00<1108030X=0P0=2`h200X82`0300h<3`0>2@d03`X>00804PdA00<04@`@00l:3P0?2Ph00P0@
2`l00`0>2@d03`X>01@?4`02010>4`0;00l=4P0>31403@/@00`:3`0F51T02PP=018@5@0>314040hC
01HD6@0E4aH00P0=2`h02P0B41<030X=00T72P0<2Pd02`T<00`:3@0>30l04Q0C01<A500:20T200`:
2`0900/92P0<2P/03P`=00/92P0E4a@02PP900<10P0I5aP04Q0A01Cooooo000Kooooo`0:00P61`0H
5QL0108300l=3P0=2``04@l@01DC500D4Q<04@l@010>3`803`d>00T04@l@01<A4P0:20T03`d>01<A
4P0=2``02`T:00h<3@0=2``00P0<2P/03`0=30X03`h;00P71P0B4@l040l=00d;300C4A8040h?00l=
400=2`h03`d@01XH7@091``03@/>00l=4002014?4P0:00l=400>30l04@lB014?4P0@3Q403P`?00l=
400@3Q405A4B01@@4@@04`l@00`04@d>01TE5P0J5QL03@T:01/G600>3@`061PF00L71@0;2`T05QHD
00/;2@0C4a42010@3P04014A3`0B4Q004a<A01<C5P804Q4I02404Q4G018B5@0B4QD05ADE01dN6P0G
61@04Q<=01<E300?40P051@>01DD400D4a4051@B01DE4`0H5aL05QLF01@F5@0E5QP051LH018F5`0A
5AP04ADF01lS8`0a=CP030lE01`O9`0D5R806Q`Y018D8@0G6BH06Q`Y018D800G6BD00P0F6B808`0I
6bL071hZ01`N:P0J72L04aHP024T;00S9R/051PI01DI600E6AH08B<N01dP6P0J71L041DA01HJ6@0D
61T05a`O028W:`0T:Bl05QdT01LN9P0H7RT0:2hn024V>@0L8C@04QPX01HL;00G7B`06Al]024W=@0J
82d04aTU01PN:P0L9Bh04Q/S00807RT_02h062<Y02/f?00L9bd062<Y01HQ9`0H8bT06B@Z024/<P0_
>T009C0d01LR9P0K9RX05R4W02Ha=`0T;cD06bD^01hX<P0S;CL09Bli02@^>00N:34072L[01hZ;00M
:b`07B/^01d/;`0N;C006RT^01h_=P0M;SD06BXa01//<`0O<3L07c4e01h`=00Q<cL08C8i020a>@0R
<c/08S<m02<c@00Q<Ch07Rhm028b@@0U=D@08S@m0P0Q<cd0@00Q<d407Rlo02@eA@0Q<T807Blm02@f
@P0S=D006Rdd01P[<P0Q=Ch0:Ce6024e?P0R=Sl0:3a502@h@@0Q=Ch07C4j01lc?00P=3d07C4j01`^
>00N;cT07c0j01h_>00M;SH07Rlg01d^=@0X>D007Bhe02Tk@@0G:Bh0:ca201TZ;P0L:bh072/`01`[
<@0H9bh05b@/01TU;00@6al06RDW01`W9P0V<B`0@Da501@P6`0N:RP06RHT01dY:01MJFT07RXZ01dY
:P0D7b405b8T01`W:P0?6Qh041/N01/U9P0I8b805R0O01DO7P0F81l06B<R01HP7`0I8b8201LQ800@
014K6P0H8b<062<W01LT:P0J9bd06RL_01TV;P0H9Bh06bLc01LS;`0H93806bLg01LS<`0F8S806B<[
01TT:0806RDY00D06B@X01HQ9@0A72004ahR01@O8`02018M8@0I01@N8`0C6ah08BHZ01DJ7P0J7b<0
6AhR01<H700F6al04aPL01HK7`0G72005AXN01PM8@0C61`05a`P03a1A@0F6al05a`P014F6P0I7R80
4QLK01@I7@0:3a<05a`P018G6`0201DJ7P8061dQ00<05AXN01@I7@0A5QX00P0D6Ad02@0C61`05AXN
01LL800X;2l04ADF01HJ6`0B5QL05QXK01LK700601<G60805ALF00<051HE018D4`0D5QD01`0E5aH0
7@0l@44061`M01@H6@0A5AH05a/L01HJ6`0C5aP04QHG01HJ6`0D61T041@E014E5P0>3a408b@V030a
<`1MGV004A8D03@e=`0B4aD03a0B02LX:P0G61X05AHH014C4`0O8B0051HE018D4`0=3`h06Q`K0080
4aDD02X03a4@01@F5@0Q8b8071hM010A400A4@l05aLF01<C4@0E5A@06ATI014A4@0C4a<04a<D01<C
5@0B4Q<04A4C01HF5`0K6a/06ATI01<C4`0C4a805QHD01@D4@0?40/04A8=014B300@4@/03a0:014B
300C50h04Q<>010@400A4A40410B00l?4@0T92H06ATH00T91`0G61<03a0:00l?3@0@4102018B4P0:
014A4@0@41003`l?014A4@0?3`l03Ph>00/;2`0?41004A8F014E6080414C00P0;c0b0;Jf]P1:BTX0
7AdM01@C4@0I61H030T701HB3`8040l=0P0A40h2010?3@0E01PG5@0?3P`04A0>00P71@0C4Q00:RTX
03<c=00m?T0030d>00h?4@0D51D0410?014@3`0A40h04Q0=018?3@0C3``04Ph;014@3P0@3`d04A0>
00804Q4?00h03`h<00/:200<2`T040l=00l>300<2`T03Pd9014@2P0:2P<03`l7018A300@3`X04A0;
01/J5P8081lM0P0B4@l01P0=30X081lM01HE4`0:2@L04A0>00l>308040l=00h03Pd;010?3@0A40h0
92<Q01/J600A3@/02`L601TE4P0=2@L06aLD00H20@0?2`P04Ph;00l;208040`9010030P5010?3@0@
3`d03Pd;00/:200=30X0?C`j04Q7A@0C4Q0030/900/:200C4Q003PX700`70`0?2PH050l;0P0B3@T0
0`0A30P040/7014<2003018=2@0=018>2P0@3`/02PT500`;1`0?3PX02`X601DD400<2`P02`X601lN
6P0];2P03@`8010=2P03014=2P03010<2@0?2`P040`900D040`91`0>3@T200l>2P0300`;1`0;2PH0
3Pd900H040`9100?2`P0800@30T04@h:01<C30092@40410801@C3P061@404A0<00d<2P0;2PX04a4D
01HD5`0<2`h03@/>00d;300>3@/04A0>00P71@0>3@/030/900l>300@3`d030/900d<2P0@3`d02`X8
014@3P0:2@L03`h<00d<2P0B4@l03`h<0P0>3@/0300=30X03Pd;014@3P0C4Q003@/=010>4@0;2@`0
6QPK09RFV@14@TD05aDH01@B5@8040hA01X03P`?00l:3P0@2@d04P`@014<400?31004Q8D01DE5`0C
4aD040hA00h:3P0A2`l05@`A014;3`0<2@X0518C01hL7@0e<c@03P`=014?400;2@X03P`=00d;300;
2@X03P`=014?40L040`=0P0?2``200h:2`0;00`8200=2@P030P901@@4@0B3Pl040/?00h93@0<1`/0
3PT?00`73@0@2a400P0>2@l0200I51X020<9014<4P0@2a003PT>03<^<P0J5AT03PX;0P0A3@h0200?
2`X03@T9010<2`0<20L06aLF00h:2@0B3Pd03PX90P0?2`X02@0>2PT03@T800d9200;20T061HI01lM
800:20/00`84010>4@0600h<3`803`X>0`0A310600l:3P04018=4@0>31403P`A00h<4@<03`dB00P0
3@/@00`:3`0=2a002`T>01/I7P0;2@h020H900/930803`d@01@03@/>010>4@0:20/02@L:00/9300?
3A004Q0C014?4P0<2P/03@/<00`:2`0;2@X03@/<010>3`0g=CH03`d>014?400>30d02@L8014?41Co
oooo000Kooooo`803`d>00D03P`=014?400?3@h03@/<00/92P0300X82@8030X;00L04a4B014?4003
0@806aTJ05=ADP1FE5D030X;00803P`=0P0<2P/03P0>3@/01PD30040000:2@L03@`:010>3`0D4Q<0
2@L800P62@0m>ch030X=010>4`0=2a003P`?0P0?3A02010>4@<03`d@01d03P`?00d;3P0@3Q404Q0C
014?400B41404a4B018@4@0?3@h03P`=00`:2`0610D09bDV00`:2`0;2@X051<C01<C4`0=3@d06ATI
014A4@071`L04a<C00l?3`0@41004A4A018B4P0C4a<04a<F01<B6002014@5P0J014A4`0C4a<061TE
02@U7`0M7QH05aT>01LI300A4`H04a@<01DA3P0E4A005Q8A01@C4@0D4Q<071XK01dM7@0F5QP03`lA
00d>400@4AD04aDI02HY;P0g>T005QTP01XM9P0G6BD200lA7P0501PJ9`0G6BH0418O01PJ9`0H6b@0
0P0G6R<201TL9@0d01PK8`0F6Ah061`O01HJ700A5A@041@C010E400@5@l04AH?01HK5@0Z;b/0310?
01PM7`0B5a/06b0V01lV;`0I7b/061hZ01LN;@2l`M@0C55U01hS=P0e>Td06Al`01TO;`0H7Rh05Q`[
020V=00Q9cD05Q`Y01HO:00U;SL062<Y02@_=@0c?T@092le020[<@0O:S006RD[01HQ9`0C7R@06bH/
02dh?P1FHFD08B``02<^<P0L9bd08Rdc01DP9P0I8b`06R@^01lY<`808bdg02H082Xc01`W;@0K:2/0
6RP[01d[;P0[>Cd0>4M<02@c>P0G:2l05BH]01PY<@0J:c<062T`01h`=00L;S80838f01l`=`0M;SH0
8S<k020a>@0T=Cl08S<m01h^>`0P<3d093A1028e?@0N<3X0838l02LiA`0G:3P03b0`02LhB00R=480
8SA0024c?P0P<cX08SDl01`_=P808SDl00T08C@k02<f?@0U>3l08C@k01`_=P0P<cX08cHm020c>P0N
;c/00P0Q<D00?00O;c`072dg01`]=`0L;CD04B8Y01LY;@0M;c40838d02Li>`0F9bL06BTY01PW:P0G
9RX05B@Y01DR:P0E8BP03aXN01@O8@0G8R4062<O02lj=00C7a/08Rh^00`H600C7al09c<c01<N800J
9BL051lQ01dX;00D7b<031LK01`W;00H8R@05b4R01HP8@0E7b005R0Q01TS900E7b0031HG01LQ8P0>
61T05b4R028];P0J9BT06BH/01XW;@0I9Rh05b@/01DR:`0L:C8062D^01`X=00Q;C/07BTg01XV<`0E
82H05R4S01TT9P806RDW00@06bHX01<N800E82805R4S0P0D7b406`0H8bD06b<V02<X;00I7R806QlS
01LL800L8BD061dQ01<H700J7b<07b@X01TN8P0A5QX051TM01/P900h?D40724U010E6@0G72004QLK
01LL800B5a/06AhR00lD600B5a/05a`P01<H700201LL800>018G6`0D6Ad061dQ01LL800C61`04AHJ
01<H700G71l0TYJI02``<@0>4Q<05ATJ01@H6@0E6AX601@H6@03014E500C5aH04aLF00T041@C00d0
20`=00/?40093@h041@E01DI6P0C5aP041@E00dA4P0B5QL051PI010D5@0A5AH061TK00803@h@00l0
6Q/M00d>400A4Q@04A8D01@E5`0H6A/02``>00d>400D5QH02P`;00lA400>40l04aDD00d?3P0A4a80
0`0C5A@02`0N81l071hM01HH500>40/030h901dO6P0i>cH0<cDb01<E500?4180414E00804A8F00@0
414E010A500@4100410>0P0?3`d00`0C4a404A8=00d>2@02010A2`0@00l@2P0=3PP02P/500l@2P0B
4`h071`L02TY:@0a<C<071`N01LG6@0;2`X05QHD00@5000A4Pd03Ph<00l?3`804Q8B01D04A4A00l?
3`0>3Ph04Q8B01@D500H61P07QhN05UJFP1BDeL0DUII01/L7P0?41805QLI079bLP0i>CT06a/K01LF
500H5aD040d;018>2`0@3`d0100B4@l03`0@3`d00@00038a;`0<2`T061LE018A3`0<30`04A8D01@F
6@031`X09b/^014D5@0I6Q`03a0B010@400200l?3`803`h<00<040l=00l>300A40h00P0C4Q002P0A
40h05aHD014@3P0C4Q004Q4?00l>300C4Ph04A4:010@200>3PH2010?2P0900l>2@0F5A4092<Q020O
7@0:2@L040l=01<B40071PD01PD300803@`:01005A@B018A3`0;2PP00P4000H50`0M71X09B@R01DD
4P0E4@h02@D200`81@0E4@h04Ph;01<?300D40d04`l<0P0?2`P00`0@30T03@T600d<2P0300l>3008
018A3`0E51806QTG01HE4`0E51803@`:014@3P0;20L2014<200301@?2`0=20@02PD100803PT50140
3`X6014<200@2`L040/700h;1`0A40`030/701<B3P0I61@04A0<01HE4@0C4Ph03Pd9010?2`081`<0
40l;00/:1P0300l>2P0300h=2@0=30P03`h:00D03`h:1P0>3@T300l>2P8030/700<03Pd9010<2@0@
30T0200@30T0400A3@X04Ph;010?2P071P403@`7014@300:2@D03Pd901TH5P0E4a<030X;00400P04
0`D03`d@00P61`0D4a4200d<2P0=00l>300D4a402@P600T81P081`D03@`:01DD4P0C4Q004A0>00h=
2`0@3`d02`X8014@3P0200`;2@@03Pd;00T03@`:00l=3P091`P04@l@01<A4P0Q7b004Q0A01XH6@0E
4a@00P0A3a006P0>30d03PX;00l93@0B310040/?00l=400H61X07AhP018C5@0;2@`040hA018=4@0A
2`l05@lC010=3P071@H03P`=01TG600:20T02@L800`:2`0?3@h03P`=00X82@0=2``04Q0A1`0A3@h2
010<3@803`/<01H040`<01PD4`0:1PD0?3Pg010<2`0G4a@01@4300`72`0A31005A0E00l:400@2a40
4`hC07MbMP0U82@05A0D00<00P0M61`0:2@U01TE5P0<20T040`=0P0>2P/01P0D41000`0001DA401M
FEP07a/J00L30P<03`/:00X03PX900d9200=2@P03``<01TG60071@H08AlP00l=3P0:2@T040h?0P0=
2``201@B4`0300/92P0?2Ph03`X>00<03PT=00<03`X>010;3`0?2Ph00`0@2`l0500>2@d02`T<00/9
300=2`h03`d@010>4@0A3a803P`?00d;3P0B41<04@lB01dK7P0?3A003@/>00h<3`0=2`h02`T<00l=
400C4A@030X=0`0=2`h200`:3@0<00h<3`0?3A003@/>00`:3@0?3A004a4D08n=T00X9RT03@/>018@
4`091`X01@<65?ooool001_ooooo00P030X;00D3100A3a004@l@01<A4P0?3@h040h?00l=3P803P`=
00T03`d>010>3`0<2P/040h?00800@0L6Q/0EUAE04Q6A`0=2``00P0?3@h03`0=2``03P`=00l>300B
4@h030/900L6100;2PP04@l@00h<3@0D4Q<0>3Hi0;Ne^00d<SD00@0401LE6P0200h<3`0400l=400@
3Q4040hA010>4@804Q0C0P0A3a801`0D4QD05Q@G018@4@0E4a@05aDF01DC500A3a000P0?3@h07P0I
5aP05aDF028P8@0=2``03Pd>01@D500B4Q8030`<00h>3P0=3@d04Q8B00l?3`0@41004A4A018B4P0C
4a<051<G01<B600A41H0410C014A4@0C4a4051D@01XK4`0E5Ph04Q@801DG2P0A4`D051@;01DA3P80
5A4@04/04`l>010>3`0?3@h04Q0A01DE5`0J6Q`05aLI018C5`0A4aL05APO010C6P0G6R<05APQ01XL
9`0L7RX06Q`X01HH9@0K7BX07Al/010B7`0I6bL05aXS01DH8@0G6R<061/R01LJ800V:Rd05a/N01<G
600J7Qd05ATH01LL600F6aD041D>04aAC01oQ8007B4P01<H700G72805A`T02D[=P0]<d409R`j02@[
?00e>Td08bPl02dbA@0P9CP07B<d01XP<00M8c<05Q`[02hd@P0e>dT082Hc01LP:@0H8BX06B@Z020[
<@0jAD/09c8h01<N900I92X06RD[01/V;00F8BL04ahT01/V;01II6P05R4U01hY;@0K9R`08Rdc01@O
9@0O:C800P0L9S009P0M9c407RPb01`V;`0N:Bl07BX]01XX:`0I9bX07bhb02Pg?00jBE007Rlf01PY
<00P<CT07c0h01PY<00O<3H06bda01la=@0M;SD072de024b>P0R<c/0:CY402Pi@`0S=3h08c=002Df
@00V>D00;Cm902@f@00R=480835102XkB`0N;cl08cE302@f@P0N<3/072lf0P0O<ST02`0T=ch0:3]2
02<f?@0Q=3/09cY1024d>`0N<CP07C0g01`_=P0J;C@06R/h00807Rhn02<07Bdl01/[>00L;CL08C8j
00LI7@0J;3008S@e01T[:`0M;bl07c0`01d];@0K:Rd06RT]01PW;00I9Rh05b<Z01dX;P0G8RH06bHW
00XD4`0D7a/072PU01<O7`0<61P06bLW038n?P0?6Q`05R4S01@O8@0I92P051lS01DP900D7b@04adO
01<M7P0401@N7`0701lY:P0>61T07BLX01DO800Z=3D0>49401XX:`0201XW;@0<01/X<00L:C407BXc
01dZ<`0J9c007b/g02Da?@0R;SX07BTe01XU:`0J9BL06B@V0P0G8R@0100J9BL04ahP01HQ8`0G8R@2
01@O8@0<01TT9P0D71l04QLK01@I7@0J7b<041DI01dR9P0F6al04aPL020U:@0Y;S808BHZ0`0D6Ad0
700[<3@06QlS00lD600K82@05AXN018G6`0010P04aPL00dB5P0S:2`06AhR01@I7@0G72005AXN010E
6@0C61`07B8V01TN8P0C61`03a@H014F6P0F6ah092PY01PL7@0I7Ah04aLH01HJ6`0A5AH6018F5`04
014E500D61L051PG014E50803a<B1P0A5A@00`0G6a`07b<T01<G600201<G600L010D5@0B5QL0310A
00lC500A5AH03a<D010D5@0@4A<04a@F02HW:@0=3Q004a@F01@E5`0C51H03@h@014B500E5QP04A8D
01XL700:30/05QPG01<E500H6QT01`T8010B4@0E5aH061XI00lA40804Q@C02H03Q0<00d@2@0@4Pd0
4Q@?020R7@0O8Ah030h=00l@4P0A4QH051DI01DF6P0D5AX05ADH014A4@0?3`d04A4?018B400C50l0
4A8=00l@2`0B4`d04a@>014B300?40X05AH@01HG4@0?40/030`<01@D500E5AL03Ph@01XJ700<30/0
6ATG010A300=3PT03Ph<00l?3`804Q8B01H04A4A00l?3`0B4Q805QHF01<C4`0;2`/02@T904m@D00H
6Ad0:2`_00P92`0I6Q`02@X<01dM7@0E5AD03@d=01@C4@0A40h0518?00h:1`0=30X03`h<0P0@3`d0
400?3P`03@`:014@3P0I61H05A@B010?3@0>3@/030`<00X;3@0=4A@0Ad]>0<gAe00R92L010D700l@
4P0@414200l?3`0900l>3@0?3P`03`h<00h=2`0A40h04a8@01@C4@0B4@l071/I00803`h<00h04Q4?
00l>300@3`/030`601DE3@0:2P803@`701HE400?3PT030/700/:200?3P`03@`:01<B40<03@`:00l0
6QTG00h=2`0B4@l02PT700h=2`0H5aD02`X800/:2@0@3`d03@`:010<2@0E4@h03@T600X6100=2@H0
0P0A3@X01P0H51405a<@01LC400A3@X02PH300`;2@803@`:00d030/900h=2`0A40h01`H400@30@0;
2PP01PD301hM6`0G51404`h:018=2@0F4@d04@`800804Pd901803PT500l:1P0@2`L040/700l:1P0?
3@T05A@@00T8100920H03@`800H50@0A40`05A@@00l>2P0F5A402PT5020O6`0;2PH300l>2P0300h=
2@0=30P040l;00D040l;1P0>3@T00`0?3PX040l;00l>2P0200`;1`0300h=2@0@30T040`900@040`9
0P0A3@X0>@0@30T04@d:014=2P0C3``030/600L60@0:2@@04Q4=00l>2P0A40`03Pd;00T81`0A3a00
3P`?014?4P050`@03@`:02<R800H5aD05A@B00T81P0;2PP04A0>010?3@0=30X040l=01@C4@0=30X0
2`X800h=2`0A40h020L500d<2P0:2@L030/900h=2`0?3P`03Pd;00d<2P0;2PP020H701<A4P0B4140
<2h_018@4@091`P04Q0A00h<3@0=2``04@l@010>3`0>30d040X>018=4@0A310040lA01XK7@02028S
9@0A00X:300>30l03PT=00d72`0C3Q805A8C00<10P091`P01`D600l=3P0C4A804@l@01@B4`0@3Pl0
2@L800X82@0>30d01P0A3@h2018>3`804@d>01@040`=00/71`0@30/01P8105iJF@0H51<07a/L014<
3`0A310020<7014<4@0>2@l04`hD00/72P0[9bP020<700l;3@0I5AH01@4201<?40802@D600X05A4B
00h:2`0;1`P04`l?014=300300004Ph=014=300E4A003PX90P0?2`X01P0>2PT03@T800d9200;20P0
0`4201LE5P802@L800@04Q0A010>3`0<2P/03@/<0P0G5AH01P0:20T040/?00l:3P0=20`030L;00d8
308040/?00D03`X>010;3`0A310040/?00`72`0600h<3`0600l=40071@P040hA00d;3P0?3A002`T<
0P0<2Pd01`0=2`h03`d@00l=40091`X030X=010>4@0A3a800P0?3A002`0@3Q403`d@010>4@0=2`h0
30X=00l=400D4QD04Q0C00l=400:20/00`4400804Q0C5?ooool001_ooooo00D02@L800h<3@0A3a00
2`T:00`;2`0700`:2`0K00h<3@0B41403`d>00/92P0>30d05A<D010>3`0>30d04@l@00d;300;2@X0
40l=00l>2`0>3@/03@`:00h=2`0>30d03`d>00h<3@0Q7b80EUAG01@B5@0C4AH020H;00h<3`0B41<0
4@lB00803`d@0P0B41<0:P0C4A@04@lB00l=400@3Q404Q0C01<A4P0D4Q<06aTJ01<A4P0<2P/04Q0A
01<A4P0?3@h0HEmP03dk?00;2@X03Pd>01<C4`0=3@d0410@01DE5@0A4A405QHF00`<300J6QX03`l?
01LG5`0=3@d05ADG01@C5`0G5aX04Q8C01HF5P0;2`T04a@?01@E3P0A4PX05AL<01LI3@0B50P05aL@
01HB3`805a<B00/05Q<B01@B4`0D4Q<05aHF014A4`0J6Q`061PJ014B5P0K7B<03Q4I01DH7`0301@G
7P0i01DH800C5Qh04A@N01@F8@0G6BD06A/X01HH900H6RH06QdV01XM9@0J7B@061/P01DI700M8B80
51PI01HJ6P0<40l05a`J01LL5`0J7aX0>3`i059HE`0H7Ql05a`Q01DL8`0C6R<051`W01/R<@0O9SH0
7RDg01PM<00M8S@08bPj01DK:`0Q9cL0CeET01@J:00G7B/07R@a028X=00M8bl051dV01`U;@0G8RP0
6RD[01HQ9`0M:2h062<Y01/V;00I92X07BP^01PS:@0L9bd062<Y01DS9P0F92L06BLZ00807BX`00`0
6BH/01h[<`0M:S<06RL`020]=P0L:C807b`d028]<`0N:Rl07BX`01l/<P0Q;cH2020_=P0701TZ<P0K
;3@0834i01l`>00L;C@07c4f01h_=P0201d^=@0=01`]=00K;3<0834i01l`>00T=Cd08c@l024b>`0U
=Sh0;D1702<e?`0T=T008cE3020a@@02028c@`0`020b@00R=4007c4l01ha>00R=C`06bhd01T/<P0O
<SP08cHl020c>@0R=C/072le020c>@0O<SP06bhd01X]<`0K;CP08310028b@P0P<3l07Bdj01l`>P0O
<3P072hb01d_<`0N<3406bh/01T/:P0I:RT07bl^01HV9P0E92L05RDZ01@Q:@0M:C005B0V01<N8P0M
:2X0628R01DO7@0L9bD04AdM020/;00I9BH04ahP01hY:`0/=cX0;CPl0P0P:c407`0I92X05R4V010K
7P0D7b405b8T01@O8@0B7Al051lQ01HQ8`0D7b405B0R01TT9P0J9BL062<V01h/<00>6b40;S]303Q5
C@0I9Rh06RL_01LT;@0E8R/0<Ci70<GBf`2^^l@0:cM101HQ9`0N:Bd06RDY01PS:00C7R800P0D7b@0
8`0@6al04ahS01LR9`0D7b<05AlT01LO8P0N8bL061dQ01DJ7P0H7B405Q/O01XO8`0H7B405AXN01<H
700F6al04QLK02P]<@0L8BD0<cPl02H[;`0F6al0:Rlc01LL800B5a/05Q/O01TN8P0D6Ad04AHJ01PM
800D6A`04aPK01@I700E6Qd04aPK00805AXM00L04aPK01XO8P0A5QT03A8E01@H6@0E6AX051PI00H0
4aLH00D04QHG01@H6@0F6Q/041HD01DK6@02014G5@0401<I5`0?5A<051XH00hD4P804ALE00h03aDC
01<I5`0F6Q/041@E01HJ6`0A5AH0?411038f=`0@51D03A4B00lC500D61T041@E00/?40804Q<E00@0
5QLI014B500F5aT04a@F1@0B4aD07P0B4a@0418A010B4@0@4Q404A<B01<E500B51<071hM03Tk>P0C
5A@05ALF01LI600G6AD04A<=010B3@0B50l04aD@018D4@0@4Q404a@F01@E6@0@4AD03PlC01<D6@0J
6Q`05QHD018B400A4@h04Q<>014B3@803a0:00T04A8<01<D300C50`04a@<01<D3P0E5Q003a0;01<C
4`0?3`l00P0A4A<07`0B4Q@03`l>01@D4P0A4Pd051D?018B400@41004Q8B01@D500@41004Q8B01PH
600820P05ADE00T92@0C4a<03a0@02X[;`0T:2/03PlA01PI6`0@4A<03`l?018B4P0A4A4040l=00l>
300A3P`04`l<00l>300A40h00P0C4Q005P0A40h03`h<01<B400Q81h01PD401<B400>3@/04a<C018C
5@0:3Q404aLJ05eQI00B51H03PlA00d>400<30d03Ph>010@400?3`d02`X800h=2`0@3`d300l>3080
3@`:00P051<A010?3@0B4@l02`X800l>2`0A4@X03Ph600l?1`804a8=01<04A0;00d<2@0=30X02`X8
00l>300:2@L040l=014@3P0@3`d04A0>00d<2P0<2`T040l=00h=2`0?3P`030/900h=2`0?3P`03@`:
00803`/800@040`9014=2P0A3@X04@d:1P0@30T500l>300L00`;2@0K6QP08B0N00h=2`0@3`h04a8@
014?300@3@P05a<?00l<1`0A3PT040d9014=2@0@3@P03`/7014>2@0B3`X04Ph:014>2P0?3PX03@`8
00h=2@0C4Ph05aHB01@C3`0@3`/03`h:010?2`804A0<01H03Pd900l>2P0J6AD05aHB00/:1`0@3`/0
3Pd9014@300E51004a8>010?2`0>3@T04Q4=00X91@0<2`L040l;00d<200F5A40;B`X01@C3`0=30P0
3Pd90P0=30P01`0E4@h06QHC01XF4`0@30T030P5018>2`0C3``00P0>2PL01P0@30T03PX700h:1`0=
30P051<?01HE4@803Pd900X03@`:00h=2`0>3@/03Pd;00h<3@0=2``02`T:00h=2`0a<2h03@`:0P0A
40h01P0;2PP03Pd;00d<2P0=30X03`h<010?3@L03Pd;00/02`X800T81`0B4@l03Pd;010?3@0:2@L0
30X;01HD5@0>30d030X;01@B4`0200h<3@0H00`;2`050`@040h?00`:2`0;2@X04P`@00h93@0<2@`0
5QHH02`];`0h>C/071dO00/;3@0>3@l04@dA00X5200B3A403P`=010>3`0E4a@061HG01<A4P0@3Pl0
3P`=0P0=2``01P0>30d03`d>010>3`0=2@X03PX;00l;30<04@d>02@04Ph?010<3@0?2``03PX;00`8
2@0=2@P03PX700l;200B3P`0510?01DA400B3Ph03`/<010;3`0?2Ph03PT=00l:3P0A3@h04Ph=018>
3P0B3Pd040`<00h:2`0<2@T03`/<01TE5P0?2``04@d>00T51P0<20P030P7014=300@30/02`L600d9
200=2@T200l;2P0C00d9200>2PT030P700T61P0F51D0518C00X82@0>30d02PP900d;300C4A803P`=
00P61`0@3Pl03@/<00/62P0@2`l04@`@00h93@02010;3`<03PT=0`0=20`200h<3`8040hA00h03`d@
00h<3`0?3A003@/>01<A500R82<05aDH00d;3P0:20/03`d@01DC5P0@3Q403@/>010>4@H03`d@1`0>
30l01@0U8bH05Q@G01<A500>30l04@lB01Cooooo000Kooooo`0601`J6`0=2``09B<T01XH6@091`P0
5A<D1P0?3@h01P0:20T03@/<00d;300;2@X03P`=01DC508040h?01404@l@00h<3@0=2``04A0>00l>
2`0>3@/03@`:00h=2`0>30d03`d>014?400=2`h03P`?00`:3@0M6b002`T>00d;3P0200l=400700h<
3`0?3A004@lB010>4@0E4aH05Q@G01<A500200l=40805ADE00/06QXJ01<C4`0=3@d04Q8B014A4@0=
3@d02PX:00h>3P0P82002PX;01<C5@0200l?4@0V00h>400<30h0410B01<C5@0G5aT03@d?01XJ700>
3Q00410B00T92@0=3@d04Q8@01hN70092@L02`/801HG4P0G618030d7028S6`0>3`L06a/F01@C3`0B
4@l04A0>018A3`0D4Q<05QHF01lQ800G61X02`/=00T=3P093A004QDK00d@6@0C5Qd04QDJ014D6@0C
5Q/201HI7P1@01HI7`0F6B005aXS01TL9P0Q8c008R@a02<U<@0Q92d07B0W01TL800F6Qd06alP01DI
6P0G6a`04QHG01PL7P0;4A40728P00lE500C61/03A8F00/B5P0A62004a`U01TQ;@0J8c806b@c01hV
=@0I7bl041HT01<I:00M8c404ALU00L=6@0G7BT05Q`W01LN:00I82X06R4Z01LP9`0N9bh062<Y01dX
;P0H8bT06RD[01@O9@0K9R`06B@Z01lZ<00I92X06RD[01<N900D8RD062LZ01/Z;@0J:Bh062L/01LV
:`0A82L08c4i01PV;`0_?DH06bTb01XW;`0R;C<082`b01h[<@0P;CD07R`c01XY<00H9Rl06BXb01`]
=@0N;cT072dg01X[<`0O<3L07Rlf01d^=@0L;C@201X[<P0T02Hg?P0N;cH08C8i02@e?00Q<ST0834h
024d>`0N<3X08S@n02<e@`0O<4008C920352DP0Q<d407Blk01`^>@0M<3L083<j01d^=@0K;3<07c0g
024b>@0O<3L0834h01l`=`0Q<ST07c0g01`]=00K;3<06b`g01h^?P0R<T808C5001`/>@0L;CL07c0h
0P0N<3@0900L;Rl06B/[01P[:@0I:RP05BDT01PX:00I:2X072/^02<`=P0K9bd06bH/049=D@0nBD`0
628S020Z:@0X<c<02A@F02@_<@0F8B<09C0b010K7`0H8bP04ahT01XU:`0W<ST07bTb01LQ:@0C7R80
5B0R01LR900E828051lQ01DP8P0D7b405R4S01TT9P8062<U01`06B@W01PU:`0A7RH0NXN?0;:oa`0b
?dL04b0X01`Y<@0E8RX08c0h07J3R`1]NX805b@/01/U;P0H8bT041/R00lI8P0B7B<05b4Y018L9@0A
728051lV01@N9`0@6b404Q`T01<J800A5QX04QLK0P0D6Ad03P0H7B405a`P010E6@0<4AD06QlS00dB
5P0D6Ad05a`P01<H70021`/04QLK01DJ7P17C5006b0T0`0F6al03P0B5a/051TM018G6P0A5aL04aTI
01HL700G7Ad05A/K010F5P0G7Ad06R0P01@J6P0A5aL041HF0P0D61T201<G60804QHG02@04aLH010D
5@0@51D04QHG014E5P0@51D04ALE01HL6P0C6AL04ALE010F500=4a404ALE00/A3`0>51804aTG01PN
700M8b404ADF018F5`0H71d03A4B018F5`011@H041@E018F5`0D61T0310A010D5@0L82405aPJ014B
500K71h04A8D01<D5P0E5QP5018C5@0A018D500A4a803a4@010B4@0E5aH06Q`K01PJ6@0?4A004Q@C
00/=300F61L02P`;018E4`0B5a<04AHB018G4`0A5Q800P0?4a802`0B5QD04aLH010D5@0>4Q<04QHG
01TI6@0G61<04a@?018C3P0C50l04a@>00804Q<=02@05AH>01HG3`0E5Ph04a@;014B300B4`d03a0;
01LG5`0@41003Ph@00d=3`0?3a403Ph=014A3`0D5A003Pl:01TI5`0G5aL06QXJ01TI6@0B4Q803Ph>
018B4P092@T051@D00/;2`0E5AD05QLF0<G6bP29SI005aPJ00H72@0<3@l06QXJ010@400?3`l2010?
3@04018?3@0D40d03@`:00l>308040l=01803`h<00d<2P0@3`d071/I00X91`0D4a403`h<014A4@07
20X03a0B00D6200L7Al03PlA00h>3P0:2PX03Pd;010?3@0?3P`2018>2`0401DD4P0C4Q004A0>010?
3@803`h<00L05A@B00/:200100002@P601LF500E51004Q8;008041080P0C4Pd0400B4@`071/G00/:
20020@0040l=018A3`0D4a4030/901@C4@0;2PP03@`:01@C4@0=30X03Pd;014@3P0?3P`2010?3@05
00`;2@0B3P/040`900h:1`0?2`P0200@30T00`0=30X040l=010?3@0300h=2`0A01LF500T8b4040l=
00`;2@0H5aD03Pd;014@300?3P`02PT801LF4P0L6aT030/9018A3@0@3`d04A0=014@300?3P`00P0>
3@T200d<200500h=2@0?3PX04A0<010?2`0=30P00P0:2@D01`0?3PX05QHB02l`:`2/[JP0KVmZ00/<
1`0B4`h00P0?40/0500=3PT02P/600X;1P0?40/071/G014@300;2PH03Pd9014@300R8Ad0AdI201LF
4P0920H05QDA00h=2@0;2PH04@d:01LC400M6AH05Q8?0P0@30T02P0F4Pl04@d:014=2P0B3P/03`/8
00h:1`0?3P`05A@B01HE4`0@3`d300l>300<00d<2P0<2`T03@`:014@3P0D4a404Q4?00H50`071P@0
40l=00d<2P0;2PP03`h<0P0>3@/01@0@3`d04A0>00l>300<2`T03@`:00803Pd;0P0@3`d08`0A40h0
3`h<01<B400<2`T03`h<00`;2@0F5A<06QTG00l>300;2PP04A0>00h=2`0=30X03`h<00`;2@0^;B/0
9bHT00h<3@0?2Ph04@`@00l=400A4Q@06a`N020T9@0G6a`010D7010@4P081PT07QTM00P31`0>30d0
3@/<00l=3P0B414040h?00803P`=0P0=2``00`0>30d03`d>010>3`0200h:2`803`/<0P0>2P/2010<
3@0400l;300>2P/03@T:00h:2@803PX70P0=2@H00`0<20L03@T8014=300201<?400300h:2`0=20`0
3@T900803PX702803`/800h:1`0=2@P04@d<01@@3`03000040`=018>3`0<1`/04@d=01HB4@050@00
3@X901hJ6@0E4A005Q8A00/71P091@@040`;00l;2P0B3Pd04Q0>00h=2`0[:RP040l=01XI5`0;2PP0
3`h<00T81P0C4Q005A@B020O7@061@@03`X>0P0D3a<02@0@2`l04PdA014<400B3A404@`@010;3`0>
2@d03@P<00`72`0200`:2`803P`=00<03@/<00`:2`0@3Pl00P0>30d0100K6AX0518C014?400<2Pd5
00d;3PH04@lB1P0>31401P030@H0=S@i00h<4@0=2a00518G00/93QCooooo000Kooooo`060040000B
4140JVQY02<Q8P0H5QL00`421P0@3Pl01`0;2@X03@/<00d;300<2P/03P`=01<A4P0?3@h00P0@3Pl2
00d;300>00l>300?3P/03Pd;00d<2P0>3@/03P`=00l=3P0=2``02`T<01DC5P0?3A002@L<018@5@0>
30l300l=4026010>4@0A3a8040hA01<A500D4QD04Q0C00l=400>30l0410@014A4@0D51@03Ph>00T9
2@0=3@d02PX:01DE5@0F5QH03Ph>01<C4`0;2``04A4C00d=3`0B4Q@0410B00T92`0>3Q004a<E014A
4`0C4aD061PJ00h>400D51D04Q8@01HF500D51807AdK00`<2P0?3`d05QHD010@3P0D51406a`G00l@
2`0D51005QDA01DD4P0D4a4051@B01DE5@0A4a802`d<01<D5P0G6a`06AdN01dQ900H6b403Q4H01DH
7P0A51T04ADH01@H6P0E6AX05QXK01HJ7P0F6Ah05QTP01PK900E5bH06A/Z028T<P0T9S807b8[01LJ
800E6A`061`M01@H6P0E6A`05APM01DI7@0N8bH05a`O01<H6`0Q9RX03a@J01<J8@0F7bP06b@]01lW
<`0H8C005Ah]01HP;@0D6RP04aTU01XP;@0L8S006Al[01lV<00H7bT05ahW01PO9`0I82P06b8Y01XS
:P0L9B`05B0V01dX;P0J9B/072L]01LR:00K9R`062<Y01`W;@0F8BL06RD[01@Q9`0@7R405bHY01/Z
;@0J:Bh06BP]01XY;P0J:C005bH^010N9`0[>D8072Xc01/Z<@0S;CH08Bdc028_=@0S<3P08Blg01d/
<`0L:S<201`]=@0401X[=@0I:S@06R/c01h_=`D07Rlf01009CHm02@e?00U=Sd093Dl020a>00O<3L0
8cHm02<e?`0W>D<09CM5020a@@0Q<T80?4eM02LiA`0R=400838m0P0N<CP0100P<CP07c0g020a>00P
<CP201d^=@<072dd00`07c0g02<d>`0O<3X072`k024a@00P<3d06b`f01X[=@0K;3@06R/b01T[;`0H
:R`201LY:@0K01LX9P0<71T05RHU01XZ:`0P;c80;S]1020/<P0?6R0092lc02Xe>00K9BL07RPY01PR
900951H07BPZ01XU9`0h@dD082/_01@O900C7R@05b8X01dX;`0H8R/06B<[01LR9P0G8R@062<U00<0
5b8T02T04A`N01DP8P0J9BL06RDW01/V:00P:bh082dc014N9P0Z=cl0?4UA00HC6`0E8RX07BXb01TV
;P0>6b<05B8Z01`Y<@0I9Rh07RPa01@N9`0E7bP072H`020Z<`0E7bT04adW01@N9`0E7bP041XT00`F
7`0>5b407B@Z018G6`0F6al07R<W01lT:00N8bL03A8F014F6P0I7R80<CHj01@I7@0201HK7`0L010E
6@093Q806AhR01<H700J7b<05a`P01@I7@0F6al05AXN014F6P0C61/05Q/N01HL700G7Ad06AlO01LM
7@0C6AT04ALG01HL700G7Ad04ALG01HL700D6QX05QXK01DI6P0D61T05ATJ01@H6@804aLH0P0=4A80
2P0B5QL05QXK01HJ6`0A5aD05Q`J01DK6@0A5aD03Q@B00`B400A5aD200dC4@0:014G5@0C6AL051XH
014E5P0>4Q<04QHG01@H6@0H71d04ADF018F5`805QXK00T02@d>01/O800f>S/06a`N01<D5P0O8280
4A8D00h?4@0D5AL01@0B4aD0<@0B4a@04A<B010B4@0A4a805QPG01TK6P0J71/051HE00T;2P0B51<0
71hM00lA400C5QD03a@@00lC4P0C5aD05ATH01@H5`0A5A@03a<B010D4`0>4Q803A4@00lC500C5A@0
4Q<>010A300?40/0414<010A2`0A4P`04a@>01HG3`0G61005AH>014C200<3@L04a@>01DF4@0B4Q80
20P801@D5P0O7b404Q8D01<C4P0A4@l03Pl:01HG4P0L71X00P0I6AT03`0F5QH0410@00d=3@0@4100
30`<018B4P0;2`/04a<C01HG5P0Y:Rh08BDX00`=3`0L7Al051DG00h>3P0200l?3`05010?3@0A40h0
4a4>01DA3P0>3@/0100@3`d0100>3@/010<1014@3P0920H2014@3P0>01@C4@0>3Ph04A8D00d?3P09
2@/04A4A018A3`0=30X04Q4?01DA3P0C3``05A4>01TE4P0D4a42014@3P0:010?3@0?3P`04A0>05IE
D`0M71X03@`:00X91`081`H04a8>010?2@803Ph600D03`h9010?2P0@3`X02PT500X91`02010?3@0:
00@30@0?3P`04Q4?00l>300920H03Pd;014@3P0<2`T04Q4?01DD4P804Q4?00@040l=00`;2@0E4@h0
4Ph;0P0?2`P00`0@30T04@d:010<2@05010<2@0H00h=2`0<2`T02`X800d<2P0A40h04Q4?010?3@01
000030/902LV900D4a402`X800L6100C4A802PT800h=2`0100004Q0@010?3@0>30d03`h=010?3@0>
30d03@`90P0=30P200h=2@0500d<200@3`/03@`800/:1P0?3PX00P0@3`/01P0F5Q80ADI10>?Tg`28
RH@01PL2014B3@80414<01L03Pl:00/<1`0<3@P0414<01TH500C4Ph04A0<010?2`0=30P04Q4=01PG
4`040`003`h:01<B3P0920@030/700L3000=2@H0510=014=2P0?2`P040`901HB3`02014=2P0901<?
300?2`P03@T600D40P0;2PP03Pd;00`;2@0@3`d04A0>00803`h<00/03Pd;00l>300A40h04a8@01DD
4P0?3P`06APF00`;2@0920H04A0>00l>300200h=2`03010?3@0A40h03`h<008040l=0P0>3@/0900=
30X030/900<2000C4Q003`h<00@30@0@3`d020L500d<2P0B4@l03@`:00/:200@3`d03`h<00X91`0>
3@/020L502d/:P0Z:BL04Q4?010;3`0@3Q403Ph@00h?4@0C5aP061`M014E5P010P@04Q<E00X82`0c
;S803PT=010>3`0>30d03@/<00h<3@803`d>00L03P`=00d;300=2``03P`=00l=3P0@3Pl04@d>00<0
4Ph?0P0@30d00`0?2``040`=010<3@02014=3P05014=2`0A3@X040`9010<2@0>2PL00P0>2PT01`0?
2`X04@d>010<3@0>2P/03PT=00h:2@0=2@H00`0>2PL09@0>2PT02@D501<?3P0=2@X030P900<0000>
2@d03PX;01LC4P0?2`X05A4@00X61@0300004`l>00D1000;1`H0<Bd/02/W9P0@30/02`T8014@3P0`
;bd05A@B01dL6P0@3`d02PT702HU8`0h=cD00@0000L6100@3`d040/?01D@500D3a<040/?014<400@
2`l00`0A31001@0@2`l03`X>00l:3P0<2P/03@/<00<03P`=00`03@/<010>3`0@3Pl030X;01HD5@0B
41404a4B01<A500@3Q403@/>00l=400A3a8700l=40H03P`A00H0108700`:3`0A3a@01P@9014?500@
3Q<Dooooo`006oooool200d;3004024O80030@804a4B014?40L03`d>01X040h?00l=3P0>30d03P`=
00l=3P0<2P/040h?00d;300<2P/03@/<00d<2P0?3P/03Pd;00d<2P0>3@/03P`=00l=3P0E4a@01P@7
018@4`0I5aX03P`A01PF6`0D4QD04@lB010>4@<04@lB00L040hA00h<3`0?3A0040hA00h<3`0=2`h0
4A4A00804a<C05P04A4A00l?3`0A4A403`l?01dM7@0Q8B404A4A00d=3@0D51D04A4C00d=3`0I6A/0
61PJ00l?4@0G5aT0410B00X:300F5QP030`>014A4`0>3`d03a0;01@E400>3`X07AhI00l?3@0@40h0
5aLH00d=3P0F5AP02@T;01@C5P0C4a804aD@01DF500F61D051LD018E500B5QD051TH03]0@@16C4`0
5Q`L01@I700I7B804QDL01LJ7`0B5QP04QHF01PL6@0C5aD05ATG01HJ6@0C5aT051LK01XN900M7S00
71db01XL;@0I6bL06A`U01XM8`0H72005a/N01TL800H6b408B@[01PK8`0E6R407R<X01HJ8P0F7B@0
7bH^01XQ:P0H8BX07BH_01hX<P0G8Bd04Q`X01@N:@0F72L06R4[01hU;`0G7BP05ahW028Y<00C6R40
5ahU0P0K8RL02@0J8BD05b4T02@]<`0I92X082/a01/V;00J9B/06B@Z01dX;P0201LR:00D01<N900N
:Bl07R/a01DS9P0K:Rd07Rd`01`[<00H9b`05bH[01TX;`0I:3006bTb01`Z<`0O;CH082lg020Z<`0O
:c808Bhf02<`>00S<CT2020^=`0901//=P0I:S@06R/e01l`>P0Q<S/06R/c01//<`0L;C@07c0g0080
834h01L08cDi02i0A00/?T8093Hj028d>00S=3X07S4h01la>`0R=3h08C=1024b@P0U=TH0;3e=020b
@00Q<cl08C<n01`_=P0L;cD06R/a01d_<`0L;S807Blc01h`=00201d_<`0T01X/<00H:Rh07Blc02Dg
>`0S=3`0830m02@d@@0R<Sh072dg01`]=P0J:c805RL^01LY;@0H:Rh06R`_01/]<00L;Bd052@Q01PX
9`0F9RL052<V01/X;P0E8BL06RD[01TT:P0H8RH04adO010J6`0D7b004ahP010K7@0I92L05b8V01hY
;@0G8RL05b8X0P0G8BX0:@0E7bP06B@[01DS9`0D8RD04b4T01@R9@0E8bH0528U010N8@0C8B@05bDX
01HT9`0E8bH062HY01<P9`0F8b/072Ta00hK8`0L:C40524Y01/X;P0H9B/06BH/01HS:@0I9R`04AhU
01/U;`0=5b805AlZ014K9`0G8B`05R0[018L:00D7RT05Al[01HP;00H8Rd05b4/01LN900I7R805Q/O
00804aPL01P051TM014F6P0F6al07B8V034f>P0G72005Q/O01`Q9@0?51P06QlS00`A5@0D6Ad03a@H
01@I7@0@5AT051TM01HK7`0C61`04QLJ01@I700C6AT05A/K01LM7@0F71`201<I6@0601DK6`0:4100
4QPH01HL700D6QX051PI0P0A5AH0100E6AX051PI014E5P0B5QL201DI6P0:01<G600@51D03Q<D014I
5P0A6QL04a`I00lH5@0<5A803QLD010I5P804AXG00`04a`I014J5`0>5Q<04aLH00lC500<41405ATJ
00`@4@0C5aP051PI00lC500A5AH201<G600701LK700@4A<06a`N030a<`0R8bD04Q<E014B5005018C
5@05014B4`0@4Q404Q@C01@F5@0C5A@00P0B51<00`0F61L02@/:01@F5@02018D4`0401@G5`0?4a<0
3A4B00hB4`8041@D00L04ADD014F4`0A5Q<041DB010E4@0@518041<>00804A8=01P04A8<00l@2P0A
4P`04A8;018C2`0D5@d051H;01<E2P0A4`P051D?014B300=3PT05ADE010@400N7R005QHH010@4P0G
5aH02@T700l@2`0E5Q404Q8@00l?3`0>3Ph2010@400C01DE5@0?3`l04a<C018B4P0;2`/03`l?01DF
5P0=3Q804aLJ00d>400H6A/03PlA018B4P0?3`l0410@018A3`0C4Q004a4>01@@3@06014@3P04010?
3@0E51804a8@014@3P8040l=01@04a<B00X9200G5Q@03`h=014?300A3@X040`901@@300D3`/04`h:
01D@300H510040h;00`;2@0B4@l04a8@00l>300D4a407QdK00/:20803Pd;01H071/I00`;2@0A40X0
4A49010@200?3PT040l:014@2`0@3`/01`H4018A3`0>3@/08R4O05=BD00Q81h02PT700h=2`0B4@l0
3Pd;014@3P0C4Q0051<A0P0@3`d0200>3@/02`X801PD4@0D40d04Ph;014=2P0B3P/04`l<1P0@30T0
6P0=30X030/9014@3P0C4Q0040l=00h=2`0F5A<061LE010?3@0?3P`040l=00h<3@0@3Q004a4D01`J
702a[k40G5YM018@4P0>30h03P`?010>4@0B41804Q0C00l=3@0=30P03`h:100@3`/02P081`<02@P4
01XI5@0J6AD04A0<010@300;30P0>S/f02@U800G61<200X;1P0300`=200?40/03Pl:00803@h902/0
40l;00h=2@0?3PX03`h:00h=2@0@3`/05A@@010?2`0?3PX01@@100`;1`0@3`/03`/8010<2@0A3@X0
3PX700l;200C3``04Ph;00l;200@30T04`l<00l;200=2@H040h>01<A4P0A40h03@`:00h=2`0=30X0
3`h<014@3@0C4Ph04Q4=014@300>3@T020L500l>300H5aD02PT7010?3@0:2@L03@`:008030/900<0
3Pd;00l>300=30X01P0>3@/01017AT@040l=01<B400G5Q@2010?3@0:00P71@0?3P`04A0>010?3@0>
3@/02`X8014@3P0?3P`010<2010?3@803`h<01<04PhA014?4P0>3Q003@h@01<G600I7Ah03Q8C00H7
2@0D5AL03`hA03<^<P0D3a<0518C014?400?3@h03@/<00l=3P0@3Pl03P`=00803@/<00@03P`=00l=
3P0@3Pl040`=0`0A3@h2010<3@0901HB4`0E4A804`l@014=3P0?2``03`/900l<1`0@3@P04@d90080
4@d:00P04@d;014=300A3@h03`/<018>3`0F4Q<05Q<@014>208040d801P04@h9014=2P0A3@/030P7
018>3`0<1`X04PdA010;3`0?2``0510?00`81`0@30/02PH602TU901?BdX06ADD00`8200D40l04Ph=
00d9200<2@P030/901<B400:2@L200/:200301/J600510<04A0?008051<A00l030/900h9300B3A40
4PdA00l:3P0@2`l03`X>00h93@0?2Ph040/?014<400B3A404`hB00h<3@0?3@h00`0@3Pl200l=3P0:
018@4@0;2@X04Q0A010>3`0B41405A<F010>4@0=2`h040hA018@4`L040hA1P0>3140100H5Q/03@/@
00h<4@0=2a0200l=4QCooooo000Kooooo`0600l=3P0B41401@<400X82@0A3a004Q0A1P0>30d300d;
300500h<3@0?3@h03@/<00`:2`0B41400P0=2``0700>30d030/900l>2`0>3@/03@`:00h=2`0>30d0
3`d>00T7200<2Pd03P`?01/I700=2a001P@901LE600A3a803`d@010>4@0?3A003@/>00l=400>30l0
40hA018@4`0=2`h02PP;00d=3@0@410200l?3`804A4A01l05ADE014A4@0:2PX03`l?014A4@0?3a00
3`hC00`;400C4QL04A0E01<B5`0M72403`hC00h=4P0@3a@05A@I030_=00D51804a@>01@E3`0_<2X0
Ce1;024Q7`0:2P/04a<E010?500J6Al0F5MM01/J800D5AH04AH@00<04AHB03h04ADD00lE4`0>5180
4QPH01PN7@084A005alQ02L^<P0A51/05a/O010D4`0@5A406AhG01LL5P0H7AL061dH01DI600H71d0
8bH/03DfBP0_;dL08B8e01HH9`0D5R805QTP01`O900I72407B0U01/N9@0[;SL06adY02X^>@0L82T0
5ahX01PO:@0I82X08b`e01@L9`0G7bX0628/01DO:@0D7RP05b4[01@K9@0G7RH06R4Y01/R:P0L8bT0
6b8X01HM8`0L92L07bLY01dU9`0L92H072HX034j?`0P:c409C0f01lZ<00M:2h07bX`02<^=08072L]
01`062<Y02<^=00R;cD07bd`020_<P0S<SD08c8g01d/<@0F9BX03ahU028a>@0>72D09cDn055OJ00`
?TL08R`e01l[<`0N:c<082de028_>00P;SL07bdf01LX<P0H:C<07Rhk024a?P0P<C/07Rlg0P0O<3L0
1P0P<CP0838f020b=P0]?d<0<TA802Xl@0808C<e01<0838f020c>@0N<3X07c4k01la?`0V=dL0;Sm?
01X[>`0I:cT07Blk01d_>P0J;C@07C0f02Lh?P0Y>cl08C<g01`^<P0J;3005RP/00807Blc02@06bda
01T[;`0K;C4072de01d^>00O<3X072dg01LX<00H:C405bP`01DV;@0G:2l06R/b01/]<@0J;3006BXY
01/[:00H:2L06BPY01TX:`0G92X06bL^01lY<P084aT05AlT02<];`0:51D04ahO01dX:P0F8BD04QdQ
03e8C00]>3h04QdS01@O9@0F82T201PR:`0801HP:00K:2h062HY01DS9P0H9RT06BLZ01PV:@0G9BP2
01HT9`0d01LU:00F92L04b4T01LT;00K:3007BXb01LT;00J9bl082dc00lL8P0E8RP04QlU00XH6`0B
82<0=D=704MAG@0L9C@051d/028[>P0g@4l09c0o01<L:`0D7B`04a`[01XS<P0Q:ST06b@a028Y;`0K
82@05Q/O02X_<`0e>Sh051TM018G6`0@5AT03Q<G014F6P0?51P03A8F01DJ7P0=4QH06b0T01XO8`0E
6Qh06AhR028W:`0C61`04QLK01PM8@0I7R805a`O018G6P8041HF01P04QPH01<I6@0B61P051XJ02@Z
:P0;4A40728R014G5`0C6AT05QXK014E5P0B5QL05a/L01HJ6`0B5QL05ATJ01HJ6`0C5aP04ADF01/O
800R:2P04APF00hG500A6QL200dF4`0401<L6@0@6AH04Q/H010I5P805AhK00T041TF00`@4@0D61T0
4ADF01dQ8P072``06AdN00`@4@0I7Ah00P0D61T0200G6a`04aLH00`=3`0I6Q`09RLY01dN800E5QP0
3a0B1@0B4aD00`0A4a<04A<B018D4`02018D4`0;014C4P0@4Q406A/J01<E500F61L02`d<01/M700J
7Al07B8U01DJ7@0?51L00P0?5AD02`0@5Q@04ALC010F4P0A614041L@00lF3`0?4`d04Q<>01DF4@0D
5A004Q<=008051D=01T04149010B1`0@4PL04Q@901@F2`0=3PP03Pl901<D3`0J6QX03Ph>01LG6@0[
:bd02@T;01dM700K6aT0414<01@E400G5aD04Q8B010@400?3`l030`<00l?3`092@T05ADE00804a<C
00X061PH02DV9P0G61`06AdP010A4`0O828051DG014A4@0@41004A4A0P0C4Q000`0C40h04Ph;014@
3P04010?3@0<014@3P0=30X030/9014@3P0<2`T040l=014@3P0C4Q0040`901<?300L61D05Q4>0P0D
3`/00`0B30P04P/501@=1`0201D>200K01DA3P0@3`d06QTG01/J600B4@l05QDC00/:200F5A<051<A
014@3P11@3h09RDQ018A2`0C4`/04A4900h=200?3PT04Q4<00X91@0:2@L03`h<00d<2P0;2PP08B0N
01@C4@0:2@L02`X800<03Pd;0P0@3`d0100<2`T040l=01DD4P0C4Q0201<?3003018>2`0A3@X040`9
00L040`901T051<A00X91`0D4a407A`J01LF500>3@/02@P6018A3`0?3P`03Pd;01HE4`0@3Q000`46
014?500`;S<0<S0e01hL8@0F51T03`dB00h<4@0@3Q<04@lD010>4`0@3Pl040l;00803`h:0P0>3@T0
400B4@d02`X600L60P0<2`L02PT500d<200A4@d05aPC01`M600C50l030d8014B3@082@@02``700l@
2`0>3`X200d>2@0401DD400D4`l040l;00`;1`803@`800<03`h:00L60P0@3`/00P0C4Ph04@0:2@H0
40`900l;200=2@H02PH300/7100>2PL040`900d91P0A3@X05A4>018>2`0@30T02PP900`:2`0;2@X0
30/9008040l=00@03@`:00l>2`0@3`/040l;0P0A40`01`0A40h03`h<01@C4@0@3`d03Pd;00D40P0>
3@/00P0=30X01@0?3P`040l=00h=2`0<2`T03@`:00803Pd;0P0@3`d02P1jNGL07ahL00l>300@3`d0
1PD3014@3P0=30P04A0<018A3@0@3`/200/:1P0I00`;1`0?3PX03`h:010?2`0=30P061LE01<?4@0C
4A@0410B00h?4@0A5AH05QXK00P<3@082@/02P/=00`;3P0B3A403@P<01DC500D4Q<040h?00/92P0<
2P/03`d>00h<3@0200d;300600h<3@0?3@h040h?00h:2`0?2``040`=0`0A3@h01P0E4A804`l@018>
3`0?2``03@T:00h:20803``700@040`8010<2@0@30T04@d;0P0A3@`04P0?2`/04@d>01DA4P0G4a00
514:018?200A3PP040d8014=2P0B3P`01`<201DA4P0@30h091lS00/62P0a;Bh03`/:00@000804@d<
01L03PX9010<2`0>2PT03`/:00d9200:1PD03PX9014?300=30P03`h:010?2`0B4@d040l;092?R`18
Ad<02`X600l>2P0A40`04Q4>00/7200@2`l04@`@00h93@02010;3`803PT=00H03`X>010;3`0@2`l0
4@`@00d;300>30d300l=3P0=00h<3@0<2P/04a4B00h<3@0A3a003P`=00d;300@3Q403P`?00d;3P0>
30l03`d@00h<3`06010>4@0300h<4@0>2a803P/B00<03P/B00H01`@;00l<4`0710/030T@01LD6`0>
2a8Dooooo`006oooool01P0:20/03P`=00`:2`0>30d02`T:00d;30H03`d>00D02@L800X82@0<2P/0
3P`=00l=3P0200d;300801<A4P0>30d03P`=010>3`0=2``03`h<00h=2`0=30X200h<3@1W00l=3P0@
3Pl061HI01@B5@0<2Pd02@L<01`J7`0H5QX040hA00d;3P0>30l03@/>00/9300>30h040hA01@B4`0E
4a@03@/<00P61`0=3Ph0418A00lA400@4Q804a@F01@E5`1VIfT0;Rla01<D5P0@4A<04A8D01<B5P0D
4aP04a8H01<B5`0>3A806QTN028Q9@0>3Q004a<E00h>400U9BD0Bd]=010@3@0@4@/04a@>010A2`0T
92804A4?01@D5@0<30h03PdB02HU:`2YZ:h081lU014A4`0D6AD04QHE014E500B5QD051PG01<H5`0H
7Q`020h>01TO7`0M8b<010d<01<G6`0A51T05QXL00lC4P0>4`l05a`G014F400C61804QLC00hB4@0B
5QL082@X01XL:`0J6bl06a`]01TK:00G6BD05QTQ01/N9@0G6Ql071lV01XM9P0/;cP06A/W01/O:P0J
7RT06b4[01LK9P0J8B/0620Z01HO:00G82T05QlY01<M9`0C7BH05R0Y01HM9@0201`S:@0V01<J800F
7B807BDX01<K7P0H82806B4S01LO8@0H828072@W02Xc>00H8RP07RT]01XS:00J92P07bX^01hW;00H
8RH06B@V01@N800K9RP06RDW01LU:00G9RT072/^01l^<`0K:Rl04R4V02Dd>@0eA4X05B@[06=bN@2f
`lH0NhR@02Hc>`0S;cL082de024^=P0R;cP2024_>00G01XX<`0J:cD0830j01h/>@0H:C<07Bhf01`]
=@0K;3@06R/c01TZ<@0I:bl072hb01d_<`0I:bl07S0b02Hh>P0U=c/08cHl01ha>00L;SP06R`g024c
@@0[?D/00P0O<Cl02`0R=4007S0k01`^>00P<cX07c0h02@e?@0N;cH06R/b01/]<@0H:Rh06B/_0080
7S0d02d06R/b01TZ<@0K;3@08C8j028c>`0N;cL06R/b01`]=@0H:C0052D/01HW;P0J:S405bP_01PW
;00E9BD07RlY01LV8@0F9B@05bDU00hL7@0B7b808B`b01DP9P0D7R@05QlT00`E6P0H8BH06B@X01lX
;@0J92T0XJb`06efN`0L9R/05R4U01DN9@0D7RD05b8X01DO9P0K9R`05B<V018P8`0E8bH05bDX01DS
9P0J:2/00P0G9BP0=@0L:Rd07B/^01TW:P0D8BL082dc01PT:P0L9bd03Q/Q02Hc=P0G8RH072X]01XV
:P0C7R802ALH01/V:`0`>T@03QLV00lG9@0@62D082Pe01XR;`0H82d05Qh[014K9`0G8Bd072Pd018M
:00<4a/05a`R00dB600D6Al082D[00H;3`0A5QX04aPL01@I7@0@5AT061dQ010E6@0<4AL0728X010G
7@0@5A/05Q`Q069ZK@0^<cL05QdP00lG6P0I7R80728V01/P8`0I7R405A/K00804ALG03804QPH010F
5P0G7Ad0<SPh01@J6P0V;2`04ALG01HL700I7al05AXJ01DK6`0L8B406QhO01HL700?51@03Q8C00`B
4P0P9BD0C51A06AZJP0B61H03aDC014G5@0=5Q@03QLF01DN7@0B6aX04AXI00`E4P0B61H051XH00lE
4`0@51D05a/L00hB4`0J7Ql00PH701XN7`0A5AH020`=00L;300Y;Bh0<cLh020T9@0E5QP04A8D00l@
4P0:2`d04Q<E010A4`D04Q<E0P0B51<2014C4P0I018D4`0C5A@04A<B01PJ6@0E5aH051HE00P:2@0M
7ah05aXK01hS9P0E6A`03A8E00`B4P0?4a@041DB00lF3`0?50h03aD?00hE3@0>4``03A4:018C3@0E
5Q4051D?018C3@0201@E3@0J014B2P0?4@H04187018D2@0F60h03@h801@E400C510020P600D51@10
@400N7Qj028R8P0d=3<0>SXh00T:1@0E5Q40410>00h>300A4@l051@D018B4P0D51@03Ph>01XJ6P0C
4a<200d=3@0?01PH60082@/0414C00P92P0B4aD01`T800d=3@0A4A404Q8B01@C4@0C4Q004A0=00l>
2P0@3`d03`h<00803Pd;01H03`h<010?3@0C4Q003`h<01<B400;2PP03Pd;00l>300?2`P04`l<00D1
000G4a00510=018?2P0I51404`h:014<200D3`/05a4<01<>2P0A3@X030/90P0G5Q@06@0;2PP03Pd;
00`;2@0@3`d06APF00d<2P0W9R@04Q4=00l?200A4@T03`l700/:1@0<2`H03`h901DD400A40h030/9
01DD4P0<2`T02@P600d<2P0D4a403@`:010?3@0F5A<00`0A40h01@0>3@/05A@B01dL6P0M71X040`9
00<04@d:01`03`/800h:1`0@30T040`900h=2@0?3@T040`900h=2@0_;R`04A0>00d<2P0D4a4040l=
00/:200F5A<03Pd;018A3`0G5Q@03@`:00h<300G5AP04Q0C014?4P040PD09bDX00T72P0>30l030X=
0P0=2`h04P0;2@`03`d<018A300@3`/03@`800`;1P0;2PH02`X500h=200J6AD08b8N00l>2@081`<0
3@d800h?2P051P40414<00l@2`8030d801403Pl:010A300?40/03a0;014B3@0:2@D03Pd9014@300B
4@d04A0<00d<200F5A402PT501DD400?3PX01PD100d<200400h:1`0K00l;200B3P/040`900h:1`0B
3P/05a<@01@@3@0B3P/03`h<014?400>30d03@`:014@3P0?3P`03@`:00`;200<2`L03Pd9018A3@0E
510020P600/;2@0C4a403Ph<00T9200G5Q@03`h<00803Pd;00<040l=014@3P0?3P`00P0@3`d200h=
2`0W00d<2P0<2`T03@`:00/:200@3`d03@`:014@3P0920H03@`:00h=2P0?3PX03@`:00/:1`0=30P0
2`X800l>2`0C4Ph03Pd:00<2000920H04PlA01@B5@0C4aD03a0B010A4`0C51H02``>00h?4@0<30h0
4a8D00P62@0D3a<05A<D01@B4`0@3Pl02PP900/92P0=2``03P`=00803@/<00H03P`=00l=3P0@3Pl0
40`=014=3P0B3Pl301@@4@0300d92P0>2P/03`/<008040`=00<04Ph<018>2`0B3P/00P0A3@X09@0A
3@`03`/:00h:2@0?2`X03PX:00d92P0>2P/04`l=01@A300B3`X040`800l;200@30T040`;01HB4@09
1@H04`lA0:2KW`0f<CD03PX:01@@3`0I5A@03PX900/71P0B3Pd04@d<018>3@0>2PT030P701@@3`0B
3Pd02`X700D4000>3@T03@`801<B3P0<2`L00P0J6AD0200:2@H02PT501DD400<2`P02`L8010;3`0A
31003`X>0P0A310600l:3P0400`:3@0=2``03P`=00h<3@803@/<00H02PP901<A4P0?3@h04@l@00h<
3@0;2@X600l=40D03@/>00d03@/@00h<4@0>31803P`A00h;4P0>31803P`A00l<4`0:1`d07adR014>
5@0R82H05A<H01Cooooo000Kooooo`09010?500;2`h05ADG00H6200<30d020P800h>3P0=3@`03Ph<
00803`l=00<02@X600`:2`0>30d00P0?3@h0200>30d030X;01@B4`0?3@h04@l@00h<3@0<2P/03`d>
0`0?3@l300l=400<00h<3`0F51L02PP;01<A500@3Q406QPL01LE6P0@3Q<04@lD010>4@0>30l040h@
0P0@3`h06@0@3`d03`h;00h=2@0=3PT03a8=01<H500A5Q@04ALI018I7P0V;c<0^/;903e3BP0A5Q`0
3a<I014D600@41H051<J01@C6`0C4QP05aHK01DE5`0A4A40410?010@3@0@4@d00P0@4@X0400A4P`0
3a0;010A300F5Q<0410>01hN700A4A0051@D01HF5`0H5aX05aHJ01DE600D5AP05QLK01<D600D5AT2
01@E600U014C5@0P8b@09BPY01@G5`0D5aH07R4P020Q900?41@0824U020Q900B4aH05aPK01TJ6`0G
61T051HF020Q8`0X:B/06ahO018E6P0B5ad05Q/Q01TN9@0I7BD05AXP01LL8`0E6R405a/T01HJ900B
5R405ATT01HI8P0I72D06QhW01HI8P0E6B806QlX01TP:00201PO9`0901LP:00I8RT072D/01<I7@0M
8RH05Q/N01dR9@0J7b<05AXM00806b0S01@05a`O01TN8@0N8bH05QdO01dU:00J8bH05b0S01XR9@0M
9RL072DU01PQ7`0J8b405AlJ01PQ7@0N:280628P024]<00K:2h0524W01h/;`806bT/00T06bT[02Pf
=`0P;Rl05R@T04iLG00e@dD06bP`01dZ<`0P;CH00`0R;cP02`0P;CH07R/d01d[=00P;CH08Rli028`
>P0N;SX0830l01l`>`0N;cP072de008072dd08008cDi028d>00U=c/093Hh01la<`0O<cH07C8f01`a
=@0M<SH07S8h01lc>@0K;cL07c<l02<g@@0L<3/05b/f01d_?00P;Sl082dn01d[>@0J:3806bXa01d/
<@0J:B`07B`a01h]=00I9c007bdg01d^=@0L;c@07c8g01la=P0L;S8072dc01TY;P0E92T05bD[01XW
;@0I9b`06BH/01LU8`0D8aT04b0G01@R6@0G91`05R<L01@P700G8R<06bHY01DP9`0@6R@051hY01dU
<@0V;SH08RTa01/S:00W<38092`^01XS900E7al07BDV01PQ8`0A6Q`07BHZ01`V;@0D7bD05B0V010K
8@0E82H06RD[01TT:P0O:S006bH/01@O9@0N:Bl05R4V01hY:`0K9RL06B<U01/U9P0J9BH05b8S01dW
:@0L9RP06B<T01LQ8`0H8b<06R@V02H_>@0Q:CD061l[01HI9@0G6RD05aXT01DI8@0D6b8051dS018P
900@8B@0428V01HO:00I7BT04ADP01LK9@0I7BL0314H01<H7P0E6Ql04AHJ018G6P0E6Qd04ALK018I
8@0Q:C804AXQ01PP:00D6b80IFic04M?E@0E7R404Q`N01TR900@6Q`092`^01DK700P9RH04QPH01XP
80804aTI0P0E6a/0<P0A5aL051XJ01`R8P0K8B405Q`O00hE5`0B6Q`04aXM010F6@0A6A/03QHH03@j
?@0F7R004QTL07AjO@1JH6005ALE00`?3P0>4Q405Q/M00TA4`0A6A/03ADH014F6@0D6QX05aTI01PI
5P0I6QP051HE00/=300g>CP0=3He01@F5@0@4Q405QPG00/=300D5QD07b4P01`N7@0@4Q404A<B01<E
500?4A004aDD00lA400C5A@04Q@C014C4P0B51<051HE0P0C5A@0900E5a@051HC010B3`0?4@h04A<@
01@F4`0K7AX05aTF01<E4P0@4Pl030h;01<E5P0B5AP04A8E010B4`0@4a804aDC020S7`0J7AP03@l9
00hB2`0@50d041<;018D2`0G6100414:01@E3@0<3@D05aP@02h_9`0E5Ph0414901<D300B4`/04A8:
01HG4P8051@B01L04Q8@00H6100];B/0De=B02@T8P0=3@/061PF00h>300O7a`0=cPc02X[9@0C50l0
3Ph;010A3@0>3P`06QXH04I6A00[:b/03`l?01@D500?3`l0410?014A4002018B4@07010@3P0?3`d0
4A4?00d=2`0B4Q003@d;018B400=014@3P0301<B400B4@l040l=008040l=00X04A0=01@B400A3P`0
514?01TF500E4Q002PP501DD4P0?3P`0@3lm0P0A40h02@0C4Q005A@B00l>300@3`d04a8@018A3`0?
3PX04Q8;018B2P02014A2@0E010?2P0?3PT03`h:01@C3`0=30P0;Rd[00H50`0C4Q005QDC024P7P0D
4a403Pd;00`;2@0C4Q005A@B02DT8P0=30X03`h<00P71P0A40h03PX700804`l<00h04@d:00h=2@0@
3`/04A0<00`<200=3PT02`/701DE4@0;30P07AdL018B4P092@T03Ph>014@3P8040l=01H040`901DA
3P0O6aP071PD014>2P0?3PX04A0<010?2`0?3PT040l;01<B3@0>3@T030/7010?2`0>3@T030/700h<
1`0?30D03``6010=1`0A3PL04@h80P0A3PL2014>2007014>1`0@3@L03Ph900h?2P0?40d061TD014B
3@0300d>2@<03Pl:03L03a0;00h;200B3P/04Ph;010<2@0C3``04Ph;014=2P0<20D03`/801DA3P0B
3P/040`901<B3P0>3@T03@`800P71@0@3`/04A0<00h=2@0=30P03Pd9010?2`0A40`03`h:010?3@0=
30X02`X800l>300B4@l03`h<00h=2`0?3P`040l=01PG5@0K6QP02`/900/=300:3@`03A0?00lA400<
3@d030d<00`<300>3Ph03`l?010>3`0?3@h03@/<00P61`0f=3D04@l@00/92P0?3@h03@/<00803P`=
0P0?3@h2014?400K00`:2`0>30`02PT8010>3`0>30`0518B00l=3P0?3@d040l>018@400>30d02`T:
00h<3@0;2@X030X;00h=3@0<2`/02@P900h=3@0<2`/030X;00l=3P0@3Pl03`d>010>3`0A3a000P41
00803P`=00<04a4B00l=3P0?3@h00P0>30d02@0=2``02PP900l;300D41402`L801PD5@0N6Q/04@d>
010<3@02014=3P08010<3@0>2P/03`/;00l;2`0A3@d03PX:014=3@0C3a0200d92P0G00h:2`0@30d0
4@d>014=3P0K61T0<2h^00h<3@0_;Bd04Q4@00h=300<2P/061HG00D3100B4140>3Hg01hL7@0;2@T0
3`h:014@300?3PX030/700h=2@0?3PX00P0>3@T0100?3PX040l;010?2`0=3@X200/;2@0F01PH5P0B
4Q003@d;014A3`092@P05ADC00h>300@40h02PX800l=3P0=2``03`d>014?400@3Pl03@/>010>4@0:
20/0;B/`018@5@0:20d0518G00l=4@D03`d@0P0>30l03`0=2`h040hA018@4`0@3Q403`d>018@4@0D
4Q<04@l@010>400<2Pd03`d@00d;3`0=2a003`dB014>5002010>4`05010>4@0=2`h02`T=010>4P0:
20/00P0?3A40100A3a8030X>01DC5P0@3Q4Dooooo`006oooool03P0<2a0020P;00/;3@0?3a405aLH
01HF5P0>3Ph05QHE0000000A4@l05ADB02`]:00=2``03`d>0P0@3Pl0200?3@h03@/<01LE5P0;2@X0
40h?00`:2`081PL0518C1P0?3A003@0>30l02@L:010>4@061@L06aTL010>4@0H5Q/040hC018@5@0A
3a8040h?01<A4P0@3Pl00P0@3`d3014@300700L80`0M7a`01PX900`C500<4aT03aHL01dT;00200<8
3P0S010B600?41D03`hE014@600@3aD030/A01DD6@0D51H03Ph>00l?3@0?40/0414<014B300A4PX0
6Q/E06AUH00D5A003`l<00`<2P0410@05aLG01<C4`0@41803`lA018B500E5AL061TL00`=4P0I6Ql0
5QLK02@U:@0A4QH04Q<F01TJ700O8B000P0G6AP0700I6aX05aTI00`=3`0T9BL0;2d_020Q8`0L7Al0
6AXL01TK6P0H6QT06adL01hP7`0G6QX051PK01@I7@0G72005a`R01DJ800B5ad061`U01HJ8`0H72D0
5a/V01@H8`0G6bH06ahW01`O:00K7RL201HI8P0;01/O:00I82P05ahV01<J8P0B6b805AhU01/T:P0L
8BD082DX01hS9P0H7B000P0J7b805P0K82<06QlR018G6P0S:2/04aPK01`Q900K8bH05alR01PP8`0K
8bD06R<S01HO7P0E7Q/0624N01PQ700J8ah072DP01HQ7@0@6ad08Rle00TF700O;C02028`<`0<01`Z
:`0M:b/06bTY01PV9P0K:BT05bDV01DR:P0K:3408Rlh02Db>`0T<CX08Bhg0`0S<3T0:00Q;SL07BXc
01/Y<P0M;3T072`i01l_?00R<cd07Bhf01TZ<P0M;SD07c4e01h`=00P<SH08C<e01h`<P0R=SL07S4e
01d`=00N<CD08C@j028e>`0O<ST07c4k024c?@0K;CT05RPd01T[>@0Q;d807R/n01h[>`0N;3L062L^
01DT:@0K:Rl06RT`02<a>@0H9Rl062Ha01//<`0J;C4201h`=00501T[;`0I:2d05bH[01HU:P0G92X0
0P0F8bT0100E8RP05b@T01PU7P0G91d201@Q6P0F01LT7@0H9Al05B4Q01<N800C7R@051hX01<M9`0E
7BP051/U01<J8P0G7R@072@W01`T9P0C6a`09Bh]01<L6`0@6AT04a/N049:D011BU409c8h01`W;@80
6B@Z03d05R4W01PS:@0K9R`07BP^01XU:`0F8BL06B@Y020Z;00M9bP06R@U01TS900G8B8051hO01LQ
8P0F82405AlP01@N7`0F8240628S01<L8`0B6b@05A`V01`N:P0M82T06QdU01`Q9`0I82H05QlT018O
9@0A82D04R8W034j@`0O8bh06QhY01@H8`0Q9Bl04ADN01DJ800;41D04aPL01@I7@0>4aL05alR00`C
6@0N9bh010dB00L@5@0D7B8051hP024[;@0D7R005AlP014K700:51D05QhP01XP8016BT/03a<D01hR
8`0A5AH02@d>008061`M02D05ATJ01HJ6`0I7Ah04QPH00TB4@0O:2L04a`K00`E500A6QT02a@C01TR
8@0740l072DT01LP7`0A6QT02Q0@01DF500G6AP03a<B00lD5`0=5AP03QHI010H6`0<4A@0318B01@F
5P0=3@/010@200lA400G6AP00@<200h@3`0D5QD03Q0?01DG5P0?4A005ALF0080418A00D051HE01hP
7`0M7ah03Q0?01<E500201@F5@0b018D4`0A4a804Q@C01<E500B51<04A<A014C400C5A804Q@A014C
400C5A804Q@A00h@3@0B514061XG00@60`0E5a@0:bd]01@E5`0B4aD0418B010B4@0A4a00418>00d?
2P0?4@`041<=00/>1`0=40T04A<<014B2P0=3PH04A8:00`=1@0B4`/08R<K018C2`0>3`L04A8:010A
2@0@4@X03Pl:01dM6`0G5aD04a<A018B400:2PP030`:00d=2`0@40h2018B400I00h>2`0B4`h0414;
00h?2P0@4@`04Q<>018B400?3`d0000001TI6@0=3@d06ATI01<C4`0A4@l04Q8@01<C4@0B4Q004A4?
010@3P0F5Q@04A4?00h>300?3`d04a<A014A3`06018A3`H04A0>04X03Pd;014@3P0C4Q004Q4?00l>
300<2`T040l=00h=2`0@3`d04Q4?014@3P0>3@/020L500X91`0=30X030/901<B400;2PP03Pd;014@
3P0=30X04Q4?01XI5`0A40`04Q4;01<C2`0D50`04a8=010?2P0?3PT03Pd900`;1`071P803@`:00/:
200H5aD04a8@00X91`0=30X040l=00P71@0B4@l0:RTW04Q7A@0T8b4030/900l>30061@<03PP8014=
300B3Pd04@d<010?3@0A40h03`h<00l?3@0<30X04Q8@00L71@0B4Q0030`<00h>3P0:2PX02`/;00d<
2P0920H03@`:01<?300?2`P03PX7018=2@0@30P03@`800l>2P804a8>00P03`h:018A3@0?3PX02PT5
010?2`0A40`03`h:00l=1`803``500l040d6014>1`0A3PL04a09018?200?30D04@h7018?200@3@H0
2@T300H70P0<3@P00`@002TZ9@0:2`H00P0;30L200`=20803@h901H04Ph;01@@3@0B3P/03PX700l;
200=2@H04@d:00l;200A3@X040`900h:1`0B3P/02PT500d<20071P8040l;00l>2P0;2PH04Q4=010?
2`0>3@T03`h:0P0@3`/050081`D03Pd;01@C4@0>3@/02PT700d<2P0?3P`040l=00h=2`0?3P`04A0>
00X:200H6QT02@`;00H:2@0C5A@05QLG00`<300;2`/030/<0P0>30d02P0=2``030X;00H41@081PL0
2`T:00h<3@0?3@h040h?00`:2`0>30d3010>3`803P`=01803`d>00`:2`0;2@X020H700H41@091`P0
7adN014?400<2P/04@l@00X82@0?3@h02`T:00X82@0<2P/03@/<00`:2`0?3@h200d;300?010>3`0A
3a0040h?00d;300C4A808AlP014?400=2``04@l@00l=3P0610D02PP900/92P0=2``0518C00803`/<
00@03@T:010<3@0A3@h030P90P0A3@h02P0B3Pl04@d>00l;300F4Q<01`<401TE5P0G4a@01P8301HB
4`0?2``2010<3@<04@d>00H06aPI02d[;00:20T061HG00`:2`0>30d300/92P0:00`:2`0100001083
01LE5@0G5Q@040l=00`;2@0;2PP020L500X91`803Pd;0`0?3P`06@0=30X03Ph<00d=2`0F5Q@04A4?
00d=2`0;2`T05QHD08n?S@0m?C/06ATG01DE4`0A3a003`d>00/92P0=2``040h?00h<3`091`X05Q@G
05IDF@0W9BX0ATA903Hc>@0?3A801@0?3A007P0H5QT03`d@00H41`040PD040hA03`j?@0O7Ah0518C
00l=3P0@3Pl030X<010>4@0<2Pd03@/?014?500C4AH04Q0F00h<4@0<2Pl03P`?00/9300A3a803P`?
01LE600=2`h03`d@01DC5P0C4A@08AlR01hL7aCooooo000Kooooo`0>00d<4@0@41<02`/=00d=3`0;
2``020P800d=3@0?3`h051@B01HF50030`8030d800h<3@0?3@h2014?400300l=3P0>30d05A<D0080
3P`=00<030X;00d;300B41401P0?3A002`0<2Pd04a4D02`Z;@0<2Pd071XM00P62@0C4AH030X?00h<
4@0>30l03P`=008040h?00<040l=014@3P0B4@d00P0C4Ph0;@0H5a@0CDe=00h@3`0@51L08BH/014H
7P0=4AX04QLM01@G7P0E5A/03`hD01HE700@3aL040lE01@C6@0?3Q<02`/=00`<300=3@/03Pl:010A
2`0A4P`04Q<;01DF401;C4L030d801HG4`0R8R001@D501PH600C4a<0410B00l?4@0A4A<051@F01PH
700<3A806AXO01<D6@1DEET0;Bhb010A500D5AL05aTH01DG5P0201HH5`0=00lA400A4a805QPH01LH
6P0Y:bX092HV01TK6P0J71/06A/J01DG5P0D5QD04QDE01/O8P0201/P900:01LL8P0D6Al04AHL01HJ
8`0E6B805a/T01HJ9@0B5R405QXU01LJ8`8061/T03005QTR01PK900M8BX05A`T01@K8`0B6B404AXQ
01<L8`0F7bD082DY01TN8@0H7B003Q<F01TN8@0J7b8051TL01XO8P0>4aH09b`_01HK7P0E6Qd05AdP
01PP8`0M9BP072@V01HO7`0G81l05QlN01HO700H8Ah06b@Q01hW8P0L9RD0;cXn08REV`0^>d4041hQ
01<Q900F92L0>4I7030n?P0I9bL06RPX01DS8`0R<3405b@/01/X<@0O;3D2024^=`0D020]=P0O;3D0
82df020]=P0Q;SL082df01l]=P0Q<3`07bll02@d@@0Z>dD08c@l01d^=P0N;cH0838f01la=@0N<3@0
72h`01T[;@0Q=CH3020c=`0K020c>@0Q=3X07C0g01d_>@0N<3X072hj01/]>@0L;S`08Rm201l/?@0M
:SX07B/g01l]=P0P;cH05bH/01l^=@0c@DT08c4j01/Y=00L;3@06Rda01d_<`0L;S805bT]01DT:@0D
8bP05B@Y00805b@Z01h0524W018O9@0B7b005B4O01PT8P0G8al05R8N01XV8P0I9B804alM018N7P0C
7R8051hW01DO:00H82/04QPT00lF800E72<04ATL010H6P0G7b00;SLf01`U900I8B<03QHI02Xa=`0d
?D@06bH/01DP9P0F8BL201@O9@0=01HQ9`0I92X07RT_01dX;P0A72806RDZ01`V:00K9BH06B<T01LQ
8P0F824051hO010J6`0200lI6P0M010J6`0B71d051hO018K800B6b805A`T01XN9`0K7RD061/R02DZ
<00R9bd06B4W010M8`0>7B803adR01LN:00J7RX051PS018F8@13Ae408bL`01DJ800F6b006b0T01LL
800B5aX0724U01dT:P0@6Ah00P0=5Q/00`0D7R004adO010J7002018L7@0g00hH6@0:51@03AHE00hD
500O8b@04ADF01hR8`0?4a@0720Q01<G600E6AX04aLH01@H6@0E6AX03Q8C00lE5@1<EE@09Rl^00dF
5@0N9bH04a`K04=<B`053Pd05b0O00dF5@0;51<04aTG00X;2P0=3`h06alN00lC5P0J8RD02Q8E00lG
6P093Q402@l?01@E5P0M7A/07QhL00d?3P0N81l04A<B01DG5P0;3@`051HE01DG5P0B51<06A/J018D
4`0>40l05QPG02PZ:@0P8R402P`;00lA400201DG5P07018D4`0A4a804Q@C01<E500B51<0418@014C
400201<E4P804Q@A02d04aDB01@F4`0D5Q<04A<@00H81@0V:2D0>S`j01@E5`0B4aD04A8C00lA400?
4@h04A<?01@F4@0H6QD05ALA00d@2@0<3`P04aD=01<D300@4@T04A8:00`=1@0=3PH05aP@010A2@0>
3`L0414900l@200?40T030d801XJ600B4Q0051@B01/K6@0I6AL05ADC01PH5P0C4a4030`:010@3P0A
4Ph03a0;014B300D5A000P0C50l01`0C4a405aLE010@3P0m?Cd05QHF00l?3`0H61P00P0B4Q00100C
4a404Q8@018B400B4Q0201DE4`0400h>300A4@l04A4?01@D4PH04Q4?1`0@3`d3018A3`03010?3@0>
3@/03`h<00803`h<00H040l=018A3`0B4@l03@`:02/Z:00<2`T2014@3P0P01DD4P0;2PP04a8@00/:
200?3P`06aXH00h=2@0@3`T04Q8:01<C2`0C4Pd040l:00l>2@0@3`/04Q4=01TH500?3P`04a8@01@C
4@0@3`d030/900/:200?3P`03Pd;01TH5P0?3Pd02@P6010?3@0>3@/04A0>01<B400A2`/3014=300:
00l>300@3`d02PT700d=2`0:2PP04Q8@0041000B4Q002`/;014A4@8030`<01@03Pd;00X91`0>3@/0
4`l<00d91P0<20D03`X6014=2@0?3PX03Pd901<B3P0E51004Q4=00d<200:2@D03@`801@C3`0A40`0
3Pd900l=2@803``500l040d6014>1`0A3PL04Pl8010=1P0<2@802PL000`90P0?30D04Q4<00h?2P0;
30L04Q<>04m@B`0I6QD00P0<3@P200d>2@803Pl:00T04Ph;01@@3@0A3@X03@T600l;200>2PL03`/8
010<2@0A3@X00P0>2PL02P0E4@h03@`801<B3P0;2PH05aHB01<B3P0@3`/06APD01DD400@3`/300d<
200D00d<2P0B4@l05QDC00l>300;2PP040l=00l>300@3`d03Pd;00d<2P0>3@/03Ph<028T8`0G6aX0
41@C00`>3@082@T04A4A00`<300=30`200h<3@803@/<00P04a4B00P61`0B41404Q0A01<A4P0?3@h0
2`T:00h<3@804@l@00d03P`=00`:2`0;2@X03`d>01<A4P0A3a00518C00l=3P0;2@X071XK018@4@0<
2P/040h?00@03@/<0`0@3Pl00`0=2``02`T:00/92P0300h<3@0B00P61`0J61T0>cTj01XH6@0<2P/0
2`T:05=ADP0E4a@030X;00l=3P0=2``040h?014=3P0?2``04Ph?014=3P0?2``04@d>0`0B3Pl02@0A
3@h040`=00`82@0=2@X02PH700P41@0I5AH0510A00/72002018>3`0A014=3P0@30d040`=00/82@0F
51D00P01014?400C4A804@l@010>3`081PL030X;010>3`0610D03P`=01TG5`0F5A<00P0<2`T00`0D
4a405aHD01<B400600h=2`0H014A3`0?3`d05QHD018B400>3P`02`/90000001>CT`06ATG00`<2P01
0@005A<D00P61`091`P040h?00/92P0A3a802`T<01<A500<2Pl03@/@092>T`0L6R003P`A1@0>30l0
4`0:20/030X=018@4`0>30l08AlR07]iO00c<C806aTJ00T720081PL01`D701HD5`0@3Q403`dA014?
500B41D04@lE00d;400;2@h00P0@3Q400`0F51L030X=01HD5`0200T72P0400`:3@081PT04a4D00h<
3aCooooo000Kooooo`0>00l>4`0H61/0410B00h>400M7Ah0:b/[07UiN@0F5QD06QXH00d=2`0A4@h0
3@h;00h<3@0?3@h2014?400800l=3P0>30d02PP9010>3`0=2``03`d>00h<3@091`P600l=400;01DC
5P0>30l0CD]>01DC5P0<2Pd0518E010>4`0=2`h040hA014?4P0>30d00P0@3Pl09P0@3`d04A0>018A
3`0B4@h04Q4=01@B400h=CH02@P9010A5@0J6b<03a<I01@F7P0I6R803`lF014>5@0L61h0;b`b01dL
8P0N7B<0;Rdb01DE600=3@l04a<C010@3P0A4@h04Q<>01<D3P0D5@l05AHA010@3P1XJ6H0A4A2018B
400F5QH051@E01<C5@0D51H05ADH0P0E51T0200E5AT0414E02<T:00B4aL0;Bhb01HG6@0E5QP05ALG
0P0C5A@06P0F61L05aTF01PJ5`0D5Q<05QPF018D4P0I6aP05QPF01DG500F61D06Q`I01TK600H6QL0
7B0N01HJ7@0G72006QlS01HK8@0D6Al05Q/Q01PL9@0F6R<06AdV01TM:00F6RD06AdX0P0G6R<05P0F
6B805APQ01HI8P0H72D05A`T01HM9@0H7bL0624X01LP9`0E7R@06QlS01<H6`0]<SD05a`O01hS9P0J
7b806b0S01PM800B5aX061dP020U:00F6ah301HN8@0[018J700K8bD0=3`m02D^;@0M9RD06B8P01XS
8@0L9B807bTX01HP900`>d4041/Q024/<00N:Bd07BP/01LR900X=3D05R8R01l[:`0N:RX08B`^020]
=@0O;3D07BXc01h[=00P;CH08Rlh01l/=@0L:C806bPa01`Y<P0P;CH08Blh01h]>00M;SP08C8l02Df
@00P<CT06R/c01//<`0N;cH08S<j028d>00201la=@0801lb=P0Q=3P08SDi028e>`0O<SP07S4g02Hi
@00S=Cl3020b?00L01h_>P0O;3`08c1001h/>P0K:C@0:3Ho03=1B@0I:2l07Rdd02Pg?`0O;CH06RPc
01PX<00E9b/05bT]01T[;`0J;3006BP]01HT:@0F8bT062D[01XV;00G8RP051lU010K800C7R805b8T
01HR90804alN01D0520N01HR800H92@05R4S01HQ9P0L9b`082Pb01HL:00D6bD06B0W014I7@0@61/0
5AhO00hG5P0>5QP0620R01HN8@0I82H072D/01@M900K92/00P0G82L03@0K92/05QlV01TR:@0L9B`0
6b@[01@M900J8bT0620S01PP8P0I8B<05QhP01DM7`0F7R000P0D71h0DP0E7Al05alQ01PP8P0I8B<0
4a/N014H700?5a/04aPM01DJ7`0F6B005QXS01DI8P0B6B404A/Q014M8`0F8BL06B0Y01LK9P0J7RT0
4QHO02HZ<`0>4Q/051TO02DZ<00N8bT05AXN01LL800C61`05alR00hF6@0E7B004ATK01DM7`0F7Ql0
4AXJ01<L6`0A6QP04Q/I01<L6@0@5aH07R<S00hB4`0J7Ql03Q8C01<G600?4a@04ADF01@H6@0C5aP0
5ATJ01LK700@51D04QPH01`R8P0G7Ad06b4Q01LM7@0>51@0:c4a01PN7P0V;2`041HF01HL700@51<0
7b0N010B4@0C5aH05a`O00XA501:DUD0=Si101TN8@0H7Qh05aTI01LG5@0P81h04aDD01PJ6@0D5QD0
5ALF00d?3P0F61L2014C4P0901LI600J71/04Q@C014C4P0D5QD05aTH00h@3`0C5A@0418A00804aDD
00`04Q@C01<E500C5A@04A<B014C4@0C5A8051HC01<E4P0@4Pl04A<@018D4@0G6AH2014C400701HH
5@0C5A805QPF01<E500B51<04A<B00lA400300lA3P0700h@2`0@4Pd051HA01<F3`0D5Q004Q<=01@E
3`0201<D3P0O01@E3`0@4@/03a0:00l@2P0A4P`03a0:014B300B4`l05QHD018B400C4a403Ph<01HF
500C4a403Ph<018B400G5aD04A4?00l@300?40/0414;014B3@0?40/03Pl:010@3P0A4@l051@B01lO
7`0C4a<03Ph>01HF5P05018B400701<C4@0;2`T05ADC00h>300F5Q@03Ph<01<C4@06018A3`H040l=
00D05A@B01<B400@3`d03`h<014@3P0201<B400B014@3P0@3`d04Q4?01@C4@0C4Q004Q4?030_;@08
1`H051<A00/:200920H03Pd;018A3`0;2PP03Pd;01HE4`0;2PH03Ph70P0?3PT08`0@3`X03`h:00l>
2P0?3PX02PT701TH5P0?3P`04@l@00/92P0I61H09RDS018A3`0=30X05QDC01lN700];2X03@`:018A
3`0@3`d02`X801<B400E3`l04Ph=014=300B3Pd03`h<00h=2`0B4@l03@d;00l?3@0<30X04A4?00`<
2P0?3`l04A4A00802`/;0P0?3P`0300A40h04@d:010<2@0D40d04Pd900l<200>3@T02PT500`;1`0?
3PX040l;014@30804Q4=00@03`h:00P70`0<2`L04@l;0P0?30L01@0@3@P04@h9014>2@0=2PH03P/6
00804a0;0P0?30L01P0A3`/00`@101`M600E5Q406Q/F00`=2@803a0;0`0@4@`02P0A4Pd040`9018>
2`0?2`P03PX7018>2`0C3``0510=01HB3`0D40d200h:1`04010<2@0<2`L02`X6018A3@803@`800D0
2PT501DD400B4@d03`h:00h=2@02010?2`0601<B400@3`d03@`:00d<2P0>3@/03`h<0P0>3@/2010?
3@08014@3P0E5A<0I6ET02<U900l?Sd0AdU8018C4`0<30`2010>3`0<00h<3@0@30d04Ph?018>3`0@
3Pl04Q0A00d;30091`P03`d>00P61`0=2``03P`=0P0@3Pl04P0>30d02`T:00/92P0=2``04a4B00X8
2@0E4a@02@L8010>3`0=2``04@l@00h<3@0=2``04@l@00d;300?3@h040h?00h<3@8030X;00H03P`=
00`:2`0<2P/03`d>010>3`0?3@h200h<3@07020N7`0:20T03@/<01DC500a;c003P`=00/92P0200d;
300:018@4@0?2``03`/<01<?400B3Pl04@d>01HB4`0C3a004Ph?014=3P<040`=00L05A8B01<?400F
4Q<04Ph?01PE5@0G4a@04`l@00804Ph?0P0@30d04`0=2P/05aDF00/92P0?3@h0518C00d;300<2P/0
2`T:01DC500=2``02PP901<A4P0:2@P04A0>01DD4P0>3@/04Q4?02LV900U92801@0>3@/01`0<2`T0
4Q8@00h>300@40h03Ph<00/;2@0>3Pd00P0?3`d0400;2`T04a<A010@3P0@3Pl061HG01<A4P0;2@X0
3`d>00`:3@0F51L020L901<A5P0;2@h061HK010>4`0>314500h<3`0>01@B5@0;2@`03@/>014?4P0<
2`d040hA01<A4P0:20T040h?01TG600@3Q004@lB01LE600B41@200h<4@0900l<4P0=2a002`T>00h<
3`0D4QD04@lB00l=40081PT040hA00803`d@00<020H9010>4@0:20/05?ooool001_ooooo00h02`T>
00l=4@091`X00@0201<A4`0H5QL0AdE600H41@0C4Q0040l=01DD4@061@4030X;00h<3@803`d>00P0
3P`=00`:2`0C4A802PP901HD5@0@3Pl02@L801<A4PH03`d@00@030X=010>4@0<2Pd04Q0C0P0<2Pd0
100?3A0040hA01HD5@0F51D2014?40<040h?01D03`h=00l>300A3@`04@/=01@?4`0?3A006APM010?
5`0C4a/051<K01<B6P060`X040`B01lH7`0R7R<04a8G01@C600J6Ah04A4C00/;3@0=3@d00P0=3@/3
00h?2P09014B3P0<30X07AdK01XJ6@0V9RH030`>014A4`0C4aD05A@I00805QDJ00X05A@I01DE6P0;
310030dA01<D5`0A4Q@02``>014B4`0@4Q403a4@0P0@4Pl06@0B51405QPD00/=200I6aH06Q`G010B
3@0G6AH06Q`I01LI5P0J71T06A/J01HH5`0K7Qh04aLJ01HK7`0I7R8051TO01<H7P0H7B<06AdV01PL
9@0K7bP06alZ01PL9`0L82/00P0G6R<301PK900d01@H8@0G7RH061lW01TP:00H8BP05b0W01HO9@0H
7B408RLZ05IKGP0G71l04aPK024V:@0O92L04QLJ03a1A00D6A`06QlR01HK7P0Q:B/05alQ01PP8P0G
7b407bLY03Hn@00V;S0072@V01/T8`0L9B@06b@S01hX:@0E7R<0=3m501dX;P0E82@05R4U01`W:`0T
;c40:SDf01DQ8@0C7al06BDU01lZ;00I9R`06BH^01PU;@0I9Rh06bP`01`Y<@0R;cL07b`d01dZ<P<0
72Ta00P072Xc01d[=00N;3D07R`e01/Y<P0I9c00938k020_=P808c8i00<09C@k02Pi@00Q<ST00`0O
<3L05P0P<CT08C8j02Hg?`0P<CT06BXb01//=00L;CD05RLa01d[>00_?DX0<3i;028`>`0E8b`04b4Z
01/Y<P0N;3D05R@^01HT;`0K:C@06b/c01/]<@0J:Bh201PW;0805R<Y01P05b@Z01PS:@0G8RP05R4W
01LR:00I92`06B<]01HP:@0E82D051lQ01<O7`0C7ah04QhL010L700@6a`04ahP01HQ8`0I8BX05adY
01DL9P0C6R803aHL00lG6P0F7R0201TQ8`0H01HN8@0J8BL051/S01HO9P0I8RT06b@[00/D6`0?61l0
3AHM01@M900I8RT0624X01<L8`0K92/05QlU01XR9@0K8bD072@V01LO8@0E7Al05alQ014I6`0B6Q`0
4a/M0`0D71h08@0G81l05AhM01HL7@0G71l061dQ01PM8`0N8R/07B4Z01XQ:@0G7R@051dR01<L8@0D
6b<041@M01hR:`0O8b`04QHO01DI8P0E6R004QLM014F700E6R0061dS018G6`0>5QT06b<U01XR900G
7b404Q/J00H?3P0?61L03aPE010I500200lH4`0h018H5P0?4a@051DG01HG6@0?41807b0R01TJ700E
5QP05aPJ01DF600G61X06Q/M018F5`0F71X04ALE01dS8@0G7A/03aDC01HL6P0C6AL051XH018H5P0?
5A<01@/900T=301?D4d092HU00lC4P0?4aH00PX=05ALG`2maLP08bP[00H<300?4A4051@B028R800@
4Q405QPG024S8P0F61L04Q@C00T;2P0C5A@06A/J01<E500L7Qd06A/J014C4P0F61L03a4@00d?3P0D
5QD061XI01lQ800D5QD3018D4`0?010B4@0A4a404Q@A018D4@0A4a00418?01<E4P0?4@h061XG01HH
5@0=3``04Q@A01DG500G6AH0418?00804A<@0P0@4Pl04`0B51405ALD01<E4P0?4@d04Q@?014C3P0@
4P`03a0:01LH4P0C50h05QLA01/L5P0?40X03Pl9014B300B4`d03a0:018C3@0?3`d00P0C4a40300I
6AL04Q8@01@D4P0N7Q`05aLE010@3P0=3@/02`/9010@3@0A4Pd04A8<010A30804A8=00T04A4?00/;
2@0I6AL0410@014A4@0410@05ADE014A3`0@40h00P0?3`d0200A4@l04a<A00h>300J6QP04A4?02/[
:@0J6QP04Q8@1P0@3`d600l>308040l=00L03`h<00h=2`0>3@/03Pd;01DD4P0@3`d03`h<00804a8@
00@03@`:00X91`0@3`d01@@20P0F5A<0200?3P`04a8@00l>300?3P`04Q4?01<B400>3@T040l:0P0=
30L01P0>3@T04A0<018A3@0D4a402@P600l>30803P`=00h0518C01LF500N7A/04A0>00d<2P0?3P`0
61LE00H5100H5aD04Q4?01DD4P071P@03Pd;01@>40803`/<01004`l@018@4@0A3a0040h?00<30`0C
4a<010@403Lg=`0=3@d03`l?00h>3P0<30`03`l?00l>300>3@/040l=0P0@30T00`0E4@h04`h:00d:
1P0200d<2P802`X800P03Pd;01DD4P0C4Q0040l=01<B400@3`d03Pd;00l=2@803``700l040d8014>
2@0A3PT05A8=01<@2`0>2`H040d801<@2`0@3@P03`d800<2000;2PH06QTG00l>2P0;2PH00P0?3PX2
010?2`804A0<01804@d:01<?300@30T03`/801@@3@0F4Pl04`l<01HB3`0C3``04@d:01@@3@0>2PL0
6APD00h=2@0c<Rh051<?01TH500A40`200/:1P0H00`;1`0@3`/04Q4=01<B3P0=30X02`X800X91`0<
2`T03Pd;00`;2@0?3P`030/9014@3P0C4Q004A0>01<C4@0>3Ph051HE00X<2`071`L03@`=00h<3@0@
3Pl040d>0P0?2``0200A3@h04Ph?00X82@0D4Q<01`D6010>3`0<2P/04Q0A0P0>30d200d;308030X;
00`01P@500`:2`0O7Ah06QPI03Pf=`0^;2d030X;00d;300<2P/03P`=00l=3P0>30d200l=3P803@/<
00<04@l@01DC500?3@h00P0=2``03@0@3Pl04@l@010>3`0=2``0518C00l=3P0C4A803@/<00l=3P0=
2``0518C01DC500>30d00P0:20T0100=2@X04Ph?010<3@0?2``3018>3`0;010<3@0>2P/03PX;00l;
300G4a@00`0001`H6@0=2@X0Og]l09jJV`0=2@X00`0@30d200l;300C00l<3@0C4A8030X;00h<3@0D
4Q<030X;01<A4P0?3@h05aDF00d;300:20T04@l@01<A4P0?3@h01P@500X82@0A3a003`d>00`:2`02
00h<3@0600d;300<2P/030X;00/:2@0E51803`h<0P0=30X0500;2PP04A0>01LF500;2PT030/900L6
100<2`T06ALH01lM7P0M6a`03`d>00`:2`0D4QD02@L:00P62@0:20d03@/@00P62`091P`03@/@1@0=
2`h0100B41<04@lB00l=400;2@`200T72P0C014?400@3Pl03P`=00h<3@0>30h03P`?014?4P0?3A40
3@/@00l=4P0?31803@/@00h<4@0:20/05A<F00T72P0U8bH02@L:00`:3@0200/9300300D31P0>30l0
20H901Cooooo000Kooooo`0>01HD6@0I5a/06QPK00D31P0B41800`4200`:2`0=30/05A@B010?3@0;
2PL03Pd900/92P0=2``200h<3@0800d;300;2@X03P`=014?4015@d@0<Bl`00H41@0?3@h600l=400<
01DC5P0<2Pd040hA028P8`0?3A004a4D00h<3P0@3Pl05aDF01PF5`0@3Pl03`d>0P0@3Pl200l=3P0G
00d;300?2``03PL901`F6P0C3Q@04a0G00d<500?3QH04A0H018?5P0710/04`hC01T@5@0D41@04Q4F
014@5@0=3A005ADG01@D500?3`l04A4A010@3P0@4@d00P0@4@`02P0:2`L05QHD01XJ600<30/04Q8B
01XJ700D51H04a<E01<B5`0D4aP201DD6@0E01<C600O82@06Q/O018C5P0A4Q@06AXL018D4`0C5A@0
4aDB01DG500C5A8051HC01LI500E5a8061XE00`>2@0B50l05aTF01TK600E5a@071hL00808R@S0100
:B`/01/O8P0M8RH07B8V01DJ800B5ad05AXP01LK900F6R<06AdV01TM:00F6RD06QhY01<F7`0D5b00
61/T0P0L7bP0100H72D05ahV01HM9@0E72@201<L8`0[01DN900O92P0314D03@i?00D6A`07R<V01<H
6`0R9bX06AhQ06Y_LP0X;C006QlR01PM800L92H04a/M01/S9@0L92H051`N01LO8@0M9BL05alQ01`T
9P0O9bT07BHV028Z;00U;S<06B@Z01LR:00P:bl072L[014L800F8B<06bHW01`X:00I9BD06bLW02@_
<@0G92X06RL_01dZ<P0N:c<07b`d01h[<`02020]=@05024^=P0P;CD07BXb01`Y<@0P;SL00P0Q;cP0
9@0N;3D07B/d01h/=@0^?4D08c8i028a>00P;cH08S4h02Xi@00R<cX07Bhe01X[<P0L;C@08C8j02<d
?00U=Sh07c0h01TZ<P0N;cL08C8j01//=00Q;cX082hk01h/=`0L:SD07bdf02<a>P0I9c00938k01TW
<@0M:cH08S0k01TY<@0F:2`05B@Y01PW;00L:c000P0L:Bl0:P0I9R`05b8X01@O9@0F8BL06B@Z020Z
=00N:3@05b4]01LQ:@0L9b/07BPZ01dY:@0E8Al03a/K014M7P0F8B<05B0R018K8`0D6RP05A/W01DL
9@0I82H06b<V018J7@0N9RP072@V01DM8@0L8bT05ahV018K8P0I8RT072D/01<L8`0Q:S407bP_01<L
8`0J8bX05QlV010I800O:2l051dS01@L7`805QhP00D03aLI00`D5P0>5QP04ATK018J700301@L7P07
01@L7@0G81d05QlL01HL6`0F6ah05AXM010E6`0201/O:01C01PO9P0F7B<051`O018J7@0:3aD05a/T
01@H8@0H72D051PQ010D7@0e>T005a`R01HK8@0O92X05a`R00lD6P0=5AP031@F00hF600C71/03AHE
01XS8P0@6AH04a`H01LP6`0C71L03aPC01TO6`0:3Pl05QLI014B500F5aT03@h@01/L7P0E5QP05QLI
01<D5P0D5AL05aPJ018C5@0;3`h051XH00`B400C6AL051XH00D;2@0D6QP03Q@B00X@3P0M8b400PP6
01LK6P0E5Q@03@l>020T8`0A5AP05QhQ01DM801<E5L03Q<F01lU9@0M7al020P601PH5P0C5A@01`T8
028T8`092`X03Q0?01DG5P0@4Q4061XI00X<2`0B51<05ALF00d?3P0@4Q404A<B01XL6`0I6aX03Q0?
01TK6P0D5QD00`0B51<00`0@4Q403a4?014C4002010B3`0;014C400F61D05aTF01<E4P0;3@X05QPE
020R7`0F61D04Q@A00lA3P0@4Pl00P0A4a003`0@4Pl03@l<00lA3P0A4a0030h:010B3@0A4`h04Q<>
014B300J6aD04Q<=01<D3P0J6aD03@h800h?2@02018C3@05010A2`0C50l04A4?01PH5P0>3P`00P0A
4@l07`0=3@/02@T7014A3`0D51803`l=010@3P0>3P/0414<00l@2P0>3`X0414<00l@2`0<30X03@d;
00h>300:2PX0820P00l?3`0=3@d0410>00l?3@0>3P`03`l=010@3P0C4a403`l=01PH5P0=3@/0<S8`
01hN700<30X0300?3P`01`0<2`T03Pd;00l>300?3P`030/900X91`0E51800P0>3@/03@0D4a404Q4?
00T81P0A40h040l=00d<2P0<2`T02PT700`;2@0E51803Pd;018A3`0F5A<00P0C4Q00900A40`03Pd8
00`;1P0>3@T04a8>01DD400A40h03@`:00l>300>30d02@L801HD5@0<2`T01`H400T81P0>3@/020L5
018A3`0?3P`040l=00D40P0<2`T00@0001TH5P0A2`d030P900h:2`0E4A805A<D01@B4`0?3@h00@41
01XJ6P0;2`/0EUIF01`L70803Ph>0180410@01DE5@0B4@l030/900h=2`0@30T03`/8018>2`0A30P0
3@X7010?3@0B4@l04A0>00h=2`0@3`d04Q4?00/:200>3@/201lN700501<B400<2PL03``700l<1`0@
3@P00P0A3PT0300T8A`08QlJ00`910091P<061D@01`I500>30T071/G00H50@0B4@d02`X600d<2P80
3Pd90P0?3PX2010?2`0701<?300E4@h04@d:010<2@0D40d05Q8?00`81@02010<2@0901@@3@0J5Q<0
510=00l>2P010000=3<_00X91@0A40`010<100802`X601P030/7010?2`0A40`03`h:00T81P0;2PP0
3Pd;00l>300>3@/03@`:010?3@0;2PP04A0>01@C4@0?3P`04A0>00/;2`0:30/03Q0?014A4@0?3Pl0
30X;00l=3P0>2``200d92P0:00l;300A3@h02`T:010>3`050`@05Q@E00L51P0G5AH03`d>00h<3@@0
30X;01<03`d>00h<3@0C4A800P0101HD5@040P<020H701@B4`091`P030X;01<A4P0;2@X03`d>00h<
3@0=2``04@l@01dK700U8b@03@/<00802`T:0`0>30d01@0@3Pl0518C0040000B41403P`=008040h?
00L02PP900L51P0>30d040h?00X82@0@30d05Q8C008040`=00h0510A014=3P0A3@h03`/<00d92P0>
2P/03`/<014=3P0?2``04Ph?00h:2`0J5QL08alP01DA4PD03`/<00<030T:00`:2`0:20T00P0?3@h0
1`020040518C00T720050`@03P`=018@4@0@3Pl00P0?3@h2010>3`0300d;300;2@X030X;00803P`=
00H03@/<00`:2`0<2P/03@`;01XI5`0C4Q02010?3@0D00l>300=30X00@0000h=2`0B4@l020L5010?
3@0<2P/01@<403<a<P0l>S/030X;00d<3P01008071XM00h<4@030@H04Q0E00h<4P0=2a0500d;3P0N
00/9300=2`h030X=00d;3P0C4A@04@lB00L51P0>30d040h?00h<3@0@3Q0030X=00/9300<2Ph03`dB
014?500@3Q@03@/@01<A5P0:20/061HI00P62@0f=3L0518E018@4`0A3a8040hA00X82`0B41<030X=
5?ooool001_ooooo00l081hS01DC5`0=2`h05aDH01/I6`091`P02PP900l=3@0?3P`03@`:018A3P0K
6QH05A<D00d;300@3Pl00P0?3@h200/92P0:00`:2`0C4A804Q0A014?400?3@h061HI01DC5P0>30l0
2`T<010>4@804Q0C00`04@lB00l=400?3A003`d@00l=3`0A3`l05Q@E01<A4P0G5AH030X;00l=3P0@
3Pl200d;300?00l=3P0@3Q004`hB01<<400A2Q403PT?01XG7P0E51`04a8J014@600A3QD040hD018<
400E31003`/>0080410B00L04A4C01HF600B4Q8061PH014A4@0A4@l0410>00804A4?01<04A4@014A
4@0A4A404a<D01<C5@0D51H0410C01PG700<2a005A@I01dL8P0@3aD04a<H01@E5`0E5QP04A8D014C
4`0E5aH04aDD008051HC01D0418>01DG4P0G6A@05ALA01LJ4`0C5A0061XE02T[9`0K7AX051HE00h@
400G61X061TL01DF6@0F61`05aXO01LL800E6Qh05a`R01`Q9`0I7R@00P0E6B806@0G6b@061`W01TM
:00J7RT05APQ01/N9`0B5Ah061/T01<F7`0H72D05QdU01DL900I82P06R<Z01LP9`0F7bD041DI01hS
9P0E6Qd0724T01PM800A5QT06b0S01TN8@0]<SD00P0K82<01`0F6ah05alQ01DM7`0E7Al0620R01TQ
8`0F7R000P0K8bH02P0J8RD06B4T01/S9@0K8bL05QlU01hW;P0P:C006b@Y01PQ9P0I8RL201XT9P0:
01hX:@0L9RL072HW02Lb=01[N7/0=T=901/X;P0N:c4072T_01XW;@8082dc00@07b`b01`Y;`0L:Bl0
7BX`0P0N;C@0100L:c806RT`01`Z<`0N;3D3024_>00;020^=`0M:c@072Xc01h_=`0J:c<072de020a
>@0N;cL06b`d01`]=@0M;SD0100N;cH0200I:3007B/e020^>00L:SD06RPc01h/=`0N;3P072Xf0P0K
:C@0B`0L:SD06BP`028a=P0E92T062H/01`Y;`0G92X062@Z01DP9P0I92X05b4W01HO9P0H8BP05Ah[
01lX>@0J8c<05b4/01/V;@0R;C80:3<e01HR8P0E8B807RTZ01DP8`0B7B405b0Y03Y0CP1oQI808BPb
01LN9@0M9BT04QXM01PP8`0L92L031<H01/R:00E72@06b8Z01HM9@0L8b/061lW028Y<@0Y<3P07bH^
014H800G7RH06b8Z01`S:`0B6B005a`P01TN8@0F6ah04aPK01HK7P0E6Qd02a0C01@I700B5aX05Q/N
01@I700F6ad05adI018H500D6QT06R8T01PP8P0C6R004APN01@K8@0E6Ql0<3@f01`Q8@0P92@05a`P
01@I7`0201HK8@0H01DJ800F6b40<cM001PL9@0I7BH082@]01DI8P0?51X04aPL01@I700C61/04AHH
010F5P0B61P09bd/010F500B61@0318>01<I5@0G71T05QPJ01DF600F5aT03a0B0P0H6A/0201/KFl0
7AhP014B500F5aT04a@F01PI6`0E61L04QHE0P0A5A@05P0C5aH051PG01HJ6@0=4A0061`K02hb<@0C
5aH03a8A014B400K7A`01`/:010E600P:2/06b<V014I700E6Qd051XJ018D500D51805QHD010B4@0B
51<2010B4@0601<E500D5QD04aDD01LI600H6QT05ALF0P0C5A@00`0A4a804Q@C01<E500201<E5007
014C4P0@4Q404Q@C01@F5@0B51<0418A010B4007014C400<010B3`0?4@h03Q0=00lA3P0A4`l04Q@?
014C3P0N81`0:R`Y01`N6`0=3``0418?0P0A4a02018D4@0>010B3P0=3PT03Pl:014B3@0C50l04A8=
018C3P0@4@`03a0;01@E400F5a804Q<>018B400=3@/3018B400C00d=2`0C4a403Ph<01LG5@0=3@/0
5QHD01@E4@0A4Pd04a@>010A300B4`h061TD01@D4P0A4@l02`/901<C4`0I6AT0410@00h>3P06014A
3`0@00l?3@0>3P`03`l=010@3P0B4Q004a<A00l>300@3`d03Pd;00d<2P0>3@/04A0>01HE4`0@3`d0
3@`:00l>30804A0>00`04Q4?01<B400A40h040l=014@3P0B4@l040l=00l>300=30X03Pd;014@3P0D
4a4200h=2`@03`h<028020L500l>300?3P`0?chl01PG5@0C4Q005aHB01<B3`0B4@d092<O01HE4`0@
3`d03`h<01DC500>30d03@/>01XH6`1_KFh051<B00h=2`0=30X03Pd;00l>300>3@/030/:01HE4`0;
2PP03Pd;018A3`0<2`T03`T;010<3@0A3@h04Ph?0P0?3@h0600:20T02`/;010@400K6a/0HV9R01DE
5@0?3`l0=CDe01XJ6P0R8R803@`:01XI5`0E518030P501@@3@0A3@X03`X6014=2P0=30X05QDC00d<
2P0;2PP05QDC010?3@804A0>00D0<c8`00L61@0E518030T8014=2P0300l;200500d91P0A3@X03@T6
00d91P0?2`P00P0<20D00`0>2`P03@`800`;1`0200/:1P0F00`;1`0?3PX03@`801PG4`0G5Q802@P4
00X91@0@30T03@T600`81@0?2`P04@d:010<2@0A3@X03`/8014=2P0B3P`03P/901TE4P0=30P03Pd9
00l>2P8030/701<04A0<00d<200D4`l030/700l>2P0@3`/030/7014@3P0B4@l040l=00d<2P0/:bT0
3`h<010?3@0H5aD02PT7014@3P0<2`T05aHD008030`<01l02`/;00`:2`0=2``03P`=014=3P0F4Q<0
>SHg00d72@0A2`d03PT;01<@4@0@3Pl020H700h<3@0<2P/0518C00T7200>30d02PP901<A4P0:20T0
518C018@4@0=2``02PP900d;300@3Pl03`d>01@B4`0?3@h0GE]L00804Q0A00P040h?00d<300Z:2T0
=38c010?3`0[:BX0=cDf00d;30803P`=00D030X;00h<3@0?3@h02PP900/92P0200d;300301HD5@0`
;Rl03P`=00803`d>00T03@/<00h<3@0?3@h02PH701<?40091@H040`=01HB4`0@30d00P0=2@X02`0?
2``05A4B00l;300B3Pl040`=00l;300@30d04@d>018>3`0@30d04@d>008040`=00<03`/<00h:2`0@
3@h00`0>30d200`:2`0d00l=3P0@3Pl02PT900X82@0R82403@/<00h<3@0610D02@L800d;300>30d0
3`d>00d;300>30d020H700X82@0@3Pl02`T:00d;2`0A40h061LE09:AS`16AD<040l=00/:200B4@l0
51<A028Q7`0E51803Pd;00h<3@0B41405aDF01XH6@091`P04a4D00`:3@0D4QD03`dB00H42@0E4aP0
30T?00T7300P7R402`T<00l=400D4QD030X=010>4@0>30l02`T<00`:3@803@/>0P0<2P/04@0>3@d0
30X;00`:300?3A004A0B00h<400>314030X?02LU:`1KFEh071XO00l=400C4A@0518E00d;3P0A3a80
518E00803`d@00<03P`?00d;3P0B41<05?ooool001_ooooo02005A0F00d83@0910P040/?01<>4@07
0`@02PH700h:2P0?2`X03PX901<?3@0I5A801`D6010>3`0R82404a4B00h<3@0;2@X04a4B02@R8`07
1@H03@/<00`:2`0?3@h0KF]^020N8@0=2`h0518E00h<3`0]:bh04@lB010>4@<03`d@020040h?01@C
400H5aD04Q4?01HE4`0:20T02`T:01<A4P0G5AP05Q@G018@4`0@3Q<04`hD01<:4P0@2A402PD<010=
5P0;2A@03P`G01@C6`0A3QD03P`A014<3`0G3Q406aLH00/;2`0L71`06ATI05]KF`1SHf<0De=C010@
40<03`l?00<0410@014A4@0B4Q800`0B4Q@02P0B4AH06APM00D42@0H5ad04Q8G01XI7`0;2Q804a<H
00l@4P0<3Pd201@F5@0701DG5P0F61D051HC01DG4P0B50l04aD@01@F4@0201<E400@01<E4P0A4a00
418?01PI6P0M7R007b0T018C5`0_<3D02``A01`N8`0G6Ql061dQ01LL800G72806AhT01@I7`8051PQ
01P05ATR01HJ9@0G6bH05a/V01dP:@0P8b`05QTR020S;00>4AX08RH_01/R:P0A6200>D180:2Y/00P
:C0072D[01<H700D6A`05a`O01TN8@0B5aX06b0S01@I700B5aX201DJ7@0301LL7`0K82<05QhP0080
620R01405alQ01PP8`0J8RD06b<V024X;@0Q:2h07B@Z01TP9P0I82P04Q/R01TR:@0K92/0624V01HO
900H8BH06bDW01PR900201XT9@0901LQ8P0H8bD0<Ca001LT:P0F8bT07R/a028_=@0U<SP07b`b0080
934g00@08Bhd01dZ<00L:Bl06bP^0P0L:Bl01@0L:C407b`d024^=P0N:c@07b/g00<082`h00L07bdh
01h/=`0V=3l09C<n01d[=P0L:S<07bdf00<07B`c0`0N;C808@0M;3807Rdd02<a>P0R<3/072Xg01/Y
=P0N;3X07R`i01d[=`0K:C@06RPc01/Y<@0B7bD04AhT02Pe>`0K:2h041/Q01`W;@0E82H0624X01<L
8`0B6b806R4Y01LP;@0G83405Ql`01@N:@0I8b`08Rdc02<^<P0F8B<05b8V01`W:`0201@O9@0J01LO
:P0I7bd0Q8ZH024W<P0d>d<02Q4G01PO900:4QD05A`R01`S:P0D6b<05QdW01/R:P0D6b<06b8Z01LN
9P0B6B403aHN010G7`0U;3@0;3<k018I8@0L8b/051/R00`A5@0A5AP201@H6`0j01LK7P0D61/03a<F
01LK7P0D61/05ATL018F6@0D61X04QHE01<H500L8R407bLY01XR9@0E728051/Q010H6`0N8bD0JF]X
03do>P0P8Q`0310C01XO8`0A5QX0314G020U:`0@5A/04aLP01dQ:P0L82T04aLR014E800I7BH04A@K
01@G700F6Qd05ATL01HJ7@0I7Ah0Oh>4028V9`0D61L061`K01HJ6@0E6AP06AXL014A4`0H61X04A4C
01<C5@0J6Q`092@V01lO8@0V9RP07QhP01DE5`0720X051HE01@F4`804aDB0P0D5Q<06@0F61D020X7
00T;200F61D051HC01`N6`0C4a4030h=00`@3`0B5aX03ADH01dU:00=5AP04AHI010F5P0A4Q<04Q8@
01@D4P0O8B003@l>018D4`0F61L04Q@C01<E500@4Q400P0C5A@00`0B51<04aDD01DG5P04014C4P04
010B4@0>40l03a4@014C4P804aDD00<04Q@C014C4@0A4a00100A4a000`0B51404A<@010B3`0200lA
3P0:010B3`0@4Ph041<<010B3@0?4@`04aD@01<E4P0?4@h03@l<00h@3`<03a4@00H03a0=00d=2`0=
3@/0410>018B400A4@l2010@3P<03`l=01T03Ph<01<C4@0;2`T05aLE00/;2@0d=3803Ph<014A3`0G
5aD03@d;01HF500E5A<08R<O01<D3`0D5@l04Q<>01<D3`0F5a8051@B020P7P0B4Q0061PH038b<P0_
;bl05aLG00H03`l=0`0>3P`01P0?3`d04A4?018B400>3@/04A0>018A3`8040l=00P04A0>00/:200A
40h04a8@010?3@0A40h05QDC00l>30804A0>0P0>3@/01`0?3P`03Pd;00h=2`0>3@/040l=01@C4@0G
5Q@01P0>3@/06P0D4a403@`:00/:200?3P`030/901XI5`0;2PH00@0001PG4`0U92803Pd;00D40P0A
3a004a4D00T72P0F51L00`44018@4@0>30`03@`:00h=2`0?3P`03Pd;00`;2@0B4@l061LE0P0@3`d0
0`0E51804a8@018<3`03014<408030X=02D09R@W00L72@0C4aD07AdO03De=`0>3Q005aLG0;Zj^P1E
EED0000001hM6`0D4a402`X8018>2`0Q7AX061@A00h91@0;1`D040h?01HD5@0B41401@<400T7200F
51D030X;00l=3P0920P02PP901PF5`091`D03`/:01@@3`0B3Pd03@T800h:2@0?2`X03PX900803@T8
00@06QHE01/G5P0C3`d04Ph;0P0A3@X0500B3P/04`l<01@@3@0?2`P04@d:018>2`0<20D03`/8014=
2P0?2`P03@T600l;200A3@X040`900<0000P71T02PH300L300060P003PX90P0@3`/0<P0?3PX030/7
00/:1P0=30P02`X601HE4@0@3`/03`h:00h=2@0@3`/03Pd;00l>300D4a402`X800l>30081`D01PD3
00h=2`0@3`d06QTG018A3`0?3P`02@T900X92@0;2@X030X;00l<3@0B3Pl02PH701/F601QFed04@/=
014;300H4Q@01@42010>3`0N71d02`T:01HD5@0100007A/L00X82@0E4a@05Q@E014?400;2@X040h?
00T7200A3a00518C0P0?3@h010040P<08R0Q0=7?d00/:R/200/92P0E00h<3@0Q7b00:2HW00X82@0B
4140518C014?400?3@h030X;00X82@0<2P/03`d>01LE5P0>30d030X;00l=3P0;2@X03`d>00d;300?
3@h03P`=00803@/<00H03`d>028N7`0=2@X02PH700`82@0C3a0200l;3004010<3@0>2P/02@D600X6
1`804Ph?01l04@d>010<3@0@30d04@d>01/G600c;c009B4R01<?400@30d02@D6018?400?3@h02`T:
00d;300@3Pl03`d>00L61P091`P08b4R01XH6@0610D00@0000l=3`0N71l061HI01TG6P0B41<00P03
00D31P0H5QT040hA00805aDH00L01@<600l<300P71/030P701TE500G4a80J6AS00805Q8A01T08QhM
059>C@0@30/05Q8A01PF5`0?3@h05aDF01<A4P0:20T04@lB00h<3`0A3a803P`A00/93P0G5AX04PlE
00@21`0H5QT03P`?01<A500B41<03`d@010>4@0?3A003@/>00803P`?01@030X=00/92P040P<0@d52
02TW:00F51H020H900h<3`050`L04Q0E00`:3`17A4X0dm7F02PV:`0E4aH0518E01LE600?3A002@L:
018@4`<03P`?00<03@/>014?4_ooool04oooool001_ooooo01d0100501HA5P0D3a<01`8600P51P0H
51D03`/<014=3@0?2`X03@T800h:200B3P/04@l@00P61`050`@02@L800L51P0B41401083018@4@0>
30d03`d>024O801NG5d0XInR00d;3P0@3Q4030X=00l=4002010>4@0T00l=400>30l03`d@00l=400@
3Pl030/801TH5P0?3P`02`X800H41@0=2``040h?01DC5P0D4QD03P`?00l=4P0E41H040T@01<>5@0<
2A002`TB00T74P0B41/051<J018?5P0A3a804`hA01D?3`0I5AD0410@01/K6`0<30`07QhN00h>3P0M
7Ad04Q8B0`0A4A400`0B4Q804a<C018B4P03018B500?018A5P0E51T020L<014@5P0H5ad06QTO01XI
8@0L72404a@F00lA400G6AP0418A01<E4P0K7AX05ALD0080418=01@04aD@014C3P0A4`h04Q@?01@F
4`0F61D02P`;01DF6@0>3a<06AXO03Xj@@1nOXH07alY01HH800C5Q/05Q/O01PM8@0H7B<06b0V01LL
8P805QXS00H05a/T01PL9`0H72L06AdX01/N9`0C5Ql201DH8@0c01TL9@0_<c`041LO00hE7@16CED0
^/?:02Tb>@0I8RP05a`P01LL7`0I7R4061dP01DJ7@0R9bX03A8E01HK7P0K82<08bP[01TN8@0E6Qd0
6R8T01dU9`0K8bD05alQ01DM7`0H82<072@W024Y;@0Q:2h07B@Z01XQ:00L8b/051dT01TR:@0L9B`0
6b@Y01XS:00L9BX06bDW01TS900J92D06bDV01PR8`0F828062<W01@Q9`0O;380934g01l/<P0M:S00
72T_008082dc00@07BX`01XW;@0J9bd07BX`0P0O;3801@0N:c<082de028_=`0P;CH08Bdi00808Rhj
0P0Q;CT01`0N;3L09S@o02Dc?P0M:cH06RPa01d[=00J:C000P0I:2l02@0I:2d06RT^01XY;P0L:c00
8C0e02/j@@0/>T@07bdj01XX=@0201TV=P0d01TW=00F92l0528]010N9P0N:c409S<i014N900Q;S@0
72L]01LR:00H8bT07bP_01TR:@0@6B0072<[01XR;`0A6R/051d/018L:00@6R<05R0Y01DP9@0D7b<0
5R4U01PS:@0A6b@04adV01dU<@0<4R80:S0n01dS;P0E72@05QdS01LN8`0I8B@02A0F01PO9P0B6B40
6R4[01/R:P0E72@072<[01dT;00F7BD04aXR00dD700X;cL0<SU100dD700D6b<05Q`S00lB5`<04QHI
0P0E6A`0800J7R404ADH00hB5@0N8RD05ATL01<G6@0K7ah06QhM01/Q8P0H82<04a/N01DL8P0I82H0
6R8U020T8`0_<R/0=SP]07moM@17Bd`08RL[02/`=00V:c407B8X01HK8@0?4a`04ADN00hB6`0C5b80
5a/V00T=600A51/051LL0P0E61d0100F6Qd06AdP04Y>D@0I7Ah200`@4@0601PL700;3a0051@F018B
500X:2X0820R0P0C4aD01`0A4A<05aLI00H62000008071`N01XJ6P0D5QD0100C5A804@0D5Q<04A<@
01DG500F61D0418?00`>2`0E5a@05QHD00L9200<40l05QXM00P@4`0D71l03QHI010E600@5QH04aDE
00805ADC00D0;2h]01@F5@0I6aX05aTH00lA400401<E500301@F5@0G6AP06A/J00<04A<B00@0418A
00h@3`0@4Q404Q@C0P0C5A@00`0@4Q403a4@00lA3`05010B3`0301<E4P0D5Q<04aDB00<04Q@A00P0
4Q@?018E3P0@4Pd03@l:00h@2`0A4a00418?00d?30803Q0?0P0?4A00200@4@l03`l=00l?3@0B4Q00
51@B01<C4@0?3`d03Ph<0P0@40h02P0A4@l04a<A00P81P0;2`T051@B0041000S8b403Ph<01@D4P0E
5A<2010@3P04014A3`0H6AD0414<010A2`<0414<00L03`l=01<C4@0<30X030`<01@D500B4Q803Ph>
00H03Ph<00@04a<A018B400@40h03Ph<0P0=3@/0100=30X04A0>018A3`0A40h200l>300@00d<2P0@
3`d03Pd;00`;2@0B4@l06QTG00/:200=30X04A0>01<B400?3P`02@P601<B400B4@l03`h<00h=2`80
3`h<0`0@3`d300l>300O01@C4@0>3@/06APF00P71@0?3P`05A@B00h=2@0I61@04A0<00d<2P0>3@/0
4Q4?018@4@0=2`h02@L:01/I700?3A003P`?00d<2`0;2PP030/9010?3@0?3P`03Pd;00L61@0920H0
2PT700d<2P0;2PP01PD3018<4002014<400c010;3`0=2`h03@/>065OHP1LG5h03@d?01dM7`071`T0
3`lA01PH600h>3P04a<C010@40081`D01`H500X91`0?2`P05a<@014=2P0?2PH03@T700d;300<2P/0
3`d>010>3`0=2``03`d>014?400=2``03P`=014?40020040514A00h:2@0C3`h04@d<00l;2P0C3`h0
3PX9010<2`0?2`X04@d<02PT8`0[9bH061@B00l;200>2PL03`/8010<2@0B3P/0510=00803@T600L0
40`900h:1`0@30T03`/800h:1`0=2@H03PX700803`/800L06aLD00d91P0E4@h02PH300l;200F4Pl0
40l;00803`h:02l03@`800`;1`0>3@T040l;01/J5P0D4`l03Pd900`;1`0>3@T02`X800h=2`0B4@l0
1@@200h=2`081`D06APF00`;2@0920H04A0>00`;2@030P002@T900T8200:20T02`T:00h;300@30d0
510A00T41P0S7Al04@/=00l82P0E3a402@D6040n?`1<BT/05Q@E00D3100B41400@0000l=3P0B4140
0@0001LE5P071@H05Q@E00d;3002018@4@0H00`:2`0D4Q<040h?01<A4P1HEUL030X;01<A4P0>30d0
3`d>0040000:20T04Q0A01DC50071@H02`T:014?400C4A8040h?00/92P0:20T03Pd=00l=3P0A3a00
518C0P0>30d01`0=2``03`d>00h<3@0<2P/03@/<00h<3@0g<c@00P0D414200l;300900X61`0A3@h0
4Ph?00P41@0?2``05Q8C00d92P0E4A80510A00<04`l@00P03@T:01`H6@0C3a002`L801<?400=2@X0
6AHG01@B4`803P`=02H040h?00h<3@0?3@h05Q@E071^K`1CDE8030X;01dK70091`T01`D800<1100>
30l00@0200P62@0c<C@040hA00<1100<2Pd0108500D31P0I5QL04@d<00P4100810<00`0003Te=00=
2@P04@d<00h:2@0Q7A`00`0001@@3`0E4a@0518C00`:2`0?3@h020H7018@4`803`d@00/03@/@00l=
4P0D4QL04@lE00/93P0C4A@02`T<01<A500B41<0518E00h<3`0200d;3P0G00h<3`0?3A0030X=01DC
500610D09bDV018@4@0<2P`05Q@G00`:3@0C4AD03`dB00H42@0K61h0AdE:01XH7@0>30l03`d@018@
4`0>30l03@/>014?4P0=2`h00P0>30l00`0<2Pd040hAooooo`0Cooooo`006oooool0200?2Q0030L<
00l:3P0A31003`/=00h:2`0=2@X03`/;0P0?2`X02P0@30X04@d:01<A4P0D4Q<04Q0A03lm?P0D4Q<0
2PP900`:2`0>30d200l=3P0701DC5015@d@0EE=F01<A500=30h05A<F00d;3P0200l=40803P`?0P0?
3A007`0@3Pl030/800l>2P0<2`L081lM01`J6`0H5QL03P`=010>4@0?3A003@/@01@B5`0I5a`06A@K
00T5300?3A@09RD]01HE7`0>3QP03a0F018A5`0D51H0518C018>300?3P/061PF00`<2P0?3`h02`/;
010@400C4a<00P0@41000`0?3a00410B010@4P03018B500W018B5@0B4AH04Q4F01@C6@061P/06APN
018A600_;SH0SXfE01lO8`0C5A@051HE01LI600?4A005QPE02HX900J71L03Q0;018E3`0H6a@051L@
01<E4@0B51405QPG01hO800C51L051DI01@D6`0M7BH092@^05=CGP0D52405QLS014D6`0E6Qh05Q/O
01@I7`0F6b404aPN00805ATR01l05QXS01HJ9@0F6RD05QXU01XM9P0C5Ql05APQ00hA6P1JGFH0B4aE
00`C6`0Q:3004APP02D^=@0F7bH051dS02@Y;@0P9BP0724T02P]<00F6ah06AhQ01XO8P0I7R404AHI
01<H6`0G71l061dP01TR8@0L92D06b<U0080620R00X06R8U01XQ9`0I82L061lW01LN9P0I82T07B@^
01LN9P0I82P072<[0P0L8bT00`0M92X06R8U01`T9`0201`T9P0401hV:00K9BH062<W01HT9`<06BLZ
00P06RP[01d[;P0M:bh06bT/01XX:`0L:Rd07R`_01/Y;0807R/a00@072T_01`Y<@0M:S807R/d0P0O
:cL02`0N:SP07BTg01`X=P0N:cT07R`i020^>`0O;CP06RPa01LU;P0K:S406BP]008062L/03@06BP[
01XY;00G9bP05RDY01`[<P0O;CL07BXi01h[>`0J9cP06bPh01/X=P0I9c@05bD`01d[<`0H9B/0934g
014M8`0R;C<06B@Z01DO9@0D7B@09c0g02L_=P0A62004aXR01DM:@0=5RH06B8a01XT;`0E7bT06B</
014L8P0E82H05R4X01HP:@0C7BP05AlZ01TQ<00O9CD08RPf01<I9@0I82P08BP_018I7`0E728061lU
0:6X[`0[<SX061lY01DI8P0F6R<04aLP0P0G6b@02`0C5b005ATR010D7@0F6R<051PQ01/O:00F6R80
9BP]02@X:`0J7R404QHI008051PK03<04aLJ02hb=@0P92L03a<F01PL7`0G6ad05a/K01HJ6P0J7b80
6B0U01@K8@0B6b406B0V01<K7@0/<2`0=SP/09:AP`3emNH0Y:NU03i3AP0V:bl06AhR01PM8P0@5A/0
4QHO01@H8P0E6B@07b<^02L[=`0G6bH04QDO01@G7`0D5ah04QDL018E6`0C5Q/03A0E01DH700H71l0
3a<F01PL7`0=4A<05aLI01HF600Y:B/08B4S01HF600D51H05aLI010@4P0I6A/00P0E5AL00`0?3`l0
4Q@B01<E4P0301<E4P03018D4@0D5Q<0418?00805aTF014051HC00d?300E5A<05aTH01<G5P0=4QD0
3ADH00H>4@0>5QT03Q<F00hD500C51D04a<A018B400F61L03Q0?01<E5002014C4P0701XL6`0?4A00
3a4@00h@3`0?4A004Q@C01DG5P04014C4P0500lA400@4Q404A<B014C4P0B51<00P0A4a800`0A4a40
418?010B3`04010B3`0300h@3@0=3``030h;008030h;00X0418<00lB2`0=40T04A<=010B3@0>40/0
3a4=010B3`0@4Q404A8C0P0A4Q@0200B4a<04A4?014A3`0D51805QHD01DE4`0A4@l03Ph<0`0?3`d0
100A4@l051@B018B400;2`T3010@3P0801@D4P0;2`T06QXH00T91`0E5A<03Ph;00h?2P0>3`T2014B
3@0500h?2P0>3P`06a/I01DE4`0?3`l00P0A4A400`0=3@d03Ph<00h>300400h>3003014A3`0@40h0
410>00<03Ph<00@030/900l>300@3`d03`h<0P0>3@/04P0@3`d04A0>014@3P0B4@l040l=00d<2P0B
4@l03Pd;00/:200>3@/04A0>010?3@0B4@l04A0>00l>300=30X030/900/:20H03Pd;01l04A0>00X9
1`0D4a401`H4010?3@0<2`T03@`:00D40`0E518040l=00l=3P0B414040h?00X82`0B41<03@/@00T7
300;2@`0518B00h=2`0=30X04Q4?01DD4P0F5A<092<Q00`;2@0=30X040l=014@3P0<2`X04@/?0080
3`X>00T040/?010>4@0@3Q40BDM:04A4AP0>3Q001PH801XJ700B4Q@00P0@4100600:2PX05QHF00D4
0P0B4@l03Pd;00l;200A3@X03`/8014<200@30X04@l@00d;30091`P04@l@010>3`0?3@h01`D601HD
5@091`P05A<D024O800?30`02PH500l;2P803PX900D05Q8A00h:2@0C3`h03`/:00/71P0201PD4`03
00l;2@0>2PL03PX700803`/801@04@d:00l;200>2PL03`/8014=2P0?2`P040`900`81@0=2@H03PX7
00d91P0>2PL040`901<?300a;BX09R8O00d9200I5A8030T600h=2@803@`801803Pd9010?2`0@3`/0
2PT501DD400>3@T030/700/:1P0=30P02@P600h=2`0A40h00`8101hM6`0?3Pd040l=00`;2@0D4a42
00h=2`0401<B400@3Pl03`d>00h<3@8040`=01P04@d>01TC5@0C3@l02`H70189300D2`h030H8014=
3P0=2``02@L801<A4P0<2P/0=C<d02TW:00n?3d030X;01LE5P091`P04Q0A01LE5P0@3Pl02`T:00T7
200:20T2018@4@0<00`;2`091`P0;B//00h<3@0;2@X040h?00`:2`0;2@X02PP900l=3P0B414030X;
0P0>30d02P0?3@h04@l@01<A4P1UHf@07A/L00h<3@0E4a@04@l@00/92P0=2``200h<3@0A00`:2`0=
2``03P`=01XF5`060P<03`/<014=3P0B3Pl03`/<00d92P0D41406aLH00h:2`0C3a003PX;00l;300>
2P/00`0=2@X02`0>2P/04`l@014=3P0@30d0510A00l;300@3@h03P`=00X82@0;2@X03P`=00803@/<
00d01@@402HT9@0M6a`02`T:014?400@3Q005aDH00d;3P0:20/01P@701XH6`0i=cX030X=00<03@/>
00H05Q@G00T6200J5QD07QXI01<?3P0=2@P201@@3`0F00P40`0C3`h01`@301HB4@0i=C@0f=OH0;^i
^P0L6Q/0518C03Dc=00Y9bX04@lB00/9300=2a005Q@I010>4`0=2Q004@lD00d;3P0;2@`03`d@00H4
1`804@lB00X03P`?00`:3@0=2`h03P`?00d;3P081PL03P`=00X82@0D4Q<02`T;0P0@3Q403@0?3A40
2`T>00d;400A3Q@030X?00X83@0;2@`030X=00X82`0<2Pd04a4D010>4@0=2`h00P0@3Q400`0>30l0
4@lBooooo`0Cooooo`006oooool07`0A2Q405@hD01TC5`0D3Q803`T<01LA4`0<1PP03@L8010:2P0B
30`050l=01<?300@3Pl030X;0040000a;c002@L800l=3P081PL030X;00L51P0@3Pl04Q0A00X82@09
1`X05aDH00`:3@0F51L03P`?01dK7P0>30l00P0=2`h02P0>30l03`d@010>3`0A40`03`h:00X91@0T
8b407ahL01@B4`0?3@l200l=400A010>4`0C41L05A8I01D@5`0>2a@081lW03He?`0D51h00PD>00d@
5P0@4AH04A8D014A400A3@X02@P500X:200B4Q000P0C4a401@071`L03`l?00h>3P0>3Q003@d?0080
3Ph@00@0410B014A4`0A4A<04Q8E0P0C4QL07`0B4AH0:RT_018A6@071`h06QTQ0450B00@41@0418A
018D4`0B51804aDB01PJ5`0N81`05QPC014C3P0H6Q@061/D01HI4P0E5a<04Q@C01<D5P0E5QX05aPL
01DF700@41P06QXT01HF8`0F5B<05QDU014A800B5A`00P0F6al00`0B5ad051TO01DJ800301@H8@<0
51PS00T05QTR00P;500E624030lH01@G800Q9Bh020lG010G7`0F7BD00P0J8bX05P0J8bT0;S<g02DZ
;@17C4l0QHZ=02db=@0L8B@06AhQ01/P8`0O92L04AHI01XO8P0B5aX05b0O01HO7`0G7b406R8T01/S
9P0J8RD08BP^01`S:P0K8RX201hU;`0D01XQ:`0G7RH05ahV01PO9`0I82H06R4W01TP9P0F7R407BDW
01PP8P0E7Al06b<U01/U9P0U<3@07R`_01DS9P0B82<05R@W01/Y;00L:Rd201h/;`807B/^00<07R`_
01PS9`0L9bd00P0L9bd00`0K9Bh072H_01/U;`0201`V<P0;01dV=@0L9C@06RHd01/W=@0J9S@06bLe
01dY=@0K:34062D^01h[<`0K:2h00P0I9R`0200K:B`072X]01/[:`0H9bX06BP]01PV<00J9cL082dm
0P0H9CH06@0H9S@06BLd01TW<P0I9bl0QY>I0;W6c00b?T@0Qi:H07V2R@0S;3<05QlV01<J8P0@5al0
2A0H01DL900L92l03QLV01/T<`0J92l051hX01XT;@0>62404adV014K9@0A6bH00P0C72/0?`0I8380
318R02H/>P0C6BD03QDM00XA6@0O9R`072<Y01TP9P1?EUd08RTc01PO:@0C5b008BD^01@H8@0F6R<0
7R8[014E7P0E6B8051PQ01dQ:P0>4Q/03a<L01DI8@0Q92T08BDX01TM800C5aX05ATL01HJ7@0M8B@0
@DE802``<`0;3a805a/N01<G6P0H71d051PI01HK7`0J8BL05QlV018K8@0G7R@07RHX030d;P0k?2h0
KFaJ0=;@_@2=ShX09R/^09JKWP22Qh/04AHK020U:`0D6240720Z01/O:P0D62@04QHR01DI9@0A4al0
4aDQ018E7P02010C700;014D6`062A002`hC00lB5`0^<CH0CE1E018F6@0E5AL04Q8D01@D5P0<30h0
0P0A4A<01`0E5AL06a/M014A4`0C4aD08R8T0000000A4a000`0C5A005@0B50l04A<>00lA300J71L0
7b4L00`>2@0E5a8051HA00h>30051`H06QhM038f>@11BD`041PK00lG6P0=4QD03Q@D01<D5@0A4@l0
3`l=01<E500201@F5@09014C4P0>40l03Q0?018D4`0C5A@04Q@C010B4@0B51<051HE00804A<B0`0B
51<01`0A4a80418A010B4@0A4a804Q@C01<E500A4a401@0?4@h2010B3`0A00lA3P0>40d03Q0=00h@
3@0@4`d03A0700hA2P0C5Pl03a8;00h@2`0A4`l0418?010B4@0A4a<04A8D018C5`0?41400P0<30X0
1P0?3`d04A4?010@3P0@40h03`l=00d=2`80410>01T03@d;00P81P071`D0410>01<C4@0;2`T03`l=
014A3`0<30X04a<A00/;2@0C4a404a<@00h?2P0>3`T051D@01DF4@0?40/04a<A010@3P0<30X03Ph>
01dM7@0S8b<06a/K00H03`l=00@03Ph<00d=2`0=3@/03Ph<0P0@40h03@0>3@/040l=00l>300=30X0
3Pd;014@3P0<2`T03`h<00h=2`0<2`T03`h<01DD4P0;2PP00P0J6AL0100>3@/020L500h=2`0<2`T2
00h=2`803`h<00X03Pd;00`;2@0=30X03Pd;010?3@0A40h04Q4?01LF500C4Q002PT70P0@3`d03P0B
4@l05aHD00d<2P0b<Bl04@l@00`:2`0I5aP03@/>00P62@0F51L030X?01DC600<2Pd03Pd<0P0:2@L0
100=30X03Pd;00h=2`0X9bD200`;2@0500@30P081`D030X;01<<4P0@2a400P0?2Q009P0>31403`dB
010>4`0<2a003@`A01DD6@061@X02@T;01@D500;2`/030`<00H61P0C4Q003`h<00/:200>2PL04Ph;
01@@3@0A30P030P600d;300<2P/0=cDf030^;`0<2P/03P`=010>3`0C4A803@/<01XH6@13@D804a0@
00/71P0L61L05A4@00`81`0I5A@03PX90P0=2@P01@0>2PT040`;010<2`0A3@/04@`900<040/800@0
4@`900l:1`0B3@X04`h;0P0>2@H09@0A30T02`L400h:1`0@30T03`/8010<2@0E4@h0:BDR01@@3@0B
3P/05A4>00<0000N6QL040l;00h=2@0<2`L03Pd9010?2`0?3PX02@P4018A3@0<2`L040l;018A3@0A
40`01`H400X91`0D4a403Pd;02@S8@0P7ad0C4]901PG5@0;2PP01PD300l>300;2PP00P0<2P/01`0;
2@X03@T:00l;300?2``030H801<;3P0J4A@00P0D2`h00`0D3Q005A4B00l=3P02010>3`0900L51P0H
5QL03P`=01@B4`0N71d02PP9018@4@0100002PP900801`D600P05A<D01dK70071@H03@/<00P61`05
0`@07Q`M00D310802`T:01/02PP900`:2`0C4A8010830040000@3Pl030X;00T7200;2@X04a4B01TG
602k^KX0>3Hg01LE5P0>30d02PP900d;300<2P/03P`=00d;300;2@X030X;00d;300=2@X03PX;00l;
300@30d00P0>2P/01`0B3Pl05A4B01PD5@0C3a0081`M00`82@0@30d00P0?2``00`0@30d04@d>01LC
500200<0000400P41@0>2P/06aLH00d:2`8020H701d02PP900`:2`0=2``02@L801DC500@3Pl02@L8
01@B4`0100003@/=00d;400B41D05Q@I01PF6`0=2a001@@800L52P0610T07Q`Q01<A5P071@X04PlA
02PR8P0R71`040X:014;2`0;1PH03@L700@00002010:2P0400l92@0X8b80W9ZK07EcM080518C00/0
0P01014?4P0C4A@02@L:018@5@0S8BH0518G014?5@0B41D02@L:00h<3`0200`:3@0404Q6B@0M6ah0
61HI00l=408030X=01D02`T<014?400?3@h01P@50040000@3Q003P`?01HD5`0?3A405A<H014?5006
10X040hC00h<4@0?3A0030X=00X82`0<2Pd03`d@01@B5@0B41<00P0F51L00`0C4A@05Q@Gooooo`0C
ooooo`006oooool07P0@2Ph03`T<01<?400B30h02`H800l;2P0@2P`03`X:010<2`0C3@d04Ph<010<
2@0@30/04@l@00h<3@0^;2d02`T:01LE600?3A004@lB00l=40091`/040hC00/9300F4AD00`0201DA
4P081@L05A0D00X82@<03@/<02403P`=010>3`0@3`d03Pd901XI5@0:2@L030X:00X82@0;2@X03P`@
00h<4@0?3A804@lE00l<4`0=2Q4040`C00T63`0921003PdE00/;4`0H62003a0F00h?4`0?3a403`h=
00l>2P0C4Pl020X701TK60051`@06ATG00<30`0G5aL00P0@41006@0@3Q404@lB014?4P0A3a<040lD
014@5@0B4AH04a8G01@C600E51T020L=00H52`0M72803`hD01HE6`0C4aD04A<B010B4@0>40h05ALD
01@F4`0A4a003a4>018D4@0I6aL00P0C5A00500D5Q@04A8D014B5P0<3A805AHK01LG800G5b40410L
01/J:00B4B406QTY01TH:00B5Ah05a`P01PL8@0F6B006QlU01lS:@0G6R405Q/Q0P0G6R<09`0F6R<0
5aXS01DH7`0H6b803a8I01TL8`0B5A`04aPN010E6`0L8bT03Q@J00`C6@0F7B<06R4W01XO8`0T:B`0
SI:F0?Olo`1BEe/05Q/O01`Q9@0H7B406QlS00@93@0J7b<04a/N01/S9P0F82805QhQ01TQ900J8BD0
5a`R028V;`0L82T07B4/01lV<00L8bd04QTS01TP:00201PO9`0C01XQ9`0K8RP06B0V01@K8@0M9BP0
5AdP010H6`0G7b806B<U018M8@0F8BD05b8V01PS9`0K9RX06RDY01/V:P0P:bl08Rda01lZ;00201dX
:P0>01LR9@0L9BX07BP/01lY;P0P:C0082Xc01XT;@0L92l07BLc01lX=@0P9cL07bTe01XU<P0J9S@2
01XV<P1401XW<00K:34072Ta01TV;P0G92X05b@[01TV;00J:2/062LW01h/;`0P;c@06BLa01@P;P0F
8c<06bPh01XU=`0J9cL072Xg01l[>@0S;ST0U9nU0<gHgP0S;C40Ae1E04eFF`0W;c@05A`R00`C6@0A
61h041LM01<J800F7BP01a0O01PO;`0L9C407RPb02/c?P0J8bh0628/01DM:00D7BX0624`01PO;`0D
6b/020hL00lE8@0N9C007B@/01PO9`0A62006B0X024X<00D6b@07bDa01@J9@0?4a`092Pa01HJ8`0G
6b@08bL`014E7P0B5Ql03A4J010D7@0B5Ql07b</018G7P0=41D2010D5`0R014E600G6ah06AdP01PL
7`0J6al04A8F01TJ7P0H6Ad05aPL02DY;00J7R404QLK01<J800D6b4051/R010H6`0H7B005ATE034c
:00P8A<0EUE705EGEP0U:Rh0@DI:02DZ<00F6b403a@J00dA6P0A5Ah051PQ014E800?4ah05ATT010C
70804aHO01L04A@K018E700C5Qd04aHM01PK800;3Q<0C4mD08^>T`0D5AT051DG01HF600E5AL03@d?
01DE5`0A4A<03`lA00d=3`0N7R005ADG00h>400E5AD0418?018D4@0201@F4`0M014C400@4Pl05aTF
00d?300F61D04A<@01@F4`051`@05QHF01PJ6@0C51H0QHZ=0<76bP0b=c/05AXN010E600A5AP05ALG
01<C4`0A4A403Q0?014C4P0@4Q404aDD010B4@092`X04A<B01<E500B51<00P0@4Q400`0A4a80418?
018D4`0301<E500401@E5P0C5A@04Q@C014C4@<0418?0`0?4@h200lA3080418=00`03a4<00h@3@0>
40d03Q0=014C3P0@4``04QD>01DG4@0>40/04A<>01@F4P0?4@h2010B4@804A8D01P04A8B014A3`0A
4@l051@B01HF500E5A<04a<A00h>300=3@/051@B01LG5@0C4a40410>01XJ600e=3804a8@00T91`0?
3`d04A0>01@D4P0:2@L03@`:00X:200E518200`=200601@E400E5Q403a0;01<C4@0@40h04A4?0P0?
3`l00`0C4a<05aLF00l?3@0500l?3@03014A3`0@40h03`l=00<03@d;0P0A40h04P0?3P`03Pd;00l>
300C4Q004Q4?01<B400<2`T02@P601`K6@0f=C<01@@202`[:@0h=cD08R4O00/:200=30X03Pd;00l>
308040l=00H03`h<00h=2`0>3Ph0410@018B4P0C4a<201HF5P0R010@400F5QH01`L701DE5@0:2PX0
3Ph>00`;2@0510805A@B00`;2`0A3a0040h?01@B5@0610L03@/>00/9300L6Ql01P@700l=3@0=30X0
3Pd;010?3@0>3@/030/902HU8`0J6AL081lM010?3@0?3P`05Q@E01@?4`0A31003`X>00h93@8030X=
02L01`H801TI6`0A4A<01@D700d=3`0B4Q@02PX:00T7200D4a@0108300d<2P0>3@/020L500P40@0=
2@H04`l<018=2P0@30X02`T:00`:2`1^K6d0I69S01DC500;2@X09B<T0040000A3a000`4200l=3P0A
3Pd040`;02XV9@0P71/03PX901hJ6@0C3`h03PX9010<2`0A3@`00P0;1`H00`0@30X040/800l:1`03
00h91P0Q014<2@0E40d04`h;00/60`0<1`@04`h;00`81@0?2`P04Ph;014=300B3Pd061@C04m;BP03
00003@T800/71P0I5A@0FeMF01<B3P0?3PX030/700h=2@0?3PX030/700T8100@3`/020L300`;1`0>
3@T02PT5010?3@0<2`T05A@B00802`X800L03`h<01LF500920H061LE00`;2@0>3@/040l=00803@/<
02L03P`=014=3P0D41405A4B02<O800>20X02@<501PB500=1`T050h@018>3`071PH04Q0A00T7200F
51D01P@500h<3@0i=cP04Q0A00L51P0A3a0040h?00`:2`0=2``0518C02h/;@0g=CH030X;00X82@0F
51D020H700<10P0H5QL020H7010>3`0=2``020H700h<3@0;2@X00P0?3@h0300@3Pl03`d>00h<3@0@
3Pl04Q0A03/i>P071@H04Q0A010>3`071@H04Q0A00`:2`803@/<00D02`T:00`:2`0=2``03PX;01DA
4P0200l;300800`82@0>2P/04@d>01<?40050@80=C4b05MCE00@30d300l;300<014=3P0B3Pl0=C4b
020L7@0F4Q<04@d>00P41@0H51D02`P900d;300?3@h03P`=0P0<2P/0BP0>30d02PP900`:2`091`P0
7A/L00d;300@3Q0020H900P62`0?3A402@L:00d;400@3Q802@L:018@5@2IUi/0LW1c00L52P0;20X0
40X:00d71`0C3@d04@/;01<=3@0A2`d0618D018<3P0G4A<02@<5014<3P0L6Q/08AlP00h<3P0G5AP0
20H900d;3P0;2@`00@0200`:3`0Q7b@040hC00d:400C4A@02@L:00d;3P0;2@`071XM08J4Q`0U8bH0
7adP01<A500<2Pd02`T<00X82`0A3a801`D601hL7P030@@05A<F00800`0A3a803@/?00X83@0;2@h0
4@lE01PF6`0@3Q403@/>00T72P0;2@`03P`?00/9300=2`h030X=0P0@3Q400`0=2`h040hAooooo`0C
ooooo`006oooool04P0>2`T03P`:00@30@0C40h051<@00/:1P0C4@l06aTF00d<200@3@X07Q`I01DC
400<20L04@d=010<300?2``04PdA010;4@8040/B01d04`dH00h8500>21D050hI014:3P0A2P/04@X:
010;2`0@2P/040/:010<2P0=30T030/800X91P0<2`H03@`800h=300?3@d030X;00X92`0>31004a4F
010=4`0?31@03@XB00/84@0>2aD04@hH010=5P0200l<4`0B00l=500@3a@04A0E010?4P0K6Q/01`H6
018A3`0>3@T0310:00XC2`0;4``03aD?00`?2`0;3@X0410>010?3@0A3`d050l@0P0F3a405`0E4AH0
3@`C01HE6`0U92X051<I00d<4@0A41@04Q8D018B4`0C4a<04Q8A018B400B4a004A<@018D4@0D5Q@0
4Q@C01/M700N82004Q@D014B5@0D5AP05AHI00804a@G01T04a@I01TJ800K6b@05aLQ01TI900H5b@0
61LU01DD900F5BD06aXZ01HE9@0S8b`06Q`Q01HH7@0G61d04aDJ01LH7@0C51T06A/P01HH7P0K7280
5aTO01PI7`0C5aX05ATK00804aLI01405a/M01HJ700I7Al061`N01HJ700C5aT05AXL01hR9@0H7B80
7R<X04I;D@2;T9L0:Bde02hc>P0E6R4061dU01TM9`0201LK9@0@01HM9P0C7bH04alX01HN:00F72L0
6a`Y01lN:`0R8Bh07Qh[01`N:`0L82`06b0/01LN:@0M92d07B@/01PO9`807B@/05d07bH^01dT;00J
8BP05ahU01HM900H7bH06R4X01/S:00L9BL082P]02@/<P0[<cX08RXa01/S:@0O9bd07RLY01/T900N
:2H08R`Z01lX:@0O9bT08b`^01lW:`0I82H07bL^01dU;@0O9S007bHa01lU<@0N93407BD`020Y=00N
:3<07RPb01lY<`0K9Bl06B<]020Z=00G8B/08R`e03Q2B`0G8BX07RPa01HQ9`0L9Rh072L`01TS;P0H
8Rd062<`045;F@0L9CD072Hf01PR<`0U;Sl06R8^02/a=`0]<cP05ahQ01LM800K8B@05ahN01PN7@0G
7A`05A/J01@J6@0F6ad0>3i7061WN00E6Rd05Q`/014H9`0C6BP05A/Z01@K:00G7B/061h/01@K:@0B
62H051`V01HO900D7B<05QlU01PQ:00F7bL04QXT01XR;00F7RX08BTe01<K:00H7bd061`W018F7`0D
62400P0c=d00200C5b006alX01@F7`0D62406QhW01HJ8`0D62005AXM0P0D6QX201DI6P0:01LH6P0E
5AL05ADG01HE5`0H51P06ADI01XH700K72406A`Q01LJ7`805QXN01l05QXO01PL8@0L7b@051PL01/M
7`0I71h08bHX0495D00k?DX04A<O01LI900B5Al04aHO01@G7P0B5A/082<Y01TL8P0D5a`051PL01HG
700C51T04Q<H018C5`0B4aP051DI01DF6P0B4aL03@hB01TJ7P0G61`06a`P00804A8D0P0B4aD08P0E
5QP05aPJ01@E5`0F5aT05AHH01@E5`0E5QP061TK010A4P0D5QH05AHG018C500A4a<04a@E00h@400M
7al020X:01@F5P0@4A804A8C018C5P0@4A@0824U05YLG`1jOH007b4U01DG6`0D5QX03PlC01<D600A
4QD02``?010A4@0A4a82018D4`1<010B4@0?4A004Q@C010B4@0L7Qd07AlN00h@3`0=3``05AHA018B
400A4A404A4B01HF6@0@3a@0410B014A4@0B4`l04Q<<018C2`0A4Pd0410A010@400@4@d04A8<018C
2`0A4PT04A8:01@E3`0E5Q804Q8B00l?400A4A003@h:01DE4P0@40d04a<A00X:200A4@l0410>014A
3`0B4Q004A4@010@3`0A4Pl03a0;00h?2P0D5A005aPC01@E400@4@`02@X500l@2`0C50l0>CXe02X[
9P0;2PP061DD028O7P0>2PT04Q0>01DB4@0C3`h040d<00l<2`0F4Q404@l=010=300T9280?clm02/[
:@0:2PT02`/9010@3P0D518030`:01TI5`8030`:00L051@B01DD4@0@3`/05A@@00L60`0l>cL0=SDa
008040l;0`0?3PX00`0=30P03`h<00`;2@0201@C4@0300h=2`0C4Q003`h<00803`h<00@03Pd;014@
3P0D4a403Pd;0P0C4Q00600A40h03`h<010?3@0;2PP03`h<010?3@0?3P`03@`:00d=3@0R8bD0:bh`
014C5P062@/02`d@01LI7017BT`0YJNY05AGF@0<3Q407R4S00T:300>3@h03P`=00d;30803P`=00/0
3`d>00d;300<2P/04a4B00`:2`0@3Q0030X;01<A4P0>30d03@/<00l=3P02010>3`0L01TG600F51D0
1P@500d<30091`P07A/L024P7`0>30`02@P7010>3P0>3@`02PT801<A4@071@D03Pd<00`:2P0E4a<0
2PT800d;2@0L61L05A8A01DA400@30/04Ph=010<2`0?2`X03PX900l;2P8040`;00D02`L600h:2@0C
3`h06aLF00/71P0200l;2P0700h:2@0?2`X040`;010<2`0=2@P05Q8?014=2P0201<?300900`81@0D
40d03PX700d91P0?2`P04@d:00l;200>2PL04@d:00<03PX701/03`/8018>2`0@30T03PX700d91P0?
2`P04`l<010=300C4Q0081lM00d;300>30d09R@V06MUI`0B418030X>00<11@0=2`l040hA00/:2@0A
40h03`h<00P71@0;2PP040l=00`;2@0=30X00P0?3P`01@0>3@/03@`:00d<2P0=30X03`h<00804Q4?
00<03Pd;00`;2@0<2`T0100<2`T0200=2``030X;00d;300>30d03`d>00d;300?3@h03P/<0P0<2@X0
1P0>2``040d>00l=400;2@`03P`?00l=40802@L:01@04a4D00`:3@071@P04Q0C00h<3`0A3a802@L8
00/92P0=2``03`d>014?40091`P03@/<00`:2`0=2``04@l@00h<3@0;2@X03@/<00h<3@803`d>00D0
3@/<00`:2`0A3a0030X;00h<3@0200l=3P0H01<A4P0?3@h04@l@010>3`0=2``030X;00d;300C4A80
4@l@00d;300;2@X030X;00h<3@0@30d01P<301TE5P0B3Pl020@5014=3P0@30d04@d>00h:2`0@30d0
4@d>0`0>2P/300l;300b010<3@0?2``040`=010<3@0>2P/03@T:00l;300>2P/03`/<01DA4P0A3@h0
3`/<018>3`0<20T02PH700h:2`0=2@X02`L800h;300;2@X030X<00X82P0B41401P@600l=3`0:20T0
5A<E06ITIP0g=CH05A<E02/X:@0I5AH03PX;014=3P0=2@X03`X=01<>4P0J5AT050lD00/62`0@2a00
3PT?01<A5P040PH0518F01DC600A3a@030X?00d;400>314200l=4P803P`A01403P`?010>4@0=2`h0
3P`?01DC5P0L6Qd030X=014?4P0?3A002`T<00l=400@3Q4040hB01LE6@0A3a<04Q0E00l=4P0201<A
5P0A00l=4P0:20d02PP=00d;400@3Q<0518E00d;3P0?3A0030X=01<A500<2Pd02@L:014?4P0>30l0
0`4400h<3`0<2Pd05?ooool001_ooooo01T04a8@00L6100E51803@`:00H50`0J6AL07A`J01lN700?
3P`02PT700l>30061@<02@D601@@4P0>2@d030L;010;400300@03PT@00h94@0C3AL03`TD00`64P0@
2a804@P;00804@P90`0?2@T0100>2PT03@`800d<200>3@T200d<200:00D40`081PL04@l@01XH6`0B
41D02@L<01<@5`0>2a@030TB00d:4`8030TD00@03P/C00h;4P0>2a803`dB0P0@3Q<0?@0<2`d03`d>
01XH6@0D4a402`X8014D4@0D7AP0?TA002db<0031`H04A<B00l?3`0@3Pl04Ph?01@>4P0E3a<05`hC
01`G7@0E51X03`hD018A5`0B4AH04A0E018A5@0C4aD04a<C01<C4P0A4@l0410>01LH5@0A4a002@/:
00H81`0M7ah0HfAV065RI00E5QP04a@H01@E6@0G61`061TM01PI7P0?3aL04A4I020P:P0O7bT04Q8L
01HF8P0D52005A@R01HE9@0D4b<05A@S04Y:DP0b<cP05aPM01PI7P0K72406AXO01@E6P0M7R<00P0I
6Ql01P0B4aP030dB014E600D61/04aLJ018F6@805ATL02H06QhQ01PL7`0G6ah06AdP01/O8P0L82<0
3A8H028V;`0?4a`05a/T01XN9`0<41T06AdX01DI900J7RT08RHa024U<00D6bD05b4[01LR;00F7RT0
51XV01XK:00Q82h07A`Z024Q;`0Q9C407b<_01TP:`0G7bX061lY01lV<01FGFL07RD_01@K9@0M92h0
72<]01/R;08061lY01006R4[01/R:P0K8RP061lT01`S:@0L8b/08RTa01DL900J8BP06R4W01/S9@0L
9BD07BHS01hW900P:BT041PK0P0M9BP0;P0K8RP061lU024X<00N9Bl07B@^01hU;`0P9S8082Pc02D^
>00O:C<07RPb01dW<@0J92h0628/01dW<@0?6B<06B<]02li@`0E7bT05R0Y01hY;P0H8bT05R4W01LR
:@0I8b`06B<]04iHH`0M9c<04a`[01@M;00L9C@05alY01LL8P0F6al061dQ01DJ7@0G71l06R0P01HL
700D6QX041HF014G5`0F71`0CUAL07=iQ`0P9SH200lE8`0F01@J:00E6bT05adY01PN:P0E6bL04QPT
01@J9P0J8RX06R<X01PQ9P0H8BL05b0W01DN9@0@6B407bPa00`D7`0E7BT04ATV018J9P0=4A`04QHO
01@H8@803Q8K01004aLP01`P:@052A808BD^00L;500>4Q/09b/c01TN8P0E6Qd04AHI018F6@0C5aX0
4a@H01PG700G5Q/05QDJ0`0F51T0100K724061/P01LJ7`0F6Ah201LJ7`0U024T:@0>4AH09BP]0495
BP0H6b005QTO01HH900E5b@06adZ00`>6P0E62805QTR01DH7`0G6R004QDJ00/>4`0H6al04QHI01TJ
7P0@4AD06AXN01LH700B4aL0:2T]01DF6P0C51P051DI00/<400@4AD04A8F01<D5P0D5AL03a0B00`=
3`0J6ad0;2d_014B5002018C5@0N014B500B4aD05AHH01@E5`0>3a403@h@018C5@0A4Q@03PlA00`=
3`0>3a405AHH01PI6`020`D07b0R01DF6`0F5a`061TN00X;400C51T0414F00D62`0A4QL08b@Y00l@
5@0L7B805aPL014B4`0@4Q403a4@0P0@4Q40600A4a803@l>00h@3`0G6AP05ALF00lA400B51<030`:
0000000;2`/04a<E01PG700>3A404A4A014A3`0B4`d04A8:010B1`0?40/03Ph@00h>3P0>3`/03a0:
010A2@804A8:00H04Q<=018C3`0A4A40410B010@40092@L200d=2`05028R800B4Q003@d;014A3`0?
3`d00`0>3P`01@0@40d03a0;00d>2@0@4@`04A8=00803Pl:02L0004001<D3`061`80004001@E400G
5Q@020L5014@3P0D4a403Pd;01DD4P0B4@l06QTG02<R800J6AL01@@201<B40020P006a/I00X:2@0D
5180<S8`01/K6@0;2`T03Ph<01<C4@0<30X061PF01<C4@0>3@T061LC00h=2@0C4Ph03`h:01@C3`0B
4@d040l;00h=2@0@3`/00P0D4`l02P0920H04Q4?010?3@0A40h04a8@00P71@0>3@/04A0>018A3`0@
3`d200h=2`0=00`;2@0?3P`040l=00l>300>3@/03`h<00`;2@0?3P`040l=00h=2`0=30X03@d=01hO
8@0202LX:P0<00X;3@0I6Q`06Q/M05]LGP2e][P07b0R07=dMP0U9RP09bPZ00h=3P0>30d03@/<0P0>
30d0200?3@h04a4B02@R8`0A3a0040h?00X82@040P<03`d>0P0<2P/06`0>30d040h?00l=3P071@H0
20H700`:2`0Z:2T04Q0A00@20`081`D03Pd;00l>300<2`T02PT700/:20071PD05A@B014@3P0<2`T0
0@0001dL6P0>2`X030P701dI600H51<040`;01@@3`0200l;2P0@010<2`0?2`X03`/:00`81`0S7ah0
3PX9010<2`0A3@`020@3014=300?2`X040`;018>3@0@30/03@T8010<2P807a/H02L06QHC01<?300C
3``061@A010<2@0?2`P040`9018>2`0@30T04@d:00d91P0?2`P03@T600`81@0B3P/03@T6014=2P0B
3P/03@T600/7100@30T030/700l>2P0G5Q<04A0>01@C4@071PH01P@500<10P0C4A@00@0200X82`0>
30l040h?00d<2P0>3@/03@`:00X91`0;2PP00P0=30X300`;2@0700d<2P0>3@/030/900d<2P0?3P`0
40l=00h=2`0600`;2@03010>3`0>30d03P`=00803`d>00@03@/<00l=3P0?3@h03@/<0P0<2P/0400;
2@X03`d@014?4P0;2@`02@L:00/9300610L00@0201DC5P0?3A000P0300X92`0<2Pd02PP901HD5@0?
3@h200`:2`0:00l=3P0=2``030X;00`:2`0=2``02`T:00T7200>30d03@/<00`:2`803@/<01l03P`=
00`:2`0=2``03`d>00`:2`0?3@h05aDF00/92P0>30d03@/<00/92P0:20T02`T:00`:2`0100003@/<
01DC500B41401@<4014=3P0D41401P8300/8200300006aLH00h:2`0@30d03@T:010<3@0B3Pl03`/<
00803PX;1@0?2``0200>2P/03@T:00`82@0=2@X020D500D10P060P<02`L80P0D4140900E4A805Q8C
01@@4@0A3@h02`L800h:2`0>2``03`d>00@20`0A3a002`T:00P61`081`L061HG00`:2`0:20T03P`=
01<A4P0D4A8030P900/7200:1PL03PX;00l:3P070PH03PT=00d83P0:1@/04@`B01<>5@081P/0D4iC
05aJG`0100@07Q`Q01TG70803@/@0`0>31400`0=2a004Q0C014?4P0200/9300@00l=400:20/030X=
00l=400>30l02PP;00`:3@0>30l00@0400P62`0=2a001@<8018@5@081P/03P`A00d;40802`T>0P0<
2Pl00`0>30l030X=01@B5@02010>4@0700P62@0C4A@02PP;01TG6P030@@030X=01@B5@0Dooooo`00
6oooool02@0;2PP08b8P0040000100004a8@00T81P0100003@`:00h=2`0200d<2P0>00D3100>2@d0
5a8G00`72`0=20h061<I00d83P0@2a803PT@014<4`0?2Q403@P?010;4@0C2P`201<:2`<04@/;01<0
40`;00l>2P0A40`04a8>014@300?3P`05A<D00/92P0P7Ql0@3i102d[<00B41D05Q<J014>5`0@3AH0
4a0I018?6P0?31D03@XA008030T@0P0>3140700?3A806aTL00P61`0B41403`h<00/:20031080624N
09:HUP1ZKfl0004001hO8@0?3a0040hA018=4@0D3Q805@lC01L>4`0I51/05QDK00l>500=314040lD
014@5@0@3a<0410B014A4@0C4a8201<C4@0P014B400?4@h05aTH01XL6`072@P02``>01PI6`0E5QP0
4a@H01@E6@0G61`06AXN01DE700A4AT06a/S01XJ900C4ad051@N01DE8@0B4Qh05A@R01HE9@0B4B40
5QDT024Q:@0O82D06AXO014B5`0@4AH061TN01dN8`0W:2d2020Q9P0G01`M8P0H6Ah04aHK01LK7P0G
6Qh051LL01LK7P0F6Qh05QTN01<G6P0B5QX05aXO01PL7`0F6Ah05a/T028V;`0J7RL05QXS024U;P0B
5Ql0720[01HJ9@0I7BP00P0Q9C00;@0E72H05AlY01@M:00D72L05adY01/N:`0L7R/05aTV01lR;P0P
9S807B<_01HO:P0E7bT04ATT01`S;P1LHfd07R@`01TP:`0K8R`06R0/01XP:`0H7bT061hZ01TO:P0J
8B/06b8X01@L800G7R@051/S020W;`0D6b<06R4Y01TP9P0K8bH07RHW01dV8`0L9B@072@V03Dm@00J
8RD07BDX01dT:P0P9bd08RTa01lV<00201hU;`0401lU<@0O9c8092dh01hX<P807BLa00D072H`01/U
;`0P:S@07RPb01HP:P02010J900E02La>P0M:2d06bHZ01dX;P0O:S006bH/01LQ:P0@6R@07BLa01PR
;@0=5b<05Al[01/R;00K82H07B8V01lT:00J7b<061dQ01HK7P0D6QX04aTI00804ALG02/05A/K01PN
9@0X;SX041HT00hD8@0631P04QPV01LM:@0F72P06Al[01DK9`0B62@05A/W01PP:00G82D05QlT01DN
900D7B@04a`S018K8`0G82T031@O024Y=@0B6RL051/W00X>6@0W:c@05ATR014E7P072a@05a/T0002
2`16BU<03Q8K01/O:00B5Ql0A4U@01dR9P0G71l041DH010D5`0A5AP03a0D00805QDJ01h05A@I01DC
600F51T05QDJ01LH7@0E61d051LL01<F6`0D5a`05APM01XM8P0L7b@04QDJ01LJ7`0E61d06QdS01PJ
9P0D5R<05aTU010B7P0B5Al06QdV01DH7`0E61h05QTN00hA5P0E61`04ADH01TJ7P0C51P201LH700C
01DF6P0O82@05QLK01<D600H6Ad02P/?01DF6P0?41@03a0B01@E5`0C51H04A8D01DF600L7Al0414C
018C5@0A4Q@0414C014B500201@E5`1c010A4`0?41804Q<E00h?4@0;30h04A8D00H72@0A4Q@03@h@
01lP8P0?41@05aPM01<D6@0:2a0061TN01XK800B4aP061TN014B5`0H6Ah03a0E01HG700S92P04Q<D
00lA400>40l03a4@014C4P0B51<03Q0?014C4P0E5aH0418A00h@3`0D5QD061PH01XJ6P0K6ad061PJ
05mNH`0<30h04A4A014A3`0A4P/0418700lA100?40/03`lA00l?3`0?3`d03a0;010A2`0A4PX04A8<
014B3@0@4@h04A4A014A4`0?3`l04Q8@01dM6`0?3`d07AdK01<C4@0A4@l04Q8@010@3P0>3P`03@d;
00h>300?40`03Pl:00d>2@0?40/0414<00h?2P0B4`h030d8010A300>3`X05aPC01PI500G5Q@03@`:
01HE4`0J6AL03Pd;00/:200C4Q006aXH08V8QP17AT@07A`J00d<2P0I6AL051@B00l?3@0G5aD02PX8
00@40`051@<02PX8018B400?3`d0410>00d=2`0510004Q4=00/:1P0D4`l04Q4=010?2`0510003@`8
01@C3`0200d<200301DD400>3@/04Q4?00803`h<00<05aHD01/J600?3P`00P0B4@l2010?3@03014@
3P0<2`T03Pd;00803`h<0P0@3`d00`0<2`T03`h<00l>300200h=2`0@00h>300820X02``>018C5@09
2P`04A8D00D6200J6ad0=cPj02X[;@1TIFL0=3Dg00000P0?3@h03P`=00d;30803P`=00P03`d>01@B
4`0A3a001@<402DS900L6Q/05Q@E00`:2`802PP901003@/<00l=3P0>30d04@l@00l=3P0J61T0KF]/
01HD5@091`P03`h<010?3@0=30X02PT700h=2`0B4@l02@P60P0>3@/05P0?3P`09bHT092?S@10?3/0
2`L601HB4@0G4a802PH500l;2P0>2PT040`;014=300@30/03PX900d9200o>cX08alN00`9200B3Pd0
40`;018>3@0@30/2014=300;00l;2P0=2@P03@T701DA3P0G4a004Ph;00d91P0?2`P04`l<010<2@0?
2`P00`0@30T0700C3``02`L400d91P0A3@X04`l<00d91P0:1P<030P5010<2@0?2`P03PX700l;200<
2`L02`X600L610030P004a8@00d<2P0<2`T04a4B00h<3@0<2Pd04Q0C00T72@0?3P`02PT700`;2@0@
3`d200/:200500h=2`0=30X030/900/:200<2`T00P0>3@/00`0<2`T02`X800d<2P0200h=2`H030/9
00P04Q0A010>3`0?3@h040h?00l=3P0<2P/02PP900`:2`@03P`=01803@/>014?4P0:20/01`D801<A
500O7B003@/>00H41`0200<09B<V00X82`0F51L04@l@018@4@0100001`D600`:2`0>30d200l=3P0A
00h<3@0?3@h03@/<00d;300?3@h030X;00/92P0<2P/03P`=00l=3P0<2P/03`d>010>3`0:20T03@/<
01DC500<2P/00P0?3@h05`0=2``030X;00d;300A3a004Q0A014?40030@804Q0A014?400F4Q<04Ph?
00L3100F4Q<05A4B010<3@0B3Pl04`l@010<3@0B3Pl04`l@010<3@0?2``03PX;00<040`=00H03`/<
00h:2`0=2@X03PX;014=3P0D414201TE5P04014=3P0=2@X0510A00h:2`801P8300T02PH701@@4@0A
3@h030P900D30`0A3a003P`=01XH6@071@H00P0;2@X06@0=2``02@L801TG600:20T03`d>018?400;
1`P03`/<00/7200A3@h04PdA00X52@0?2Ph03PT?00X52`0>2@l040/B01XH7@0<2Pl04Q0E00l=4P0T
8RL0108700`:3`0=2a000`0>3140500=2a002@L:00`:3@0<2Pd03P`?018@4`0?3A002`T<00d;3P0>
30l030X=00d;3P0@3Q404a4F00d;400@3Q<00P0501<A5P081P/030X?0`0=2a001@0<2Pl02`T>00l=
400;2@`04a4D00803P`?00L02`T<01@B5@081PT03P`?00T72P0>30l02@L:01Cooooo000Kooooo`0E
01<B400V9B<09bHT03hm>`0=30X03`h<00T81P0>3@/03`h<00h=2`0?3P`04a4B014<4P0B3A@03@P>
01D@5`0Y92X0:RD[01@?5@0>2@h03`X>00803`/>00@04Ph@01892`0B2@X04PT:0`0@2PX04`0A3@`0
3@`:00l>300C4Q0040l>00h<300>30l040hA00l=400<2Pd03`dB01<A5P0C41L04@hE018?5P0E4Q/0
514J01<@600@3A@00P0?3A804P0A3a@04Q0C018@4`17ADP08R0Q01HD5@0Y9bP0=38c014B500:4180
51XL01<G6P072`d03@hB014?500@3Q<04PdC01@>50805@hE00X040`C010?5@0E51T05QDJ00h=4P0=
3@l04A4C018B500B4Q804a<C0P0B4Q801`0C51@061XI01DG5P0?4A005aTH01LH6P0B4aH00P0C51P0
2P0B4aP04a@I01LH7@0F5ad05QHN01hN9P0M7BL05QHP01LG8@0F5R8201DE8@0L01PG900I6BH05aLT
010@600F5a`06Q/P01DF6`0F5a`06Q/P01@E6P0N7b@05AHK01@E6P0G61d061TN014D6P0G6R006A`S
01@G7`0E61h05APO01PK8`0F6Al05QTP01PK8`0I72805aXR01<G8@8061`W01<05ATT024U<00E6B@0
6alZ01PL9`0E6B@05QXU01TM:00I82X06R8]01@L9`0E7BP06b4]01/P;00C62@05Q/W01XQ;00J8bh0
5R8[00804QlX00L072@`01TO;00T:SL02Q0N01`R<00I7b`05Q`Z00805adZ01`05ad[01PN:`0H7RT0
82L^01TP9@0N9B/07RD]03<j@`0_=T006R4Y01/R:00M9BP07bPX01hW9@0M9RD07RHX06A/K`0O9bX0
82L]01HM8`0P9bd07bH^020W;`0Q:30082La01`S;@0J8b`07RLa0P0K9Bl07P0O:C<082Xd020Z=00K
9Bl07BLa020Z=00N:3805AlY01@N9`0I8RH051hP01DN8P0I8RL06b@Y01XS:@0L9B`06b@/01DN9P0H
8BX04QXS01DM900P9B/07b@Z01<H7P0I7R<07B8W01DJ7`0C61/05AXN01DJ7@804QPH00<05Q`Q01DL
9@0@5b800P0C6R@0200H7bX04QTS01<J900F7BL05ahX01DL9P0D6bD051/S0P0E72803P0E72<05A`T
01DL900I82T03A@N02<Z=01?EV0092Xe01XQ;00P92h0C51I014E7P0N8R/03A4J0P0K7bP2010D7@06
00`?600P92d0=c]301@I7P0B5a/041DI0P0B5AX02@0A51T04Q<H018C600C51T051<I01HE6`0H5ad0
5QPM01DH7@0301@G700I01HI7P0H6b0041<H0454B@1JGF807b8W01TL8P0C5Ql06A`W018D7`0[;CP0
61/T01TL9@0G6R404QDK02LZ;`0P8bP051LL01HI7P0A4QH05AHJ00l@500F5a/07b0T00h?4`02018C
5`0901@E6@0?41@06Q/O00d>4P0D5AL04Q<E014B500C51H051DG00804Q<E02@051DG01<D5P0B4aD0
4a@F01HG6@0>3a404a@F01HG6@0E5QP04a@F018C5@0@4A<05QLI00X;3@0T9BL0UIJH02HW:`0B4aT0
410H00h>5P0B4QX02PXB00l?5`0D51`07AdU014A6@10@4P03@dE018C600B4a@0418A00lA400@4Q40
4A<B018D4`0C5A@201DG5P0W00lA400@4Q404aDD014A4`0C4QH0MWEj02/Z;`0C4aD04Q8C014A3`0A
4P`04A8:00lA1@0?4@<04A8;018B500A4A404A4?010A300A4Pd04Q<=014B3@0@4@`0414?014A4@0B
4Q@04A4A01`L6P0^;R`04a<A014A3`0>3P`05ADC01@D4P0B4Q00410>00l?3@0@40h03a0<00803Pl:
01d0414<018C3P0C50l05QLB01<D3`0>3`X04Q<>01LH4`0@4@`020L501@C4@0A40h030/9010?3@0A
40h05aHD01TH5P17AT@07ahL00P71P0C4Q002`/:014A3`0:2PP03`l=014A3`0?3`d04A4?00h>3002
010@3P0400L71@0S8b40?C`h00`;1`803Pd900h03`h:014@300T8al06aXF00l>2P0@3`/04a8>00h=
2@0F5A<03@`:014@3P0>3@/05A@B03He<`804A0>00D040l=00l>300C4Q006APF010?3@0200l>3006
010?3@0A40h04A0>00h=2`0?3P`03Pd;0P0=30X0400@3`d03Ph?01<C5@092P`030d?00`<3P0@4A<0
1`P:018C5@0E5QP0EUMI01TJ700?3a403`d>00h<3@0=2``200h<3@0D00l=3P0[:BX04a4B00P61`0D
4Q<02@L8010>3`0?3@h03@/<00h<3@0A3a0040h?00l=3P0:20T0518C00`:2`0W9BH040h?01HD5@0>
3@/200/:200M00d<2P0>3@/03@`:010?3@0A40h03`h<010?3@0@3`h0BDQ602HR8P0;1`H040`;014=
300;1`H04@d<00l;2P0@30/04@d<010<2`0?2`X04`l>01TE500C3`h03`/:018>3@091@@040`;014=
300?2`X00P0>2PT0100?2`X04@d;00d91P0A3@X2018>2`0301DA3P0?2`P03PX700803`/800D03@T6
00h:1`0?2`P04@d:00l;200200`81@0F014=2P0@30T03@T600h:1`0G4a006QHC018>2`0<2`H040l:
00d<1`0;2PD04Q4<00/:1P0920@03`h;00L6100E4a<03@`;00/:2@0<2`T02`X800`;2@803Pd;0P0=
30X01P0<2`T02`X800/:200;2PP03@`:00h=2`8030/900<03Pd;00l>300?3P`01P0<2`T01@0A3a00
3`d>00l=3P0@3Pl03`d>00<03@/<01/03P`=00d;300=2``03@/<00`:3@0>30l08R0S01hL7`0C4A@0
;bd`01TG6P0:2@/06aTL06QVJ@0B41<02@L:00d;300G5AH02PT901@B4`0A3a001`D600`:2`0>30d0
3@/<00`:2`0>30d00P0?3@h01P0=2``030X;00d;300>30d03`d>00h<3@8040h?00@02@L800P61`0?
3@h02`T:0P0>30d03`0=2``030X;00h<3@0=2``02PP901LE5P22P84071XK01HD5@0=2@X081`M04U5
AP0@30d04@d>018>3`0201<?40<03`/<0P0>2P/00`0<20T03PX;010<3@0200h:2`<03`/<01<040`=
014=3P0F4Q<061@E01DA4P0>2P/02`L800l;300B3Pl04@d>01@@4@0A3@h05A4B02/W:00W92D02@P8
01HD5@0?3@h02`T:00803@/<01L03P`=00T7200V92D02PP900L51P0=2P/030P9018>3`0;1`P03`/<
00l:3P0>2@d040/?010;4@0=20h03PT?014<4`0<2Pl061HK018@5@0=2a001@<800l=4P0200`:3`80
3P`A00D03@/@00`:3`0610L03`d@01@B5@0200`:3@0400h<3`0<2Pd030X=00h<3`803`d@00T0518E
05UGG00G5AX020L;01DC60071@X04Q0E00d;400>31400`0?3A802@0>3140518E00`:3@0C4A@030X=
00h<3`0A3a803P`?02LU:00200l=400300X82`0<2Pgooooo01?ooooo000Kooooo`0700D3100^;2d0
81hO03Hd=@0E4a@0108300d;300200T7200=00P61`0>30d081hQ01XE700B31L05Q0J01TC7@0E41L0
4`hD018=4@0?2Pd0510?01DA400200l;20<04@P90`0?2@T04`0B3Pl02PP900/92P0?3@h03P`?00X8
2`050`L03@/@014?500@3Q<02`T>00P62`0?3A804@hE010=500?31<03P/B00l<4`0=2Q000P0<2Pl0
4P0=2`h03P`?00l=400K6A`030X=00<1100D4QD09bDX010@5@0C5Qd00`H=00X<4`0E5Q/05A@L01`K
8P0?3Q@040dD018>5@8050lF00@05Q8H010?500@3a@05QDI0P0;2`d0?@0E5AL04a<E01<C5@0C4aD0
4A4C010@4P0?41404aDD01DF600A4Q@04a@F01LH700E5QX04a@H01DF6`0C51T04A8G01<D6@0F5Qd0
410H018B6P0I6B<05QHP010@6P0H62806a/U01@D7P0I6B<09RH`01XJ9@0E5Ad05AHK00l@5@0>3a@0
51DJ014B5`0Z:c00=CHk02HW;00N7b@07b0U01XJ8@0?4Q/05aXS01XL9`0C5B404aHO01@F8@0E5b<0
5QTR01HH8`0C5B404aHO01HH900J7RT0720/018F8P0H72P06QhZ01`P;00E6B@00`0D62<05`0H72H0
6alZ01TO:`0H7RX05Q`X01LM:@0L8Rh082Pc01/S;P0G7bX04adW018O:00C8BX0524Z01DM:P0L8S80
7R@d01`R<P0M8c<03Q@T01DK:`0F72`05ad]008061h^01<061hZ01TP:00F7B@06R4Y01TP:P0X;cT0
8bXd01LN9`0N9B/07bLZ01`T9@0L9B@07BHU01`T:00J8BL072<Y02<Z<00J8BL06b8X00<07RD]01h0
7B@/01/R:P0I8R/0624[01PR;00K9Bl07bTc020Z=00O:C<07BLa020Z=00N:3805R0Z01hX<P0N:340
6R@U01LQ8P0E7b0051hP01TS9@0M9bT03QPJ01`U:P0E7R<06R<X00hG700F7B<05AXP018F7`0D6242
01TM9P0`01HJ8`0F6b405a`R01DJ7@0A5QT041HF00lE6P083aD06R4Y014H7`0:4AT051/S01<J8P0A
62003aHN01<J8`0F7BL051/U01<J8P0G7R@061lU01HM900D6b<05A`T01XQ:@0A62006R4Y030g?`0G
7RH07B@]00D94P0T:3404QHO02<W<00E6B804aLP01DI8P0A5Ah05QXS014E7P0?4a`02P`E00d@5`0B
5A`05QTP01<F7@0A51/04aHM0`0@4aX00`0C4a/051@L01DE7@0201@G700D01<F6`0D5a`05APM01HI
7P09314041<H02T/<@0d=c`051LL00d@5@0@4aX05aXR01HI800Y;3<09RT`01@G7P0C5Qd04QDK01lR
9`0I724201LJ7`0C01LH700H6Ad051DI01XK7`0O82@04a@H014B5P0N7b<04a@H01@E6@0C51P03@hB
01@E5`0C51H04A8D010A4`0C51H05QLI014B500201<D5P06014B500C51H05QLI01PI6`0C51H04A8D
0P0D5AL05@0B4aD05AHH00T:300?41802``>03Df>00A4QH0:b/d00P84P0N7RP06QXT00h>600C4ad0
8R8/0;Bd_P1aLG/0BTYD00l?6@0N7RH0414B010B4@02014C4P0J010B4@0?4A004Q@C01@F5@0B51<0
4A<B018D4`0A4Q@03`hC00d<4P0<2a409bH[01@D5P0>3Pd03Pl:00l@2P0@4PP0418500lA0`0@4PX0
4A<B010B4@0?4@l03Q0=00lA3P0?4@d200lA3P0;010B400A4a804A<B018C4P0410801`L500h>300P
81h04A4?00l?3@0@40h00P0A4@l2010@3P0300l@300?40/03a0;00803a0;05804Q<>010A300;30L0
4A8=01PI500=3PT051D@010@3P0O7ad03`l=00P81P0>3P`0410>00L71@0D51803@d;02DU8`0G5aD0
4Q8@010@3P0=3@/03Ph<01LG5@0<30X04Q8@00T91`0=3@/02@T7018B400>3P`0:b/Y04U8A00D4`l0
5A@@014@300?3PX04Q4=02XY9@0L6aL030/701<B3P0E510030/700/:200>3@/06APF01HE4`071P@0
0`8000h=2`0@3`d03`h<00h=2`0@3`d051<A018A3`0>3@/030/900h=2`0?3P`03@`:00h=2`0?3P`0
3@`:00`;2@0=30X04A0>010@400410@09BDU00410@0B4Q80000000T92@0@41000`<3018B4P0<30`0
3Ph>00l=3P0>30d03@/<0P0>30d09@0?3@h01@<401<A4P0G5AH02`T:00H41@030@8030X;00X82@0;
2@X030X;00/92P091`P04@l@01@B4`0F51D030X;01/I6P050`@030/900h=2`0A40h04a8@00l>300<
2`T03@`:00H50`071P@04A0>01XI5`0A40h04@d<02/W9P0K5aH04`l>00h:2@0@30/00P0?2`X02@0>
2PT03`/:00l;2P0D40l00`0004E1@00Q7A`04Ph=00`81`0200l;2P0/00h:2@0?2`X03`/:010<2`0>
2PP01P80018>2`0A3@X02PH3010<2@0:1P<03`/8014=2P0?2`P03@T600h:1`0?2`P06QHC00X60`0M
6AH09B4N00P40@0D40d040`900l;200E4@h05a<@018>2P0@40P02`/300H600071`002PX201<B3@07
1P404a8=014@300@3`/010<000`;200:2@L05A@B00l>3005108200d<2P0400X91`0;2PP030/900`;
2@802`X80P0=30X0100>3@/04A0>014@3P0>3@/600`;2@0A00h<3@0=2``03@/<00h<3@0?3@h03@/<
010>3`0>30d030X;00/92P0<2P/03@/<00T72P0C4A@0JfU/06UWJP0<2Pd00P010080300K6A`0518E
00400P0E4aH03P`?00`:2`0i=cP081hO01DC50050`@04a4B00T720<02`T:00@03P`=018@4@0=2``0
3@/<0P0>30d02`0=2``030X;00d;300;2@X03P`=00/92P081PL02`T:00X82@0=2``03P`=00803@/<
01X03P`=00T7200>30d00@0002/Y:P0100009bDV00d:2P0>2P/0=30a014=3P070`@00`0000d92P0>
2P/02`L800d92P0>2P/04@d>01<?400@30d04`l@01DA4P0B3Pl040`=014=3P8040`=01d03PX;00`8
2@0X92D09R8S010<3@0G4a@04Ph?00H20`0=2PX05a<D01<?40060`<00`0001`H6@0P7Ah00@0004I4
A@0B41404@l@018@4@0;2@X04a4B00800@071@H02PP901<A4P0A3Pl02PH700l;300200/720<03`X>
00`03`X@00h93`0=20h04@`C010>4`0=2a005A<H01`J7`0@3Q<04a4F00/93P0<2Pl200d;408030X?
00@040hA01PF6@0I5aX03`d@0P0=2`h0300?3A0030X=00l=400?3A002`T<010>4@0100@03P`A01@B
5`0H5Q/02`T>00@21`8030X?0P0=2a003P0>31403`dB00T72P0@3Q40:RP[028P8`0A3a8020H900l=
400U8bH04@lB00`:3@091`X06QPK5?ooool001_ooooo01T04a4B02HT9@040P<030X;00X82@0<2P/0
3@/<00/92P0?3@h02`T:00X82@0I5aX06aDO01D?6`0R72P09AlY01@?5P0>2@l040/?010<300I5A80
6ADA00l<1`0;20<04`/:00804`X;0`0A2`/04`0E4A802`T:00/92P0@3Q403`d@00`:3@0@3Q<03`dB
00`:3`091``03P`A01<A5P0@3Q<0514H018?5P0=2Q4030T@00h<4@0@3Q<00P0?3A804P0@3Q404@lB
018@4`0M6ah06aTL01HD5`0>30l05Q@G00d=4`000``09BPa01hO:@071`l08R4Y010?5`0?3QH040dD
018>5@8050lF00T04a4F014@5@0N7B80=SHi01hN80092@/03@d?010@4P0A4A<00`0C4aD0=P0E5QP0
3a4@00d>400E5QP04A8D00h?4`0B4aL051DI01LH7@0E5Q/04Q<H01<D6@0D51/04a<K01LG7`0F5R00
4A4K01<C7@0I6B<07alY01@D7P0I6B<0;2`f01/K900?41D061TN01XK800B4aP05AHK01TJ7`0C51T0
8B8W01PI7P0E5Q/061TN01<D6P0A51d06Q`X01`N:P0F62@05ALS01HH900G6BD06A/W01PJ9P0D5R80
4aDQ01TK:00D62@03a<O01XM:`0b=T802`lK014E8@804ADP01@051PS01PL9`0K7bT06AdV01<I9@0G
7BT05Q`X01@J9P0Q:3<0<c]6020X<`0G82X04A/U018O:00F8b`0628/01@K:`0G7Bd06Al_01HL;080
6Al_00<05Q`/01LM;@0H7Rh00P0I7bl05@0I7bd05ahV01HM900H7bL04APR01HM9`0<4ad05A`V01hU
;@0N9B/06B4T01XS8P0M9BL06b<W01dT:P1MI6X0:2le01DL8P0O9R`082L_01`S:`0201XQ:@0701/R
:P0J8bX05b0Z01PR;00K9Bl07bTc01hX<P0201`V<00601/U;`0M9c406R@^01XT;P0=5b0051hP0P0K
9BH0@@0E7b404Q`N01<M7`0H8R@06B<U01DO8@0R;2h03QPJ01HL8@0?51X04ADN02L[=00O8bh04aLR
01@H8`0H72D05a/T01<H7@0@5AP04ALG01PO8P0:4AL05ahT00`C6@0=51X061lW01DL900A62002a8J
00lF7`0G7RP05A`V01@K900H7bD06B0V01DL8`0A62004QTQ010G7`0D6b<05QdU020W;`0D6b<04QTQ
01DI8P0H72D051PQ014E7P0?4a`05a/T018F7`0I7BH0310I014E7P0H72D05ATR010C6P0F6B006ahU
01<F7@0=41L03a8I01<F7@0B5A`04A@K008041<J00<04Q@K014D6@0A51T00P0A51T08@0B5AX051LL
01dP9@0I72405aXO01dP9@0=41D051LL01HI800@4aX04A@K00d@5`0R9B`02PdD00d@5`0@4aT041<H
00X=4P0G6Ql04aHK01XK7`0D5AT04a@H018C5`0?41@04A8F01@E6@0Z:bl05aPL01PI7@0?41@0414E
00d>400201HG6@0H010A4`0=3Q003a0B014B500C51H04Q<E014B500B4aD05AHH02HW:@0E5QP02``>
018C5@0@4A<02``>01@E5`0E5QP0414C014B50082@/051DI03<c?00B4Q`06QXT0P0;2aD02@0=3AL0
61PR09jNZ00n?TP06ATS00h>600C4a/03a0A014C4P02018D4`0300lA400>40l03a4@00804A<B0P0C
5A@02P0A4Q@03`hD018A5`0B4AH0410C01dM7@0?40`03@h800h?2@0@4@P2010B1@09010B2P0@4Q40
3Q0?00d?3P0=3``03@l>00h@3P0>40d0418A00<04A<B01404A8A010@3P0L71X04Q8@00`<2P092@L0
51@B00h>300?3`d04A4?010@3P0?3`d0410=014B3@0@4@`03Pl:00d>2@0200l@2`0?01@E400@4@`0
5AHA01<D3`0=3PT01PH4018B400=3@`03`l=00h>300:2PP05ADC00H6100=3@/02@T700804A4?00X0
2@T701<C4@0>3P`04Q8@01@D4P0@40h02@T701LG5@0=3@/0410>0P092@L04@0D4`l03Pd9010?2`0>
3@T061LC00d<20071P803@`801DD400@3`/03@`800l>2P0B4@l03Pd;00L6100<2`T05A@B008030/9
00<03`h<010?3@0>3@/00P0=30X06`0B4@l03@`:00X91`0<2`T03Pd;00/:200>3@/03`h<00d<2P0<
2`T03@`:014@3P0?3`l03@d=0000000H61P0410@01LG5`061PH03Ph>01@D500;2`/03@d=00/;2`0?
3@h03P`=00d;300200h<3@0600l=3P0>30d03`d>00`:2`091`P07A/L0P0@3Pl200h<3@0900l=3P0=
2``02`T:00h<3@0;2@X01`D600d;30091`P02PP900803Pd;00l030/900X91`0;2PP03@`:00`;2@0;
2PP071/I00T81`0A40h01`H400l;2P0U8B003`/:01LC4P0E4A000P0@30/03@0>2PT03@T800h:2@0@
30/03@T801/G5P2=RHP0920O00`81`0B3Pd02`L600d9200?2`X00P0A3@`0300?2`X040`:010<2@0P
71T06QHC00h:1`0F4Pl03PX7014=2P0B3P/040`900h:1`8040`900L05A4>00<0000n>SL0GUYG01@@
3@0B3P/04@d:00803`/801803PX700d91@0F5Ph03`l5010@200D50`03@d500`;1P0920<04a8=00X9
1@0920@02PT5014@300E51809B@R01/J600:2@L201DD4P0600T81P0:2@L03@`:00d<2P0<2`T02PT7
0P0=30X0100@3`d04a8@018A3`0>3@/600`;2@0C00`:2`0;2@X030X;00h<3@0?3@h03@/<00h<3@0<
2P/02PP900/92P0?3@h04@l@00h<3`0;2@`0N7Ii085oPP0J61/02`T<01HD5`0200H41`0:01@B5@0A
3a801@<601HD5@0S8B80108301@B4`0A3a003@/<00X82@<03@/<00@04Q0A01HD5@0<2P/03P`=0P0?
3@h02`0<2P/02`T:00X82@081PL030X;00d;300:20T02`T:00d;300@3Pl04@l@008040h?03/04@l@
00/:2P0G5AH061HG00L51P0C4A801`D601@@4@0U8B8040`=00L4100H51D04`l@00/7200=2@X030P9
00l;300B3Pl04`l@010<3@0=2@X040`=01<?400@30d03@T:010<3@0B3Pl04`l@018>3`0A3@h06aLH
00h:2`0400403`/<00H20`0810D04`l@00X61`0810D040`=01<?400B3Pl04a0A01dK702>S8d0<2h_
00l=3P0>30d02`T:01LE5P0:20T040h?00/92P0=2``040d>00X61`0?2``03@T:00`82@02014<400=
010;3`0@2a403@P>00X52`0=20l02@L<010>4`0J61d030X?01dK80040PL02`T>00`:3`0200d;4080
30X?01802@L:00h<3`0?3A003@/>00l=400=2`h04@lB00d;3P0?3A003@/>00P62@0<2Pd020H;00d;
400G5AX0<S0e01DC600A3a@400/93P0>00d;400>31404Q0C00X82`0F51L03@/>00X82`0B41<04a4D
00T72P0610L02`T<00h<3`0H5QTDooooo`006oooool200/92P0500X82@0;2@X03P`=010>3`0B4140
0P0<2P/200d;300O01DC5`27PH/0:28_01LA700;1Pl03PX@00h93P0A3@l04@d<010<2@0@3@T040d7
00l<1P0K4a405@`=01P?400B30`0208401<=3`0?2Ph081hQ00h<400>31404a4F01LE6`0?31<03P/B
01TF7@0G51/03P`A014?500200h<4@<03`dB0P0?3A4200l=40803@/>02P03`d@01LE600@3Q404a4D
018@5@0@3Q<04A0I010@7@0F5R806ATU00h>6@0=2aH03`dG018A600C41L04PlF01DB600B41D04A0D
01@D5P071`T0CTi@00l?4@0H61X0410B01<C5@0G5aT04A4D01@C60051@T051@G018C5@0H6A/07QlR
018C5`0?41@09BHZ01lP9@0@4AH051@K0P0C4a/01P0H62404Q8L01@D7P0C4a/07AdU01lO9`805QHN
0P0G5al04P0F5ad05QHN01DF6`0L7B8061TN01<D6@0K7240;2db01LH7@0J6b005QLL01<D6@0G61d0
5QLM01`N:P0@4Ql07Al/00h@7@806A/X00<061XW01LI9P0F62D00P0H6RL01P0D5R<061/[01<F9P0N
8C808bHf01DH9P8061`X00T05a/V01XN:@0G6b@051PQ01hR:`0M8bl05Q`X01XP;00K8bh00P0F7RT0
9P0E7bT06R<^01DN:00C72L06B8/01PO:`0M8c806Al_01/Q<@0E6b/06Al_01HL;00G7Bd06R0`01dS
<`0Y;cl07B<c01@J:00N9Bd06B0W01/R:`0E6bH0728^01lU<@0K8Rd06R4Y01TP9P0I8B@072@U01hV
:00N9B`072<[01dT;00P9bl072<[01PO9`0N9B/05ahT0P0K8RP0200H7bD051dT01LQ:P0G8B/082Xd
01/U;`0I8bd05R0Z0P0I8bd03@0J92h06bD_01TS;@0H8R/07BDY01/S9P0E7B005alR01PP8P0B6Q`0
51`N01<K7@0E7Al00P0H82805@0F72007R<Y024U;P0g>dH0;C0n01HJ9`0J7R/05a/W01PL9P0H7B<0
5a`O01HL7@0D6Qd04QXM01HN8@0E72404APN01PO9@0E72<04aXS01@K9@0201@J9P0/01<I9P0E6RD0
5a/T01TM9P0J7bH061dS01LL8P0E6R007R<Y01DJ800G72804QLL01LL8P0D62405a/T01PL9@0k?dP0
7b</01@H8@0L82T020`E01PL9@0=4AX051PQ010D7@0D5b003Q4J01<F7`0>4AX04QDN01DH8@0H72D0
2@/D01<G800<41T05ATR00lB6`0D5ad05APM01LJ7`0F6Ah051LL014D6@0F6Ah201TL8@05014D6@0?
4QL04aHK01@G700B5AX00`0@4aP01`0>4AH02PdB014D6@082a006A`S00hA600A51T00P0E5QX0200D
5AT04a@H018C5`0@4AD061TM01HG6`0C51P04Q<G0P0C51P2014B500U00T:300G61X0414C02TZ;00H
6A/04Q<E014B500@4A<04Q<E01hO8@1LGEl03a0B01XK7@0A4Q@05AHH014B500C51H04Q<E01DF600A
4Q@05aPJ01@E6@0H6Al0410H010@5`0D51`04a<K010@5`0B4QT05ADM01@D6`0@41L03PhF00l@5@0A
4Q<0418A00h@3`02010B4@0W01<E500Q8b8092HU01LI600B51<051HE010A4`0A41D03PdB010?4`0D
4aH04Q8A01<D3`0>3`T04a@>00/<1@0F60h01`P202h_:P0f>3L02`d<014C4`0?4A4061TK00d>400E
5aL02@X<01<D500:30/04Q@C01`M6`0820L03Ph<00l?3@0E5A<04A4?01PH5P0E5A<03@d;00<03`l=
00@0414=00h?2P0>3`X03a0;0P0>3`X00`0?40/04A8=014B3@03014B3@0C00/;2@0I6AL030`:014A
3`0820H03`l=010@3P0:2PT04A4@01<C4@0D51804A4?01`L6P0D51803Ph<01@D4P0G5aD04A4?01<C
4@02018B400;010@3P0?3`d03`l=00X91P0K6QH03@`8014@300R8Ad0:bXV00h=2@0?3PX00P0@3`/0
3`0?3PX03Pd9014@3P0>3@/05aHD00l>300I61H02PT700d<2P0?3P`02PT7014@3P0?3P`03Pd;018A
3`0200h=2`0500d<2P0<2`T03@`:00`;2@0=30X00P0>3@/0700=30X030/900l?3`0?3`l0410@01@D
500?3`l04a<C00`<300?3`l03@d=00/;2`0=3@d04A4A014?400C4A8020H700d;300D4Q<03`d>00/9
2P0=2``030X;00h<3@0B41404a4B018@4@0;2@X200h<3@09028P8@0h=SL04@l@00d;300<2P/02`T:
00`:2`0=2``03Pd;00803@`:0`0>3@/200l>308030/90P0=30X08`0A3@`030P7010<2`0C3`h040`;
00h:2@0?2`X04Ph=00d92@0E4A008alN01TE500>2PT040`;00h:2@0<20L03PX9014=300@30/03`/:
00h:2@0?2`X040`;00l;2@0E4@h09R8O01`H5@0;1`@040`901/G501>BTL03`/801HB3`0810805Q8?
00803PX700@03`/8018>2`0D40d04Ph;0P0=2@H300h:1`0D00d:1P0=3@D04A4800l?1`0<30@03`l7
00`;1P0=30L04Q4<00d<200A40`02PT500l>2`0X9bD0W9^I02DT8P0:2@L02`X8014@3P0?3P`2010?
3@0600h=2`0=30X030/900d<2P0<2`T03Pd;0P0B4@l0200=30X01`H501/J600:2@L04Q4?00h=2`0?
3P`03@/<100>30d200l=3P0N00d;300@3Pl01`D600l=3P0;2@X03Pd?00d;3P0d<SD0:BLZ010>4@0C
4A@03P`?00`:3@0A3a80108500h<3`0@3Q403`d>00X82@0;2@X030X;00/92P0>30d02`T:010>3`0?
3@h03P`=02@R8`0j>3T03@/<0P0>30d01@0N71d040h?00X92@0>30d040h?00804@l@00<03`d>00h<
3@0D4Q<00P0;2@X200d;3004010>3`0<2P/04@l@010>3`<03@/<02/04`l@018>3`0>2P/030P9018>
3`0A3@h030P9010<3@0B3Pl03PX;00H20`0@30d030P900d92P0?2``040`=014=3P0@30d03PX;010<
3@0A3@h040`=00l;300C3a003@T:00l;300B3Pl04`l@01DA4P0=2@X040`=018>3`0A3@h040`=014=
3P0@3@h0@T110:n][P10?Sl03P`=00P61`0@3Pl030X;00802PP900D02`T:00d;300?30d03`/<018>
3`0200l;300=018=4@0?2Ph020@7014<4P0C3Q@04@dB018=50091``040hC08^9SP1kNGh09B<X01DC
600200h<4@0700d;400>31403P`A010>4`0F51L06QPK00l=400200h<3`0E01@B5@0E4aH040hA01<A
500H5QT0518E014?4P0B41D03P`A03@b=`0[:Bh04@lD00`:3`0E4aP02`T>010>4`0=2a0030X?014?
500@3Q404@lB00802`T<00@03`d@00`:3@081PT03P`?0P0<2Pd00`0@3Q402`T<ooooo`0Cooooo`00
6oooool0200=2`h02`T<00T72P0:20/03P`?010>4@0>30l02`T<0P0=2`h0300<2Pd040hC02DO:@0?
2AD07QPR01<=5`0@2a802PD901@@4@0C3`d04@d:010=20803P/400`050`:00h6100O5aD03@L700/5
1`0A2`d01`8602d[<00@3A@08b0W0<W6c@1VHf`2014>5`0<01XG800G51/03P/B00l<4`0;2@h03`d@
014?4P0B41<04@lB010>4@0?3@l03`d>0P0@3Pl00`0=2`h02PP;00d;3P0200h<4@0^01@B5`0F4aX0
5aDP018@7P0;2AL040hK018@7@0@3QT04@lI00/:400A41H03`hC01<C5@0N7R003`lA01TI6@0;2`/0
1`L700d=3@0K6ad05QHH00000P061@X05aHK01PG700?3Q@04a<G018C5`0N7b<08b@X018C5`0@4AH0
71dR01@E6P0?3aL04a<K00h>5P0;2aD0410J00l?6@0A4A/020P@00h>5P0C4a/051DJ01DF6`805QLL
07L05aPL01PI7P0@4AH04Q<H014B5`0:2a002@X?01`M8P0J6b006a`Q01PI7P0E5Q/05aPM01HG7@0H
6b@051HR00h@700/;SX03@lK01/M:@0D5R805QPT01PJ9P0G6BD05QPT01LI9@0D5bP05AP[01@G:@0A
52D04QDT01<F9@0A5B4061`X01HJ9@0D62406AdV01`P:@0M8Bd05Q/W01LM:@0H82/05alZ01XR;@0=
5B0061l[01/O:`0H72P07Qh/01lQ;P0F6BP07bDc01dS<@0@5R@06Al]01PN;00E6bT05ad[02<Y=`0M
8c406Al]01dS;`0M92h05A`U028Y<`0P9S8051XW020V<P0R:C@06b8Z01LN900I8BD082PZ02@/;`0K
8R/06b8/01`S;@0M92`06R4Y01LN9P0M92X051/Q024X;P0L92L07RHY01@M8P0P:C<06R@^00lI8`0A
6bD072H`01hX<P0J92h07BLa01`V<00H8R`05b4[01TS;00J8BP061lU01DL8P0J8BH072@W01TQ900G
7b804a/M01@L7P0H82806B8Q01TO8P0E6R007R8[028V<`0F6BX06A`]01PK;00E62T05a/W01TM9P02
01TN8@0701HM7P0G7b8051`O02<[;`0[<SP09Rde01lV;`0201TO:`0:01PN;00I7bd06Al_01/P;00I
72D05QTR01LJ8P0I72<05aXQ01<F70804QDJ01d05QTN01DI700R9BX082D[01PL9@0A5Ah06AdV00lC
701;CeP0ADUB018F7`0;3aP05ATR01HJ8`0<41T0418N00lA7@0B52003@lK01dO:`0[;cX01`/F01@H
8`0<4ad02a8L024X<P0N9Bh041DK018E6P0201@G700501<F6`0A51T04A@I01@G700E61d00P0A51T0
100F6Ah04aLJ01<G6@0A5AP2010D5`0800lC5P0A51T05aXO01@G700I72<03Q4H01@G700C51T201<D
6005018C5`0A4QH03a0D01@E6@0C51P0100@4AD0D00>3a40414C014B500@4A<06Q/M02TZ;00K71h0
414C00l@4P0B4aD04A8D010A4`051PP04a@F00h?4@0<3@l061TK00l@4P0B4aD0414C00h?4@0<3@l0
2P/=00P92`0H6Ad03a0E00h?4`0B4aP04a@I018C5`0F5a`05aPM01DF6P0@4AD03@hC00d>4P0>4100
6adL02PZ:@0C5A@07R0O00D71P0F61L06A/J010B4@0<3Pd03Q0?00/<3P0C4QL03PdB00d=3`0@40l0
4a@?018C3@0?40X051D?00/<1P0I6QD04A8=018D400D6AD00`L600hB4P072`h02PhA01DI7@0=4A@0
3Q8E00P;2`0;3`h082DQ0:NXYP0h>3H04Q8@00`<2`092@L07QhL01@D4P0B4Q003Ph<0P0C4a400`0B
4Q004A4>00h?2P0300l@2`L03Pl:018020X700D7100:30T02P`9018D4@0A4a001`T602X/:@0B5140
00400002000;3@X04A4?00l?3@0=3@/04A4?01<C4@0D518300h>30<03@d;00@05QDA00T8100C4Ph0
0@000P0h=c<03@0>3@T03`h:010?2`0@3`/03`h:00h=2@071P@04Q4?01XI5`0<2`T0BTU701LF500=
30X00P0;2PP02P0@3`d04A0>00h=2`0?3P`040l=01lN700K6QP02PT700l>300=30X400h=2`0;00d<
2P0>3@/02PT700P71@0A40h040l>0040000>3@/040l=00l>300=30X00P0;2PP04P0<2P/00@0001/I
6P0;2@X0518C01DC500J61T07A/L00`:2`0:20T03@/<00800@0:20T02`T:018@4@0>30d030X;01<A
4P803P`=100=2``300l>300500d<2P0;2PP02PT7018A3`0D4a400P0;2PP00`0C4Q004A0>00h:2@04
00h:2@0<00`81`0300003@T801@@3`0M6AP0:bLV01HB4@0A3@`040`;018>3@0C3`h04Ph=0`0?2`X0
1P0@30/03`/:00l;2P0?2`T02`L400l;20803PX700@0510=00`81@0J5Q<02`L40P0A3@X00`0@30T0
3PX7018>2`0200d91P04014=2P0D40d03PX700l;208040`90P0?2`P03P071P403@`7010?2P0<2`H0
3@`700h=2@0?3PX04a8>00d<2P01000030/903/j>0081`D010<10P0=30X00`0?3P`02PT700`;2@04
00d<2P8030/900<02`X800`;2@0@3`d00P0A40h00`0L6aT0BTU701DD4P0200l>300I00X91`0H5QL0
1083014?400H5QL02PP900/92P0<2P/03@/<00/92P0<2P/03`d>02/Y:P0N71l03`d@00D31P0?3A00
3P`?00H41`0100807A/N0:>QY01hMWT04a4D00P62@0200h<3@05010>3`0>30d03@/<01HD5@0A3a00
0P0C4A802`0>30d06aTJ02TW:00C4A800@0000P61`2DTY<0L6i_01`J6`0C4A803P`=008030X;01X0
3P`=010>3`0?3@h03@/<00l=3P0=2``030X;014?400<2P/04@l@00d;30071@H02`T:014?400:1`L0
5Q8C01<?400B3Pl00`00018>3`0C3a005Q8C00T51P0C3a002PH700l;30<03PX;0P0?2``02`0>2P/0
4Ph?01DA4P0>2P/02@D600d92P0^:R/09b<T01LC500F4Q<02PH700803@T:00h030P900h:2`0>2P/0
3@T:010<3@0B3a001P@501LE5P0;2@X03`d>00X82@0<2P/03`d>00h<3@8030X;00@03@/<00h;300?
2``040`=0P0?2``01`0A31003@P<00h93@0O6R000`0400L2200C3QD00P0?3A801P0d<SL09B<X0040
100:20d03P`A00d;40<030X?02403@/@00l=400C4A@02PP;00h<3`0A3a806QPK01LE600>30l02`T<
01<A500B41<03P`?00D3200=2a00<2hc00D3200D4QL04a4F00D3200@3Q<03`dB010>4`071@X02`T>
01<A500D4QD03P`?00`:3@0>30l02`T<00`:3@0?3A000P0<2Pd00`0@3Q403P`?ooooo`0Cooooo`00
6oooool01P0?3A003@/>00/9300<2Pd03`d@014?4P802`T<0P0=2`h0300<2Pd03@/@00H120060PX0
40/B00T42`0B3A804Ph?010<2`0?2`T03PX700h;1P803@X500@030@301081P0]9B<050h>0P0>20X0
3P0;1`/07a`S00L42`0N72<0cL[C04e:D`0C41T02`PA00d:4`0=2Q4030T@010=500<2Pl04@lB0P0C
4A@0700@3Q403P`=010>3`0?3@h03P`=018@4@0A3a803@/>00h<3`0C4AH03`dB01PF6`0L6B007A/V
01/I9`0B41h04Q0M01@B7@0B41/04Q4H00H52P0A41D0410B01TI6`0[:bd05ADE010@400I6AT201PH
600I014A4`1DE5H0@d=501/J7`0>3A803@`A00h=4`0D51T0414E01<D600D5AT03@hB014B5`0C51T0
2``A010@600J6R805QHN01<C7@0?3aT071`V034a>`0G5al0410H01`L900201@E6P0:01DF6P0F5a/0
5aPL01TJ7P0E5Q/06AXO03`m@P0`<CH020T>034b=`806a`Q04406AXO01LH7@0G61d05QHM01<F7`0G
6BD0:bdi0<;4d01NH6`02P`H014C7`0E5b<061XV01HH900D5R8061XV01LJ;@0J73405QT]01LJ;@0K
7Rl041<R01<G8`0N8Rd061`W01HJ8`0N8R/0720Y020T;`0K82`061hZ01PP:`0I8B`06b<^01PP:`0K
82`071/Y01`J:00Q7B`09B<a01@H900M8c006b4]018H9P0O9C806b4]018H9P0?5B8082Hb01HL:P0K
8Bh08BLc01TP:P0I82T07B@^020V<P0H7R/08BLe02L]>@0M92h06B0X01/R9`0O9bT08BT/01`S;002
01XQ:`<06R4Y00T06R4W00dD6P0K8RP07BDX02D]<00F7b@05AlX01hX<P0A6bD00P0G8B/0100C7BL0
6R@^020Z=00M9c4201HP:P0O01/T;@0H7bH05A`T01@K8@0G7R@06B0V01PP8`0D71l04ATL01<K7@0F
7R005QlN01DL7`0B5Ql05QXU01LK:@0A52L05AP[01PK;P0F6BX05aXY01TM9P0I7R8061dP01/R9@0?
5aX04ATL06=[K`2l`l/09Rde01hT;`0201/Q;`0Y01XP<00K8C406b0c01hR;`0I72D04aHO01DH800H
6b805QTP01<F700>4AH051LL01XN8@0L82<0;S4e01HK8@0I7BH06QhW018F7`0=4AX0@dM@0455CP0C
5b0020`E01dQ:P0S9c003A4J00T;5`0?4Ad05aTU00T;5`0C5B408BD`00lC7P0Q:3805ahX01hU;`0`
>D80=Ce600lD6P0A51T00`0C5Q/2018E6P0901<F6`0E61d04QDJ01<F6`0G6Qh04QHG01@H6@0C5aP0
4ADH008041@G00L04A@I018E6P0A51T0004801@G7P062@h051DJ00<051DI00@04a@H014B5P0B4aL0
4Q<G0P0@4AD200l@500900X;3@0>3a405QLI01<D5P0E5QP030d?01PI6`0C51H04A8D00804Q<E00L0
414C02<T9P0@4A<020T;01DF600@4A<04Q<E00804a@F0180414C01@E5`0A4Q@04A8D01/L7P0B4aL0
3a0B00l@4`0?41@03PlA01DF6@0E5QX04a@F010A500>3a<03@h@01<E500<3Pd200X<2`0R01<E5008
2PT02`d<010B4@0<3Pd03Q0?018D4`0A4a803`lA00d=3`0<30`03Ph;00h?2@0:2`D03a0:01PI4`0<
30T07AdK01TI6@072@L0314=018F5@0D61T02`lB00d@5@0520d01`X?00hB5@0@51D04ADD01<H5025
Qh@08b<Q00L71@804a<A00d05aLE00P81P0:2PP02@T700h>300B4Q00410>00l?300>3`X03a0;010A
300?40/03Pl:00H03a0;00`06A/H018D4@0F61D030h;01XL6@0A4a006A/H0001000L7Q/08B<P018D
4@0>40d2014A3`04010@3P0=3@/03@d;00l?3@D03@d;00T03Ph<00h=2@0I61@030/700X91@0>3@T0
5QDA00h=2@0?3PX00P0@3`/04P0?3PX03Pd901@C4@0?3P`051<A00L6100P7ad01PD300`;2@081`D0
51<A00`;2@061@<051<A00L6100C4Q00<C0^02`[:@8030/900h03@`:00h=2`0?3P`03`h<00h=2`0=
30X030/901TH5P01000040l=03He<`0A40h03@`:00l>30804Q4?01H04A0>010?3@0A3a008AlP0080
0@0=2``05Q@E0040000200402`T:01HD5@0=2``02PP901PF5`0=2``030X;014?400>30d020H700T7
200=2``03P`=0P0?3@h0100>30d03@/<00X91`0<2`T200d<2P8030/902P01PD4010?3@0=30X040l=
00X91`0100003PX9010<2`0?2`X03@T800h:2@0e<C00510?00@0000D40l03`/:01`H5`0D40l04`l>
010<2`0B3Pd04`l>010<2`0=2@P03PX9010<2`0A3@`040`;00h:2@0A3@/02`L400d91P0<20D040`9
01LC400D40d040`901<?300;1`@04`l<0P0@30T01`0B3P/03PX700d91P0@30T04Ph;00l;200@30T0
0P0A3@X2010<2@803Pd80P0;2PD0400?3PX051<?008100081`D040l=00D3100G5AH0;B//01HE4`03
0P0040l=00l>300E51803@`:00X91`0;2PP300d<2P0300`;2@0A40h03`h<00<03@`:0P0>3@/04P0N
7A/030/900`;2@0;2PT06aXH02`Z:`0<2P/02`T:01DC500?3@h02PP900D3100A3a0030X;00d;300F
51D0EUAE05ABE@803P`?00`0:BLZ00X82`0<2Pd03@/>01PF6@2OWJ00NgUl00l=400B41<03P`=010>
3`0B414200l=3P0Q01XH6@0@3Pl02@L800d;300@3Pl02@L800L51P0;2@X06aTJ010>3`0Q7b004a4B
00`:2`0A3a003@/<00/92P0<2P/03`d>014?400<2P/03`d>018@4@0=2``030X;018@4@0;2@X05A<D
00T7200Q7b009R@U00P61`0A3@h04Ph?00804@d>00L03@T:01@@4@0E4A80510A00D10P0C3a003PX;
00<040`=01T03`/<00h:2`0>2P/030P9010<3@0C3a003PX;00/7200=2@X061@E00d92P0;1`P04`l@
00h:2`0B3Pl0510A00l;300;1`P03@T:00l;300B3Pl0514B014?40091`P040h?00802`T:00<03@/<
010>3`0@3Pl00`0=2``00`0=2P/03`/<010<3@0200l;300=010;3`0300808QdQ04Y5B`0H4aT03@P>
010;4P050`P03`dB01/I7P0I5a`03@/@00l=4P0200d;400A00`:3`0;2@h02`T>00`:3`0610L03`d@
00h<3`0B41<03P`?00d;3P0C4A@04Q0C010>4@081PT01P@701DC5P0A3a@00P0<2Pl04@0Q7b@05aDJ
01DC600A3a@04a4F00L52P0>31407A/P03`j?`0@3Q404Q0C00d;3P0<2Pd03`d@00/9300A3a8040hA
00803@/>00<040hA014?4_ooool04oooool001_ooooo0`0;2@`300`:3@0@00T72P0=2`h030X=00d;
3P0>30l030X=010<4@0A31803PT>00/72`0>2@d030P900d9200>2PP03PX7010<2@804@h900/05`l<
01D=2`0Z8R004`d=00d72P0?2@d04@`B00`9400C41P040dH01HD7P02018?6P0300h;500@3AH040dF
00803P/B04P040hC018@4`0C4A@04@l@00d;300;2@X040l>014@3P0=30X04@l@01LE600D4QD04@lD
01<A5P0@3Q<05Q<J01TF7@0F4Qh06ADT01PD8P0B3a/040lH014?6@0B4AP02PT=018B5@0?41005ALE
02<U8`0D5A<03@d;018B400:2PT04Q8B00h>400Q8B@01PH:00X93P0F5AX05aHL00h=4`0E5AX04Q<G
010A5@0C51T05QLL01DF6`0F5ad051@L014A6@0A4AX04Q8L01HF800E5Al06QXT02`/=P0M7BD06QXR
01dM900E5Q/05AHJ01@E6@0E5QT05aPJ01XK7@0C51T03PlD018C600A4QL06a`Q071aMP0J6b0301TJ
7`2701LH7@0G5ad06QdU018E7P0A4a`0;c8k02LZ<`0K7RL04aHO01DH8@0H6b@05QTR01DH8@0G6RD0
6A`_01/M<`0L7c@09bXn02LZ>`0<3ah051PU01hR;@0I7BP05QXS01XN9P0H72D07B@^01dS;`0G7BT0
4a/V01DM:00F7BP07B8^01hN;00T7Rh09ah_02HJ;00S6R/09RLc01PO:P0F7BL051/V01dS;P0B6B<0
6b8]01XQ:`0L8bd051/V01dT;P0J8B/06b8Z02Xa>P0E72L0728_01/Q;`0I7bd0728^01PO:@0I82P0
7RD[01hV:@0M9BP07bD`01dT;P0K8R`06R4[01`S:`0N9Bd07RD[01hV:@0A6A`06b<V028Z;00C7Al0
6B8/01`V<0094ad07RPb01`V<00Q:cD06B<]01dW<@0K9Bl05R0Z01DO:@0I8B`0724[01XN:@0L82X0
6alX01LK8`0G72805AXP01LL800K82<06QlR01LL7`0D6Ad05a/T01<G8P0I72/06Qda01DG;@0J7380
6Qd`01XM;P0J7RP061dQ01LL7`0R:2/0:S4g024X;P0Y<3L0ADaE00dB7@0J82d06Al^01XO<@0K83@0
6Qlb01TN<P0J7Rd05aXS018E7P0C5Qh05QTP01DH7`0D5ad04QHJ01@H6`0F6Qd05ATJ028V:00I7R@0
5a/T00804ADN00/05a/T018F7`0=4AX03a<L018F7`0A5Ah05ATR00dA6P0E5R<040lM01DG9002010B
7`04010C7`0D6RH05Q`X010H8`803aLR00@04a`U014F700B5AX04aHK0`0B5AX00`0F6Ah05APM01DH
7@0201<F6`0>01@H700B5QL05QXI01HJ6@0C5aP041@F018F6@0?4QL05QTN01<F6`0^<CP03a8I01@G
700B4aP301<D6003018C5`0@4AD04Q<G00<04a@H00l04Q<G014B5P0B4aD04a@F00T:300G61X030d?
01LH6P0?41805AHH01@E5`0B4aD05AHH01PI6`0;30h00P0B4aD02`0C51H03PlA018C5@0D5AL04Q<E
00P92`0C51H030d?014B500F61P04Q@D0080418A02h04A8C014C4P0C5A@0418B00lA400@4Q80414B
00lA400@4Q406Q`K014C4P0g>CP030h=018D4`0A4a804Q@C010B4@0?4A003@l>00`>3@0>3P`04Q8?
01@E3`0A4P`03@h7010A2P082@@02@X601<C500>3Q8071/P01@F5`0:3P/05ATH00`?4@0;3A404A@J
00d@5`0C5Q`02PdA00/?400?4a80314=01LJ5`0=3@`04A4?0P0?3`d02@0:2PP05ADC014A3`0@40h0
4Q8@01@D4P0@40h03@d:00l@2`03010A300300l@2`0@4@`0414<00@0414<018010H301hP7@0:30T0
0@<101HH5@0?4@h01@L402HX9@1:C4T04A<@018D4@0;3@X04A4?018B400A4@l03@d;00`<2P0=3@/3
00l?3@80410>00T03`l=00T8100H5a<03`h:01/J5P0?3PX04Q4>00h=2@0?3PX00P0@3`/02P0?3PX0
3Pd900X9200E518020L5014@3P0<2`X05QDC00`;2@0@3`d200`;2@0902TX9P0<2`T04Q4?00d<2P0H
5aD051<A00P71@0G5Q@03Pd;00@03`h<00L03Pd;00T81P0@3`d01`H401HE4`0/:bT051<A00803`h<
014040l=018A3`0A40h03Pd;014@40081`L03`d>04Q6A`0d<S<05aDF00d;300@3Pl0<c4b01`J6`0<
2P/0<2h_01<A4P0300l=3P0300d;300=30`03P`=00<03`d>0P0>30d0100B4@l04A0>010?3@0?3P`2
00h=2`0E010?3@0A40h0?3/i02h]:`081`H04A0>010<2`0A3@`040`;00l;2P0@30/0;b/Z01PD4`0=
2@P04@d<00`81`0I5A@03P/:00d9200<20L04@d<0080510?01L040`;00l;2P0@30/04@d<010<2`0?
2`X040`:00d91P0B3P/03`/800d91P0D40d04@d:00H2000A3@X030P601@@3@0B3P/04@d:00l;200>
2PL040`9014=2P03010<2@<04@d:01D040`9018A3@0=30P030/800l>2`0=30X02PP700d;2`0@3Pl0
2@L9014?4P0B41<02`T<00X8200A40h02@P601`K6@0920H04Q4?00/:200<2`T00`0=30X03@0<2`T0
3`h<00h=2`0>3@/030/900d<2P0A40h092<Q018A3`0@3`d02`X8010?3@0<2`X00P0@3Pl03`081PL0
2`T:010>3`0>30d03`d>00d;300;2@X040h?00d;300X9RL08b4T00h<3`091`X06ALJ014?4P0200l=
400<00`:3@0F51L040hA00d;3P0<2Pd02PP900/92P0=2``02`T:00X82@0D4Q<040h?0P0=2``0300:
20T030X;018@4@0A3a002@L800l=3P0A3a005aDF00h<3@0;2@X030X;00h<3@8040h?00X04@l@00d;
300?3@h04Q0A00h<3@0<2P/040h?00h<3@030@801P@50P0X9RL01P0>30d04@d>01PD5@1`K6d0Ad=4
01<?408040`=00<02@D601<?400<20T00P0@30d0500A3@h040`=010<3@0?2``03PX;00d92P0@30d0
4@d>00l;300C3a0040`=00d92P0B3Pl06ADF014=3P0@30d0510A01dI6P0L61T03@T:0P0>2P/03P0<
20T01`@501@B4`0=2``03P`=00T7200>30d040h?01@B4`0B41403@/<010>3`0?3@h03@X;100?2``0
3P0>2@d040/?014<400@2a40=2le01@?5@0<1`h030X?018@5@0<2Pl02`T>00l=4P0:20d03@/@100<
2Pl0400>31402PP;014?4P0<2Pd03`d@00d;3P0?3A0040hA00/9300>30l04@lB00d;3P0:20/02@P<
018@5@0;2@h200d;4003018@5@0S8BH03P`A00803@/@00T05aDJ02/Y;P0:20/03P`?00`:3@0=2`h0
40hA00`:3@0@3Q400`0=2`h00`0<2Pd03`d@ooooo`0Cooooo`006oooool030071@X02`T>00h<4@0>
31402`T>00L52P0;2@h03`dB00/93P0<2Pl040hC00d;408050lC00@03PT=00l:3P0<20T04@d>0P0>
2PT05`0?2`X040`9014=2P0A3@X040P500T1000A2@L03PP800/52@0G4AD03`X@01<@5`0E4Q/02PPB
01TE8`0811802PLB00d:4`0@3AH04PlH00d:4@081@`040hC008040hA01P03`d>00d;300<2P/030/8
01LF500@3`d03@/<010>4@0<2Pd040hC00`9400>2a804@hE014>5`0C3a/061@R01XF900D4A`05A8K
01DD700B4AH04Q8D018D4`0>40d200lA300A00`=200E5Q404Q8@018B4@0H61P05aLI00T9300<2a00
61LM01LF700P7bD03`hF010@5@0@4AD04Q<G01DF6`0D5AX00P0?3aL09P0D51`05QHP01/K9@0M7BL0
6QXT01XJ9@0E5B404a<M01<C6`0L72@05aPM01PI7P0G61`05AHI01@E5`0E5QP061XJ014B5P0J6b00
5AHK01<D6@0I6Ql04a@I01HG700C51T061TN01XK800F5a`05aPM01LJ8@0520l0<cHm01PK8P0?4QT0
5aXQ01XM900I72<06QdT0P0K7RD06P0H6b@05aT^01LI<00L7S@09BLl02<V>00H6bX04aHU01LK9P0K
7bX061`U01@H800I7BH05QdW01/R;P0D72L04ATT01<J9P0B62@05aTV01hJ:@0U72d09APZ02/I;@0i
:Sd0?cm;0P0M92`06@0K8RX06R4Y01DL900A62009Rde01<J8P0B6B407B@/01TP:00N9Bl0;cE001/Q
;@0V;3X06R0^01/Q;`0P9S<072<]01hU;@0T:c808b/^020W;@0M92l092Xf02D[=`0Q:3800P0M92`0
3@0K8RP0AdmB01HN8@0Q:B/08RX/01hX:P0A6b@08bdg020Z=00f@4X04Q`V01<M9`0F82X00P0G8B/0
2`0F82X05AlY01HN:@0K82`06al[024U<00N8R`05ATR01@H8@0G728061dQ00806b0T02h05a`O01HK
7`0B5Ql06AdX01TL;@0G6Bh06add01DG;P0I6c006A`_01XN:P0I7R8061dP01<I7@0C6R805QdU01/R
:`063AL08BLc010F9@0D6B`061d`01/P=@0H7C<051T_01<G9`0D5R804aHO018E7@0C5Qd051LL01<F
6`0J7R404aLJ018F5`0<41404QHF00P=4`0?4a`07B4Z01@H8@0?4a`05QXS01XN9`0G6b@04QHO0P0H
72D04@0E6B<05QDS018A8@0S9C@05QPW018D8`14AeH04aTW00hD8P0G7b`02aDQ010J9P0=5R405AXP
01DH7@0D5a`04aHK00804QDJ01@04aHK018E6P0A51T041<H014D6@0A51P04ADD01LL6@0H71/051PG
010D500B5QL00PH900lB5P0D5a`0@DA;01dP9`031P/03a0E010A5@804A8F00@0414E00l@500@4AD0
4Q<G0P0C51P03P0B4aL04A8F01@E5`0;30h02P/=05YKG@0N7b4030d?00l@4P0C51H03a0B010A4`0H
6A/05aPJ0P0D5AL030092P`03a0B01/L7P0720X0;Rla02@U9`0?418061TK00T:300A4Q@03a4?014C
40<04Q@A02/04aDB01DG500@4Pl03a4>014C400?4@h03Q0=00d?3P0>40l0004001hP7`0<3Pd061XI
018D4`0C5A@05ALF01LI600F61L05ALF010A3@0E5Q405QLA018C2P0?4@H03@h701@E400D51804Q4E
02<R:P0n?4L05aTN0088100E6aT0:S0a01TN8P052Q00;C4j00D:400N8bL03Q@E00H<2P0:40`03A4=
00803`l=00X02`/901`L6P0:2PP02`/900l?3@0@40h04a<A01dM6`0K6aT04Q<?0P0@4@`0100A4Pd0
414<010A300?40/500h?2P0602LY9P1]LVh08BHR00/@300?51001``80P0D6AD010083@T0314=00D:
1P0A514200h>300400l?3@0@40h0410>00l?3@<04A4?0P0?3`d02@0>3P`04A0<00T8100A40`02PT5
01@C3`0<2`L03Pd900l>2P02010?2`0@00l>2P0>3@T02`X801HE4`071P@02`X800P71P061@<02`X8
014@3P0>3@/04Q4?040o?@0E51803`h<00h=2`8051<A00@03Pd;00l>300>3@/03`h<0P0@3`d02@0?
3P`03Pd;01XF4`0C3``061@A01TE4P0810402@D2018>2`0200l;200i014=2P0C3``04@d<01LF5P0B
4140:bTZ05YHF@0B41404a4B01DC500D4Q<00@0000h<3@0J61T02`T:00d;300:20T02@L800d;300F
51D06QPI018@4@0?3@h03P`=00d;300>30d03`d>01HE4`0A40h03Pd;00d<2P0>3@/03`h<010?3@05
108071/I014@3P061@<07QdK010<2`0=2@P040`;018>3@0@30/03@T800T5100@30/03PX9010<2`0I
5A@04@d<010<2`0B3Pd0510?01DA400G4a805A4@00803`/:00H03PX900l;2P0?2`X040`:00/7100@
30T200l;200801@@3@0A3@X0510=018>2`0D40d03PX700l;200>2PL200d91P03010<2@0B3P/040`9
00803`/80`0@30T02@0?2`P03@`:00`;2@0@3Ph03@/<00P61`0B418030X=02TW:P02018@5@0900@2
1`0H5QX03@/<00T81P0>3@/061LE00@30@0;2PP03Pd;00803`h<00H03Pd;00d<2P0<2`T02PT700`;
2@0>3@/200d<2P0C018A3`0;2PP03`h<00/:20061@<05aHD00X91`0O7Ah02PP901TG600d<S<0;bd^
00/92P0A3a002@L8010>3`0B41404a4B00H41@0200X82`0<01LE600=2`h01P@701@B5@0F51L01@<6
01DC5P081PT02PP;018@4`0A3a003@/<0P0>30d04@0=2``04Q0A00H41@091`P04@l@00l=3P0<2P/0
3P`=00X82@081PL02@L800d;300@3Pl00`4200X82@0<2P/03P`=00<03`d>00D040h?00`:2`0?3@h0
3`d>00/92P0200d;300A01@B4`0B41400`4200800@0B41404`l@03Pd=@3Ccm00RXJ700`82@0K5aP0
4Ph?00d92P13?d004@d>01HB4`0?2``0100@30d01@0?2``04Ph?01/G600I5AH03PX;00804Ph?00X0
2`L800D10P0:1PL02`L800`82@0D41405Q8C00d92P0810D04@d>0P0?2``03`0E4Q<04Q0A01@B4`0?
3@h03P`=00/92P0F51D08AlP01`J6`0>30d03`d>00h<3@0<2@X03`/<00d92P0200l;300=00d8300C
3Q804PdA00L2200I51X02PD;00`83P0B41D01P@900X83@0610T03@/@01<A5P0200/93P0X00`:3`0=
2a003`dB014?500>30l04Q0C00X82`0=2`h03P`?01DC5P0e<cH081hQ00`:3@0B41<05A<F00h<3`07
1@X071XO00H52@0l>Sl06ALL01dK801jN7d081hS01PF6`0:20d040hC00h<4@0:20/03`d@00d;3P0>
30l040hA00`:3@0C4A@040hA01@B5@0C4A@03`d@014?4QCooooo000Kooooo`1I010;2`0A3@h04Pl@
01<>400@2`d030T;010:3@0?2`d01`D601<>4`0A3A404@/>00/62@0?2Pd03P/>00l=4P0;2Q003PlF
00H5300B4aT030/@00l=4@0>2`d02@H701DA400<20H04Pd=018>3`0;1PL04@h@00h;3P0;2@d02PL<
01HD6P0<2@l03P/B010<4`0A2a804`lF018=500E3aH02PL;018=4P0B3A4040d@014=3`0A30l040`?
00l=400O7B006APK00d<400C4QH04@lE00h=4P0?3A<03`dD018@5P0?3A@05a@K01HB6@0E4AL04PhD
01@@5P0D41D040hA01@C500C4Q<04a8A01<C400@3`l04A4>01<C400@40h061PG010@3`0C4a804Q8C
01TI6P0G5QT05ADG02LW:@0H61/04A4D01`M800O82<08b<V01TI7P0>3Q<00P0H61d03@0B4QP040lF
01@C6P0F5A`05AHL00l@600D5A`03Q0F01PJ7P0A4aL06Q`P01@G6P0B5AL00P0E5aX01`0E61X05aTN
01DG7@0C5A/04aDJ01@F6`0F61d00P0D5QX02P0G6Ad06Q`P01XL7`0G6Qh051LL01XM8`0D5Q`0<cHl
024T:P0C5Q`201@G7@1`01DH7P0F6Al05APN01@G7P0G6RP05QTY01dQ<00L7bl08BDc02<V=00F6RD0
5a/W01/O:`0L82`06AdW01dQ:`0H7bT05AdV01DM9@0G7RT05ahX01DK900K7RX08b@`02HU<00Q72X0
;RLf03ljB00_<Cd06b4/01dT;@0K8R/06B0X01XQ:@0I82L0<SU0024X;@0G7RD0620T01PP9@0F7BD0
6B0Y01LM:00Q:3<061hY01XP:`0U:cP07bDa01dT;`0Q:3407RD^01PP:@0H8Rh07RTf020[>00[=D80
7BHb01/U;`0O:340?TM>01/V:P0M9bP06B8T01XU9P0E8BL06BD^01PT;@0S;SL041/T01DQ:P0F82X0
5AlY01@N:00G8B`05b0/01@L9`0F72L0724/01`R;00P9Bl03Q<L01PM9P0G7B<05A/P01HL8@0C6Ad0
4QPK01HL8@0B5ah06AdW01DI9@0B5BH06aha01LJ;@0D5bP06ah]01LK9@0N8bT0724V01DM800C7B40
6B4W01<L900F7bT05A`Z01TQ<00B6R/07bDf01`S<`0Z<d405Qd/00hC80804aHO06404QHM018F6`0C
5a/051TK01PL7`0B5QT061dP01LK7`0E6Ad05a/S014E7P0E62405QTQ00lC6`0B5Qh041<K010D6P0A
5A/051PN01DI7P0/<3L0BdiJ01TL:`0B5R<05APV01<H9@0a=T<05adZ01DK9P0L92h04aXU01TR;00B
6R@05AXP01PL8P0J7R<04ADK00dA5`0J7R<04QHJ014E6@0>4QH03a<G018G6@0B5QX04ADG01<G600K
7b403a<E018F600C5aT061`N014E5`0=4A@04ADH03/o@P0Q92L04A8E018C5@0C5AD04a@G01<D5P0B
51@04A8E01<D5P0D5AH051DH01<D5P0A4a<030d>018D500C5AD0@49201LH6@0D5AH0418B01<E5@0<
3Ph03Pl@01DG5`0>41002``=020R8P0F5aP04A<C00d?3`0C5AD05AHG014B4`092PX04A<C00d>3`0B
51<051DC01@E500D5A<04Q<A0080414?01D051DC010A400@4A004Q<A00l@3P0=3P/04aDA01@F500=
3`/03a4>010B400?4@d03a4>00h@3P0A4`l051HC00lA3`0<3P/0414>018C3`0A4`d00P0=3PP07`0B
50h030h:01HG5@1<C4`051@G01HF6`0=41003a@?00P<1`0D61H0Ada;038e=`19CDl08bLY02<V9P0@
51803aD@00`?2`0@4`l03Pl<01DF4P0?40d04a@A010A3@0>3`/03a0<00l@3@0@4@h04a@@010A3P0>
3`X00P0@4@`05`0A4P`0414<010A300@4@/04Q<>00l@2`0;30H030d700h?2P0>3P/0?d0l01<C400;
30P03a0<018B3`0<3@T03a0<010A3@0E5A8051@A00l@3@0<30X0414?0080414@00H03@h=00`=2`0<
3@`04a@B00l@3`0?40h200X;2P0?01<B400=30T04Q8?00l>2`0=30T03@d:014@3@0F5A805ADB00d=
2P0>3@X03`h;01<C3`0>3PX05QHB00804Q8>0100410<018B3P0=3@T05ADB00`<2@0B4Ph04A0=018A
3`0A3`d03`d;00l<2`0@3@`03P`:01<@3`0?3@/04@h=0P0E4Q40;@0@30/03PT6014=2P0>2PL03`/8
014=2P0F4Pl05A4>010=2@0?30T05Q@@01dK5`0O7a/05aLD00L7100I6AD061PD00d=2P0>3PX0<c8`
01LF5P0C4Q803Pd=00X92@0B4A403P`;00l>3@0?3P/03Pd;00`:2P0;2PL0>SPg01`K6P0=30T04A0>
00X8200@3``03`h;00d<2@0;2PL03@`900l>2`0=30T03Pd:01DD4@0200h=2P0=01<B3`0=30T040d;
00`91`0=2`P040d;00l=2P0@3@/02`T600X81@0B40d03``:00d:200200h;2@07014?300=2`P030X7
010>2`0?3@X040d;00h<2@0200`:1`1_00l<2P0B3``03@/700d;1`0?3@T04Pl<01<@3@0>30P04@l;
00X7100>2`P02`P5010>2P0A3@X03PX700`81@0C3``050l<00d91P0=20D04Pd:018>2`0>2@H03PX7
018>2`0;2PP030`:00l>3P071PH03Pd<01/J6@1dLg@0JFQY01@C500>3@l06QTJ04i=CP0<2`/02PT7
00l>300<2`T04Q4?00X:200<30X03Ph<014@3P0@40h03Ph<00d<2P0?3P/040h;014>300>2`T03@X8
00l<2`0;20L03`d<01DB4P0?30`04Q0?018A400_;Bd04a8B00@30`0>3@d030/:01<B4P0>3@`03`h=
010?3`081`L040l>00l>3@061@H061LI01@C5@0:2@X04Q4C00L61`0:2@X03`h?01<B4`061PL08B0R
034`<@0>3@d02`X:00`;2`0>3@`03Pd=010?3P1NGE`06aXJ00@30`0P7ah06QTH00T8200>3@`030/;
00h=3@0?3Ph02PT900l>3P0=30`030/;01HE500D4a<02`X900d<300A410030/<00803Pd>01D03@`<
00h=3@0?3Pl03Pd=00/:2P0];2`0<C0a00l>3P0?30d05A8C02PU9P0S7b004Ph?00l;300A30d03`X<
03@_<@0A2`d04``>00h92P0>2`/00`0=2`X05@0>2`/04Pl?01PF5@0G5A@03@/:00h<2`0A3Ph040h<
00X71@0=2PP04Pl>00l=300H5AD07A/J00d:2P0>2``03``=00P51P0>2``040h?00L51`0200h<3P0W
00/92`081PL03@/<01<A4P0A3`l01`D5010?3P0B41002PP8010?400=2`/02@H8018A4`0<2@`02`P<
00l>4P0@3A802`L>00X93P0>2a80518K01XH800B41L02`T>00d<3`0920X030/?00`;3P0>3A402@P=
010>5P0A3aL02`X?00l>4@0>3@l03@`?00X92`0?3Q003Pd@00802`X=01/03`hA00l>400>3A005QDG
00P7200?3Q0040lC01@C5P081`/06APK01HE6@1:B4d06aTN00`;400C4AH02`T>01<?500?2a004`lD
010=4@0@31403P/?00l<400@3A404PhC014=4P0>2`l05?ooool001_ooooo02X030L300d81@0=20D0
3PT600h91`0>20P02P@401@>3`0B30h06A<E00P2100C3@l04`X;018<3`0?3A803@`B00X;5P072aL0
BdmK03i2CP0:3AH01@@=01@A600I5a`040h@01<A4P0@3Pl0518C014?400?3@h04Q0A00d;300;2@X0
5A<D00X82@091`P05Q4E01@>4P0;1@T03PP<010:3P0S7B4201@>4P804`dA00@04P`@014<400<2a00
3`hD0P0D4aT02`071P`0<2le01LF70061@/04Q4G00/:400?3Q@040hB01<?400A3@h04Ph?0080510A
00@05Q8C01PD5@0G4a@05Q8C0P0E4A80100D4a<06QXH01hN700J6QP401@D4P0:01DE4`0A4@l04Q8@
018B400C4a@05aLI01DE5`0M7Al061PJ014A4`805aLI00P05QHH01DE5`0F5QP05aLI01DF6@0U:B`0
:Bd`01<G6P804ADH04X06AdP018F6@0B5QT061`O01HJ7@0C5aX05aXQ01HI800C5Qd04QDJ01<F6`0E
61d03a<F018F6@0C5aP05ATJ01XN7`0D61T08B@Y018E6P0?4QL04A@I01/N8`0H6b005QTN01LJ7`0F
6Ah04aHK01@G700I72404aPN02@X<@1:CUL0?d=<02L[=@0<41/04ADP01lS;`0B5R805QXV00dA7P0L
82`041LQ01HM9@0G7RH04aXR02/b>P1EG6@082L_01TP:00L8b/05ahV01/R:P0H7bT061hZ01TO;00I
7b/06B0Z01PO:00F7BD05QdS01lV:`0K8bH05QhQ01LO8P0H82<06R4W01TP:00J8BT072<[01lV;`0O
9S006R4[01`R;P806Al[00`06b4_01PP;@0K:SL0?dmN020`?`2O[;`0Ef=c01l[>@0H9C006R@^01TT
:P0H8bD201LS8`0<01PV:P0E8RP05B8X018O9P0D8BT072H_01LQ:`0J92h05R0Z01LQ;@0H82d051`W
0P0G7RP01`0=51h08RTa01hU;@0L8b/05QdS01DL8P0C6Ql00P0B6Qd01@0D6al05Q/Q01@H8@0C5b40
4aLR00804aHU024051PT02HZ=P0G6bD061`U01LL8P0L9BP04alO01@O8@0F8BH07bTc02@^>P0M9SD0
HFYi00TC7`0=5b405R0Y01PS:@0E7BD04aLP01<H7P0B5a`04QLJ01<H6`0C6AT041HF018G6`0H7B80
51TO01@H8@0@4a`04A@M01<F7`0E61l00P0F6B00:`0E61d051LL018F6@0A5AP04QHI01DI7@0R9S40
3aDS010F8P083QX04ALS01TP:P0E72H04aXT014H800C6R8051/S01<J8P0F6b406AhT01dR:00C61h0
3A8H01XO8`0B5aX04aPK00lD5`0=4a<04ALG018H600C5Q/04A@I01TL8@062Pd04ADH018F6@0A5AH0
4aLH014E5P0@51<04ADD018F5@0@4Q400`0A4a82018D4`0?010B4@0A4a804Q@C018D4`0A4a80418A
01LI600C5A@010H500D71P0A4a80418A01PJ6@0E5aH04aDD00804A<B00L05ALF018D4`0@4Q4010H5
02<U900A4a804aDD00H04A<B1P0C4a<0200N7Qh04a<C00h>3P0?3`l04Q8B01@D4P0B51004A<>0P0@
4Pd200h@2`0G00X<1`0<3PT04A<>01LI500F61<04aD@010B3`0B5140418?00lA3P0D5Q<04aDB01DG
500620D08bDR00@60`0E5a@04A<?00h@2`0=3`X03Q0;00lA300A4`h00`0@4Pd0100>40/03@l:010B
3@0B50l200lA30<0418=0P0A4`h01@0@4Pd03a4<00h@2`0>40/03a0;00H03a0:00/010D000<4000=
3PP06AXD00T:100@3`/04`l<01@@3@0E4@h05Q8?01@@3@0201<?300M01@@3@0E4@h0510=014?2`0;
2`/04aDD00d?3P072@P020X9014C4P0=3`h04aDD00T;2P0:30/03Q0?02LY:0092@L03`l=010@3P04
108092@R03Ti=`0@40h06ATG01LG5@0;2`T03Ph<018B400>3`X00P0?40/200h?2P0900l@2`0<3@P0
3@h9010A300>3`X03a0;01PI500=30X040`;00804@d<0`0C3`h08@0>2PT03`/:01@@3`0D40l03@T8
014<2@0B3@X04@`9010;200@30T04`l<00H2000?3PX02PT500L60P0>3`X051D?00h?200<3@D05AH>
014B300>3`T02P/5010A300:2PP020P6014A3`0@40h02PX801<B3P0=30P030/700h=2@0200l>2P07
02<R7P0<2`L0;2/W00X91@0E51003@`800l>2P0200d<20803`h:00<03Pd900d<200>3@T00P0?3PX2
00d<200600l>2P0=30P03@`800d<200?3PX03Pd90`0?3PX02`0A40`03Pd900`;1`0<2`L020L300d<
200@3`/02@P400X91@0?3PX03Pd900803@`80P0?3PX00`0=30P030/700/:1P0200X91@0300`;1`0>
3@T03Pd900<03Pd900L03@X7018=2P0?2PL03PT600d81@0L5a@050l<00803PT60P0F4@h01P0;1`@0
30/900h>300>3P`02PX8010@3P804Q8@00`04a<A00`<2P010@001PH401LG5P0F5Q@0000000L71@08
20H0000001@D4P0?3`d200h>300G00d=2`0?3`d05ADB00h=2@0?30L03`/800h:1`0?2`P040`;00<0
000;1`L02@D6010<3@0E4A800`4200L71@0820H030`:01<C4@0=3@/04a<A00/;2@0<30X00P0=3@/2
00l?3@0=00X:2P0A4A403`l?00T92@0820P02`/;010@400A4A403Ph>00d=3@0I6AT0:2PX00/;2@05
00`<2P0601/K6@0:2PP01@D300T91`0<30X0410>1P0;2`T01`0A4@l0000000@40P17AdD0>c/i00`<
2P0<30`00P0;2`/200`<300>00h>3P0<30`01`L700P8200T92@09bLW00X:2P091`P02PP900h<3@0C
3a003`/<00/7200@2P`401893003010;2`0=30X03@`:00<03@`:00T030/900d<2P0=30X03@`:00h=
2`0B4@l04A0<00l>2@0B4@d00P0>3@T02@0F5A<06QTG00P71@091`P03@/<01lM7P0o?Ch0;R`_00h<
4@0200`:3@1400d;3P0=2``02@L800d;300=30X02PT701<B400E51003`l=01dM7@0<30`02`/=00D5
1`0:2P`04Q4F01TH7@0A41D03@`B00T83P0:2A004@lJ02LU<00=31<030/@00h>400:2PX061PH02<S
8`0I61`020L=01@C6`0610l03PdB00h>400A4A<03Ph@00`<3P0F5QP0820R01DE5`0;2`d04A4C01@D
5P0:2P`05aLG010@400A4A406ATI01DE5P0@41804A4C00`;3`0Y:2d02PT>00h=4`0D4aT04a4F014<
4P0E41H04@`B010;4@0C3Q@03PT?010;4@0=20h040/A01@?5@0?2Q0Dooooo`006oooool0700=2PD0
3PX6010<2@0A3@X0510>01@@3`0;1`H02@H500D10P0d<340510A00d72@0C2Pd04@/>00`:3`0;2Q00
2P/D00T;5`0;3AT05aTT014A6@0A3aD03P`A00l:3P081`L020H700L51P0>30d200L51P0;00l=3P04
0P<03P`=01hL7@0B414030X;00X62@0H4aL020<701HA5@0300800P0C3Q83018=4@804@`@01804a8G
00X93P071P/071/P03dl@@2n_L80@T5600X93P0J6Ah030/@01dL8@0D4QH04@l@00l=3P0@3Pl04Q0A
014?400D4Q<201LE5P0401DC500C4A804Q0A01@C508061PH00<04a<C00h>3P0@41000P0C4a<01@0F
5QH05ADE00d=3@0=3@d051@E008030`>01D0410B018B500E5AL05QHH01PH6P0G5aT05QHH01LG6@0H
61X04Q<F018F6@0@4QD082@W01TM800C5aX05a/N01<G6P0E6A`06QhQ01PL7`0D61/00`0E61l0;P0D
5a`04aHK01<F6`0A5AP051PK01DI6P0G6a`06AdN01DI6P031P/05QTN01TL8@0G6Ql00@@901<F6`0J
7B806A`Q01@G700@4aP04QDJ01TL8@0H7B<0724W02L/<P0E6B8061`V01`P:`0B5R406AdY01HJ9P0[
;c/0720/01TM:@0D6bD08RTa01lV;P0F7BD0=Se5071gO`0f?DD072<[01dT;00J8BT06b8Z01PO:@0F
72P201LM:@0c01HM9`0F7BH051/S01PO9@0F7B8041PK01<K7P0J8R@05alR01PO9@0K8RP06R4W01PO
9`0J8BX07RD_01HM9`0L8Rh06Al[01PN:P0L8Rh07BDb02djA`1^O8T0>dUF0;O4d01^NXX0;CU701/W
<`0P:S@07RT_01PS9@0F82405b<S01`W:P0I92P06RDY01HQ9P0E82H06b@[01HO:00K92d05b0Y01@L
9`0E7BP051`W01XQ:`0E72H072<]02P_=`0M92`06B0X008061lU01l04QXN01TQ900J8RD05A/P01@I
7`0F6R<05a/U01HJ9@0E62L071l^01/O:`0L82`06AdW01XN9`0:3aD05QlQ018N7P0E828031LL00lI
8`0O:CD0Ae5N0;O0c`0_>DD07BLa01<M9P0:5A/03aLO01HJ8`0D6Al04aPM00804aPK00X04ALG018H
600G720061dR00lD6P0E6B804A@M018E7P0E62405QTP0P0G6R4201@G700L01@H6`0B5QT03a<F00`@
500=4A`05Q`X01PN:P0<4Qh03aDQ014H8P0F7BL04aXT00lF7P0@5ad04QTO01<J800D6Al04aPN01HK
8@0F6al04QLK01@I7@0B5aX05AXM018G6P0=4a<041HF018H60803Q4F00P06ahS00/?4P0>4QD02PhA
00lC500A5AD04QHE010D4`803A4@00L04Q@C014C4P0@4Q40418A018D4`0D5QD0418A00@04A<B01<0
418A00/=300B51<03a4@01<E500L7Qd05QPG01XL6`0?4A004aDD014C4P0<3Pd06adL01dO7P0H6QT0
6Q`K024S8P0;3@`010H500H04A<B00@0410@014A4@0B4Q8051@D0P0E5AD01`0T92@05QHF00l?3`0@
410051@D01LG5@0@4Ph01P0@4Pd01@0A4`h04Q@?01<E400A4`h0418=00805ALD00X03@l<00h@3@0A
4a002`d:01`N6`082PL01PP500L91P0O8Ah0418>1@0?4@`03`0@4Pd04Q@?01<E400A4`h03a4<010B
3@0B50l0418=00h@2`0<3PT03@l:00lA300D5Q405ALB010B3@0200d?2P0300lA300@4@`03Pl900@0
3Pl902D0414;01<D3P0Q8Q`03Pl9018C3@0>3`T04Q4=014@300C4Ph051<?018A3@0=30P04A0<010?
2`0A40`04Q4=014@300=30P01PH600/=300:30/05QPG01TK6P082PT04aDD00`>3@0@4Q405aTH00h@
3`000P403`l=04I6A00E5A<03Ph<00<30@0=3@/02PX80080410>00<020P600d=2`0B4Q001P0>3`X0
0`0<3@P03a0;010A300200/<1`0801PI500;2PP030/900h=2`0@3`d04Q4?01<B400?3P`200h=2`08
00l>300>3@/03@T8018>2`0C3``04Ph;010<2@0A3@X2018A3@0?01`K5`0E5Q40414<01@F4@0B5@h0
3@h700T:0P07200030d700X;1@0@4@/03@h:00H6100E5A<02@T70080410>01@061LC00h=2@0;2PH0
3@`8014@300B4@d02@P600H50@0f=C402@P401HE4@0920@03`h:00T8100?3PX03Pd900/:1P0@3`/0
30/700d<20803Pd90P0<2`L00`0?3PX03Pd900d<200200h=2@0900l>2P0@3`/040l;00l>2P0B4@d0
3`h:00`;1`0@3`/01`H200803Pd900D02`X601LF4P0?3PX03@`800h=2@02010?2`803Pd900D03`h:
00h=2@0=30P03`h:010?2`0500l>2P0A00h;200I5A806aLD00l;20081040;2PU020L6@0B3P/03PX7
01HB3`0A3@X02`L400/:200>3P`02PX800d=2`092@L00P0=3@/04`061P@05aLE00`<2P0D51802`/9
014A3`010@0071`J010@3P0?3`d04A4?00h>300=3@/02`/900`<2P0@40h051DA00d<200=30L00P0<
2`L0400=30P03`h<018A3`0D4Q801P@500/92P081`L08AlP01<C4@051@<04Q8@014A3`0>3P`0410>
00/;2@0<30X200d=2`803`l=00T051@D00L71`0C4a<05ADE00X:2P0C4a<030`<00/;2`0<30`00P0>
3Ph03@0:2PX03`l=00h>300<30X02`/900X:20092@L01PH400h>300F5Q@04A4?00d=2`0@40h01P0;
2`T200`<2P0400h>300A4@l02`/900h>30<02`/;00l030`<00h>3P0>3Ph02`/;00`<300?3`l03Ph>
00d=3@0:2PX04a4B01HD5@0L6Q/08alP01/G600D41400`0@2P`20189300N010;300>3@/040l=014@
3P0@3`d03Pd;00`;2@0=30X03`h<00d<2P0>3@/05A@B01HE4@0A40/04Q4=010?2`0>3@T03Pd;00l>
30081`D03P`=00X82@091`P07Q`M01hL7`0@3Q<03P`?00l=400@3Q403`d>0P0>30d200d<2P0[00h=
2`0?3PX020P600l?3`0:2PX07QhN00X:2P0?3a403PdB010?500=31404A0F018A5`0:2A002PPC01TG
8P0:2A003`hC00d=3`0=3@d00`<300d=3@0;2`h051<I01<B6P0>3AH03`hC00h>400A4A<0410B00h>
400F5QP07AdO01DE5`0;2`d03@d?00l?4@0;2`d04Q8B00d=3@0?3`l051@D018B4`02018B500300H6
2@0>3A8020L<00803`hD00H05aDJ00X83@0F51T03@/@00l=4P0:20d2014?500400h<4@0@3Q<0518G
010>4aCooooo000Kooooo`0Y010=200A3@T04@d:018>2`0C3`d04`l>00l;2P0@30`05a<D051<C@0M
6AX03@X:00h9300=20d02`T>00/:400>3QD03a4I010?600@3aL04@hC018=4@0B2`l05A0A00l<3@0B
41405A<D018@4@0>30d03`d>00h<3@0J61T03@/<01PF5`0D4Q<03P`=01<>4P0G4QH06A@H014<400E
41@01P0B3A404@0@3Q4040lD018A5P0I61d06aXO010@501FEEX09RDZ00T83@0@3a@03`hC00`;400@
3a40518C018@4@0C4A80518C00L04a4B01h04Q4B01<C500D51L04a<E010@4@0A41@05A@G01DE5P0H
61/06a/M00h>3`0=31005QHH00`<3P0I6A/05ADG010@4P0K6ad04a<E01LG6@0F5QP05ADG01HF600G
5aT05AHI01HJ7@0I7B005ATL02<W:P0B5QT201<G6P0401HJ7@0I7B0061`O01@H6`8051LN00H05QTP
01HI7P0D5a`04aHK018F6@0C5aX401DI6P0V010B5`0F6Ah06ahS014D6@0P8bP05APM01XM8P0I7240
5APM01<F6`0D5a`05aXO01HK8@0E6R007b@Z01HK8P0L8BT0720Z020T;`0S9c80<SI101@H900H72P0
6alZ01PO:@0G7RH05A`T01@K8`0H7bL072<[034h@00H7bL07bH^01/R:P0G7RH06R4Y01LN:00I7bX2
01TP:P1K01TP:00G7RH06B0V01PO900B6Qd051`O01XR9@0H82<08RT_01hU:`0J8BL06b8Y01XQ:@0G
7RL061lY01XQ;00H7RT06b4]01hT<00J8Rd05b@`02<a?@0I9c<0;3Q702TeA00I9C<07BPc02<]=`0Q
;3806B<V01HP8@0H8R805b4S01TR9P0L9RT06B4U01HN8P0I8BP06R8Z01`T;@0J8RX05alW01hU<00U
;CH05ahX01/R;00A62806R4Y02<Z<P0G7RH061lU01`S:@0D6b007bLZ028Z;@0E72404QPN01@I8P0D
6R<051XT01HJ:@0I7B`05AXV018G8`0@5Al051TR00/A5`0O:2/04A`M01PS9@0kADX0:38k014J9@0L
9C40=Ci904QAG@0B6bD06b@]010J8@0H82L05adU01HL8P0D6Ql04aTL018I6`0D6a/051`K01LN8@0H
7R<04QPN01HK900301PK900B01LJ8@0E61l051LN01@G700E61d05QXM01DI700D61/04QLJ01LK9P0B
62@04ALS028Y=00N92l061lY01<J8`0B6B404aXQ0P0E72806`0B6Al03Q<I00hC6@0@5AX04AHJ018G
6`0E6Qh04QLJ01DJ7@0C6AX03aDE014G5`0B61P05ATL00lB5P0_<SH0;S8e01XN8@0D61X041@E00lC
4`0B5QD041@C00lC4@0D6AH05ALF01<E5002014C4P0301@F5@0G6AP04Q@C00@04aDD0P0B51<04@0?
4A005QPG018D4`0>40l092HU01DG5P0G6AP051HE014C4P0B51<05aTH01TK6P0A4a803a4@018D4`0F
61L02P`;00H04A<B00@04A4A018B4P0B4Q804a<C0P0D51@2018B4P0801<C4`0E5AD04Q8B00l?3@0?
4@d03a4<010B3@0A4`h2018D3`0C014C3P0B50l04Q@?010B3@0A4`h04Q@?01<E4P0F61D0418?01<E
4P0D5Q<03Q0=01DG500?4@h05QPE00`>2`0D5Q<04A<?014C3P02018D3`03014C3P0@4Pd04A<>00<0
4A<>0`0?4@`00`0@4Pd03a4<00d?2P0200d?2P07010B3@0A4`h03a4<00d?2P0>40/03a4<014B3@06
010A2`0501DF400^;bT03a0:014B300@4@/00P0@3`/04`0C4Ph03Pd900T8100A40`05QDA018A3@0=
30P03Pd9010?2`0=3@P04Q8B01hP7`0M7ah04A<B00`>3@0I6aX0:2XY00`>3@0C5A@00P0=3`h03P0I
6aX0DU9@01lO7@0820L051@B014A3`0=3@`03Ph<00l?3@0@40h03Ph<00l?3@0B4Q003a0;0P0>3`X0
0`0@4@`04A8=00l@2`0200l@2`8051D@0P0?40/2010?3@<03`h<00D03Pd;014@3P0D4a404a8@014@
3P02010?3@0L010>2P0B3``04@h;010=2P0@40/04A<>01@D3`0;30P02@d700lB3@0A5@l02`h701DF
3`0P8AT06Q/C01LH4P061`404A8<018C3`0[:bT0Hf=Q01LG5@030`804A4?01LF4P0?3PX03@`800h=
2@803`h:0P0B4@d02`0;2PP051<?00D40@0E51003Pd900X91@0F5A404Q4=00T8100@3`/03Pd900<0
3`h:00<03Pd900d<200>3@T01@0>3@T200l>2P0<010?2`0E510051<?00/:1P0F5A403Pd900d<2009
20@061LC02l^:P0@3`/03Pd90`0?3PX400h=2@0300l>2P0B4@d04A0<00D03Pd901D03@/701TE4P0M
6AH05a<@00X60`0F4Pl0510=014=2P0D40d030P500L3000V8b0051<A014A3`0;2`T04a<A00d=2`0:
2PP03`l=00X:200;2`T00P0A4@l01`0=3@/03`l=018B40071`D05ADD01HF500<30X00P0;2`T01`0=
3@/03`l=00h>300:2PL03`h:00l>2@0>3@T00P0<2`L0300<2`T03`h<00X92@0<2P/04@l@018@4@1i
MgP0:b/Y00`<2P0B4Q0020P600X:208030`:0`0=3@/200h>300:00h>3P0;2`/05aLG01TI6@0>3Ph0
30`<00h>3P0<30`02`/;00d=3@803Ph>0P0A4@l01`0?3`d03Ph<00d=2`0<30X04A4?00h>300<30X0
0P0=3@/00`0<30X03Ph<00h>300400h>300?00d=2`0>3P`02`/900h>300=3@`02@T700h>3P0?3`l0
30`<00l?3`0B4Q803`l?00`<300>3Ph030`<00803Ph>00P02`/;00`;300:20T03@/<01@A4P0@30d0
2PH7010;308040X<01H04@X<0189300@2`/03`h<014@3P0B4@l04A0>00l>300=30X04a8@01LF500B
4@l030/9010?3@0B4@d03@`700d<200>3@T040l;00l>300=30X030/90P0>30d01`0:20T040h?01HD
5`0A3a@03P`?00l=400@3Q400P0?3@h0>00<2P/02`X800h=2`0:2@L02`X600l>2`0A4A005QHF00L7
1`0>3Ph0820R01PH6`0;2Ph04a8G01LF6`0<2a403`hD00/:4P0=31@030/@01<B5`0=3@l03Ph>00l?
3`0>3Ph02PX<02LV;0040`T03@`C00l>4`0=3@l03Ph@00d=3`092@/03Ph@00T92`0@41804A4C00P8
2P0:2P`06a/M00h>3P0<30`03`l?010@400?3a005ADG010@4P0B4QD01`H;01@C600>3A<01@@:010>
4`0>31403@/@0P0B41D01`0;2@h04Q0E00l=4P0>31403`dB010>4`0>31405?ooool001_ooooo00l0
3P/600h:1P0=2@H030P500/71@0:1PD03PX9010<300N6Q/04@d>010<3@0>2P/04`hB014=4P0>3140
0P0<2a406P0<2a000@0500X62`0C3a00614B01H<3@0?1PL0514B00h<3@0F51D0F5IG05YHF@0@3Pl0
3@/<02TW:00<2P/03@/<010>3`0B414040/?03<^<P1^JFd08QdQ01HA5@0I51P04@`@0`0B3A403`0C
3Q804@lB018A5P0<2a002`X?01LF6`0B4AH05aHK01PG700K6Ql030/@01DD6@0?3Q<05aHH01LE5P03
01DC500<01@B4`0A3a003`d>00l=3P0B41404a4B01@B4`0A41@040lD01<B5`0F5AX05A@I0P0D4aP2
01<B5`0;01LF6`0B4AH040lD01@D5`0?3a407AdO018B500?3a408R8T01PH6P0E5AL00`0D51H02@0E
5AL07b4T01LK7P0I7B00;C4d096EV00U:B`041@G01<G6P0201DI700:01LK7P0E6A`04aHM01@G7P0F
6B005APM01@G700B5AX051PK01<G6P805ATJ00P04QHG01DI6P0/;c@061/P01@G700A51T06ahS01TL
8@805QTN01h05aXO01TL8@0H6b0051LL024V;00F6b404aPN00dB600J7bH06alX01`P:`0i?DP0KW9m
02lc?`0Q9C404ADP01HM9@0L8b/07RD]020W;`0O9Rh05ahV01`S:`0F7BD082L_01TP:00F7BD061lW
01DL900G7RL301PO9`0501LN9P0D6b406R8V01HN8@0C6ah00P0E7B00800V;C<072<Y01PO9@0L8bT0
6R4X014H800M92h06R4[01PO:@0O9C407R@`01LO:P0G92h05B<^00lM:00I9C<05b<a01XV<P0G8B`0
6bD^01XU:`0F7b<051hO01LP7`0J82<05AXM01<K7@0H7b809BX^02de>00H7bD05A`R0P0E72@0:@0M
92`09bhf01XQ:`0H7bT0>3m901PO9`0G7RH03QDM01<J800G7R@04aXO01TQ900J8RD05ahS01XQ9`0J
8BT051/T00hE7`0@5R@04ALU014G8`0J82`041LP01<J8P0E72809Rhb01DO800C7Al0Ae1D02lh?`0;
51d0620[00dE800^=T4041PR00hG800J8bX04a/S01DL900D6b404aXO00804QXL00T051dL014J6@0>
5QT051/P018I7`0A62004aLP01DH8@0G6R<00`0G6R400`0G6Ql05QTN01<G6P02018F6@0E01<G6`06
3AL04ALS01<I9@0D6bD082La01PO:@0A62004QTQ01LN900I82H05ahT014H7P0E6R006AhT01DJ7P0?
51P04AHJ01DJ7@0?51L04AHI00803aDE00X04aTI010F500E6A`02`lB01PL7`0L82<04QHH01HJ6`0C
5aP03A4@0P0A5A@0100A5A<07B8N01@F5@0C5A@2018D4`0301DG5P0F61L03Q0?00@0418A00<03Q0?
01LI600:30/00P0G6AP03P0R92<0EeUH01<E500Q8b805QPG00lA400E5aH03Q0?01DG5P0F61L03a4@
01LI600I6aX02`d<1P0A4a80100C4a<04Q8B018B4P0A4A42010@400301<C4`0?3`l03`l?00804A4A
00@0410>00lA3@0?4@`0418=0`0A4`h04P0C5A00418=00lA300@4Pd04A<>018D3`0@4Pl04aDB014C
400>40d0418?014C400F61D04aDB00X<2@0>40d04A<@00h@30D03a4<00D04Q@?01<E400A4`h0418=
00lA300200d?2P<03a4<0P0>40/00`0=3`X030h900h@2`0200lA300300h@2`0@4P`04Q<=00@04Q<=
00H04A8<00D6000>3`T0414;01`M5`092P@200d<200;018A3@0@3`/03@`8020O6`0L6aL05A@@00l>
2P0B4@d05A@@018B3P0J71T00P0@4Q408`0J71/04A<B01`N7@1=Cdh01`T800T;2P0?4A0061XI01@F
501EEE<01PH401@D4P0000007alM01@D4P0@40h03@d;00l?3@0B4Q003Ph<00`<2P0A4Pd03@h900h?
2P0B4`h04a@?010A300<3@P02@X501@E400L7AP061TD010A300=30X03Pd;00803`h<00<040l=014@
3P0?3P`00P0B4@l01@0@3`d03`h<010?3@0=30P03`h:00803Pl:01D0418=01<E400D5Q4061dG00H;
1@021`40:2dW04E:@`0O8AT0824I02@U7@0L7AL02P/5010A2`0H6A@05QHD01/K6@04108061PF02LW
9@0A40`00P0?3PX0400@3`/030/700T8100:2@H03@`8010?2`0>3@T03@`801@C3`0B4@d04A0<01XI
5@0H5a<03`h:014@300?3PX3010?2`0500l>2P0>3@T03Pd900h=2@0?3PX00P0>3@T02P0?3PX04Q4=
014@300?3PX04Q4=014@300=30P04A0<00X91@0?3PX200`;1`0301TH500A40`040l;00803Pd900@0
4Q4=01LF4P0E510040l;2@0=30P0800?3@T04Ph;00`81@0B3P/03PX700X60`0A3@X03PX701<?300A
3@X03@T601PF4P0G5aD030`:00l?3@0410804A4?01@D4P0=3@/05QHD00X:200K6aT0410>01@D4P0=
3@/01@D301hN701dM7806QXH014A3`0J6QP04a<A0P0;2`T01@0=3@/03Ph;010?2`0?3PT03Pd90080
30/700X030/901<B400F51@020H700/92P081PL07A/L01@D4P0:2PP03`l=0P0<30X00`0820H03@d;
00d=2`0400d=2`0:00X:2P0B4Q802@T900D51@0=3@d02`/;00P8200?3`l04Q8B00l?3`803@d=1P0<
30X01P092@L04a<A010@3P0<30X04Q8@01HF50H030`:01T03@d;01<C4@0<30X00`<200X:20010@00
3@d=00h>3P0820P02`/;00l?3`0:2PX03`l?00h>3P020P804a<C01DE5@030`<04a<C00l=3P0>30d0
4@l@01DA4P0F4Q<03`/<00<040X<01/04PT<00l:2`0=30X03Pd;00l>300>3@/03@`:00h=2`0D4a40
6APF01DD4P0<2`T02`X800l>2P0?3PT030/700/:1P0=30P03@`:00h=2`0@3`d02PP9010>3`0<2P/0
0`4200d;3P0?3A800P0=2`h0400>30l03P`=00d;300=2``03@`:00`;2@0=30X03@`800T81@0J6QP0
?clo00d=3@0>3Ph03`lA014A4`00008200`;400`00P7300P7b@03`hD00`;4@0>3A<04A4C00h>400<
30`0000002<S8`0410H051<H00/:400@3aD030/@00T92`0<30h03`lA00d=3`0@41805QHH014A4`0<
30h03@d?014A4`0B4Q@0410@00l?3`0B4Q804a<C014A4P0F5QP03Ph@01@D5`020@H04a8G00`;400C
4QP01`D:00l=4P0W9BX04@lD00P62`0=2a004Q0E00l=4P0C4AH0518G0P0A3a@Dooooo`006oooool0
6`0?3PT03Pd900d<200<2`L02`X700X91`0G5Q@03`d=00`:2`0100003P`=00`:2`0B41<04Q0E014?
500?3A803@/@00/9300E4aH04Ph?00P20P0@1`L06Q0?01<:2`0>2``00P0100X82@02055?D00=00/9
2P091`P05aDF00h<3@0?3@h03P`=01LE5P0:20`04a4F02LU:P020@D02PP=018@5@0200l=4P06010>
4`0A3a@04@lD014?50092@/06QXL0P0@41801P0820X04Q8D01XJ700E5AL01@D700H6208051@F00T0
5QHH01@D5P0D51H051@F01<C5@0@41803`lA010@4P0A4A<00P0B4Q@0100C4QH0414F010A5P0A4QL4
018C600<010A5P0B4aP061TN01HG700D5AP04Q<E01TJ700?41804A8D01dN800F5aT05AHH0`0D5AL0
200E5QP041<E00hB5@0G6ah01@T<03Xn@@062Pd04ADH0P0F6Qd0100D61/061`O01PL7`0D5ah201DH
7`8051LL01004aHK01PL7`0F6Qd06AdN01PL7@0C5aP06AdN0:6TZ@0Y;3405aXO00001@0X:c00DEAI
01DH7@0D5a`05APM0P0I72405P0E61d04QLK014F6P0N8bL0724W01hR:P0F6R<09BTb01LK9@0S9c80
4ADP02<W<P0f>TD02Q4I01<J8P0B6B404aXR01LN9P0D6b<072<[01/R:P0Q:30201XQ:@805A`T0240
5QdT01LN900H7bD061lU01LN900F7B<06B4U01DM800C6ah05alR01HN8@0M9BP0620S01HN8@0G7R@0
5ahU01@K8`0M92`07B@^01/R;00N9Bl082La01/T;@0D82T09S<l01@Q:P0F8Rh04A/W01LQ;@0F82/0
5b0Y01LP9`0G8B@00P0I8B<0200N8R<061`M01LM7@0H71l082@W02P]<00F6al04AHJ0P0D6Al0:@0D
6b406R4Y01TP:P0I82X0C5=M02H]=@0M92`04APP01<J800F7B<05QhR01HN8@0D71l05ahS01lV;00Q
:3006b8[01@K9@0D6RP06R0^01/Q;@0/<Sh07bH_01dT;00F7B<051`P01DO8@0?6A/07BLZ00hG7P0<
5A`0:C8k01DN9`0<5Ah05QlX01lX<@0J8b`03aLP01<J8P0B6Al04QXN00804QXL00H05AhM014J6@0?
5aX04a/O014H7P0A620201<G800701DI8P0E6R005AXP01DJ800E6Qh051TM01<H6`02018G6P07018G
6`0E72@03A@N018I8`0A62809B`f02Xa>@02018I8@0D01@K8@0G7b805QhQ014I700F6al06QlS01LL
800B5aX051TL014F6@0B61P04ALG00hD500D6QP06AlM018H5P0>4QD07B4T00T=40031`P200dA4P06
01<G5P0>4Q4051TE01@I5@0@5A406QlK0`0?4a801@0@51<04ADD014E500<40l03A4@00803Q8A01@0
3A4@00`@3`0C5aH041@C014E500;3`h01@T801<G5P0>4Q405QXI01<G5P0>4Q404QHE01PL6`0i>cX0
9RPW00/=300C5A@051HE01<E50P04A<B0P0@4Q4200lA400701DG5P0?4A003@l>00lA400@4Q40418?
010B3P04010B3@0P014C3P0J71L04A<>00h@2`0?4@`03@l:00/=200B5140418?018D4@0:30T04A<@
01PJ5`0D5Q<06Q`I018D4@0G6AH04aDB00lA3@0>40/03@l:00h@2`0?4@`04A<>01TK5P0K7AP05QPC
01<E400@4Pd03@l:00h@2`0@4Pd200h@2`0300lA300A4`h04A<>00@03a4<00<03Q0;00lB300@4``0
100@4``0;`0B5@h04aH?014D3@0<3`P04QD>00/>1`0B4`h02``700l@2`0C50l03a0;01PI500G61<0
4Q<>00l@2`0F5a805aPC014B3@051`@02P`9018D4@041P<01`T607IhM@2CUI809RPU00H81@092`P0
6A/H00/=2P051@<03a0;01<D3`0<3@P03a0;00X;200=3PT02@X500l@2`0E5Q403Pl:00T:1@0@4@`0
30d800d>2@0B4`h04a@?00803a0;00d02``7018C3P0G61<05AHA01<D3`0:2PP030`:00d=2`0?3`d0
4A4?018B400=3@/03Ph<00<03`l=01@03Ph<00/<1`0>3`X03Q0;00lA300C5A005AXD04U>B01@EDl0
3aH?01LN5`2>UHh0d=O?034c;00;30@0414900h?2@0=3PP04A8<00<40@803@d;01H03`l=00d=2`0:
2PP040l;00h=2@0?3PX040l;00d<200;2PH03Pd900d<200N7AT02`X601<B3P0>3@T04A0<010?2`0A
40`04a8>014@300?3PX03Pd90`0?3PX00`0>3@T03@`800d<200300l>2P0800d<200?3PX04Q4=010?
2`0>3@T04Q4=014@300=30P200h=2@0;00l>2P0>3@T02PT500/:1P0@3`/04Q4=00l>2P0@3`/06APD
024P700H5a<00P0@3`/00`0C4Ph04A0<00h=2@0500h=2@03010?2`0B4@d030/7008040l;02403`h:
01<B3P0B4@d040l;00h=2@0=30P030/700d=2`0:2PP09RHT0000000B4Q003`l=00L71@0?3`d030`:
00l?3@0<30X03Ph<01DE4`020P002@T80451?`0410805ADC01/K6@0D51802`/900`<2P0?3`d0410=
00/<1`0;30H00P0;30L03P0<3@P03Ph<00D50`0:2PT010@400`<300G5aL02`/;00/;2@0B4Q002`/9
00l?3@0=3@/02@T71P0=3@/0200>3P`04Q8@00/;2@092@L03`l=00h>30061P@030`:0P0@40h0100?
3`d03Ph<00d=2`0=3@/200`<2P802`/900H030`:00l?3@0=3@/03Ph<00X:20020P0600d=2`0B01<C
4@00000051@B018B400E5A<04A4?00h>3P0@410020P800/;2`0>3Ph01`L700l?3`0A4A401@D5010@
400B4Q802@T90P0;2`/0100:2PX030X;018@4@0F51D300l;308040X<00<040/<00h=2`0>3@/0100>
3@/00`0@3`d04a8@018A3`0200l>300A014@300@3`X03`h:00d<200<2`L03@`:00T81P0>3@/03P`=
01hL7@0M6a`03P`=01<A500?3A803@/>00h<3`0?3A000P0>30d0@@0D4Q<04a8@00`;2@0A40h04A0<
00X:1`071`D02@T701PH5P0410803Ph>01@D5P0>3Q005QHH01`K800c<SL0E5=H010?500<2a003PdB
00`<3P0?3a402`/=02@T9P1DE5H05aLI01<B5`0@3a@03`hC00d=3`0:2P`03@d?014A4`0?3a40410B
01DE5`0?3a402@T;00`<3P0>3Q002`/=00l?3`0<30`0410@018B4P0>3Pl03`lA00h>400A41@01@@9
01@C600<2a406APN00X93P0H5a`0Ogj302/Z;`0:2@h02@P=018A5P0?3Q<05aHK01TH7@0D4aP04a8G
01Cooooo000Kooooo`0<00l>2@0=30L030/700`;1`0<2`P02`X801@C4@0j>CP061HG018@4@0=2``0
518C0P0B41D03@0A3a<040hB010=400?30h04Ph?01<>3`0A30`05Q0@01092P0=20T03@X;01<A4P0@
3Pl00P0?3@h08@0@3Pl04Q0A00l=3P0A3a003`d>00X82@0@3Q4040hC01PE6`0:20h040hD01LE6`0L
6R005aDK00h<4P0C41H040hD014?5@0K6Ah06a/M010@4P0=3@l04a<E00P82P0I6A/03@d?01HF600A
4A<04Q8D01LG6@0A4A<04a<E01LG6@02018B500401@D5P0@4180410B01<C5@80410B02D05ADG01HG
6P0E5Q/04a@I01@E6P0E5Q/05QLL01@E6P0C51T04Q<H01<D6@0I6Ql061TN01DF6P0J6ad05aPJ01HG
6@0Q8R@05AHH01<D5P0=3Q006a`N010@4P0L7Al051DG01@G6@0@51L051PK01HJ7@0B5QT061`O01@H
6`0G6ah05ATL01<G6P0G6ah06QhQ00<051LN00`04aHK01@G700G6Ql05ATL01@H6`0G6a`05QXK01<G
600E6AX07b8W05ULH@0O8RL201/N8`0E02T/<@0D5a`051LL01DH7@0H6b006A`Q01LJ7`0F6al05AXN
01PM8@0D6Ah05Q/Q01@I800G72<06QhW01TM9`0L82/08BD`03LkAP0J8BT05A`T00806R4Y00X06B0X
01<J8P0I82P06B0X01XQ:@0H7bL06R4Y01@K8`0G7R@0620T0P0I8BD201XQ9P1^01PP900I82@05QhQ
01HM8P0I8BD06B0U01DM800K8bH072@W01XR9P0J8BL06b8Y01LN9@0O9Rl07RD^01LN:00I82X06B8[
01TU;00J9bh062D^01LR;00K9C00628]01TR;@0I8B/06B4Y01/S9`0L92H07B8U01dO8@0P8B<071lP
01dO8`0C5aX06AdP01dR9P0F7B005A/O01HL8P0B6Al04ATN01HM9`0c>T@05ahX028Y<@1@Eel0@4M?
01PO9@0F7B<06B0U01/S9P0F7R404a/O01LO9@0K8bX06B4Y01@L9@0D6bP04aXX01`S;`0_=T808BTa
01TQ:00G7b@051dQ018K7@0?61/05AhQ01HO8`0E7R80620W018J8P0J8RX06b</01lW<@0C6bD06B4Y
01@L8`0B6R0051dQ014J700B6ad06B8Q01/U900D7B00624T01XR:00E7BD06AlW01TN9`0G7BD041HL
01@J800C6Al04APK01<I7@0I82806AlR01<I700A61/0@dYB02H]=`0L8bd04QTR01HM9@0F7B@04aXQ
018I7`0B6Ah201@L7`0F01<K7P0D6A`041DI01TN8P0F6ah04aPK00hD5@0F71`02a4A01@J6@0@5Q@0
:Bl/01LM6P0E6AX0:Bd_01@H6P0;3a005QXJ01<G5P0A5A@05AXF01<H50804AHA01l04AHB00hC4@0=
4Q404aPG014F500?51<03A8A00lD4P0@5A<04AHE00hC4P0A5QD0314?018G5P0A5Q@04QLE00hC4@0?
51<03A8A010E500>4a805AXH01@I600K81h0?D500<c>c@1VJ6L030h=01HH5`0@4Q404Q@C00@04aDD
00<04Q@C014C4P0C5A@00P0B51<0100A4a80418A00lA400B51<2014C4P0?018D4`0A4a80418?014C
3`0A4`h04aD@018D3`0@4Pd04Q@?01hP6`0<3PT0418=014C3P0B50l04A<>00803a4>00H051HC01<E
4P0L7Q/07b4N00d?300?4@h2014C4007010B3`0F61@020X701DG4P0@4Pd04aD@01XL5`03010B3@0C
01<E400B50l0418=018D3`0D5Q404A<>00d?2P0?4@`08R@O018D3`0C5A003@l:01@F4@0@4Pd03Q0;
00`?2@0A50d04QD>00lB2`02018E3P0300hA2P0?4P/03a4<00<04A@=00T05QLB00h?2P0>3`X051D@
018C3P0>3`X04Q<>00h?2P0?40/00P0D5A006P0?40/04Q@A00lA3P0O8Ah05ALD00d?300Q8b00=3Hc
00`>2`0B51403a4>010B3`0<3P/04A8=00h?2@0@4@`04Q<=010A300>3`X0414;00h?2P0C50h061TC
01<D3P0?40/03Pl:0P0=3PT0100@4@`04A8=010A300C50l3014B3@0300l@2`0@4@`0410>0080410>
0`0?3`d01`0=3@/05aLE01<C4@0>3P`04Q8@00`<2P0>3`X00`0?4@`0700B5Q005Q/E08bAR`1lPW/0
51/D01<J4`21RH80]Kbd02la:@082@404149014B300<3@L020T301<D3`0B4Q00410>00h>30061P@0
5aLE018A3@0D4`l03`h:00h=2@0?3PX03@`8010?300=30P2010?2`09018A3@0A40`0>cXf01<B3P0:
2@D030/7014@300;2PH03Pd900804A0<0`0>3@T0100?3PX03@`800l>2P0@3`/300l>2P0:00h=2@0=
30P040l;014@300>3@T040l;01@C3`0@3`/03Pd9018A3@803`h:00X04A0<010?2`0B4@d06APD01/J
5P0A40`030/700h=2@0B4@d040l;0P0>3@T0:P0?3PX04A0<00d<200>3@T04A0<01<B3P0<2`L040l;
01<B3P0>3@T010<1014@300?3PX02PT5018A3@0G5Q802PX8014A3`0Z:RP02`/901@D4P0<30X06a/I
00/;2@0E5A<01PH400l?3@0>3P`030`:00l?3@0>3P`0410>00/;2@0@40h051@B01DE4`0=3@/06ATG
00d=2`0=3PX030d800`=1`8030d800/03Pl:018B400=3@/03`l>00`<300>3Ph0>SXj01PH600A4@l0
5QHD00T91`0300`<2P0>00d=2`0?3`d03Ph<00d=2`0>3P`0410>00h>300:2PP05aLE00h>300?3`d0
2PX801DE4`0@40h300d=2`0300/;2@0@40h030`:0080410>00P03@d;01<C4@0:2PP05ADC010@3P0;
2`T03@d;00/;2@H03Ph<0P0G5aD0<00D51802@T8018B400=3@/04A4A01DE5@0@41003Ph>018B4P0:
2PX02@T900h>3P0=3@d02`/;00X:2P0>3Ph02P/;010A4@0=3Pd03@`<01DC500A3a003@X;00l;300A
3@h04@`=00h92`0>30/03@`:00l>300Y:2H04Q4?00d<2P0<2`T03@`:00l>300A40h040l=014@3P0A
40`040l:010?2`0?3PX03@`800d<2P0A40h05A@B00h<3@803@/<02H02PP9018@4`0?3A803P`?014?
4P081`T040h?00d;300A3a004Q4?00l>300F5A<05aHB018B3P0;2`P03Ph;04Y:B00W9bD03`l>00`<
3@0A4A8030`>014A500X9b/0=cLj00h>4@0=3A003PhA00`<3P0?3a4030`>01PH6P0X:2X030`>00X:
3@0Y:2`05aLJ00l?4@803Ph@00H03`lA00d=3`0=3@l030`>00l?4@0@418200`<3P0G018B500?3`l0
3Ph>010@400B4Q803`l@00d=3`0@41803`hB010?500D4aP04Q4G02d/<P0C4QL07QdR08>2Q`0m?440
51<H014@5@0@3a@02PT>01<B5`0B4AH00P0?3Q<Dooooo`006oooool01@0?3PT030/700/:1P0<2`L0
3@`900802`X8014061LF00`:2`071@H03P`=00l=3P0?3a403P`@00`:3@0;2@`030T:00h:2`091@H0
4@d>01@B5@0=2`h03`d@01@B5@0200h<3@<03@/<0P0<2P/03P0@3Pl030X;00h<3@0D4Q<05A<F028P
9P0D4AP02`P?00h;4P0Q7RD0B4E<01dJ8@0?31<04a0G0P0>2a806`0J61d061PJ00/;3@0C4aD0410B
00/;3@0C4aD05aLI00/;3@0@41805QHH00000P0C4aD03@d?01HF600G5aT030`>014A4`0F5QP04A4C
01@D5P0@41803`lA01@D5P0A4QH051DJ01DF6`0201HG700301DF6`0C51T04Q<H008051DJ01404a@I
01@E6P0C51L061TK01/L7P0H6A/09RLY020Q8`0I6Q`092DW05AEE`0U9RP05QLI014B500M82805a/N
01HJ7@0201@H6`0501DI700H71l061`O01LK7P0F6Qd00P0E6A`0200K7RD05APO01PK8P0P8bP06ahS
010C600C5aX051PK0`0F6Q/05`0E6AX05aXO01dP9@0F6Ah05aXO01XM8P0I72404QDJ01<F6`0F6Ah0
6A`Q01XM8P0K7R<06AhR01LL800F6al061dQ01TN8`0F6b406QlU01XO9P0J7RL06alZ0080720[00P0
:c8j01/R:P0P9bl061lW014H800@5al05ahV01PO9`806B0X00@06R4Y01/R:00H82<0620S0P0I8B@2
01XR9@0E01HN8@0H82<0620S01HM8`0G7R@061lU01@L7`0K8bH07RHY01`T9`0J8BH06R4W028Y;`0A
62003A@L01DL9P0M92h06R<Z01HR9P0F8bT04b0V00805R0Z01L04adW01TQ;00I82X06B0X01PO9P0H
82<06QlR028R9@0Y:R`0:2T[00X<400]<C@0Ri2C02X`=00E7B009bhd00lG7@0G82D06B8Y028Y<`17
CUP0:S4k02H]=@0202<Z<P0D01`S:@0F7B<05QhR020X:`0N9RT05alS01PQ9P0I8RT05b0X01@M9P0D
72T05Qh[01DM:00G7bX05QlW01<L8`0F7b@051dQ018J7@0D71l201HN8@0;01DM800C6ah04aXP01DL
8P0F7BH05QdW01LN:00@62402a@K014J7`0C7B000P0=5aP06P0:51<08R`[038l?P0W<3@03QLL018K
8P063AD031<K01/R:P0G7R@06B0V010G7@0I8B@05AdP01PP8P0I8B<04QXL00hF6@0B6B404QTS01DL
9P0C6R8082L_024X;P0D6b405A`R0P0G7b802@0E7B0051`O00/@4`0K82<051TL00P=400N8bH0318B
01@J6P0201XP7P0^00L=2@0:40`04QPD018F5`0A5AH05ATJ01HJ6`0@51<04ADD01LL600F6aL05a`H
01HK5@0A5Q003A8<01`R800>51801P`:00X@3P0L8R0051XH00lE4`0<4Q003A<A00L=2`0@5Q@03A<A
024W9@0C6AL03Q@B00`B400F71X0318@00D;2@0A5aD07B<Q014G5@0G7A/08BLU038d<`0F61L00040
01TK6P0K7A`0418A014C4P804Q@C00T04A<B010B4@0?4A005QPG018D4`0@4Q403a4@014C4P0B51<0
1@0A4a802@0A4a004A<?010B3@0D5Q404Q@?010B3@0C5A0061XE00h@2`02014C3P03018D3`092`H0
4A<@00804A<@00H0418?00lA3P0B51404aDB014C400B514201@F4`0I014C3`0=3`X01`T400T;1P0C
5A006Q`G01<E400>40/04A<>01HH4`0A4`h03Q0;00lA300B50l05aTD018D3`0J71L0;BlZ01<E400;
3@P08bDP00T;1P0A4`h03Q0;00d?2@0201XM5P09010C300C5Pl04aH?014D3@0@4``03Q4:00d@2@08
2`@02Pd60080414<00D04A8=01<D3`0D5A004Q<>00d>2@0200`=200900l@2`0@4@`04A8=018D4@0;
3@X05ALD00X<2@092`P04A<@00D03a4>00<03a4=00h?2@0>3`T00P0?40X2010A2`0=018C3@0A4P`0
3a0:00d>200>3`T03a0:00h?2P0@4@`03a0;00h?2P0?40/04Q<>00l@2`02014B3@0300h?2P0=3PT0
3@h900803@d;0`0>3P`01`0?3`d071`J00h>300;2`T03@d;00T91`0D51800P0A4Pd06`0>40/03@l:
010B3@0B5a403Q<=01hS7@083`P010/400lD3`0I81P04Q@<00@500092P803Pl901<D3P0M7QP04a@?
00P81P0;2`T0410>01HF500_;bd05QDA01dL600D4`l04A0<01DD4003014@300H018A3@0A40`03Pd9
00d<200`;b/03@`801lN6P0C4Ph03Pd901LF4P0?3PX02@P400/:1P0<2`L03`h:01@C3`040`005QDA
010?2`0<2`L06QTE01@C3`0?3PX03Pd90`0=30P900l>2P<040l;02H03`h:00h=2@0>3@T03`h:010?
2`0A40`06QTE018A3@061@403`h:01DD400A40`03@`8010?2`0:2@D04a8>01/J5P0>3@T03@`801@C
3`0>3@T06APD024P700920@03@d;014A3`0@40h03Ph<010@3P0=3@/06ATG00L71@0L71X03`l=01<C
4@0<30X01`L500`<2P802`/901@030`:03lo?@1?Cdd07alM00`<2P1ADDl0;Bd[00H70`0;30L030d7
00h?2P0?40/04A8=01PH5P0M7A/04a<B01<C4`0E5AD071`L010@40D03@d;00H03Ph<00/;2@0>3P`0
3Ph<00`<2P0=3@/2014A3`0500`<2P0B4Q003`l=020P7P0B4Q00100=3@/200h>300<00d=2`092@L0
3`l=00h>300;2`T05ADC00h>300C4a4030`:00/;2@0?3`d03Ph<1P0=3@/0200B4Q008b<Q01lO7@0;
2`T051@B02PX9P1aLG403@d=0P0:2PX0:@051@D02PX:02h^;P1FEUH010@4014A4@0;2`/0;bl_02HX
9`082PT04A<B00T92@0A3a0081hO00`:2`0=2@X04@d>018>3`0C3a004a4@010?3@0I61H06aXH00D4
0P0E518040l=00d<2P0>3@/040l=00/:200<2`T04A0<014@2`0A40`03`h:00d<200=30X03Pd;00l>
300?3@h03P`=00803`d>00T0518E00L52P0K6A`02PP;018@4`0M6a`03`d>014?400A40h00P0@3`d0
3`0@3`/02`/600l@2`0>3`X04A4?01@D4P0=3@/02`/;010@400:2P`03@d?00/;3@0:2P`03Ph>00l?
3`0200l?4@0800h>400=3@l03Ph@00h>400L71h05QHH030`<00;2`/300l?4@@03Ph@0P0?3a406`0=
3@l03Ph@018B500B4Q804A4A010@400?3`l04A4B018B500C4aD03`lB018A5P0=31401`H<01@C6@0@
3a@03PdB01dL8@0K6Ql03PdB01HE6P0?3Q<040lD01DD6@0>3A804Q4F00/:3`0Dooooo`006oooool0
3`0=3PP02P/600X;1P0<3@P03@h:00`<2P0B4Q000`<2014A4@020P803`l?01DE5@0@41803`hA00h<
3`0200l;300800l;2P0C4A804a4C018A5P0=3Q<03a8I00011P0@3a4200l=3P09010>3`0B41404a4B
018@4@0E4a@03`d>00h<3@0C4A80518E008030/A0P0?3Q@00`0;2Q006aXP01HE6`02010?5@0F00d<
4P0>3A<04Q4F00d=3P0>3Ph04a<C014A4@0=3@d03Ph>00d=3@0O7al0000000l?3`0:2PX04A8D00X;
3`0A4QH071dQ00T:3P0:2`l05aPL00l@50804Q<G00P0414E018C5`0>3a<04ADH01@H6`0C5aX041@G
018F6@804aLJ01805ATL01<G6P0A5AP051PK01@H6P0?4a@05a/L00lC500=4A806AdN00dA4P0B5QL0
=c/l01TM7P0A5AH01`/<01<G6@0E6A`301@H6`0301HJ7@0G6ah061`O00806AdP00P05a/N01DI700A
51/051LN01LJ8@0>4AH01@P=01TL8@804aLJ100F6Q/01P0G6Ql05APM01HI7P0A51T061/P01`O9080
5APM00L05QTN01PK800I724071lT01TN8@0H7B005a`O00806AhR00<05a`P01@I7`0H72@00P0K7bP0
1@0I7BH05QXS01HM9@0B6B407RD]00805ahV00<06B0X01PO9`0H7bL00`0I82P00`0I82H0620R01TQ
8P0201TQ8`806R8T00<05QhQ01TQ900H82<00P0G7R@0100I82H0620S01/S9@0L92H201/S9P0401`T
9`1=E5X09bhf01XQ:@809Rde03@06R<Z01TT9`0K9RX062<Y01TS;00J8Rd05QhY01PN:P0H7bT061lW
01TN9@0H7B4061dP01HG6`0H6Ad05QLK01dP9@0D5a`09R/_01PN90032Q006b@[00LA5`0?6R002QDK
00P@6P0S:S@09Rdg034h@00N9Bd07B@/01LN900D6b404aXO01TQ900J8RD05b0T01PQ9P0I8RT05b0X
01@M9P0D72T05Qh[00hF8@0C6bH05AhV00`E700A6Ql051`Q01@K8@0E7B005QhQ0P0E7Al06`0A6A/0
3aLJ014H7P0F7BH061lY01HL:00D72@06b@[01lX;@0I8bH051hO01<M7P0D7Qd05R0O018L7P0M9bX0
82T^018K8P0A620041LO01PO9`0A61h051/Q01<J800K8bH051`O014I6`0201HN800;01@L7P0A61h0
41LO01<J8P0?5Qh061lW01HM8`0>5QT04QXM01LO8P0D71h00P0A6A/07@0@5AP08bP[018G6P0@5QH0
5A/K01XP800220H0:Bl]00X@3@0@5Q804aTE04A:AP0D61T03Q8B014E500D61L041@C00hC3`0E6QH0
2Pl:01@I4`0G71H03Q<=01<H4P0E6aT0318@01DK6@0B61H010X800802Q0>01P02@l=014G5@0=4a40
51XH01DK6@0A5aD041HD00T?3@0630X05adK00X@3P0<4Q004aTG00dC4@0:40h041HD00T?3@0=3`h0
5ALF02@V9@0:30/05aTH00h@3`0A4a82018D4`05014C4P0@4Q403a4@01@H5`0?4a800P0<40l00`0@
51<04aLF00hB4@0400hB4@0300hC3`0>40`03a4<00804Q@?00@0418=01<E400E5a805aTD0P0D5Q40
0`0K7AP03Q0;018D4@02014C400>010B3`0?4@h04A<@010B3`0>40d03a4>010B3`0?4@h03Q0<02`^
:@0;3@P05QPC010B3@0:30L200h@2`0C010B3@0E5a80418=00h@2`0<3PT02P`701DG4P0>40/07R0K
01/M600B50l0828M075cKP0S9B004A<>01DG4P0E61807B8K01`Q6P0200lD3@0=010E3P0=4P/020d6
00/@2@0A5Pl04QL@01DJ4`0=3`X03a4<014C3P0@4Pd03a4<010B3@02018D3`0:010B3@0>40/03Q0;
00d?2P0B50l02`d800X<1`082PD061XE014C3PH03a4<0`0?40X3010A2`0=01HG4@0C50h03a0:00`=
1`0=3PP0414;00l@2`0@4@`03a0;00d>2@0>3`X0414<00l@2`02018C3P0300h?2P0<3@P03Pl:0080
30h;0P0=3``200h@3@0T00`>2`0B51403Q0=01@F4`082PL04a<A010A300B4@d03a0;00h?2P0@4Pd0
51HA00L9100:3`T0314;00hC3@052@@051TB010B2`0<3@D03Pl700l@2P0K71H0:b`V00l@2`061P@0
5aLE01@D4P0C4a407QhL014@300G5Q8040l;00h=2@0B4@d03`h:0`0B4@d05`0@3`/03@`800`;1`0;
2PP040l;028Q7@0B4@d02PT501DD400c<Rh05aHB01@C3`0:2@D010<000/:1P0A40`07A`H00l>2P0C
4Ph0<2l[01/J5P0?3PX03Pd900803@`800<03Pd9010?2`0B4@d00`0A40`2018A3@@03`h:100>3@T0
5P0?3PX040l;014@300L6aL05aHB00`;1`0B4@d05QDA010?2`0>3PX04a@?00L80`082@@030d800X;
1P0?40/04A8=00/<1`0310003a0;01TJ5@0<30X2014A3`80410>00L030`:00d=2`051@<061PF00h>
300?3`d03Ph<00806ATG00d03Ph<014A3`0@40h06QXH018B400H61H05ADC028R800<30X02PX7014C
3P0B5@h0418=00803Q0;00L04A<@010B3`0210<00@<200/=300B51<02@/:00D03`l=00`03Ph<00/;
2@0=3@/03@d;00`<2P0=3@/03`l=00H70P0@4@`020T400`=200L7AP200d>2@80414<00H03@h900`=
200@4@`03Ph<00l?3@0>3P`200`<2P0300l?3@0=3@/0410>008030`:0P0?3`d300d=2`<03Ph<02l0
3`l=01hN700J6QP020P601@D4P0Y:BL0E5AD00410@0;2`/02PX:00l?3`0S8b<06a/K00410@0820P0
61PH00X:2P2UYJD0DE=B000100092`X051HE00D51@00000061HG010>3`0?3@h03PX;00l;300D4Q40
8R4O0450?P0D4a402PT701PG5@0>3@/03@`:00h=2`0?3P`02`X800d<2P0A40`040l:010?2`0?3PX0
3Pd900h=2`0200l>308040h?00X03`d>00h<3@0@3Q400@0401HD5`0610L06QPK01PF5`0>30d03`d>
0`0?3P`0400?3PX04A4=00`=200;30L06AXE01`M600?3`d04A4?01HF500B4Q805QHF01<C4`0A4A<0
410@00l?3@0?3`l200h>400700d<4@0:2@h02@P=00L72@061PH02`/;01DE5@03010@4P0600l?4@0>
3Q003Ph@00l?4@0@41804A4C0P0?3a404`0B4Q@0410@00l?3`0=3@d030`<00l?400@41804a<E00l?
4P0A41D05A@I010?5@0510X03a0D00d>4P0?41@03PlC00d>4P0C51P00P0A4QH0100>3a<010D900h?
4`0>3a<Dooooo`006oooool09P0=3PP02``600X;1P0=3PT03Pl;00d=2`0@40h03Ph=01HF5P071`L0
3Ph>01LG5`0>3Q003`h@00h<3@0@30d03``<00d;300920X0414F00/@5P0P:34021@O00P@6@0?3a40
3`d>010>3`0E4a@06QPI01`J6`0<2P/05aDF01@B4`0A3a004Q0A018@4`0H5ad03PdD0P0?3QD0500=
31<03PdD00d<4`0A41L03`hE018A600D4aX040lD010@4@0B4Q803Ph>00l?3`0B4Q804A4A00l?3`0=
3@d04Q8B01@D500:2PX04Q<E0P0A4QH08`0L7B4051DI00X;3`0@4AD02@X>010A5@0D5AT0414E01DF
6P0@4aH04ADE01DI6`0B5QL03Q8B014E5`0C5aP051PH01DI6`0B5QL041@D01@H6P0H71d03a<D018F
5`0Y;Bh02`l@01DI6P0H71d041@E01HJ6`0?4a@06alP01<G600E6A/05ATL008051PK00<05ATL01LK
7P0E6A`00P0E6A`02@0F6Qd05a/N01TM800G6R404aHM01LJ8@0P8bP06A`Q014D6@0201@H6`0801DI
6P0F6Q/05QXK01LK700G6Ql041<H01XM8P0@4aP201LJ7`0301/N8`0I72405QTN008051LL00@05APM
01LL7`0G71l05a`O0`0G72001P0E6Ql05a`R01TN9@0J7RL06AdV01LK90806B0X00@08BP`01TP:00K
8RX07bH^0P0I82P301PO9`0801PO9@0I8R806B8P01TR800I8R806B8S01TQ8`0G7b8201TQ900<01LN
900H7bD06B4T01TQ900I8B<0620R01PP8`0K8bD06b<V01XR9P0G7RD061lV0P0K8RX0<P0F7b@06B@V
01/V:@0H8bL06B<Z01XR;00F7RP06R0[01XO:P0J7bP06QlV01XO8`0I7R807b0U01lQ9`0E61h07b<X
01HL8@0R:S404QXQ00hH800;5ah0B5EL014O9`0?72@04QXT018I8`0?5R007bH^020W;`0Y<3P05ahT
01PO9@0F7R8051`O01DM800E7R805AlT01LQ:00F82P04adV01<L:00F7b/051dX01@M9`0O:C405b4X
00hH7@0D72405A/Q0P0D6ah201@K701P01<J6`0@5aT04APK01PN9@0I7bT05AXV010H8P0C7B@04Q`Q
00hH700B7Ad04ahO018M6`0?6QP041/M01HP8`0E7b<05AlV01`T:`0@61l04QXR00lG7@0A6Ah05AdS
010I6`0?61/03aPJ014J6`0C71h05QlQ01@K8@0A62005A`T010G7P0E72804aXO00dE600C6ah06b<U
01HN800B6Q`04a/M01lU9P0:3Pl092T[07MmO@0U:b/04QLF01XP7P0oAD<04QPD014G4P0F71L05A/F
02HZ:@0F6QT03a<B018F5@0C61D05AXF01DJ5@0@5A004AH@010E3P0=4P/041D?00hD400B6QL01@/8
00dD4P0C6aP0318@01HM6`0<51405QhK00lG500<4a403A@B010H5@0=5A8051`I00`D4@0>5Q<04ATF
010H5@0?5Q<041PE018J5`0=51803aDC01/O7P1hNWT03a4@01TK6P082@P07b4P100D5QD00`0B51<0
4A<B00lC4P0300lC4P03010D4`0A5A@03a<B00@03a<B00@03a@@00h@300?4@`04A<>100B50l01P0F
61<06A/F00d?2P0@4Pd03a4<014C4080418?00D04Q@A01<E4P0D5Q<04Q@A014C4002018D4@0R010B
3`0=3`/06adH00L9100C5A003a4<03Xl=`0P8Qd03Q0;00lA300B50l03a4<00h@2`0A4`h03Q0;01@F
4@0;3@P06adH00@60P0<3PX04Q@?0412?@0F61<01`T401PJ5@0>4P`051TB01DJ4`0>4``0314:00dB
2`0>4``041D>00lD3@802@h700/04aPA00`>2@0?4@`04Q@?00h@2`0=3`X0418=00/=200@4Pd04A<>
00h@2`02010B3@0600X<1`0D5Q404aD@00L9100^<2/030h91P0>40/00`0@4@/0414:010A2P03010A
2P804A8;00L0414:00l@2@0@4@X04A8<010A300A4Pd03a0;00803@h900L03a0;010A300?40/0414<
018C3P0A4Pd03a0;00804A<@02@0418?00lA3P0>40d03Q0=03@f<`1QHf007R0M00`>2`0@4Pl02@T7
010?2`0C40d04Q0<014>2`0A4@`04a@?01<C3P0=3`X01`/500lB3@0>4P`07B0I01HG400D5@d04a@<
00d>200@4@/05aPB010A300A4@l03Ph<00l?3@0@40h03`l=00d<200A40`200d<2003010?2`0>3@T0
4A0<00804A0<00/040l;00l>2P0?3PX030/801XI5@081`D040l;01TH500?3PX07QdI00h=2@0201LF
4P0<01dL600`;b/04A0<00d<200<2`L04a8>01PG4`0<2`P03`h:00h=2@0=30P03Pd90`0?3PX00`0>
3@T03`h:010?2`02014@308040l;00L03`h:00h=2@0>3@T040l;014@300@3`/03`h:00<03Pd900l0
61LC020O6`0H5a<02`X600`;1`0?3`/04Q<>00l@2`0C50l03Pl:018C3`0@4@`03a0;018C3P0C50l0
0P0?40/06`0=3@/0410>00h>300=3@/04A4?018B400C4a40410>00`<2P0=3@/03`l=014A3`0:2PP0
4Q8@00`<2P0@40h04A4?00/;2@0>3Pd04A4?00`<2P0B4Q003Ph<018B3`0A4`h04A@=010B3@0200d?
2P0700lA3P0C5A803a0>01XL6`0620L03Q0?01<E500300l?3@803Ph<00<03@d;00/;2@0=3@/0100>
3P`0500<3@P051D@00d>2@0A4Pd03a0;010A300C50l05aPC01DF4@0>3`X030d8014B3@0@40h051@B
00l?3@0<30X03Ph<00/;2@092@L03@d;0P0B4Q001@0>3P`030`:00d=2`0=3@/03Ph<00803`l=00D0
410>00h>30071`D030`:014A3`0200l?3@0E00h>3P0B4Q804a<C00X:2P0>3Ph02`/;00h>3P0C4a<0
3`l?00/;2`0?3`l06ATI01hP7`0J7A`041<B00T;2P0F5QH0410@01DD500?3@h040h?00803``=00L0
40h>01`K6@0h=cD03`h<01LF500@3`d04A0>008040l=00D04Q4?00l>300A40h04a8>00l>2@0300l>
2P04010?3@0>3@/030/900l=3P<04@l@00P03Pd?02<Q9P0>30l040hA00h<3`0<2P/040h?00d;3080
3Pd;00h03`h<00l>2P0B4Pd03Pl9018C3P092PL01@H300h?2`0;2`T04Q8@00h>3P0C4a<0410@00`<
3@80414=00/03`l>00h>400?3a403`hC01lN8`0R8BH03Ph@00h>3P0<30X04A4>010@4002010@4P80
3`lA00@03Ph@00d=3`0?3a40410B0P0?3a400`0A4A<0410@014A4@0201<C4`0:018B4`0@41804Q8D
014A500<2a0051<H01lN900C4QP03PlC00l@50802@X>00P03a0D00h?4`0>3a<051DI02l`=00S92P0
3a0D00`=4ACooooo000Kooooo`0J00h?2@0<3@L02``700d>2@0>3`/03@d;00/;2@0<30/00P82018B
4P0C4a<010@400d=3`0>3@h040h?018>3@0@3@d03@d?00D62P0J7bH0DU]T0:Jd`@1<GFd03adZ00l?
4P0?3@h200h<3@0@00l=3P0@3Pl0518C020N7`0L6Q/04a4B010>3`0?3A002PT@00d<500D4a/04A0H
010?5`0510`04Q4I01<B6P804A0H00H040lG00d<4P0D51D0410@00/;2`0=3@d2018B4P0H01XJ6P1?
Cdl030`<00d=3@0U9BD030`?01PI7@0A4QH05QLK01`M8@0E5QX07b0T014B5P0B4aL04a@H00`=4@0B
4aL04ADF01@H5`0G6aX05ATH01<G5P0D61L05ATH0P0B5QD201<G5P0901@H5`0C5aL04ADF014E5P0m
@D804aLH018F5`0<41404QHG008041@E01@04ADF00dA4P0J7R007b<V01`P8`0H71l05QXM01DI700J
7R4061`O01<G6P0A5AP04QHI01HJ7@0G6R404aHM014D6`0V:Bh0=cXo01/N8`805QXM00@05ATJ01@H
6@0E6AX05QXK0P0G6Ql0100K7R<051LL01HI7P0B5AX301<F6`0A01@G700E61d05QTN01DJ7@0F6ah0
5a`O01DJ7@0E6Qh05a`P01/P900J7b@061dS01TM9P0K7bP07B4Z01LN9P0@5al00P0D6b<00`0]=3`0
>d9:01LN9P0301LN9P0;01PO9`0H7bD06R<R01XS800I8Ql06B8Q01TQ8P0H82805alR01XR9@0I8B@0
0P0H7bD0200J8RD0620R01HN800E7Al05alQ01TQ900H82<06b<V0P0R:Bl03@0@5al04aXR01LP9@0I
92D06RDW01LR900I8RP06B8[01DN9`0J8B/06alZ01/O:00J7bD00P0J7b<0A00D5ah08RD/028W;@0B
61l0DEYQ0<3;d@0P;3@06RL_01XY<01aPXX02Q/S02Le?P0T;3D09Rdg01LN:00F7BD04aXR01LN9P0J
8BL06B0V01TP9@0C6ah04QXM01@M8@0F8BD06B@Z01TT:`0F82T05Al[01<M:@0I8bd07RPb024[<`0H
8bT041/O014I7P0C61h04aPL018G6P0C6AT051XH01DK6P0F71`05a`O01TN9@0I7BP05QXV01<K9@0B
7B<04ahR01PS9P0C7al041`L01@P7P0:5Q@02QDG01<N8@0H8bL092le0419D00S;3<05AhU01<L8@0A
6Ql051dR00dG6@0C7Al051hO0P0<5QL06P0@6Q/06B0V018I8@0E72@04APN01@K8@0C6ah051`O01PP
8`0K8bD05AdO014I6`0?5aT08bTY01DK6`0A5aL0<SPh01`R8P0I7ad051XH010F500A5a<020l800T@
2@0:4@X0720O0P0E6AP0:00F6QT041@B00`A3@0:3`T041D?014F400B5a004aPA00XA2P083PX041TF
014J5`0B6aP02Q<@04=<B@0]=S<02a@A00hG500=5Q<04a`I020Y9P10BDH03AHC010I5P0B6aP02a@A
00XC401BFeP0?4E2051IEP0E7Q/05b0M01lU8`0>4Q40?Cln00H81`0S9B@05ALF01@F5@0A4a82018D
4`05014C4P0@4Q403a4@00`@3`0?4a800P0A5A@00`0>4Q40310?010D4`04010D4`0>010E4@0?4@d0
4A<>010B3@0B50l04aD@010B3@0J71L092HQ03Dg<P0N81/04A<>01DG4P0@4Pl200lA3P05014C400E
5a@05ALD01<E4P0B51400P0D5Q<0200B51405ALC00X<1`0E5a805aTD01/M601LGUT0:bdX0P0>40/0
400@4Pd03Q0;00h@2`0A4`h0418=00d?2P0A4`h05QPC00D70P0F61<04Q@?00L9100C5A003a4<01`N
6@0=4@/200/@2@0>00`A2P0=4P/03A8;00`A2P0?50d03A8;00lD3@0Q9Ql0@TM000lA300@4Pd04A<>
010B3@0>40/200lA308061XE00T0418=018D3`0@4Pd05ALB00L9100<3PT03@l:00L9100A4`h01@0=
3`X0100=40X04A8:014B2P0A4PX3010A2@0300`=1@0=3PH04A8:00804a@<00X04Q<;00l@2`0@4@`0
3a0;00d>2@0>3`X0414<00d>2@0<3@P03@h90P0@4@`03P0=3PT02P`900/=2P0<3P/03@l<00lA3P0@
4Pl02P`901`N6`000@001PP501@F4`0F5Q@040`90P0C3``05@0B3P/04`l<01<B3P0920@05QDA00l@
2`0E5Q404A<>00H90P0>3`P03a08014B2P0B4`d03a0:00d>200>3`X05QHD00@40P0F5Q@03@d;00h>
3003010?2`<04A0<01<040l;00l>2P0?3PX040l;014@300B4@d051<?00`;1`071P8051<?014@300?
3PX05A@@010?2`0D4`l02@P500P70`0F5A4040l;00804A0<00@020L300X91@0C4Ph03Pd90P0=30P0
1@0>3@T03`h:00l>2P0?3PX040l;00@04Q4=00<04A0<010?2`0@3`/00P0@3`/0?00?3PX03Pd900h=
2@0?3PX040l;014@300B4@d04a8>018A3@0<2`L03`h:018A3@0C4`h04Q<>00`=200:2`H01`P302<T
7`0?40/05QLB02PY901GF5<0@D8m01`M600B4Q004a<A00l?3@0=3@/051@B01PH5P0B4Q006ATG00L7
1@0D5180410>00P81P0E5A<06ATG00/;2@0=3@/03Ph<00d=2`030`403@d;01DE4`092@L02PX800T:
1P0=3`X03a8;010B3@0=3`X030h900h@3@0?4@h04aDC00H81`0F61L05ALF00L920803`l=00@03Ph<
00d=2`0<30X030`:0P0=3@/04@0?3`d04A4?010@3P0<30X05QLB00@50P061`803@h9010A300D5A00
2``700l@2`0@4@`03@h900h?2P0B4`h03Ph<0080410>00D03@d;00/;2@0<30X030`:010@3P0201XJ
6003010@3P0=3@/03@d;00803Ph<0`0@40h02`0;2`T03@d;014A3`0=3@/02`/900l?3@0?3`l02@T9
010@400<30`04a<C00805ADE00d05QHF00L71`0@41002`/;00h@3`0C5QD01@T800X>3@0B51<03`l?
0000000;2`/030X;008040h?00l03@/<00l=3@0>3@/030/900L6100D4a402`X8018A3`0=30X03Pd;
014@3P0=30X040l=018A3@0?3PT00`0?3PX0;@0?3P`03@`:00/:200=2``040h?014?400B41408R0S
08B2Q`0f=3L05A<F00T72P0?3@h02@L800l=3P0?3P`03Pd;00d<2P0=30P030`701<D3P0<3@P01PL2
03@e<00[;2L07AdK024Q7`0J6QX06a/K01HF5P0A4A003a0;00l@2P0>3P/03Ph>010@4P0C4QL0TI2E
07YiOP0U9BH0000000h?2P0@4@`03`l?00l?4@0200h>40803@d?01802`/=00d=3`0?3a403Ph@00d=
3`0?3a40410@014A4@0E5AD05QHF01<C500@41802`/=018B5@0?3Q<040lD01<B600<2a4200l@500:
00`=4@0>3a<0414E00/<400C51P03a0D02`]<@0R8bL030dA010A5ACooooo000Kooooo`0[010A2`0=
3PP02``700d>2@0>3P/030`:00h>300<30/01PH601DE5@0C4a<01`L7014?400C4A8051<A01HB4@0D
4A40410B00`=4@0I82L0Lh290?7oo`2dbM`0<dEC010A500@3Pl03`d>00h<3@0<2P/02`T:01/I6P0T
8R<07A/L014?400@3Pl04@lB01PG7P0@3aL03@`D00X94@0R8BT08B0X01<B6P02010?5`0M00h=5@0=
31@040lE01<C500@410051@D01HF5P0C4a<04A4A02<S8`21PH4030`<01HF5P18B4P04Q<F01HI7P0=
41D04aHK01DH7@0M82D0>Se201LJ7`0?4QL04QDJ00lB5`0B5AX04ADF014G4`0B61@00`0C6AD05P0D
6QH04QPD010F4P0D6QH061hJ01DK5`0@5QD04QPH00hD500T:RX0318B02<Y:@0<4Q8051XJ00L=3@0G
7Ad07bDU01HL700J7b007B4T01XN8@0G6ah201HJ7@0301TM800H71l05QXM008051PK00X05ATL024T
:`0A51/071lV06EXK@26RHh04aHK01PL7`0G6ah05ATJ0P0C5aP00`0D61T061/P01hQ9P0301HI7P05
01@G700B5AX04aHK01DH7@0F6Ah00P0G6Ql00`0E6Qd05adM01TN8@0201HK7P0301PM8@0K82@06b0U
00806QlU00X0724W01dR:00T:c<06R4Y01LN9P0A62006b8Z01TP:00E72@05QdU0P0G7RH0100I82P0
6B0V01XS8P0J8al201TR7`0501PQ7`0H8B00620R01XR900J8RD00P0H7bD01P0J8RD0620R01HO7`0G
7b406B4S01XR9@805alR00`051/Q01HM8`0K8RP092/a02@^<00K9RH07RPY01/U9`0K92X072<]01TP
:P0H7bT201XN9`0[01TN900H7B4061dQ02@W;`0T9c0061`U01PN9`0H8BX0=3i701LR;00?7BH04B8Z
041AF`0:72H05bP`01`T;P0L8bd06R4[020W;`0K8RX07bH^01/R:00C6R0051`P014I700C6ah05AlR
01HQ9@0J9B/06RD/01LQ:P0F82`04adY01DO:@0^>4806B<[00XE6`0I92P03aLL01<H7P0B5a/04aPK
01@J6P0201HL6P0/01LM7@0I7R406QhV01TM:00J7RX05alY00hI7`0?6Qh04A`O00@@400;5aL0520N
00dI5`0L9bT02aHI00093@0g@TP0GfQ_03<l@`0E7RD04AXO010I7P0F7b@04A/M01@N800A6a`03ALH
018L7@0B71h06R4W014H7P0C6R003A@J00hE6`0>5QT041PK014I700B6Q`04ATK00lG6@0>5aH00082
018H600N92@2010F500;00dC4@0K8Ad04QPD014G4`032P<041L@01LN5`0?4a803Q8A018F5@0B5a<0
0P0<4@d00`0W;2H041D?00`A2`0201<H4@0>018I4P0F71P01Pl<018K600D7AX06B8O09nXY@1AFUL0
7bPU01DN6`0>5a@01@h;00TB3`0`>CH200XC400@00dF4`0<5A80214>04M@C@0Y<Rl0:c@a00081@0;
51402a4?020T8`082PT0;2h]00d?3P0L7Qd020X9014C4P804Q@C00@04A<B010B4@0?4A003Q<A0`0>
518200`B40D03Q@B01<03a@@014C3`0C5A00418=018D3`0C5A003a4<00`>2@0F61<07b4L014C3P0=
3`X02`d801@F4`0A4a00418?014C400C5A804A<@00803Q0=0P0A4a006`0?4@h03@l;00X<1`0B50l0
3@l:00/=200H6QD0418=00h@2`0=3`X03a4<00d?2P0>40/03a4<014C3P092`H06Q`G018D3`0=3`X0
3Q0;00/=200L7QT051HA00T;1P0:30L04aH@018I4@0200/B2P0900hE3@0?5Ph03aH>010G3`063@D0
0`X200`C2`0G7QH041D?00803a@>00l041D?00lD3P0<4@/04aPB01hS7@0K81X03Q<=00lD3P0;40X0
6A`E0085000I71D092LP00D80@0E61401P0=40T3018C2`03014B2P0@4@T0414900<0414900X04A8:
018C2`0C50`03Pl:010A300?40/03Pl:00l@2`0B4`h03@h90P0C50l01`0>3`X03@h9014B3@0:30T0
2@h:00X?2`0;40`00P0>4`l05@0<4@d03Q<?01@I5@0G71P0314=00/;2@0?2`P04`h;01@?300C3P/0
4`l<01@@3@0;1`@04A0<00/:1P0B4@d04Q<>018C3@0>3`P04A8:018C2`0201<D3P09018C3@0=3PT0
4A4?01HF500b<S004A4?01PH5P0?3PX03Pd900803`h:0P0>3@T0300B4@d040l;00l>2P0?3PX040l;
014@300E51003Pd9010?2`0A40`02`X600T810803Pd900X04A0<00l>2P0>3@T04Q4=00P7100<2`L0
5A@B004000071P804a8>0`0=30P02@0>3@T03`h:00l>2P0@3`/04a8>01LF4P0F5A4051<?018A3@03
014@30804Q4=01d040l;00h=2@0>3@T03`h:010?2`0A40`04a8>014@300;2PH020L301<B3P0D4`l0
3`l;00`=200720<04A8=02<T7`1MGUT06AXE014B3@10@C`0j>WT0<c=b00[;2T04Q8@01@D4P0?3`d0
3@d;014A3`0201<C4@0M028R80092@L05ADC00h>300=3@/02`/900P81P051@@06a/I01`L6P0>3P`0
0P8001@D4P0@40h020P602PX9P0@40d04Q@?014F3`0@5@l0314;00T>20083@T01P/704Y>C00M8B00
10P700T=300D5QD00P0A4@l0100?3`d03Ph<00d=2`0<30X200h>300H010@3P0C4a404Q8@00`<2P0:
2`H05AHB01hO6@082@<030d700l@2P0:2`D030d700d>200>3`T0414;010A300@40h03Ph<01DE4`0C
4a4030`:01<C4@0@40h03`l=0P0H61H00`0?3`d03Ph<00d=2`0200h>300?010@3P0A4@l04A4?00T9
1`0>3P`0410>00T91`0<30X05QHD01<C4`0<30`05QHF00T92@051@D03@d=00802PX:01d04Q8B02TY
:@020P802P`;00@71P0=4A0051PG00L9200A4a806adL014A4@0>3Ph0410@00d;30091`P03`d=01@C
4@0A40h05aHD00l>300B4@l02PT700`;2@0?3P`04Q4?00h=2`0@3`d04Q4=00l>2@0300l>2P<03`h<
0P0>30d0100?3@h040h?00T82P0c<CH200X82`0S00h<3`0H5QL03`d>014?400@3`d03`h<00d<2P0<
2`L04A4<00/<1P092P@05aPC04M8@`0a<Rd04A4?01DE4`0=3@/03`l?00`<300:2PT03Pl:00d>200=
3PX03`l?014A4`0E51X08b8X02DT:@0?3a001PH401@E400A4P`03Ph>00h>400=3@l00`0<30h01P0;
2`d03Ph@014A4`0@41803`lA010@4P803`l?0P0>3Ph0100?3a003`lA00/;3@0A41@201<B5`0901<B
600B4AL04Q<G00/?4P0=4A@03Q8E00`@4`0:3Q405ATL00802PhA00<010P;00`@4`0@51L05?ooool0
01_ooooo01T03a0:00d=2@0<30T03Ph;00l?3@0<30/03`l>00h>3P0@414030`=00/;300<30d03`dA
018A4`0=3@`03@`=014@4@0>3Pl05QHI010C5`0[<CH0H6Y`05aXL00D7B804Q8A00804Q4>01L04A0>
00l>3P0?3Ph03@`=00d<3P0C4aH03PdA01dN8@0?41<03@`B01@C6P0F5A/040lE01@C600>3A<051<I
01HF6P0C4QH03`hB014@500C4QH04A8C01<D5@0201`L7@0Y014B4@0C51<03a0@01LH5P0B4a403Pl=
018C4@0>40l04A@E00h?4@0E5QX051HK01hP9P0c=3d05aPQ00hA6@0B5A/051LL01@H700?4a@04QLG
01@F5`0@51<04QLE010E4`0E6QP051XG01PN6P0F7AT06B4L01<K5@0C5aD05aTK01TK7@0A5aL0;C<c
09VPX00Y<C405QhM00hD500B61P00P0E5aT07P0G6ad04ALJ02P^<@0O92D0<STj01@J6`0F6ad041PF
01LM700I7Qd04aXI01XO7`0H7Ad06b0Q01TN7`0Q9RL0;S<d01<H600G71`05a`K01HK6P0C61P061dK
01HK6P0J7R406b8U01@J7@0H72005adP01@H70805ATM00`061`O01XM8@0H71h061`O01DJ7@0H7B40
6QlS01HM800E71l05adQ01TP8`0J8RD201`T:00;01XR9P0K92P05b0V01TS:00K9BX06B<X01/U:`0F
7R806R8X01PQ9@0H82@00P0G7R<03`0J8RD06R<R01XS8@0K92807RHW01`T9@0F7al05alQ01/S9@0I
8B@0620S01/R9P0H82<06B4S01XR900201/S9@0501TQ900G7b807bL[018I7`0F7B<00P0J8BP0FP0E
7R<0524R01HS8`0G8bD05R0S01HP9@0I8bT0620V01<K8P0@6Ad05AdQ01/R9@0D71l06R4U028Z;P0F
7R805AhS01@O900K9R/0520W01@R:@0B82L05bH^01l_=P0F92`09Bhg01TQ:P0G8BX0624Y014I800C
7B<07RL]01`T:P0H8BD05B0R01HO8P0J9BP04ahS01DP9P0G8BP04adU01DO:00F7bT0624[02lg?`0D
72D02A4H01HN900P:Bh041TK00lH6P0A6Q`04AXK01HO800C71d05QlS01TR:00G7RL05QhX01dT<00O
:3804QdS014L800C7B003APH028];00]>CL03aXI00lI6@0B6ad04ATM01`T:00g?d<07BHZ01HN8P0K
8bP051`R014I7`0F7R<04AXM00lH6P0D7Ad05b0N01`V900F7Ad041LG01@K700D6Qd051/N01LN8@80
3A@G00L03aHH01<J6`0E71/05A`J01DJ6P0>51403a@B008041DB00P051TF01<I5@0D6QH051XF00lE
3`0J81/0318=014E50804aLF02P03Q8@014F4`0B5a<0>Slj01XO6P0@5@l04aPA00lD3@0C61802@l;
00lE4P0<4a005Q/H00lF4`0J8Qh07R<P00lF4P0>5Q8051TF01<I5P0D71P03Q@A010G500C6QL03A<@
01<I5P0>5A805Q/H00`C3`0<51005adJ01PN6`0?5A803Q<@018F4`0;3P`03Q8?014E4P0C5Q@041@A
0P0D5aD02@0B5Q<04ADB014F4`0@5Q@0318@00T?3@0=4a40318@01DK6@0500hD4P0400dC4@0A5A40
4aHB010D3`804AD@00T03a8>010C3`0C5a804QDA010D3`0F6AD04aHB01DH500^<Rd00P0<40/00`0B
5A403a8>010C3`02014D400j018F4@0A51003A0;01PL5P0@4`d06ahH02DY8`0;3PP04QH@00lC3@0=
4@/03Q4;00d@2P0>4P`041@>01@H4P0?4P`071lI018E3`0C5Q0041@>00H91@0D5a402@d701@H4P0@
50h0=CXc02hd;00X;RH03Q@<018H4@0A5`l04AL@00hD3@0<4P/041H?018H40093`P041@>018F400:
3PL05ATC014E3P0>4P/0310:018F400B5Pl020`6010D3@0G6aD05AL@00/=1P0e=c00B4Y401XL5@0A
4``03@l800h@2@<0418;00h03a4:00h?200@4@X04Q<<010A2P0?40T04A8;01<D3@0B4``03a0900d>
1`0@4@X04a@>00h@2@80418<00/03Q0:00lA2`0B50h04Q@>020R700E5a4030h8014C3@0B50h061XF
014D400200lB3P0800hA3@0?4Ph030l;00hB3@0A5A003Q4=00d@300?4@d2014?3@0>01@B400A3``0
3Pd:018B3`0<30T04Q8?018C3`0E5A80:B/W010B3@0@4@/04A8=010A2`0>3`T200l@2P07018C3P0:
2`L05aLD02l_;00Q8Qh0;BhY014A3002010@2`803@d800P0410;00l?2P0@40/04A4<00l?2P0=3@P0
3`l:014A2`804Q8=01804A4<018B3@0<30L03@d:018B3`0>3P/07alL00/;200=3@X03Ph:01PH4`0_
;b/05aLB01HF4@0:2PL04Q8=00h>2P0A4@`2010@300300l?2P0>3PT0410;00804A4=00P0410;00l?
2`0?3`/0410;010@300?3`X0410;014A30<03`l:01P03Ph900d=200A4@`0410;00T91`0D50l03Ph9
01`L5`0<3@P04Q<=01@E3`0B4`d030d8024R7@0;30H04A8=02d^:@2>ShX0OGii02//9`0=3P/03Pl<
00d>2P0;30P200`=2P0D01PI5@0P8Ad03a0<01HG4`0D5A806Q/G010A3P0A4Q003a0=00h?3@092PP0
30d;00d>2`0?40d04Q<@00L81P0<3@/04A8@00d?2P0=40X200lA300P00hA300@4`l051DA010C3`0?
4`h030d;00`?2`0<3PX09bLT034b;P0>3P/04A8>00`=2@0@4@d03Pl;00h>2`0?40`04A4>010A3@0=
3PT030d8059CCP0f=c403a0:00h?2P0A4Pd030d800h?2@0=3PP03Pl:010A300>3`X2010A3`0=01TJ
600F5a@03Pl=01PI5`0?40h030d;010A3P0A4Q003a0=010A3P0=3P/02``800l@300200l@3@0>00h?
300<3@T01`P5010A3@0=3PX05AHB00l@3@0C4a802`/:00`<2`0B4Q403@d<00`<2`0>3Pd2010@3`0K
00h>3@0E5A@02PX9010B400?40h030d<00/<2`0A4Q000P<100h>3@0?3`h03Ph=010?3P0@3`l03`h=
00h>300<2`T03`l=00X:200G5Q@02PX800d=2`0<2`T061LE00/;2@0<2`T08b<P00803Ph901h03Ph:
00d=200A4@h03@d:014A3@0@40`0410=00l?300>3@`03Pd=00l>3`0@3a407QdN01<B4@0>3@d040l>
010?3`0?3P`04A0>00d=2`0=30T04A0;00/9100C4@/030X400h>2@0B4@`03@`9010?300>3P/2018B
4@0=01<C4@0@40d03`l<00d>2`0>3Pd0410A01@D5P0?3a404a8E018B4P0;2`T030`9010@3@0200l?
3P0600h>3@0>3Pl03@d>00d=3P0>3Pl0410A0P0B4Q@06P0@4180410C018B4P0?3`l0410@00h>3P0@
41404a<E018B500A41@03`hC00h=4P0?3Q@051<I018B5`0<3Q403A0C014A5@0>3a<03A0C00/;3`0?
41@03a8E00h>4`0C51P020/>5?ooool001_ooooo00h030d800`=2@0;2`T03@d;00l?3P0>3Ph03@d=
00P82@0A4A<03Ph@018A5@0>3A806aXO01dM80804a<E00T05QHG00P8200;2`/02`/:00l?3@0E5A<0
4a@?010A300B3`X00P0?3PT0IP0?3PX03@d;00d=2`0>3Q003a0D00X;3`0?41D0000500lB5`0A41H0
40lD00l>4`0@3a@0410B014A4`0G5aT07alO01DE5@0@410051@D014A4@0O82@0>S/m018C5@0E5QP0
10H501XL6`0>40l04A<@00lA3P0C5A805ALB018D3`0?40/03Ph>01<C5P0H5ad061PR01DE800B4Q`0
41<L010C6@0@4aP04AHI014E5`0O82@071dO018C5@0F5aT04QHE018G5@0Q9bD0?TA001hU8@0?61<0
41XB01TL6P0=3@l071dO018F5`0C71/0I6e/01`V9@0C7A`051XJ01@G600F5aT061PJ018D5`0V;S00
4a/M00H>400K92<04Q/J01LP7`0@6AH05QlK018K5P0@6A@0624L00hD400@5Q804QPD01DK5`0G7AT0
6AlK018H500@5Q802a4=00hD400G7AT06R0M00P@4P0=5AP051`O01@L7P0E7Al03ADG01PM800E6Qd0
61hN01XN7`805QXK0P0H7B40300F6al041PK01DM800L92L0628T01DO8@0H8R@062<U01HQ8`0I92H0
6RP[01@R9@8062HY00/062DW02D`<P0I8bD05R0R01PR8`0H8280620Q01lX9`0K8bD06B4S01/S9@02
01lW:@0801PP8P0F7R006B4S01DM7`0F7R0072@V01XR900H828201/S9@0601TQ8`0G7b405alR01dT
:P0K8RP08bX`0P0J8BT04`0I8RL052<U01LU9P0H9RL04b4R01LR900M:2X062<U00/E5`0`>S`04Q`N
010J700E7b403a/K018N7P0S;bl07BTY00XE5`0<5aT00`0B7B401P0D7bD05b8X01TT:P0I8b`0628[
01LQ:P<05b8X03/062<W01dX;00G8RD062<U01LR900O:Rh07BP^01PS:@0J92/06R<Z01TR:@0E7BD0
3QDM018I8@0C6B405ATR02/_>01MIFT07b/[01HR8P0G8b@051lQ01PS9`0A724041XS00lI8`0?6B@0
41XV018L:00B72H02QDK00hI7`0N:2X051hO00PB4@0A6aT05QlL018K6P0D6a`05Q/N01lT:00b>S`0
7bLY014I700C6R003aHL010G7`0i@4H09Rha01LP8@0D7A`041TF01DN6@0F71P04aTE01DK6@0F6ah0
4QLJ018G6`0200lD600I014F600A5aL04QPF01<I5@0H7AT05Q/G014F4P0;40`02Pl;00lD400F6aL0
2a0<018G4`0A5Q8041DA018G4`0?4a804aLF01@H5`0<40l05AXG014F4P0@5A404AHA014F4002018G
4@03018G400@5A4041DA00@041DA01H07B8N00dB3P0B5a<05a`H010E4@0?51004QLC014F4P0@5A40
2Pl;01@I5@0?51004QLC00lD400A5Q803Q<?00P=2@0;40`04AHB018G4`0=4Ph03Q<?1P0A5Q80200>
4`l0314=00dC4@0J81h05Q`J018H5P0F71X020h<0P0>518200lE4`0400hD4P0=4a4041DA010E4@80
3a@@0`0>4`l300lD40803Q<?01@020d801XO6@0:3`T0724K01@I4`0>4`d04QLA01<H4P0@5@l04QLA
014F400?50h06AhG00X?200H7AH082DN00T>1`0>4``03a@=00hC30803A8;00<03Q<<010E3P0@5@h0
100@5@h06P0>4``0314:00`A2P0;40T0314:00dB2`0?50d02Pl803Hk=00H7AH00@H000D:0`0B5a00
3Q<<00lD3@0C614041D>00dB2`0<3`P05QTB018E3P0L7aP051L@00lB2`0E61404QD>0`0A50d02@0K
7QL04A8<01PI4`0D5@l06AXD00`=1`0B4`d03a0:00h?2@0200l@2P06010A2`0A4P`03a0:010A2`0B
4`d0414;0P0?40X00`0=3PP03Pl900h?2@0200/<1P0B00d>200;3PL03A0900d@2@0;3PL030l800d@
2@0?4P/06A`E00`?200930D04aH?00`?200D5Q403@l:00lA300B50l0418=0P0A4`h04@0B50l03a4<
00d?2P0?4@`04Q@?00@60`092`P02`d:018D4@0=3`d02`d:01HH5@0D5Q<01`T600/=2P0b=3402P`9
00803a0;0P0@4@`00`0?40/03Pl:010A3005014B3@<0414;01X04A8<01@E3`0G6180414;01<D3P0G
61804Q<=00d>200@4@/04A8:00h?1`0A4PX0414;00d>200@4@/03a0;00L71@0H61H0Ti>A01PH5P0@
40h04a@?00L80`0H6A@04a@?00T:1@803Pl:00H01`P300X;1P0@4@`02@X500h?2P0@4@`300l@2`0F
010A300A4Pd0414<00l@2`0A4Pd0414<00l@2`0?40X03@h800h?2@0?40X0414;014B300;30H030d7
02TZ9025QX006Q/E00@5000<3@P04Q<=01PI4`805QLA00@04Q<=00`=1`0>3`T03@h80P0N7aT02P0B
4`d03@l:00d?2P0<3PT03@l:00h@2`0?4@`04Q@?010B3@0>40/2010B3@0400d?2P0?4@h03Q0=00d?
308030h;0`0=3``01@0>40d02`d:00/=2P0>40d03a0;00803Pl:01003@h900h?2P0?40/04A8=00h?
2P0?40/03Pl:00`=200?40/02P/602LX8`051P404A8=00d>2@0@4@`03Pl:0P0=3PT02`0>3`X0414<
014B3@092PD0?Chi014B3@0>3`X05QLB00<4000:2`H03Pl:008030d800P04A8=00h?2P0<3P/03Q0=
01@F4`0@4Pl02`d:018D4@803Q0=00H03@l<00h@3@0?4@h03a4>00d?2P0:30L2018D3`0L00d?2P0:
30L05ALB00H80`0?4@`02P`701LI50092`H04Q8@014A3`0;2`T03@d;00X:200<30X04a<A00d=2`07
1`D06QXH00/;2@0410803Ph<01DE4`0D518030`:00H6100J6QP0410>018B40<03Ph<01<03`l=014A
3`0@40h0410>00l?3@0=3@/030`:014A3`04108010@300<30@0U9B<0Ngah02DV8@000@0051D@00D6
0@0=3PT04a@?00803@h900D0414<018C3P0A4Pd0414=00l?3@0200d=2`0>00l?3@0B4Q004a<A00d=
2`0<30X0410>00/;2@0:2PP040h:01<>200D3`T04Pl8014>1`0A3PT200l>2P04018A3@0B4Q004Q8@
018B40<03Ph<00T03`l=010@3P0A4@l03`l=014A3`0B4Q003Ph<00d=2`0>3P`00P0A4Pd0100A4@l0
410>00l?3@0?3`l200h>3P80410B00l03`lA00h=4@0F5QP03Ph>014A4@0=3@d04A4B01@D5P0:2P`0
410C01@C600C4QL03`hC00`;4@0B4AH00P0A41D01@0C4QL051<H018A5P0A41D040lD00804a8G00<0
3`hC010?5?ooool04oooool001_ooooo01H030d800d=2P0<30X02`/900`<2`0?3`l04A4A00P82@0B
4Q@03@d?00`;3`0:2@h020L<00d<400>3Q005aLI01lO800B4Q802PX:00d=300>3P`03@d;0P0=3PT0
100A3PT03`h900l>2@0>3@T200d=2`1A00P82P0?41@01`P<01TJ7`0110T07B0U014@5P0@3a@03`hC
010?500@41804A4C01DE5`0L71`051@D014A4@0D51@04a<C071aM@31`/@0;2d_01@E5`0;3@`04Q@C
010B4@0B51403a4>010B3`0@4Pd03a0;00h?2P0>3Ph04Q4E01HE6`0F5R0051@N018B700?4Q/03a8H
010C600@5AP05APK02@U:@0O828051DG01LH6P0E6AP061dL05AJF02DVYH0F5mK028[9P0H8QX06QhL
00/;3@0N7b405ATJ00XC4P0@6AP05AlN01<M700D6QX051PI01HG6@0H61X05aXM01HN8@0C6ah07BDW
00/C5@0I8B804a`K014J6@0E7Q`02a@A014J5`0B6aP061hL01DK6@0D6QP02Q0>008041HD01D04QPF
01@J600B61H06R0N01HL6P0B61L09Rh`01XR9@0F7R40=cm104M?D@0K8bD05AXM01<H6`0F6ah05adM
01<I6@0B61P0;34e02X_<`0T:Bd00P0J8RD0100N9RT072HX01<M7`0E7b4201LR900>01TT9P0J:2/0
3a`R01PU:`0H9RT04alR02D`<P0G8B<05AlQ01PR8`0H82806B4S020X:P0K8bD201PP8P0301`T9P0O
9bT072@V00805alQ01@04QXL01<K7@0K8bD072@V01LO8@0I8B<0620R01HN800G7b806B4T01`S:@0N
9B/09bhd01hU;@0K8RX05b0U01TV:00M:b`062HW01HT9@806RDW00d02A@F01@N800jA4H06B4T01DM
800G8B<07BTY010L700C7al05B4Q00`G6@0R;Bl04ahR00804QdQ00H051lU01DP9P0F8BL05b4Z01DO
:00D7RL201@O9@0@01DP9P0B7B405B0T01DP8`0I92H07BPZ01HQ9@0I92X041/Q014K8@0F7bH03aPO
01LO9P0F7BD03aHN00lD7@802`lH02T0<c/o018N7P074a<031LH00lJ700A720041/P010K8@0=5b00
4Q`U01HP:P0A6bL0;SQ202lj@00B7B<04adO01/U9P0H8R406R<Q01PQ7P0C71/05A`M01HK7P0M8RH0
=Cdo020X:P0?5aX04aXP018I7`0A6200<STo01lW:P0@6AX04a`K014J5`0@6A@051XF014G4`0D6QP0
5AXM014F6@03014F6P0@014G600A5aL04ALE014G4`0F6aL05AXF014F4P0?510051TE01lT800G71P0
3Q<?01@I5@0C61@04QLC01<H50804ADD00P04QHE00`@3`0F6QP051TE010E4@0A5Q404AH@018G4@80
4aPA00`04aPD018G4`0A5Q803a@@00hC3`0=4Ph05Q/G00D:1P0A5Q804QLC01<H500A5Q8200`A3@0>
01@I5@0F6aL0;34]034f<P0=4Ph04QLC01LL600D6AD04QLC01TN6P0B5a<05Q/G01<H500?5102010E
4@0<01<H500>4`l03a@@01<H500?51002Pl;018H5P032@L0>3hl00X>30093`d06b4O0P0>518200lE
4`0300hD4P0=4a4041DA00<03a@@0P0>4`l00`0?51003Q<?00dB3P0200hC3`0700lD400B5a404AH@
010E3`19CTP0Ada601@I4`02018G4@0;010E3`0A5Q0041D?018G400I7QL02@h700dB2`0C61401P/4
00dB2`0>4``00P0=4P/00`0>4``03a@=010E3P03010E3P803a@=00`03Q<<00lD3@0A5Pl03a@=00/@
2@0<4@X051TB00/@2@0B5a0041D>01@I4P0H7AH2010E3P0N01<H4@0D6A803Q<<00`A2P072P<03a8;
01@G400B5@h04A@=00lB2`0D5a003a8;00/>1`0B5@h02`h7018E3P082@<061TC00/<1P061`403Pl9
00l@2P0A4P`0414;00h?2@0=3PP03a0:018C3@0D5@l04Q<=0`0@4@/02P0?40X03Pl9014B300D5@l0
4Q<=00l@2P0>3`T03A09010C300?4P/200hA2P0O010C300=40T03a8;00`?200>4@X04A@=00d@2@0<
3PT02@/600lA300B50l0418=014C3P0<3PT04A<>018D3`0>40/03a4<01HH4`0>40d051HC00X<2@0L
7Q/0;c4^03<e<P0C5A801@L400d?300H6QL04A<@0043000200l@2`80414<00<03a0;00h?2P0A4Pd0
0`0B4`h0600?40/03Pl:00l@2P0;30H02P/500`=1`0=3PP030d701<D3P0E5Q0061TC018C3@0=3PP0
3a0:00l@200;30@03@h600h?2@0@4@/051D?010A300>3P`030`:03@d<P8030`:00d01`P300d>2@0=
3PT01PL201lP6`0C50l01PL201LH4`0>3`X05AHA00/<1`0C50l03a0;00<03Pl:00<03a0;010A300@
4@`00`0?40/06@0>3`X03@h900d>200=3PP03a0:01<D3P0E5Q005QLA010A2`0B4`d0Ce1:00d>2007
20804a@>01XK5@0F5a402``600h?2@0?40X03Pl901@E3`0<3@L03@h800`=1`0A4P`00P0>40/01P0=
3`X03Q0;00h@2`0@4Pd04A<>00lA30<03@l:00D02P`700lA3P0>40d03Q0=00`>2`0200d?300700`>
2`0=3``03@l<00/=2P0:30T03@l<00l@2`0200h?2P0500d>2@0>3`X03a0;014B3@0=3PT00P0?40/0
5P0<3@P0414<0001000A4Pd02P/6014B3@0=3PT02``700l@2`0>3`X030d800d>2@0B4`h05AHA00X;
1P0G61<02@X500`=200@4@`02``700d>2@0@4@`200d>2@0:010A300=3PT03Q0=00d?300@4Pl03a4>
00`>2`0>40d0418?00lA3P@03@l<00`03Q0;00`>2@0F61<04aD@00d?2P0;3@P02@/6018D3`0G6A@0
10H300h@2`0:30L2014A3`0C00h>300=3@/04a<A00d=2`051@<06ATG01/K6@1@D4h0410>014A3`0:
2PP0000000@40P0M7A/00P80010@3P0?3`d0410>00d=2`0200h>300F00`<2P0:2PP030`:018B400=
3@/03Ph<018B400G5aD04a<A01XJ600?3`d020P602DU8P051P4010D001HG4P0=3PT03a0;00d>2@0?
40/030d800/<1`8030d801D03Ph;00h>300<30X030`:00h>300A4@l05ADC014A3`0?3`d04Q8@00l?
3@0=3@/04@l:01D@2P0F4@/05A8=01@A300B3`X03`h:010?2`0@4@`00P0@40h0100?3`d02`/900`<
2P0?3`d2018B4007014A3`0=3@/03`l=014A3`0?3`d03Ph<00l?3@02014B3@06014A3`0@40h0410>
00l?3`0=3@d03Ph>0`0?3a406@0>3Q406QXL00h>3P0<30`02PX:014A4P0C4aD03@d?00l?4P0B4AH0
4a8G010?5@0;2Q0040lD00h=4P0?3Q<04A0E018A5P0?3Q<05A@I014@5@0B4AH04A0E00h=4P0A41D0
5?ooool001_ooooo01H0414<00h>2`0>3P`030`:00X:2@0@41003`l?00d=3P0E5AL03@d?00d<400?
3Q<04Q4F014@500:2P`02`/=01<C500D51@03`l?00d=300=3@/03`l=0P0>3`X0100C40/04A0;010?
2P0@3`/200l?3@0@014A4`0B4aL051DI00X;4010@dP0BTeB014@5P0@3a@03`hC010?500@41804A4C
01@D5P0H61P04a<C010@408051@D00@0>S/o0821P`0C51H03PlA0P0C5A@0FP0A4a804A<@00h@3@0D
5Q<06adH01HG4`0A4@l04A4A01<B5P0E51X05AHL01DE7P0B4Q/03Q4H00lB600A51T041DH01@G6`0Q
8RH06a`N01<D5P0G61X05a/J03Dj>02W[J/0noom0:jf/@13C4L08B/S01DJ5`0F5aT061TK00dB4`0J
82004a`K018K6P0?61L04ALG018G600E5aT05aPJ01HJ7P0C6Ql04QTN01/R9`0=5AP0620R01<K7@0F
7al07RLW014J6P0K92804QXJ01TO800<4Q404AHG01@I6`0E6aX051XJ01@J6`0B61L04ALG01TN800B
61L05a`N010E600A61/03aHI01hT9`0^=CL04QTK014F6@0@5AP05Q/O01TN8P0F71d05Q/N01LL800H
7B806QlT01LO8`0D72004ATM01lY;00G8B@06R@W01hY;00M:2/06RDY01HS:@806BH/00l05bDY01LT
9`0I92L072HX01XT9P0J92D05alQ01@L7P0H82805QhP01DM800H82806R8U01/S9P0I8B<00P0H82<2
01HN8@805alR0P0I8B<01`0G7b405QhP01XR900O9bX06B0V01/R:00Q:2h00P0J8BT0F@0E7R<062DW
01`Z:`0D8R<05B8S01PS9@0B7Al05b8T02H_<P0=5QT05AdP01/S9P0H82<03aXK01PS900F8B80<cho
01LQ8`0D7R00628V01HP900F82D0628Y01LQ9`0E7bD0628[01XT;@0L9Bh06R@[01LQ:00E7bH04Q`P
01@N8P0F8B@05b4S01/U9`0?6Qd06RDZ01TT:@0H8RP072D[01HO9@0C6b407bH]01/R:@0B61l06AhU
01DI8@0K8bH072LV01DP8@0F8B8051lQ01<M8P0F82D04adT014J8`0D7RL0624/01LP:`0f?dT0>dI<
01hY;`0@6Q`04adN01HP7`0I8R004a`I010I600B6AX041DH01DJ7P0I8B<04a/M01@L7`0H7bD05A`R
014H800B6Al03ADH00lG600E7Qd04a`I014J5@0D6QH04ALC01@J600F6ah04QLJ00<04aPL00@04QLI
014G5`0@5Q@041HB0`0A5Q804P0B5a<05a`H020U8@0H7AT04AHB01DJ5P0@5A404AHB00lD400D61L0
4ADD01DI600>4Q404QLD00hC3`0E6QH051TD018G4@804AH@00D04QL@018G4`0A5Q804AHB010E4@02
00lD4004014F4P0B5a<04aPD00/@30804AHB01405Q/G010E4@0@5A402Pl;010E4@0?51008RLS01XO
6`0?51002a0<00hC3`0C61@05a`H00lD400H7AT04QLC00X?2`0300lD4008010E4@0A5Q804QLC018G
4`0A5aD09B/Y08jDTP0h?S`400hD4P803aDC00<03Q@B00dC4@0?51001@0?5100300@5A403A8>00`A
3@0=4Ph03a@@010E4@0B5a402a0:00`A2`0Z;bT0:BhX00hC3@803a@>0P0>4`d01`0=4P`03A8;014F
3`0>4``04AH?018G400;40T01@0>4``0100?50d041D>010E3P0@5@h300lD3@0500hC300C61405a`E
01<H4@0=4P/00P0?50d0400@5@h0314:010E3P0G71D08BHO010E3P0<4@X03Q<<00dB2`0:3`P03a@=
00d@2@0<3`P03a8;00T<1@0?4P/2010C300;01@G400<3`P041<<010C300B5@h04a@>00h?2@0@4@/0
4Q<=00d>200@4@/00`0B4`d3014B300J01@E3`0?40X030d700l@2P0A4P`03a0:00h?2@0A4P`05QLA
01@E3`0@4@/03Pl900d@2@0@4``03a8;00d@2@0>4@X03a8;01<F3`0=40T04A@=01DH4@0A50d03a8;
00lA300;3@P300h@2`0;01@F4@0@4Pd030h9014C3P0B50l03Q0;00d?2P0>40d0418?00/=2P0=3``0
0P0S9B801P0A4a002@/803<e<P19BdP03Q0=014C40803a0;0P0@4@`0;@0?40/03Pl:010A300B4`h0
4a@?014B3@0>3`X030d8014B300>3`T030d701DF400H6A<051D?00l@2P0A4P`04a@>00l@2P0<3@L0
3a0:00h?1`0?40P03Pl700d>200?40X04A8<014B3P0=3@/05QHD00d=300E5A<03`l=014B3@0B4`h0
3a0;00d>2@0^;bX05aPC01@E4@11@Sd061TD01LH4`082@H03a0;010A300300l@2`09010A300B4`h0
6Q/F01/L5`0B4`h03@h900l@2`0@4@/03a0:00803Pl900<04A8<01<D3P0H6A<00P0?40X03`0H6A<0
30d701`M5`0@4@/02P/701`M5`0V9b404A8<00l@2P0>3`T05QLA014B300B4`d03Pl9014B300200h@
2`0;00d?2P0<3PT03@l:00h@2`0:30L02`d800`>2@0>40/03a4<010B3@0?4@h00P0>40d0100=3``0
3Q0=00lA3P0>40d200lA3P8030h;00P03a4>00l@2`0>3`X03Pl:00d>2@0>3`X03a0;01@E4080414<
00/03Pl:00X;1P0=3PT05QLB00`=200A4Pd03@h900l@2`0>3`X04Q<>00l@2`0200/<1`0400h?2P0B
4`h030d8014B3@804a@?00T01`P3014B3@0@4@`04Q<>00h?2P0=3PT0414<00`=200A4a000P0=3``0
100?4@h0418?00/=2P0>40d300d?30803Q0=00`03Q0;00T;1P0C5A003@l:00X<1`0>40/03a4<00/=
200<3PX02P`701@F4@0@4Pd2010@3P0?018B400=3@/06a/I00d=2`0>3P`0410>00P81`0P81h01@D3
00l?3@0K6aT03@d;014A3`0820H02`/900@030`:00/03`l=018B400A4@l03@d;01<C4@0J6QP03`l=
00h>300A4@l04Q8@00l?3@02010@3P0D00`<2P0?3`d04A8=01TJ5@0;30P03@h901TJ5@0A4Pd03@h9
00/<1`0>3`X05AHA01XK5P0E5A803Ph<010@3P0A4@l03Ph<00/;2@0=3@/200h>3009018B400D5180
4A4?014?2P0D40X05Q8<01DB3@0C40/04@l:008040l;00D03a0<00l?3@0>3P`030d<014A3`04010@
3P07014A3`0?3`d03`l=00h>300<30X03Ph<01<C4@0200l@2`<03`l=0`0?3`l01@0@41804A4C014A
4`0B4AD06ATK00<03@d=00T0410A00h>400F5QP03`hB00`;400?3Q<04Q4G014@5P0@3a@00P0?3Q<0
2@0A41D04Q4F010?500A41D040lD01@C600E51T040lD014@5@0Dooooo`006oooool06@0H6A@03@h:
00l?3@0?3`d02`/:010@400:2PX03@d>00`<3P051@L03PdA00@320071P/02`/>00/;3@0<30h07alP
03@d=00>3Ph02`/:00d=2`0C4a40414<00`=200?30L00P0=30L0RP0>3@T03@d;00d=2`0@418010D9
00d>4P0E5Q/01@P=00P;400A41H040lD00l>4`0@3a@0410B014A4`0D51H04a<C014A4@0@41004Q8B
01@D500@4AD06Q/M00h?4@0@4A<03a4@00X<2`0@4Q40418?00d?300D5Q<07AlJ01PI5P0C4a4051@D
01<C500C4QL051DJ01LH7@0D51`03a8I014D6P0C5Q/041DH010C5P0I6Qh05AHH018C5@0D5AL051PG
02<X9`1PIV@0X:JR06M^JP0W<2/06R@L01dR7`0C51H01PX;01HK6`0<4Q806b4Q00XC4P0@6AP04aTI
01DJ6`0G6a`06AXL01<H700941P061lV01LN900K8RP03QHJ00lG6P0A6A`07BDX01DM7`0G7b404ATK
01DJ7@0G71l03a@G01HK7P0>4aH02@hA01<H6`0?51L08BHY01XO8P0E6Qd04AHI00P=400G71l06b0S
00lD5`0D6A`05Q/N01XO8`0I7R807R<W020U:@0K82@06AhR01hS:@0K82H05a`R01PO9@0N9B/082L]
01XS:00F7b@072DZ01hY;@0I92P05R4U010M8`0P;C<05R<Y01@Q9`0L:2d03aXN01XT9P0H8R@06B<U
01PP8P0C6ad05alQ01<K7P0F7R40620S01TQ900G7b805AdP01TQ900H82<06b<V01XR9@805AdP0P0J
8R@0100H82805alQ01/S9@0O9bX201XQ9`1M01`S:@0G7RH07B@/01PQ9P0C8280528S018P8@0C7R00
4A`N00dH6P0=5aT03ADH02/c=P0J8RD03aLJ01dU:00A6a`04Q`M02Pb<`0A6a`02A<E01`V:00J8bP0
5b0U01TR9`0L9B`06B8Y01HO9P0H8BX072D^01hW<00M9Rd0624X01DN9@0F7b@0624V01PQ9@0B71h0
5b4S01LQ900<5a/04QdQ01@N8`0@6Ah05QlT01PP9P0H7bD03QDK01PN900731803a@J00lG6@0F81l0
5AlP01<M7P0=5aP02A<E01DN900H8BP0624Z01<K9@0@62<04a/V018K9@0E82H07RT_01`W:@0?6AX0
218A00hG5@0B6aP041TH018I6P0@5AP04aPL010H6P0B6Q`04a/N00lF700>5A/04QTQ01DL8P0C6ah0
4ATJ00hG5P0?61D051dH01<I5@0A5a<051XH01HK7P0C61/051TM00804QLK00h04QLI014G5`0@5Q@0
41HB018G4`0D6AD05AXF014F4P0@5A404QLC01DJ5P0A5Q805AXF018G4`806AhJ00X05ATH00dA400D
61L041@C01<G5@0@5A405a`H01DJ5@0A5Q0041D?0P0A5Pl0:P0>4`l03a@@010E4@0@5A404AHB018G
4`0C61@02@h:00dB3P0J7a/03A8>01LL600;40`02Pl;01LL600D6AD06AhJ01PM6@12Ad<0;c@`01LL
600C61@05AXF018G4`0>4`l02a0<01<H500@5A402a0<010E4@0B5a<051TE018G4`0<4@d03Q<?018G
4`0F71X051XH02/a;`083P`061hL00dC4@803Q@B0P0?5A<00`0>51803A<A00hC3`0300lD40<041DA
00h03a@@00hC3`0?51003a@@010E4@0C61806QlI018G4@072`H03A8<018G4@0@5@l03a@>014F4080
3Q<=00<04AH@00hC300<4@X00P0;40T00`0=4P/03Q<<00lD3@0200lD3@0400hC300=4P/03Q<<010E
3P803a@=0`0=4P/04@0?50d04AH?00lD3@0;40T0314:014F3`0=4P/041D>00H;100H7AH07B8K00dB
2`0<4@X02Pl800`A2P0=4P/051TB00803a8;01804A@=018E3P0>4@X03Q4:01PK500<3`P04QD>01@G
400H6a@03a8;01DF400A4P`0414;00P90`0C50h03a0:010A2`0A4P`201@E3`05018C3@0?40X04A8<
010A2`0>3`T00`0?40X02@0@4@/04Q<=01<D3P0@4@/03a0:010A2`0<3`P03a8;00hA2P0200d@2@05
00lB2`0B5@h03Q4:00lB2`0@4``00P0=40T0600?4@`02`d800`>2@0=3`X0418=01/M600[;BP04A<>
00P:1@0<3PT02P`700d?2P0K7AX03a4>01<E4P0A4a002P`9018D4@072@H03a4>00D7100G6AH03a4>
00P:1`803a0;0P0@4@`0100?40/03Pl:00l@2`0@4@`2014B3@0W00h?2P0=3PT04a@>014B300:2`D0
3Pl9014B300:2`D03Pl900l@2P0C50h0414;00l@2P0C50h0414901@E3@0@4@T030d700d>200<3@L0
5AHC00d=2`00000010@2018B400E5A<02P/600d>2@0F5a801PL2010A300:2`L04a@?02HW8P092PD0
6a`G00/<1`082@H0414<00<03a0;00X0414<014B3@0L7AP07b0K014B3@0=3PT0414<014B300@4@/0
3Pl90P0=3PP03@0>3`T0414;010A2`051P002``900/<1P0<3@L05aPB0001000K71H0=3D_01DF400?
40X00P0A4P`0100720803a0:014B300A4P`200d?2P0300`>2@0;3@P02`d8008030h900H03@l:00lA
300>40/03Q0;010B3@0?4@h300h@3@0500lA3P0@4Pl03a4>010B3`0A4a000P0>40d0200A4a003a0;
00h?2P0>3`X03@h900h?2P0?40/05AHA0P0@4@`03P0>3`X02@X500/<1`0?40/020T601<D3`0@4@`0
3a0;00h?2P0B4`h03a0;00/<1`0:2`H02``70P0<3@P01`0@4@`00@800001000B4`h01@H100h?2P0A
4Pd00P0=3PT0200?40/02``700lA3P0>40d02`d:00h@3@0C5A803@l<0P0<3P/0400;3@X03@l<00h@
3@0?4@h03@l:00P:1@0C5A002P`700H80`0>40/02P`7028T7`0L7QT020X500D70P0<3PT200/;2@0A
00`<2P0?3`d04a<A00T91`0E5A<03@d;00T91`092@P0;Bd[03`l>P2OWid020P600l?3@071`D06a/I
00h>300C4a400`0=3@/200h>300400`<2P0A4@l05ADC01<C4@804Q8@01<04a<A01DE4`0C4a403`l=
00T91`051P<000400083000G61<04a@?00d>2@0@4@`030d800/<1`0>3`X04a@?01HG4P0C51003Ph<
008030`:00<03Ph<014A3`0A4@l00P0>3P`01P0E5A<071`J01PH5P0B4@`04Pl8018?2P804@h900`0
3Pd9010?2`0?40/03`l=00h>300=3@/02`d<01LG5@0D5180410>00d=2`0>3P`3010@3P0400d=2`0;
2`T03@d;01@D4P803Pl:0`0?3`d00`0@41004A4A014A4@02014A4`07018B500E51P05aLI00l?3`0D
51@04a<C018B4`0200d=3`06010@4`0E51T05QDJ018A5P0;2Q004A0E0P0?3Q<01@0A41D04Q4F010?
500@3a@04A0E00806QTN00<05A@I01@C6?ooool04oooool001_ooooo01`07QlJ00d=2P0?3`d04a<A
00d=300?3`l03Ph>00h>3`071`T02`/=01hN8@0100D04Q4F014@500>3Q002`/=00l?400G5aL03Ph>
014A400C4a4051@B014B3@0?40/03P/600`;1P0=30L03Pd90P0=3@/0:`0];Bl0:2T]028S9`1<CE80
6QdR01<F6`0A41H040lD00l>4`0@3a@0410B014A4`0D51H04Q8B010@400?3`l0410@01<C4`0:2`l0
824S00l@4P0=3Q005QPG01<E500A4a804A<@00d?300>40d03a4<00l@300B4Q0051@D018B4`0@4180
4Q<G01LH700E5Q/03a8G018E6P0E61d04AHI00hA5@0F5a/00P0D5AL04P0B4aD03a<B014F5@0G7A/0
>3hj02D/:00B6aH04adE01/P7@0B5QL03a<D01XN7`0@5QH05adM01<I6@0D6QX05ATJ01HJ6`805ATJ
01D08BD[00XA6`0mA4d0ADaD03Y1B@0R:C003aHL00XB5@0E7B004QXM00dE600B6Qd00@H:02L/<00B
5a/05AXN01PM8@0I7R805AXN00lD600`=CT00P0L8BD01`0A5QX06AdP01<G6P0A5AP06AhQ020U:00A
5QX00P0G7b807`0L8bT07RD[01PO9@0F7B<08RL]01dR:00E6R004APN01<J800B6Al0624V01HO900I
8RL06B@X01HQ9@0H8bL03Q/Q01LT;00A7RH041dS01HR9`0C7R80624V01LP900I8bD0620S01@L7`0G
7b80620S01TQ900H82<00`0G7b805P0I8B@05QhQ01XR9@0J8RD0620S01`T9`0I8B<06R8T01PP8P0G
7b406B4T01`T9`0I82H06R4W01`S:@0H7bL07RD]01LP9@0D7b804ahP01LR900E8282014K7@0B01/U
9`0H82<0@TY=01TN8P17C500?TI901lY:P0i@d@0FF=T01dW:00B71h072HX01TR9`0F7b@0624V01dV
;@0J8bX05AhU0`0D7BH00`0D7B@04Q/R018K8P0201PQ9P0W01DN8P0A6ad06bDW03I1A00F8BD062<W
01`V:`0E7R<08R/`01`T:@0A61h010/A02H/<P0H7B<07B8X00dE600F81l04adL01HP800H8R<04adO
01/T:00I8RL06R<Z01PQ:@0E7RL05QhY01LP:P0G8RP05R4W014L7P0C7Ah06R@S01XS8@0@6AH041TH
01<J6`0A5QT051TM00804a/M01P041PK00lF700@5ad04QTQ018I7`0@61/03QLH014J6@0D7AX04a`G
018H500?5A404QPF01DJ7@0B5aX04aPL018G6`0A5QX04ALH014G5`0A5aD04ALC010E4@0B5a<301@I
5@0<01LL600F6aL04QLC01DJ5P0A5Q80724M01hS7`0N8R4041@C018F5@0?4a804aPE0P0E6QH01@0C
61<04AH@014F400C61805AXC00803a@@0P0@5A42014F4P0A00X?2`0X;BT02@h:01HK5`0B5a<061dI
01<H500;40`04QLC00X?2`062`L00`P401TN6P0F6aL02a0<00T>2P0?51000P0<4@d03P0T:BD04aPD
00`A3@0C61@03A8>01<H500A5Q803a@@00hC3`0?510041DA010F500=4a405Q`J0P0:40h00`0@5Q@0
3Q@B00hD4P0200lE4`0500hD4P0=4a403Q<?00hC3`0?5100100@5A43014F4P8041DA01802@h801LL
5P083@L020d701XO6@0?50h041D?00hC3@0A5Q003A8<00hC3@0C61803A8;00`A2P0:3`P02a0900lD
3@0>4``3010E3P0400dB2`0;40T03A8;010E3P803a@=00<03A8;00`A2P0<4@X00P0<4@X02@0;40T0
314:00dB2`083@H05a`E04mDC@0N8a`02Pl800/@2@0200dB2`0F00/@2@0?50d041D>018G400<3`P0
4A@=00d@2@0D5a002Pd6020S701<CdP04A@=010C300B5@h04A@=00/>1`0B4`d051D?01TJ500?40X0
7AhH00`=1`<04A8<00T0414;00l@2P0?40X04aH?01@G400C5Pl03a8;00d@2@0<3`P00P0D5a001@0A
50d03Q4:010C300D5a003a8;00804A@=00`03a8;010C300A50d03Q4:010C300<3`P02`h700d@2@0>
4@X03Q0;00d?2P0?4@`200h@2`0C01LI500V:2<03a4<00/=200=3`X02P`7014C3P0E5a802@/601XL
5`0f>3<01PP501<E400E5a806A/F0084000<3PT05ALB00lA300200l@2`80414<00<03a0;00h?2P0?
40/00P0?40/3010A300302<T7P0R8ad05QLA00804Q<=00/030d7014B300A4P`051D?010A2`0>3`T0
4a@>018C2`0E5Ph03Pl700/<1P02010A2`0@00d>2@0?3`d06QXH03`l>P2?Shd071`J018C3P0N7aX0
:R/V00/<1`0O81/04A8=00`=20082@@02``701LH4`80414<00H03a0;00h?2P0>3`X03Pl:00l@2`0=
3PT201<D3`0400/<1`0@4@`0414<00d>2@803a0:0P0>3`T01P0=3PP030d701@E3`0?40X02``601hO
6@803a0:0P0A4P`00`0F5a403@h800`=1`0201<D3P0700T:100C50h051D?018C3@0?4@`03Q0;00d?
2P0300`>2@0600d?2P0?4@`0418=00d?2P0<3PT03Q0;100>40d00`0?4@h04A<@00lA3P02010B3`04
00h@3@0=3``0418?00l@2`803Pl:00T03@h900h?2P0?40/04Q<>00h?2P0?40/03Pl:00/<1`0>3`X0
0P0?40/0200A4Pd0414<00`=200=3PT0414<00l@2`0=3PT030d80P0=3PT0200@4@`030d803Hg<P09
2PD04a@?00`=200=3PT0414<0P0<3@P02P0?40/02``700/=2P0=3``02@/800/=2P0B51403a4>00h@
3@0=3``200/=2P8030h;01l03Q0;00d?2P0L7QT03a4<00L9100>40/03a4<04A6@@0m?cX05aTD00X<
1`0G6A@03@d;00/;2@0:2PP051@B00h>300;2`T04A4?01DE4`0I6AL02PX800h>300C4a40=SHd00X:
200Q8Al03Ph<010@3P0=3@/05QHD00803Ph<01`030`:00h>300@40h0410>00l?3@0<30X05QHD01PH
5P0G5aD02@T7000000071`D05QHD01PH5P0C4a007AhI01HG4P092PD02``700`=200@4@`03Pl:00d>
2@0<3@P02``700P9100<30T03`l=0P0=3@/00`0?3`d04Q8@018B4002010@3P0<01DE4`0N7Q`06ATG
018A300C40/040d800d<200>3@T040l;00h>300?3`d03a0>0P0>40l0100=3`h051@B01<C4@0A4@l2
00l?3@04014A3`0>3P`03`l=010@3P803Ph<00<0410>010A300@4@`00P0A4@l05@0B4Q004Q8B010@
400@41003`lA010@4P0B4Q@05A@H01DE5`0?3`l05ADE014A4@0@41403Ph@00T92`0B4AD061LL01LF
6`0A41D02`X@00h=4P0200d<4@0500l>4`0@3a@03PdB018A5P0A41D00P0F5AX00`0B4AH04a8Goooo
o`0Cooooo`006oooool05P1[K6L051DA00X:200D51802`/:00l?3`0=3@d030`=00`<3P0H61X0:BT/
01@C60081``0410C00h>400G5aT030`=00l?3`0820P04a<B018B400>3P`200l@2`0D014>2@0@3`X0
40l:00l>2P0?3`d04A4?05EEE`1?D5@07QlS01DF6`0>4AH030lD018A5`0F5AX03PdB01LF6`0N7R00
3Ph@01@D5P0@410200l?3`0K010@400B4Q80414E00l@4P0@4A<05QLI010B4@0E5aH03a4@014C400@
4Pl04Q@A01<E400A4Ph04A4@010@400@41404A4B018C500F5aX05aPK018F600C5QX061`P01@I700@
4aL051DI00804a@F02<04Q<E00hB4@0H7A`04ALE01TO6`0J8Qd03AHA018L500=51404aPI01DI6P0>
4Q<04QHG00lD5@0F6a/05AXK01DI6P0D61T04aLH018G600C6Al072<]018I8`0E72@07B@/01LN9P0G
7R@031<I018J7@0H82<04QXM01LO8P0Q9RX0GV=W02H[;`0201DJ7P0i014F6P0E6Qh02PlC01/P900:
3a<06AhR020U:@0D61/05APK01LK7P0G6al05QXN01@I7@0E7B405QhR01XR:@0I8BP05QhU01LN9@0O
8b/0ADYA03e2B@0D6b8082L^01HM900G82H05QlU01LP9P0H8bP06B@Y01`W;@0D8BT04b0X014N9P0D
8BP05R8X024/<@0I8RP05b0U01/T:00I8B@05QhQ01hV:@0J8RH072@X01@K800I82D07B@Y01XR9P0J
8BH05QhR01PP900I8BD06R4V01`T9`0I8B<06R8T00805QhP01806R8T01PP8`0D6b405ahT01/R:00I
82P06R4Y01DN8`0D7R805R4S01hY:`0C7R005QlR010I700B6ad05Q`P01`S9P0S:2`209RMX@0<01DM
7`0C71h07RLY01HO8@0K92L041TL01TQ9`0?5a`0620U01XR:@0I8BP05AdU0P0E7BH0>@0D72H051`T
01<K8`0C6b<05QhS01HN900C6b004Q/N01XS9P0`>cd062<V01<N8@0E7b804adP01PQ9@0A6Qh041LL
034i?@0C6Ah02PlD01@I7P0E71h05R0N018K6@0B71/05AhN014J700D72004QXO01<K8P0H82P06B4[
01LO:@0C72H051lU01<N900@6ad04adN018L6`0A6QP03QLD00dF5@0D6a`05a`O01DJ7P0C6ad03QHH
00lG6P0;4QP051/Q01LN9P0A61h051`O01<L7@0G81l04AXG014J5@02014G4`0301<I5`0E6Qd04QLJ
00804AHJ00L04QLK00dB4`0I7al05A/I01<I5@0D6AD04AHB008041DA01@04QLC020U8@0D6AD04QLC
014F4P0=4Ph04QLC01<H500M8B004aLF018F5@0?4a804QHD01<H500B5a<03a@?01HK5@0?50h0;34[
028W80<041DA01404AHB018G4`0B5a<03A8>03m4@00=4Ph0314=01HK5`0>4`l03a@@00dB3P0F6aL0
3Q<?010E4@0E6QH02@h:01DJ5P0200hC3`08010E4@0=4Ph03a@@02L/:00C61@03A8>01@I5@0;40`2
010E4@803a@@00/03Q<?00lD400<4Q003Q@B00X@3P0?5A<02Q0>00dC4@0D6QP0318@00hD4P0200lE
4`03014G5@0>4`l041DA008041DA00<051TE01PM6@0@5A400`0A5Q801@0@5A403a@@010E3`0:3`T0
4aPB00<04AH@00T041D?00lD3P0@5@l03A8<00`A2`0?50d02Pl800`A2P0?50d00P0A5Pl200lD3@05
018G400@5@h020d600/@2@0>4``00`0?50d200dB2`0<010E3P0>4``01``500hC300;40T04AH?010E
3P083@H07R<L00`@2`0B5a004AH?0P0?50d07@0>4``041D>00hC300<4@X04A@=01@G400>4@X04QD>
00d@2@0V:B80CE19024T7@0_<R/05APA00hA2P0?4P/05QLA018C3@0E5Q003Pl9018C3@0@4@/04Q<=
014B300@4@/03a0:014B300C50h04aH?008051L@00@041<<00`?200;3PL04QD>0P0@4``03`0930D0
41<<00hA2P0<3`P03a8;00d@2@0<3`P03a8;00hA2P0<3`P04QD>00hA2P0;3PL03a8;018E3P02010B
3@0G014C3P0?4@`03@l:00lA300B50l02`d800lA300D5Q402`d8018D3`0<3PP04aD?02X/9P14Ad40
3Q0:00P:100B5@l03A0:020R700Q8ad02`d700lA2`0B4`h00P0C50l01@0A4Pd03@h900/<1`0@4@`0
2P/600<0414<01h03Pl:00h?2@0B4`d02``600/<1`0;30H030d7014B300;30H0414;00l@2P0>3`T0
4Q<=01<D300A4PX03Pl700d>200@4@/04Q<=010A300>3P`04a<A038b<021PGl0:RXX018C3P051P<0
5aPC00`=20092PD200l@2`0500/<1`0B4`h020T400T:1@0@4@`00`0=3PT02@0>3`X03a0;00l@2`0@
4@`03a0;00d>2@0C50l04Q<>00`=200200h?2@0S00l@2P0>3`T03@h800l@2P0<3@L05QLA014B300=
3PP03a0:00`=1`0D5@l03Pl9014B300G61803a0:014B300C50h0414;01DF400C50h03Pl901@F4@0>
40/03a4<010B3@0;3@P03a4<00`>2@0C5A002P`8014C3P092`H03Q0<010B3`0>40d00P0?4@h02@0>
40d03a4>00lA3P0<3P/0<S@a010B3`0;3@X04A<@010A300200l@2`<03Pl:00L03a0;00/<1`0@4@`0
51D@00d>2P0j>cH05aPC00803@h901X03Pl:00d>2@0@4@`030d800l@2`0A4Pd0414<00h?2P0=3PT0
2``701@E401hNG@0@d@o010A3@0D5A003@h900l@2`0<3@P02``700d>2@0<3@P02@/800d?300<3P/0
2P`900d?3080418?02H03a4>00`>2`072@H02`d:010B3`0<3PT04A<>01XL5`0@4Pd03a4<00/=200?
4@`051HA014C3P0?4@`02P`700/=200?3`d030`:00d=2`0E5A<030`:00h>300<30X02PX800`<2P0B
4Q0030`:018B400C4a403Ph<00`<2P0?3`d0410>00X:200B4Q002`/900h>30803@d;00L05aLE01PH
5P0L71X04A4?018B400?3`d0=3@b00805QHD01403Ph<018B400;2`T04a<@01LH4`0:2`H04a@@00/<
1`0=3PT02``700l@2`0n?cX0414=01dN6@0>3`X03a0<010@3P02018B40804A4?01D0410>00d=2`0<
30X04A4?01HF500A4@l03@d:018@300A3`/03`h:010?2`0A4@h02PX800l@3@0:30X06A`L00d@400>
41003@d;00h>300A4@l00P0C4a400`0B4Q003@d;00h>3002014A3`0V010@3P0?3`d05AHA01@E400C
4a404Q8@014A3`0B4Q804A4A00d=3@0>3Q00410B00h>400C4QH051@F00l?3`0@41003@d=00d=3P0<
30h03`lA010@4`0E51T051<H00`;400D4aT030/@01PG701<Be0051<H010?500>3A804A0E010?500A
41D040lD00h=4P0@3a@Dooooo`006oooool0200b<bh0004001<C4@0A4@l09bLV018B4P0:2PX03@d>
0P0=3@l08@0B4AD061LL01TH7@0/;2l0410B01HF60092@X01`L701<C4`0A4A004A4?00l?3@0<3@P0
3@h9010=200?3PT03Pd800d<200>3P`04A4?010@4P0=3Q805AHJ01dN8`0@4aP010L<00l>500:2@h0
30/@024P9@0_;c4071`N018B500200d=3@0Z00l?3`0A4A404A4A00l@500<3@l03a0B01HG6@0F61L0
4aDD00lA400?4@h03Q0=010B3`0B50l06AXG01TI6@0D51@04Q8B01<C4`0C5A@05QPG01XK7@0E6AX0
4QHH01HJ7@0C61`04A@H01<D600A4Q@04Q<E01<D5P0A5A@03A8A010F500F71P04QXE018K5P0Q:b<0
2a8?010F5P0A5AH051PI0P0A5AH201DI6P804aLH01404aTI01@J6P0A5a`000LA01XQ:P0^=Cd0_<?;
01hU;00;4QP04ATL01@L7`0@61/04QXM01DM80093Q80;34e00dB5P0201@I7@0701LL800D6Ad01``@
01PM8@0O92P0PXN;01TM8@0201PI7@0801LJ7@0F6Ah05QTN01DJ7P0F7B<05A`R01@M900E7RD201LP
:@0K01HM9@10A4d0=3Q100hE7@0T:c<05ahV020Y<00O:2l07BH]01`W;@0K9R`06RD[028_=`0N:c<0
3a`T00XG7`0H92/07RT_01HO9P0F7bD0624V01LO8P0F7R4072@W01@K8@0L8bT092/a008051/Q0240
8BP^01/R:00I82H061lU01TP9P0H7bD05AdP01PP8`0I8B<051`N01HN800K8bH05alR01TP9P0L8bT0
61lU01TP:00J8BT05ahT01/U:0064A<02QDG010J700H82<07RHY014I700C61`04QLK00dB5P0O92P0
8RL[018J700F7R000P0I8B<0800G7b805AdP010G7@0L8bT031<I01XQ:@0C6R803aHN018I8`0E72H0
5ahX01LN9P0E72@051/S01DL8P0G7R@06R4V01PP8`0F7R4051hP01@O8@0;5QP041/M01dW:@0F8280
214C05=KGP2V[[405Q`P01LL800N8bL02a8C0P0?61D01`0?61H041TH014I6`0A6A/04QTO01@K8`0E
72D00P0E72H0600D7BH05R4W01DP9P0?6Q`04adN018L6`0?61H03aPE00lH5`0A61T04QLJ018G6`0=
5AL02a<E01PP8`0?5Q`05QdS01DL900I82H03aLJ01@L7@0I8R40624N00`E40804ALC00X04QPF01<H
6`0D6A`05AXN01/P900:3a<05adN01TO7`0<4Q0041HB0P0@5A40100F6aL04aPD00`A3@0@5A4201@I
5@0501<H500B5a<04AHB014F4P0A5A@00`0B5QD02`0B5a@04AHB01HK5`0@5A005Q/E00H;1@0P9Ah0
20d601<H500B5a<03a@@00<03Q<?01<02Pl;01@I5@0@5A404AHB00lD400N8al0<SLc01hS7`0E6QH0
2@h:00dB3P0@5A405AXF01hS7`0>4`l041DA00lD400<4@d03Q<?008041DA00D03a@@00`A3@0;40`0
3a@@010E4@0200hC3`0D01LL600N8al0728P01@J600C6AL03aDC00/A3`0=4a404aTG00P>300?5A<0
41HD00`B400@5Q@041DA018G4`0@5A403A8>014F4P0F6aL600hC3`0300lD3P0=4P`03A8<008041D?
100A5Q007`0?50h03Q<=00dB300<4@X02a0900dB2`0?50d03Q<<00L<1P083@H02Pl800T>1`0D6A80
5a`E01<H4@0;40T02Pl800`A2P0:3`P02a0900L;1P093PL07b@M00d@3017C4D0008000hC300;40T0
3A8;01@I4P0A5Pl00P0<4@X00`0=4P/03Q<<00`A2P0200`A2P8041<<0`0?4P/200hA2P0600P;100P
8a`02`h701@G400>4@X04A8<0`0@4@/02`0A4P`0414;00d>200@4@/05aPB01PI4`0E5Q003a0:00`?
200=40T03a8;00<041<<00/03Q4:01@G400>4@X05aXC00T<1P0D5a0030l800lB2`0;3PL030l8014D
3@0200hA2P8041<<0P0?4P/00`0@4``03a4<00lA300200h@2`803a4<01H06A/F020R7@0A4`h03Q0;
00X<1`0C5A0051L@01DH4@0A50d03A0900hA2P0C5Pl03Q4:01@G400J7AH0;S4Z03Hi<P0D5a002P/6
00/<1`0=3PT0414<0P0B4`h05@0A4Ph0824L01LH4`0?40/02``700P9100A4P`03Pl900`=1`0B4`d0
2``600l@2P0@4@/04a@>01@E3`0;30H02@X400d>200@4@T02P/300`=1@0200d>200=010A2`0?40/0
2`/900l?3@0C4a405aLE00d=2`0>3`X020T4010A300;30L02P/6010A3002014B3@0600h?2P0;30L0
3@h900l@2`0>3`X03@h90P0>3`X600l@2`0300h?2P0@4@/04A8<00@0414;00@03Pl900X;1@0:2`D0
3@h80`0@4@/06`0?40X03@h8010A2`0B4`d0414;01HG4@0C50h0414;00l@2P0@4@/03a0:00/=2007
2@@0>S`g00@60@0H6QD02`d800P:1@0E5a803@l:014C3P0K7AP020X500d?300Q8b007R0M00T;2002
00lA3P0600<50P0A4a007R0M00@60`0?4@h01@L40P0?40/04@0>3`X03@h900d>2@0=3PT020T4018C
3P0<3@P03@h90411?03Mg]T0:b`W01<D3`0H6A@05QLB01<D3`0<3@P051D@008061TD00X05AHA010A
300>3`X0414<00/<1`0N7aX03a0;00T:1@0H6A@03a0;0P0B4`h02@0?40/03@h900d>2@0;3@X03@l<
018D4@0@4Pl02`d:00lA3P0200h@3@05014C400H6QL0;S0]03m1?P0J71L00P0=3`X01P0I6aH03Q0;
00h@2`0?4@`03@l:00/=20<02P`700`04a<A00l?3@0C4a4051@B010@3P0C4a404A4?00`<2P0=3@/0
410>00l?3@0=3@/200l?3@803Ph<0P0=3@/01`092@L02PX800X:200>3P`04A4?01<C4@071`D00P0A
4@l08@0E5A<05aLE07inO01>CT`04A4?01@D4P071`D0410>01PI5@0@4@`07QlJ05MHD`0M7QT02``7
00d>2@0/;BP0QXN2020Q70092PD00040010@3@0>3P`04A4?018B400@40h04A4?018B400>3P`03@d;
014A3`0D5180410>00`;200200d<200<00h=2@0=3PT03@d;01HH5@092`P04aDD00hB4`0J7Ql02Ph>
00`<300=3@/03`l=0P0A4@l4018B4006010@3P0?3`d03`l=018C3P0A4Pd03`l=0P0>3P`0700?3`l0
4Q8B01<C4`0B4Q@04A4C01<C5@0D4aL04Q8D014A4@0@41004A4A00l?400;2`d04a<E01@C5`0510T0
61LL01@C6@0@3aD040lD01TH7@18Ad`04A0E01@C600?3Q<03PdB014@5@0B4AH2010?5003014@5Ooo
oooooooo01;ooooo000Kooooo`0D00l@2`0>3P/071`J00d=2`0T92<030`<00/;2`0@41403Ph@00X:
300@41<07A`Q018A5P0X:2/020P:00`<3P0>3Pl02`/;00`<300:2PT2010@3P0N00d>2@0?40/04Pl:
00l>2@0>3@P03@`8010@3P0C4a4051@F00831`0720`01@H;00d@5@0R9BX0;2/a00l>4`0B4AH04a8G
010@4P0820X04A4C00d=3@0<30`03`l?010@400?3`l03@hB00d>400>3a40414C0P0A4a80=@0>40l0
3Q0=00h@3@0@4Pl04A<>01TJ5`0J6QX04a<C00l?3P0@40h0418?01DG500K7A`061`K018F600A5AP0
4AHJ01<F6P0D5AT04Q<E01<D5P0E5QP04aLF018G5P0G7A/05Q`H018J5@0F7aX0:S@/01<L600A6QT0
4aTI01HK6`0A5AH04Q<E01DF600D5AL04ADF014F5`0B61P051XJ01PP900I82P051/R00893`16CE<0
5A`Q00XB5@0F7R4051`N00TA4`0?5aT041PJ00<03a@G00`05Q/N01@I700B5aX04QLJ00hC5P0D6A`0
7B8U07IkOP0F6Qd061TM01PI6`0H6Ad201HI7P0;01DJ800D6b<041LO00hG800D7RL06B<]01TR;00D
6b<06alX01PL9@0E72@00P0N9Bd06P0C72<05AhU01@M900B7B<051lU01HQ9`0C82P04b0Y01HS;00?
72@08B`e01@N9`0E7RD06B8X01HO900F7B<05ahT01<J800X;cD09bhd02/b>00C6R00:2le00T@5P0M
92X06R4W0P0I82H0:P0H7bD05AdP01LO8P0G7b4051`N01HN800K8bH0620S01PO9@0M92X051/Q01@K
8`0J8BT05ahT01<M800J92H09c4c03m9B`0J8RD051`O01XO8`0I7R80724U01HI7P0E61d02PlC01DM
7`0G7b406B4S01PP8P0E7B0051`O01@K8@1FGF<072<Y01HM9@0@5al06b8Z018I8`0C6R@05A`V01LN
9P8061lW0P0E7280@00I8BD0620S018J7@0;5AL04A`N01DP8P0A71h03QPJ00dG6@0B6ad04a/N02`d
=`0J8B@05AXN010E6@0@5aL041TD010I5P0@6AL04AXI018J700A6A`051`O01LN900E72<04APP01<J
900D7BH051lU018M8`0>6A/04A/L018L6`0=5aD03aPE01<L6`0@5aP0314D018G6`0=5AL02Q8D00hF
6@05318031<I014H800`=cd06B4T018K70084A004Q/H01@M600C6AD04QPD014G5@0@5AP04aPK01HK
7`0731006QlS014F600=4a<02Q0>01DK5`0B5a<2014F4P0300lD400=4Ph05a`H00H04aPD100A5A@0
300A5Q<04AHB010E4@0A5Q405a`F00hC3@0B5a401P/401<H500A5Q803a@@00dB3P80314=00D03A8>
018G4`0C61@041DA00lD400203Ll>00;01TN6P0?51002Pl;00lD400<4@d061dI01lT800@5A404QLC
014F4P0@5A400P0A5Q804P0@5A403Q<?00/@300:3`/03A8>00lD400>4`l04AHB01/P700Q9R80728P
014G5@0>5180318@00/A3`0>51803A<A00P>308041HD00P02Q0>00`B400>4`l04AHB00lD400<4@d0
3A8>010E4@H03Q<?00<03a@>00dB300=4P`01`0@5@l08`0?50h03Q<=00dB2`0<4@X03Q<<00lD3@0>
4``05AXC00dB2`0320406QlH00`A2P0?50d09BXS00`A2P093PL03A8;00`A2P0:3`P05a`E00@90P03
2040724J0:>XX@0V:b@03a@=00`A2P0=4P/051TB010E3P0<4@X03A8;00hC300=4P/03a@=008041D>
0P0>4@X300lB2`0F010C300E614020/400d@2@082`@05APA00hA2P0C50h03a0:00d>200B4`d051D?
00l@2P0B4`d05AH@01XK5@0I6Q@051D?00`=1`0=40T0314:00hC30<03a@=00P03Q<<010E3P0F6a@0
=CXc00P=1`0<4@X03A0900lB2`8030l800<041<<00hA2P0A50d00P0@4``2014D3@0300lB2`0?4@`0
3Q0;008030h902D03Q0;00lA300210004aD@00L9100=3`X05ALB01HH4`0A50d04QD>00hA2P0:3@H0
2`h7010C300:3@H04QD>00P;100R9Ah0@4<l01<F3`0D5A00414<00d>2@0>3`X0414<018C3P0>3`X0
3a0;00H70P0<3@P0414<01LH4`0D5@l03@h800X;1@0B4`d03@h80080414;01@02P/5014B300R8ad0
6Q/E00/<1P0>3`L02``4010A2@0A4P`03@h800h?2@0>3`X03@d;00l?3@0;2`T03@d;00D50`0>3`X0
20T400l@2`802``700<04a@?01DF4@0A4Pd00P0<3@P00`0A4Pd04Q<>00l@2`0300h?2P803@h90P0>
3`X200l@2`07010A300B4`d04Q<=014B300@4@/04A8<018C3@0201HG4@06018C3@0?40X03@h800`=
1`0>3`T0414;0P0=3PP200l@2P0401DF400B4`d03Pl900d>20803a0:00D030h900T;1P0d=S400040
01PJ5@0200d?2P0A010B3@0<3PT0008001DG4P0;3@P071hK02T[:00M7a`020X700h@3@0?4@h020X7
01DG50072@H01PP503Dg=00M7a`00P0>3`X200d>2@8030d802/01PL201@E400B4`h04A8=01lP6`1d
MG00:2TT010A300D5A004a@?018C3P0<3@P04a@?01DF4@0D5A004A8=00h?2P0=3PT01`P300X;1P0;
30L010D000h?2P0=3PT02P/600l@2`0A4Pd03a0;00d>2@0;30L03Q0=00/=2P0@4Pl04A<@00d?300<
3P/04aDB00lA3P092`P01@L400h@3@0I6aP030d:0080004000D051HA00H80`0G6A@03@l:00/=2002
00X<1`802`d800`0410>00d=2`0@40h0410>00h>300?3`d04a<A00l?3@0>3P`03`l=00h>300=3@/2
010@3P803`l=0P0>3P`0;`0D51805aLE00h>300;2`T03Ph<00d=2`0:2PP051@B00l?3@0>3P`01PH4
024Q7`21PGl06QXH0000000N7Q`0PH5o00X;1`0=3PT03a0;02//9`0<3@P02``7018C3P061`808b@O
00`=200L7AP04Q<>00X;1`0>3P`04Q8@01@D4P0A4@l0410>014A3`0>3P`030`:00l?3@0A4@l03`l=
00h=2P0?3PX03@h900h>300?3`d0414>00801PP700D061`M000310072``02`l?00h>3P0300h>3003
00l?3@0@40h051@B00805QHD00<03`l=00`<2P0>3P`00P0<3@P08P0<30X03@d;00h>300@41003`l?
01PH600D51H03`lA01PH6P0B4QD03`lA018B4P0D51@04Q8B00l?400=3@l030`>00X93@0K6Ql06QTN
00l>4`0100H04a8G01/J7`0B4AH03PdB01@C600C4QL03PdB014@5@0B4AH040lD00l>4`0@3a@Doooo
o`006oooool01@0:2`H03Pl;00L71@0=3@/03@d<00803`l?01l0410A00h>400<30h03@d@010?500=
3140410C00P82P0@41804A4B014A4@092@T09bLV01lO7@0@40h04Q<>00l@2`0F4`h04A0;00l>2@0A
40`051@B01HF500A4A<0414E018C5`0?41D04A@I01TL8@0J6Al030/@00803`hC00D051@F014A4`0@
41803@d=00h>3P02010@400A00l?3`0>3a<04A8D010A4`0=3Q003a4@018D4`0A4a803a4>010B3`0C
5A804aD@01<D4P0B4Q<0410@014A400C50l00P0C5A00600G6AH061`K01@H6@0>4QD04AHJ01HI7@0E
5QX051DG01HG6@0G61X04aLF01<H5P0C6AL03aDA01@K5`0:4`h06B<K018L600?61L041HF01<H600B
5AH05ADG01LG6@804Q<E03@041DF018H600B6aX05QlQ00hE6P0@61`092/`010E5`0G7b8051`N01<K
700D7Ad04a/L00lH5P0D7A`07B8T00L=300F71`04ALH01`R8@0B61P04aPJ01dS8P0J7b00D5IG00dC
4P0I7Al05aPJ01PH6P0H6Ad061TN01LJ7`0F6b406B0X01PO9`0E7bP05AlZ01DP:`0I8bh061lY01XN
:00N8R`05QdV01@K900Q:3406b@/01dV;P0L9Bd06R@/01dW;`0P:S<0E65Z0P0N:c@04P0H9Bd08blh
018L9@0G82P07BH]01@M8`0E728072<Y01HM8`0J8BP072<Z01hU;00h?dH0W:>Z02`c>P0N9B`06b8Y
01PO9P806B0W01405ahT01LO8P0F7R005QhP01TQ8`0J8R@0620S01LN900J8BL07B@Z01PO9`0G7RH0
7B@Z01<L800A6ad04adO02H_<P0201HM800701DJ7P0C5a/05ATM01DH7@0M82D061/P01LM800201LN
800701HL7`0C6Ad04ALK018H7P15Be406R0V01LL9@0201XP:00b01LL9`0E6RD051XT01HK900H7BH0
6AlW01XP9P0G7B<05A/P01@K7P0E71l05QlR014M7P0D824041/L00lI6P0G8B<04Q/M01LO8@0A6A`0
5A/N00hC5`0C61`041LF014H500A61D04QTG01<K6@0D6a`05A`O01DK7`0E6b4051XQ01@I8P0D6B<0
4a/T014L8P0@6b403aTK010J6`0B71/041TG010I5P0B6aX04QTJ018G6P0H7B403aLI018J700E7B02
014H7P0701DL900B6Al06b<V03]3A00Q:RT03aPE010I500201DK5`0:01@J600B5aX04AHI010E6@0P
9BT0MGYn020V9`0E6a/051XH00lE4@8041DA0P0A5Q801@0D6AD06QlK014F4P0A5Q804QLC00804aPD
00<051TE014E500@51<00P0?4a80300@5A804AHB00dB3P0B5a805AXD01XO6@0A5Pl05a`E018G4`0A
5Q8041DA00lD408041DA01804AHB018G4`0<4@d041DA01@I5@0[<2`082DQ010E4@0D6AD04aPD01@I
5@0;40`0314=01<H500;40`041DA014F4P0E6QH3010E4@803a@@00l03Q<?00dB3P0B5a<04aPD014F
4P0>4`l03A8>014G5@083P`02@l=00dC4@0D6QP06AlM00dC4@0:40h00P0?5A<0200<4Q003A<A00`A
3@0@5A404AHB00lD400=4Ph03Q<?1P0@5A400`0?50h03A8<00dB3002010E3`0300lD3P0>4`d03a@>
008041D?00D03a@>00hC3@0<4@X02a0900lD3@02014F3`0900`A2P0E6Q<0314:00`@2P0>4``0<SL`
04Q=AP0A5Pl0314:00804QL@0P0>4``04`0B5a002a09014F3`093@P04AH?00hC300=4P/03Q<<018G
400=4P/02a0900hC300=4P/02a0900`A2P0=4P/0314:00d@2@0>4@X00P0?4P/0200@4``04A@=00P;
1@0>4@X03a8;00`?200>4@X041<<1P0@4@/02`0R8ad07b0J01HG4@0@4@/04A8<01@F3`0A50d03a@=
010E3P0?50d03A8;0080314:00D02a09030e;P1FFe@061dF00/@2@0200lB2`803Q4:0P0?4P/0200C
5Pl03a8;00hA2P0A50d041<<00`?200?4@`03@l:0P0;3@P03`0=3`X03a4<014C3P0=3`X02@/6018D
3`0=3`X04Q@?01LJ4`0@4`/03A08010C2`0?4PX020/300hA2@0200d@200;010C2`0B5@d03a8;01DF
4@0A4Pd03a0;00d>2@0<3@P03@h906=TG`0O81/00P0C50l07@092PD04Q<>01<D3P0?40X02``6014B
300=3PP04a@>00`=1`0=3PP03Pl901`M5`0K71H03a0:00d>1P0@4@T061TA01PI4`0@4@/03Pl900`=
200A4@l04a<A00d=2`0A4@l02`/9014B3@0<3@P0414<00803a0;00D04Q<>010A300>3`X03@h9010A
300201<D3`<03a0;00<03Pl:00`=200>3`X00P0?40/200h?2P0300d>2@0>3`X03Pl9008030d700D0
3Pl9010A2`0G618061TC01<D3P02010A2`0600l@2P0@4@/04A8<014B300B4`d0414;0P0>3`T07@0=
3PP03Pl9010A2`0B4`d04A8<014C3P0<3PT03a4<02PZ9@0E5a803Q0;018D3`0D5Q403a4<01@F4@0@
4Pd051HA02`^:`0E5a@020X700lA3P0=3``03a4>01HH5@082PL05ALD00D7100e=c@0828P00H03@h9
02<0414<00`=20061`803@h900/<1`0E5Q405aPC00d>2@0A4Pd02``7014B3@0C50l030d800h?2P0=
3PT030d800d>2@0@4@`030d800h?2P0=3PT0414<018C3P082@@02``700d>2@0?40/0414<01<D3`0H
6A@06A/H00`>2`0:30T03Q0=00`>2`0200X<2@0500h@3@0D5Q<03a4>00d?300B51400P0I6aH0100>
40/02P`801LI50082PL200`>2@0>00h@2`0@4Pd04aD@01DG4P0>3P`02`/900`<2P0>3P`03@d;00`<
2P0A4@l0410>00l?3@0@40h2014A3`<03`l=01P03Ph<00d=2`0=3@/061PF01lO7@0A4@l03@d;018B
400>3P`04A4?01DE4`0;2`T05QHD02<S8@0K6aT02@T700l?3@0B4Q005QHD01LG5@0C510030d8014B
3@0D5A0200P9100800h?2P0A4Pd03@h901@E40082@D03Pl:00h>2`0?3`d2018B4006010@3P0A4@l0
4Q8@010@3P0=3@/03`l=0P0@40h0600?3``03Ph;00d>2P0=3@/03Ph<00lA3`0A51<03a8A00lC500>
4aD01``>05YNH00?4A003`l=00d=2`0<30X03@d;00l?3@0@40h051@B01DE4`0=3@/02PX800h>3080
3Pl:0`0>3P`0600?3`l0410@014A4@0B4Q@04A4C010@4P0>3A404Q8D01@D500E5AD0410@010@4@0D
51H05QHH00l?4P1=C54092<X01@D6@0E51X03PdB01`K800C4QL04Q4F00`;40803`hC0P0B4AH00`0@
3a@03`hC010?500Dooooo`006oooool06@0;30L04A4>00l?3@020P003`l>00D51@0<30`02PX;00`<
3P0?3a403PhA00/:3`0H5a`02`X>01<C5@0E5AL02PX;00/;2`0:2PX0=3@c02DU8`0>3P`04Q<>00l@
2`0C40/00P0<2`H0400?3PX0410>014A3`0>3Q0071dQ00`=4@0720d030lD00H93P0C4QP061LL010?
500920d0410B00H6200A4A<200l?3`04018B4P0@41003`l?010A5@804a@F07X0414C014C4P0D5QD0
4aDD010B3`0B51405QPE01<E400A4Q00410B010@400C4a004Q<=00lB2`0=40X04A<>01DJ5P0G6a/0
41@G010E6`0E61d051DI01@E5`0F5aT05aPJ01<G5P0@5A@06b4O014G4`0<4`l03AHA01`V7P0B71P0
31HE00hD500B5QL04a@F01LG6@0H61X051@F018C5@0A5AH03aPG014J6@0@6AX03aLJ01PP8P000P@0
6B4S00lH600;51<03QLF028[:@0I8Ql0214>02/d<@0G7A/03Q@B018H5P0;4@l05adK014G5@0C6AL0
51XH01PN700f?3X04QPF01LL6`0F5aT05aLI01TI6`0H6Ah05aXO01PL8P0H7bL06b@]01/T;`0B7RX0
3a/W01@O;00K8Bd07R8]01/O:P0E72H05ahX01<J900E7RL04a`U01@M9P0H8R/07bTb028/=@1NJg@0
7R/d01HS;00E8R/06RH_01DO:00D7BH06b@/01LP9`0D6b4061lU01TP9P0A620061lW01@K8`0A6200
ADaD00hE7@0L8b/061lW01HM9@0G7RH061lW01PO9@0H82<05AdO01PP8P0I8B<05QhQ01DM80805ahT
01007RD[01XQ:@0B6B405QdS01HO8`0K9BL0BE=E02H^<@0G720051TM01/P900M82D071lT01<F6`0I
72405aXO0P0F6ah03P0E6Qd04aPK010E6@0@5AT04QLM01DJ800>4aT05ATR01dQ:P0A5Ah06QhY01LK
9P0F6RD05QXS0P0G6b@03`0G72804QLM018G700E6Qh061dQ010I6`0F8R80?4Q802hi>@0641403QPI
010I6P0:4Q@00@T;01HL7`0201<H6`0=014G5P0A5a<04ALC01<I5P0E6aT05Q`L01PM7`0D6Ad041DK
01@H800H72D05QXS01<K8`02010K8@0W01<M7`0@6Q/03aTH01<M6`0A6QL03AHE00lF5`0B5aX041DI
00L?4@0?5aT03ADH010G7@0<4aT051/S01hU:`0B6Qd06B8S00XC4P0@6AH0624L00lE4@0@5Q804aTG
01@I700B5aX041DI00H;3`0L8BD051TK00`B4P0630X051XF010E4@0A5Q803a@@00dB3P0A5Q804QLC
00803a@@00H041DA014F4P0A5Q804QLC01DI600D61L2018F5@0P01@H5P0E6QH05Q/G01<H4`0=4P`0
4AH@00`A2`0B5a005Q/G01@I5@0A5Q8041DA00lD400>4`l02a0<018G4`0>4`l05Q/G010E4@052PH0
7B8N010E4@0A5Q802a0<00lD400>4`l02Pl;010E4@0<4@d041DA00dB3P0A5Q8200lD400300hC3`0@
5A404AHB00804QLC00H03a@@00hC3`0?51004AHB018G4`0G7A/200dC4@0400hD4P0?5A<04aTG010F
50<03A<A00<03Q@B010F500B5a<00P0B5a<00`0?51002a0<00T>2P06014F4P0300lD3P0=4P`03A8<
008041D?00<03a@>00hC3@0?50h00P0?50h08`0>4`d03A8<00`A2P0;40T03a@=018G400A5Pl03A8;
01lT7@0I7QL020d600L<1@0;40T05a`E00hC300<4@X04AH?00lD3@0<4@X01P/500T>1`0;40T02@h7
00hC300C61404QL@00dB2`0?50d04AH?00X?20093PL03a@=014F3`0B5a003Q<<0080314:0P0>4@X3
00lB2`04010C300K7QL08B@M00X=1P804aH?010051L@00d>200A4P`04a@>00h?2@0<3@L04A8<01LH
4P0E5Q004a@>010A2`0?40X03a4:00/@2@0<4@X03Q<<0`0?50d200P=1P0<010E3P0M8Q/04AH?01<H
4@0A50d03Q4:00lB2`0>4@X030l800lB2`0A50d03a8;0P0>4@X00`0=40T02`h700d?2P0400h@2`0=
00d?2P092`H02@/6010B3@0?4@`04aD@04U<A@0^<BX05aXA00T<0`0=40L04A@;00`?1P02010C2P0<
00/>1@0?4PT04aH=00L:0@0;30L03Pl:00l@2`0@4@`03a0;00h?2P0K71L061TD0`0;30L02`0@4@`0
3a0:00l@2P0?40X05QLA00l@2P0B4`d03a0:01<D3P0>3`T02``6008030d701@04A8:00T:0P0;30@0
3@h800l@2P0C50h03Pl:014A3`0C4a4030`:010@3P0;2`T03Pl:00/<1`0<3@P03Pl:00d>2@0?40/0
414<00h?2P803a0;01D03@h900`=200>3`X03a0;010A300>3`X03@h900l@2`0@4@`03a0;00h?2P0<
3@P02``700d>200>3`T03@h800h?2@0?40X04A8<018C3@0?40X00P0=3PP200l@2P0T00h?2@0A4P`0
51D?01DF400A4P`03a0:00h?2@0=3PP03Pl9014B300C50h04A8<01<E40072@@07AlJ010B3@0?4@`0
3Q0;00T;1P0>40/010H300`>2@0H6QD0418=00L91P0A4a004Q@A00d?300A4a00418?00@60`0F61D0
2@/800/=2P0=3``01`T60P0=3PT200h?2P803a0;00l020T4014B3@0D5A00414<00`=20061`80414<
00l@2`0A4Pd01`P300`=200>3`X0414<014B3@0?40/00P0<3@P01@0>3`X05AHA00`=200:2`H04a@?
00802``70P0>3`X01`0=3PT03Pl:01HG4P0N7aX07b4N010B3`0;3@X00`0=3``03@0D5Q<03a4>00`>
2`051`@00`D200L91P0=3`X030h901HH4`0U9b80DE=>01`N6@0?4@`00P0>40/01P0?4@`0418=010B
3@0@40h03`l=00d=2`80410>00<030`:00h>300?3`d00P0?3`d00`0A4@l051@B00h>300300d=2`80
30`:00D02`/9014A3`0;2`T03@d;01@D4P03018B400=00d=2`0J6QP0>c/i01`L6P0M7A/0000001HF
500000007alM00`=2@082@@04A8=00<4000200l@2`07010A300D5A00004001<D3`0G61<03Pl:00L8
1@0200`<2P802PX800<030`:010@3P0@40h0100@40h00`0>3P`03@d;010@3P02010@3P0900h@3`03
1`H0310?07UmOP0U:Rd00PL:01/O8@0?4A003`l=00<03Ph<02T03`l=00d=2`0@40h04A4?00d=2`0<
30X03`l=014B3@0B4`h04Q8@010@3P0?3`d03@d=01DE5@0=3@d04Q8D01HF600<30h0410C01HF600D
51@04A4A00d=3@0A4A805aLI018B500L71l07QdR01LF6`0Q82D081lU01@C60061@X06APM014@5@0@
3a@02PT>010?500C4QL04Q4F010?500200h=4QCooooo000Kooooo`0V01HG4P0:2`L06a/I01<C4@0=
3@`02`/;00d=3@0=3@h030`>00/;3@0=3A003`hC00d<4@0;2`h04A4C00/;3@0;2``03@d=00T92@0G
5aH05ADC00`<2P0?40/04a@?014>2@0;2PD030/6010?2`0?3`d03Ph<014A4`14ADT0>3Tm01LH7@0;
3Q<020/@00T83P0?3Q<2010?500901PH6P0@41804Q8D010@400A4A404a<C014A4@0@41004A8F00<0
4Q<E01H04aDD01@F5@0C5A@03a4>018D4@0F61D04Q@?010A400A4A<03`l?00l@300?40X030l800`?
1`0@4Pd051TE01TM7@0@51L03A8H01<F6P0D5AT051DG0P0F5aT08@0B5QD03A8@00hD4P0D6QH0<cXf
014J5@0=5`l04A/G00dG5P0B61P061/L01DF600E5AL061HI01HF600D5AL04ADF00lH5`0A6QT041TJ
01<K7@0C6A/072@V01`U900>5aH02a@C010I5P0N9b<05AhI00`E400W<2/06R0L01`R7P0201DK5`1;
00hD400?5A405A/G00dC3`0B61@000H200hD400B5aD05aLI01PF6@0I6A/061TN01LJ7`0H72805QdU
01LP:@0I8Rd05R8^01DQ;`0C82d06b4]01dQ;00K7bX05A`V01XQ:`0N9Bl07bPa01PQ:P0J8b`08B/d
02Tc?00X<S/06RL`01PU;`0H9Bh05b@]01TU;P0F82T051dV01dV;P0Q:S406R4Y01<J8P0I82P06R4Y
01/R:P0L8b/04aXR01TP:00M92`06B0X01HM9@0D6b<05A`T01TP:00H7bD06R8U01DM7`0I8B<06R8T
01@L7P0D71l05A`R01LN900C6R007B@/01lV;P0C6R0061lT00dE600e?D0051`O03Hk?`0N8bL04QLK
008051LL00L03A0E01DF6`0?4QL05a`O01HK7P0E6Qd051TL00804AHJ00L07b@Z02T^=00I7R@04aLP
01@H8@0H72D05a/V00805QXU01805a/T01PL9@0H72D04aPN00hC6@0K82D08RL[01/P900@6A/0:3@d
05aXJ016DE402aDF01HP8@0I8R<07BDW024Y:`0=51H201PM800K010F5@0B61@04QPD01@J5`0F71X0
61hN01LL7P0C61`04QLM01<H7P0E6R005QXS01DM9P0A72804QdS01HQ8`0@6Q/03ALF018L6P0A6QL0
3AHE00dD5@0@5AP041DI01TQ8`0N9RP041PK008051/Q00L0:c8j00dD6P063Q403aLH01@M700C71T0
214<00804ALC00X04QPF018G6P0A5QT04AHJ01TN8P0<4AD06b0R01HL700630X03aDA0P0B5a<0100:
3`/02@h:018G4`0H7AT200hC3`@03a@@00l05ATH018F5@0@51<041@C018G500E6QH061dI01<H4`0=
4P`041D?01HK5@0D6A804aPD018G4`0@5A40100?5102014F4P0A01DJ5P0?51007R<O01XO6`0:3`/0
3A8>00/@300B5a<04aPD00/@300B5a<03a@@01<H500;40`03Q<?018G4`0A5Q800P0?51000`0@5A40
4AHB010E4@0200hC3`09018G4`0D6AD05AXF01<I5`0<4Q003A<A00/A3`083P`02Q0>008041HD00X0
3A<A00`B400=4a403A<A018G4`0A5Q8041DA00lD400<4@d02Pl;1P0?51000`0?50h03A8<00dB3003
010E3`<03a@>01h03Q<=00`A2`0>4`d03a@=00hC300?50d041D>00lD3@0<4@X00@H000@90P0I7QL0
3Q<<00D:0`0<4@X02a0900`A2P0@5@h0314:00X?200<4@X051TB01TN5`0:3`P061dF00D:0`0;40T0
3A8;00lD3@0@5@h200T>1`0600dB2`0D6A806AhG01<H4@0>4``04AH?0P0@4``300lB2`0?00hA2P0Y
;2D0<SD^010C300H6a@04A@=018E3P0?40X0414;014B300@4@/03a0:014B300=3PP03Pl900804A8<
00D0414;00d?2@0:3`P02Q4900`C2`0300dD300800hE3@0R:B401`h60007000;4PX03A8;018E3P0=
40T200lB2`0600/>1`0@4``041<<014D3@0@4``03Q4:0P0=40T03P0<3PT03a4<014C3P0A4`h03a4<
00`>2@0B50l051HA010B3@0:30L01@L402P[900R9Ah05AP?0P0;3PD02@0=40L030l600`?1P0?4PT0
20/200`?1P0D5`h02@`3014B3@02018C3P06014B3@0>3`X03@h900/<2@0I6QD04Q<>0P0=3PT06P0;
30L03a0:00`=1`0B4`d08B8L01<D3P0>3`T04A8<00L80P0>3`T05QLA014B300=3PP04A8:00T:0P0;
30@030d700d>200A4P`03a0;00h>300@40h02`/9010@3P0:2PP03Pl:0P0<3@P200h?2P0;00l@2`0@
4@`03@h900h?2P0?40/03@h900/<1`0=3PT03a0;010A300?40/0100>3`X03P0=3PT030d800`=200=
3PT03Pl900l@2P0@4@/04A8<018C3@0D5@l04a@>014B300@4@/03Pl90P0<3@L01`0@4@/04Q<=018C
3@0?40X04A8<01LH4P0C50h00P0>3`T01`0?40X04A8<014C3P0B50l05aTD0001000:30L00P0@4Pd0
4@041P40;c4/00H80`0>40/030h900D7100@4Pl051HC00h@3@0@4Pl04A<@00D7100L7Q/04aDB01HH
5@0@4Pl05ALD00803Pl:01<03a0;010A300@4@`04A8=01/L5`0=3PT02P/600/<1`0F5a805AHA010A
300<3@P0414<00/<1`0@4@`02@X500h?2P0@4@`03a0;008030d80P0=3PT01`0A4Pd03a0;01/L5`0@
4@`020T400/<1`0<3@P00P0;30L00`0?40/05AHA01HH5@0200d?300500h@3@0<3P/030h;00h@3@0;
3@X00P0>40d02P0A4a005QPE014C3P051`80418=01@F4@0V:2<01`T400lA300>40/200d?2P0?00h@
2`0?4@`03@d;00d=2`092@L03@d;00h>30092@L03Ph<010@3P0?3`d03@d;00l?3@0B4Q003`l=00<0
3Ph<0P0=3@/01@0?3`d03Ph<00d=2`0=3@/03Ph<00803`l=01X0410>01@D4P0?3`d092@R00L71@0E
5A<08b<Q00X:200<30X00`<100P81P0=3PT08R<N00d>2@0S91l051D@014B3@0g>3<06Q/F00h?2P0<
3@P02``700l@300<30X03@d;00`<2P802`/900@03@d;00h>300@40h0410>0`0>3P`03@0@40h051@B
01DG5P0C5A@04A<B00lC500/<340]KVj0497BP0F6ah01`X<00d?3P0?3`d0100@40h3014A3`<03`l=
00h0414<014B3@0A4@l04A4?00l?3@0=3@d04a<C014A4@0A4A<04Q8D014A4`0C4aH05ADG018B4P80
3`l?01804a<D01<C5@071`T04A4D00@3200F5AX051<I00d<4P0?3Q<020L<01@C600?3Q<04A0E00h=
4P0@3a@04a8G018A5P0@3a@200h=4QCooooo000Kooooo`0I09>AU@0Z:B`0:RX[03`m?0093@T03Q4=
00`@2`0@51003@h=00L7200>3@l03`dA00h=4P0W9RX05ADH00811@0>3Q003@d>00l?400<30d04Q8A
00`<2`0>3Pd03Ph;014@300200h=2P0I010@3@0?3`d03Ph<00d=3@0H6AX061PI01HG6@0?418051@F
01@C5`0@3a<04A4B010@4P0B4Q@0410B018B500?3a404A4B01DD600C4QH0410C014B5P0A4Q@04Q<E
01<D5@0201<E500f010B400>40d03Q0=01<E4@0C5A0041<A014D4`0?4Q404A8@018C3`0C4`l051@A
00l@3@0D5A@07b8R01<G6@0<4A<03a@F010C5P0G6Ad061XM018E5P0A5AH04AHF01HK6@1>De40a<S6
038j=P0A5Q<04QXG010H5`0G71`06QhO01@G600B4aD05ADG01PH6P0G6A/05ATJ01<H6@0C6QX05QdN
01DL7@0F7Ah06b<R01<K6P0D6a/05QdL018J600B6AL051/J01@K600F7A/041DC0P0H7A/0E@0L8Ah0
3Q<@010E4P0K81l04QLF010E5@0N8b<05AXJ01LL7P0J7B<05aXP01HI7P0H6al06AdQ01PL7`0H7B40
4APN01HO:00R;S`08bln01LT=@0I8Bh072<^01hV<@0F7BX0620Z02Pb>`0T;CH072D^01HP:@0F8BP0
5b4Y01DO:00H8b`0:3<l01dY<P0F8BX0624Y01/U;@0I8BX072@[024Y<00S:C0051XP01LM8P0N92T0
6AhS01HL8@0K7bD05Q/Q01XP9@0G6b005a`R01TO900L82H0724V01XP9@0J82<05adP01`R9@0K8R@0
5Q`O01PN8P0G7B<082H/01@J800X;CH0A4YB01/Q9`0G7B8041LJ01PO8P0C6Qd0>d1301hS9P0O92H0
6AdQ01LL7@0C61T05Q/L01<H6P0H7B005AXM01@I700C6Qd00P0D6Ql0B`0j@DL07bD/010H7P0F7RD0
5alW00lG7`0F6b<05ATS01DI8@0G72806b0W01hS:00J7b<05Q/O02<X;00W;2h07b@W01HN7P0;5a@0
72DU01<L7P0:4aD04a`P01PP90053A805QdS01hU:P0R:2d051XO018I6`0A61P041LF00lF500@61D0
51/I01@K6P0A61P04QTJ018H700B61h04aTQ01<J8@0B6Ql051dQ01HP8@0@6AL03QHD00lF4`0>5Q80
3aLE014G6@0@5AP04QLK00TA5@0=5AT04QTN01PO9@0>5A/05QdS01<J800G7b802A4C00`D5@0E7Q`0
4a`J03To?P0?5A@061dN00dB5@0730l04AHJ00hC5`0B5aX03Q8E01LL7P02018H5`0D00`A3P0>4a00
4ADC014F4`0@5A80314>00lC4@0?514041@B00lC4@0>4Q0041@B014F4`0?4a403A8?00lC4@0@5A80
3a@@01<H500A5Q4200lD3`0401@I500>4`h03a@@00lD408041DA00<04AHB018G4`0D6AD00`0?5100
4P0A5Q80;C8^01LL600@5A404QLC01<H500F6aL03a@@00L<200?4`l04QLC01<H500A5Q802@h:00dB
3P0A5Q803A8>010E4@<03Q<?01T03a@@014F4P0I7QX05a`H010E4`0E7Ah03QDF00lH5P0:4@d041P@
00/F2`0?6@h031@=00TC300=5Q003ADB00TA3P0@5A803Q8@00`A3P0A5A<03Q<?00lD400>4`l03a@?
008041D@00X03Q<>00hC3@0>4`d03A8<01PM5`0=4P`04QLA00hC3@0A5Q004aPB0P0>4`d0200A5Q00
41D?018G400@5@h03a@=00hC300=4P/03Q<<0P0B5a00100:3`P03a@=01<H4@0>4``200`A2P1300lD
3@0=4P/02a0900hC300=4P/01@X3010E3P0=4P/04QL@00`@2@0@50d04aL@00lC300;3`P03A4:00`@
2@0=4@X04QH?00lC300=4@X041@=00`?200>4@X04A@=00lB2`0>4@X04A@=00d@2@0I71D03A09014D
3@0:3@H03Q4:018D3@0>40T0418<01DG400?4@X04Q@>00h@2P0?4@X03a4;010B2`0@4P`04A<<00dA
2P0<4P/03Q<;00hB2`0;4@X02a0901@H4@0`=Rh061dF014E3P0>4`/03109018E3P0?4P/04QD>00lB
2`0;3PL04A@=01DH4@0F6A8051L@010C300200`?200I00hA2`0?4@`04aH@01@G4@0?4@/02`d700P;
1@0<3`T03A0:01<E3`0?4@/030l800lC301PI5d07B4I018F3`0<40T03a8:010C3@0>40T03Q0800h@
2P0>40T04Q@>00h?2@0200d>200500h?2P0@4@/04A8<018C3@082@@00P0B4`h0:P0F5a404a@>018C
3@0;30H051D?01hO6@0C50h02@X400`=1`0>3`T051D?00d>200:2`D04Q<=00h?200B4``061TB010A
2`0<3@L02@X400h?2P0<3@P03Pl:010@300C51003a0;010B3@0<3PT0414<01DG4P0C5A004A8=010B
3@0:2`H03Pl:010A300;3@P02``700h?2P0B4`h0414<00h?2P80414;01<03Pl900d>2@0=3PP03@h9
00l@2P0@4@`02`d700/<1`0?4@/051H@00/<1`0A4`d03Q0:00d?2@0?40/0418<010A300?4@X0418;
00804Q@<0280418;014C300M7aT061TD018D3P0;30P030d8010A3@0;3@P06A/F00d>2P0B50l04A<>
00h@2`0D5Q402`d8055CCP0V:2<04A<>00/=200H6QH03@l;02<U8@0=3`/030h:018D400@4Ph030h:
01TK5`0<3PX03a4=01@F4P0B4`l04A8>0`0?4@d08`0>40`020T500d?2`0?40`02@X600`>2P0=3`/0
4A<>00d?2P0=3PT061TD02LX8`0B4`h03a0;00lA300H6QD04A8=010A3@0a<Rd0824L01<D3`082@D0
4Q<>00l@2`0;30L04A8=010A300>3`X030d800h?2P0@4@`03Q0<00X<200<3PX02P`800802`d900d0
3Q0<01<E4@0B51003a4=00D71@0<3PX03Q0<00T;1`0B51003@h;00h@300A4`l03Q0<00803@l;0100
3a4=010B3P0@4Ph051DA020P7@0E5A804A4>018B3`0:2PL0410=01<D400B4Pl03@d:00H71@0>3`/0
3Ph<0`0?3`d200d=2`0]00/;2@0>3P`051@B00l?3@0>3P`05ADB00/<200:2`L04A4>014B3P0Q8Qh0
4A4>00d=2P0720@0414=00d=2P0:2`L04a<?00D60`0<3@P0414<00`=20061`<0414<024R7@0H6A@0
3a0;014B3@0<3@P03Ph;00h>3@0@40l04A4@00l?3P0>3Pd030`;014A400C4a80410?00d=300;2`X0
3Ph=00`=2P0C51804A<A00803a4?03402Pd;00d@3P0V:BT02`h>00X?3P0@4a<03Q0?00l@3P0@4A00
4Q<A014B4@0>3`h04Q<A014B4@0@4A003a0?010A3`0A4Q0051DE00l@4@0;2`d03a0B01@E5`0=3Pl0
30d@01dM800=3A003PlA018B500@41<05QHH00l?400@41403@d>010A4P0D5AL04Q<E00h>400@41@0
4Q8F010@4`0;2`l02PX>01@D6@0A4AH03`lD014A5P0D51T03`lD00804A4F00<02`/@00d=4P0>3Q<0
5?ooool001_ooooo01T0E55L00H42`041@T06AXL00L=20083`L04QTA01HL5@0=4P`01@D500X92P0I
5aX01PD:00l>4`0920d03PdB01HF6@061PP03`lA00H6200E5AL04a<C00d=3@0>3Ph04A4?00803`l=
0P0>3P`0500?3`d03Ph<01HF500N7Q`09bLU010@3P0B4Q005QHF01<C4`0B4Q804a<C01@D5P0E5AL0
3@d?00h=4P0A41D05aHK01TH7P0I61d04A8E0P0A4Q@3014C4P0O00lA3P0>40d03@l<010B3@0B50l0
3Q<?00dC4@0>4Q40418A014A4@0C4A805A<D00l=3P0@41007AlN01DI600=4a405Q/L00lB5`0;3a80
310C014E600G6a`04QHG01dQ8P0/<2l0OX:101TM700@51<05ATI00lC5002010D5@0600hB4`0?4a@0
4ADF01<G600D61T04QHG0P0?4a@01`0D6AX05A/K01HL700F71`04ALG01DK6`0I7al00P0E6a/0=`0D
6QX041HF018H600@51<04ADD01DI600D61L04QHE00dA4P0A5AH03Q8C01XN8@0B5QT07b<V018F6`0L
8bd05AhW014H800F6al061dP01HJ6P0G7Ad07BDW01TQ:@0I8S409C1201@Q=@0N9cH06bDa01TS;`0F
82`05AlZ01hX<P0Q:c@06bD^01LQ:P0I92X06RD[01LR:00D7RL05AlX01XT;@0J8bX05QlV01TR:@0I
82H05ahT014H7P0Q9RX0724U01PM8@0I7B0061`O01LK7P0H71l00P0I7B006@0F6Qd06AdP01`P8`0M
8B@07R8U01dQ900H7B005a`O01`Q900J7b805AXN01XO8`0G7280724W01/P9P0H72D0<3@m00hB6`0E
6Ql04aPL01HK7`0G71l05AXM01LL7`0E6Q`00P0A5aL00`0G7A`06AlM01TO7`0201<H6`1;01@I700F
7R406b8X01dT:P1FGf@08BXa01hW;P0A72806RD[00PA600D6R004AHL01<H7P0J7b<0724U01/P900E
6Qd03Q@D014G5`0F71`04aTI00hE4`0>5a805AhM018J6`0?5aX051/S00D<5@0>5Al072<]00P?600=
51`0>D16020X;00@61/03QHH014J6@0F7a`051dH014J5@0>5a@03AHE018J700D6b404aXT014G7P0B
5a/04aPK01@J6P0B61H041HB014G4`0@5Q803Q@B00lD5@0>4aH061dQ014H800=51`04QTQ01DL8P0B
6Al06R4W01HN8@0D71l02a<E01PP8P022P`03ADG01PM800I7R40314D01DJ7@0O92L04AHI00803Q<F
0P0?51L01`0@5AP041HG010D5@0=4A003a<B014E500?4a800P0A5A@200hB4@<04ADD00<041DA00lD
400@5A400P0A5Q800`0>4`l03a@@00hC3`0200dB3P0300lD400@5A404AHB00D04AHB01P041DA00lD
400>4`l03Q<?00lD400@5A402Pl;010E4@0>4`l03a@@01TN6P0N8al02Pl;018G4`0K81`02Pl;00dB
3P0H7AT03Q<?01XO6`0C61@02a0<010E4@0C61@200lD400900`A3@0C61@05a`H018H5P1[M7H0P8Z;
018M6@0A71804Qh@008031P:00l031P<010K4`0A6aT02Q@E00L?4@0@5A@03a<B00X>3@0>4Q404AHB
00T>2P0@5A4041D?00lD3P0@5@l00P0@5@h03@0I7QP04AH@00H;1@0>4`d06QlI00`A2`0E6Q@05Q/E
018G4@0?50h02Pl9010E3P0?50d00P0=4P/00`0?50d041D>00lD3@02010E3P0F00`A2P0?50d03a@=
00dB2`0<4@X02a0900dB2`0>4``0314:00X?200<4@X04QL@01<H4@0:3`P02a0901hR6`0W:R<0:2/T
01TL5@0B5@h04aH?010C30803Q4:00@03a8;010C300B5@h04QD>0P0C5Pl04@0D5a0071lH02ha:P0=
40T030l800d@2@0?4P/041<<00hA2P0B5@h05aXC01@G400<3`P02@`500/>1`0>4@X03a8;008041<<
0P0?4P/0100=40T03Q4:00lB2`0?4P/200hA2P803A0900X03Q4:014D3@0?4P/02Pd600`?20072P<0
2@`500lB2`0B5@h030l8100?4P/02`0>4@X03A090002000B5@h071lH00D80@0B5@h051L@00/>1`0=
40T03Q4:00803a8;01003A8;020U7`2V[:H0:BhX018G4@0A50l03Q0;00d?2P0>3`X071dH02PY900S
91l04A8=010A2`0?40X03Pl90P0?40X03`0@4@/04Q<=000100051P00@T<m0;jo^@0/;BL02@X401<D
3P0310002``600h?2@0@4@/03Pl900l@2P0201@E3`0;018C3@0G6180414;00H70@051P0020T500h?
2@0A4P`03Pl900d>200>3`T00P0A4P`0400@4@/030h900P:1@0=3`X04Q@?010B3@0?4@`02@/601@F
4@0>40/03a4<01XL5`0;3@L0414;014B300=3PP300h?2@0B010A2`0>3`T03@h800d>200>3`T02``7
00h@2`0N81/02P`700h@2`0?4@`04aD@00h@2`0=3`X03a4<010B3@0>40/03a8;0P0@4`X02`0@4`/0
3a8;00hA2P0?4@`03@l:00/=2P0A4a004Q@A00lA3P0=3`X03Q0;00803a4<00@03@l:00`>2@0=3`X0
3@l:0P0A4`h03P0=3`X03Q0;00H80`010`0071hI014C3P092`H03Q0;01@F4@0@4Pd03a4<00`>2@0F
61<04A<>0`0;3@X300X<2@803Q0=014030h;00h@3@0@4Pl02`d:00T;1P0;3@P010H100d?2P0K7AP0
2`d800X<1`0@4Pd05aTD00d?2P0<3PT0:2XU024R7@0200/<1`0^014B3@0=3PT03@h900h?2P0=3PT0
2``700`=200@4@`04Q<>00lA300@4Pd05aTD014C3P0C5A0030h900lA300:30P01@L200/<2@0@4Pd0
3@l:00X<2@0J71T0:B/X07eoO00:30T0004000lA3P0;3@X03Q0=01@F4`0A4a0030h;014B3@0O81/0
4A8=00X;1P0A4Pd0414<00X;1P0<3@P01@H1014B3@0L7AP03@h9010@3P@03`l=00d0410>00d=2`0?
3`d04Q8@00X:200D5180=3Da01dN6@0;30L0414<014B3@0?40/02``700H03@h900H02``700d>2@0A
4Pd03@h900/<1`0>3`X200d>2@0400`=200=3PT03@h900h>30803@d=00H03Ph>00l?3`0?3`l03Ph>
010@400;2`/200d=3@0E00P8200A4Q004Q@A01@F4`0620D01`T600lA3P082PL02`d:00d?300?4@h0
5ALD01LI5P0E5aH03Q0?00T;2P0?4A004Q@C00`>3@0?4A003Q0?00803@l>01403Q0?010A4P041@T0
2@X?01/L8@0?41D04A8G014B5P0D5AT0FeaP01PI7@0@4A<04a@F00d>400720X01PL901<D5P0201@E
5`0C018C5@0@4A<03@h@014B500<3@l04A8D00/<3P0?41@051DJ00l@5@0;314030dB00/<4@0C51T0
2P/@01DF6`0I6Ql07AhS01/L8@0Dooooo`006oooool04P0;21403@/B018C5`0H6A/03aD@00/B2`07
3PH03aD>010E3`0B4Q802@P:01LE600B4AH040lD00l>4`0=31402@T<00T92`803Ph@00H03`lA014A
4`092@T030`<014A3`0@40h300l?3@07010@3P0=3@/04Q8@01@D4P0M7A/030`:00l?3@02018B4P0;
01<C4`0D51@05ADG01DE5`0B4Q@051<H01<B5`0B4AH04a8H01@C600A4QD00`0A4Q@2014C4P0:018D
4`0@4Pl04A<@014C3P0@4Pd03a@@00`B400>4Q40418B018B4P80518C01/04Q0A014A4@0H6QT06QhM
014G5@0>4a@03A0E01TM800U:B`061`O00hB4`062P/07R8S00`@3`0U:BP05QXI00T=300G6a/06AdN
01<G600@51D04QHG01@H6@0F6Q/05a/L01PL7@0F6Q/00P0B5QL01@0E6Q/05adM01DK6`0@5QH03Q@D
00806AlO00L05A/K01@J6P0D6QX041HF018H600E6AP04aLF008041@C01d04ADD014E5P0;3a003a<D
01LK7P0J7R406AdP01@H7@0J8B/051dV014H800D6Ad05Q/N01@H6@0<4A@04QXM010I8P0>5bH062<e
01<P<`0S;3/07BLc01LQ;@0C7BT05AlZ01lY<`0S;CH06B</01HP:@0201/V;00?01@O9@0D7RL05AlX
01XT;@0K92/06B8Y01lX;`0E72806B0V00`C6@0I7R806QlS01HK7`0I7B0061`O00@05QXM0P0G6ah0
100H71l06AdP01`P8`0M8B@201XO8P0C01`Q900I7R405AXN01PM8@0J7bD06b0V020U:`0B5Ql05QXS
01<G800>4aT04AHL01XO8`0K82@041DI00`A500F6ah041DH010F5P0201@J6P0f01<I6@0@5AP04AHI
01<H6`0G7b807BDX01lW:P0J8bP00``A00dF6`0?6R007RT_018K8P0B61h041DK01DJ800N8bL06QlS
01@I7@0F6ah03A<C018H600S:BT07B<S01<K600F7aX01Pl>02/c=00H82<05ahV01@K900J8B/05A`V
00dD7@0R:C40K7=i03Y1AP0@61/03QHH01TR8@0P:BH0624L010I5@0@6AH041TH018J7@0D6b404QTS
018H7`0A5QX03a@G018H600C6AL041HB0P0A5a<02P0@5Q@04ALG018G6P0L8BD03QDM010G7`0E72@0
51/Q00dD6P063A<200/C5P0:02H^<017Ce403ADG01<K7@0:3a801P/>01XO8P000@@06b0S00X?4P80
3Q<F0`0?51L01@0@5QL03a<D00dA400A5A@051PG00<041@C00H03A4@00/?3P0A5A@04aLF00lC4P0>
4`l2014F4P05010E4@0?510041DA018G4`0?51000P0;40`00`0>4`l04AHB014F4P05014F4P0G00hC
3`0?510041DA010E4@0?51003Q<?00dB3P0D6AD03a@@00dB3P0J7a/09R/W01dR7P041`@0314=00lD
400D6AD05AXF01<H500G71P05Q/G00`A3@0A5Q800P0=4Ph04P0@5A40314=00dB3P0B5a<04QPF065[
JP1SKVX01Q4;01DQ60033`<03QX@00TE300;5Q804A/L00dE7P0841d03Q@P00P<3@807B4P01D041@C
01XO6`0>4`l04QLC00lD3P0=4P`03Q<=014F3`0B5a002Pl901DJ50011P0061dG00dB30042@@05AXD
00X?2@0=4P`04QLA00D:100A5Pl00`0<4@X00`0>4``041D>00hC300200hC300400dB2`0@5@h041D>
00dB2`802a0901403A8;00hC300=4P/02a0900T>1`052P<00PL102T^9`062`@020`601HI4P0H6a@0
3a8;00X=1P0;3PL03Q4:00lB2`0200hA2P0D00lB2`0@4``041<<00hA2P0930D01PT200`?200L7aP0
3Q4:00d@2@0>4@X041<<014D3@0>4@X000<001<F3`0H6a@05APA01dP6@0E614600lB2`0400d@2@0>
4@X03a8;00lB2`803Q4:00`020/400T<1@0=40T04A@=010C300;3PL05QTB01LJ4`0>4@X03a8;018E
3P072P<200/>1`0:00`?200=40T041<<014D3@0J7AH01`X401<F3`0V:B80Bdi700T<1@803a8;0P0>
4@X03`0?4P/03A8;0046000Z<2X00`P2010E3`062@@030h900T;1P0;3@P071dH02X[9P0S91l030d8
00h?2@0300l@2P803Pl901804Q<=00d>200D5@l0?3dg0;Ff/00P8A/04a@>020Q6`03100051D?01<D
3P0@4@/03Pl900d>200A4P`04Q<=010A2`0A4P`200`=1`0:00h?2@0P8A/03@h800h?2@0?40X03@h8
00h?2@0A4P`0414;00h?2@802P`701002`d800`>2@0<3PT03Q0;00X<1`0H6QD03Q0;06EWHP1cMG00
3a0;014B300>3`T03a0:01@E3`0A4P`03@h80`0?40X02@0>3`T03@h8018D3P072@@04A<>00X<2@0F
61<03a4<00L81@0200`>2@0G00h@2`0?4@`03@l:00hA2P0?4PT03A0700`?1`0<3`P03Q4:00@60@0>
40/04A<@02X/:@0T9R<02`d:00X<1`0<3PT03a4<010B3@0=3`X02@/600`>2@0:30L00P0;3@P0;009
2`H03a4<00`>2@0O8A`01@L200H80`0E5a80418=00d?2P0<3PT0418=00/=200C5A003@l:00d?300?
4@h04A<@00h@3@0<3P/0418?018D4@0:30T03a4>01HH5@0C5A802P`900`>2@0?4@`02P`700T;1P0=
3`X02`d800P:1@0@4Pd02P`700P:1@0?4@`02@/601<D3`092PD03@h9014B3@0>3`X0414<100=3PT0
=@0@4@`04A8=00/=200A4`h07R0K01TK5P0F61<02`d800T;1P0I6aH03Q0;00/=20092`H030h901<E
4P051`@04aDB03i0?@072@H061XG00h@3@0:30T0418?01XL6@0C5A802`d:00h?2P0H6A@04Q<>00/<
1`0B4`h05QLB01@E40010P002P/600P91@0A4Pd00@80014A3`0>3P`03@d;00h>300@40h04Q8@014A
3`0>3P`03`l=00/;2@0F5Q@0<c@`01DF4@020`004A8=0080414<1`0?40/01P0<3@P03Pl:018C3P0>
3`X030d800h?2P803@h900D030d800d>2@0=3PT03Ph<00d=3@0300h>3P0a00l?3`0A4A403Ph>00T9
2@0I6AT061PH00/;2`0:2`X03Q0=01LI5P0;3@X0418?01@F4`092`P03@l<00lA3P0C5A806Q`I01dO
700S9B@06A/J014C4P0I6aX07R0O01LI600@4Q403@l>00/=300=3`h03a4@00`>3P0J6al01`P=014B
5`061``04a@I01@E6@010PH01PL;04E6BP0=3Q804Q<G00h?4`0D5AL04A8D00/<3P082@/02``>00D6
200200d>400401<D5P0=3Q004A8D00l@4P803a0D00@04A8F01TJ7P0L7B404A8F0P0>3a<0100G61`0
4a@H00T:3P0<3A4Dooooo`006oooool01@091Ph03`dC00P92`0>3a403Q<@00802a8;01D02a4:00<7
0P0?3`d04A0A00h<3P0<30l03PhA00h=4@0<30l03@d@010@4P092@/0;2`^00l?4@0=3@l0410A00h>
3P0?3`d03Ph<00d=2`0>3P`00P0?3`d0200A4@l03Ph<00<30@0?3`d03@d;018B400?3`l04A4A0P0B
4Q802@0@41803Ph@010@4P0C4QL04Q4F00h=4P0?3Q@04Q4G010A5@02010A5006010A4`0@4Q80418B
018D4`0A4a0051HC0P0A4`l0700B5Q@03A<A00hB4@0A4a804a<C01@B4`0E4a@05aDF01@D500E5aH0
7b<R01XP7P0=4Q@02`hC01LK7P0H71l0310C01LK700S9bP061`M018F5@0<40l06QhM018F5@0J7Qh0
720Q01HJ6`0C5aP201@H6@0c01DI6P0G6a`06AdN01TM7P0F6Q/05a/L01PM7@0E6a/051XJ01<I6@0E
6a/061hN01@J6P0A5aL04QPH01@J6P0B61P05A/K01DI600F6QT051PG00lC4P0>4Q4051PI01LK700@
51D07b<V05YNH@0Z;S40?d=901<J8`0A6R<041LN01@I7@0E6Qd05QXK01`Q900@5a`051dV01dV=@0H
8cD0524d02@]?00L9S8051hZ018L:00G8B`08R`f01dW<00J92d05b4Z00805b8X01005B0V01HP:@0H
8R/07BL`01dV;@0I8RT07BH]01HM8`0Z<CL061lU01PM8@0G72005AXN01/O8P0J7R4061`O0`0G6ah0
0`0D61/05QXM01PL7`0201TM800401PL7`0E6Qd06AhQ01XO8P806AhQ01<06QlS01TN900H7B<061dS
01LK900>4Q/061`U01LK8`0N8R`0:Rlf02X_=@0J7b@051TN01DJ7P0G72005AXM014G6@0C61/05Q/N
00<04aPK00X04a/M01@L7`0E7B005AlR00lH7@0F7b@04A`Q01DP9P0@6B005adS0P0J7bD0?P0J7b<0
5a`P01HK7`0F6ah05Q`L01DK6`0W;Bd09B/[00lG5@0L9B8072DT08RATP11BD`04QTQ01LN9P0>5Ah0
2a8K02L^=P0i@4H061lU01HN8P0=5AP03ADG01@L7@0H8Al04a`J018K6@0E7Qd05AdO01@K800A6200
3aHP018H7`0@5AT03A8E014G5`0E6aT04QPD00lE4@0>51003aDC01<H6@0>4aH04AHJ018I8@0C6R80
4QTQ010G7@0A61h05A`R01PP8`0;4aH031@F00XB500X<3808RX/00hC5P0L8B@03A8E018G6P0:3A00
5AXM1@0?51L0400?5AH03a<D00hB4@0C5aH05ATH014E500@51<03a<B01@H5`0C5aH03Q8A00lC4P0>
4Q402a0<010E4@0A5Q8200dB3P04010E4@0B5a<04AHB00lD40<03Q<?1P0@5A405@0=4Ph03a@@014F
4P0A5Q803a@@00dB3P0G71P061dI00lD400<4@d041DA014F4P0E6QH03a@@01<H500B5a<092TU020U
8@0E6QH0314=014F4P0201<H500300T>2P0>4`l041DA00804AHB01D03a@@00dC3`0>5a802Q@=014L
4`0640L03AP?00LA300>5aP02Q8J00`C8@093RD05QXg02T]@`0b=cX010P700hB4@0@51<06QlK00L;
200?51000`0?50h200lD3@803a@>00X061dG00T>200=4P`04QLA00X?2@0A5Q003a@>00X?2P0>4`d0
314;0P0>4``0100<4@X02a0900dB2`0?50d300hC300900dB2`0<4@X0314:00`A2P0=4P/03Q<<00lD
3@0>4``0314;00803a@=00`0314;05iSG00[<2T04QH?010C300B5@h04A@=00lB2`0B5@h04aH?010C
300?4P/200hA2P0500lB2`0=40T041<<018E3P0@4``00P0?4P/00`0@4``03a8;00lB2`02014D3@03
00hA2P0B5@h04A@=00803A0900<03a8;00/>200@4``0100?4P/00`0@4``03A0900hA2P0200lB2`80
3Q4:02`02@`500/>1`0@4``04QD>010C300<3`P03a8;02<V7`0F6A802@`500hA2P0?4P/04QD>010C
300>4@X03A0900lB2`0@4``02Pd600hA2P0<3`P051L@020S7@0;3PL04aH?014D3@0>4@X03A0900lB
2`0>4``0314;00T?2@0;40X03a<?00d@2`0>40/0418=00`>2@0=3PT0414<018C3P0>3`X03Pl900l@
2P80414;00/03Pl900d>200A4P`051D?014B300A4Pd04A8?018C3@0?40X02``600X;1@0201<D3P06
00L81@0@4@/03Pl900l@2P0A4P`03a0:0P0=3PP0100D5@l04Q<=02LX8P092P@2010A2`803Pl90180
414;00l@2P0=3PP03@l:010B3@0=3`X02P`700`>2@0@4Pd03@l:00`>2@0@4@d0F5YE05MIE00;30L0
30d700h?2@0=3PP2010A2`8030d701403a0:018C3@0B4`d04A8<00h@2P0=3`X061XE00`>2@0B50l0
2`d800lA3@0<3PT02@/600X<1`0=3`X03Q0;00hA2P0200hA200:00lB2P0?4P/03Q4:01HH4`0Q8ah0
3a4>020R7`0J71T0418?00`>2@<03@l:00@030h900/=200@4Pd03Q0;0P0A4`h09P0<3PT03a4<018D
4@0?4@`030h9018D3`0A4`h0;S0[02PZ9@0B50l04A<>00lA30082PD02`d8010B3`0D5Q<05ALD00h@
3@0;3@X03a4>00d?300;3@X04aDB01LI5P0A4a0030h;010B3@0>40/0418=00h@2`0;3@P04A<>00lA
300=3`X01`T400/=200A4`h030h90P0>3`X0100B4`h04A8=00/<1`0>3`X2010A30803Pl:02H03@h9
00`=200:30L02`d801@F4@0?4@`04Q@?00`>2@0@4Pd020X600h@2`1KGEP09bTT00`>2@0?4@h02P`9
00d?300A4a003Q0=00L91P0?4@h03@l<00h@3@0@4Pl03Q0=00`>2`0?40/05aPC01XK5P0A4Pd02``7
010A300<3@P03a0<014B3@0B4`h020T5014B3PH03@d;00L030`:010@3P0C4a403Ph<00/;2@0A4@h0
2P/60080414<00<02``7014B3@0@4@`01@0>3`X01`0?40/030d800d>2@0A4Pd03@h900`=200@4@`0
0P0?40/0100>3`X03a0;00l@2`0?40d500h>3P1200l?3`0<30`030`<024Q8@0H61P02`/;02PY9`1K
GEX0Gf5N01LI5P0720H03a4>00`>2`0?4@h03Q0=00d?300B51404aDB014C4P0=3`h02`d<00h@3`0@
4Q403Q0?01<E500?4A0030h=010B4@0A4a8030d>00`=4@0D5AT0A4E:01HG700;31003a0D01DF6P0K
7200C4eA01hO8`1lOH406Q/O00h?4@0C51H02@X<010A4`0C51H04Q<E014B500=3Q005AHH00l@4P0A
4Q@04a@F01TJ7P0;2`l02``@01hO8`0U9RX03a0D01<D600@4AD02@X>01DF6P0D5AT0414E5?ooool0
01_ooooo00d05A8I00l=4`0D5AT06a`N010E500?5A402Q0<00hD3P0?50h010@200h=3@0<2P/04Q8D
00809BDW00X05QHH00/;3@0=3@l051@F014A4`0?3a404A4C00X:300>3Q0030`;0P0;2`T0400<30X0
3@d;00h>300?3`d05QHD00T91`0D51803`l=00d=2`0A4A404Q8B01<C4`0B4Q803`lA00h>400A4A<2
018A5P03014@5@0B4AL04a8H00<03a0D0`0?41802P0@4Q4051HE00lA3P0=3``0418?010D4P0?5A<0
41@C018D4`0B4Q8201<A4P0J01@B4`0B4Q804A<B01TM700H7Q`07b@U01DH7@0@51L061`O01<G6P0E
6AX07R8S00<7200A5A@05a/J00dA400E6AP04aLG010D5@0?4a@04QHG01<G600B5QL041@E014E5P0D
61T201DI6P0601HJ6`0E6Q/04aTI018H600G7Ad0728R0P0F71`2018H600401<I6@0@5QH04QPH010D
4`804aLF0P0?4a80<`0F6Q/0<3@e00lC500N8RD041@G01@H6`0=41H041LO00lH7`0B6Al051TM01DJ
7@0G6ah06b0T02@[<@0L92d08R/j03M3D`0J9cP08BXi01TS;`0C7BT05Al[01TS;P0Q:cD06bD^01hX
<@0L9Rl062<Y01LR:00I92X04Q`U01hX<@0^>440;3Dl01/T:`0A6R403aHL02H]<`0K8RP06b0T01DJ
7P0H7B405QXM01LK7P0I7B006alR01hR9@0P92L04QHI01DI700201PL7`0301LK7P0E6A`0314D00<0
4aPK0P0G72004P0Q9R`06AhT00lD6P0E6B804ADN00lC700L82/06QhY01`P:`0K7bT06QhW01hS:@0A
5Q`06AhT01PM8@0D6Ad05a`P01dR9P<05AXM02D051`N01@L7`0D71l0218D00`E6P0>5a`041/O01@O
9@0F7bH06AlU01lT:P0K82H04aPL01DJ7P0J7b<05AXM01TO7`0A5aL051XJ01<I6@0B6AP05b0M00L@
3`0Q:BX02a<F01DL8P0A62003QDM01PO9`20Qhd0inob04I>D@0E7B004ATL01<K7@0A6QX03aPG0080
4AXI02<041PJ018J7@0C6R404APP018I8`0C6B004AHJ010E600C6AT05A/I01<I5@0G7AT061hJ01<I
5`0@5AH03Q<F01PM8@0=51`03QDM01DL900?5Q`01@`B00hE6`0;4aH051`O02Xb=00V;S00PHV;05aT
IP0?51L00`P;01HK7P0A5QT08bP[05QMH002010E60<03a@G00D03Q@E00lC500=4A004ADD01@H5`02
010D4`03014E500M8B007R8Q008041@C00@04aLF00`A3@0>4`l03a@@0`0=4Ph01P0?510041DA014F
4P0A5Q803a@@00dB3PH03a@@04803Q<?00lD400@5A4041DA00lD400>4`l03A8>00hC3`0<4@d03a@@
014F4P0:3`/03a@@028W8`0J7a/03Q<?02DZ9P0L8Ad03Q<?010E4@083@T02a0<00T>2P0H7AT0314=
00/@300@5A404QLC00`A3@093`/031D=01XT700?6A003QP?01DN6@043@X02A0E00lE8@0=4RD02@dX
01DH>@0O8c`0<C@h00040`0=4A002Ph=00/@300:3`/03A8>00lD3P0A5Q0041D?00dB2`0<4@X01@X5
01lT7P1BEe406b0J00X?2@0>4`d07R<M05IKE@14BD<04AH@024V800@5@h2014F3`0;00`A2P093PL0
314:010E3P0>4``03A8;00hC30093PL020d600/@2@0=4P/00P0?50d02@0=4P/03Q<<01<H4@0>4``0
4aPA010E3P0D6A80008000lC300200`?200500d@2@082`@02@`500hA2P0?4P/00P0>4@X02@0?4P/0
41<<00P;10082`@02@`500X=1P0;3PL03A09010C300200lB2`8041<<0P0=40T03@072P<04aH?01PK
500930D03a8;014D3@0@4``03Q4:00d@2@0>4@X04A@=00d@2@0>4@X00P0?4P/300hA2P0;010C300B
5@h041<<00hA2P0=40T02`h700hA2P0:3@H03A0901@G400<3`P00P0?4P/400d@2@0I01PK500=40T0
1PT201dP6@0<3`P03A09014D3@0@4``03Q4:00d@2@0>4@X0314:00L<1P0>50d05AXD00D:100F6A@0
5ALB00/=200A4Pd0414<00`=200>3`X05AHA00d>200300h?2@803@h80280824K01@E3`16Ad404Q<=
01<D3P0B4`d05AH@00d>200F5a4020T4010A2`0H6A<030d7014B300?40X0414;01<D3P0B4`d03a0:
00`=1`041@003@h800H70@0C50h03a0:00d>200>3`T04A8<010A2`0>3`T030h900lA300=3`X02@/6
0P0;3@P02P0F61<03a4<00`>2@021000004000l@2`0F5a406a`F010A2`092P@200`=1`0300/<1P0>
3`T04Q<=00804a@>00P0418<014C3P02100061XE079dK`1?DD`06A/F00`>2@8020X501403@l:00lA
300?4P/03Q48014D2`0C5Ph04QD>00hA2P0?4@`06Q`G00lA3P0A4a0030h;00h@3@0?4@`03Q0;00`>
2@0200/=200300d?2P0B50l03@l:00802`d801d030h901LI500c=C002`d800d?2P0;3@P03@l:06U[
IP1ZK6L0;BlZ00X<1`0D5Q40418=00/=20082PL02`d:00d?300;3@X02P`900lA3P0>40d06A/H01PJ
5`0A4a003Q0=00/=2P0>40/02P`700d?2P0200lA300:014C3P0?4@`030h901DG4P0D5Q4020X500X<
1`0720<030d800d>2@802``700<03Pl:00d>2@0=3PT00P0=3PT01P0@4@`04A8=010B3@0:30L02`d8
00H80`803a4<01<02P`7024S7P0O8A`06adH01@F4@0C5A0030h;00<50P0a<c001PP601HH5@0E5a@0
3Q0=010B3`0<3P/01PP500P:1`0=3``0414<00803Pl:00h030d800h?2P0C50l09BHQ09^LU`0P8A`0
20T6014B3@0T9B003Ph<010@3P0B4Q004A4?00h>30<03@d;00@03Ph<00l?3@0@40h04Q8?0P0B4`h0
10061`<03a0;01@E400:2`H500d>2@0400h?2P0<3@P030d800l@2`8030d800@03a0;00d>2@0=3PT0
30d80P0=3PT00`0?3`d03`l?00h>3P0200h>3P0A00d=3@0?3`l03`l?00T92@0=3@d02`/;00`<300E
5QD08R@Q02la;P0>40d020X701<E4P0;3@X03Q0=00d?300<3P/00P0@4Pl0<00=3`h0418A01@F5@0B
51<0418A018D4`0A4a803a4@00h@3`0A4a804Q@C00h@3`0I6Q`03@hB02@U:@0A4QH0414E01HG6`00
00@061TM02PY;@010PH0ATM;01LH700>3a405aPJ00T:300@4A<030d?028S9@0K71h03@h@01@E5`0?
4180414C018C5@0@4AD04a@H00`=4@092Ph03@hB00l@50041@T04a@H014B5P0B4aL01PL;02PY;ACo
oooo000Kooooo`0?00l=4P0A3a@0414E010A4`0/<Bl0GVAP03<i=@0@5A407b@P00/;2@0>3@/02PT7
00410@0K6a/0:b/[00806ATK00P0AdM9018B50061PT04A0E00h=4P0:2@h030`>00`<2`8030`:00/0
3@d;00h>300?3`d02`/901HF500820H04a<A00l?3@0:2PP03`l?010@4002014A4@804A4C00H05ADG
018A5P0A41D04A0E00h=4`0<2a4400l@50803a0B00X061TJ01hP7`0A4a803a4>01@F4`0?514041HD
014E500B51<04Q8B0P0B4140200C4A804Q8B014C4P0D61L05adK038g>00U:2d03a<F0P0=4A@02@0G
6a`05ATJ00X>3`0@51<0720O00dA400?4a8041@D018F5`0201@H6@<04aLH00`051PI01HJ6`0G6a`0
5ATJ01HJ6`0D6AT051XJ01<I6@0E6a/06R0P01PN7P0E6a/2018H600501<I6@0@5QH04QPH01lS8P0J
7Qd00P0C5aH0;00E6AP05ATJ01`P8@0?4a@04aLJ00<72P0O8bH07B4V01<J8P0C72<051/Q01DJ7P0C
61/051PK01lT:00a>3h09blh02`f@P1=FFT0;S]<020Y>00I8bl05Al[01PR;P0I8bh072H`01dW<00L
9Rl06bD^01XU:`0H8bT05R4W01HP:@0N:340:C<l02Pa>00J8bX05AhU014H7P0G7R@04QTO01/P900E
6Qh061dQ0P0G71l0100H7B006AhQ01`Q900N8bH201@I70805AXM0P0F6ah04`0=4QD05AXM01<H6`0C
61/05a`O01DJ7P0R9bd06AhT01DJ800G6b@07B4Z01lS;00G6bL06QhZ01/O:P0D62<04aLR01PL9@0H
7B@00P0G72801`0F6b404aPN018G6`0E6Q`05A/K01HL700D71h00P0C6ad0;`0G8B<0628T01DO8@0D
7b<041/O018K800E6b406AhT01PM8`0C61`051TM01LL800G71l061hN01HL700B61P04ALG014I5`0D
7AX06B8Q018K700@61/06B0V018I800F7BD01PdC05AKH02_]kT0=Cdo01@L7P0E7Al05alQ01DM7`0B
6Q`04a/M010H6P0>5QT04ATL018I800@5al04QTQ018H7`0A5QX04aPK01HL700E6aT04aTE00806AlK
01@05A/I018H600A5QT0724U024X<00C6R803A@L00`C6@0B6Al0B4mE01XR9@0I8B@04QXL00H>400/
=3H0:C4c00dB5@0X;C001PX=00hC5P803a@G0`0@5AP03`0?51L03Q<F00hD5@0@51D03A4@00lC4P0A
5A@03a<B014E500=4A006AdL01XN7@0@51<04aLF018F5@0300lD4004014F4P0@5A403A8>010E4@80
3a@@00<041DA014F4P0A5Q801P0?51001`0@5A403a@@00hC3`0>4`l03a@@010E4@093PX00`0>4`l0
100B5a<03a@@01/P700B5a<200`A3@08020U8@0@5A4020d9010E4@0<4@d08RLS00L<200G71P200dB
3P0H014F4P0?51003Q<?01<I5@0?5a400P`400<=1@0@6Q801a0;00XC400;51D05A`T00`B7P073200
310Y00/@8`0?4aH061`K01`P7`0=4A002Pl;01@I5@0>4`l03Q<=0P0?50h200hC300B00lD3P0C6180
7b@N00hC3@0@5@l0314;00lD3P0i?SP0;34[00870@0>4`d02a0:010E3P0A5Pl03A8;00X?200>4``0
4QL@0P0;40T0500>4``02@h700T>1`0=4P/03Q<<014F3`0?50d0314:00dB2`0>4``00`P10087000C
614051TB00lD3@0G6a@041<<014D3@0E61404A@=0P0B5@h200hA2P0600lB2`0@4``04QD>01DH4@0C
5Pl041<<0P0?4P/0100@4``03a8;00hA2P0>4@X200lB2`0?00/>1`0<3`P03Q4:01<F3`082`@00080
020S700A50d041<<00hA2P0=40T03Q4:014D3@0=40T03Q4:00803a8;0`0>4@X2010C308030l800@0
3a8;01DH4@0>4@X03A090P0B5@h00`0:3@H041<<010C300200lB2`0300d@2@0<3`P01@P1008020/4
00@04A@=00T<1@0G6Q<03A090`0>4@X02`0=40T02Pl801dR6`052P@061dF00hC30072`D01PT200L:
0`0>40T04A8<00803a0:00@0414;00h?2@0=3PP030d70P0=3PP01P0>3`T07AhH024R701EEU003@h8
00`=1`802P/500T03@h800X;1@0H6A@00`@000T:100>3`T05QLA014B300<3@L00P0?40X0100=3PP0
3a0:018C3@0@4@/200`=1`0300h?2@0=3PP03Pl900804A8<01D0414;00/=200<3PT030h900/=200<
3PT02@/601TK5P0@4Pd02`d801TK5P0@4Pd04A<=01/L5P0P8A/04a@>00/<1P0>3`T03a0:00h?2@0?
40X00P0B4`d02`0A4P`03@l901@F4@0J71L020X5024S7P0B50l020X500/=200:30L030h900803a4<
00P03Q4:00hA200@4`X04A@<014D3@0@4``010H100d?2P805QPE00<0418?00X<2@0>40/00`0>40/0
0`0=3`X030h900lA300300`>2@0400/=200D5Q40008000T;1P8051HA00/0418=02DW8P1?DD`0:2XU
00d?2P0?4@`04aD@00h@2`0<3P/03@l<00h@3@0200lA3P0;014C400:30T06adJ01<E4P0=3``04Q@A
00T;200>40/04A<>00h@2`0=3`X00P0A4`h0100@4Pd03@l:014C3P0A4`h200X<1`0Q00X;1P0<3@P0
2P/600T:1@0=3PT0414<00h?2P0=3PT02``700`=200@4@`04Q<>00lA300;3@P03Q0;00P:1@0>40/0
30h900L910072@D020X500lA300D5Q403a4<01/M6P0Q8b00Ngej018D4@082PL00P@100h@3@0?4@h0
3Q0=00802`d:00D030h;014B3@0?40/030d800h?2P0201<D3`0300`=200n?cX0004000805QLB00<0
004000l?3@0?3`d00P0@40h200l?3@0<010@3P0<30X02`/9010@3P0B4Q004A8>00X;1P092PD01`P3
00l@2`0D5A003Pl:1@0?40/0100@4@`03@h900d>2@0@4@`200d>2@04010A300=3PT03@h900`=2080
3@h900@03`l=00l?3`0?3`l03Ph>0P0=3@d0400@410051@D00`<300:2PX03Ph>010@400F5aH02P`9
018D4@0E5a@05aTF00`>2`0>40d0418?00lA3P0>40d2018D4@8020X90P092`X07@0:30/02`d<00`>
3@0=3`h03a4@010B4@0?4A003Q0?00<41P0720X05AHH00831`0C51P0FeaP02LX;00;3100EUML01<D
6@010PL051DJ00l@4P0G61X02``>01`M7`0X:B/0HfAV02DV:00>3a404A8D00803a0B00d0414C00T:
300A4Q@03PlA00/<3P0?41804Q<E01HG6@0A4Q@06a`N01lP8P0J6ad0P86301Cooooo000Kooooo`0I
014?4`0E51P04Q<F01LH6P21QXH0l_Of08jDTP0I7a/05a`H00X;1`0>3P/04A0=010@3`0:2PT03`l>
00h>3`0C4aD0;Bd_00l?4P0D4aL051<H00d<4@0B4AH03PdA014A400200/;2@0=00l?3@0@40h03@d;
00l?3@0D518020P6014A3`0B4Q003@d;00`<300>3Ph03`l?010@4002010@4P0600l?4@0:2@h03PdB
01DD6@0A41H05A@J0P0@4AH0:@0?41D0414E014B5@0B4aH07b0R01lQ8@0M7ah04A<A01@F500@5180
3aDC010D4`0B51@04A4A014?400D4Q<05Q@E01HF5P0G6AP061`K01/Q7`0L8B<03a8G014E600J7R40
5ATL01DI6P0B5QL07B4R01<G5P0A5A@03Q8A010D4`0B5QH05QXK01<G600D61T03Q8C01@H6@0A5AH0
4aLH00<05ATJ02L051PI018G600E6a/04ALG01PN7P0D6QX092XZ01/Q8@0;4A404aTI01PN7P093@d0
61hN034e=00W:bX05a/J01@H5`0F6QT04aLH01/O800B5QL04aLJ01TM80093A005ATN01lV;00L9B/0
82L]01DJ7P0C61`05QTN01DJ800J8BT06R8/01LQ;@0N:SP05R<c01lX=`0M9c<00P0I8bl05`0K9C00
7BLa01/U;P0O:C8051hW01PS:@0K9R`04QdS01PR:`0I8b`051hW010I800C72<06R<Z01XQ9`0F7B<0
31<I01XO8`0G7200<cPl030g>@0L8bD05ahP00805A/N04T051XM01DL7P0C6Q`04QTK010G6@0B61X0
41LI01DJ7@0G71l051TL01DJ7@0I7R405Q/O01DJ800@5A/05Q/Q01/O:00W:c@0;C4j028V<P0[;c/0
;30l01`P:`0G6bH07R8]01LK900C61h05AXP01PM8`0C61h03Q<G01LL7@0I7al05adM018J6`0@61X0
3aLI01DO800>61X07bT[03Q3AP0;5QT05b0T014G7@0D6Al05Q/Q01LL800D6Ad04aPL01@I700B61P0
5A/K01TO7`0L8R804ATG00lH5@0E7Qd03aLJ01@L7`0C6R0041LN01LN900B6Qh06B4S02</:`0N9bD0
8b`[01dU9`0P:2X04a/M00lG6@0B6Qd03A@I00804APO02T041LN010G7`0A620041HL018G6`0F6ah0
5Q`L018H5P0A5a<04QPD010F4P0@5Q@04aPI00hC5P0E6Qh04APP00lF7P0K8RX06b8X00hE6`0J8BL0
1`lB00lG6P0@61X072@V00T?4@0@61X03a@G00T>4@0A5QT041DH01TN8@0B5aX03A8E01@I700A5QT0
<CHi01LL7`0=4Q@03A4B00hB4@02010D4`0400hB4@0A5A@03Q8A00lC4P8041@C00@04ADD00dA400B
5a<04AHB0`0@5A40200?51003A8>010E4@0;40`03a@@014F4P0@5A404aPD0P0>4`l00`0?51004aPD
00T>2P0200hC3`803A8>00L041DA018G4`0@5A405AXF014F4P0<4@d03A8>00804AHB00/04QLC00hC
3`093PX04AHB01/P700=4Ph03a@@01DJ5P0`=C404AHB00hC3`02018G4`08014F4P0?51004aPD01XN
700M92804ATF014I5@0:4P/200hF3`0I01DM600F7Q/04a/I00`B50073A402PlC014E5@0<40l02@d<
018F5@0@5A40314=010E4@0=4P`0314;00dB300=4P/03Q<<00dB300A5Q0020/700lD3P0>4`d03a@>
00hC3@0200lD3P0300`A2`0?50h041D?00803a@=00@03A8;00`A2P0?50d041D>0P0;40T04`0=4P/0
2a0900/@2@0<4@X04AH?00hC300A5Pl02@h700hC300@5@h04aPA00lD3@0:3`P02a09018G400D6140
4aH?00hA2P0?4P/00P0<3`P01P0?4P/041<<00hA2P0>4@X051L@01<F3`803A0900L03Q4:014D3@0C
5Pl04QD>010C300?4P/03Q4:008030l800T03A0901DH4@0D5a003a8<00`?2@0M81T0NGae018E3P0?
4P/00`0>4@X01`0?4P/02Pd600d@2@0>4@X020/600d@2@0>4@X00`0?4P/02`0=40T03Q4:010C300=
40T030l800hA2P0?4P/03A09010C300D5a004QD>00803A0900<041<<00lB2`0A50d00P0>4@X03P0?
4P/041<<00hA2P0?4P/04QD>00`?200=40T04QD?00D:10083@D03aD<01<H400:40L04AD=0P0>4@T0
1@0?4@T0414:010A2P0@4@X03Pl800803Pl901<030d700l@2P0<3@L03@h800h?2@0A4P`04Q<=014B
3@0B4`d03a0:00`=2@0G61803a0:03`m=`0L7AL04A8<01DF400I6Q@051D?00<03a0:00L04A8<00h?
2@0A4P`03a0:014B300=3PP03a0:00803@h800H03a0:014B300@4@/03Q0;00/=200=3`X200lA300=
00h@2`0=3`X02P`700lA300=3`X02P`700h?2P0C50h051D?00l@2P0<3@L03@h800h?2@0200l@2P08
014B300B4`d04A8<00h@2P0<3P/03@l:014C3P092`H200d?2P0M00X<1`0=3`X03a4<014C3P0@4Pd0
3Q4:00T<100@4`X03a8:010C300?4P/03a4<00h@2`0];b`00`D2010B3`0A4a003Q0;00`>2@0=3`X0
418=00h@2`0<3PT02`d8010B3@0D5Q403a4<00`>2@0@4Pd00P0A4`h03@0=3`X05QPC00`>2@0@4Pd0
3Q0;01`N6@0P8Qd02`d800`>2@0@4Pd04Q@A010B3`0>40d00P0=3``00`0?4@h020X701DG500200/=
2P0601<E4P0D5Q<03a4<014C3P0<3PT02P`70P0<3PT0?00A4`h03a4<00X<1`0:30L0418=018D3`0?
40/03Pl:00d>2@0;30L03@h9014B3@0F5a803Pl:00X;1P0A4Pd0414<00h?2P082PD0418=00/=200G
6A@03a4<00T;1P0<3PT03Q0;00`>2@0D5Q404Q@?01LI501EEe@03@l<00`>2`0@4Pl051HC00`>2`0=
3``03Q0=010B3`0A4a003a4>00d?300>3`X02P/701<D3`0>3`X04A8=00T:1@0=3PT0414<00l@2`0=
3PT02``700l@2`0@40h03`l=00d=2`0<30X03Ph<014A3`<03`l=00h0410>00h>300@40d06AXE01@E
400@4@`030d800/<1`0E5Q402P/6010A300C50l04A8=00l@2`80414<0P0?40/02P0@4@`04A8=014B
3@0?40/03Pl:00d>2@0>3`X03a0;00l?3@0>3Ph200l?3`0400h>3P0=3@d03@d=018B4P803`l?00D0
4Q8B00h>3P0>3`h02@/800`>2`0200X<2@0g00h@3@0=3``05ALD00/=2P0:30T030h;00h@3@0C5A@0
4Q@C00d?3P0>40l02`d<010B4@0>40l030h=02@V9@0@4Q402P`;00lA400@4A803a0A018C500A4QD0
414D00l@500:2a005QLL01@E6P0B4aT05AHL00l@5P0<3A404a@F00h?4@0B4aD03a0B02PY:`0O8280
414C01HG6@0<3@l0414C00X;3@0@4A<03PlA00d>400A4Q@04Q<E00X;3@0B4aD03a0B03Df>010@D<0
4Q<E020Q8`0Dooooo`006oooool04P0?3A003@`?014B500:2`d0B4e=08bBTP1?EED05Q/J00X?2`02
0`004a<?00l>2P0<30X03`l=00/;2@0<30`04a<D014A4`8040lD00H03PdB00d<4P0<2a402`X?02l_
;P0G5aD200h>300<018B400?3`d03`l=01DE4`0A4@l0410>01@D4P0C4a403Ph>00l?3`0@41004A4A
0P0?3a40FP0D51H04Q4F014@5@0C4QL03@`B01LF700A4QL04Q<H010A5P0>3a<03@hB00`=4@0S92H0
?d1205AEE`0F61L03@l>01TM700<4Q003Q8A01<E500A4A404@l@01@B4`0E4a@051@D01DG5P0E6AP0
5Q`J01HK700A51T03a<F01@H6`0H71l05ATJ018F5`0?4a@03Q8A010D4`0A5A@041@C01DI6@0F6Q/0
4aLH00lC500:3Pl05a/L01@H6@0B5QL04aLH01DI6P0F6Q/05ATJ01DJ6P0I7al03Q@D01@J6P042PX0
82HV00X@400D6QX06b4Q01@J6P0S:BT0728R024U900M8B005ATH014E500D61L06alP00X>3`0K7b00
5QXM01<G6P0S9bX06QhS01PO9@0B6b007B@Z01dR9P0P9BT09bXa01DI8P0F7BL06B4/01PR;P0F8S00
62Hd01HP;08051hZ01d05R0/01`V<@0S;CL072H_024[=00E7bP06RD[01TT:P0E82H04A/T01LQ:P0A
6b@03AHM010I800B6b8072<Y01LN900?5Q`06b0T01DJ7P0X;C408b/]00dE5`0D71h05AdO01HN800D
71h04QXL01@L7P0301LO8@0;014I6`0B5aX051TL01@I700C61/051TM01LL800F6b405AXP01HK8@0H
72D00P0J7RL0@00N8Rh06AdY028V<@0W:cH06alZ01DI8P0G72<05Q/Q01LL8P0H7B<04aPN010E6@0C
6AP061hN01HL700D7A`05AdO01<K7@0@6Q/051hP01DO8@0nBD/08bh`01XT9P0D6R005AXP01HK8@0E
6Qh04QLK014F6P0B5aX041HF01<I6@0B61P051XJ00lF5@0D7A`05alQ014I6`0>5QT041LM018I7`0C
6ah051`N014J6@0>5a@04AXE00`E4P0`>3X0IVi`0459B`022@l01PdC01dT;00;4QX04APP01`S:`0>
5Ad02A0H00lE6P0B5a/05AXM01DK6`0E6aT201DK5`0A014G4`0@5Q@04QLH00lD5`0G72008RTa01XQ
:@0C6R803QDK00/B600A61h0;CDh008:3@0J8R@01@d?008:300C6Q`00P0>4aH03@0?51L041DH010E
600@5AP02@hA00@9300B5aX0Q8V<06M/K`0D6Q/03A4B00hB4@0@51<00P0?4a80200@51<04QHE00hB
4@0@51<051PG010D4`0?4a803Q<?0P0A5Q802P0?510041DA01<H500=4Ph04QLC010E4@0G71P04QLC
014F4P0B5a<2010E4@0500D:1P0<4@d04QLC018G4`0A5Q800P0?5102010E4@0:00hC3`0A5Q804aPD
018G4`0A5Q804QLC00dB3P0@5A40314=01@I5@804AHB00L0314=00lD400A5Q804AHB00lD400>4`l0
4AHB00803a@@01`041DA018G4`0C5aH05Q/M018G6P0@5QH03aHA00lF3P0>5P/05alA00`D1@0A6@X0
4AX900PA000@60/03a<@02<W9P10A4<0720O00H;1`0V:bL05AXF00dB300>4`d04QLA010E3P0;40T0
3A8<0P0@5@l00`0<4@/02Pl900dB300500hC3@8041D>00<03Q<<00dB2`0=4P/00P0>4``300dB2`80
314:01003A8;01<H4@0;40T03A8;00D:0`0?50d03A8;014F3`0?50d0314:00/@2@0?50d05ATB014D
3@0>4@X041<<0P0=40T01`0>4@X04QD>010C300C5Pl07b8K01hQ6P0A50d00P0?4P/00`0A50d04QD>
018E3P02010C300;00lB2`0<3`P030l800lB2`0930D04A@=00/>1`000P004A@=01XM5P0B5@h00P0=
40T05`0@4``03Q4:00lB2`0L7aP010L001@G400U:24051L@00`?200o@S/0<C@]01TL5@0?4P/04A@=
010C300B5@h03A0900hA2P0B5@h04aH?00hA2P0:3@H03a8;00804A@=010030l800D80@0=40T03A09
014D3@0D5a004QD>00`?200;3PL0H6=L05QKE00I71D020X601PM5P0:40H02a880P0=4`T0100=4@P0
30l600d@1`0?4@P2010A2@0500l@200>3`L0:b`V01/L5P0<3@L00P0=3PP03@0C50h01PL4014B3001
0P003@h800L80P0>3`T02``601@E3`0:2`D05QLA00/<1P0720801P0>3`T04P0C50h04Q<=014B300A
4P`0414;00l@2P0A4P`03Pl900`=1`0=3PP03a0:010A2`0Y:bH01`T400lA300:30L03a4<018D3`D0
3Q0;00<03a0;00l@2P0?40X00`0@4@/0400?40X03@h800d>200?40X0414;00l@2P0C50l00040018D
3`0D5Q4071hI00h@2`0<3PT03a4<00h@2`0;3@P200h@2`0H01@G40072P4041<:010C2`0F6A8041<<
00X<1`0F61<0>S`i00X<2@0B514020X700h@2`0<3PT03a4<00h@2`0:30L030h900lA300>40/030h9
00/=200<3PT03a4<0`0=3`X01P0>40/03a4<014C3P092`H051HA01LI50802@/600<03a4<018D4@0=
3``00P0?4@h02@082PL03@l<00L91P0>40d02P`900lA3P0D5Q<08bDR010B3@0200lA3003010B3@0?
4@`02`d800803a4<00@03Q0;00`>2@0=3`X0418=0P0?40/03@0C50l04A8=00d>2@0A4Pd03Pl:00d>
2@041@002``7018C3P0G61<0828M00@60`0X:RD00`051`80300D5Q403a4<00d?2P0A4`h0418=00`>
2@0<3P/03@l<010B3`0E5a@051HC00X<2@803@l<00L03Q0=00lA3P0?4@h03a4>010A30051P404a@?
00802``700<03a0;01<D3`0B4`h00P0A4Pd200l@2`06010@3P0A4@l0410>00d=2`0>3P`0410>0`0>
3P`200l?3@0900l?300N7aX0414<00X;1P0?40/01`P3010A300I6QD061TD008030d800L01`P300l@
2`0@4@`0414<00`=200A4Pd04Q<>00803a0;00/03Pl:00d>2@0>3`X03a0;00l?3@0>3Ph03`l?010@
400?3`l03Ph>00l?3`03010@40803`l?00<03@h=00/=2P0;3@X00P0<3P/08@0=3``04aDB0001000?
4@h00`D2028T8@0@4Pl030h=00L9200<3Pd051HE014C4P0>40l03@l>01HH5`1;CD`0:R`[01`N7@0A
4a8071hM00lA400:30/04a@F00D6200F5a/03a0E014B5`0D5AX04a<K014A6@0@4AL04A8F01<D5P02
00l@4P0701@E5`0?41803a0B00h?4@0D5AL04A8D01LH6P03010A4`804A8D0P0B4aD01P0;30h03a0B
010A4`0?41803@h@00h?4ACooooo000Kooooo`0B00h<3@0=30h04A8D00D62P0@51L08bTY00dC4`0:
3`h02a0<00X;1P0E5A0020L200`=200?3``030`:00d=2`0B4Q<0410B0P0?3Q<04P0=31803@`D00/:
4P0;2Q00;2`[01DE4`0=3@/03Ph<01@D4P0C4a4051@B01/K6@0D51803@d;00l?3@0A4@l03Ph>00l?
3`80410@00T0410B00l?4@0B4Q@05aHK00l>4`0=31402`X@018A5`0B4QX00P0C51T09@0A4QL03@hB
00`=4@0@4AD07QlQ03ho@@0D5AL01@L601<G5P0=4a403A4@018D4`0@41004Q0A01DC500D4Q<04a<C
014C4P0?4a803aDC01<H6@0B5AX03a<F018F6@0E6A`051PI01<G600@51D03A4@01HJ6@0L81l05a/J
01<G5`0830d0720Q01/O800@51D00P0A5AH04@0B5QL04aLH01DI6P0F6Q/05ATJ01<H6@0I7al05adM
020V9P0G7Ad0>3hn018H600P9RH061hN01@J6P0C6AT02a4A00805ATH03L04aLF014E500E6AP082@U
01DI6P0F6Q/04QHI01`P8`0<41<05ATN01LO8P0=5aT04QXM01TN900J7bD07R4Z01HJ9@0B6B<051`W
01/U<@0M:CD06BLd01dW<`0D7RX04adY01HP;00C7BP06B<]01LQ:P0F82T051hW01XU:`0A728051lU
00lI8P0C7BH041XS010I800B6b803QLN01LN900F7B<05A`R01TN8P0F6al04QLK020X:P0A6A/06B4S
01LO8@0F7R005AdO00hF600A6A/03ADG00803aLI00@01@d?00lD5`0H7B0061dP0P0C61/0=00I7R80
4QLM01HK8@0H7B<061`U01TM9P0J7RL061`W010D7`0L82/0;30j01lS;00D6Al06AhT01LL8P0G7200
61dQ01HK7`0D6A`04QPG01<I5`0B61H05AhK01HO7P0A6QT051hO02@^;`0A6a`06bHX02D`<P0=5aT0
5adS01HK8@0D6Al04aPL018G6`0A5QX0314D00lE5@0F71`04QPH00lE5@0D71/04a`K01HN800D71h0
2a<F00dD6P0A61d03aLJ00lG6@0@6AL2010I500W01DN6`0?61L09bla02L_<P0I82H000H>00`C7@0=
51h05QdW02L^=`0?5Qh02A0F01<I7P0@5AT03a@G014G5`0C6AL051XF018H500?5A403aDC014G5`0@
5AP05Q/O01dT;00F7BD03QDM00`C6@0=51X05QdS0418B`053A0041PJ01XR90063Q003QHH00`A500>
4aH03a@G00803Q<F00P041DH018G6P0G71l04QLJ02L/;`0I7R403a@F010D5@803a<B0P0@51<00`0>
4Q404ADD010D4`02018F5@0300hB4@0@51<03a@@00804AHB00@041DA014F4P0C61@03a@@0P0@5A40
300B5a<020d901DJ5P0<4@d02a0<01HK5`0;40`02@h:010E4@0D6AD041DA00hC3`804AHB01@03Q<?
00/@300?510051TE01LL600F6aL04AHB00lD400@5A403A8>01HK5`0B5a<04AHB00/@300B5a<04aPD
00hC3`0=4Ph041DA00lD40803Q<?00<03a@@010E4@0A5A@00P0@51L05`0?4a@03a@@00lD3@0@5P`0
5A`=00`C0@0;4`004AT400/C000<4`401PT500X>3@0T:2L04aLF038g<`1fNgL05Q/G00`A2`0=4P`0
5AXD014F3`0;40T0314;00803a@>00<0314;00X?2@0<4@/01@0>4`d2010E3P0500lD3@0>4``03Q<<
00hC300?50d00`0>4``200dB2`0700hC300?50d02a0900X?200;40T06b0I00X?200200lD3@0B00`A
2P0;40T03A8;00lC300>4@X04A@=01@G400=40T030l800lB2`0C5Pl041<<00lB2`0F6A804aH?018E
3P0@4``03a8;0P0@4``0200<3`P03a8;010C300A50d03Q4:00d@2@0?4P/04QD>0P0E6140100<3`P0
9BPQ00T<1`0A50d200d@2@0=014D3@0@4``04A@=01<F3`000`008B@M03m2>`0R9Ah03a8;03m2>`0^
<BX04QD>00d@2@02018E3P0301<F3`0?4P/041<<008051L@01D04A@=00lB2`0=40T030l800d@2@0A
50d051L@00`?200;3PL04QD>01TL5@0F6A802@`501PK500U:24061/D010C300C5Pl03A8;00/A1`0;
4PL00P0;4@L0100<4@L03A0700`?1P0?4@P2014B2P0D00l@200=3PH0<34[01/L5P0720802@X400d>
200E5Q0051D?028S7@0A4P`0414;00@500092P@03@h801HG4@0?40X03@h800H70@0<3@L600h?2@@0
3a0:0P0>3`T0300B4`d0414;00h?2@0>3`T03a0:010A2`0P8Qd01@L2018D3`0A4`h01`T400d?2PD0
3Q0;00L03Q0:00h?2@0?40X0414;014B300B4`d0414;00803@h802D03a0:00h?2@0;30H02@X501XL
5`0?4@`020X7010B3@010`0030h901XL5`0C5A003@l:00h@2`0:30L08RDN01TL4`0J7A@051L?01PK
500=40T02P`701TK5P0@4Pl07R0M00H81@0>40d02`d800d?2P0A4`h03Q0;00T;1P0>40/05aTD00/=
200:30L04aD@00804Q@?0P0>40/200d?2P0A00h@2`0?4@`03@l:00X<1`0;3@P030h900/=200A4`h0
30h;00T;200>40d03a4>00L91P0:30T03a4>01@F4`0;3@X00P0>40d01`0H6QL03Q0;00lA300A4`h0
4Q@?010B3@0:30L00P0@4Pd0100>40/030h900`>2@0>40/2010A300?01@E400B4`h03Pl:018C3P0>
3`X06AXE01HG4P0A4Pd03@h900X;1P0?4@`07R0K020R7@000@007b4L00803Q0;00<03@l:00h@2`0>
40/00P0;3@P01`0I6aP04Q@A00@60`0<3P/02P`901TK600=3``00`0>40d200lA3P07014B3@0;30L0
3a0;00h?2P051P4061TD010A300200l@2`0400h?2P0<3@P030d800l?3@804A4?0`0>3P`300d=2`80
3Ph<00L03@d:01HG4P0;30L02P/7010A30082@@04A8=00804Q<>00@02``700T:1@0>3`X030d80P0?
40/01@0=3PT0414<010A300?40/0414<00<03a0;00<0414<00l@3@0?3`l00`0@41002@0?3`l0410@
010@400?3`l03Ph>00l?3`0A4A403a0?00`>2`0300d?300C00h@3@000@006Q`I010B3`0>40d0>3Xg
02`^:`0B51<02@/:01PJ6@0G6AP04Q@C00@61@082PT02P`;02HX9`0>40l02`d<00X<2`0201@F4`0<
00d?3P0C51H03PlA01<D600?41D04A8G01<C6`0A4A/03`lI00h>5`0C51P04Q<E0P0=3Q00200C51H0
414C00X;3@0?41804Q<E028S9@0K71h05AHH0`0@4Q43014C4P0400/=300?4A00418A00lA40803@l>
5?ooool001_ooooo01803`d=00/:2P0=3Q003a0D00/?4P0<4A@03a@G00T>3@0=4Ph03`l=00/;1P0=
3@H03@h900h?2P0>3P/03`l=00l?3P0?3a4200h=4P0<00d<4P0=31@030/D00`;4@0C4a803Ph<00l?
3@0B4Q004A4?00`<2P0?3`d03Ph<0P0=3@/00`0>3P`03`l=00h>3P0200l?3`0R010@400@4180410B
01TI6`0L6b004A0E01@C600C4QP051<I01<C6`0=3A@03PlE010A5P0@4AD04a@H01DF6P0:2Pd061TL
010A4`0C51D04QHF00dC4@0=4A004Q@C010@400B41405aDF01HD5@0D51@04Q@C014E500@5Q@04aPJ
01@G70804ADH00`04QHI018F5`0B5QL041@E014E500F6QT061`K01@H5`0E6AT02`l@024U9P0P92D3
01@H6@0:018F5`0C5aP05ATJ01HJ6`0E6AX05AXJ01LM7@0C6AT051XJ00`B4P805Q`L00H05A/K010E
5@0G7Ad02a4A01TO7`0D61L201LK6P8041@C02`06AdN018F5`0D61T061`O02<W:P0=4A@0FUiR01hV
:00D7Ql041PK01HK8@0?51X06A`V01LK9P0E6bH05QhZ01XT<00I9C4062Hb01hX=00E7b/05R0/01TS
;`0B72L05R0Z018L9@0T;SL0628[01HQ9`0C7R@05B0V01HP:@0D7RL041XS01@M900I8RT051dT010G
7@0F7B<061lU01@I7@0N8bL06b0T02@/;P805b0R00X041TK01@M7`0G82404Q/L01XS9@0C71d06R<T
02D^<00M9BL05AXM0P0K82<01`0G71l051TM01HK7`0F6b406QlU01/P9P0I7BH00P0H72D0EP0I7BD0
61`V01DI8@0D6Al06QlT020U:P0H7B4051TM01@I700F71h05a`P01LM7P0D6QP04QPF010F500C71T0
4a`K00dF5@0=5aL04A/L01DO800?6a`02aLH01@N800F728051TO018G7@0B5a/051TM01HK7`0M8RD0
8bTY01@J6P0G7Ad041HF01PO7`0@6AP031@F01<K7P0@61/041LL01DM800A6A/03QLF00lH500@6Q80
4A/C01<L5`0@6AP03QHH00`C600C6R808RTc00`C7P0B62<05A/V01LN9`0@5al04APN01LM8P0D6Ad0
4QLJ01@J6P0D6QP03aDA00/A3@0>51004QPF01@I6P0B5aX04QLK01<J8P0@5al04QTQ01@K8@0A61h0
51/Q018J7@0@5aX0HVY/06=[K@0C6ad02a8D00`A500>4aH041DH0P0?51L0200@5AP03Q<F018G6P0@
5AP02PlB010E600;4A804QHG0P0?4a82014E500700`@3`0=4A0041@C01<G5P0>4Q40310?00lC4P03
014F4P03010E4@0=4Ph0314=0080314=00H04AHB018G4`0B5a<0?44m03i3?`0C61@300hC3`0:00`A
3@0A5Q802a0<00X?2`0@5A404QLC00dB3P0>4`l03A8>010E4@8051TE00L03a@@014F4P0@5A403Q<?
01DJ5P0>4`l04QLC008041DA00<04AHB010E4@0>4`l00`0=4Ph05`0>4`l03a@@00lD400?4a403Q8C
014E5`0A5AD03a@@00hC300?50`03aD:01@K3@0<4`<04AP600dD0`0<4PD041@A010D4`0?4a803A4@
00lD400B5a<041DA00803A8<00D03Q<=00hC300=4P/041D?00hC3@0200dB30803a@>1@0>4`d00`0>
4``03A8;00dB2`0300dB2`0300hC300?50d03a@=00803Q<<0P0=4P/020083@H02Pl800X?200E6Q<0
;C8[00/@2@0:3`P0314:0P0=4P/01`0>4``03Q8;00d@2@0A50d04aH?00`?200=40T00P0?4P/00`0>
4@X03A09010C300200lB2`0L00hA2P0?4P/041<<00lB2`0;3PL030l800hA2P0@4``03Q4:00d@2@0?
4P/05aXC00P;100?4P/02@`5014D3@0F61<04A@=00`?200>4@X04QD>014D3@0C5Pl030l801PK500B
5@l04QD>01@G40803a8;0P0=40T200lB2`0600d@2@0?4P/03Q4:00hA2P0@4``04A@=0P0?4P/02P0>
4@X03a8;00d@2@0:3@H03a8;00`?200>4@X04A@=01@G400A50d200`?200701@G400?4P/03a8;014D
3P0?4`h03A<900`C200200/A1P0400hB200?4PP030l500lA1`804Q<:00h03a4700d>1P0D5@l04A8<
00X;1@0@4@/03@h8014B300G61<02``601<D3P0<3@L071dG00/<1P803@h800@0414;00h?2@0=3PP0
4Q<=1P0=3PP300l@2P<0414;00<04a@>014B300@4@/00`0?40X01P0?4@`02`d800`>2@0O8A`02P`7
010B3@D03Q0;00<03Q0:00h?2@0>3`T0100>3`T200d>2080414;02D03Pl901HG4P2DUY40<38]01HH
4`0:30L01PP3018D3`0X:RD06adH014C3P0@4Pd01`T401hQ6P0A50/06QdD01<F3P0B5@h030l800`>
2@072@H0418?00@50`0W:BH0E5IC01<E400>40/03@l:00h@2`0=3`X04aD@028T7`0C5A003a4<018D
3`092`H02`d800803a4<00P03Q0;00d?2P0=3`X03Q0;01@F4@0=3`X05QPC01/M60803a4<00l03@l<
01LI5P0@4Pl01`T600lA3P0<3P/0418?01@F4`0<3P/03a4>00/=2P0B51405ALB014C3P0?4@`00P0>
40/0100;3@P03@l:00lA300?4@`200h@2`0D00lA300?40/03@h900d>2@0>3`X0414<01TJ5@0l?CP0
30d900`=200@4@`04A8=01HG4P0O8A`0EEMB00`>2@0E5a803Q0<00/=200>40/200d?2P0900T;1P0=
3`X051HA01hP7@051`@04aDB018D4@0<3P/02P`900H03Q0=00L0414<018C3P0?40/04Q<>00L80`0F
5a80414<00803a0;00@03Pl:00d>2@0=3PT03`l=0`0A4@l0100>3P`03@d;00`<2P0<30X200d=2`0>
00h>300@40d04a@?00`=200?40/04Q<>00/<1`0E5Q403a0=00P9100C50l03a0;01TJ5@092PD200h?
2P0500l@2`0>3`X03Pl:00h?2P0@4@`00`0A4Pd00`0@4@`03`l=00h>3P0400h>3P0900l?3`0>3Ph0
30`<00`<300>3Ph04A4A010A3`0=3``03Q0=00<03a4>02<04Q@A08^=RP0K7AX04aDB00T;200<3P`0
3a4@01<E500a<S4051HE00/=300A4a806A/J00H81`0>40l05QPG00/=300A4a801`T601DG4`0:30X0
51HF014B4`0=3Q403a0E010A5P0B4QX03`lI00d=5`0>3QP03PlC00d>400>3a40414C00l@4P0200`=
3`804Q<E00<09RLY018C5@0?41801P0@4Q40100?4A004Q@C01<E500A4a8200lA41Cooooo000Koooo
o`0C00l>300?3Pd02@/:010A5@052Pd02PlC0001100830h03A8>00D60@0?40T030`400h?2@0<3@P0
414<010@3P0=3@`03Ph>00h=4P0200h=4`0@00h=5@0>31L03PdC010@400=3@/03Ph<010@3P0C4a40
4A4?01DE4`0:2PP030`:010@3P0;2`T02@T700l?3`803Ph>01X03`l?010@4P0A4A<07AdO01LF6`0>
3A804Q4F00l>500D4aT07QhV00h>5P0?3aL03a0E010A5P0F5a`03a0D01LH700E5QX02``>010A4`0;
3`l0318@00hB4@0D5QD04A4A014?4080518C05D04Q8B014C4P0@51<041HD01<H6P0D5a`04aLJ018F
6@0A5AP04QHG010D5@0B5QL05QXI01<G5P0=4A003Q8A00dA4@0C5aP02@d>01<G600>4Q<06QhO01DI
6P0B5QL04aLH01DI6P0F6Q/05ATJ01DJ6P0A5aL051XJ01XP800K8B406AlO01HL700630`05Q`L01<I
6@0O9BD03aDE018F5@0E6AP05a/J01<G5P0B5QD05ATJ00hB4`0N8R<051PK00dA50072`h06AdQ01@L
7P0@6Q/041PK020U:`0B5ad0828^01HJ9P0I7b/072@a01HP;00B7RX05R@_01HP;00G8Bd06B<_01DO
:`0C7BP04adW01LQ:P0c?DH06B</010K8@0C7R@041/Q01TS;00E7bP03QPQ018K8P0I8RT05b0W01LN
900C6R004QTO00806QlS01@051`O014I6`0?6AX05b4R01<M7P0F824041XK02D_<00`>S/06R@U01@N
7`0J92D0218C01HK7P0H7B005a`O01HK7P0E6Qd051TM01TN90805Q/Q00H05a/T01DI8P0D62405AXP
01HK8@0D6Ad201LL801K01<H6`0D6A`04AHI014G5`0D6QX05Q`L01HL6P0B61@04ALE00lE4`0C71T0
5AhM018K6P0/=SD06B<T00lI6P0C7al01Q8B018L7@0D6R004QLM014F700C61`05Q/O01PM8@0Q9RT0
9bd]00lE5@0F71`04aTI01TP800H8B003QHH010H6`0A6A`03QHI00dE600?61L03QLF00dF4@0>6100
3aT@010I500>5aH00PX<014I7@0>5Al04QPT00T?6`0A5b<051XV00hE7`0E72@04aXP00`B5`0@5AT0
4aPK01LM7@0E6aT04ALC00`B3P0A5a<05A/I01@I6P0C61/04AHJ01@K8`0@5al03QDM00`C6@0941H0
2a8H00L?4P0D71l0<c/m04A<CP022P`05QhP00dB5@0>4aH04QLJ01DJ7@0D6A`03a@G018G6P0J7b80
4AHI000110062`h03a@F010D5@0200lC4P8041@C00L03Q8A00P<2`0=4A004ADD018F5@0F6QT061`K
0080314=00/03Q<?010E4@0?51002a0<00lD400<4@d03Q<?00lD400<4@d0;c@`02@Y9@02010E4@06
00/@300=4Ph041DA01HK5`0A5Q803Q<?0P0@5A401@0<4@d04QLC00hC3`0;40`0314=00<03a@@00d0
41DA00lD400B5a<0314=01dR7P0C61@03Q<?00dB3P0B5a<03a@@00/@300=4Ph03Q<?00803a@@0P0>
4`l06P0B5a<051TE018G4`0<4@d03A4@00lC4P0>4Q0041DA00@91@0;40/03A8<01<H4P0C5aH0310?
00/?3P093@`02a0<014F4P0?51004QLA010E3`0<4@/03Q<<01<H4@0H7AL041D?100=4P`500hC3@03
00`A2P0:3`P02a0900<0314:00@03A8;00hC300>4``03Q<<0P0=4P/03@0>4``03a@=00/@2@0:3`P0
2a0901/P6@093PL03A8;00hC300=4P/02Pl800/@2@0=4@X00P0=40T00`0?4P/030l800d@2@0200lB
2`05014D3@0@4``041<<014D3@0>4@X00P0=40T2010C300400hA2P0;3PL030l800hA2P8030l800P0
3Q4:00D80@0G6Q<04aH?00hA2P0K7QL0?T4j014D3@803A0901004A@=010C300A50d041<<01@G400:
3@H092LP024T7@0;3PL02Pd600lB2`0C5Pl03a8;00hA2P0B5@h03Q4:0P0?4P/3010C300D00hA2P0<
3`P04aH?014D3@0?4P/06ahG00hA2P0@4``03Q4:00/>1`0<3`P041<<018E3P0620@0008000/>1`0F
6A806b4G00hD2P0>5@P200hD200400lD200@4`P03A0500lA1P80418701003a4600h@1@0@4@/03a0:
00T:100?40X02``600d>201HFE<0@d@n010A2`0A4Pd02P/500T:100?40X01PL10P0=3PP00`0A4P`0
20T300h?2@0500h?2@80414;1P0?40X4010A2`0600lA300:30L04A<>0084000620<03@l:1@0>40/0
2P0?40/03a0:00l@2P0>3`T030d700/<1P0>3`T03a0:00h?2@0@4@/2018C3@0E00d?2@0E5a801`T4
00h@2`0T9R404aD@01@F4@0O8A`05aTD00h@2`0=3`X01`T400lB2`0520005QT@014D300@4``04A@=
018D3`0A4`h03a4>0080004000T071dK01lQ700D5Q402`d800`>2@0;3@P03@l:014C3P0<3PT00P0>
40/0100;3@P061XE00h@2`0>40/200d?2P0F00h@2`0?4@`02@/600P:1@0G6A@06Q`G00`>2@0:30L0
6adJ02X/:@0I6aP01PP501@F4`0<3P/01`T600`>2`0:30T04Q@A010B3`0D5Q<07AlJ01DG4P803Q0;
00@0418=014C3P0:30L03Q0;0`0?4@`02`0@4Pd04A8=00`=200<3@P03@h901<D3`0O81/0LgA_01hO
6P0E5Q404Q<>00803Pl:01<03Q0;01DG4P0>40/06adH00/<2@0J71L04Q@?00/=200=3`X02`d8018D
3`0N81/0GV1M00h@3@0B51400`D201LI5P0@4Pl03a4>00<03Q0=0P0=3``2010A300400l@2`0=3PT0
7QlJ00D60@803@h90P0>3`X200l@2`06010@3P0?3`d03`l=010@3P0>3P`030`:0`0=3@/200h>3004
00h?2`092PD02P/600l@2`80414<00h04a@?05UJE@0N7aX03a0=014B3@020`00414<00h?2P0?40/0
4Q<>00h?2P0<3@P03a0;010A30<03a0;00<0414<00l@3@0=3@d00`0<30`00`0=3@d03Ph>00d=3@02
00`<300400d=3@0>3Ph03Pl>00d?30803Q0=0P0?4@h06`0A4a005aTF00lA3P0;3@X051HC00P:1`0>
40l02@/:01PJ6@0A4a80418A01DG5P0>40l00@<2018D4`0[;B`030h=00d?3@0F61D00P@0020R7`1O
HF000`D401<D5P0>3a@03a0E010@600200h>600=010@6`0@4AD03PlA01<D5P0H6A/04A8D00d>400?
41802``>014B500<3@l02``>01<D5P03010B4@<03a4@00@03@l>010B4@0A4a803Q0?0P0<3PdDoooo
o`006oooool05@0>3@/04a<B00X<2`0?41@01@X=01HK7`0/<CD01`/=00hC3`092PD04a<<00H6000>
3`T030d7010A300@40h030`;00h>3P0?3Q<03`hD00l>5P0200l=6008010?5@0;2`/02@T700X:200?
3`d051@B01<C4@0K6aT200l?3@0A00`<2P061P@01`L500l?3`0>3Ph03@d=00l?3`0@41804A4C01<C
5@0@3a@02`X?00`;400>3A<07QdS01lO9`0?3aL00P0B4QX05@0A4QL05QLL024R9P0B4aL051DI01PI
6`0I6Q`03A4A00/A3`0?4a805ALF018B4P0@3Pl0518C01DC500C4a<04Q@C010D4`0?5A<04QLH01@G
700201DI700G01<G6P0C5aP04QHG01DI6P0H71/051PG00lC4P0B5QD041@D030d=@0;3a006QhO00hB
4`0K7b003a<D018F5`0C5aP05ATJ01HJ6`0E6AX06AhO01PN7P0F71`00P0=4a<01@0;4A403A<C03a2
@P0B61P07B<S0080728R00<04QHE01<G5P0F6QT00P0F6QT0700E6AX04QHG00`@4@0C5aX07b<V01TM
800@51T04a/M00lI6P0A6A`0:Rle01@I7`0D5R805a/W01TO:`0K8c005R0/01<O:`0F92l05R0/028/
>00P:SH04adY01@N:@0@6R@05AlX02@^=`0B72D3010K8@805b4Z01d04A/T01<L8`0H8BP05QlV01HM
8`0J8BL04APN01PM8@0F6al0=Ce001dU9`0G8B806B<T018L7@0C7Ah0218C008<3@0K9BH041XK00hH
6@0O:BX04A/L01<H6`0I7R406QlR01HK7P0I7R4082DY01`Q9`02014F700C01PL9@0I7BH05a/T01HK
800K82@06AhR01/P8`0F6ah03a@G018H6@0@5QH04ALG01DK6P0F71X05A/I01<I5@0E6aL04ALC010I
5P0201@M6P0D03M1@00V<34051hO010L700:5QH02A<D01DK8@0D6Al04aPN01<H700D6Ad05AXN014F
6@0H7Qh05Q`L01DK6`0I7al0620O01`U900G7b42014I700j00dE6008418031DD014J6@0C71L04A/C
018L4`0A6a@051dL00hF600H82@0ADaF00/A7@0K8Bl051XX01<I9@0D6bD05ahV014H7P0;4AH041DI
018G6P0B61P03aDC00lE4@0@5Q805Q`H01HL6P0?5AD04QLJ01@I7@0:4AT02A0H00hE7@0A61h03A@J
00`C6@0430l05QhQ014I6`1EGEl0;3@f00`D5P0?51L03Q<F01<H6`0K82<06QlR00hC5P093Q404AHI
00hC5P0J7b807b@W014G600=4A803Q8A010D4`803a<B01d041@C00X>3@0>4Q4041@C01<G5P0I7A`0
5a/J00dB3P0<4@d03a@@014F4P0@5A402a0<014F4P0<4@d041DA01TN6P0:3`/0314=000300083@T0
5a`H014F4P0@5A402a0<01@I5@0B5a<041DA00lD400200hC3`8041DA00d03A8>00`A3@0?51004QLC
00`A3@0@5A404AHB018G4`0@5A40:c0/010E4@0?51003Q<?00<041DA01l03A8>00lD400@5A4041DA
00lD400>4`d04AH?01<H4@0@5@l02`l=00dA4P0A5AP030lC00`?500931<05QTP00/>5@0=41D03A4A
010D4`0I7A`041@C00T>2P0B5a<041DA014F400@5@l03Q<=010E3P0B5a004QLA00803a@>00<041D?
00dB300<4@/01@0>4`d00`0<4@X02Pl800`A2P0200dB2`0300`A2P0=4P/03A8;00803A8;0P0<4@X0
1`0=4P/04aPA00/@2@0=4P/01@X300lD3@0;40T00P0>4``05P0<4@X02a0900`A2P0?4``03A0900`?
200@4``03Q4:00`?200>4@X041<<018E3P0>4@X02Pd600/>1`0A50d03a8;00d@2@0?4P/041<<00lB
2`0=40T200hA2P8030l800P04A@=00X=1P0S9Ql02Pd6010C300L7aP0=CPa018E3P803A0900P041<<
00hA2P0?4P/010L000/>1`0@4``0>3/d02`_:0803a8;0P0@4``02`0>4@X041<<01<F3`0>4@X03a8;
010C300?4P/041<<014D3@0D5a002`h700803A0900H061/D034d;@0@4``03Q4:00d@2@0>4@X2010C
300800`?200>4@X05APA01XM5P0:3@H010X000hD2P0?5PX2014G2`04014E2P0@4`P03a8700lA1P80
3Q0501003a46010B1`0B4`d03Pl900L80P0>3`T02``600h?2@0e=S00;RlY00L80P0?40X04A8<01@E
3`0B4`d030d70P0?40X00`0G61801`P200h?2@0500h?2@0400l@2P0>3`T03@h800d>20802``600<0
3@h800h?2@0?40X00`0@4@/01P072@@02P`701@F4@000@00<38]00P:1PD03Q0;00<03a4;010A2`0?
40X00`0?40X2018C3@803a0:0P0A4P`02P0E5a40004000h@2`0?4@`05QPC00D70P082PD04A<>010B
3@0=3`X200lA300H018E3P0:3@@05QT@010C2`0@4``03a8;00D70P0C5A0020T702/]:P041P<05aTF
01PJ5@0B50l03Q0;00d?2P0:30L030h900T;1P0:30L030h9010B3@0G6A@092HQ0`0=3`X01`0>40/0
3a4<014C3P0<3PT02P`700lA300A4`h00P0;3@P01@0H6QL07R0M01HH5@0<3P/03a4>008030h;00l0
3a4>00/=2P0A4a002`d:00`>2`0F61<04A<>00h@2`0?4@`04A<>010B3@0;3@P03a4<010B3@0?4@`0
0P0>40/06`0@4@`03@h900l@2`0>3`X0414<01PI500N7aX01@H301@E400:2`H03a0;00T:1@0:30L0
4A<>00lA300620<03Q0;0043000@4Pd02@/600h@2`0?4@`051HA01lQ700L7Q/01`T6018D4@0200d?
300300L91P0?4@h03a4>00803Q0=0P0=3``02P0@4@`02P/6010A300@4@`0@d@o00X;1P082@@02@X5
00X;1P0=3PT200h?2P06014A3`0=3@/03@d;010@3P0?3`d03@d;0`0>3P`200l?3@0N00l@30082@@0
30d800l@2`0;30L04A8=02`]:01TIF0061TD00d>2`082@@01PL2018C3P0?40/0414<01DF4@0?40/0
3@h9010A300?40/03Pl:00d>2@0>3`X03a0;010@3P0>3Ph03@d=00`<300=3@d03Ph>0`0@410300l?
3`0300h?3@0=3``03@l<00<03Q0=00T05ALD0001000?4@h02@/801XL6@092`P05QPG00/=30082PT0
0P0?4A0040092`X04aDD01<E500?4A006adL010B4@0e=cD03Q0=00L9100S9B80Gf5P00`>3@0@4A<0
3@hC00l@5@0@41T200l?6`0=018B7@0C51P03a0B01<D5P0H6A/04Q<E014B500>3a403@h@02TZ;008
2@/03@h@00l@4P02010B4@803a4@0P0>40l01P0=3`h0418A014C4P0>40l030h=00/=31Cooooo000K
ooooo`0V00X:1`0C51402@/:00h?4@0<3Q<08bL[07YlP@0D5aX02P`=00/<300<3@X06QXF00l@2P0=
3PL03a0;010A2`0=3@X03@d<01DE5@0@41<02`X>010?5@0?3QD04Q4G00h>4@0>3a404A8D00d>400>
3Q002P/=010@4P0?4180410B00l?4@0720X05ADG014A4P0?3a0200/;300400h?4@0?3a40410B014A
50804Q8F02l04Q8E01dO900@51h03A4K00P;5@0E6B801`XB01TK8@1GFEh05aPL00`=4@0B4QH05ADH
018D5P0?4A80418E01@F5`0A4Q<04A4D01DD5`0B4a@05QHI01LH6P0C5AH051HI014E600D5a`05QXN
01DI7@0D61/05AXM01DJ700A61T04AHH00lF5@0>5Q@03aLE02@Z:P1<D5808RHX01TM7`0@51H06alQ
018F600D61X05ATK01HJ700201DI6`1G01DJ700?51P04aPK00/A4@0I7al051XH01hT8`2DVYT07R@T
01@I6`0E6Qh051XM01<G600C5aH06QhM01<G5`0D61P051PJ01LK7@0;3Q8061/P00T<4P0I728061/Q
010G6`0E6b0051TO02T]=@0J7BL05ATT01HI9`0F72/06B0`01PP<00E82l05b4a014I;P0X;dH092]1
024Y?P0I8SD062@c01PS<@0E7b`051hY01DN:00I8bX06bD[01HN9@0J8bT06B4X01PP9P0I8RL06R8V
01@K800S:Rl072@X01LN8@0P9bX0FF5T02@];@0C71X03aTG010G600B6QX041XJ01HL7`0T;2h08BX/
01lV:@0R:Rd05alS01<K8@0P9Rl082L`01TO9P0K8RP0:30f028Y;`0G7B805QlS01HN8P0C6Qh051/O
01TN8@0R9RX07R8V008051TL05405QXM01<H6P0B5aT051TK01DJ6P0F6a`05a`L01HK6@0H7A/05AXG
014G5P0C61P04QTJ01DK7@0B61/05QdP018J7P0H7b<051XP01HI8P0D61l051PM01@I6`0B61L04APD
010H500@61<05alM01@M7@0@5aX05AhR018K800G82D04QXO00lG6`0;4QL03QHH01<J6P0H7al061lL
018K4`0A5a004QPC018J6@0@51L07b@X05mUJ`0G6R<05a`V01@I900B5B004QHQ014G800@4ah04QHK
01DJ7@0F6ah04aPH010E4@0@5Q4051XE01PM6@0F6aT03Q<D00hB5P0C5ah04ADJ01@J7`0N8bP092P[
01DL7@0A5aL05a`K00XA400>5A@04aLI01LN7`0<41<041@G00hC5P0A5AL00P0F6Q`09P0>4a@03A8D
01DJ6@0@5A@03a@C00dB4@0>4a403A8@00lD4P0A5Q<041DC00lD4`0A5QD02@h=01HK7@0@51H03Q8E
014F600>4a@04QHE00hC3`0D6AD05AXF00hC3`0<4@d04AHB010E4@0J7a/09b`X01`Q7@0>4`l04aPD
010E4@0>4`l02a0<018G4`0A5Q803a@@0P0@5A401P0?51003Q<?00lD400=4Ph03a@@010E4@803a@@
00P041DA00dB3P0>4`l02Pl;01PM6@0A5Q809b`X00dB3P<03Q<?02H041DA014F4P0<4@d03A8>00lD
400@5A403Q<?010E400@5@h041D?00hC3P0;40d03a<C01<G600>4Q<04ADI01TM8@0P92P03Q4F00X>
4@0>4a002a0>00dC3P0>4a002a4<00T?2P0>50h02a4;00dC300?5@l03A<<00/A2P0<4@X02Pl800hC
3@0I7QL051TC00dB2`D03Q<<01803A4;00d@2P0?4P`041<=00lC3@0@50h03a8<01@G4@062@D030l9
00/?2@0@4`d02`l9014F3`0;40T03Q<=010E3`0B5a4300dB2`0;00`A2`0>4``03a@>010D3P0;3`P0
310901<G400>4P/02Ph700/?200<40T00`0?4``0200B5Pl03a8;00lB2`0>4@X03a8;010C300=40T0
3Q4:100?4P/0200A50d09RTR02ha:P0<3`T04A@=00L:0`0A50d041<<0`0?4P/01@0=40T03Q4:00`?
200D5a002Pd700804A@=00L041<<01<F3`0B5@h041<<00lB2`0>4@X030l800803Q4:0P0=40T04@0>
4@X041<<00lB2`0>4@X041<<00lB2`0<3`P051L@010C3@0>40/030h801<E3`0C5Pl03Q4:01@G3`0A
50`03a8800804A@:01P06R0E00dE2P0=5P/05AhB00lF3@0>5@/041L;00T@1`0J81H06QlD00hC2`0:
3`D03Q8:00`>200?40`03Q0:01@F4@0D5Q805QPB02X/9`0;3@T061TD00/<200/;BT300d?2@0_00h@
2P0>40T051H?00X<1@0>40X03@l900h@2@0A4``03Q0:00/=1P0E5`d02P`601@F300=3`L03a4:00h@
200<3PP01PP400T:1@0B50h03a0<01DG4P0D5Q4041<=00d@2P0G6Q@0C4i801HH4P0>40X03A0:00lA
2`0?4P`03a4;00h@2P0C5@l071hG01<E3P0C5@l04A<<01@F400A4``03@l800h@2P0A4`d0418<00`>
200D5Q400P0@4Pd0100;3@P04A<>00d?2P0:30L200h@2`1A010B3@0C5A00418=00P;1P0:30H030l9
00lB300<3`T04aD@00h@2`0A4`l01`T500T;1`0A4`l03`l;00l?2P0@40`03a0;00`>2@0?4@`03Q4<
00lB3@0<4@X030l:00hD3@0@5Pl02`l900h@2P0?4@/03@l900`?2@0?4@/04QD?01TK5@0;3@T02`d7
014C3@0<3`T03@l;00/=2@0=3`/03a4=00`>2P0>40`03a4=014C3`0=3`/0418>00/=2@0:30P03a0=
00d>2`0>3``03a0<00h?2`0?40d03Pl;010A3P0A4Ph03a0=00d>2`0;30T02`d900`>2P0?40`03Q0<
00d>2P0?40`03Q0<01@E4@0H6QH01`T501<D400@4Ph030h900lA3@0F61<05ALB01LI50092`H04Q@?
00803Q0;00D03a4<00P:1@0D5Q405ALC01<E4@02014C3`0M00`>2P0C5A403a4=014C3`0<3PX03Q0<
010B3P0<3PX0414=00H70`0E5A80410=03`m>@0E5Q803@d:00d>2P0>3P/03a0<010@3@0@4@d04A4>
00`=2@0=3PX04A8>010@3@0>3P/03@h:00h?2`0?3``00P0?40`0300A4@h03@d:010@3@0?40`020P5
00h?2`0g=c@0:b`X00P91`0@40d01@H401TI5P80418=02L0414<018D3`0?4@`03Q0;00lA300=3PT0
3Pl:00l@2`0;30L03Q0;01HG500;30/05AHE01HG5@0:2`T04A8@00h?3P0<3@`07QlM00h?3@0E5Q@0
30d<00l@3P072@H030h;00h@3@0?4@h030h;00/=2P0F61D03@l<00/=2P0=3``030h;00l@400A4Q40
2``<01dN7@0>3`l00P0?4100700G61L03a0@00d>3P0A4Q80;c0`00X<2P0E5aD02@/:01<D5@0D5AP0
30d@00`=4P0>3a@04A4J00h>5`0?3aP0820Y01/L7`0F5aP04A<C010A4P0@4Q805AHG00l@4@0B4a@0
;Bh_01<D5@0A4Q<200`>3@0601<E4`0E5aD07AlM00h@3P0?4@l04aDC0P0D5Q@00`0B51803a4?00h@
3P0Dooooo`006oooool03`0:30L02`d900<50P0<3@l01`L;00/<4@0K72401`P=00H7300;310030d@
01HH5`0>3`T03@h700`=1`0200d>200700`=200K6aT0000000d=3@0G5aT02@P=01LF6`02014B5`80
30dB0240414F018C60030`P051DJ00T:3`0A4QL03@hC00@52@0;30h03a0B00h?4@0?41803PlA00T:
300<3@l0414C00l@4P0B4aD05AHH02X]<P0J8Bd02Q0L01HL:00W;SP03a<L00dA6P0N8BP04a@I018C
600920h040lD01HF6P0E5QX00P0A4QH02P0C51P03a0D00/<400<3A403a0D01@E6@0>3a<03@hB00lA
5P0@4aP3014D6@05018G6P0C6Q`041PJ00hF600?61P00P0A6aX02P0D6a`06AdP01DI700?4aH051PK
01LK7P0E6A`051PK01DI700F6Qd201DI700b01<G700@5A/06b0T00`A50052`/041HC00T?2`0R:2H0
5A/K014F6P083A405a`S01<G600>4Q403a<B00lC500P92D02`lB00`?500A51T010L>05mRJ`1iO8D0
4aHO018E7P0G6R<04QDN028T<00L7RX041@P01HL:P0H7Rh06R0a01PO<@0H7c806b8f01lR@@1>DG80
7R=2018I=@0L9Sl04Aha024^@@0^>DX082Xf02@/>@0G7RT05A`T01/R:00J8RD201TQ900]01PP8`0F
7R405AdP01DM800H82<05QhQ01TQ900Y<C<0:c4_01<I5P0=4a403Q@B00/A400?5AD05AXM01LL800P
9BT08BH/01`Q9`0I82P06R0^01XQ<@0F7R/04QXU018K9@0F7bH05b0U014K7@0F82404A/K00dG5P0E
7Qd061dP01PL7`0D61/03Q8E00lC5P0A5AP03A4D00`@4`0A5AP04aLJ01@H6`0G6a`05ATI00805a/J
04X051PI01<G6P0D61/041<H010C6P0D5ah03A0G00hA6P0B5Ah04aDQ014D6`0A51T04aPF014H4@0@
5`l04A/A02H`:00<5A801a4C00@=500>5b002Q8M01<L9@0A6B4051/S00dD6P0E6ah04ALG01<G600D
61H051TE01@I4`0C61D04aLH01DI700F6Qd05ATL01<F6`0A51X05APO01DH8@0B51l051HR01<E8@0?
4QT041@G014E5P0B5QD04aPD01@I4`0B5a004QLC01@H5`0A5AL03Q4F01@G7`0:3A804aLJ01DI6@0B
5QD01@X600dB300A5Q003a@>00dB3P0?4a@041@E00dA500?4aH03Q8E00hB4`0=4A803Q8C00lC4P80
41@C00@04AHB018G4`0B5a<04QLA0`0?5A401P0?5A<041HD010F5P0F6ah09BX]01<H70803A8H00d0
5Q/P00hB4@0?51007b@P020U8@0>4`l01``800lD400>4`l03a@@014F4P0?51002@h:00804AHB00D0
41DA00lD400C61@061dI010E4@03014F4P03010E4@0>4`l03Q<?00@03a@@00P03Q<?00870`0U:RH0
00D100L<20093PX02a0<00lD40803A8>018041DA00lD400>4`l03a@@00`A3@0?51003Q<?00dB3P0@
5A403a@@00hC3`0<4@d02a0<00hC3`0A5Q804QLC010E4@0?510200L<200B00lD400>5@h02Q4:00dD
3@0>5@h031<<00hE3P0=50d031<<00dD3@0?5Pl031<<00XA2P0>4``0314:00dB2`0D6A804QL@1P0<
4@X00`0<40X03Q0;010B3@02010B3@0F018D3`0?4@`0418=010B3@0C5A0010H1010B3@0A50l03Q<=
018G4@0H7AL05Q/E01<H4P0?50h02a0:00`A2`0>4`d04AH@018G4@0@5@h03Q<<00lD3@8041D>00<0
3Q<<00/@2@0;40T00P0;40T200`A2P0701HI4P0930D06A`E00d@2@0;3PL04A@=010C3002014D3@0@
010C300>4@X030l800hA2P072P<06QdF014D3@0I71D030l800hA2P0@4``04A@=00lB2`0=40T03Q4:
00lB2`803Q4:00<03A0900hA2P0?4P/00P0>4@X0100=40T02`h700d@2@0?4P/600hA2P0I00d@2@0<
3`P02`h700/>1`0:3@H02@`500H81@1NH5d06adJ00T;1P0520805QTB00lB2@0=40H02`h300`@0P0>
4P@03aD903e5>P0P:R405b4H01PR6@0S;B@02aD<004;0P0201DO5P0500/E30094`X03A@<01LJ5`06
20D00P0;3@X02@082PL03Q0=01PJ5`092`P02P`900h@3@0?4@h071hI00h@2P0300lB2`0400hA2P0=
40T04aH?00lB2`802`h702P030l800`?1P0;3`<000<000lC1@0;3P<04QD<010C2P0A50d05ALB01XL
5`0G6AH02@/800lA300?4@/020/400/>1`0A50d041<<00hA2P0=40T030l800hA2P0@4``03a8;00`?
200@4``071lH00d@2@0E61403a8;01<F3`0?4P/030l800d@2@0>4@X030l800X=1`0<3PT03@l:0`0>
40/0600=3`X04aD@01@F4@0?4@`04aD@018D3`0=3`X04Q@?00h@2`0:30L03a4<01DG4P0>40/030h9
00lA300@4Pd03@l:010A300B4@d04Ph;00h=2@0>3`X03a0;00d?2P803A8<0P0<4``01@0;4P/02149
00X?200<3`P03A0900803Q4:00P03A0900X=1P0<3`P04QD>00lB2`0L7aP02`h700`>2@@03@l:01<0
2`d8018D3`0A4`h03a4<00d?2P0;3@P02P`7014A3`0?3`d04A4?00l?3@0<30X04A4?00l?3@0A4@l0
3`l=00`<2P0;2`T030`:00803Q0=100=3``0900;3@X04A<@00h@3@010`002P`9010B3`0>40/02`d8
014C3P0I6aH05ALB00P:1@0A4`h04aD@00/=200B50l05QPC02d_:P2WZJ@08R@O00P:1@0B50l030h9
00/=200D5Q405aTD010B3@0D5Q405aTD010B3@0>3P`00P8000`<2P0B4Q005ADC00/;2@804A4?0P0@
40h200l?3@803Pl:00H03a0;014B3@0@4@`03Pl:00d>2@0>3`X300l@2`0300/;20071`D02`/90080
410>00D05aLE01dM6`0@40h04a<A01DE4`0200h>300>00`=2@0;3@P02P`700d?2P0@4Pd04A<>010B
3@0:30L030h9014C3P092`H03@l:01/M6@0D5Q<2018D4@0>00X<2@0?4@h04A<@01@F4`1OHEh07AlL
0001000<3P/03@l<00T;200G6AH04A<@00`>2`0B514200h@3@803a4>00X03Q0=00d?300@41006ATI
03<c<`1IFET06ATI00h>3P0<30`03@d=0`0@41008P0?3`l04Q<E00/<3P0<3@l04Q<G00h?4`0A4QH0
3a0E00d>4`0=3AD02PXB00P8400E5A`051DG01@F5@0E5aH04aDD010B4@0=3`h02`d<00h@3`0?4A00
3@l>00lA400A4a805aTF00X<2@031@807AlL00lA3P0=3``0418?00h@3@0?4@h2014C400300lA3_oo
oooooooo01;ooooo000Kooooo`0500`>2@0:30P01PP500l@4P0@4A@00P0<3A80=@0E5Q/02``A00H7
2`0<3A002@/:014B3@0A4P`03a0:00d>2@0;30L02P/600/;2P0D51<04a<C014A4`071`T0410B00h?
4`092Ph01`P<01DF6P0=3Q807QlS01TI7@0B4aL06AXN00h?4`0=3Q8030dA00d>400<3@l03@h@01DF
600G61X04A8D00l@4P0B4aD02``>010A4`0H6A/0D5=G07MnR00@5R803QDP00`C7@0B5Ql02PhG00hA
600K7240824V014@5P0H5a`030`A0080414E01T051DI024R9P0K7200414E01DF6P0@4AD04a@H014B
5P0?41@05aTN018E6P0@4aP04QDJ01<F6`0A5QT041HI00hF600=5AL041TK01<M7P0D7Ql04QPK01<G
6P0D61/05ATL00805a/N03T05QXM01@H6`0A5AP05QXM01PL7`0E6A`04QHL00X?5@0R9b/06QlR00dC
4`0E6aX07B<Q00@:200F71d0314E01dR9P1LHFP03a<D01TM700N8R<0310A01TM7P0B5QT01@P=020S
:00@4aX0A4M>061SJP0F6B4051LN01@G7@0D5ah07b8Z01lR:`0Y;CP06R4/01XP;@0G7B/051`Z01LN
;`0N9CP0;S5?05=FMP0T:DP082M301HQ>@0B7c80AE9T04iIJ@0M9c<072@`018J900L8b/06R4W01HN
8@0G7b800P0J8RD08@0F7R406b<V01DM800G7b806R8U01TQ900E7Al0=3Xj020V900H7Q`061hN01DK
700H7B005Q/O01DJ7P0H7B4061dS01DJ800G72D08bTf01PO;@0C6bL05AdX01HN9`0A6R405b0U010J
700B71h03aTI00lI600F7ah04QLJ01@H6`0201DI701<014E600?4aH05a/N010D5`0D61/05QXM014E
600A5AL05ATI01LK6P0F6QT051PI01<G6P0D61/04aHK01/N9@0@4aX05QTP01DH8@0B5Ah05QTQ01<F
700C5aT05AXG01@K4`0C6Q804adD01TS700C71/041PK00lH800D7BH041TR01PQ:P0=5Ad061lV00`D
600?5AP04QPH018F5P0B5a@04aPD01@I5@0C61H04QHG01<G6P0D61/04QHI014D6@0B5A/05APO01HI
8P0D5b005APQ01@F8P0D5ah04aLJ014E5P0@51@04AHB014F4@0B5a804aLE01@H600A5AP03a8G01<F
7P0=41D03A4D010D500W:bX09R/W00`A2`0C61804QLA014F4P804ADF0P0@51L01`0?4aH03Q8C00hB
4`0>4Q<041@C00dA400>4Q400`0@5A40500@5@l0318>00`B3P0>51003Q@B00lE4`0@5QH02@hA01XO
8P0<4AD02a0D00lD600F6b003Q8A00hC3`0J7a/07B8N01@I5@0B5a<03a@@100>4`l0200;40`03A8>
00lD400>4`l03A8>00lD400C61@041DA0`0A5Q80100@5A403a@@014F4P0@5A4200lD4006010E4@0A
5Q803Q<?028W8`0=4Ph04QLC0P0?5100300A5Q803a@@00lD400@5A403a@@00dB3P0?51003A8>010E
4@0=4Ph02a0<00dB3P803Q<?00D03A8>00/@300>4`l041DA00lD400200hC3`0600dB3P0M8Qh0;34]
018I4P0;4P/03A@=0P0?5Pl03@0B6A803aH?00hE3P0?5Pl041L@00lF3`0=50d03A8;014F3`0=4P/0
2a0900lD3@0>4``01@0=4P/05P0=4@/03Q0;010B3@0@4Pd03a4<014C3P0D5Q406A/F03m1?00G6A@0
3@l:01HH4`0A5100314;00dB300G71H0314;00X?2@0C61803Q<=00X?2@0;40X200dB300800dB2`0;
40T02a0900hC300@5@h03A8;00/@2@0=4P/200lD3@0:00dB2`0;40T071lH05IIDP0G6Q<03a8<01DH
4@0A50d03A0900hA2P@041<<00d05APA018E3P0=40X0OH1i09VLU@0G6Q@03Q4:010C300A50d03a8;
00d@2@0>4@X03a8;00803Q4:00/03A0900hA2P0?4P/03a8;018E3P0C5Pl03Q4:00d@2@0@4``03A09
00hA2P02010C300@00hA2P0=40T041<<00lB2`0=40T030l800/>1`0:3@H04Q@@04M9AP0J71P03@l:
00h@2P092`L03a8900hA1`803A0501/041<700lE2@0A6@h04Q`C020Z8@1NJ5l0Qi6801lY800>60l0
2aD<00LA20094`X03QP?00hE3@0U:2D01`T600d?300@4Pl02P`9010B3`0;3@X04A<@00d?300?4@h0
414?014C3P0?4@/00`0@4``05P0?4P/03Q4:00`?200=40T03a8;00hA2P0=40T03a89018E2@082`<0
41<800lB1`0@4`X02Pd400hA2P0J71L07R0K00d?300C5A804A<>010C300>4@X2010C308030l800@0
3A0900`?200>4@X041<<0`0?4P/0100H6a@02`h701DH4@0<3`P200lB2`07010C300?4P/041<<018E
3P0?4P`02`d800`>2@0200d?2P8030h90P0>40/04P0:30L02`d800lA300A4`h030h900d?2P0@4Pd0
3@l:00X<1`0@4Pd03@l:00h@2`0@4Pd03@l:00d>2@0B4Ph04A0<00l>2P803a0;01L03@l:00hC3@0>
4`d03Q<=00/B2`0:4@X02A09010D3@0>4@X030l8010C300A50d03Q4:01DH4@0@4``03Q4:00`?2@0?
4P/041<=014C3P0@4Pd04A<>010B3@0200h@2`803a4<0`0>40/0200=3`X0410>00l?3@0A4@l03`l=
00`<2P0@40h03`l=0P0@40h01@0?3`d04A4?01@D4P0C5A80418?00803@l<01003Q0=00lA3P0:30T0
3Q0=010B3`0A4a00BD]807=eLP0>40/03@l:00lA300@4Pd03a4<00/=20092`H03a4<0P0;3@P04`0@
4Pd07R0K05]MF00B50l03a4<014C3P092`H04A<>00lA300A4`h030h900lA300A4`h030h900/;2@0P
81h030`:00l?3@0<30X00`0@40h200l?3@803Ph<00<03@h9014B3@0A4Pd00P0?40/00`0A4Pd03Pl:
00l@2`03010A300@00l?300?3`d04Q8@014A3`0<30X03@d;018B400D51802`/9010@3P0A4@l030`:
01<D4@0=3`X02`d800`>2@803Q0;00@03a4<00T;1P092`H03a4<0P0<3PT0500B51007AlL010B3`0@
4Pl04Q@A00P:1`0@4Pl030h;01`N6`092`P05aTF00d?300>40d030h<01/M6`0H6QL03@l<014B400=
3``03Q0=100@4Pl0200D51@06a/K020P800X:2P020P800l?3`0=3@d03Ph>100?3`l0900>3a402@X<
014B500F5a/020T=01@E6@0G61d04a@I014B5`0C4a/04A4I00d>500<3@l03Q0?014C4P0B51<0418A
00h@3`0B51<07b4P01@F5@0<3Pd04A<B00lA400<3P/0418?00d?300K7AX0418?00d?300C5A80418?
00d?300?4@h04Q@A00d?31Cooooo000Kooooo`0=00P:1@0?4@d02P`900@51`0?41@05AHK010A5P0=
3Q<02``A00/<400=3Q403a4@00/<1`0200d>2@1:00/<1`0;2`P03@d;00`<2P0G5aH030`<00X:2P07
1`L02PX<01<D600B4aL03a0D00/<400W:2`0M7Ei08:3Q`0:2`l04Q<G014B5P0:2`l04A8F014B500<
3@l02``>01DF600G61X04A8D01<D5P0D5AL030d?00l@4P061`T0=CTl04U?F00941X000<=00/?6@0@
51d0720Y00/>5@0D5AX05QLL00X;400G61d04a@H01HG6`0G61`051DI01PI7@0E5QX03@hB014B5P0@
4AD03a0D00`=4@0B4aL06ahQ01@H6`0B5QT05ATL01HJ7@0A5QT03aDH00lG6@0>5QP03aPJ010J6`0?
6AX04QPK01DI700D61/04aLJ010D5`0?4aH201<G6P0e010D5`0E6A`061`O01@H6`0B5Q/082D[055F
FP0?51L03aDE018H600=4a<03Q@D01XO8P0>4aL082DY030e>P0L82404aLF01dQ8P0F6Q/061`M01LK
7P0V:Rd04aLJ01HI7P0520d04QDJ01hQ:00K7b804ADH01TM8@0Q92T07R4X020T;00J8BT061lY01DK
9P0A6B@05AdZ01dT=01=DF`0NGfJ03DjE`0L8cd0<CaB01l/?`0G93D08Rdm024[=`0=5B007RD`01LN
9P0C6R000P0G7b802P0F7R405alR01XR9@0H82<05AdP01<K7P0E7B00620S01LO8@0F71`2010F5P06
014F6@0?51L03Q<F01@I7@0@5AT04aPL0P0D6Al0200J7RL04QPT018H900C6BD051XV01<J8`0?5Qh0
5ahT0P0A6A`03@0@61X04AXI01DN7@0L8B@06AdP01PL7`0E6A`03a<F00`@4`0C5aX02`lB00lC5P0D
61/00P0B5QT0100B5QL051PI01@H6@0B5QL2014E600N01/N8`11A4T041<H01<F7@0J7B@03a8I014E
6@0?4a@03a<B014F4@0@5`l03aH>01DO5`0D7AX04Q/M01hW;P0?5b804a`V00hG7P0D7B@04QXR02he
>`0P:2/051/N01<I6@0B5QD04AHC018G4`0C61@051PH0`0C5aX06P0B5QT04A@I01@G700D5a`04QDL
014D6`0B5A`05APQ01PK800D61T041@E00lC4`0@5A403a@@014F4`0D61L051PI018E6@0@4aP04QDM
01@G700>4QD04ADE03Hj>@0j?c/04AH@0P0C6180100C61@04QHG014E5P0B5QT2010D5`0=00lC500>
4Q<03a<D010D4`0<40l03a<B014F4P0@5A403a@@014F400;4@d0318>00`B400200dC4@0@00hD500?
5AD0;38b01<H6`0730l051TL00/@4`0A5A@02a0<00dB3P0A5Q805Q/G01/P700@5A404AHB010E4@@0
3a@@0P0A5Q801@0?510041DA01<H500?510041DA00<04AHB00<03a@@010E4@0?51000P0=4Ph09`0?
510041DA01/P700:3`/04QLC024V8P0C61@05AXF010E4@0>4`l03A8>00hC3`0<4@d02a0<00X?2`0?
51005AXF01<H500<4@d03A8>00lD400@5A403a@@00dB3P0?510041DA00lD400;40`03A8>00`A3@0>
4`l051TE00T@2@073PL02a8;00`C30083`P02A0900hE3P0200`C300300lF3`0>5@h03A@=00803Q<<
00@0314:00lD3@0B5a0041D>1@0?50d0500>4P`03Q0;010B3@0?4@`03Q0;00lA300D5Q401PP3028T
7`0620<04Q@?00d?2P0930T03A8<00X?2@0G71H08RLQ01TN600J7aT06AhH0P0?50h200dB300B014F
400730D02@h701/P6@0B5a003A8;014F3`0@5@h04aPA018G400@5@h03A8;00/>1`1ZKFH02P`800T<
1@0C5Pl01PT40P0<3`P04@0>4@X03a8;014D3@0C5Pl020/40085000A50d041<<02T/9@0L7aP03Q4:
010C300A50d03a8;00d@2@0>4@X03a8;00803Q4:00P03A0900hA2P0?4P/02@`500hA2P0D5a004QD>
010C30803a8;01403Q4:00d@2@0=40T03Q4:00lB2`0A50d041<<00lB2`0>4@X03A0900`?200B50l0
1@L301dO6P0A4`h04aH?01TL5@03010C2P0<014D2@0B5@X041H:00dE2P0L8a/0TIR@0?Kmm@3=e<`0
?D@l01TP600A610031<;0P0;4PX0100:4@T0310<00X<2@082PL200lA3P0800T;200>40h02`d:01<E
4P0A4a00=SPe010B3@0=3`T300hA2P0F00d@2@0<3`P05QTB00X=1P0?4P/04aH?00lB2`0=40L020/1
00lB1`09304041<:014D2`0=40L03A0900hA2P0?4P/03@l:02HX8`0T9R403Q4:00`?20803A0900X0
30l800d@2@0>4@X03A0900hA2P0?4P/03Q4:014D3@0F6A8092LP0P0H6a@0200?4P/041<<00`?200>
4@X04A@=01@G400H6a@051LA0P0>40/07@0?4@`03Q0;00d?2P0@4Pd020X500/=200B50l00`D001@F
4@15Ad807R0K0084000<3PT02@/601<E400A4`h03@l:014C3P0E5a804A<>00d?2P0B4`h0414<00h?
2P0?40/0414<00h@2`0=3`X03Q0;00803A8<00/0314;00/B2`0>4@X041<<018E3P0?4P/041<<01DH
4@1?DT/0UiZC02d`:@0201PK500700hA2P0A4`h03Q0;010B3@0?4@`030h901<E400200d?2P803Q0;
0P0?4@`02@0@40h03`l=01<C4@0A4@l030`:010@3P0B4Q003@d;00l?3@0201DE4`0=00h>300@4Pl0
3Q0=00`>2`0=3``0418?01<E4P092`P03Q0=01<E4P0;3@X06adJ01dO700200lA300M00h@2`0=3`X0
3Q0;00lA300:30L030h9014C3P0?4@`030h900H80`0:30L03a4<018D3`0C5A0030h900H80`0@4Pd0
4A<>00h@2`0@4Pd04A<>00h@2`0C4a40?3`j01/K6@0<30X02@T701/K6@0?3`d00`0>3P`200d=2`08
00d>2@0A4Pd04A8=00h?2P0?40/04Q<>00`=200=3PT300h?2P0400`<2@0<30X03`l=010@3P803`l=
00<030`:018B400@40h00P0W9bD02P0?3`d04a@@01@F4@0@4Pd03@l:00`>2@0;3@P030h900X<1`08
2PD300`>2@0D00lA3@0H6QL05aTF00X<2@072@H030h;00d?300620D09BLT014C40092`P04aDB00`>
2`0?4@h061XG01XL6@0?4@h02@/800/=2P0<3P/200h@3@0500lA3P0>40d03@d=018B4P0@41000P0=
3@d03`0<30`051@D01<C4`0A4A403`l?00d=3@0<30`020X9018D4`0N7b405QLI01<D5P0<3A403PlC
00l@500200l@5@04010A5P0B4aT03a0B00h@3`803@l>01@04A<B01@F5@0F61L09BLV01LI600=3`h0
4Q@C00h@3`0N81d08B<P00d?30092`P03a4>01LI5P0D5Q<05QPE00lA3P0>40d04A<@00/=2QCooooo
000Kooooo`0o00`>2@0D5Q803a4>00@51`0A4QH04a@I00l@5@061``03a0E018C5`092Pd02P`;00@5
000:2`D02``700X;1P0<3@T04A4?00h>301SHf8071`L00P8200Q8B403@d=018C5P061`/0414E00l@
500E5QX0ADI:02X[;`020`L03a0D01DF6P0;31002P/?00h?4@0A4Q@04Q<E01HG6@0A4Q@020T;014B
500B4aD02``>00l@4P0000805ATL018H7`0E72H04APP01PL9@0000T000<<014D6`0?41D05aPM01PI
7P0=3Q<0414F018C5`0C51P04Q<G00804A8F00L0414E00d>4P0K72005QLK00X;3`0G61`05aTM0080
4QHI04d051PK01<G6P0?51L03aDH010H6P0?5aT03aPJ00hH6@0<5QL041HI01<G6P0B5QT04aLJ010D
5`0A5AP051PK01<G6P0A5AP05ATL01HJ7@0D61/051TL02<X;01<DED04QLJ01lT9`0D6QX04ALG01HL
700L8B@0724U01HK7`0?51T07B4R01@H5`0P92D04ADF010D5@0W:bh05ATL00X>4@0:3A80:B`a018E
6P0P8bP0C51A02@X:@0A5AL06AdP01`O900F6b006B0V01TP:00G7RL05AhW01LO:P0M93807B4j03Pl
E`0D6SD01`lV01<N<P0=6R/0:CI6028^>P0/=T802Q8M01dT;`0@5al05A`R01TQ900H82<04a/N018J
7@0G7b8072@W01/S9P0201@L7`806R8U050061dP01LM7P0I7R406QlR01LL7`0B5aX05AXN018G6`0E
6Qh05Q/Q01LL8P0L82T02Q4K00lE8@0D6bD04aXT014H800@5ad04aXP010H6`0>5QT03QHH010I600B
6aX06AdP018F6@0?4aH04ADH01TM800M8B@07R8U01<G6P0B5QT04ADH00lC5P0A5AP04QHG01DI6P0D
61T04QHG014E600B5QT0:B`a06MZK`0R9BX05APO01lR:@0P8bP051PJ01<G5P0D6AD05Q/E01<J4P0A
61005AlH00H?3P0J8RH0GVM`03<kAP0>5R003QLN018K8P0A6Ah0;3@g01dU:00C6Q/04aTI01<G5P0B
5a@04QLC01<H500D61P05ATL01@H6`0C5aX04QHI018E6P0C5Q/041<H00hA60803a8I00D04A@K01DH
7@0?4a@0310A00lC4`0201<G5P0;014E500A5AH04ADH018E6@0D5a`05QTP00lB5`0?4aH0310@01XN
7@0H7AT00P0?50h01@0@5@l04AHB00hB4`0=4A803a<F008041@G0`0?4a@01`0@51<03Q8A018F5@0E
6QH04QLC014F4P0D6A<00P0=4`l300dC4@0<00dC4`0F71`0<3Hf014F6@062`h05a`O01<I6P0?4a80
3Q<?014F4P0B5a<04AHB0P0>4`l01P0@5A404AHB00lD400=4Ph03Q<?00dB3P8041DA00D03Q<?00lD
400@5A403Q<?010E4@03014F4P03010E4@0?51003a@@00803Q<?0P0?51005@0<4@d051TE00T>2P0:
3`/04QLC00T>2P0?51003A8>00`A3@0>4`l03A8>00/@300=4Ph04QLC01TN6P0H7AT04AHB010E4@0?
51004AHB010E4@0200lD4007010E4@0>4`l02a0<00hC3`0;40`01P/700L<200200`C3007018I4P0A
61402a8;00XA2P0=50d02Q4:00/B2`0200dD3@0600`C300?50d03A8;00`A2P0C614051TB1P0?50d0
800>4P`03Q0;010B3@0?4@`03@l:00h@2`0B50l02@/601@F4@0B50l02@/600/=200F6Q@03A8<00/@
2P0A5Q0061dG00hC3@0?50h041D?00T>200@5@l03Q<=00`A2`0?50d01@X300H;100H7AH04QL@00dB
2`0?50d03A8;0P0?50d02`0>4``0314:0085000L7aP03A0:00hA2P0D5a005APA014D3@0@4``03a8;
00803Q4:00@03a8;014D3@0?4P/04aH?0P0E614020092`L03Q4:010C300A50d03a8;00d@2@0>4@X0
3a8;0P0>4@X02`0=40T03Q4:00lB2`072P<02@`500hA2P0@4``04A@=00lB2`0@4``03Q4:008030l8
00<03Q4:010C300=40T00P0=40T300`?200700/=200?4@`01PP300hA2P0:30P03a8;00hA200200lB
2@0M00lB1`0@4`P03Q@:02L/9@0O9Qh0H6MO0=;Id@32al405A`D014H400>5@d03A@<00/B2P083`L0
3QD=00h@300H6QL04Q@A01DG500G6AH03@l<00h@3@0<3P/020X700lA3P0H6QL051HA00`?200=40T0
0P0>4@X200`?200C02X]9P0=40T02`h700lB2`0<3`P03A0900`?1@0N8AH030l4014D2`0>4@P03A07
00`?200;3PL030l8014C3P0M7aX061XE00hA2P0200`?200?00d@2@0>4@X041<<00hA2P0=40T03Q4:
00lB2`0>4@X02`h700`?200L7aP051L@01<F3`0;3PL04A@=008030l800@03Q4:010C300A50d04A<=
0`0@4Pd03P0?4@`03Q0;014C3P092`H03@l:01@F4@031@005ALB04mAC00V:2<02P`7010B3@031@00
20X50P0:30L0300E5a807R0K01PJ5@0>40/04a@?014B3@0>3`X03a0;010A300>40/030h900d?2P<0
3A8<00l0318<00X=1P0>4@X04A@=00lB2`0A50d06QdF09^NU`3en?40?3lh0085000I71D061/D00h@
2`0:30L00P0>40/010092`H04Q@?00d?2P0=3`X200h@2`803a4<00T0410>014A3`0E5A<04a<A00h>
300A4@l051@B00d=2`0<30X00P0A4@l00`0:2PP03Q0=00d?300200d?300<010B3`0B51405QPE00`>
2`051`@0008001HH5@0K7AX0418=00lA300>40/03a4<0P0@4Pd02`0B50l02`d800d?2P0A4`h06A/F
00h@2`0I6aH06adH00d?2P0<3PT051HA00L0418=00H03`l=028R800C4a403Ph<00/;2@0?3`d2014A
3`80410>0P0?3`d00`0=3PT0414<010A300200l@2`0:010A300<3@P03@h900d>2@0>3`X03@h900`<
2@0>3P`0410>014A3`8051@B00T03`l=00`<2P0;2`T07AdK01lO7@0@40h0414>018D3`0?4@`00`0>
40/00`0=3`X030h900`>2@0200/=200500`>2@082PH02`d:024S800M7a`00P092`P040082PL051HC
01lQ7P0?4@h01@L400d?300;3@X07b4N03<e<P0E5a@01PP501XL6@0;3@X030h;00d?300>40d200d?
3006010@400:2PX051@D01hN7P0<30`03@d=0P0B4Q802@0A4A403`l?00l?3`0@41002`d<01LI600Q
8R@05QLI01PI6`0200`=4@0M014B5P0?41D02P/@00d>4`0A4QP030d?00h@3`0A4a804Q@C014C4P0>
40l030h=01LI600?4A002P`;00lA400>40l010H300`>2`041P<01PP501@F4`0A4a0030h;01HH5@0@
4Pl030h;010B3`0=3``05?ooool001_ooooo01403@l:00T;200?4@h051DG02@U:00:2a00414F00h?
500<3A802``@00/<3`0<3Pd05ADC01TJ5@0F5a803`l=00d=2`03010@3P0B00h>300@40h020P600d=
300=3Pl02P/=00h?4@0;30h030d?00d>400>3a404A8D00X;3@0?41802P/=01@E5`0>3a404Q<E0P0@
4A<0=@0?41802``>00h?4@0D5AL03PlA01DF600@4A<03Q0D00/?5@093QD02PlE00dB600?4QT04aHM
010C6P0:3A803Q4F01@G700?4QL0<C<h01@E6@0<3A405AHJ014B5P0@4AD05QLK00l@500e=SX0;Bhb
00d>4P0M7R803a4D010D5@0D61T04aLI010D5`0?51L04ALJ014I6`0A6A`04Q/M010J700>61X041HI
014E600C5aX06AdP01DI700D61/05ATL01<G6P0D61/05ATL00804aLJ00H041@H010E6@0D6A`051TL
01DJ7@0@5AP201LL7`0701HK7P0E6Qd06AhQ01LL800>41405ATJ02T];P0301LK700O01LK7P0C5aX0
61`O04mCEP0F6Q`07b<V03/o?`0H71/04QHF014E5P0B5QP06QlR01<K7P0D720061lV01HO9P0E7RH0
5b0Z01HK<00J7cH07bDm01/S>@0L:3X082hl01/X=`0A7BT072Ha018J9@0D6bH05A`T01LN900201DM
80805QhQ00L051`O01TQ900G7b804a/N01PP8`0O9bX05QhQ00805a`P0P0E6Qh04@0D6Ad04AHJ01DJ
7P0B5a/04aPL01<H7P0B5ad05AXQ010G800?5Ql04APP01<J8P0D6b804QTO01<K7`0C6ah04ATL0080
4QXL01804QTK01<G6P0G6ah05a/N01DI700I7B007R8U01lS9P0F6Qd04aLJ014E600F6Qd07B4T01DI
700H71l05a/N01DI700D61/201DI700H0413B00=41D051LL00lB5`0B5QT04QLE01@I500F6aD061dG
014H4@0>50l04AXF01`T9P0@61h05AhW00lG8P0@6B802aDH018L7`0<5AL0620R00lG6@0B6AX04aTI
0P0E6AP01P0C5aH04QLC01@H600E6A`051PK01<G6P804ADH02/04QDI010C600B5AX061/P01<F6P0B
5AX04aPK00dC4`0;4A4041HF01@J6P0A5aL041HG014F6@0@5AT04QLK01<H700D6Al04A@I010D5`0<
41004aLF00/@300B5a403a@>014F400B5a<03Q8C00dA4P0?4aH04ADH010D5`0@51D03a<D010D5@0A
5A@02`l>00lC4P0C61@03a@@00dB3P0B5a4041HC008041HD0P0=4a4200`B400601HL6P0;4A004ALG
010F5@0B61P03a@A0P0A5Q801`0B5a<04AHB00/@300<4@d04QLC01@I5@0A5Q800P0>4`l01@0<4@d0
3a@@00lD400>4`l03A8>00803Q<?00<041DA014F4P0A5Q800P0A5Q801@0?51004AHB018G4`0B5a<0
4AHB00803a@@01807b@P00dB3P0=4Ph0:BhZ01@I5@0?51003A8>00hC3`0A5Q8041DA00hC3`0A5Q80
41DA01<H500A5Q803Q<?010E4@0=4Ph2010E4@0;00hC3`0=4Ph03Q<?00dB3P0?510041DA00`A3@0?
510061dI010G400?5Pl00P0D6a@03@0?5Pl03QD>00lF3`0;4P/02Q4:00dD3@0>5@h03A@=00lD3@0C
614041D>014F3`0?50d01`0<4@X03@0=4P`03Q<=00`A2`0;40X0314;00lD3P0k@3X06QlJ00dB300@
5@l02@h8010E3`0<4@/00P0=4P`0400;40X092TS02/`:P093PP02a0:01`Q6`0E6Q@0314;00/@2P0C
61403a@=00X?200N8a`07B8K00dB2`0;40T300`A2P0J00dB2`0E61402`h700lB300>4@X041<<00`?
200B5@h04A@=00lB2`0=40T03Q4:010C300?4P/051L@00`?2@0G6Q<03Q4:00d?2P0>4@X041<<014D
3@0?4P/03A0900hA2P0?4P/200hA2P0:00d@2@0>4@X03a8;028U7P0I71D03A0900`?200>4@X02Pd6
00d@2@@03a8;0`0=40T03@0>4@X03a8;00lB2`0@4``04aH?03Lj<`072P<06QdF018E3`0930D03A09
00lB2P0?4PT00P0@4`X02@0>4`T010T303Y1>@0Y<2P0;SD]03Hm=@0F7AD03aH>00XA2@0300`C2`07
01DK500<3PT02`d800d?2P0;3@P02P`700`>2@0200h@2`0600T;1P0?4@`01`T501<E400>4@X03a8;
0P0@4``200hA2P0E01PK500930D03A0900hA2P0;3PL041<<014D2`0_<RT041<:014D2`0<3`P03Q4:
01<F3`0D5a0030l801<F3`0;3PL03Q4:014D3@0B5@h041<<00803a8;01@041<<00lB2`0=40T03Q4:
00lB2`0=40T03a8;00X=1P0B5@h03Q4:018E3P082`@04A@=010C300<3`P03Q4:014D3@0>4@X03A0:
010B3@804A<>00<03a4<00h@2`0>40/00P0@4Pd04P0;3@P02P`7010B3@0F61<00`D100d?2P0>40`0
2P`7018D3`0L7QT051HA014C3P0D5Q404Q@?00h@2`0B50l0418=00h@2`D03a4<00h0418=00dB300<
4@/02Pl901<F3`0@4``03A0900lB2`0@4``04QD>02X]9P1<CdP06ahG010C30803a8;00H03Q0;00d?
2P0H6QD05aTD00`>2@0?4@`400h@2`803a4<00D04A<@01<E4P0G6AH05ALD010B3`02014C4005010B
3`0<3P/02P`901<E4P0O8Ah00`0>40d200d?300E00`>2`092`P03a4>014C400:30T03Q0=00P:1`0?
4@`030h900d?2P0@4Pd04Q@?00lA300=3`X02`d800h@2`0;3@P07R0K01<E400;3@P030h900803@l:
00h03a4<018D3`0>40/03@l:00lA300>40/03@l:00lA300>40d020X701DG500=3``04A<@00/=2P80
3a4>0P0>40d200d?300500l@2`0=3PT03a0;018C3P0@4@`00`0>3`X0100?40/0414<00l@2`0>3`/2
010@3P0=00h>300C4a404Q8@010@3P071`D02`/900d=2`0;2`T04a<A014B3P0?4@`030h900d?2P02
00h@2`0;00d?2P0?4@`04A<>00`>2@0:30L03@l:00lA3@0=3``07AlL02HX9@0A4a000P0=3``00`0C
5A802``:00h@3P0200lA3P0600d?30092`P04A<@010B3`0E5a@02P`90P0?4@h07@0@4Pl03a4>00h@
3@0=3``03Q0?00`>3@0@4Q402P`;010B4@0B51<0418A00lA400=3`h030h=00d?3P0?4A00418A00d?
3P0@4Q404A8D00T:300@4A<030dA014B5P0?41@03@hC010A5P0=3Q<0414C0080418A00<03a4@00h@
3`0<3Pd00P0=3`h200lA400;00h@3`0@4Q405aTF010B3`0?4@h0828O034c<00>40d030h;020R7`0I
6aP00P0=3``00`0<3P_oooooooooo`0Booooo`006oooool0300=3`X02@/700H81@0J6ad0@D9600d>
4`082@h030dB00d>4`041@T03a0C00h@3`804a<A00D04Q8@010@3P0<30X020P600d=2`0200`<2P0:
00d>2@0>3`X03`l=00T;2`041@L04a@F00P92`0Z:bd0HfAV00l@4P803@h@00l03a0B00h?4@0=3Q00
3@h@00/<3P0?4180414C00d>400?41804A8D01TJ700P8B<08b@V03Hg>@0I6Qh01P0?4QL02P0@4aP0
2PlC00hC5`0;41H07B8X02`^<`0I6Qh05AHJ01<D600B4aL2014B5P0301<D600E5QX04a@H0080414E
00l04A<F018F5@0C5aH04QHF01<G600D6A`04APK00/C5P0@61/0620T00hG70094QL041HI01DI700D
61/00P0E6A`0200C5aX04ADH018F6@0D61/05QXM01@H6`0B5QT051TL0P0E6Qd01`0C61/04AHI01LL
800T:Bd05AXN010E600G71l00P0C61/01P0D61T04aLH018F5`0A5AH04QHG01DI6P<041@E00D04QHG
01DI600I7Ad05a/J01@I5@02018F5@0I01<G600C61/06R8U01XR9@0?5Q`05AhU00083`0J8R/07R<f
01/P=00L8SL07BDh01l[>`0X=T<062Hc01TU<@0J92h06b<^01`T;@0M92`072<Y01HN8@0J8RD08BT/
01dU:00200hF6@0>01DM800D71l03aLJ018J7@0M9BP07B8X01HK8@0>4aT06AhT00lD6P0T:Bl07b@Z
014F6`0J7b<201@I7@0E01PM8`0F6b405Q/Q00lD6P0>4aT04AHL00lD600H7B403A8E01<H6`0>4aH0
6b0S014F6@0F6Qd09RX]02<W:P0>4QD05ATL01TM800E6A`051PK00804aLJ0P0B5QT01`0E61d05aXO
01XM8P0F6Ah01`/>01lS9P0S9bX00P0D61/07P0J7R405ATL00dA4P0A5Q409R/U07UnN00K81X03A<?
02/a;@0=5Q@05AdO01@L8`0F7bP08b/f00hG7P0B71d041XK014J700A6QT041TH00lF5P0?5AD04ADD
01<G5P0E6AP05QXI01HJ6P0E6A`051PK01<G6P8051PK02L04QHI01DI700L82<03Q8E01HJ6`0>4QD0
5Q/K00/D4@0:4a8031DE00P@4P0;4aD03aLJ01LO8P0941H03QDK00dD6P0=4aP041<H00lC5P0?4a<0
4ADD018G4`0A5Q004aPB00lD3P0=4Ph051PI00/?400G6ah04QHI01XN8@072``05ATJ00`@4@0D61L0
4QHE014E500@5A400P0>4`l01P0=4P`03Q@B00dC4@0=4a403aDC010F50803Q@B01403A<A00dC400=
4a403Q@@010F4`0A5Q803a@@00X?2`0>4`l02Ph:00hC3`0A5Q805AXF028W8`0M8Qh03a@@01DJ5P06
00lD40804AHB0P0@5A4200lD400=00L<200A5Q804AHB014F4P0<4@d00`P400hC3`19CTX04AHB00/@
300A5Q805AXF010E4@0500lD400600hC3`0@5A404AHB00lD400;40`02@h:0P0@5A4200lD40@03Q<?
01@03a@@010E4@0@5A4041DA01/R6`0H7aP041L@014H4@0H7aP09bhW00hE3P0:4@X02a8;00hE3P0<
4``02A0900`A2P0C61405Q/D01<H4@803Q<<0P0?50d09`0>4``03A8;00dB2`0<4P/03aH?014H4@0>
5@h01@`501HM5P0@5a00U9^D05=JD`0C6Q<01@`501PO600=4`d04AH@00lD3P0<4@/02Pl902T^:00c
>38000D002P]9`0Y;RP02@h801LL5P0<4@/08BHO00/@2@0@5@h0IfaU051ECP0=4P/01``500/@2@0D
6A803a@=00L<1@03010C300300lB2`0>4@X03Q4:00H03A0900H04A@=010C300>4@X03A0900hA2P0A
50d3010C30803A0901<041<<018E3P0A50d03Q4:01PK500m@3T061/D02HY8P0J7AH030l800lB2`0B
5@h03Q4:00/>1`0@4``03a8;00T<1@0:3@H041<<00803A090P0<3`P200hA2P803A070P0>4@P01P0?
4PX03a8;01PK500:3@H04A@=00P;10802`h70P0>4``0200@5@h03a@=01DJ4`0U:R<07b@M00X?200=
4P/04aPA0P0=4P/06@0j?CH04QD>00P;100@4``02Pd600lB2`0;3PL04aH?018E3P0=40T03a8;01<F
3`0=40T03a8;01DH4@0<3`P03Q4:00/>1`0@4``03A0900`?200=40T03a8;010C300:3@H00P0C5Pl0
3`0=40T030l800hA2P0`<b`0?D0g01<F3@0A50/03A07018E300a=2d03A0900/>1`0?4P/03A09010C
300200d@2@0G01LJ4`0C5Pl03Q4:00`?200B5@h05QTB014D3@0@4``03a8;014D3@0D5a005APA00`?
200930D03Q4:00lA2`0A4`h03a4<00T;1P0?4@`051HA018D3`0?4@`00P0>40/04`0?4@`04A<>010B
3@0B50l030h9018D3`082PD0418=01/M600<3PT0418=014C3P031@0051HA00L<1P0:3`T01P/601<E
400I6aH00`0@4Pd01@0?4@`0418=018D3`0E5a803Q4:00803A0900H041<<018E3P0A50d04A@=010C
300>4@X300/>1`80418=00H03a4<00h@2`0=3`X030h900lA300<3PT200X<1`0?00h@2`0A4`h051HC
00T;200E5a@02`d:00`>2`0G6AH030h;00d?300?4@h03Q0=01DG500V:2D03a4>008030h;00<0418?
00lA3P051`@00P0@4Pl200h@3@0=00d?300<3P/0418=010B3@0?4@`03Q0;00`>2@0:30L0418=00lA
300<3PT02P`700`>2@0200h@2`<030h90P0>40/0100=3`X02`d800/=200=3`X200h@2`0<00h@3@0;
3@X04Q@A00d?300>40d030h;018D4@0G6AH03a4>00d?30031@803@l<0`0>3`X03@0@4@`04A8=014B
3@0A4Pd051D@010A300>3`X0414<00`=2@0=3@/03`l=010@3P0>3P`00P0=3@/0600A4@l04Q8@00/;
2@0;2`T03@d;00l@3@0?4@`030h900X<1`0;3@P03a4<014C3P0D5Q4061XE00P:1@0=3`X01PP3014C
3`0=3``03a4>014C400@4Pl03a4>01@F4`802P`901L03Q0=00L91P0=3``051HC00T;200C5A802P`9
014C400>40d030h;014C400?4@h03@l<010B3`0<3P/03a4@00P:2@0;3@`0418A00D71P0A4a8030h=
00h@3`0200lA400:010B4@0D5QD06adJ018D4@0C5A8051HE00`>3@0@4A<03PlA01DF60803a0D00@0
3@hB01HG6`0E5QP04Q@C0P0=3`h0100E5aH071hM00d?3P0A4a8200lA4008010B4@0;3@`01`T601<E
4P0=3``02@/8010B3`0?4@h2018D4@04010B3`0>40d03@l<00`>2aCooooo000Kooooo`0=014C3P0:
30P03a4>00X;3@0F5aX03a0E01hO90061``05AHK01DF6P0>3a802@X<00l?3`02010@3P803`l=00D0
3@d;00/;2@0;2`T02`/900`=200200d>2@0700d?3`0B4aD03PlA00H72@0B4aD08B8T00l@4P0200d>
400300l@4P0>3a403@h@00803a0B00/051DG01DF600@4A<0414C00`=3`0E5QP05aPJ014B500Q8R@0
2P/=00hB5@0500hA5P0600lB5`07310051TM01@I7`0=4QP0310E0P0;3100100@4AD04a@H01<D600B
4aL2014B5P0D01<D600D5AT05AHJ01<E5P0A5A@04QHE018F5P0C5aP051TL01DK7P0B6Qd05alR01hV
:P0F7b@04Q/P01<I7P0A5AP03Q8E00lC5P0C5aX201@H6`0401DI700G6ah06AdP01LK7P805ATL01L0
4aPK01@I700B5aX03a@G01DJ7P0V:bl06b0T01TN8P0N8bH05a`O01HK7P0E6AX051PI01<G600A5AH0
4QHG01<G600B5QL04ADF010D500A5A@04QHE01DI600200hC3`0`010D4`0B5QD04QHG010E600A6A`0
4a/N014H7P0H8BP00``C028Z<`0I7bl04AHY01/R=@0P:CX04Ad[01`Z=@0B82/05B4[01LQ:`0G82T0
5AdV018I8@0J8BL0620S01/S9P0N9RT06R8U010H6`0E7B00620S01TQ900H82<06b<V01lW:P0l@DL0
5QXR02@Y;`0R9bd0724W09:GW@15BU005a`Q010E6@0N8bL04AHJ01TN8P0A5Q`05AXP0P0B5ad04@0E
6Ql04AHJ00dB5P0>4aH06AhQ010E600F6ah020d@01DI700B5QT06AdP01dQ900F6Qd02@d@00lC5P0@
51L04ADH00804aLJ00H051PK01DH7@0;3Q<06QdR0454B@0W:bh201TM800J01@H6`0C5aX051PK018F
6@0@51D05a`G028W8@1GG5H05a`F00`B3P0H7Q`04AXI00041`14C58010dF018K900D7B803QPG00hH
6@0A6QT04a`K014J6@0@5aL041HF018F5@0C5aH201@H5`0301DI6`0C5aX04aLJ00804aLJ0P0D61/0
5P0@51L04ADH018F5`0T:2T051PI010F5@0:4a002a@C00hF5`0B6Q`041PK00`D5`0Q:2h02Q4G01@K
8@083aD061lT01@H6`0B5QT04ADE018F5@0B5a<200lD3P04018G4@0=4Ph05a/L01@H6@80310C00/0
9b/^01HJ6`0=4A8020`=00L9200A5A@041@C010E4@0?51003Q<?00hC3P0200`B400300lE4`0B61H0
4ALE00803A<A0P0=4`l200hD4007010F4P0C61@0314=01@I5@0A5Q803A8>01dR7P0200dB3P0401HK
5`0B5a<020d9014F4PH03a@@0P0@5A4200lD40803Q<?00l04AHB00@91@0O920041DA00hC3`0C61@0
3Q<?03Ll>00N8al06QlK00hC3`093PX02Pl;00/@300<4@d00P0=4Ph00`0>4`l03a@@00lD400200lD
40803Q<?00<041DA00lD400?51000P0>4`l0100=4Ph03Q<?00hC3`0?5103010E4@07010G400?5Pl0
2A0900/B2`0<4``05ahG00hE3P0200/B2`0:00dD3@0<4``02A0900dB2`0C614051TB018G400=4P/0
3Q<<00lD3@803Q<<0P0=4P/00`083PL02a8;01DL5@02010G400O00dD3@052`D0<CPa00/B2`0940T0
00@0010G400F71D010T30002000J7aT04QLA00P=1`0@5@l00PL101TN600N8ad02a0:01HK5@0@5@h0
3A8;0087000;40T05Q/D010E3P0=4P/04aPA018G40052P<00@H0010E3P03010C300300lB2`0>4@X0
3Q4:00H03a8;01/06A`E01LJ4`0B5@h03Q4:00d@2@0>4@X030l800lB2`0A50d03a8;00hA2P0@4``0
2@`500`?200>4@X020/401hQ6P041`404A@=00hA2P0B5@h06ahG01HI4P082`@03A09010C300>4@X0
0P0;3PL0100?4P/041<<00lB2`0=40T200`?200300d@2@0=40L03A0700803Q4800P03a8:00lB2`01
100061/D00`?200D5a005APA010C30803a@=0100314:00X?200@5@h05Q/D01DJ4`0:3`P041D>01<H
4@0<4@X03a@=02lb:`0@4``03a8;018E3P0?4P/041<<0P0=40T200`?200?00hA2P0?4P/04A@=00lB
2`0930D03a8;01HI4P041`0041<<00d@2@0<3`P03A0900lB2`0@4``03A0900804aH?00H03a8;00hA
2P0?4P/05APA01/N5@0;3PD2010C2P0601TL4`0h>c@06A`E01@G400B5@h03Q4:0P0=40T01`0@4``0
5APA00hA2P0<3`P03Q4:018E3P0E61400P0B5@h03`0C5Pl030l800<6000Q91d07B0I00`?200F6A80
20X400lA300C5A004Q@?00`>2@0;3@P030h900d?2P0200`>2@0D00d?2P0>40/03a4<00H80`0:30L0
30h9010B3@0;3@P01`T400lA300>40/02`d801TK5P0^<2/00@H0028W8@062PD02P`701@F4@0?4@d2
00h@2`803a4<00P04A<>01<E400>4@X03A0900hA2P0@4``04A@=010C30803Q4:100=40T2010B3@05
00lA300=3`X03@l:00`>2@0;3@P00P0<3PT0200=3`X03a4<010B3@000P004aDB00L91P0H6QL0418?
0P0B5140300?4@h03Q0=00`>2`0=3``05aTF010B3`0=3``02`d:00h@3@0?4@h02P`900d?30D03Q0=
1P0=3`X0200;3@P03@l:00h@2`0>40/02`d800X<1`0<3PT03Q0;0P0?4@`01@0<3PT02`d8018D3`0=
3`X030h900803a4<00h03@l:014C400:30T010H300h@3@0D5Q<0418?00lA3`0?4@h061XG00lA3P0H
6QL0;S0]00l@2`803Pl:00D03a0;010A300@4@`0414<01<D3`0200l@2`05014B3@0?3``0410>014A
3`0?3`d00P0=3@/200h>300C01@D4P0J6QP0410>018B400F5a@05QPC01TK5P0C5A0030h900d?2P0>
40/01`T400/=200F61<0:B/V00d?2P092`L03Q0=00lA3P04010B3`0?00`>2`0E5a@06A/H01<E4P0@
4Pl02P`902HX9@0A4a00004000`>2`0A4a003a4>018D4@0?4@h02`d:00803a4>00T020X901lQ800L
7Qd00P@300L9200C5A@03a4@010B4@0A4a800P0?4A005@0B51<0=CLd01lQ7P082PL02@/:01DG5P0j
>cd08b@V03Lh>P0Q8RH03@hB018C5`082@`04Q<E010B4@0?4A003Q0?014C4P0C5A@03@l>018D4`02
010B4@08018D4`0=3`h04A<@00`>2`0?4@h04aDB014C400?4@h2010B3`0400lA3P0>40d03Q0=00d?
31Cooooo000Kooooo`0<00D70`0;3@T0418?00X;3@0;30l02P/@01/L8@0>3a@01PL<00H62P0F5aX0
51DG0`0<30`0400?3`l04Q8A01@D4P0;2`T030`900`=200=3PT03@h800d>2@0<3P`03@l>00lA400C
5A@03a4@00/=300?4A0200d?3P0300lA400>40l03@l>00803PlA0P0E5QP200l@4P0700h?4@0D5AL0
4Q<E00T:300F5aT02P/=00l@4P0200l@4`0900l@500=4A@03A4D01@I7@0@5AT04AHJ00XA5`0=51X0
4ADJ008051DI00L05QLK01DF6P0A4QH04A8F01<D600D5AT04a@H00804Q<G02@04Q@E010E4@0@51<0
4QHF01DI6P0E6Qd04aXM010H6`0B6Al05AdT01<L8`0B6b805A/P01<G6P0@51L04aLJ01TM800L82<0
6AdP01@H6`0F6Qd05a/N01HJ7@0D61/051TJ018H600D6A`04QLK00hC5`0B5ad05a`R01<H7@0E6Qh0
51TL00hD5@0A5aL201@H6`0701<G6P0C5aP04aLH01<G600F6QT05ATH018G5002010E4@04014F4P0C
5aH04aLF01<G5P804aLH02004aPL01TQ900A61d04aXQ020Y<00D7BD07bPb028X=`0I7bh0;3=303Ho
C@0P;3P0:CM101HT;P0I9Bh06bD^01/T;@0F7RP04aXR01@K8@0I8B@06b<V01PP8`0D71l04a/N00hF
6@0?5aX04ATL018J7@0C6ah04aXP010D7@805a/U00X061`V01XN9`0b=Sl0;34g01<H7@0I7R80D5EI
02<X;00G72003a8G0P0E61d0400F6Ah06A`Q01DH7@0E6A`0310C01<G6P0K7b80ATY=04]?DP0L82<0
61`O01<G6P0B5QT051PK01PL7`0B5QT301<G6P09018F6@0A5AT04aHL01`O9P0H6b8082<X01DH7@0A
51T04ADH00805QXK01H04ADF018F5`0E6AT041@A018G4`0K81`05Q/H01@J600C6AP041TI01TQ902;
U9L09S0d00hG700B6ad04A`H014K6@0C7AX04a`I010I5P0@61D04QPF0P0C5aH2018F5@0W018F600A
51T04A@I018E6@0C5aX051PK01@H6@0>4Q<04aLH02DY:@0i?C`06AdL00hE4`0B6aP05AhM00lH6@09
41@02a8H03HmA01>EEd05QdU014H7`0>5A/03aLJ01DI700D61/04QHF018F5@0A5Q803Q<=00dB300G
71H03a@@00/?400<41404ADH01DI700C5aX0310A00803a<D00<051PG00lC4P0?4a800`0?51002P0@
5A00318@00dC4`0A5aD051XH01<I5`0>51003A<?00dD3P0>5@l300lF3`0<00T<2@0D6AD02@h:00hC
3`13B4@05AXF01<H500@5A404QLC00lD400<4@d05AXF2@0?510200hC3`0800dB3P0G71P05Q/G00/@
300A5Q803A8>00lD400B5a<200dB3P802a0<00D03a@@00hC3`0?51003a@@014F4P02018G4`04010E
4@0?51003a@@010E4@804QLC00<03a@@00hC3`0>4`l00P0=4Ph0100<4@d03Q<?00hC3`0>4`l300lD
400700lF3`0=50d02a8;014H4@0940T031<<00hE3P0200`C300800dD3@0;4P/02a8;010E3P0B5a00
4AH?00hC300=4P/400hC30803A8;01X03A<<0005000I81T02A09018I4P042`@041L@00D<1@0940T0
4QTB00`C300G7QL0AD]4034f<00=4P`04AH@00/@2P0A5Q0041D?00X?2@093PP03a@>00dB300>4`d0
3A8<00hC30805a`E00@02Pl800T>1`0>4``04AH?0P0=4P/00`0A5Pl0314:010C3002010C300300lB
2`0>4@X03Q4:00H03Q4:00P061/D01LJ4`0C5Pl041<<00lB2`0@4``02Pd600d@2@804A@=010041<<
014D3@0:3@H02@`501LJ4`0@4``05QTB018E3P0930D02Pd6014D3@0H6a@04aH?00T<1@0A50d041<<
0P0>4@X0300?4P/03Q4:018E3P0A50d03a8;00hA2P0=40T03A0800d@1P0=40D03Q4600hA20803a89
00@03A0906IYHP0K7QL04A<>0P0=3`X04`0=40T04A@=00P;100;3PL051L@00X=1P0>4@X030l801<F
3`0B5@h03A09014D3@0D5a001`X301<F3`0<3`P041<<00X=1P0C5Pl00P0>4@X300lB2`0K014D3@0B
5@h01`X3020S700c=Rl05APA010C300>4@X03A0900hA2P0?4P/041<<00lA300>40/03a4<00lB2`0>
4@X03A0900lB2@082`8041<:00hA1P0=40D04A@:01<F3P0:3@H030l800803Q4:00@03A0900hA2P0B
5@h04aH?0P0=40T200hA2P0A010C300>4@X04QD>01@G400A50d02@`702d`:@0V:B803a8<01`O600A
4`d03Q0;00`>2@0B50l02@/600X<1`0@4Pd00P0=3`X0600>40/03a4<00lA300@4Pd02P`7034c;P0<
3PX03a4<00d?2P0:30L03@l:00lA30072@@03Q0;01/N600K81X07B@M01@I4`083@L04QLA010B3@0<
3PT03@l:010A30<04A8=00H041<<00hA2P0>4@X03a8;010C300>4@X200`?20<03a8;00D03Q4:010B
3@0?4@`03a4<00d?2P0200`>2@0300/=200>40/03a4<00803a4<00h03Q0;018G4`0<4@d03Q<?00`A
3@1HGET0EEYF01DJ5P0?51003Q<?00dB3P0:3`/0314=00lA3P803@l<00@030h;00h@3@0B514030h;
0P0=3``0:`0>40d03a4>00lA3P0F61<04aD@00lA300>40/03a4<010B3@0Q8ah05QPC00h@2`0?4@`0
418=00h@2`0:30L03a4<018D3`0A4`h02`d800T;1P0>40/03a4<010B3@0?4@`03@l:00`>2@0?5100
2@h:01<H500;40`07R<O06Y_J`1HGET05AXF01<H500<4@d03a@@02lc;`0A4Pd0414<00l@2`0>3`X0
0`0?40/03P0C50l03a0;010A300C50l04a<@01@D4P0C4a40410>00d=2`0>3P`0410>00l?3@0H61H0
7alM0P0=3@/03P0B4a004Q@?01PJ5@0E5a803Q0;010B3@0A4`h03a4<01@F4@0M7aX0;BlZ01@F4@0?
4@d03a4>0P0>40d01`0?4@h04A<@018D4@092`P03Q0=014C400<3P/00P0@4Pl0500=3``03a0>01dO
700V:2D030h;018D4@0C5A803a4>00`>2`0?4@h04Q@A03i2@@2KWih07B4P00`@3`0B5QD09BPW00lC
4P0@51<03a<B0P0<40l05@0>4Q403Q0=00/=2P0?4@h04Q@A00d?300?4A0030d?01PI6`0A4Q@03PlC
00l@500?41<03@l?00h@3`0@4Q403a4@00d?3P0;3@`03Q0?014C4P0200h@3`09010B4@0<3Pd0418?
00h@3@0D5Q<04Q@A00/=2P0B51403@l<00<03Q0=0P0?4@hDooooo`006oooool030092`H02`d900P:
1`0?41804Q<G00X;40020`P03PlD00`=4P0:2`l07b0S01<D5P8030`>00d02`/=00d=3@0@40l04a<A
00`=200>3`X03a0;00l@2P0>3`T03Pl:010B400;3@`02P`;00<03@l>00d03a4@00d?3P0=3`h03a4@
00h@3`0=3`h03PlA00T:300=3Q003PlA00d>400?41803PlA00803@h@00<03a0B01<D5P0=3Q000`0B
4Q802@0A4Q@03a<F00lC5P0A5QX03QHI00082`042@l00P/@00/A5@0200d>4P07014B5P0H6Ad06Q/O
01LH700K72008R<W01dN8P0201<D600=01@G5P0?50h03Q<?014F4`0E6AP051XJ01<I700B6Qd04aXP
018J8@0E7RD05QlX01@J8002010D5`0E01@H6`0G6ah05a/N01<G6P0@51L04ADH018F6@0A5AP041@G
018G600C6AL05a`N01HK7`0A5QX04QLN01HJ8`0F6b405a`P01@I700C6AT07B<S008041@G02T04aLJ
01@H6@0E6AX05ATH01HJ6@0E6QH04aPD018G4@0C61805AXE01`P7`0I7Ah04ADF00dA500B5QT07R<W
014H7P0G7RH08BPa018K900=5B006B4/01HL:00J82`07RHb01lY<`0O;3D082hg01<Q:P0C82P04Q`U
01<L9@0E7BH05ahV00hE6`0F7R405alR018J7@0@61/04a/N010H6`0201LO8P0A014I700B6Qd06B0V
00hB7@0D62@08RHa01lS;P0J7RP06AdV014F700H7B800`P<038g>`0G72005AXM01<G6P0E6A/00P0@
51L02@0E6A`051PK01lS9P0I7B00720S00d@5@0M82D061/P01TM800201HJ7@0Q01hR9@0=4A@03A4D
00/?4P0<41<03Q8E014E600E6A`05QTN01PK8`0C5Qd05APO01<F7@0A51T06A`Q01DI700E6AX05QXK
01HJ6@0C5aH04ADD01@H5`0A5A@02`l>01@H6@0;4A404QLJ00`D5P0H828082TZ01XT9@094a@04adK
00803aXD00X04A/F014J5@0>5a@041LE018H5P0C5aH04QHE014E500@51D041@F0P0@4aP0800@51P0
4ADH018F5`0@51D03A4@01DI600J7Qd07b@P00X?2`0?5a<031LC010J6@0A6a`03QLL03M0A`13C5D0
6R</02lh?`0E7R@04a`Q00dF6@0?51L03a<F00hB4P0@51<04AHB00lD3P0E6Q@0314;00dB3P0M8B80
3Q8C0P0:3Q401`0A5AP06AdN00@82@0@51D03a<B00hB4@0?4a800`0?51002@0@5A0041HD00hD500=
4a<03aDC014G5@0@5Q8031<<00dD3@0300lF3P0400hE3@0R9b401P/701lT80806AhJ00H01``8010E
4@0?51004AHB00lD400<4@d700lD40804AHB010041DA00lD400?51003a@@028W8`0;3``03A8>00lD
400D6AD01P/700lD400@5A405Q/G00/@300>4`l00PL30P0?51002`0>4`l03A8>00`A3@0<4@d03A8>
010E4@0B5a<04aPD014F4P0@5A403Q<?00<03A8>0P0<4@d500hC3`0700dB3P0@5a002Q4:00T@2@0A
61402A0900/B2`0200dD3@8031<<0P0;4P/00`0?50d041D>00hC300200`A2P803Q<<0P0=4P/200`A
2P0Q00/A2P0i@c/0P8Z2014K4`0>61004A/C00<;10074@T03aTA004;0`0;5@d01@l701/Q6`0F6aD0
8BHP01@I4`042@<051TC00`A2`0A5Q003A8<010E3`0<4@/01@X401LL5P0;40T061dF02ld;@0E6Q<0
41D>00X=2@083@H04AH?00802a0900D03a@=010C300@4``041<<00lB2`0200hA2PH03A0900H03Q4:
00d@2@0>4@X03Q4:00lB2`0@4``300hA2P0D00`?200>4@X051L@01lR6`0:3@H030l800lB2`0<3`P0
20/501<F3`0@4``02`h700X=1P0=40T03a8;018E3P0?4P/03Q4:00lB2`0@4``400hA2P0500lB2`0A
50d04A@;00d@1@0=4@@00P0>4@H04@0?4PP03a8903<f;`3;c/P0MgUd024S80061`D051HA010C300F
6A804QD>01/N5`0Y;2D06ahG01@G400<3`P02`h700<03Q4:00D041<:00`?1P0E60l030l601DH3`02
00hA200;01@G3P0C5Pd030l600X=100<3`H041<<018E3P0@4``04aH?01XM5P0;3PL01P0>4@X0400B
51003a4>00lA300A4`h03a8;00hA2P0>4@P041<8018E2P0@4`P05a/=018E2P0B5@d05APA01<F3`0A
50d4010C300H018E3P0D5a004A@=00d@2@0?4P/03Q4:00`?200@4``04A@=00`?200?4P/03A09014D
3@0>4@X04A@=02X]9`0K7AP02P`700d?2P072@@010H100`>2@0>40/03a4<0`0@4Pd0400A4`h0418=
04=5@00@4Pd03@l:014C3P0H6QD03@l:01<E400@4Pd03Q0;014E3`052P@082LP00XA2P042@<200dB
300300d?2P0>40/04Q<>00804a8>00L0410<010C300>4@X03A0900hA2P0?4P/03A0900@03a8;00D0
3Q4:00d@2@0?4@`03a4<00h@2`0200`>2@0500/=200D5Q404A<>00d?2P0;3@P00P0=3`X02P0;40`0
51TE0002000>4`l041DA01DJ5P0A5Q803A8>00lD400A5Q8200dB3P8030h;00@04Q@A014C400=3``0
4A<@0P0>40d200d?308030h;00`06A/F01HH4`0A4`h03a4<010B3@0A4`h0:2XU01LI50092`H030h9
00lA300>40/200d?2P803Q0;00<03@l:00`>2@0B50l00P0Q8ah04P0D5Q403a4<014C3P0F6aL04QLC
00@91@0D6AD02Pl;01DJ5P0@5A4051TE00X?2`0@5A40314=04iCC`0A4Pd0414<00l@2`@03Pl:00D0
4Q<>00l@2`0@4@`04a@?018B3`02018B400R010@3P0?3`d04Q8@01@D4P0O7ad08R8P01DE4`0B4Q00
4a<A01HG4`0G6A@04A<>00d?2P0?4@`04A<>00lA300E5a807AlJ00T;1P0:30L01@L201@F4P0?4@h0
3Q0=00d?300?4@h04A<@018D4@0620D06A/H038d<@0E5a@03@l<00T;2@805aTF00D0BD]80=3Bc`0T
9R<0418?00lA3P02014C4080418?00T041@C03Tm?00=4A001PX900lC4P0C5aH03A4@00hB4@0?4a80
0P0=4A003@0@51<06A/H01@F4@0?4@`03a4>010B3`0I6aX06Q`K01PJ6@0A4Q@04a@F00T:300=3Q00
100>40l0400?4A00418A01@F5@0E5aH03a4@00d?3P0>40l02@/:00L91P0B51403@l<010B3`0J71T0
3Q0=00`>2`0=3``200h@3@80418?5?ooool001_ooooo00L04A<>00T;1`0<3P/04a@F018C5`0`<CH0
>CXo00803PlD00<03a0D00`=400<3@l00`0=3@l0400=3@d03`l>00l?3@0<3@P03Pl:010A300A4P`0
3a0:00h?2P0?4@l06A/J00P:2@0<3Pd04Q@C00840`0?4A0200d?3P0:00lA400>40l03@l>010A4`0:
2`d030d?00h?4@0?41804Q<E014B50803PlA00<04Q<E00l@4P0=3Q000`0B4Q80:00A4Q@03a<F00lC
5P0;41@04QXM00P@4`0U;3804AXO01DK7`0D5AT04a@H01TJ7P0Q8RH092DY01TJ7P0D5AT071dQ01TJ
7P0@4AD04Q<G01DH5`0@5@l03A8>014F4`0E6AP04aTI00hE5P0=5AP03A@J00XB6@0=5Qd03aPQ010F
700A5AP04QHI01DI700G6ah05QXM01<G6P0A5AP3018F6@0e014E600B5aL04aTG01PN7P0I7R8051TM
01DI8P0D624051TO01<H700@5AP04QPH01`R800?4a@041@G01<G6P0D61T05ATJ01DI600F6aL05AXF
01@I500C61805AXD01LL5`0N8R40720Q01HJ6`0B5QT06AdP02T^<`0R:C406B0X01TP:P0N9S40<SY5
01`T;`0L8Rh08RPd01hV<@0G8B/07BXc01XX<@0B8BP041dU00hH8@0?62404a/T01LN900?5Q`04a/N
01DM800D71l00P0C6ah0=`0>5QT05QhQ01DM800?5aX04QXM01dT:P0W:cH04QHR00lC7`0@51l061`V
00D94P0A5Q`08RL/00D:3P0K82@04QLJ01DJ7@0E6AX05QXK00lC500>4QD04aLJ018F6@0:3Q403Q8E
01TM800?4QL06A`Q00lB5`0I7B005ATL00/?4P0A5AP04QHI02L[;P0L82<05a/N01@H6`0B5QT04aLJ
01@G700C5Qh03A0G01PK8P0I72<04aHK01LJ7`0F6Qd04ADF018F5`0F6QT04ADD00`@3`0C5aL00P0B
5QL0400D61T03A8E01PM800@61X072@V00P>3@0H8R403QPG01LR7@0>6A<031LA00hH4`0@6A@03aPE
010H5@0B61H2018F5@03014E500@51D04ADH00804A@I01X041@H014E600A5AH04aLG018F5@0E6AP0
2Pl;00dB3P093PX06b<O00XE4@0640l02Q@E01lX;@1LIFh0F65Z00`E7P0/=Ch03QLM018K80094QD0
3A8E00dA500=4A403a<B010E4@803a@>00/03A8<01<H500C5aP01PX;038f>@1DF5/04QHI00lC500F
6Q/04QHG014E500200lC4P<03a@@01T03a@?014G5@0>51@02a4A00`B400?5A<041HB00/B2`0<4``0
3aH>010G3`0?5Ph03QD<00870@0B5a<05a`H00P=2@0G71P04AHB00hC3`0@5A404AHB010E4@0>4`l0
314=00H03a@@0P0A5Q83010E4@0=00lD40052PH03a@@01hS7`0730P0LgQd02@Y9@093PX03a@@00hC
3`062`L06AhJ01DJ5P02018G4`0;010E4@0>4`l03A8>00`A3@0=4Ph041DA01<H500B5a<03a@@00dB
3P0?51000P0>4`l200dB3P0400`A3@0>4`l03Q<?00hC3`<03A8>00T04APA00/B2`0940T04APA00/B
2`0>5@h03A@=00hE3P0=50d00P0;4P/01`0<4``0314:00hC300>4``0314:00dB2`0>4``00`0=4P/2
00`A2P0D00P?20074@T0<cde00D<1P033@D05AlG01<M5@0>610010h600/E3@0@6Q800@/300XA2`07
30H07B8L01HK5@0<4@/04AH@00H;1@0A5Q02018G4@0>00`A2`062`D02a0:00D:0`0B5a003a@=00L<
1@0B5a004AH?00lD3@0@5@h04aPA00lD3@093PL3010C300300lB2`0>4@X03Q4:00H03a8;0`0>4@X0
0`0=40T030l800`?2002010C300;00d@2@0:3@H03A0901@G400]<2T04aH?014D3@0I71D05QTB010C
300<3`P00P0=40T00`0;3PL03A09010C3002010C300400hA2P0=40T03Q4:00hA2P8030l800H03A09
00hA2P0A50d04QD<00d@1@0=4@@200hA1P0900lB200?4PT0=STb06i`JP0n@3/05QPE01TK60041P40
3@l:00804A@=01006QdF02HY8P0N8AX05QTB00d@2@0930D03A0900lB2`0=40T03a89018E300?4PT0
30l601<F3@0=40L04A@;0P0K7QD02@0A50/03Q48014D2`0;3PL03Q4:01@G400;3PL03A0900X=1P06
00hA2P<05ALD02<051HA018E3P0A50d03Q4801<F2`0;3P<03Q46018F200=40D03A08010C300<3`P0
2Pd600T<1@0<3`P04A@=00lB2`0A50d05QTB01<F3`0>4@X04A@=010C300?4P/051L@01<F3`0?4P/0
61/D00L:0`0?4P/03A090044000N8A/051HA00T;1P02010B3@802`d801L030h900d?2P0>40/03Q0;
00d?2P0@4Pd020X502@V8@0>40/051HA00h@2`0?4@`03Q0;00d?2P031@003Q0;010D3P0B6A80LGQa
020W800@5@l0314;00T=2@0200lA3005014B3@0B4@d04Q4=018A3@0?40X00P0=40T01P0>4@X03a8;
00hA2P0A50d041<<00lB2`803A0900D03Q4:00h@2`0>40/03Q0;00`>2@0200/=200>01HH4`0A4`h0
30h900/=200<3PT03Q0;00870`0>4`l041DA01HK5`0>4`l04AHB00hC3`0<4@d200hC3`0400X?2`0=
4Ph03Q0=00/=2P8051HC00P030h;00lA3P0?4@h03Q0=00d?300<3P/02`d:00X<2@803a4<00<03@l:
00h@2`0@4Pd00P0A4`h07`0<3PT02P`700`>2@0:30L020X500lA300<3PT02`d800`>2@0>40/03a4<
01DG4P0S9B008B<N014C3P0:30L03@l:01@I5@0=4Ph000D100lD400=4Ph04aPD00dB3P0H7AT01P/7
00`A3@001000<3Da010A300?40/00P0>3`X300l@2`0M01<D3`0?40/03a0;018C3P0@40d04A4?018B
400A4@l0410>018B400A4@l06a/I01`L6P0;2`T04a<A01DE4`0M7Q/08bDP01HH4`0>40/03a4<00h@
2`0A4`h06Q`G020R7@0C5A0061XE00h@2`0E5a<00P0>40d200lA3P0A010B3`0B51401@L401DG500Z
;2T03Q0=00X<2@0<3P/09bTV00L81P031@80>C/h00`>2`0>40d03@l<010B3`0C5A800P0?4@h02@00
0@003Q8A014E500J7Qd041@C00T=300<40l03A4@00hB4@0200dA400?010E4P082PL02P`7014C3P0C
5A803a4>00/=300620L05ALF00`=3`0?41806AXL01LH6P0@4Q403a4@00803Q0?00P0418A018D4`0H
6QT06A/J018D4`0?4A004A<B00d?3P803@l<00@01PP501XL6@0/;R/02@/80P0>40d200lA3P03010B
3`0A4a3ooooo01?ooooo000Kooooo`0O00`=2@0?40h01@H5018E5`0I6b007b8W02ha=`0;3Q803a4E
00h?4P0;30d04A4A00/;3P0=30l03Ph@00l?3`0>3Pd03@d;00/;200=3PT0414;010A300>3`P03@h8
00/=2`0@4Q403@l>00lA400@4Q403@l>00lA400200d?3`0?00lA4@0>41003@l?00h?4@0;30h03a0B
010A4`0>3a40414C00d>400B4aD04A8D010A4`0;30h04a@F00<04A4A00T0418A00hB4`0>4Q<03Q<F
00lF6@0?4aL0DEML018J7P0=4AD00P0>3a<00`0B4aL04a@H018C5`0201<D6080414E00`04A8F00l@
500C5A@04AHA00dB3P0@5A<051TH014F600?5QP051`P01@K8P0@620201<L9007018H7P0A5AT03a<G
018E6@0F6Qh06A`P01HI7@03018E6@0G018F6@0B5AT04AHF014G5@0I7al06QlS01HK7`0F6b8051TP
01DJ800D6Ad04aPK01@J6P0E6aT051PI01@H6`0E6A`051PI01<G600A5A@05Q/H01DJ5`0D6A@00P0B
5a40800E6Q@04aLH01LK7P0J7R4051PL018E6P0F6b0061lW01DL9@0A5b805QdY0418E00N9S405ahZ
01DL:00K92h06bD^014N9`0C8RT0528Y01@P:00C7BD04a`S01<K8@0C6R005QhR014I700C6ah06b<V
01`T9`0E7B004a/N0P0D71l03@0F7R4082P[02T`=P1<D5/05a/W01XN:P0B5R404aLQ024U;@0B5ad0
61dQ01`Q900I7R800P0F6ah03`0C5aT05a/M01@H6@0D61X05QXM018F6@0G6ah03a<F01HJ7@0?4QH0
720T018F6P0Q9BL07R8T014E5`0201PL7`0@03Di?00V:Rd0720S01DI700B5QT051LK01HI7P0D5al0
5APO018E700E61l06A`Q00lB5P0G6ad04QHG018F5P8051PG04T04QHE01<H6P0B5QT05ATL018G6P0F
6ah04QPK010H6P0@6AP04Q/J010K5`0K9R806bHP01lZ8`0I91h04ahH014J500?6A803aLC014G500A
5Q<04AHD014E5@0A5AH04aLJ01DH7@0C5Q/04QDI010D5`0@51D04QHF00lC4P0C61@03Q<?01@I4`0@
5@l06R8K010K5P0A6QP03aPJ01LP9@0J8RX05QhX018K900;4a`03QHL01/U:00a>C/04QLI014E5`0?
4a<041DB010E4@0>4`d03A8=010E400>4a003a<D00`@4@0]<C@0CU9F018F6P0B5QP03a<D01dQ8@0F
6aT04QHD014E4`0@5A403a@@00hC3`0>4`h03A<B00802a4A00`03Q@C00hD4P0=4`l02a8<00`C300?
5Pl04AP?010H3@0>5@`051TD01DJ5P0>4`l200/@300301DJ5P0A5Q804AHB00803a@@00<04AHB00hC
3`0?51001@0?5102010E4@803a@@0P0>4`l0300G71P03A8>01@I5@0:3`/07B8N00L;200D6AD03a@@
00dB3P0A5Q808BHR02hc;`804AHB0P0@5Q800`0@5A403aDA00lE4@0200hD400300hC3`0=4Ph03A<?
008041DA0P0?510400hC3`803A8>0P0<4@d03`0=5@d03QD>00`E3@0B6Q<031<<00lG400<50`03aH?
00dE3P0:4PX02a8;00dD3@093PL03A8;00hC300200dB2`0300hC300=4P/03A8;0080314:01`02a09
01lV7P0M9al02Q8;00hG3`084PX0210900dF3`0<5Ph0210900`F3P0640P03QL?00/B2`0>4`d0314;
00hC3@0;40X0314;010E3`0<4@/03Q<=00dB300>4`d04AH@00lD3@0:3`P05a`E0P0>4``01`0M8Q/0
;c@]02`a:P0E6Q<06AhG010E3P0>4``00`0@4``00`0?4P/03Q4:00hA2P0600hA2P@04A@=00<041<<
00hA2P0@4``00P0@4``200d@2@0X014D3@0?4``01@T200lC300C5a003a<<014E3P093@H0310900lC
300;3`P03109010D3@0<3`P041<<00lB2`0:3@H02`h7010C300>4@X03A0900`?200=40T03Q4:00lB
2@0=40D03A4300hB100>4@H03a8800lB2@0>4@X04A@=01TK5P041P<0418>018E3`0A4`d030l800d@
2@803a8;014041<<00/>1`0@4``03a8;00hA2P0@4``04QD>00d@200I71@01`X1018E3@0?4PX02Pd4
01<F3@0D5`l051L>01<F3@02010C2`0600lB2`0@4``04A@=00d@2@0D5a0041<<0P0>4@X200lB2`0A
00hA2P0=40T04A<?01PJ5`0G6AD0418=00hA2P0@4``04QD<00`?1@072P005AT<00H:000?4PL03Q49
014D3@0>4@X00P0B5@h03@0>4@X04QD>01<F3`0>4@/04A@=018D3P0=40T03Q4:00lA2`0B5@h061/D
01HH4P0C5Pl00P0=40X02@0E61403A0900/>200@4Pd03a4<00d?2P0<3PT03a4<010B3@0200d?2P0F
00h@2`0@4Pd03a4<00h@2`0>4@d03A0=00/>2`0?4`h0310:00hA300>4@/02Ph802HY8`0L7QT02`d8
014D3`083`P0:c@/01`S700C6Q<01@`500dA30803a4<00`03Pl:00h>2P0?3`X04@l<00d?2@0;3PL0
30l800hA2P0@4``03a8;014D3@0?4P/200`?200800lB2`0D5a003Q0;00h@2`0=3`X030h900/=200:
30L400lA300D010B3@0?4Pd04aTE01TN6`0G7AT01PX700`B3P083PX02Q0<00`B3P0?5A403Q<?00hD
400H7AT05aXG00/=2P0@4Pl051HC00d?300@4Pl400`>2`0400d?300=3`/030h900d?2P803Q0;0P0?
4@`0100<3PT03Q0;00h@2`0?4@`2010B3@0400h@2`0=3`X030h900d?2P803Q0;0P0A4`h04@0@4Pd0
3a4<00h@2`0=4@/02Pl;00hD400?5A402@l;014G4`0K8Ad061hJ00/A3@0<4Ph02a0<01<I5@0?5100
3a0;00803Pl:00h0414<014B3@0A4Pd04A8=01@E400@4@`03a0;014B3@0@40d04Q8@01<C4@0B4Q00
3`l=00h>3080410>0P0>3P`2010@3P05010A3@0B50l0418=00h@2`0=3`X00P0>40/02@0?4@`051HA
00`>2@0F61<02P`7010B3P0>40d03a4>014C4003010B3`09018D4@0K7AX05QPE010B3`0C5A80418?
00/=2P0@4Pl06A/H00803a4>00`04A<@00`>2`0=3``03a4>00`>2`0@4a003Q8A00X@3P0B61H02Q0>
00lE4`12B4H300lE4`0400/A3`0:40h03A8?010D3`804Q@?00@04A<@018D4@0A4a003Q0?0P0D5QD0
0`0K71h05AHH00d>400300lB4@0500hA400=40l030l>014D4`0C5QD00P0=40l0200A51<03Q4@01<E
4P0B51404A<@01PJ5`0J71T02P`91P0A4a0Dooooo`006oooool09P0E4aP030/@00<63@0010l0GVMa
04aFH00G8BX02aHI00L=3@0:3`/0414900h>1P0=3@/03a4@020R8@031@@03Q0?00X<2`0>40l03@h?
00l@4P0A4Q@030d?010A4`092`X0418A00d?3P0:2`d030d?00/<3P0<3@l03PlC00d>4P0A4QH02``@
010A5@0?41803@h@0P0>3a402@0:2`d020T;00d>400G61X05AHH01<D5P0>3a401`P:014B5002018C
5@0>014B500>3a403@h@01@G600E6AX03Q8E00T=400F6Qd0;C0d00hA5P0=41D061/P00lB5`0;3Q<2
01hQ9P0N010C600<3a@04A@I018E6P0F61T071hM00/?400C5a/05AdP00dD6P0<5A/04a`S014J8@0=
5A`04QTO00lF700A5Qd04QHQ01LK9P0@51l0720[00lC700?4a/04AHL010E6`0A5Q`04AHJ014F700B
5aX04QPH0P0C61/0=@0D6A`051TM010E6@0J7b<09R/^01TN8@0=4QD051XJ01@I700J7b804aPK00hC
5P0E6Qd03a@F014G5`0B61P05A/K01@J6P0B61P03Q@D018H600I7al04QPH01<I6@0L8B@051TL010E
6@0L8BL0314G01DI8P0F7BD04aPR01LP<@0I93H05b8c01DQ;`0L:3D07R/d01/U;P0F8BP04a`Q018L
7P0C7Ah05AdO014I700C61`041DI01<H700J7b<061dQ01LL800H7B405AXN008051TM00<04AHJ014E
7P0F6R<00P0G72803P0E6R003a@H01DJ7P0C61/06AlO01XO8P0E6a/051TL014D6@0B5AX04QHI01@G
700Q9BP0;S8e0P0E6AX0300B5QD05ATH01@I5@0?5100318@01HL6P0630X06R0O01<I6@0F71`05AXM
00X?4`8041DI03l04AHL01XO9@0D5ah051LN01DH7@0G6Ql06A`Q01XN8@0D61X05a/L014E500?4a40
6QlK010F4P0?61D06b@S01`U900C71/031DD00/E500>61L051hO018L7@0C7A`06R@S05QSH@0jAd00
62DN01LT6P0?6a402QH:010L4@0>60l03aTA00`C400:410041DH014F6P0>4aL04AHI01@I700B61P0
3aDE018H5`0D6QH04QPD00dD3P0=50d04AP@00lF3P0?6A004APA00hF4`0U;Bl041DK010F7P0=51`0
2@dF00T?500B6Q`041DF00lD400?50h00P0?510200hC3`803Q8A01H03Q8B010D5@0B5QT051LL01DJ
800>4aT041DI01DK6`0;4@l04aTD014H4@0=50d02Q4:00hD400A5a<04ALD00P=400;41<03aDF00lE
5@042PX04QPG0P0:40`05P0:40/02a8;00dD300@5`l04ALC010F500E6aT04aTG00dC4@0A5aD03Q@B
00/A3`0<4Q003A<A00`B400?5A<0318@00X@3P0L8R00?TA201XP7P0B61H200lE4`0;00hD4P0=4a40
41HD01<I5`0I7ad03Q@B014G5@0X;R`0;C<a00H<2P0<4Q000P0@5Q@0400=4a40318@00dC4@0C71L0
3AHA00<<1`0>5a8031D@014J5@0@6A@01a0;00/D3`0=5Q404AXE00TB3@0?5@l200hC3@03010E3`0?
50h03Q<=008041D?0P0?50h03P0>4`d03A@=00hI4@0>61002aH>00LA2@0;5@d02aH>00HA2@0@6Q80
5b8J00TC2`0640P01@l70P0>5@h200dD3@0700`C300=50d04QTB01@K500?5Pl03A@=00/B2`0200XA
2P0;00dB300?5@h02A0900/@2P0>50h051/D00D:100@5Pl02a8;00/@2P0@5@h00`0=4P/02P0?50d0
41D>018G400E6Q<03Q<<00H;100E6Q<04aPA00H;0`093`<300/A1`0a00hD2P0@5@d03Q<<00`A2`0;
40X03Q<=018G4@0;40T020d6010E3P0:3`P03A8;010E3P062`@04AH?00lD3@0<4@X02@h700X?200?
4P/04QD>014D3@0>4@X04A@=010C300A50d03Q4:00lB2`0@4``03A0900lC30001`008BPQ00XA2P0?
5Pl04APA03Pm>00]=2d04APA00L>1`0B6A8020l800hE3P0D6A805QTB00T<1@0G6Q<05APA00/>1`02
00lB2`803Q4:010041<<010C2P0:4080318300dC1@0=4`L03A8:00`A2P0?50d04AH?00X@1P042P00
4aT=00T?0`0A50/041<<0P0?4P/06@0>4@X03A0900hA2P0<3`P04QD>010C300<3`P04A@=00d@2@0?
4@`02@`500T;1@0>40/041<<00T;1@0@4Pd06QdF00d@2P072@@051L@014F3P0>50X03A<900`B200=
4`T00`0>50X0@00@5P`04aT?018H3P0A5Pl03Q4:00h@2`0A50d03A0900hA2P0F6A803Q4:014D3@0A
50/03a8900hA200?4PT0318800/A1`0B60l041D>00dB2`0?50h05Q/E00870@0I7QT061dG00460P0I
7QT00080028W8`093@T04aPB010E4@0;40/02Pl900P=2@0>4`h03a@>00hC3`0=4Ph02@h:01<H500?
51000080020U8@0g?3P061dI00/@300@5A402@h:014F4P0E6Q/06b8X05EMH00>51<04a`G00`C2`0<
50T02a<801dT6P0L8AX02Pl801dR700=4P`3010E3`08018G4@083@L05Q/E010E3`0?4Pd03@l:00@6
0@0C5A0200X?200700`A2P0=4P/03a@=014F3`0>4``03A8;00`A2P0300/@2@`0314;05D03A@=00TB
2P084PX031<<00XA2P001P004QLA014F400<4@/0418=01<F4@0;40X04QLA00dB300A5Q0041D?00/@
2P0@5@l01@X4010E3`0730H02a0:00hC3@0C61802a0:00hC300G71D041D>00P=1P000`004QL@00@9
0P0:3`P05AXC00H;100L8AX02Pl:00lD3P0<4@/02a0:01<H4P0@5@l0314;00/@2P0>4`d0314;00dB
300B5a403Q<=010B3@0=4P`0310:00lA300>4`d04AD?00d?2P0;40X03a8=00h@2`0<3PT0:R`W00L9
100E5a8030h901XL5`0C5A0030h900T;1P0<3PT05aTD01<E400<3PT06A/F00`>2@082PD02`d801hP
6`0d=S406A/F03Tk=P0/;RT01PP301@F4@0@4Pd03a4<00803Q0;0P0=3`X03@0C5A002@/600h@2`0;
3@P03@l:00`>2@0A4`h06Q`G00`>2@0D5Q401@L201<E400>40/00P0?4@`0100A4`h04Q@?010B3@0=
4@/500`A2`0=01DJ50062`D00@H001`Q6`042@<04aPB010E4@0>4`l0314=00/@300<4@d03Q<?00P=
2@0200lD400=01@I5@0?5100314=018G4@0=4P/02Pl900`A2`0;40X03a@@00hC3`0<4@d041@C00L;
2P0200hB4@@03aDC00D03A<A00`B400>51804ALE00/A3`02010F500=00P>2P093PP03A8<00lD3P0;
40X02a0;01<H500=4Ph03Q8@00hB4@0=4A00310?00X>3@0Dooooo`006oooool03@0>2A005A<K00L:
4`0O9C40[;O20;;0b`0A7bP02QHJ00H?3P0<4@/04A8800l?1@0=3PT00P0>40l0600I6aX05AHG014B
500C51H030d@014B5P0720`03PlD00/<400<3Ph020X9010B4@0@4A<030d?01HG6@0D5AT05AHJ01PI
7@0=3Q<010D:01HG700B4aH03@h@00`=3`803@h@00@030d?00d>400C51H04A8D0P0@4A<00`0=3Q00
414C014B5002014B50803a0B00H02P/=00/<3P0C51H05QLI00l@4P0I6ah2010C600501TL8@0D5a`0
4QDJ01@G700C5Q/00P0B5AX0600@4aP030lD00/>400B4aD04QHI01<I7P0H8BP03QLN01DO:00B72D0
4a`S00lG7P0B6Al05Q/O02DZ<P0T:3@03Q8N00dA7@0>4Qd051PS01TM9P0B5Ql04ADN018G7@804aPN
0P0C61/0>`0E6Qd061dP01TN8@0K82<03a@G018G6P0K82<061dP014F6@0C61/05a`O01DJ7@0J7b80
5Q/N00X?4P0B5aX051TL01<H6`0B5aX04aPK01@I700G71l06AlO00`B4P0G7Ad08RPX01@J6P0F6ah0
5Q/O01lT:00B5a/061dS01LL8P0D6R804ah`01PU>00J9CP062@d020Z>@0T;SP04adW01@N900C7Al0
4A/M010J6P0B6Q`04QLK01DJ7P0D6Ad05Q/O01/P900F6al05AXN01<H700B5a/051TM01HK7`0D6Ad0
5AXP008051TO00/05a`P01HK7`0@5AT04QLJ01<I6P0nA4@0A4Y:02<Y:@0T:B`051LL01@G7@0201<F
6`0H01`P900W:bh05QXK01TM700G6aX05a`H01HK5@0C61804QPD038h=00K8Al03Q@B00D;2`0?5AD0
5Q/N00hC5`0C61`03a@J00X?5@0?51X06QdT01LJ7`0F6Ah051LL0P0C5aX02P0C5aP05QXI01HJ6@0C
61@06AhH010F4P0>61D05R4M01LR7P0B71/200`F5@0b00hH5`0=5aP04A/L01HP8@0H8R<0:3<b014N
5`0>6a@05R<I01HT5`074`L03AT<00XF30053`L04Q/G01hW9P0E6Qh020dA00dB5P0@5AP04QPI010F
5P0<4Q803Q@B014G4`0@5Q803A@>00dD3@0A61005QhD00H>0`0940T041HC01HK7P062`l02@dE00<8
3P0G7280724T00dB5@0C6AP041D?010E3P0A5Q004QLC014F4P0A5Q<04ADD014E5P0@51D2010D5`07
00lB5`0O8b`0HfM`00P=4@083Ph03Q@@014G4P0200hE3@0;00lF3P0@5Q803aDA00`B4@0W;2l00086
02<X:`0/<S804ALG00lE500>51800P0=4`l03@0=50d03aH?014H400?5A403Q@B018H5P0@5Q@0318@
014G5@0@5Q@05A/I00hD4P0:40h01@0<4Q001@0O9B<05A/I018H5P0;4@l0318@00802a4?00L03A<A
00hD4P0<4Q004aTG010F500C6AL06AlM00803A<A01803aDC01<I5`0E6aT05A/I00lH5@063`X03aXD
010K5@0C7QP01Q4;00LB300;50h0?DQ203a7@@0=61800Pd700L@2`0>50d2010E3`0400lD3P0A5Q00
4QLA00lD3P<03Q<=00<03A8<00`C300B71@00`0:5@d0500A71@00Pd500hI4@0=610021<;00XE3@0M
:20062<K00lF3`0>5@h031<<00XA2P083`P02Q4:010G400A61403QD>00`C30083`P01`d70P093PP0
2P0;40X02@h800hC3@0<4@/01P/500lD3P0730H04AH@018G4@083@L300`A2P0400dB2`0>4``0314:
00D:0`803a@=00X00PL000/@2@0D6Q0051X>014G2`0=4`P02a4700`B200>50/03Q<<0`0@5@l03`0?
50h03Q<<00X?200=4P/01@X300X?200C614051TB00lD3@062PD061dF01@I4P0<4@X03A09010C3002
00lB2`804QD>01P04A@=00hA2P0?4P/041<<00d@2@0>4P/072<L05QRFP0?6A401@l700`F3P0X<RX0
8B/S00dG3`053`L03QP@00PB2P0>5@h000D008B7P00e>3401`X300@60P0A50d200lB2`803A090100
3Q4:00hA200;4@<02a8300/A1@0;4@L02a4800/@2@0@5@h04QL?018H3P093`<03Q@500H<000@4`X0
41<<0`0?4P/03@0>4@X03A0900`?200@4``03a8;00/>1`0@4``0:2XU01DG4P0@4Pd06A/F018D3`0;
3@P00P0?4@`01`0D5Q403a4<00/=200A50d04aP@010F300>50X00P0=4`T03P0>50X03aD;00hD2P0@
5P`04aT?018H3P0@5P`02`h700d@2@0A50d03a8;00`?200@4``03Q4:0P0A50d0<P0?4P/03Q4:00lB
2`0;4@L02@l500lE300<4@X020d600T>200>4`d02Pl;014F4P052PH08bPT08^@S00O9200008000lD
400E6QH020d901@I5@0<4@d02Pl;00hC3`0=4Ph02a0<00dB3P0C61@09b`X02db;P0@5A406AhJ024V
8P0H7AT041DA00X?2`0?51006QlK01LM803Rjo80W:FZ02@^;P0010000``400TC200540804QX>01DJ
4`0:3`P04aPB0P052P@020062`D02a0:00hC3@0C61801``6018G4@093PP04AH@0P0;40X01`0>4``0
3A8;00dB2`0<4@X03A8;00hC300?50d0100>4``00`0@5@h0314;00`A2`0900`A2`0]00/B2`0530D0
2Q@<008<100;4P/031<<01PO600>4`d03Q8<00/=200=3`X04A<>00/=200=4P`02@h800dB300<4@/0
20d700/@2P042@<03A8<01<H4P0U:R@082DO00lD3P011P0041D>00T>1`052P<04QL@01<H4@083@H0
5Q/D00@90P0;40T0008000T>1`0=4@d041D?01DJ500930P02Pl900dB30093PP02Pl900802@h800D0
314;00dB300C5A004aD@014C3P0200h@2`0400lA300>40/030h900d?2P804A<>00P0418=04mAC00[
;BP04aD@00/=200K7AP020X5014C3P803a4<00l061XE01DG4P0;3@P02@/601DG4P0F61<020X501<E
400J71L0418=01XL5`0>40/03@l:01PJ5@0<3PT00`0?4@`200h@2`0=010B3@0E5a804aD@01HH4`0C
5A00418=00X<1`0>40/04Q@?014C3P0:30L03Q0;014C3P0200lA3004014C3P0B50l0418=00dA2`D0
314;01l02@h801HK5@0B5a4061dG00dB300>4`d02@h:00`A3@0>4`l0314=00/@300@5A406AhJ014F
4P0>4`l041DA01DJ5P0A5Q404aPB010E3P0B5a404aPB00lD3P0=4Ph05AXF00T>2P0J7Qd04QHE00P<
2`0>4a803Q@B00@03AHC01<031DB00D>2`0A6QL05b0M03i7A00L9B808R/V01LL5P0I7QP020d700H;
1@0F6aH06AhJ01HK5`0E6AL04aLF014E500@51<03a<B01Cooooo000Kooooo`0D00l:3`0@3a@00PD=
018F800lADl0>TMA00PE7@064AD020h>00/@300?40T03@d600h>300;3@`02P`;04M9B00];Rl03a0B
00d>400>3Q4200d>4P0K00d>4`0@4AH03a0C00X;3P082@`03a0D00X;3`0;310030dB00X;400?3aH0
30`D01PH8@0l?D<05aPK010A4`0=3Q00414C01<D5P0D5AL03PlA00l@4P0<3@l03@h@014B500B4aD0
414C00803a0B00h0414C018C5@0B4aD0414C01HG6@0N7b404Q<E01@E5`0@4QD03Q4F00lB5`0@4aP0
4aHK018E6P803Q4F01T04QDJ01<F6`0@4aP041<H01<G700<4QL06b8W01HN9P0T<3T03APQ01DR:`0=
6B804Q/S010H7`0:4QH051TM01@H7`0K7bT03A4L03<g@@0?51/051PQ014F7@0?51T041DJ00804AHJ
00@04QLK018G6P0B5aX04QLJ0P0C61/01P0D6A`061dP01<H6`0C61/05a`O01@I70804AHI00L03Q<F
01TN8@0I7R403A8E01<H6`0A5QT04QLJ008051TL02<04aPK018G6P0H7Qh07B<S01LM7@0?5AD09B/[
02P]<00E6Qh05Q/O01<H700F6b404aPN01PN9P0S;3d0:3=602PcA@0N:SX07bXh024[=@0B72D05b4W
01LP900D71l04ATK01<K7@0D6Ad05a`P01DJ7P0F6al05a`P00lD600F6al04QLK01@I7@0201LL800=
01DJ7P0F6b404QLM01<H7P0G72005AXN018G6`0G71l04ALH01XP800L8R804QPH01<H6P0201HI7P07
01@G700D61/05QXM01TM800B5QL06QhM01LK6P0201<H500A018F500C61L05adL01DK6`0>4aD07R<V
00`A500@5AT04AHL01/P9P0N8bT0720Y01hS:P0I72805QTN01DH7@0D61/00P0C5aX0>00D61T03a<B
01LK6P0D6AD04aPD00dC3`0?6AD03aTH010J6@0A6aX03aTH00hH5`0nB4L072HW00dG600@6Q/04Q`M
00lJ600E8Q/072TQ01@Q5`0K:1d021@900dH3@0A6a<041XC00dD4@0F71`06b0T01HK7`0D6A`05AXM
01DJ700B61P041HD00lE4`0@5Q@041HB00lF400>5@h03aH?018I40083`L06B0I014G500>51D03a@G
01DJ7`0E6R005Q/P02<X:`0E6Qd03Q@C00lD400A5Q004aPB0P0E6QH06@0D61L03Q8A00lC4P0B5QL0
4QHI014E600@4aL0=CU106aaN00F6al05A/K01DK600@5A004AP@01DL500J8AX05Q`H018H500>5180
20/>00`A501ZKg808bTY01HL700<4Q000P0?5A<03P0>51003A@=00dD3@0>5@h041HC00lE4`0@5Q@0
3aDC00hD4P0C6AL02Q0>014G5@0<4Q002@l=0P0>51802`093`d03aDC00/A3`073@/041HD00`B400>
51803aDC010F500A5aD041HD00803Q@B00H04ALE00T?3@093`d03aDC00/A3`0@5Q@200hD4P0B010F
500>518020l=00TB3@0<5a40218<00`G4@0950h041/E00`E3`14CdT0>dI000lI4`084`d03QLB010F
400B5a4041D?0P0>4`d04`0?50h03Q<=00hC3@0>4`d03A8<00`A2`0;4P/031L?00PC2`0=61006B@L
038m=@0;5Ph031L?00lJ4P0950`03QTA01HQ6@033PH0100>5@h0500?5Pl031<<00XA2P0;4P/041L@
01PO600F7AH041H@00dB300;40X03A8<00lD3P0F6aD05AXD01PM5`1>Ddd03A8<00P=1`0A5Q003A8;
100<4@X0800=4P/041D>00D:0`0@5@h04QL@00X?200A5Pl02Q0600X@10093`<0318700hD2P0<4PP0
318900lD3@0C618051TC014F400<4@/03Q<<00X?200@5@h0314:01LL5@0]<R/02a0:010E3P0:3`P0
2a0900`A2P0=4P/030l80`0?4P/0100C5Pl04QD>014D3@0?4P/2014D3@0:00d@2@0<40T03A@=02Pb
:P0?6A4010h601PR6P094P/03QP@00/E3@80218:01P02aD=00dD3@0>4``08RDO00/>1`0A50d041<<
00hA2P0A50d041<<00hA2P0=40T030l800`?1P0<4P@02a4300T?0`0:40H0318900lD3@0@5@h01P/4
014G3@0<4PH200X@0P0700hA200?4P/03a8;00lB2`0@4``04A@=010C3002014D3@0<010C300>4@X0
4QD>01TK5P0K7AP051HA00P:1@0;3@P05aTD01@F4@0@4Pd03@l:0P0A4`h00`0>4@/03aD<00dC2@02
00`B20803Q@:00H03A<900`B200=4`T03aD;00dC2@0;4@L200d@2@05018E3P0C5Pl03Q4:00`?200>
4@X00P0A50d200lB2`0[010C300@5P`03Q@:01<H400?50d02a0900dB2`0:3`T0314=00dB3P0L8Ad0
>Chj059GD`0F6aL04AHB00X?2`0A5Q803A8>010E4@0?5100314=00hC3`0:3`/02@h:00`A3@0=4Ph0
41DA00lD40093PX02Pl;014F4P0<4@d02Ph;01@I5@0:3P/05Q/G018I6P1^Mgd0BE9F00P@40063`X0
2Q@<00`D2P0200XB1`803a@=01402Pl901DJ500:3`T02`l:00lD3P0:3`T03A8<00lD3P0;40X0314<
014F400@5@l03Q<=014F3`0@5@h03Q<<00`A2P0200/@2@80314:0P0;40T00`0=4P/03Q<<00dB3005
00dB30D0314;00D02a8;01LN5`0?6A4031H>00hE3P0200dD3@0700/@2P0?4`d03@l:00h@2`0B50l0
3@l:00hC3@0300dB300S00/@2P0<4@/03A8<010E3`093PP03a@>00`A2`0;40X02Pl800`A2`0<4@X0
51TB00T>1`083@H04AH?00hC300:3`P02a09028W801nPg`0;S<]059GD@17C4H041D?01<H4P0730H0
5Q/E01TN600?50h03Q<=014F400;40X051HA01<E400A4`h00P0>40/03@0?4@`0418=00lA300?4@`0
418=00lA300>40/0418=00/=200B50l04A<>00H8100F61<00P0@4Pd0400=3`X03a4<014C3P0D5Q40
1PP500/=200=3`/06Q`G03`n>@0/;RT02@/600d?2P0H6QD03a4<00X<1`0=3`X2014C3P80418=00h0
3a4<00h@300/;RT02`d800lA300:30L04aD@00`>2@0>40/02`d8014C3P0E5a804Q@?00d?2P803a4<
00@04A<>018D3`0@4Pd03Q4<1@0=4P`07`0;40X0314;00`A2`0H7AL05Q/E00dB30093PX03A8>010E
4@0=4Ph02a0<00hC3`0=4Ph0314=02`a;@0E6QH05Q/G00dB3@0A5Q003Q<<00hC3@0?50h0314;014F
4P0=4Ph03Q<?00X>3@0B5QD04aLF00/@3P0?5A<01@0<5A804P094Pl02Q<@059KF03:dm00HfaY00D:
1P0E6Q@02a0:028W8@0U:R@0314<00hC3`0B5a<04ADC010D4`0A5A@051PG01HJ6ACooooo000Koooo
o`0U010<3@0:2@X02@X>01@I7`053aL03aTR00@>5`053a@02@hA00d?3P0?3``03Pd900h>300@4Q40
1@L600L9200310D030d?00/<3P0>3a80414E04e>DP0A4QL0414F00h?4`0>3a@05AHK014B5`0F5a`0
4A4I01@D700L72@05ADO00h>60030`l01@D=00h?4P0200/<3P803@h@00@02``>00l@4P0@4A<0414C
0P0<3@l03@0>3a40414C00h?4@0>3a40414C018C5@0C51H05aPJ03Hg>@0o@4808B8T01dN800C5AT0
0P0C5Q/01@0@4aP04aHK01<F6`0D5a`04aHK008041<H0P0D5a`01@0>5A`02aDN028_>00K:C<08c4l
00805B<^01403a`U01<M9P0D72<04QLK01HI7P0I7B80>Ci402X^=`0j?dD04QLK01`Q9`0@5AT04AHI
01<H6`0C6AX04ALG018G6P0201DJ7@0O01@I700B5aX04AHI014F6@0K82<05a`O01HK7P0E6Qd04QLJ
01@I7013B4/07b@W01@I700J7b805Q/N01@I700E6Qd05Q/N01PM800G71l05AXM01<H6`0F71`03A<C
01DK6`0F71`0:Bl_02@Y;00J7b<05AXN01LL800201HK8@0E01`R:P0=5RD051la01XU=P0J8c@082Xg
02@^>00L9Bh072@[01LN900B6Qd04ATL01DM7`0C61`051TM014F6P0D6Ad06b0T01PM8@0K82@06AhR
00807B8V0P0E6Qh03P0B5ad04aPN01PM8`0F6al03a@H018G6`0@5AP05adN018H600D6QX0728R018H
600C5Q/04aLK0P0D61/01@0D61X04QHG01LK700P92<0720O00<05a/J00P02PlB010E600730l0CU=G
02L/<00:3aD06b0V01HJ8`805a/T00<051PS01@H8@0B5A/00P0B5QT04@0D61/05QXK01HJ6`0N8R<0
4ADD01PL6`0E6AP05QXI01<I5`0?61L03AHE00hG5P0A6QT04Q/J014J6@063`h03QLF00805b0O00`0
3aPG00XE4P0=6Q<02aP?00D?1`0>6Q000Ph4018M500=5`l041HB010F500@5QH200/@4`0e014F6@0@
5QH03aDE00dC4`0<4Q003aDC01<I5`0D6QH04QPD00hD400>5@h04APA01HM5P083`P04ALD05YPH00f
>ch02PlB01<H70042@d041DH02H[;P0D6QT03A8>00lD3P0B5a<04aPD01@I5@0C5aH0310?00hB4@0A
5AH04aLH018F5`0@51L0724U00462P0H7B4041HF00X@3P0=50h02A0900dD3@0@5a003A<?00/A3@0<
4Q0092T/00T>4@073@d00`T900T?3`0>51800P0?5A<0500>51003A<?00`B3P0;4P/03Q@B00lE4`0=
4a402a4?00hD4P0A5aD06b4O00lE4`0B61H04ALE00L=2`0<4Q003A<A00T?3@0C6AL03Q@B0P0=4a40
2`0<4Q002a4?00dC4@0?5A<03Q@B00T?3@0B61H0318@00X@3P0A5aD051XH008020h<01P03Q@B010F
500@5Q@06R0N02H/:P0=5Q401@d800060@0=5Q4031D@010I500D7AP0=Slj02Xc;P0;50l02A8=00PA
300>50h02a0:00`A2`0@5@l03A8<00X?2@0@5@l200lD3P803Q<=00<03A@=01@N5P0E7aL00P0E7aL0
800b?3@02A<;00TC2`053`L02Q@<00/E3@0D7QH04A/C00`C300=50d03aH?014H4@0B6A806B0I01XQ
6P0C6Q<03aH?01DL5@0B6A80318;00X?2@0;40X03A8<00X?2@0=4P`04QLA00870@0U:R@01``701HK
5@093PP03Q<=0P0>4``200dB2`1A00hC300D6A804QL@01HK500>4``02@h7018G400<4PP03Q@8018H
300G7A8051X@00hD2P0<4@T03Q<<00lD3P0>4`d03A8<00/@2P0@5@h0314:010E3P062`@02a0901PM
5P000P007B8K01LL5@0730D03Q<<00lD3@0?4P/04QD>010C300=40T03a8;00hA2P0A50d03Q4:010C
300A50d03A0900dA2P0J8AX00`X300lF3`0530D05A`E00hE3P083`P03QD>00dD3@073PL02a8;00T@
2@0;40T05aXC01dP6@0?4P/02Pd600lB2`0C5Pl04QD>010C300?4P/03Q4:00hA200;4@D02a4400/A
1@0=4`T04QLA01HK5@0k@3X05AXC018H3P0>50P020h100H<000=40L03Q4:00803a8;00`041<<014D
3@0A50d04QD>00lB2`0=40T03Q4:010C300;3@P0418=014C3P0D5Q42018D3`0C00lA300C5A003a4<
00lA300A4`h03a4<00/@2@0:3`P02a0900hC300B5a0051TB00dB2`0;40T0314:00hC300<4@X02Pl8
010C300200`?2009010C300?4P/030l800lB2`0@4``03a8;00hA2P0?4P/04A@=00802Q06010041H=
00hC300;40T01``5010E3`0X;BT05a`H01<H500H7AT02@d900050@0>4`l03a@@00`A3@0>4`l041DA
0P0<4@d09`0>4`l02a0<00`A3@0;40`03A8>014F4P0>4`l04QLC010E4@0<4@d04aPD00H;1`0B5Q<0
1``801<H500>5AH04Q/P00062@0@6AT03AHA018I4@0<4`/04AP@00lE2`0;40T03Q<<00`A2P1PIEl0
?44k01HK5@0@5@l02a0:00lD3P0>4`d00@H001XO6@011P0051TC00X?2@0200hC300700dB2`0<4@X0
314:00dB2`0D6A804aPA014F3`0300lD3@H03A8<1@0<4@/02@0;4P/07bHO00XD300J91`00`X300lF
3`083`P02a0:014D3`02010B3@0A018D3`0>40/02Pl900X?2@093PP020d700T>20083@L0008000`A
2`0A5Q004aPB00dB300F6aD03A8;00/@2@083@H00P0;40T06P0B5a003Q<<01`Q6P0730D02Pl800lD
3@0j?cP08RLQ0;Jk]@2PYIl03Q<=004600042@<04AH@01HK5@0:3`T02a0:010E3`0730H03Q0;00lA
300>40/03@l:00lA300A4`h0418=0P0A4`h06`0?4@`03@l:00`>2@0D5Q406adH00<5000@4Pd04A<>
01<E400D5Q405QPC014C3P0?4@`04Q@?00`>2@0B50l0418=01LI500D5Q402@/6014C3P0G6A@0418=
00D70P0C5A005ALB010B3@02014C3P80418=00h03a4<01lQ701=CdX06adH01DG4P0;3@P05aTD00X<
1`0P8Qd03Q0;018D3`000@006adH010B3@803a4<00@04A<>018D3`0@4Pd03Q4<1@0=4P`02P0:3`T0
3A8<01<H4P0>4`d04QLA00X?2@0?51003A8>00`A3@0?5102014F4P0Z010E4@0>4`l0=S/g01`Q7@0M
8Qh03a@?014F400?50d041D?00hC3@0<4@/04QLC01/P700i?SX06alN00lC4P062PT03Q8A010F500?
5A<03A<A00/A3`0:40h02a4?018H5P0A5aD051XH02le<`0J81h06b4M01LL5P0=4P`0@4Do04I;A@0D
6A@04QLC014F4P0@518041@C018F5@0G6aX06alN5?ooool001_ooooo03401`<0018A400310H02@hB
00L?5@002a40214H00TA600<4AD0414C018A400C4Q005QHF00X<2`0G6AP06A/J01DG5`0000801`P:
00D5200G61`0NW]o01dN8`020`P03@hC00421`0J6b0020P=00h>5P092A404Q8K00`<5P0000T02PXF
01@D800G5b403PlC00h?4@0@4A<04Q<E00h?4@0<3@l03a0B014B500C51H03PlA00X;3@0=3Q00414C
00803a0B00T0414C014B500A4Q@03@h@01HG6@0K71h04Q<E00l@4P0=3a<00P0A51T00`0@4aP03Q4F
010C600201<F6`0M018E6P0E61d051LL010C600A62002aTT018P;@10D5d0GVik04ADH@0B8Bh06BLb
01<P:@0A6B005AXN018F6@0F6ah0;C8f01dR:00D6Ad00PL:00lD600=4QD05A/K01PN7P0G7Ad04aTG
01@J6P0C6AX01@0A5QT02@0B5aX04AHI01<H6`0B5aX03a@G01LL7`1[L7<082DX00L<3`0201`Q900S
00/@4`0E6Qd04aPK010E600?51L04QLJ01LL7`0O9BD06b4Q010F5P0C6AT0DeUI059GFP0L8BD05Q/O
01LL800@5A/061dS01LM9@0H8C006RHf01PT<`0D7B`05AlZ01<M9`0L9Bh0620V018I7`0@61/041PJ
014I6`0A5QX04aPL018G6`0H7B400P0S:2`0;00K82@06QlS01lT:00K82@05AXN01hS9`0H7B<051TO
01TN900G72003a@H01<H700>4aH020d?014G5`0D6QX03aDE01<I6@0B5QT04ADI01<G6P0E6A`05ATK
018F5`0G6a`0720O01PL6`0F6QT05a/J01HJ6`0E6Qh061dS01@I7@2k`<H0AdaB01hS:@0P9B/061`U
01DI8P0D62404QHQ014E7P0D5ad04aLJ0P0B5QT02@0B5QL04aLH01XN7`0@51<04QHE010D4`0F6QT0
4aTG014I6002010I600G014J6@0B6aX04a`K01XS8P0F7ah041TH00hG5P0@6AP04A/G00PE3P0?71<0
4alG01LR6P084`/04QdE00dG3`0?5A403aDD00hD500M8RD08RLZ018H600A5aL00P0?5AD01@0?5A<0
41HD01<I5`0D6QH04QPD00803aDA00h031<<01PN6P0<4Ph05adL06meM@1;D5<05Q/N01<H700G7200
4aPK028W:P0G7A`03a@@00lD3P8041DA01404AHB018F5@0A5A@04QHE018F5`0A5AH03a<D00dA5009
3Q400PL:01@I6`083P`051XH02D[9`093`/02Q4:00`C300200`B3P0A00lE4`011`L06b4Q01@J6P08
3Ph06R0P00`B400@5Q@04ALE014G4`0@5Q803aDA00hD400<4Q003aDC00/A3`093`d00P0<4Q003@0B
61H02Q0>00lE4`0?5A<02@l=00lE4`0D6QP02Q0>00`B400?5A<0318@01@J600@5Q@00P0=4a401P0@
5Q@03aDC00X@3P083P`03aDC014G5@803aDC00l041HD00X@3P0B61H04aTG00lE4`0H7Q`0:2h/075j
M@11BTD02Q<>00PA300740/03QLB00T?2`0@6A@00P0A6QD01@0H8A`04AXE00X?2@093PP02a0:0080
4AH@0`0@5@l200lD3P0>00hC3@0=50d041PA01@N5P0B71@031H>02@^9P0;5@d01a4900dG3`0F81P0
218:00LA2@094`/200dD3@<031<<00X04aXC01PO600A614031<<010G400?5Pl0318;00/@2P0=4P`0
41D?0P0:3`T0200>4`d000@000hC3@083@L04aPB00P=1`0C61803a@=0P0>4``0300=4P/03Q<<01@I
4P0E6Q<03A8;00lD3@0@5@h02Pl800L=0`083P803A<700lE2P803aD;00<03aD<00dB2`0<4@/00P0;
40X0500=4P`0314:00L<1@0<4@X01@X300P=1P0=4P/0:2dV075fK`1TJF805Q/D0002000A5Pl041<<
018E3P0@4``030l800hA2P0<3`P04A@=0P0>4@X03@0@4``03A0900lC300=4P`05A`E00hE3P0<4``0
1`h7018I4P0940T03QD>00dD3@073PL00P0940T0200B5@h030l:0002000G6Q<04aH?00`?200C5Pl0
4QD>0`0@4``03P0@4`X02a4500`B1@0=4`T03a@=01@I4P0G71H0?44k01@I4`0>4``02a4700/A1008
3P803Q480`0?4P/2010C300900hA2P0A50d02`h700T<1@0<3`P03A0900`>2@0O8A`05ALB00803@l:
01T02`d8010B3@0B50l04A<>00d?2P0>40/04A<>00`A2P0=4P/03Q<<018G400F6a@05a`E00lD3@0>
4``03a@=014F3`0@5@h03Q<<00lB2`0=40T02@`500`?200>4@X02`h7008041<<00@03a8;00d@2@0?
4P/04A@=0P0;4@L0>@0B60l041D>00hC300>4``02Pl901dR7P0I7QX01P/700hC3`0J7a/04QLC00T>
2P0=4Ph03Q<?00lD400=4Ph02Pl;00/@300>4`l02a0<00hC3`0<4@d03A8>014F4P0<4@d03Q<?00dB
3P093PX010T501dR7P1/LFd07R<O0004000<4a<07bT[05ALGP042`T03QLD00P>2@0:4@X03QD=00lE
300:3`P02a0900dB2`0N8ad02Pl900450@0>4`d04QLA010E3`0D6A<03A8<00hC3@000P004QLA01<H
4P0400`A2P0600hC300?50d051TB01<H4@0@5@h03A8;0P0<4@X600hC3@D0314;00l02a8;00hE3P07
4@T05b4I00<:0`022@800@P100X?2@0A5@l0418=00h@2`0?4@`030h900/@2P0=4P`00P0:3`T08@0<
4@/02@h801PM5`0>4`d010T300/@2P052P@020d70002000C61403Q<<0003000=4P/010T2014F3`0;
40T01P/401HK50083@H01``500lD3P0Q9R0092TS00X?2@0F6aD051TC00P=1`0<4@/01``600/@2P0A
5Q003A8<00`>2@0300d?2P0500lA300A4`h030h9010B3@0A4`h00`0@4Pd0600;3@P04aD@00D70P0=
3`X0418=00h@2`0A4`h051HA010B3@0?4@`0418=014C3P0O8A`02`d800L91P082PD0008001DG4P08
2PD03Q0;024S7P0?4@`02`d8018D3`<0418=0P0?4@`03@0@4Pd0:2XU00d?2P0?4@`02P`7010B3@0<
3PT06Q`G00H80`0?4@`03@l:01/M600;3@P00P0?4@`0100A4`h04Q@?010B3@0>4P`500hC3@0600L<
1P0=4P`02a0:01XO6@14BD<03Q<=0P0;40`0700>4`l04QLC01@I5@0E6QH061dI00D:1P0=40d01@X6
014F4P083@P02@h800/@2@0B5a403a@>00P=1`093PX051TE018G4`093@`05QXI00X>3@0@51<041HD
00lE4`0<4Q002Q0>00/A3`0<4Q0200hD4P0<00lE4`0@5Q@04QPF00D;1`0;40X02a0901HK5@0K81X0
4QLB00T>2P0B5a<041DB0P0>4Q42010D4aCooooo000Kooooo`0]00l>2P0>3PP02P`800T<30083@l0
1a0D00X@5P0;41H030hC00d=4P0?3Q804Q4B00d=3@0?4A001PP700P:2@0=3Pl06Q/M00l@4P0A4QD0
3a0D01@E6@082@h0414F00l?5`071`h04Q8J01LG7`1BDU`06QXT010@6`0@41`03`lK014@7P0:2AL0
4A4L00l@500>3a<03a0D014B5P0?41@03@hB010A5@0?41@04a@H00803a0D03<051DI014B500B4aD0
4Q<E014B500?41803PlA01DF600@4A<02@X<018C5@0C51H05aTM00/>4`0=41D04aHK00`?500?4QL0
5aXO01HI7P0I72405APM00lB5`0A51T03aTS01PZ=`0W>TP0Zkc70>Cdn`3Ahnh0DF9_04YHH`0]>T<0
4a/R01XO8`0<3Q805QXM01HK7P0E6Qh04aPJ01PN7P0D6A/04QPG01DK6@0I7ad05Q`I00lE4@0?5A80
51XI01DJ7@0D6A`00P0B5aX0300A5QT051TL014F6@0A5QT04QLJ010E600C61/07R<V018G6P0E6Qd0
51TL03Pm@0804QLJ01X05AXM01/P8`0L8B@06AhQ01@I700Q9bL0:Bl_024W9`0oADD0/;Jf0:jc]@0M
8RH06AhR01XO8`0F6b40;34g02H/<`0J8C00624a01<M:`0F82d07BHa01PQ:`0F7bL041PO010G7@80
5Q/O01X03a@G018G6`0E6Qh05AXN01LL800L8BD05Q/O01DJ7P0D6Ad061dQ01<H700I7R80=CXn02hc
>@0E6R0051TO01/P900F6al05AXN01DJ7@0G71h03aDE014G5`0J820051XJ01@H6`804QHI0P0E6AX0
300B5QL05QXK01DI6P0@51D04aLH01DI6P0C5aX04AHL01PL9@0H72@0@TI?01PL9@805QXS00P04aLR
014E800D62<05QXU01@H8@0E61`04aLJ018F6@804ADF0P0B5QL0>P0E6AX04QHG01<G600O8b@05a`M
018I6`0E7Al051`N010H6P0B6aX05AhM00XC4P0=5QD041TG014J5`0?61D03aTD00HA2`0E81X02aH@
018M5`0?61<041LC00X@3@0=4a406QlN00hB4`0L82<09b`]01@J6@0B61L04ALE018H5P0D6QP04ALE
00hD4P0?5A<041HD010F4`0B61D04aTF00hD4P0G7A`03A<C01dS8`0D6A`02a0C01TN8@0<4A@03A8D
014G5`0@5QH051PF018G500?4a803Q8A010D4`0C5aH2018F5@0=014E500@51<03a<B00lC4`0<4Q80
5adL00dB4P0;4@l06AlM01lU8P0=4a00318>00hD4@02018H5P0400lE4`0>51<041HE00lD4`80318@
0P0>51807@0?5A<041HD014G5@0@5Q<03Q@A00lE500F71`04ALG00hD500@5QH02a4A00dC4`0U:b/0
4QPH00H<300B61P03Q@D00dC4@0M8b4020h<018H5P0?5A<04aTG01@J600>5180318@00lE4`0@5Q@0
318@00803aDC00D041HD00lE4`0>51804ALE00hD4P02014G5@0E00hD4P0=4a403aDC01LP6`0@6A@0
1Pl:00hG4P0740/02Q<>00/D3`0<5A003QLB00TB3@0>5a8031@?00lD3P0H7AL051TC00/@2P0>4`d0
5Q/E00803a@>0P0>4`d03P0=4P`0318<00hG3`0=5`l031H>00TC2`0A6a<03AL?018L500Y<b/08B/S
00XD300>61002A<;0P0<4``200dD3@8031<<01@03aH?014H4@0>5@h041L@00lF3`0=4`d03A8<00hC
3@0@5@l0314;00dB300@5@l03Q<=010E3`0=4P`020d7010E3`0>4`d03a@=00dB2`<0314:02L04QL@
0866O`2@UHh0:BhW01PM5P0D6A8041H<014G2`0@5PX03A<801TO5@0]<bT09BXR00`A2P0>4`d03a@>
00hC3@0?50h03a@=00P=1P0<4@X02a09010E3P0>4``02a09020U7P0M8Q`051TB00P=1P0@5@h03A09
010C300?4P/03A09010C300>4@X04QD>00d@2@0<3`P00P0>4@X00`0D5a0061dF00hE3@0200`C2`0;
00XA2@0<4``03A@<00XA2@0<4`/02a8:00T@200?5@h04QD>014D3P0?4P/00P0>4@X00`0:3@P041<<
010C300200lB2`06010C300A50/03A<700hD200?5@/03a@=0P0@5@l0200G71H02Pl900dB2`093`D0
3Q@800`B1P0A50/041<<0`0?4P/01@0>4@X04QD>01DH4@0>4@X02`h7008041<<00d05QPC03@f<@0J
71L03Q0;01PJ5@0B50l071hI00`>2@0@4Pd03Q0;00/=200A4`h03Q<<0080314:00l03A8;010E3P0A
5Pl0314:00/@2@0=4P/04AH?00lD3@0>4``04A@=01LJ4`0B5@h04A@=018E3P0>4@X00P0@4``03P0>
4@X03A0900lB2`0B5@h041H<00hD2P0D6A4041D>00dB2`0?50d03Q<=00hC3`0:3`/02a0<0P0@5A40
300B5a<03A8>00lD400:3`/03Q<?00`A3@0;40`03A8>00hC3`0:3`/03A8>018G4`8041DA0P0A5Q80
500@5A40314=018G4`0?51004aPD00`A3@0E6QH03A<C01lX:02IXJ80:2l^00hD4P0>5A003A8=00T>
1`0;40T041<<00d@2@0A50d03A8<0P0<4@/02P0A5Q004QLA00/@2P0>4`d020d701PM5`1bMg405Q/E
00`A2`0>4``200dB2`0600`A2P0=4P/03a@=00hC300=4P/0314:0P0:3`P00`0;40T03Q<=00hC3@04
00hC3@D0314;03402a8;01DL5@0;50`01`h804A;A00L8a`03aH?00hC3@0G6QD05ALB014C3P0@4Pd0
30h900dB300@5@l0314;00/@2P0?50h02a0:02<X8P0G71H01``600T>200<4@/08bPR061UGP0A5A00
61dF00T>1`0B5a003Q<<010E3P0K81T05AXC01@I4`0Q9Ql03Q<<00lD3P0;40X0314;00X?2@0?50h0
3Q<=00T>200:3`T0314;00/@2P0=4P`04AH@0080418=02803a4<00d?2P0>40/0418=00d?2P0B50l0
4aD@00lA300>40/03a4<01@F4@0H6QD0418=01DG4P0T9R404aD@00lA300A4`h0418=018D3`0@4Pd0
3@l:00h@2`0D5Q404aD@014C3P0F61<04aD@03Xl=`1VJ6<0@T@o010B3@0D5Q403Q0;0`0?4@`200h@
2`0=00lA300;3@P03a4<018D3`0C5A003a4<010B3@0A4`h0>C/f018D3`0L7QT01PP501<E400200lA
3004014C3P0B50l0418=00hB30D03Q<=01D03a@>00dB300<4@/061dG04I;A@0B5a401P/701<H500N
8al05AXF00dB3P0A5Q803a@@010E4@0>4`l03a@@00hC3`0@5A0041D?00hC300?50h00P0=4P`04`0L
8Ad09BXV020U8@15BDP04QHE00hB4@0=4A003aDA00hD400=4`l03Q@@018H500E6aL03A<?00lE4@0;
4@d03aDA00dC3`0A61800P0@5@l01P0<4@/03Q<=014F4@0;40`03a@@010D4P803Q8A00<0310?00/?
3_ooool04oooool001_ooooo00d07AdE014B2`0C50l0004000`@4@052Pd030lD00/>4`0W:2d03PdC
00T73P0A41D03`lA00<03Q0?02<03Q0@00h?4@0=3Q0061TL00L8300;3100414F00L83@0A4AT02PXB
02PX<00c<c/0aLG?02d]=`0A4Ad01`LC01DE8@0A41h02PTG00P8500?3aH00P<8018C600<3A805QLL
02LX;@0C51T00`@900h?500X:Bh061TN00d>4P0?4180414C00h?4@02018C5@0T00h?4@0=3Q003@h@
00L82P0F5aT02``>00h@50062@h04aHK03Tl@@0M82D02`hC01@G700;3Q<02PdB01LJ7`0F6Ah05APM
01LR:`0@8S00=4MF09ja`03`ool0dN?a041AG`0C8B`04AhW01HN900E6Qd061TM014E5`0C61/05A/K
01LM7@0E6a/04aTG0P0B61H0300D6QH04QPD00`B3P0A614061hL01<H6`0G71l05Q/N00lD5`0@5AP0
6AhQ01HK7P804AHI00@051TL01LL7`0E6Qd05AXM0P0D6A`0>P0E6Qd05a`O01dR9@0/<C@06QlR02P]
<00N8bH04QLJ01dS8`0C6AT06R0P01HL700e>c/0>Sm201PM8@0F6al061dQ020U:`0Q9R`041HM01HN
:@0D7RX04Q`X01<K:00F7BT06B0Z014H800B61l05AXP01LL800H7B405AXN028W:`0T:Bd04aPL01@I
7@0G720041DI01<H700F6al051TM014F6P0B5a/05Q/O01HK8@0H7B<04AHL02<X;00:3a<06AhR024V
:@0:3Q004ALG00L=3@0E6a/04aTI01DI6P0D61T201<G600E01LK700J7Ql05ATJ01/O800A5AH04ADH
01TM800G6Ql05ATS01dQ;00C5b80310K00L;500D624041@M01TM9P0@51d0<3@m00/?600H7B<04aLI
00804ADF00d04aLH018F5`0A5AH04QHG01PL7@0J7Ql05ATL01TM800B5QT051TM01lT:00P9BT05Q/N
008041DH00h05adM00lE4`0?5A<05Q`H00hD400D7QP02A@<00lH4`0:4`l04a`I00lE4`0>51<041HF
018F5`804aLH02T04QHG01@I6@0E6aT03aDC010F500N92808BLU01XP7P0G7A/0318@00dC4@0M8b40
10X801@J6P0B61P04AHI00/A4@0D6QX04aTI00hD50052`/02Q0@018H60093`l02a4A00T=3P0@51<0
1`/:00`@3`0C5aH041@C00lC4P0@51<04ADD00hB4@0=4A003a<A00lE4`0?5A403aDC00hD4P0200dC
4@0501LM6`0=4a4041HE014G5@052`T00P083P`08`0B61H03aDC00`B40073@/061hL00H<2P0H7Q`0
2@l=01TO7@0=4a403Q@C01TO7`062PX02Q0@00/A4@0=4a<041HF00X@400E6a/0318B00@:2P0?5AD0
3Q@D01LM6`1SJFL041HD01lU8`0630X07B<Q020V900?5A<04ALE00D;2@0:40h04ALE00803aDC0P0>
518200dC4@0600H<2P0F71X03A<A00T?3@0@5Q@02@l=0P0>510200dC3`80318>00X04ALC00lE4@0>
51002@l;01LM6@0Y;b/051TC010E3`0=4P`0314;0P0=4P`0900<4@/092TS0003000;40X03Q<=00T>
200@5a003QD>00XA2P0>5@h04QTB00lF3`0H7aP0<CPa010G400>5@h041L@00/B2`0@5a004QTB00hE
3P093`T05A`E00dD3@0@5a003aH?00dD3@0<4``03A@=00lE3P0=4P`0314;014F400B5a403A8<00X?
2@80314;01/03A8<00hC3@0>4`d041D>00hC300:3`P01``5014F3`0Q9Ql0>d0i0<gBb`3[l>T0=S/d
00dB2`0320404AL=010F2P0=4`L03aD:014G3@0?5@/03aD<00X?200@5@l03Q<=014F400>4`d00P0<
4@X200dB2`<03Q<<0P0=4P/05@0<4@X03A8;00hC300;3PL03a8;018E3P0>4@X030l8010C300F6A80
30l800/>1`0F6A801`X30495?P2TZZ007R@J00P>10052`405adC00/A1`0600hD2P18014D3@0@4``0
3A0900d@2@0?4P/041<<00d@2@0B5@h041<<00/>1`0B5@h04A@;00T?0`0A5``02a47018G400;40/0
0PL301hS7`0b=c4041D>00/A1`093`@041H:01DH3`0?4P/04QD>014D3@0=40T04A@=01@G400;3PL0
30l801DH4@0>4@X05aXC01/M600:30L03@l:010B3@0=3`X04A<>02h`:`0A4`h030h900d?2P0<3PT0
3@l:00/@2P0=4P`03Q<=00lD3P0=4P`0314;00X?2@0E6Q@01P/501DJ500D6A<02@h800lB2`0C5Pl0
3Q4:00d@2@0>4@X02Pd6018E3P0H6a@051L@00`?200C5Pl030l80P0B60h04P0:3`L02a0900`A2P0<
4@X02Pl900P=2@0<4@d041DA00hC3`0;40`03A8>00/@30083@T0314=018G4`0>4`l020d900X?2`80
3A8>00@02a0<00`A3@0=4Ph03a@@0`0@5A401`0?510020d901XO6`0;40`0314=00/@300=4Pl00P0=
4a4200`B400400dB3`083@T02Pl;010B3P804A<>00d04Q@>00hC3@0=4P`02a0:00dB300?50h02Pl9
018G4@0<4@/06b0J02T^:00L8A/02@h800802@h700<03Q<<00D:0`0;40T00P0@5@h00`0G71D03Q<<
00hC3002010E3P0D00P=1`0;40X03Q<=00X?2@0;40X04aPB00dB300<4@/04aPB00hC3@0@5@l01`h7
00T@2@094`/05AlG01`S700E71D03aH?00/@2P0<3`X200d?2P0P010B3@0A4`h03Q<=00H;1@0N8ad0
3A8<00`A2`0320803A8<01@I4`0C61803Q<=00lD3P0G71H0?d@m018G400<4@X041D>00D:0`0<4@X0
20d601PM5P0@5@h0314:00lD3@0<4@X041D?00dB30052P@03a@>00H;1@0=4P`200X?2@0G00dB300A
5Q003a@>00hC3@0E5a802P`700T;1P0>40/03@l:00X<1`0>40/03a4<010B3@0?4@`030h900/=200M
7aX0CU1;01DG4P0K7AP0OGmj01<E400A4`h00P0H6QD00`0@4Pd020X500X<1`0200`>2@05010B3@0C
5A004A<>018D3`0C5A000`0A4`h200lA3003010B3@0?4@`0418=00804A<>00@0418=00lA300?4@`0
3Q0;0P0?4@`3018D3`0c014C3P0@4Pd0418=010B3@0B50l051HA00h@2`072@@030h900lB3@0=4P`0
3a@>00`A2`0;40X03Q<=00dB300@5@l04AH@00X?2@0730H02a0:018G4`0320@0314=00hC3`001@40
41DA018G4`083@T03a@@00`A3@0@5A404AHA018G4@0>4``02a0:01TN60000P008RLS01DJ5P0H7AT0
7B4P00X>3@0F6QT03Q8A01<H500>4`l02Pl;00`A3@0@5A404AHB00802a0<00`04AHB01LL600E6QH0
3A8<00`A2`0;40T06b0J00hC3@0?50l08RLS00lD400>4Q0200lC4P803A4@5?ooool001_ooooo00d0
1@D000X;100J6aH030h;01LH6@0A5AP0310C01HH7@0l?D809bH/01HD6`0>3A803PlA00<03Q0?02<0
3Q0@00h?4@0:2`d03@hA00h?4`082@d0414F01lP9@0C4a/0000700/;4`0=3AD0@T9<00412`0>3QT0
5aLS01HF8P071Q@02@PF01PH900B4aT051DJ014B5`0D5AX061TN024R9`0>3Q<0:BX_06m`M@1YJVl0
30dB01DF6P0?41<03a0B00h?4@02018C5@0=00d>400?41803PlA00`=3`0F5aT04a@F01<E600>4AH0
7R4V0413B00W:Rl04aHK01@G700200lB5`804QDJ020061/P01TS;@086RH04bDc03U;F@1cQI<0J7Z8
024b?`0?7BP031TR00hF7@0@5AT05QXM018G6@0C61/05A/K01LM7@0E6a/04aTG01HL6P0N928082HR
01TO6`0B61@04aXC01HL6P0C61/05AXM01@I700@5AP051TL01<H6`804AHI00<04QLJ01<H6`0B5aX0
100C61/02@0D6A`05Q/N018G6P0O92L04QLJ024V:@0J7b8041DH01hT900201PN7P0G010F5P0P9RH0
7B8U01<H700A5QX041DI01@I7`0F6b4041HM01DM:00C7BL04Q`W01@L9`0H82T06b8Z01<J8P0C6B00
51TO01HK7`0G72005AXN014F6P0S:2`00`0E6Qh0100<4AD05Q/O01PM8@0G720201DJ7P0C01TN8P0E
6R004aPN01hS:@0731006AhR00P=4@0>4aH0FEmP02H/;00A5aL08bTY00X@400?4a@03Q8C00dA4P0>
4Q<04ADF01@H6@0300lC500@024U:00U:B`06A`Q018F800G6bH04QHQ01@H8P0<41T04QHO028V;`0J
7RL05AXP03m3B`0J7RL06b0V01<G6@804ADF00@04aLH018F5`0A5AH04QHG0P0C5aP05P0>4QD051PK
00hB5@0@5AT051TM01DJ7P0C61`03a@G00hC5P0C6AT02Q0>01@J5`0A5a<02@l;00`D3P084`/01@h9
00XC3`0C71T05A/K010F5P0A5aL201<G600B018F5`0A5AH03a@A00lE4@0?5A<04ALE01PN700E6aT0
318@01`R800G7A/061hL0006100K8B405a`O00lD5`0@5AP04QPI0P0A5aL04P0C6AL04QPF010F5P0>
51@03A<C00X@400F6Q/05a/L01XN7P0A5A@02`l>018F5@0?4a8041@C014E500>4Q403A8>00lD4080
3aDA00`03Q@@00hD4P0=4a403A<A018H600;4A401P`<00lE5@0B61H0318@00lE4@0;4@d200`B4080
20h<01h05Q`J01<I5`0>5180318@01PN700;4A406AlO01XP800H7Qh05Q`L00/A4@083Ph041HF00T>
3P0B61P041HF014G5`0?5AD03aDC01@J600I7ad051XH01<I5`042PP02Q0>01@J600>5180318@01@J
60093`d200lE4`803Q@B0P0=4a401P0<4Q00728P00P>300U:bT0C59@00dC4@803Q@@0P0=4`l200`B
3P0U00lE4@0B61@04aTE00`B3P0>510061hJ010E3`0>4`d03A8<00hC3@0A5Q004aPB00hC3@052P@0
2@h801HK5@0L8A/04QLA00hE3P083`P00`X300T@2@0<4``020l800T@2@0P9b002A0900dD3@0?5Pl0
3QD>00P?200120403A@=00L>1`0D6a@03A@=00`C300200/B2`0:00`C300=50d04ALA01DJ500D6A<0
314;00T>200A5Q004QLA00`A2`<03A8<01L03Q<=014F3`0F6a@061dF01DJ4`0B5a0051TB014F3`12
Ad00Jg1Y01dQ700@5@h04AH?00dC2@0<4PH02@l300X@1@0<4PP02a4700P=1@0730D02@h800L<1P02
01PM5`80314:0P0=4P/300hC30803A8;00<0314:00dB2`0>4``00P0=40T0400>4@X03a8;010C300?
4P/030l801/N5`0;3@T03a8;01`O600F6A80?D<i0003000B60h020h401@J40073@<600hD2P803a8;
0P0>4@X2010C300D00H90P0A50d03Q4:00P;100930D06A`E00X@1P0E6a00008002H[9@0Y;RT051TE
00P=2@0E6QD02a0:00hC300A5`d03Q@:014D3@0>4@X2018E3P0600hA2P0B5@h02`h701<F3`062@80
30l80P0?4P/03`0C5A002P`700lA300E5a803Q0;00X<1`0B50l020X500h@2`0C5A003a4<00h@2`05
2P@01``600`A2`02014F400H00lD3P0@5@l03a@>01XO6@1RIf40<3D_00T>200A50d03a8;00X=1P0>
4@X04aH?010C300:3@H03Q4:01@G400B5@h05aXC014D3@0D6Q005A/A00hC2`0?50d041D>0P0;40X0
0`0?51004aPD00lD400200/@3006010E4@0B5a<04AHB00hC3`0=4Ph03Q<?0P0=4Ph300hC3`@03A8>
0P0>4`l02@0E6QH0<CHb04mDD00K81`01``800hC3`0@5Q802Q0<00P>2P0200L=2`0800X>3@0P92<0
3a@@00`>2`0E5a803a4<00`>200;3@P200T>200F00dB300?50h03A8<018G4@0;40X04AH@01PM5`0@
5@l03Q<=024V7`0=4P/02a09018G400A5Pl020d600dB2`062`@041D>018G40083@H03a@=014F4080
4aPB00<0314;00X?2@0@5@l00P0@5@l03@0H7AL03A8<00H;1@0120404aXC00lI4@0C7AD04aXC00T@
2@042`@03Q<=00hA300=3`X00`0<3PT06`0<4@/02Pl900lD3P001@0041D?00lD3P0;40X03Q<=00dB
30093PP02Pl900lD3P0G71D01P/400hC300C61402a09010E3P093PL05a`E010E3P0<4@X03a@=00`A
2P0>4`d03A8<00L<1P0200hC3@03014F400B5a403A8<0080314;00<02a0:00X?2@0A4`h00P0>40/0
0`0@4Pd04Q@?018D3`0300lA300B00h@2`0=3`X030h900`>2@0I6aH071hI01HG500[;BP030h900lA
300E5a805QPC010B3@0<3PT03@l:00`>2@0:30L03@l:0`0@4Pd01@0?4@`03Q0;010B3@0B50l04A<>
0080418=00D03a4<00d?2P0;3@P02@/600`>2@02010B3@0400lA300@4Pd0418=014C3P80418=0`0?
4@`2014C3P0^010B3@0?4@`03Q0;00lA300@4`h03a@>010E3`0=4P`0314;00lD3P0A5Q0051TC01HK
5@0@5@l03Q<=018G4@0C61@02@h:01HK5`0G71P02a0<010E4@0E6QH04aPD010E4@0;40`08bPT00D:
1@093PP0314:00X?2@0=4P`06AhH06ebKP0H7AT06b0L020T8`0<40l04aLF00T=300B5a<03a@@00dB
3P0>4`l0314=00T>2P8041DA00d05AXF01/P700I7QX04AH@014F3`0H7AH020d701TN6015BTD03a@@
010E4@0=4Pl0310?00803A4@00<03Q8Aooooooooool04_ooool001_ooooo00d04Q<=00/<200>3`X0
3Ph<00d>3@082@X06AXK00X:3@0F5AX02`X?00d<4@0B4AH03PlA00<03Q0?02<03Q0@00h?4@092P`0
3PlB02TZ;P0A4QH02``A02X[<00J6al04a@I00L83@0C51T00P8901LG7`0I6B405ADN00@43@0?3aX0
2PXF018B700?41H05AHK00001@0B4aP03PlD01@E6P0A4QL01@H;01HG700J6b004A8G010A5@0>3a80
3a0B00d>4002014B500:00`=3`0B4aD03PlA01<D5P0>3a405AHH018D5`0:3A8030lD01@G70804A@I
02T041<H01PK800N8BH05aXO01@G700E61d04aXQ00XF800?72L03QdX01l^>P0V=D404B0/00TF800B
7BH05alV018G6`0D5a/04ADH01<H6`0E6Qd05Q/N01DK6`0C6AT03aDE01/Q7`0O9B<051XG01DK5`0G
7AT04ALF00lD5`0@5AP04QLJ01<H6`0L8B@03a@G010E600D6A`05a`O01HK7P05018G6P0U01<H6`0D
6A`02PlB01DJ7@0?51L06QlR01LL7`0A5QT051XJ01PN7P0G7Ad06AlO01PN7P0D6A`0724U01PM8@0E
6Qh051TO01<H7P0D6R406B4Y01LP:@0F7RP051dV01HN9`0H7bL06QlV01HK8@0C61h05APM01HI7P0E
61d03Q<G02`a=@0D6Ad041DI01PM8@0301LL80805Q/O00/05a`P01TN8P0G72805AXP01@I7`0m@TH0
51TM018G6`0B5aX0;C8d01hT900201@J6P0J014G5`0C5aH04QHE014E500B5QD05ATI01HJ6`0A5AH0
51PK014E600F6Qd05QTN00hA600?4ad04aLP00`@6@0B5Qh03Q<J01@I7`0C61d061dR00`A5@0F6al0
20dB01DJ7P0C5aH2014E501d01<G5P0B5QL04ADF010D5@0E6A`0720S01HJ7@0F6Ah03a8G010C6P0?
4QT041<I01@G700C5aX04QHI01@H6@0@5A80314=01HK5P0D6A<06B4J03]5?@0C71L04APE00hD500I
7R404ADI01<F6P0C5a/051LJ01@E6@0C51H04aPE01@K500A5a<041HB01<I5@0B61H03aDC01HL6P08
3Ph07R@T079hN00Z;c8041DI00dB5`0@5AX051TL00X@400<4Q00<cTf05=IE@0Z<2h01P/:01HL700>
51@020`?01LK7@0D61T04aLH04U=CP0e>CP03a<B010D4`0A5Q803Q<?00dB3P0?50h03aH>00hE3P0>
5@l03A<@00dC4@0=4a<020d@00`A500>51H03aDE014G5`0=4a40;C<_00dD3@0@5Q803aDA01LM6@0@
5Q@04QPF00881P0E6a/04QPH03i4A00c>3/010T<018G6P093Q4051TL00dB5@0>4aH02a0C010E600F
6ah03a@G01HJ7@0=4a<03A<B018H5P0C6AL05Q`J00/A3`0B61H010X8018G5@0K8Al020h<01@J6009
3`d200lE4`803Q@B0P0=4a401P0:40h0:Bl]01TO7@0I7ad0;38`00dC4@803a@@100>4`l00`0?5100
3A8>00hC3`0200hC3`0O014F4P0@5@l03a@>00lD3P0@5@l04QLA01@I4`0C61803A8<01TN600@50l0
4AH@018G4@0G71H051TC00lD3P0@5@l04AH@00hC3@0=4P`051TC00`A2`0?50h02@h800`A2`0>5@h0
20l801/R6`0<4``04APA00P?200200T@2@0600XA2P0;4P/031<<00`B300<4@/03Q<=0P0?50h2010E
3`803Q<=0P0=4P`06@0<4@/03a@>00lD3@0;40T02@h700dB2`0B5a005AXC00`A2P0F6a@03A4;018G
400A5Pl03A<900hD200=4`L03A<800hD2P0=4`T03149010E3P0>4`d020d701dR700P9Al01@0=4P/0
0`0>4``03A8;00dB2`0300`A2P0:00dB2`0H6a@05APA014D3@0C5Pl04QD>00hA2P0E61402Pd600d@
2@803Q4:00L0Gf9K01DH3`0<3`P051L>00H90@0B5@`03A0700H041<:00<030l800hA2P0@4``00P0A
50d0>@0@4``03a8;00hA2P0C5Pl09BPQ010C300B5@h03A<900lE300K81T0UY^E09fRW@0j?c/08BHR
00`A300>4`d0314:010F300630803A0900hA2P0B5@h04aH?014D3@0@4``04QD?02/^9`0A50d030l8
01DH4@0A50d030h9018D3`0=3`X030h9010B3@0>40/030h900/=200=3`X030h900/=200<3PT08RLS
010E4@093PX03Q<?010E4@0>4`l041DA00T>2P0=4Ph05ATE014F4P0=4@`03A09010C300300hA2P0?
00`?200`<b`04QD>01<F3`0=40T041<<00lB2`0>50X03aD;00`A2@0<4@X03A8;00lD3@0?50h03Q<?
00802a0<00<03A8>00lD400?51000P0@5A4200`A3@0600lD400=4Ph0314=00hC3`0?51003Q<?0P0=
4Ph00`0;40`02Pl;00X?2`0200/@300D01/P700d>CD03a@@00hC3`0@5A403Q<=00lF3`0>5@h03Q@?
00hB4@0?4a@0C4e?02X[;00A4A0051@A00h?2P0C5@h0418=00`A2`0=4P`300lD3P07014F400<4@/0
314;00dB30093PP03Q<=00@90`0200lD3@0:00P=1P0<4@X04QL@06Y_J00U:R<02a0900`A2P093PL0
3Q<<018G4@8051TC00P041D?00hC3@0B5a40<cPb00`A2`0@5@l04aPB010E3`802Q4:00L02A<;00dG
3`0>5@h03A@=01@K500=4P`03A4;00803@l:00X03Q0;00lA30083@L041D?00`A2`0730H03a@>00/@
2P0A5Q003Q<=0P0<4@/00`0=4P`02a0:00T>1`0200`A2P0C00X?20093PL0314:00P=1P0B5a003A8;
00T>1`0<4@X02Pl800/@2P0<4@/02a0:00P=1`0B5a402@h801<H4P0<4@/02Pl900/@2P0200`A2`08
00lA300A4`h04A<>00lA300>40/03a4<014C3P0>40/200d?2P0;00h@2`0?4@`051HA00`>2@0=3`X0
7AlJ00lA300;3@P03Q0;010B3@0A4`h00P0@4Pd02@0B50l04A<>00h@2`0>40/0418=014C3P0B50l0
3a4<00h@2`0200lA300500h@2`0=3`X03a4<010B3@0A4`h00P0@4Pd2014C3P<0418=00D04A<>010B
3@0=3`X03@l:00h@2`0300lA300800h@2`0=3`X03@l:014C3P0@4Pd03Q8<00lD3P0@5@l200hC3@0;
010E3`0;40X03Q<=00lD3P0=4P`02a0:00lD3P0A5Q80314=010E4@0>4`l00P0?51006`0;40`03Q<?
00hC3`0F6aL0?44m01LL5`0E6Q@02a0900hC3@0K81X0=CXd01XO6`0@5A405Q/G01XN7@0?4a804ADD
00/?3@0A4a004A<>01@F4@0E5a804Q@?00d?2P0>40/03@l:010B3@0201@F4@0=00h@2`0=4P/0314;
01LL5P0=4P`041DA00lD400@5A403Q<@00dA400?4a804QHE00lC4P0Dooooo`006oooool020000000
3`l=00X:20092@L00`<201`L6P0I61H02@T90P0@41800`0?3a403@d?00d?3P0300d?3P0K00d?3`0=
3Q001PL900l@4`0P8BD03a0D00<42@0;31403PlB01HG6`0:2`l0414E00h?4`0I6Ql0>3Tn03`m@P0H
620051@L00h>600K6b<02PXB01TI8@0F5Qh0<30h00X:4P0;2a<03`lG00802@TA00H03PhE00l?5`0I
6Ql03PlB00l@4P0=3Q02014B500f00d>400A4Q@04a@F01TJ700>3a405QLI00`>4P0<3a@051LL01HI
7P0E61d051LL00/>4`0F6Ah06QdR01@G700F6Ah04QDJ014F6`0A61h03aPO00`E7@0>6b@05b@]018O
:0095Ql05b4Z01dU:`0B6Qd04QLK00hC5`0B5a/04aPL01@I7@0C61/04QLJ01HL700V;2`09B/[014G
5@0@5Q@04QPF00dC4P0?51L04AHI010E600B5aX05AXM018G6P0A5QT04QLJ01@I700E6Qd051TL100C
61/09`0D6A`05AXM01@I700H7B005AXM01HK7P0E6Qd051TL01DK6`0H7Qh04aTI01DK6`0B61P041DH
01<H700?51P051TM01/P9P0H7B<05Q`R01HM9@0E7RD051dT01DL900G7BD06AhT01`Q9`0G6b404aHM
01@G7P0E61h051LL02T^<P0oA4P0724U018G6`0D6Ad04aPL01HK7`0201DJ7P0@01HK7`0H7B4061dQ
00/@5P0M8RP09BX`07EjOP0D6Ad041DI01@I700E6a`03A<C00T?3`0?5AD05adM014E50804AHB01H0
4ADD018F5P0C5aP04QHI01LK7P0C5aX04QDJ01PK800K7RD04QHO02``>@0N8bT041DK00`A5`0G7200
7R<W01DJ7@0A5aL06AlP01DK6`0B61H04aLE0P0A5Q80A00C5aH04QHG014E5P0C5aX04QHI01XN8@0D
5a`04QDJ00d@5@0A51`061/R01LJ8@0B5AX04aLJ01DI700>4Q804AHB01HK5P0C618041D?018I4@0h
@SX03Q@@010F500;4A406QhQ018E6`0@4aP051DJ01DF6`0E5QX05AHH01@H5P0@5a0031<<00`C3@0=
4`l03Q@B00/A3`000P009R`/01DK701JGf808BHY014F700F6R<061dS00`A5@0;4A403A<A010F4P12
BD80?48n01<I5P0A5aD04aTI00dA50000@@05ATL00dA4P0E6AX0;c<b00lC4P0@51<04AHB00hC3@0=
4P`03a@=0P0>5P/0;P0=50d03A<?00`B400<4Q<061dQ00P=4@093Q4041HF00L=3@0@5Q<09bdY00T@
2@0?5Pl01`d9018H500>518041HD00dC4@0?5AD020d@018G6P0=4QD082DX018G6P093Q406AhQ010E
600=4QD07R<V00P=400]<SD0004401LL7`073@d05A/K00D;2@0:40h010X801LM6`0>518092XX00T=
2`29Shd0BU1>00@:200I7ad200lE4`803Q@B0P0=4a42018H5P0401HL6P0A5aD020h<00`B40H03Q<?
00H03a@@00/@300;40`03a@@014F4P0?510300lD3P0<010E3`0A5Q004AH@00<70P0Z;bT00@H000hC
3@042@<00`P2010E3`0K81X05AXD0P0;40X03@0=4P`02Pl900H;1@093PP041D?00/@2P0B5a404QTB
01PO600@5a001Pd601XQ6P0>5@h00`0<4``00`0;4P/02Q4:00`B300200hC3@803A8<00D03a@>014F
400>4`d03Q<=00dB300200`A2`0=00/@2P0;40T03A8;018G400C61403a@=00P=1P0>4``02a09024V
7`0A5Pl01@X3014G3@0200dC1`0900`B1`0;4@L02a4700hC2`062`@0314;00P=1`0730H0314;00L0
3A8;01@0314:00/@2@0;40T02a0900dB2`0F6A805aXC01HI4P0@4``03a8;018E3P0930D01`X301XM
5P0F6A803A0901HI4P0C5Pd03a8700/>0`805QT>00<02Pd300lB1`0?4PL00`0?4PL0100?4PT02`h7
00d@2@0@4``2014D3@0E010C300M81T03a8;01<F3`0`<b`051L@00/>1`0>50X051TA00`A2P0G71H0
:Rl/02HZ:@0P92<01P/700hC3@052P<02a4800`B200=40T041<<00804A@=00@03a8;00/>1`011000
5aXC0P0C5Pl0GP0H6a@09bXS018D3`051`801PP301hP6`0K7AP01`T400lA300=3`X02P`700`>2@0D
5Q406A/F01`Q7@093PX01@X600hC3`0C61@04QLC00H:1`0=4Ph01``801DJ5P000`00314;00/>200C
5Pl04QD>00/>1`0?4P/05aXC02/^9`0520401PT200D80@0=40T041<<00`B200=4`T03Q<;00/@2@0=
4P/03A8<00P=1`0730P041DA01@I5@0=4Ph02Pl;00/@300<4@d03Q<?00T>2P0;40`03Q<?00T>2P0:
3`/041DA01<H500?51003Q<?00lD400<4@d02Pl;00/@300<4@d02Pl;00P=2@0Q9R802Pl;00050@07
30P03a@>00`B200@5@h04QLB00hB4@0<3@l0000400P92`0@40l0410>010A300>3PP03a4<00T>200:
3`T02a0:00P=1`0<4@/07b@N01DJ500?50h201<H4P0?010E3`0A5Pl00`P100H:1@0H7AH010T200`@
2`0U:R<02a0901@I4P03204010T201<H4@093PP02a0:00<03Q<=00l04AH@04I;A@0B5a403A8<00hC
3@0:3`T01`h700XA2P094`/02aD=00/B2`0<4``05QdF00dB300>4@`00P0?4@`02`0B50l04aD@01HK
5@062`H00`P201<H4P052P@03Q<=014F400;40X020d700802a0:00<01P/500`A2P0=4P/00P052P<0
;00?50d03Q<<00T>1`0>4``02a0900T>1`0;40T0314:00X?2@0A5Q0051TC00`A2`0E6Q@01``600dB
300;40X03A8<00lD3P0>4`d0314;00lA300<3PT03Q0;018D3`0<3PT01`T4014C3P0>40/030h900d?
2P0>40/03a4<010B3@010`003@l:00T;1P0;3@P05aTD014C3P0>40/03@l:00h@2`0?4@`0418=0`0B
50l0100A4`h0418=01<E400B50l2010B3@0800lA300=3`X03@l:010B3@0A4`h03@l:00X<1`0;3@P3
00h@2`0700d?2P0>40/03Q0;00lA300>40/03a4<010B3@02014C3P0700lA300C5A005ALB00d?2P0<
3PT03Q0;00hA300200dB30803Q<=00l03A8<00`A2`0=4P`03a@>00hC3@0?50h04AH@00dB3P0:3`/0
3Q<?00P=2@0B5a<04AHB01TN6P0:3`/00P0=4Ph040052PH01P/6014F400<4@X02@h80005000R9b40
2a0<00P=2@0>4`l03A4@00/?3P0<40l04QHD00d?300>40/400lA3003010B3@0?4@`0418=00804A<>
00d0418=00T>1`0D6A805a`F00/@2P0E6QD03a@@00dB3P0A5A<04ADD01HJ6@0H71/03A4@01Cooooo
000Kooooo`0<01HF5P0=3@/00`<101dM6`0:2PP03@`:00h=2`0510@02@T900h>400820X00P84100<
3Pd03P0<3Ph030d?00`=3`0?41<02``@00`=4@0=3Q<020T=00/<3P092P`04a@F00@4200:2`l02``@
0P0D5AX03@0000D02@TA00L73`051@d03@dE00`<500A4AT09BD]00`<500C4a/02PXB01DE7@0@41P0
0P0B4QX010082@h03a0C010A4`0>3a42018C5@0N00h?4@0<3@l04A8D014B500=3Q004a@F00/=4009
314041<H00d@5@0<3a@03a8G00`?500>4AH03a8G00`?500A51T04aHK01<G6`0I7R80724U014I7`0:
51d03QPQ018O:00<5Ql03aPO014I800>5A/051TM0P0B5a/301<H700;018G6`0F6ah08BLW024W9`0A
5aL041HD01<I5`0B61T05AXM01<H6`0?51L00P0@5AP0100C61/04AHI00hC5P0?51L2014F6@@04aPK
00P051TL01DJ7@0I7R4061dP01HK7P0B5aX04aPK01PM80805A/K0P0B61P06`0I7al061dP01`Q9@0G
72006QlS01XO9@0B5ad04aPN00lF7P0?61l04AXQ01DL900I7bH06b0V01XO9@0F6R4051LN01DH7`0E
61h051LL01<H700W;3005a`P01HK7`0C61`03Q<G01PM8@0201HK7`0?01PM8@0J7b<06AhR018G7@0C
61h08BH/02@Y;@0M8RH020dA00lD5`0H7Al02@l?02P^;P0>51@01`d;00804AHB01L04QLC018F5@0B
5QH04QHG01DI700:3Q40310C01PK800I724051LN01DI8@0k@4H0;c@j01/P9@0>4aL05AXM01DJ700C
6AT04QPH00dC4P0C6AL03Q@@01<H5002014F4P1Z01<G5P0B5QL04ADF028V:@0B5QT051PK00hA5P0C
5Q/04aHM014D7@0I72<061/R018E6`0C5aX05a/L010D500E6QH0=3Td01<H4P0:3`P02a4:01XT6`09
3`/051XI00dB5@0D5a`041<I014D6`0D51`05AHK01DF600D5AL04QDA00dD3@0A61405A`F014G4`0=
4a407bDS01TO7@052`/051XK01DJ7@0?51L03Q<I01XN:@0K7bP03A8E010F500A5aD01`d801XQ6P0F
71P041HC01`R800B61P041@G00lC5P0B5QT000@500dA4P0G6aX03a<B010D4`0A5Q803Q<=00dB300?
50d03AD:00dE200=5@`0318>00`B400<4A@0Ada@01`Q9@062`h05A/K00`B4P0=4a0020l80006000=
50d02Q0<01<I5@0B61H02@l=014G5@0?5AD051TL00hC5P0C61/020d@00X?4P021`X05AXM00lD5`0;
41<00`P;03@i?02UZZd08bP[00dB5@0730l04aTI00`B40804QPF00P02@l=014G5@093`d09B/Y061V
I00S:BL07R@R00L=2`803aDC0P0>518300dC4@06014G5@0<4Q003A<A01<I5`0@5Q@03A8>0`0>4`l2
00lD400:00hC3`0B5a<04QLC018G4`0<4@d01@X600/@2P0<4@/03Q<=014F40804aPB01P07b@N07Ai
L`0U:R@03a@>00P=1`0Q9R004QLA020U7`0K81X04AH@01<H4P0E6Q@06AhH00lD3P0=4P`041D?00/@
2P0A5Q000@L100hE3P073PL072<L04mFC`0]=2d300hE3P0:00`C300;4P/04ALA01@I4`093PP00@D1
02<X8P1GG5H0Ada600hC3@<03A8<00h0314;014F3`0?50d02Pl800`A2P0@5@h03Q<<010E3P0A5Pl0
6b0I04Y?B00F6a@00`P100hD2P803aD900T03A<800`B200=4`T04QL?00P=1P0E6Q@04QLA00T>200?
50h00P0>4``300dB2`<0314:0`0;40T0100<4@X030l800lB2`0A50d200d@2@805APA0P0>4@X0100=
40T071lH01@G3`0?4PT200d@1@0301<F2`0;3P<03a8700H03Q4600<03A0900hA2P0?4P/00`0@4``0
5@0F6A804QD>00`?200E61402@`501DH4@0D6Q001``501TN5`0D6AD04ADC0001000<40l020d:01<H
4P0=4P`02a0800hD2P0>4@X04QD>00lB2`0200hA2P0<00T<1@0D5a005aXC01DH4@0B5@h010L101<F
3`092`H03Q0;00lA300C5A004Q@?0P0=3`X06@0@4Pd03@l:00lA300B50l04A<>00lD400;40`03Q<?
01DJ5P0B5a<03Q<?014F4P0J7a/07B8N00hB3P083@T03a@>010C3@0@4``03A0900X=1P0H6a@09bXS
01dP6@0>4@X00P0D5a004`0G6Q<05APA00X@1P0;4@L03Q<;00T>1`0:3`P08RLQ02L/9P0D6AD03A8>
014F4P0>4`l02a0<00`A3@0B5a<06AhJ00`A3@0730P00P0=4Ph0100<4@d04aPD01LL600B5a<200lD
400X00dB3P0<4@d03A8>00hC3`0B5a<0008000P=2@0?51006AhJ01DJ5P0D6A<051X@01PM5P0K81/0
5a/J01@E5`0D5AT07b0T01HF5`051@<030d801DE400?4@`020d700`A2`0@5@l0314;01DJ500V:bD0
6AhH00`A2`0?50h05AXD01@I4`03204082DN00hC30093PL041D>00/@2@800PL000@051TB00T>1`0<
4@X03Q<<0P0:3`T200`A2`802a0:00l03a@>00D:100A5Q002a0:00`A2`0H7aP02A0900H@20094`/0
2a8;00XA2P0@5a0041D?010D3P0?4@`00P0>40/02P0?4@`041D?00T>200F6aD0=3Tc00hC3@0=4P`0
4AH@00dB300;40X200dB300D00X?2@093PL02Pl800T>1`0<4@X03A8;00D:0`0>4``041D>00hC300=
4P/03Q<<010E3P0730H03A8<00hC3@0=4P`04AH@00T>200?50h200hC3@0:00lD3P0:3`T020d700h@
2`0:30L03Q0;01HH4`0C5A003@l:010B3@803Q0;0P0=3`X02P0>40/04A<>014C3P0J71L02`d8010B
3@0F61<04Q@?00d?2P0<3PT200h@2`0400`>2@0>40/0418=010B3@803Q0;0P0?4@`0100>40/0418=
018D3`0A4`h200d?2P0;00lA300>40/0418=01HH4`0E5a803Q0;00d?2P0<3PT03@l:00h@2`0@4Pd0
0`0A4`h2018D3`09010B3@0G6A@06adH010B3@0>40/0418=00lB3@0=4P`0314;00803Q<=0P0=4P`0
0`0>4`d03a@>00lD3P02010E3`0D00<810042@D05AXF00lD400A5Q802Pl;00hC3`000`003a@@01LL
60062`L082DP000200093PL05a`F00hC3@0I7QP04QLC00X?2`0@5A4200X>3@0700H:2@0A5A<05QPC
01HH4`0D5Q403a4<010B3@03018D3`80418=0P0A4`h030021`00314;00T>200320805AXE00@91@0=
4Ph04ADC010D4`0F6QT06alN00dA41Cooooo000Kooooo`0<00H72@0<3@d04A4A03`k>@0F5A@03Pd;
014@3P0<2`T02`X8014A4@0<3@d02@/:100<3Ph0700<3Pl030d@00l@4`0>3a<01@H:00d>4`0B4aP0
2``A00/<3P0A4Q<02``=00d>40082@/03a0B00l@4`0:2`h02@X=01hO900Q8RL030dA00/;4P0<3A<0
414G010@5`0?41H03PlE010@5`0@41P200d=5@08018B6P0C51T04A8E018C5@0A4Q@051DH01DF6@0@
4A@201hO8P0900X;3P0A4Q@0414C00lA500>4A@04ADH00lC5P0:3A4041<G008041@H01406QhR01`O
8`0=41D030lD01<E600F5aX03Q8E01@I7P0P:2l05alV018K90084Q/0210H00hE700B61h061dR01@I
7P03018G7@0@018G700B5a/04AHI018G6P0F6al05AXL00lD5P0B5aT05AXL01HK7P0B5aX03Q<F01HK
7P0K82<05AXM01<H6`<04AHI00<03a@G018G6P0A5QT00P0A5QT0500B5aX051TL01PM800C61/051TL
00lD5`0F6ah092T/018G6@0=4a<061dN01@J6`0[<C809b`_01<H700E6Qh06QlS018G7@0@5A/0<3Dk
0P0B6B4201<J800`01@J800D6Al05a`R01HJ8@0F6B005aXQ01LI800C5Qd051TM018G6`0@5AT06QlS
01TN8@0E6Qh05Q/O01<H700C61/05Q/O01TN8@0G72004aPM018G700D6Ah05APL018G6`0C61/06b0S
01DK700A5aL0;C<c01<I6@0C6AP05AXG01HK5`0F6aP05QXJ01DI6P0E6A/05ATL01<F6`0D5a`05APM
018E700A51/04QLL020U:P0C61d05Q/N0P0B5aX01`0B61P05A/J01/Q7`0=4a006b4N00lE4@0C6A80
0P0A5Q806P0C61L04QHG014E5`0L82<041<I01LK800C5Q`051LO01<F7P0E62004aHN01<F7@0F6Al0
720S01hR8`0D61P06b0L024V8P0F6aD05AXC010F3P0;4P/041HB01DK6P0?51L041<H0P0F6B00F00G
61h05QHK01<C5@0A4Q@04ADA010G3`0A5a8051XF00dC3`0;4@h03a@B00X@400E6a/07B<S010E5`0B
5a/04ADM00lC7@0>4aX04QLK00lE4`0>51805A/F00`C30083PP03aDB018H5P0=4a<03Q8E00hB5P0?
4aD04QHG010D5@0@51@03a<B010E4@0A5Q803Q<>00dB300?50d03QD900dE2@0=50`03A8>00`B400<
41<0:Bda01HK7`0=4QD04AHG00dC4`0>4a003aH?01HM5@0<4P`02Q0<018H500J81d04ALE00/A4@0=
4a<02a4B00dB5@0;41<06QlS04mDF00?51P04AHJ00dB5P0D6Ad03Q<G02DZ;`0S:2d03A8G01<H7@0D
6A`04ALG00X@3P0D6QP03A<A03<i=`0;4@l03Q@B018H5P0A6AH03aLD014H5P0mAD4200lE4P803Q@A
0P0=4a00100A5a@051XG00hD4P0;4@l200dC4@803A8>00h03Q<?00lD400?51003a@@00`A3@0A5Q80
3A8>00hC3`0@5A403A8>00`A2`0=4P`03Q<=00lD3P803Q<=01h02@h801lT7P0;40X041D?00L<1P0<
4@/03Q<=00lD3P0<4@/03a@>01<H4P0B5a40:c0Z01/P6P0@5@l03A8<00/@2P0=4P`04QTA00T@2@0?
5Pl03QD>020W800>5@h031<;00dD3@0>5@h03QD=00dD3@0@5Pl2014F400501<H4P0B5a403a@>00dB
300<4@/00P0=4P`200hC3@0401lT7P0Q9Ql04AH?00/@2@803a@=01802a0900lD3@0=4P/08bPQ00X?
200C61403Q@;00lE2@0@5P/03A<800X@1P0<4PP0318900P=1P0?50h01P/500P=1`0;40X300hC3004
00dB2`0<4@X0314:00`A2P802a0900D02Pl800/@2@0<4@X04aH?010C300200d@2@0>00hA2P0?4P/0
3A0900D80@0B5@h02`h7018E3P0<3`P04QD<018E2`0@4`T03Q4700d@1`0A50X600hA1`8041<<0P0>
4@X2010C300G00lB2`0B5@h04A@=00lB2`0A50h041<=00T?1P0>4`/0314:018G4P0=4Ph041DB00X>
300C61D03A8<014F400:3`L041H<00`?200@4``02`h700`?200A50d0100=40T08P0E61403Q4:018E
3P0];bX04A<>00h@2`0@4Pd03@l:00lA300D5Q404A<>00`>2@0>40/03a4<00/=200=4Ph0314=00dB
3P0?51003Q<?00dB3P0@5A403A4>00P=2@0=4@d04aPD00X?2P0B50h02`h700hA2`0@4P`03a8<01@F
400>40X2018E3P0J00/>1`0?4P/020/300`B200>50X04AH>00X?20093PL06QlI01`Q6`0@5A002a0;
00dB3@0>4`l0314=00P=2@0=4Ph05a`H00`A3@093PX05Q/G01<H500;40`03A8>018G4`0@5A4200`A
3@0X00dB3P0>4`l03Q<?00hC3`0=4Ph02a0<01hS7`0:3`/02`l<00/@300=4P/03Q@:00dB2`0=4Pd0
310?00h?4P0=3Q402@T=00l?400G5Q@05QDB010A2`0A4`h02Pl800dB300?50h02Pl901DJ500?50h0
3Q<<00`A2`0=4P`041D>00lD3P0=4P/0>Chg01dR6`0<4@X04aPA00`A2P803a@=00@0314:010E3P0?
50d02a090P0<4@/04P0=4P`03Q<=00hC3@0:3`T03A8<00P=1`0?50h0314;010E3`0:40X02Q4:00L@
200>5Pl04QTB00hE3P0<4``0314;00d@2`8030h90P0>40/01@0<4@/04aPA00dA3@0/<B/03A8<0080
3Q<=00<03A8<00`A2`0=4P`00P0>4`d0200<4@/02Pl800hC300>4``02Pl800`A2P0>4``03A8;0P0<
4@X02P0=4P/041D>01XO6@0D6A<02Pl900lD3P093PP03Q<=01<H4P0=4P`200`A2`0300/@2P093PP0
3Q0;00803a4<0`0@4Pd200lA3003010B3@0?4@`03@l:008030h900H06A/F00D70P0B50l03@l:00lA
300@4Pd200`>2@05010B3@0?4@`03@l:00h@2`0?4@`00P0=3`X0300A4`h04Q@?00h@2`0=3`X03Q0;
00lA300=3`X03a4<01<E400B50l03Q0;010B3@8061XE0P0?4@`01@0>40/03a4<00lA300B50l04aD@
00804Q@?0P0A4`h0100>40/04Q@?01<E400=3`X2018D3`0600dA2`0>4`d03Q<=010E3`0A5Q003Q<=
0P0=4P`07`0<4@/03Q<=00hC3@0=4P`04AHB00lD400T:BD061dI018G4`0@5A404AHB010E4@0F6AH0
41@@01<G4`0>4@d04aPB01HK500?50h051TC00870P0@5A402Pl;01<H500<40l04ADD00H:2@0@5180
4Q@?01@F400E5a400P0A4`d04`0D5Q004aD?014D3P0?4@/03@l900hA2`0A4`d04aPA00`A2`0E6QD0
3A8=010E4@0B5Q@03a<A00hC4@072`X03a<C01/O7P0@51<05?ooool001_ooooo00<030`<00d=3@0>
3Ph00P0>3Ph00`0=3@d02`/;00d=3@0200l?3`0G00d=3@0;2`d051DI00@52P0K72403@hC00/<4@0B
4aP03a0E014B5`0@4AH02@TA00l?5`061``030dB018C5`0?41@03PlC00l@4P0=3Q002P`<00L9200:
30/00`0>40d0@`082PT03a0B01@E5`0>3a402P/?00h?4`0@4AH020T>00L83@0<31@0=cLo0083200D
5AP02@X>018C5`0>3a@05aLO00d=5@0K6b<02``A00h?500G61`00`@600d?3@051`8010H101LI500=
3``02@/8010B400=3`h0414C01HG6@0D5AT05QLK02DV:`0<3aH010L>02HY<@2]/KX092Pa014E7P0B
5Ql04ADN01@H8@0F6B805APQ01DH7`0D5ah041<J014D6`0D5ah05APO00lB6@0H6b005APO01TL8@0C
5Q/02@`A01HJ7P0D61/04QHI010D5`0G6ah0>3`o01hR9@0F6Qd00P0G6ah00`0?4aH04QHI018F5`04
018F5`0K01<G600=4A803Q8C014E5P0C5aP051PI01DI6`0F6ah0:2d`028W:P0B5a/0724U01LL800?
51P05a`P01`Q9@1BEe/0Zk2d04aAE@0G72803a@J018G7@0K82H05Q/Q01<H7P0E6R005Q/Q00805AXP
05`04aPN014F6P0A5QT05Q`M01DK6`0H7B007B8T01HL700D6A`05AXL01LM7@0H7B005Q/M014G5`0G
6a`03a<B01@H5`0F6QT04ADE01DI6P0H71d051PI01XN7`0G6ah041@G01XN8@0;3a8051LL01HI7P0@
4aP07B0U00L:3`0A51X05QTP014D6`0>4AP03A0G01/N8`0H71l020`?00hB5@0A5AL03Q8C01TM7P0B
5QL020`=01`P8@0=4A40=CTj01DK6@0C6aD051XF01@M600D6aX041DH00hF6@0D6R404ADP01@K9@0B
5b@030lN00lC7P0H6b4020/@01TM800?4aH02`l@014E5P0e>CP061`K010D4`0B5a<051TE00lG4`0@
6AH051dJ014G5`0E6AX061TM01<D600I6Qh082@W01TN800<4Q802Q<B00lE5@0I7Ah02@d>00lC5007
2`X04ADF018F5@<041@C00H04ADD01<G5P0D61X03a<F00H:3@0N8R@201HJ6@803A8>02003Q<?00lD
400@5A404AHB018F5@0A5AH020`<010D4`0F6QT0310?01/O7P0;3`h0310?00D9200D6AD04aPD00X?
2`0<4@d03A0=014C4P0C5aH03Q4A018C5@0J7Ql03a8C01TK6P0C5aH03a8A00dC3`0?5A4041HC00dC
4@802Q0>100>51801`0=4a<02a4A02<X:`0d>C`0314D01DJ7P0@5AX00P0;41H08@0]<CX000@=02@X
<`1YKGP04QHO00hF600740h02Q<@00`B400V:bT061`K00T?2`0D6aL000H000lL5@0A6a@03AXA00dD
3@0C61801``600hC3@0>50h02Q4:02D/9@0G7aT01@h901HO6P0<5A002a4=00hC3`0A5Q804QLC00lD
400400dB3P07010E4@0>4`l02@h:00/@300>4`d03A8<00`A2`0200dB300R00hC3@0@5@l03Q<=00hC
3@0A5Q005a`F00`A2`0J7a/01P/700@91@0A5Q80QHZ6055FDP0>4`l06b0L0004000@5A402Pl;00/@
2P093`H04aPA00/A1`1@EDd092TR00hD2`06308020d6010F3@0F71804aPA00lD3@0A5Q8041DA00lD
40803Q<?01H04AHB00/@300;40`02Pl;00`A3@0A5Q80314;00dB300?50h041D?00lD3P0=4P`0314;
00dB300>4`d03a@>00dB300<4@/03Q<<01DK4@0D6A803A8;0P0>4``300T>1`0I018G40093PL0314:
014F40011P004AH@00X?2@0E6Q@041D?00X?2@0L8A/02Pd900X?2@0A5Q003A8<014F40062`D03Q<=
00X?2@0<4@/02@h800/@2P0=4P`041D?00hC3@0200`A2`0P00dB2`0@5@h01P/400/@2@0=4P/0314:
00P=1P093PL0314:014F3`0G71D06QlH00lA300=40X01PT2010C2P0>4@P02Pd4010C2P0G6Q802Pd6
06AVH@0>40h030h;00h@2`0>4@X03a8;014D3@0?4@`020X500`>2@0=3`X200hA2P0900d@2@0<3`P0
4A<>00T;1P000@006A/F00P:1P0L7QT061XE00802P`700<05ALB00d?300E5a800P0A4`h0300@4Pd0
3a4<00`>2@0;3@P03Q0;01DG4P082PD04aD@00@60@0A4`h02a0<00lD40803A8>0280314=00L<200@
5A4020d900`A3@0=4Ph0314=014F4P0=3`X00`D000lA3P0@4Pl0@D=201DG5P0;3@X03@l:0044000>
4@T061/B00d@1`0A5Ph06QlH01<H4@083@H02a0900dB2`0;40T03a@=018G400?50d02a0:00hC3P0?
4a803Q8A0P0=4A00200>4Q40310?00hB4@0:3Pd041@C00lC4P0:3Pd03Q<?0P0<4@/02P0=4P`03Q<=
00hC3@0<4@/02@h8010E3`0:3PT010T301XO6@052@D200X?2@0M00/@300=4Ph041@C00lC4P0:3Pd0
5QPF00P:1`0@4Pl03@l;00dB2`0>50X03A<:00hC300B60h03aD<00`A2P0<4PP02a4800/@2@0<4PP0
3A8:010F300F718051X@00T?1@0;4@L051X@00/A1`0=4`T00P0@5P`02`0?5@/03A8:00lD3P000P00
3a@>00hC3@0:3`T03A8<00P=1`0C618041D?00802Pl900L02a0:00<80P0C6A803Q<=000400083@L0
2a0:00803a@>01003A8<00`A2`0<4@/03A8<02ld;@13BD003A8;01dR6`0@4`l0314:024V800;40/0
41DA00/@30062`L04AH@100=4P`00`0;40X02@h800/@2P0500/@2P0900lD3P0;40X01@X400X?2@0>
4`d051TC010E3`0;40X02Pl900802a0:01<02Pl9014F4P000`00314=00dB3P0A4a003@l<00h@3@0?
3`d04A4?01@D4P0?3`d02`/900d?2P0A4`h051HA01<E400>40/030h900804A<>00P03a4<00d?2P0?
4@`04A@?018G4@0A5Q002a0:00lD3P804A<>00<04Q@?010A300@4@`00P0A4Pd07@0@4Pd01``601PM
5`0=4P`05AXD01@I4`093PP0314;014F400=4P`041D?00dB300<4@`051TE010E4@0B5a<02a0<01<H
500=4Ph020d900870`0L8Ad03A8>01TN6P052PH02a0<00dB3P0>4`l03A8>0080314=01L01P/700`A
3@0?51001@X600P=2@0:3`T04QLA00/@2P0=4P`03Q<=00h@3@0E5a@06adJ01PH600?3`l04A4A010@
400:30T03A8>018G4`0<4@d04aPD00X?2`0200dB3P0<010E4@0C61@02a0<018G4`0<4@d03A8>010E
4@0A5Q8041DA00lD40083@T0314=0P0@5A403P0>4`l02`l>014E500A5AH03Q8C00`@4@0=4A804ADF
00dA4P0?4a@01PX;00dA500=4A<03Q8C5?ooool001_ooooo00<02`/;00`<300<30`00`0<30`00`0;
2`/030`<00`<300200`<300@00/;3@082@h030`D01DE7@0;2a<03`lG01DE7@0C4a/030`D00d=5@0:
2Q804A4I00h>5P0@4AH04a@I00l@5@802``@00P02@X<018D500?4A003a4>00h@300<3PT03@l:018D
4@803Q0?02P02`d<00`=3`0B4aD0414E01LH7@0A4QL0:2P`065QJ@0Y:Rl03a0C00T:3P0I6Ql04Q8J
01DE7`0D51h02@TC00h>600[:c<05aPM00421P0L7Q/06ahG01`O600930D051HA01dO6P0F61D04Q@A
01@F5@0G61T04Q<E01<D600@4QL03a8K01XM9P0N8BX0A4M@00lB6`0E62404QDN0P0A51d01P0B5Ah0
4aHO01DH800B5A`03a8I010C6P804aHM00d04QDL01`O9P0F6B005QTP018E700;3QD04QDJ00dA500C
5aX04QHI00lC5P0L82<05QXM00<04aLJ00@041@G018F6@0A5AH04QHG0P0E6AX06`0D61T04QHG010D
5@0A5AH04aLH01@H6@0E6AX05QXK01XO8`0S:2`07B8V01<H700J7b<05AXN010E6@062`l07R<W0825
R@35b/h0:Rlc01@I7`0E6R0092T_02db>00M8RP04AHL01<H7P0301@I7`0E01<H7P0B5a/04AHI01LL
7P0D6QX051TL01TO800F71`05a`O01HL7@0F71`05a`O01<I6P0>51@04ADD01/P700H7AT04QLC014E
500C5aH04aLH008051PI03`051PK01<G6P0C5Q/05QTP01XM900B5A`061/R00hA600;3QD04QDL01<F
7@0G6R408bH]010C6P072Pl05ATK02hb<`0H71d04ADF00hB4`0;3a0051PI00dA4P0R9RL06AdN03m3
A00R:2H01`h:00D>2@094Pl041PI01<K7P0B6Qd03A@K01/R;00A5b<0318P01@J:P0J82`07R4U00dA
500E6A`01`/<03/o@00D61T07B4P014E500D61L04aLF014E500>5A@03aTH00lH5`0;41403a<D01<D
5P0A4Q@05AHH01PI6`0D6AX200dF5@04014H6@0D61/03a<F014E60<03A4B00<041@C014E500B5a<0
0P0B5a<04P0?4a<05QXK01TM7P0`=3@092PW01/O7P0<40h03a@@010E4@0A5Q404QLA01<H4P0830/0
4QHE01PL6`0<40l02`l>00lC4P801PX900`0720O00T=30093@`0310?010B4@0A4a80418A014C4P0D
5QD03Q0?01TK6P082PT201<E5009014C4P0D5aH03A4@00lE4`0B61H041HD00lE4`0@5Q@03A<A00<0
3Q@B02L03A<A00`B400630`05Q/N00H;3P0A5QX05AXO01@I7`052A8020`F01lS;P0B5R40SY:N01DL
900@61X04Q/I00dF4`093`d041DC0045100=4`l00@X501LT7@085@h03alF00/K4@0;4P/04aPA00`A
2P0B5a0041H?01@K500?5Pl02a<<02@^9P14CDP09c0[010I500>4`l00P0A5Q80300>4`l03A8>00hC
3`0?51005Q/G01TN6P0A5Q803A8>014F4P0>4`d03A8<00`A2`803A8<01l03Q<=010E3`0B5a403a@>
00P=1`052P@020d700860`0=4Ph04AHB00L;200n@cl0:2dY00lD400>4`l01``802H[9`0730P02@h8
03To=P011`001`d301HL4P000`004AL=00P>100L8QP03Q8<0003000B60h03a@=00803Q<?100?5100
1P083@T0314=00dB3P0?51004aPD00dB3@803Q<=00H03A8<00hC3@0>4`d03A8<00/@2P0<4@/300hC
3@0300/@2P0?50d04AH?0080314:0P0=4P/02P0M8Q/05AXC00dB2`0<4@X02a0901HK5@0730H04aPB
00T>200A5Q0200/@2P0>00L<1P0?50h0<cPb04M<AP0:3`T00@H0020U7`0=4P`02@h800dB300>4`d0
2a0:00T>200:3`T200dB300;00X?2@0;40X041D?00X?2@0>4`d03A8<00`A2`0=4P`03Q<=00lD3P0@
5@l00P0A5Q004@0<3PT03a8<00X=1P0B5@`04QD;01@G300C5P/03Q4800d@2@1LGUT051HD00P:1`0:
30L03A0900P;100930D041<<00803A09100?4P/03@0=40T04A<>01DG4P0N81/02@/605]MF00<3PT0
2`d800`>2@0?4@`06A/F00h@2`092`H00P0=3`X200h@2`<03@l:00D04A<>00X<1`0B50l04Q@?014C
3P0200hC3`0400/@300<4@d03A8>00X?2`803A8>01L04AHB00hC3`083@T02Pl;00lA30072@H05QPE
018D4`0g>3X0414C010B4@0?4@h03Q0;014D300@4`P01`X1010E3P0D6A803Q<<00P=1P0;40T03Q<<
00dB2`0200hC300?00dB2`0<4@X020d800H:2@0>4Q4051PG014E500<40l02Ph=01<G5P0=4A00310?
014E500=4A0041@B00<041D?0P0A5Q001`0D6A<041D?0005000U:R@03a@>00L<1P0B5a800P0;40`0
100<4@d03A8>00lD400?510200D:1P0;00X?2`0B5a<02a0;00X?200<4PP02Q0600/A1`0?5@/03188
00hD2P0=4`T00P0<4PP01`0>50X04AL=00dC2@0B60h041H<00T?1@0;4@L00P0@5P`06@0A5`d04aT?
018H3P0A5`d03Q@:01XO6@0?50h01@T501hS7@0G71H03Q<=010E3`0;40X03a@>00dB300;40X061dG
01LL5P042@<01``6024V800E6Q@02a0:00dB300<4@/00`0:3`T03@0:3`P02@h701hT6P042P005a`E
00dB2`0;40T01``600dB3@0@5A404QLC01DJ5P001000100>4`d800dB300>00H;1@0D6A<05a`F01LL
5P021`404aPB010E3`0;40X02Pl900`A2`0;40X02Pl900lE4@0E6QH200dB3P0M018D4@0@4Pl03a4>
00l?3@0@40h04a<A010@3P0=3@/03Q0;01HH4`0J71L061XE010B3@0<3PT02`d800`>2@0620<04Q@?
01XL5`0<4@/03A@=00lD3P0<4@/03a@>014C3P0>40/03@l:00d>2@0?40/00P0B4`h07P0C5A001@X4
0005000A5Q00008000hC3@0?50h010T3018G4@0=4P`04AH@00D:100B5a802@h:00hC3`0;40`01``8
00X?2`083@T04aPD02ld<013B4@02a0<00T>2P0?51002a0<00dB3P0>4`l03A8>00`A3@803A8>02@0
5a`H01@I5@093PX03A8>00L<200@5A40314=014F4P0C61@04Q@A010@3P0F5Q@051@D00l=3P0A3a00
4A0A01`N6`0@5A404QLC01dR7P0?51003Q<?00dB3P0;40`0314=00/@30062`L0314=00`@3`0=4A00
41@C014E500@51<03a<B00/?3P0?4a82018F5@0;00lC4P0<40l041@E00hB5@0?4aH04QHI01<G6P0@
51L05ATL020T9`0=4A@00P0@51L00`062Pgoooooooooo`0Booooo`006oooool300`<300300/;2`0<
30`030`<008030`<0P0:2PX02`0<30`030`>00d>4`0;2a<07AdU010@600J6R80ShnG02`/=00D51`0
5ADM00<03@dE00X04Q8J01@D6`0?41D03PlD00l@5@0=3Q402``>00d>3`0:30/02P/;0P0=3`d0100=
3`h030h=014C4P0B4aD200d>4P0T010A5P0>3a@04Q<H00/;4`0Q8BT020P>018C5`0:2a0051DK00h>
600@41`051@P00l?6`0>3QT06a/T00h?5@0F5a/0:2X[00h@3@0=3``04A<@00d?3@0<3P`04A<C010A
4P0A4Q@051DG00l@4P0A4Q@04Q@I01HI800:2a80<SDl02T/<`0E61l041<J0P0D5ah01@0B5A`041<J
018E700D5ah04QDL008041<J00@04A@K018E700B5A`05QTP0P0B5A`0100G6R406A`S01PK800A5AP2
01HJ7@0>018F6@0@51L02`lB010D5`0?4aH03Q8E01<G6P0B5QT04ADF01<G600G6a`061`M01HJ6`0A
5AH301@H6@805ATJ00d05QXK01LL800F6al05AXN01HK7`0G720061dQ01LL800F6al051TM018G6`0_
=3P04AHJ00804aPL0P0D6Ad01@0A5QX04QLK010E6@0B5a/04aPL008051TM00L04aPL014F6P0G71l0
4aPL010E6@0E6Qh06b0S00804AHJ00H04aPL01DJ7P0D6Ad04AHJ014E5@0F6QX2014E5@0801@H6@0:
3Q0051PK01PL7`0F6Qh051LL01DH7@0B5A/201@G7P0700d@5`0L7bH04A@K01/N9@0A51/05aXQ00hA
6002010C6P0R01DH7@0D61X04ADF00hB4`0G6a`02Ph?01XN7`0D61T03Q8C01PL7@0<41407b<T00P=
3P0T:bX051dK00lG600@61T04QXM00`D5`0A61h04APQ00H=5`0A62<05A/W00P>5`0C5QP05a/L01dQ
8P0C5aP0J6a]024U9P0B5QL03a<D01@H6P804QHH02`061lO01TP800C6AT041@E01HF600H61X05A@G
018B500A4A<03a<D00lF5P0@5aL04QLJ00P;400B5AX02`lC01<G6P0A5AP03a<E010D5@0B5QL051PH
01<G5P0B5QH03a<D014E5P0;3a005a/L00dA4P0D61L041@C00hB4@0?510041D@014F400A5Q4041@C
00P<2`0G6aX02@d<01@H5`0C5aH0:Bd/00`@3`803Q8A01@051PG00dA400A4a8051HE018D4`0A4a80
4aDD00lA400D5QD01PP701HH5`0620L05ALF00d@3`0>4Q403aDC014G5@0@5Q@03aDC014G5@803A<A
0P0>51808`0=4a40318@00/A4@0;4A403A<C00`B4`0>4aH02PlC010E6P0D6Al0HfQ_01/P9`0_=3d0
3A@K00L=3`0A6QP01a0=00lE4`0@5A@051PG00T?3@0A6QH04b0I00TF3`0<6Q<01A0900`D3P0?5@l0
3A<>014H4P0;4Pd05A/G00lE4P0=4a001@h:00803aPE01001Pl<00hC3`0A5Q804AHB00lD400>4`l0
3a@@00hC3`0H7AT06b0L010E4@0=4Ph04aPD00hC3`0=4Ph0314=0P0=4Ph0300>4`l02a0<00hC3`0;
40`03Q<?018G4`0g?3P09R/W00T>2P0@5A403a@@00T>2P803Q<?01<03A8>018G4`0@5A402Pl;018G
4@0Q9ah04QP>00T?1@0?5@`05adC00`B200=4`T0=3X`02X`9`0<4PX06R0F00T>200:3`/0314=0080
3a@@0P0>4`l04P093PX03A8>00hC3`0=4Ph03a@@00`A300?50h03A8<00`A2`0=4P`03a@>00hC3@0<
4@/02a0:00dB300?50h041D?00lD3P803a@=00d03A8;00hC300?50d03Q<<02L/9@0G71D01``5014F
3`0>4``03Q<=00H;1@0>4`d020d700804AH@00d051TC00<80P0A5Q00<cPb04aAB`0@5@l061dG05AI
D`0R9b4041D?00lD3P0:3PT041D?0080314;00P04aPB01DJ500@5@l02Pl9010E3`0<4@/041D?00/@
2P80314;01P03A8<00lD3P0?50h03A8<00X?2@0=3``04Q@?00lB2`0E60l03a8701<G2@0A5@L041@7
01hQ5`0j?CD04Q@>00lB300:3@H06QdF014D3@0<3`P04QD>00/>1`0>4@X4010C300A00hA2P072@@0
3a4<00P:1P0F61<08R@P01DG4P0?4@`0418=05]MF01TIV40418=00h@2`0C5A004Q@?014C3P0?4@`0
0P0>40/01P0@4Pd03Q0;018D3`0;3@P09BLR00P:1@8041DA00<02a0<00`A3@0?51000P0=4Ph00`0C
61@05a`H014F4P0200X?2`0C00`>2@051`@05ALD00`>3@0L7Al01PL900lA400B5140418=00hA2P0>
4@L03a8900hC300<4@/02Pl900/@2P0<4@/03Q<=00dB300200`A2`0700dB300>4`d03a<?00dA400?
4a803A4@00X>3@0200T=300600hB4@0:3Pd041@C00lC4P0830/03a<A0`0@5A402P0?51003Q<?00dA
3P0?510041DA03Xo>`0F6aL02@`9010E4@0?510200hC3`0>00dB3P0>4`l02@h:01@I5@0>4`l03A8>
00T<2@0F6aH02a0900dC2@0;4@L03188010F300=4`T200X@1P0900T?1@0:40H02a4700hD2P0:40H0
318800/A1`0<4PP03aD;00803A<90P0>50X05`0=4`T0318800T?1P0<4@/04AH@014E401NHed0C55;
00`@2`0=4P`01``600lD3P0@5@l04AH@02L/9P0oA3h05Q/E028W8@0B5a402@h900`A2`0>4`d03A8<
00802a0:00h0314;00dB2`0>4``0318800X@1P0A5Pl03a@=00/@2@0<4@/03a<?00hC3`0;40`03a@@
00X?2`802a0:00<02Pl900/@2P0=4P`01`0>4`d01`0?50h02Pl900T>200A5Q0020d701HK5@0?50h0
0P0;40X02P0<4@/02a0:00X?2@0=4`l0=3Te02@Y9@0B5Q<04Q@A00T;2@0@4Pl200l?3@03014A3`0@
40h0410>00803a4<0P0@4Pd06@0?4@`03Q0;014C3P0A4`h02P`701XL5`0S9B004AH@010G400C6180
51TC01DJ500F61<04Q@?00h@2`0>3`X03a0;010A300?40/03@l:00dB300B5a40BDi800/?2`0?50h0
0P0=4P`04@0>4`h03a@>00dB3@0>4`d03Q<>014F4P083@T041DA00lD400>4`l0314=00T>2P0>4`l0
41DA01/P70042@D03Q<?00@03A8>0240314=00lD400B5a<06b0L01HK5`0;40`03a@A02HZ:P0Y;Bh0
5ATJ00lC500?4a<04A<C00h@3`0A4a804Q8B014A4@0C4a<051<D00X<2@0E6QH02a0<00lD400730P0
4QLC00lD400A5Q806AhJ01LL600B5a<02Pl;00hB4@0?4a800`0@51<00`0?4a8041@C018F5@0201<G
5P05010D4`0>4Q403Q8C00/?400@51D00P0G6a`01`0@51D02Ph?00dA4P0@51D05a/L00dA4P0D61T0
5?ooool001_ooooo00D0410@00l?3`0=3@d030`<00d=3@0200h>3P0L00d=3@0;2`/02`/;00d=3@0>
3Q0030dA01@E6P051P/03@hC01TJ7`0^;c@06AXO00D62`0A4QL03@hC00`=4P0=3AD0410H00d=5@09
2A402`/B00h?500;31403a0E014B5P0;30h02``?00d>40802``>02l04A8D01/L7P0M7R804Q<G00d>
4P061``01@H;01/L8@0=3AD02PXB00d=5@0?41D04A4I00d=5@0E5B005A@R014@7P0:2QL05ADQ00d=
5`0@41L04a@I00X;3`0K72006Q/O00`=4@0G61`04A8F00P82`0=3Q003PlA010A4`0>3a40414C01PJ
7`0H6b006ahS010C60062@h041<H01PK800D5a`05aXO01HI7P0B5AX03a8G014D6@0201<F6`804QDJ
0P0C5Q/2018E6P0?00d@5@0A51T04aHK010D600C5aX04ADH01<G6P0D61/04ADH00/?4P0C5aX04ADH
00hB5@0E6A`04ADH00<04aLH0P0B5QL02@0A5AH051PI01@H6@0C5aP04QHG01<G600E6AX04QLK010E
6@0201DJ7P0E014F6P0H7B407B8V018G6`0A5QX03Q<G01XO8`0I7R804AHI01HK7P0J7b8061dP01@I
700@5AP03Q<F010E600B5aX04aPK01@I700D6Ad04AHJ008051TO00l04AHL01HK8@0R9bd06AhT01HK
8@0C61h04QLM00hC6@093Q805QXM00`@4P0C5aX05ATL01<G6P0R9BX00P0G6Ql0500N8BP06A`S00lB
6@0G6R406A`S01<F6`0G6Ql01`X?020S:00>4AH05QTN01<F6`0A51T05aXO00P;40031P/01`/=01`P
8@0;3a0041@E0P0=4A8201<G600[01LK700D61T0720Q014E5P0P9BP041DH00`A5@0@5AT05Q/O00lD
600M8RH000D;01XO9@0oA4X0<cPn018G6`0320H03A4@01<G5P0=4A004aLH00P<3@0@51L02`lB00`?
500;3Q<03Q4F01@H700A5AH03Q8C018C5@0E5AL0518E01@@500F51L061PJ01<D5P0=4A803Q8C014E
6P0C5Qd06QdT00lB6@02014D6@0?010C600@51L04QHI01<G6P0B5QL03a<F00/?4P0=4A@06alR0455
A`0H71d03A4B00dA4@0=4A003A8>00<03Q<?01002`l>01TM701:CTd06alN01HJ6@0;3`h061`K00H:
2@0E6AP041@C014E500;3`h03@l>010B4@0?4A003@l>0P0A4a802P0:30/04A<B014C4P0G6AP071hM
00hA400F6QT05A/I01<I5`0=4a4200X@3P80318@0`0>5180;P0=4a405Q`J00X@3P0@5Q@03A<A010F
5P0@5AP02@hA00hC5P021`/0314E00hC600=5AP051dL01LQ7@084@h051XH00dB400>4Q403aDC00D>
2`0>6QH04alK00PH4P0>7AP041/G00dF4`0:4a004a`I00dF500?61D01Pl>00D>300:4a801a0?00XC
4P0E7Q/03Q<?010E4@0?51003Q<?00lD400A5Q803A8>00/@300=4Ph200/@3004010E4@0>4`l03A8>
00`A3@803A8>02<03Q<?01<H50093PX01``800dB3P083@T0;34]01<H500730P06b0L00/@300<4@d0
5Q/G010E4@0<4@d010T500/@300A5Q806QlI00`A2P0=4P/02a0900`A2P0:3`P02a0900hC300<4@X0
5AXC01HK500;40T02Pl800/@300=4Ph03Q<?00dB3P0200/@300]00L<200;40`04AHB01TN6P0Q9R80
51TD00`A2`0=4P`03Q<=00dB300<4@/03A8<00hC3@0<4@/02a0:00`A2`0>4`d06AhG01HK500;40T0
3A8;018G400?50d0314:018G40093PL03A8;014F3`0?50d04QLA010E3`0>4`d010T300L<1P093PP0
20d7010E3`042@<00@H00005000:3`T000<000hC3@093PP01P/500803a@>0P0:3`T200`A2`0O00dB
300@5@l03A8<00hC3@093PP03Q<=00T>200=4P`01``600T>200=4P`03Q<=00dB300;40X020X700/=
2@0C5Pl08B@K01`O4`0P91D03a<401@H2@0F6P/04QH800/?0P0?4PL03Q4:020S700E614030l8010C
300200`?20@03Q4:014030l8014C3P0A4`h03a4<00@60@0?4@`0418=00L9100@4Pd07R0K02DW8P0>
40/02@/601HH4`0C5A004A<>00lA300200h@2`803@l:01X06adH01LI500l?ST06adH00hC3`0A5Q80
3Q<?00lD400>4`l02Pl;00P=2@093PX020d900T>2P0=4Ph03Q<?010B3`092`X051HE00l@4P0D5AL0
414C00lA4@0P8Ql03@l:00`>2@8041<:00H0314:00/@2P0>4`d03a@>00dB300;40X200`A2`0@00dB
300>4`d03Q<=00`A3@072`X01PX900P:2@0<40l061`K01HJ6@072`X03A4@02/_;P0E6AP01`/:01<H
5@803A8>00d0314=00/@300;40`020d900L<200=4Ph02a0<0004000B5a<02@d9010E4@0?51003Q<?
00803A8>00/000D1018G4`093PX03a@@028W8`1bMg80314:00dB2`0;40T0314:010E3P0200hC300:
00lD3@0B5a004QL@010E3P0>4``0314:00dB2`0<4@X04AH?01@I4P<03A8;0P0?50d2010E3P09014F
400;40X041D?018G4@0730H02a0:00X?2@0N8ad05Q/E00802@h800T02a0:00L<1P0K81X0?D8l00hC
3@0@5@l04AH@00hC3@0=4P`00P0<4@/03P0>4`d03Q<<01@I4P0630804QP>010E3P0C61403Q<<0005
000A5Q4041DA000200000`004AHB10093PP00`0;40X0314;00`A2`0500`A2`0D00X?2@042@<08RLQ
020U7`0;40X00`P200dB300;40X0314;00dB300<4@/02Pl900X@300B5a<07B8N00D:1P0];b`0:2XW
00lA3P0@40h200l?3@03010@3P0A4@l04A<>00<0418=0P0A4`h0200=3`X02P`700d?2P0;3@P03@l:
014F400@5a003Q<=0P0=4P`00`0@4Pd051HA018D3`02014B3@0K010A300>3`X03a4<00hC3@0=4P`0
41D?018G4@0;40X01``600hC3@0I7QP0PhR201LL5P0?50h0;C8]08J;Q`0]<Rh05Q/G00460P083@T0
41DA014F4P0?5100=3Te071eL@0^<bl0314=00803Q<?01403A8>00`A3@0<4@d051TE010E4@0>4`l0
3a@@00dB3P0=4Pl04aPL01LL8P083A4020/@00/>4`0>4Q@04Q<E014B5003018B4P0>014A3`0?4@h0
7B8N00dB3P062`L04QLC00hC3`0;40`0314=01PM6@0F6aL04aPD00/@300@51<500lC4P06010D4`0A
5A@04ADD010D4`0?4a803A4@100>4Q<0100A5AH051PI01<G600D61T200X>3`0300861`072`cooooo
01?ooooo000Kooooo`06018B4P0@41003@d=00d=3@0>3Ph03`l?0P0>3Ph200d=3@0;00h>3P0>3Q00
20T=00l@5@092Pl030dB00/;400000D04A8G00H7300@4AH00P0<3A803`092Pl06ATS018B6P0<31@0
3@dE00l?5`0;31401`P=00T:3`0720`04A8G01LH7@0B4aL03a0C00d>4P02014B5P0E00h?4`0?41@0
4Q<H01LH7@0I6Ql051@L00d=5@071`l030dB01PH800?3aT03@dI00H54`081aD061LU01LG8`0?3a/0
20PA01PH800D51/0410H00804a<K00<04Q<H01@E6P0F5a/00P0B4aL0500B4aD03PlA014B500H6ad0
004401PK800D5a/06QhQ01DH7@092`l04QHI018E6P0D5a/04ADH00`?500=41D04aHK01DH7@0D5a`0
4QDJ0P0C5Q/0200@4aP05APM01<F6`0L7b@08B@Y01<G6`0E6A`05QXM0P0E6A`03`0=4A@041@G01@H
6`0D61/04aLJ01@H6`0A5AP05ATJ01@H6@0B5QL04ADF010D5@0A5AH051PI01<G6002018F5`0G01<G
600F6Q`05AXN01@I7@0G72005Q/O01<H700D6Ad05AXN018G6`0D6Ad000<700H;3`0M8RH03a@G014F
6@0>4aH0314D010E600>4aH03a@G014F6@0C61/00`0D6A`02@0D6Al04aPN01@I7`0C61h05Q/Q020U
:`0C61h04QLM014F700201<H7P0;014F700D5a`051PK020T9`0E6A`041<G03Tl@@0E61d04aHM01XM
900K7RD00P0F6B803@0E61l04A@I028U:P0<3a@0>Se2028U:P0<3a@02`hC00hA5P0A51T051LL02LZ
;`0I7Al00P0;3a00100A5AH04aLH01@H6@0830d200/?400?00lC500A5AH03a<F010E6@083A<020dA
00lD600E6Qh04AHJ00H93@0320`051TL01XO8`0F6ah0318B00805AXF02P05Q/G01LK6P000@805a/L
00hB5@0=41D05APO01<F7@0@4a`03a8G00/?400>3a4051@F018@4`0B3A405A0D01/F6P0L6Qd05ADG
00d>400>3a402`hC01dP:@0@4a`04A@K00hA600D5ah041<H00lB5`0@4aP04ADH00lC5P0>4QD04ADH
00X>4@0420/0720R00861`0:3Pl04aLG0P0?4a83010E4@0=00X>3@0B5QD0<CDd00lC4P0B5QD03A4@
00hB4@021PD03Q8A00T=300B5QD03A4@00/=300200lA400700`>3@0@4Q404Q@C01LI600C5A@03@l>
01XL6`0200P:2@8061hL00<051XH00dC4@0:40h00P0;4@l03P0<4Q003Q@B00hD4P0>51803A<A010F
50093`d020h<00hD4P0@5Q@04QPH038h>00E6a/00PP80P0E6Qd0:0063Q0031DD00dG500<5A805A/I
00lD4`0;3`h04ALE010I5P0F8Qh000P40310?0034Pl02Q@C00hF60053@l03ADG00dE5P0;51<0EemQ
010I600?61L041TH01/T8`1:D5003Q8A010E4@0?51003Q<?010E4@0B5a<03a@@00T>2P0:3`/0314=
00hC3`0B5a<03Q<?00dB3P0<4@d200dB3P0b00hC3`0D6AD03A8>00dB3P0@5A4000D100hC3`0@5A40
0@H201DJ5P0;40`041DA00`A3@0<3``0;c@`08^@S00:3`/051TE01@I4`0E6Q@04AH?00lD3@0A5Pl0
1P/400hC300D6A801P/400T>200<4@X00@H000lD3`0<4@d03A8>00hC3`0<4@d02a0<00lD400:3`/0
314=00dB3P0A5Q8061dI00lD3`0;40X03A8<00lD3P0=4P`02a0:00dB300>4`d200dB3080314;01@0
61dG01@I4P0730D02Pl800hC300;40T03A8;00`A2P0730D04aPA00hC300=4P/03A8<014F400<4@/0
1P/500T>200@5@l0314;01XO6@804AH@00L00`P200lD3P0E6Q@01P/5018G4@093PP03Q<=00802Pl9
00T0314;00hC3@0;40X02a0:010E3`0?50h03A8<00T>200C61800P0<4@/02`0;40X0314;00dB300=
4P`02a0:00T>200=3``030h:010C300I71<051P:00807b<B00d08bLF00/?000A5@@06al@01PL3P0>
4@P051L@00`?20062@8030l801<F3`0<3`P03A0900803Q4:01`03A0900`?200B50l01PL401HH4`03
1@0061XE0001000B50l03@l:004300072@@02P`701HH4`0?4@`03@l:00`>2@0>40/0418=014C3P0?
4@`0418=01PJ5@0D5Q409BLR01<E400=4Ph04AHB0P0?51005P0=4Ph020d900`A3@093PX01``800lD
400E6QH04aPD00lA3P0<3Pd03Q0?00l@4P0@4A<051DG00X:300C5A@02P`900lA300B5@`03Q4:00`A
2`0=4P`2010E3`0D00dB300;40X02a0:00`A2`0=4P`03Q<=00lD3P0C5aD051PG01<G5P0?4a804aLF
01lS8P0K7ah01PX900/?3P0Z;Rd04aLF00H:2@0C61D200hC3`<03A8>01l04AHB01DJ5P083@T04aPD
00dB3P0D6AD04AHB00lD400>4`l03A8>00`A3@0=4Ph082DQ01hS7`093PX00@H200D:1P0R9b802@h8
00/@2@093PL02Pl800hC300;40T03A8;00hC300A5Pl04QL@010E3P0>4``03A8;00803Q<<00<041D>
01<H4@0=4P/00P0;40T05P0=4P/03Q<<010E3P0A5Pl051TC000200011P002a0:018G4@0>4`d00@H0
01dR700D6A<020d700/@2P062`D07b@N028W8@0B5a401P/500X=2@062`D200/@2P802Pl90100314;
00dB2`0=4P/02Q0601HL4P0C614041D>00H;10093PP05AXE00lD400Q9R80=3Te00X?2`0;40X03A8<
0P0>4`d00`0=4P`0314;00/@2P0500/@2P0C014F400[<2X0>Sli02H[9@093PP03A8<00`A2`0;40X0
314;00hC3@0<4@/02Pl900X@300C61@0;c@`01PM6@0W:BH05aTF00lA3P02014A3`0b00l?3@0@40h0
4A4?00/=200@4Pd051HA018D3`0<3PT02@/6018D3`0?4@`05QPC010B3@0?4@`061dG014H4@0>4`d0
3A8<00/@2P0@4Pd04aD@010B3@0@4@`04Q<>01<D3`0A4Pd03@l:014F400B5a4010P401`Q6`093PP0
0`P201TN60021`40?T<m0005000J7aT010T40415@@021`<020`900@91@0E6QH03a@@00H;1`093PX0
6QlK01dR7P083@T2010E4@0O00hC3`0<4@d0314=00dB3P0F6aL041DA00X?2`0=4Ph041DA00lD4P09
3Q@04aLP018F7`0I72D061/R01<F6P0B4aL03PlA00l?400@41003Ph>00`=2`0@4Pl010T500X>2`0?
51005AXF00X?2`0@5A403A8>00hC3`0200`A3@05014F4P0A5A@041@C00lC4P0>4Q400P0?4a804P0>
4Q403a<B00lC4P0?4a803Q8A00dA400?4a@041@E00dA4P0;3a003Q8C01@H6@0X;2d0?D5201TM7P0E
6AX07b<T00lC51Cooooo000Kooooo`0801<C5@0@418030`>00/;3@0=3@l03Ph@00/;3@0<30h200d=
3`0800`<3P0;2`d03PlC00/<4@0C51T01@D:00d>4`0D5AX200`=4P0A00h?500:2a00414F00X;400I
6B80410J00X:500>3QL0410H00d=5@0>3QH030`D00X:4@0K6b807alW01@E6`0?41D00P0=3Q<02P0<
3A804A8G01TJ7`0>3a@020T>00d>4`0?3aL01`L?00l?5`0<31@201HF800?00X:5P0J6BL0D4mO01PG
9@0B4Qh03PhJ010@6@0L72@04Q8L00X95P0:2QD03`lJ00/;5P0S8b`0;Bhd00803a0E01l04Q<F010A
4`0D5AL05QTJ00/?400E6A/05a/L00dA4P0F6Q`07b<T01DI6P0>4Q@03a<E01<G600?4aD03A4D018E
6P0E61d04aHK010C600A51T051LL00lB5`0E61d041<H01XM8P0S9R/04QDI01LK7P0E6A`041@G0080
51PK00@04QHI010D5`0E6A`061`O0P0C5aX05P0D61/05ATL01HJ7@0E6A`04aLJ010D5`0E6A`051PK
01<G6P0D61/05QXM01XN8@0F6al04QLK014F6P0O92P09BX^01DJ7P0>4aL0314E01@I7@0?51P201`Q
9@0801LL7`0G7Ad051XJ01LM7@0L8R804aTI018H600D6QX301DK6`0301@I700J7bD04QHO008051PQ
00<04QHO01HJ8`0E6B800P0B5Ql0B00C5b0051PQ018G7@0F6Al051LL01DH7@0A51T04A@J01lR:@0A
51`05QTR00`?600Q92h0>3Y6010C700J7B@041<H01DH7@0;3Q<05aXO014D6@0C5Q/041<H01HI7P0?
4QL07b8W04]>D`17Bdh0310C01PL7`0?4aH051PK00dA500B5QT051PK00`@4`0C5aX03Q8E018F6P0A
5Q`041@M014F7@0B5ad041DI00lD600C61X061hO00/A4@0N92@06b4P00H<2@0A5Q004QLA00dB300A
5A<04QHG010D5P0D5a/03Q4H01LJ8`0G6B@04A<O010B600@4A<04a<E01LE600A31004`dA01dG6`0K
5QX05A0D014@4P804A8D00T0:bdd06=UL@0D5R8041<M00D84@0E62403a8I00lB600>4AH00`0=41D0
2P0=41@04aLJ00T=400>4QD02PhA01<G600<41403Q8B00hB4@0>4a4200hC3`0300X>3@0?4a803A4@
00803a<B01H03A4@00`@3`0H71/0:Rh]00hB4@0C5aH041@C00dA4P0B5QL041@E00X>3`0=4A8041@E
014E5P0@51D03Q8C00@7200M8B80<CDf00lE4`0@5Q@03aDC0P0<4Q000`0?5A<02a4?00`B400400hD
4P0V00`B3P0C6AD01P`801TO6`0B61@04ALD00/A3`0<4@l03A<A01LM700=4a804a`J01@M6P0<5Q<0
3aPE00T?3@0K81l09b//00/?3`0<5A@06bLV00`F5@0/>cX06bTZ014L7`0V<3@03aPL00PB5@0;51H0
2A4D02/c=P0>5QP041PJ00L<3`0?51L04QPH00hB4@0?510200hC3`0;014F4P0C61@03Q<?010E4@0A
5Q80314=00lD400G71P03Q8A00dA400<40l00P0=4A007`0>4Q403a<B00/?3P0:3Pd03A4@010D4`0;
3`h061dI00P=2@0<4@d03Q<?00H;1`0@5A404ADB034f<P1lPGd06AhJ00hC3`093PT02a0:00hC3008
3@H03Q<<00dB2`0:3`P03A8;00lD3@0A5Pl03a@=00dB2`0;40/00P0;40`02`0=4Ph03a@@010E4@0B
5a<0314=00lD400>4`l03A8>00lD400;40/03A8<00<0314;00@03A8<00`A2`0;40X03A8<0P0?50h0
1`0>4`d03a@>00/@2@0:3`P03Q<<00/@2@0<4@X00P0=4P/01P0;40T041D>00/@2@0;40T01``6014F
4080314;01X04QLA01hS7@0?50h01``600dB300;40X03Q<=00/@2P0:3`T02`l:018G4@0730H0314;
00hC3@0A5Q003A8<00X?2@0=4P`03a@>00dB300A5Q003A8<00lD3P0P9Al05AXD00X?2@803Q<=01P0
3A8<00/@2P0<4@/02a0:018D4P0B51403a8;00hA200C5`T0>3`[09JKR02UZID0?T<^024V4P0A5PD0
4QH600lB2@0B5@h071lH01LJ4`0<3`P041<<00hA2P0?4P/2010C300J00lB2`0>4@X051HA01@E4@0?
4@`030h;00d?2`0E5a803a4<018D3`0=3`X04Q@?00h@2`0D5Q403a4<00d?2P0<3PT03Q0;014C3P0B
50l03Q0;014C3P0@4Pd04aD@00<50@0?4@`200hC3`0S00X?2`0<4@d03A8>00/@300>4`l03A8>00hC
3`0I7QX05AXF00X?2`0=4Ph04ADD00T=300?4a@02PhA00lC5P17Bdd020`;018G4`0=4P`03A8:00dB
2`0>4`h03Q<?00`A3@0;40`0314=00lD400=4Ph02Pl;00T>2P0=4Ph04AHB014F4`0F6QT00P0Q9B@0
2@0D61L03Q8A00dA400@51<02Ph=00hB4@0=4A0020`;00hB4@0200dA40803Q8A00T03a<B00X>3@0F
6QT020`;00X>3@093@`03Q8A00hB400=4Ph00`0<4@d00`0=4Ph03a@@00H;1`0200dB3P0D01DJ5P0<
4@`02Pl900/@2@0:3`P02a0900lD3@0<4@X02a0900X?20093PL0314:00lD3@0E6Q<02Pl800dB2`0;
40T02@h700`A2P093PL400hC300@00lD3@0@5@h051TC00870@0C61803Q<=00T>200=4P`02a0:00dB
300:3`T02@h800`A2`0=4P`01@X400lD3P803Q<=00<0314;00T>2@0<4@/00P0;40X05@0<4@/03Q<=
00hC30093PL03aD;00P>1P0;40T03a@=010E3P0B5a402`l;01HK5`12Ad<0DEEB00hB3P0;40X03Q<=
014F400@5@l03A8<00P=1`0600/@2P0[038g<@2[/:X0:RlY014F400:3`T03Q<=00`A2`0;40X03A8<
00hC3@0<4@/02Pl900/A3@0@5A402@h:01PM6@0C5A8030h;00d?300C4a4051@B010@3P0?3`d0410>
00lA300<3PT02`d800`>2@0>40/03a4<018D3`0<3PT02P`700d?2P0<3PT03A8<00hE3P0>4`d04QLA
00lD3P0B50l051HA010B3@03014B3@0L00h?2P0;3@P07R<M00/>2P0E6Q@03Q4=010E3`0=4P`04QLA
00hC3@0?50h0314;01<H4P0C61<02Ph;01PM6@0@5A403Q<?01TN6P0Y;RX092TU00/@300@5A401``8
014F4P0<4@d04AHB00hC3`80314=0P0=4Ph05P0>4`l03A8>00dB3P0?51004AHD00/?6@0D62D03a<O
018F8@0A5Ah03Q4G014D600:3Q003@h?018D4`0?4@h03Pl=01DI5@0X;BT0?D8n014F4P0=4Ph300hC
3`804AHB00H02@h:00hC3`0B5QD04ADD00lC4P0=4A0200lC4P0400dA400>4Q403a<B00lC4P<041@C
00/03Q8A010D4`0C5aH051PG00lC4P0:3Pd04aLF00lC4P0@51<02Ph=014E500Dooooo`006oooool0
100D51H01`L901PH6P0;2`d200T92`0I00h>400@418010@600/;3@0?3a4051@F010A5@0720`0QhR<
03Pi?@082@d03PlC01<D600;310020T=00X;3`061`/05QLL00h>5P061Ph04A4I010@600>3QH02@TA
00l?5`0200d=5`0d00h>600<31H02PXB01<C6`0>3QH04A4I00d=5@1:BU80W9bT00h>5P0K724051DJ
00`=4P0I6Ql010D:00`=4P092A4020PB00/;5`0d<d40ZjZh02TX=P0D520071`X00h>5`0J6R803`lI
01<B800B4Al03PhK018B7P0C4ad04Q8J01<D6@0D5AX05AHJ018C5`0?41@03Q4C00H:2`0F6Q/09b//
01<G600?4a@051PI010D5@0E6AX0310A01<G600@51D0310B014E60804aLJ0P0E6A`01`0B5QT041@G
00hB5@0D61/05a/N01<G6P0?4aH00P0E6A`05`0=4A@0310C01@H6`0>4QD03A4D01<G6P0F6Qd04QHI
014E600D5a`07B0U00lB5`0J7B803a8G01@G700?4QL041<H01DH7@0I724061/P01@G700H7B406AhR
00806QlS00D061dQ01HK7`0E6Qh04QLK01LL800202DZ;P0W01LL800M8RD03Q<F01@I700;41<04QLJ
01@I700A5QT02a0C01XO8P0H7B005a`O01PM8@0>4aT061`U00hB6`0@51d03a<L01HJ8`0J7RL04aLP
010D7@0C5b0051PQ00lD6P0@4aX04aHK018E6P0?4QL041<I01@G7P0@4a`051LP014D7@0B52005QPT
01<F7`0=41D04ADH00803A4D00<051PK010D5`0A5AP01@0A5AP01@0B5AX051LL01<F6`0A51T04QDJ
00804aHK0P0@4aP07`0A51T051LL01HI7P0G6R806QdV01LJ8`0B5A`04aHK01DH7@0?4aD04ADF00/?
3P0>4Q004AHB00`A2`0A5Q003A8>018G4`0C5aH041@E014E600`<cP03a8I010C7@0:31P00@<@01@F
7@0C51H051@F01HC5P0G4QH00P0I4aL03`0G4AD05Q4E01<A500?3a404a@F01/M8`0I6bL04Q@P00P:
5@0?4Q/04aHO00d@600L7bH000<801@G700200P;400H01@G700@4aP03Q4F00dA5@0>4QD041@G010D
5P0=4A802`l@00/?3P0<40l041@C00T=300830/04ADD00X>3@0J7Qd01`/:00`@3`0@51<02`l>00lC
4P052@P06alN0P0:4100300;4A403A<C00hD500A5aL010X:01/Q8@0220P07bDU01<I6@0>51@020h<
00X@3P<03A<A05D03aDC00`B400=4a403Q@B010F500A5aD04QPF010F4P0:40`05adI01dS7`0C6AD0
3Q@@018H500?5A40318>00/A3@0:4@/0214<00/D3`0<5Q803QLD00dC4@0I7Qd0=CTj00D:3@0?5aT0
3APJ00@?4@0:6AT06RT/02Hd=`1`O8804A`R018M8`0<5Q/01a0E01XR9@0>5AL000L901LL7`0@5AL0
20h>00P<2`0C61@01``800hC3`0E6QH00@H200lD400@5A40314=00dB3P0?51003Q<?00dA400830/0
2@d<00lC4P0@51<03a<B00X=300A5A@06AdL00dA400830/03A4@00X?2`0=4Ph041DA00P=2@0B5a<0
5AXF00lD400<4@d02a0<00`A3@0>4`l03a@@00`A2`1;D4X00PL101`Q6`000P003A8<00<02a0:00`0
314;00hC3@0<4@`03A8>00lD400=4Ph02a0<014F4P0I7QX03Q<?00L<200=4Ph200`A3@0700`A300S
:2801``600P=1`0B5a403a@>010E3`03014F400500hC3@0=4P`0314;00`A2P0;40T00P093PL0200;
40T0314:00/@2@0@5@h03A8;00hC30042@80314;0P0;40X01P0>4`d04AH@01<H4P0@5@l03A8<00/@
2P80314;0P0;40X01@093PP03A8<014F400>4`d02a0:0080314;02@02Pl9014F400:3`T041D?00H;
1@083@L041D?00L<1P0>4`d02@h800/@2P0=4P`03a@>00/@2P0=4P`04aPB00P:2@0A4a004QD>01LJ
4@0^<R<0PhMf0?7fhP3ZkMX0B4dg02hc7`0A5PD051P700H9000m@3T0RHb501lR6`0=40T05APA00X=
1P0<3`P200lB2`0300d@2@0;3PL030h900804aD@0P0>40/00`0C5A00418=00lA300400d?2P0]00`>
2@0=3`X0418=00d?2P0>40/051HA00/=200A4`h06Q`G01LI500@4Pd04aD@010E4@0A5Q80314=0046
0P0E6QH04AHB00`A3@0:3`/02a0<010E4@0?5100314=00D;2@0>51@02Q0@00hC5P0@5AT01``?01<H
6P0?5A<0318>014G4P0010004AP@00X?2P0=4Ph03a@@00dB3P0<4@d02@h:00dB3P093PX02Pl;0080
4AHB02L03a<A00lC4P0@51<02@d<00`@3`0>4Q403A4@00/?3P0A5A@05a/J00T=300830/02`l>00dA
400D61L020`;00dA400D61L03a<B00P<2`0I7A`01PT801PL6`000@003Q8@01HK5`0C61@04AHB0002
000H7AT02Pl;00/@300<4@d051TE01TN6P0@5A4051TC00dB30093PP00P0=4P`0800>4`d020d7010E
3`0?50h0314;00T>200C61803Q<=00/@2P0:3`T0314;00X?2@0C61803A8<00T>200;40X0314;00T>
200>4`d0IFYT030e;`042@<020d700lD3P0:3`T020d700lD3P0730H03Q<=00dB30093PP03Q<=0P0;
40X04@0>4`d03a@>00`A2`083@L02@h800`A2`0>4`d04AH@018G40062`@02`l901HL4P0=4P/03a@=
00/@2@0=4P`03a@?00803a@@00`03A8>00D:1P0=4P`02@h800X?2@0?50h03Q<=00H;1@0@5@l03a@>
00hC3@0=4P`200hC3@0Y01DJ500N8ad0724K00X?2@0@5@l01``600hC3@0M8Q`000<0010E3`042@<0
4aPB00L;200Q9R8010T500lD400B514061XG01LI5P0@40h03`l=01dM6`0;2`T03`l=00/=200>40/0
2P`700`>2@092`H03a4<01/M600C5A004Q@?00T;1P0;3@P04AH@00T@2@0<4@/020d701@I4`0@4Pd0
0P0B50l03P0?40/03Pl:010A300>3`X04A<>00lD3P0320803a@>00@90`0V:bD04AH@02db;00W;2H0
2a0:0P0?50h04P093PT04AHB00hC3`0;40`05Q/G01dR7P0I7QX03Q<?00X?2`0=4Ph02Pl;00T>2P0=
4Ph04QLC01DJ5P0?5100314=00hC3`803A8>0`0@5A404P0@5A<02`lJ00lE8`0A5b<03A4L00T=5P0D
61l020/@00T=400;3`l03Q0?010B3`0A4a0041DA01XO6`0K81`03A8>00X?2`803a@@00T04QLC01LL
600=4Ph02Pl;010E4@0;3`h0310?00dA400>4Q400P0@51<01`0B5QD0310?00`@3`0B5QD05ATH010D
4`0<40l00P0?4a801@0E6AP082@S01lS8P0?4a803Q8A00803A4@00<03Q8A00lC4_ooool04oooool0
01_ooooo00P04Q8D00@41P0410H00P8401<C5@061PP020P:018B50803Ph@01802PX<00`<3P010PH0
5AHJ07enPP13A4P051DI00011@0:2`l020T=01<D600I6Qh01`P<00X;3`0=3Q<01PH>00d>4`0e=Cd2
00l?5`0g00d=5@0<31H02`/E00h>600C4ad05QHP00/;500A4A/02PXB00h>5P0J6R805QHN00d=5@0E
5Q/02``A00<42@0B4aP0414F00d>4`061``03@dE00l?6P0L72P0IfMc01`L:@0@41`06QXT00h>5@0G
61d03PlG01<C7`0B4Al03PhJ018B700C4ad03`lH00h>5P0A4QL04a@I01<D600A4QH04A<G00L;300>
4QD051PJ00/?400?4aH03a<E00/?400>4QD03Q8D01DI6P0D61/041@G00lC5P02014E60805ATL0P0D
61/01@0B5QT051PK01@H6`0A5AP041@G008051PK0P0>4QD03@0C5aX05ATL018F6@0D61/05ATL018F
6@0C5aX00005024T:@0?4QL05APM01dP9@0=3a@00P0B5AX01P0E61d061/P01PK800E61d04aPL01@I
7@805a`P02405Q/O01@I7@0?51P03a@H01DJ7P0L8BD06b0T01<H700<4A@020d@01@I700P9BP0724T
00L<3`0H7B005a`O01HK7P0>4aH05AXM014F6P0G72806alX00lC700B5Ql041@M018F7`0R9Rl06AdV
01<G800D62404ADN00/@5P0?4QL00P0B5AX01@0@4aP04QDK01HI800@4aX04aHO008041<L00@051HR
014D7@0@4aP04aLJ0P0>4QD01P0D61/04QHI00lC5P0?4aH041@G014E60804QHI00<04A@I01<F6`0B
5AX00P0A51T0100C5Q/041<H010C600A51T2018E6P0;014D6@0C5Qh04aHO018E700?4QP03a8G010D
5`0=4A804QHE014E500A5Q800P0C6180900@5A002a0<014E500C5aL03A4D00`@4`0<3aD041<L01@G
8@0F62@03a4N01XL8P0D5AL051@F01@C5P0J5AT07APL02XT:00R7B404`hB01<B5@0F5aT04Q<E00X<
4P0:31P04Q@P01/N9`0I72D04A@M00lB6@0;3Q<07B0U04Y=DP0K7R<05aXO00`?50803a8G01D03a<G
00lC5P0?4aH05a/M01`P8@0H71d041@D00/?3P0:3Pd061`K00L;2P0>4Q403a<B01@H5`0B5QD01PX9
00/?3P0>4Q404aLF00L;2P0B5QD00P0>51@300dC4`0900lE5@032@T03aDE01@J6P000P800`T900dB
4P0:40h02a4?0080318@00@03A<A00hD4P0=4a403A<A100>5180500G7A/0318?00@:1P0;4@d04QPD
00X@300>51003A<?00`B3P0>5@h051/D01LQ6@0:4`h02A<?00`E4P0<4Q005Q/K02``<@0D6A`02A4D
0P084aD060075AP0;C`o071mP`1BGfD03Q/Q02Td>P0@6R00628T08N?TP1BFU`04QXL01<H6`0>51@0
4QPF01<H500=4Ph02Pl;00H;1`052PH03A8>00hC3`0B5a<03Q<?00/@30803A8>00<03a<B00`@3`0<
40l00P0?4a802@0>4Q404ADD00lC4P0=4A003a<B00/?3P0<40l0314=00D:1P0200`A3@0300dB3P06
2`L03Q<?00<0314=0P0>4`l0400<4@/020d70002000B5a408BHP014F400=4P`0314;00dB300>4`d0
3a@>00`A300<4@d03a@@00`A3@0:3`/200hC3`0<00T>2P0730P02@h:00lD400;40`020d80005000A
5Q003A8<018G4@0D6A<03Q<=0P0:3`T05`0;40X02Pl900T>20093PP0314:00dB2`0<4@X02Pl800/@
2@0?50d04aPA010E3P0010003A8;01<H4@0?50h03A8<00/@2P0:3`T02a0:00`A2`0@5@l03Q<=0080
314;00D03A8<00`A2`0:3`T0314;00dB300300X?2@0>00L<1P0>4`d020d700X?2@0=4P`010T300lD
3P0N8ad0;S<]01LL5P042@<04aPB00P=1`0:3`T200lD3P0E00dB300<4@/030h;018D400@4``05QT@
01lS501CEdH0/[JU0;BiY@0h?BT03A8001DI200>4P<02`h501/N5`1FFE8061/D010C30072P<03a8;
008041<<00H03a8;00hA2P0<3`P03Q0;00d?2P0>40/2010B3@0300d?2P0@4Pd03a4<00<03@l:01H0
3Q0;00lA300?4@`0418=00`>2@0=3`X04Q@?00h@2`0@4Pd05QPC018D3`0=3`X0418=01DJ5P021`<0
82DQ01<H500=4Ph00`P400`A3@093PX02Pl;0P0=4Ph03P0;40`05adK00@:2P0@5QH03Q<F00T>4P0E
6Qh04AHI03To?`0d>SP04QTC01dT700;4P/0314=0P0>4`l03@0<4@d02Pl;01@I5@0:3`/03Q<?018G
4`0E6QH092TU01<H5@0>4Q403a<B00T=300<40l00P0=4A006@0:3Pd03A4@01@H5`0:3Pd020`;00`@
3`000`802`l>01<G5P0;3`h0310?00D81`0F6QT00040014E500010<06QhM00lD4@0<4@d051TE00T>
2P0E6QH02Pl;00P=2@0;40`00P0:3`/0400>4`l0314=00X?2@062`D02@h800hC3@0;40X02@h800L<
1P0:3`T010T3014F40001@004QLA00lD3P0<4@/200/@2P0M00L<1P0>4`d06b0J00/@2P0:3`T041D?
00@90`0;40X06AhH00T>200@5@l04QLA00hC3@0<4@/02Pl9010E3`083@L03a@>00hC3@0;40X03A8<
00`A2`0=4P`041D?018G4@0?50h03Q<=00dB300;40X00P0:3`T04`0:3`P010T201HL4P0010003A8;
00/@2@0@5@h0724K01<H4`1CF5@0DUMC00dB3P0?51003a@>00X?2@083@L02a0:00dB300:3`T0100;
40X200X?2@0700@9100=4P`0314;00X?2@0D6A<02a0:00L<1P02010E3`0:00hC3@062`D010T300P>
2P093PX03A8>01HK5`0Z;2T04Q@A01@F4`804A4?01P05aLE00l?3@0?3`d04A<>01<E400?4@`04Q@?
01HH4`0>40/0418=00H80`0D5Q406adH01<E400=4P`01@`501<H4P0=4P`04aPB00h@2`0C5A006Q`G
01<D3`0A4Pd201DF4@0>01@F4@0=4P`01@X401PM5`0T:B<0FEiH02ld;P0O91h0724K00/@2P0?50h0
4AH@00P=200;40`200dB3P804QLC00<03Q<?00lD400@5A400P0@5A401`0A5Q803a@@010E4@0C61@0
3A8>00/@300>4`l00P0<4@d0500>4`l03a@@00lD400>4a405A`T0088500=51l000<>00D94P073140
51PK01<G600B5QH04A<B010B3`0?4@h03Q<?01@I5@0C61@0314=0P0=4Ph01P0<4@d041DA01DJ5P0G
71P03A8>00hC3`80310?00X03Q8A00lC4P0@51<041@C00hB4@0@51<03Q8A00`@3`093@`020`;0P0A
5A@01P0:3Pd02`l>01XN7@0R9RD03A4@00`@3`802`l>00<0310?00dA4?ooool04oooool001_ooooo
020020L<014@5@0920d01`H;01TH7@0<2a0061LL00`;400:2@h030/@00h=4P0@3a@030d?00l@4P0C
51H01@H800X;3@0;30h03PlA00X;3@0D5AL08b@V00h?4@0<3A002``?018C5P0L7B00?3e100X;3`0;
31403a0E00l?5`8030`D01d05QHP01dM9`0D51l03`lK010@6`0=3AL071`V00/;5@0>3QH02@X?00`=
4P0F5a`02@X?00h?500<3A0051DI01@D6`0=3AD0<30i05eMIP0<31H03@dF01LG7P0=3A<04Q<F00h?
500B4Q/04Q8L00h>5`02018B6`0C010@600?3aL04A8G018C600A4QL0414F018D6@0C5a/05aXO018E
6P0B5QX05aXO00lC5`0G6Qh041<H01@H700?4aL03a8G01<G6`0201<G6005010D5@0B5QL04ADF00hB
4`0@51D0100A5AH0100D61X051PK014E600A5AP2018F6@0?01HJ7@0C5aX04QHI01<G6P0?4aH04QHI
01DH7@0G6Ql041<H01dP9@0<3a@05aXO01HI7P0D5a`04aHK00<05APM00P04aPL01@I7@0F6al05Q/O
01DJ7P0C61`041DI014F6P8051TM0P0B5a/03`0B5a`06QlT01DJ7`0F6b00314F028W;00B5a`051TN
01<H7@0@5AX0724V01<H7@0D6Al05a`R00`A5`02018G7@0:01<H7P0E6R004QLM018G7@0D6Al05Q/Q
01<H7@0C5a/051PJ018F6@8041@G0P0A51T02@0C5Q`03a8I00lB6@0B5Ad03Q4H01@H6`0C5aP03Q8C
00lC500201@H6@07014E5P0B5QL04QHG01@H6@0E6AX05ATL010C6002014D6@0500lB5`0@4aP04A@I
00lB5`0A51T00P0B5AX0:@0@4aP03a8G01<D6P0@41P0414G018C6@0@4AH03PlC00l@4P0>40l04aDD
018D4@0@4Pl04aDC00lC4P0>4Q804QHH014E5`0?4QH04QDJ00hA600G6R<03A0I00`?60082QD04aLL
010D5@0?4A<04A4C01DD5`0J5aX091lS01lK7`0D4aD0414C010C500E61T0:bhc02HY<@0E62004A@K
00802@`B00`04QDJ00/>4P0E6Ad09BT/00hB500B5QT030lD00hA600@4aP04A@I010C600>4QD2010D
5`0<00lC500=4A80310A00`@3`0:3Pd0310?010D4`0?4a8061`K00hB4@0?4a80310?0P0@51<01P0;
3`h041@C01<H6P0B5aX041DH00hC5P803A8E00P02PlB01LL7`093Q4051TL00P=400<4A<03Q@C00dC
4@80318@00@03A<A00hD4P0>51803Q@B100=4a40<`0:40l04QPH00`B4@0>4Q4041HD00X@3P0=4a00
2a4=00X@300=50d05A`E01TS6`0@6A@02aD?00XC3P0=4a403a@D01@H6P093Q403ADI018M8@0@6b00
8S0e08fLX@3ao_l0/L3402@c>00H9B/07RX^00TE5P0C7Ah03ADE00H>300C6AP03A8@00D:1`0E6QH0
4AHB00hC3`0W;2P05a`H014F4P0=4Ph04QLC00lD400@5A403a@@00/@300>4Q<041@E00lC500200dA
4P803a<D00P0310A00<61`0C5aP041@E00lC4P0C61@06AhJ01dR7P803a@@00<03A8>00hC3`0=4Ph0
0`0=4Ph02@0>4`l0314=01HK5`0D6AD02a0<00P=2@0=4Ph03Q<?00dB3P0200hC3`0F00lD400=4Ph0
3A8>010E4@0>4`l02Pl;00/@300<4@d03a@@00dB3P0;40`051TE01<H500A5Q400`L301`Q6`0>4`d0
2@h800lD3P0<4@/03A8<00hC3@<03a@>00@0314;00dB2`0?50d03a@=0P0<4@X01P0?50d00@H001/P
6@0730D02a0:00lD3@803A8<0P0<4@/01P0=4P`041D?00lD3P0=4P`02a0:00`A2`803A8<00@01``6
00lD3P0=4P`02@h80P0?50h0300A5Q002@h800X?2@0>4`d03A8<00`A2`0730H07B8L02H[9@0:3`T0
3a@>00dB30803a@>01P03A8<00/@2P0A5Q0061dG00d?300A4`l03a8;01@G3P0C5`T05a/;01lS4`0d
>2P08RHF00dA1`0>4PH03A4401@G3`0;3PL071lH018E3P0@4``030l800lB2`0>4@X200d@2@0:010C
300A50d04aD@00`>2@0=3`X05ALB01HH4`0<3PT0418=00lA30803@l:00L03Q0;00lA300B50l0418=
014C3P0>40/03@l:00804Q@?100=3`X02P0?4@`0@DI204=8A00420@04AHB00460P0E6QH03Q<?00X?
2`093PX300/@300:01XP7P0A5aL04QPI07f2QP1[L7@04AHJ00hC5P0=4Q@04QPF00hD40803QD>02l0
3Q8@00lC4P0>4Q402`l>00X>3@0830/020X9014E500K7ah04QHE00dA40093@`0310?00dA400:3Pd0
2`l>00`@3`0?4a802`l>00T=300?4a80310?00X>3@0<41004aLH00/?400>4A804ADF00X>3`0>4Q<0
41@E01dQ8P0=4A803a<D00/?400A51800PL300dB3P0?5100DUMC01<H500=4Ph04AHB00lD40093PX0
314=00dB3P0200`A3@0R01@I5@0H7AT04QLC00dB3P0>4`l03a@@00dB3P0=40d03a@@00`A3@0:3`/0
2a0<00`A3@0>4`l03A8>01<H50082`P0724M00`A3@0;40`0;C8^030d<@0=4P`01@X500dB30093PP0
1P/500lD3P083@L03A8<00P=1`0?50h0314;00/@2P803A8<00L03Q<=010E3`0B5a404QLA01<H4P0@
5@l03A8<0080314;0P0=4P/03@0A5Ph05Q`B010E3P0;40X02`h:01<H4P0?50l04AHB018G4`0?5100
314=00hC3@0<4@/00P093PP0100<4@/03a@>00/@2P0>4`d2010E3`0W00hC3@0=4P`03a@>010E3`07
30H03Q<=00X?2@0520@03Q8=00T>200G71H01``700`A2`0A5Q002Q0<00lD40093PX02a0<01@F4`0A
4a003Q0=018B400D51803@d;01DE4`0?3`d030h900h@2`1>D4/0;c4/00/=200@4Pd03@l;01DG4P08
2PD04A<>00h@2`0_=2h06R4J00803Q<=00h01``600H80`0?4@`03Q0;00d>2@0A4Pd0414<00X;1P0=
3`X03Q<=00/@2P0?50h010T301lT7P<041D?00@03Q<=00`A2`0<4@/03Q<>0P0@5A402P0>4`l03a@@
00lD40093PX04aPD01PM6@0?510041DA00lD400;40`200lD40802a0<00<041DA00`A3@0=4Ph00`0>
4`l0300=4Q0020`A00XC6@0=4aP05QhS00hE6P0<4A<05A/L01@J6P0C5aL041@C00hB4@803A8>00@0
41DA00lD400?51004AHB0P0>4`l01`0?510020d9020U8@0=4Ph04AHB00dA400>4Q400P0?4a82010D
4`0800hB4@0C5aH041@C00dA400H71/0:Rh]00`A3@0?510200/@3004018G4`0F6aL03a@@00hC3`80
3A8>00<03Q<?00lD4?ooool04oooool001_ooooo03`05aHK00L62`0510T03`hC00/:3`0510T010<8
00`;400K6Ql02PT>00/:3`0N7B8020T;010A4`0720X051DG00/<3P0720X03@h@00P92`051PP03PlA
00T:300>3a405ALF00T;2P0C5A@01`L901LH6P0@4AD02``@010A5P0>3a@02``A014A6@0F5R001`LD
00/:60071a<0=SI2061PJP0Z:S@03PhF00h?500J6b008b@Y00P93@0?41@051HE00X<2`0<3@l0414E
01TJ7`0@4AH03@dD00l@5@0B4aL030h>00lA400?4A82014B5`0400l@5@0A4QL04A8G014B5`804a@I
01L04a<J014A6@0@41P03a0H01<F7@0K7RD04aHM01DH7`0G6R402`hE01PK8P0;3QD041<J00L:4@0@
4aX02PdA00dA4P0?4a@04ADF01TM7P0L82405ATJ010D5@03018F5`0A01@H6@0F6Q`04aLJ00lC5P0B
5QT051PK014E600?4aH03A4D018F6@0E6A`04ADH010D5`0H6b0061/R02T/<`0T9bh00P0C5Qd01P0F
6B004aHM010C6P0A51/04QDL01<F7@<05Q/O010051TM018G6`0?51P05a`P01@I7@0A5QX051TM01HK
7`0B5a`08bL`01PL9@0@51d06alX00lC701@E5d0=SY30`0E6B802P0B5Ql041@M00hC6@0H7B404AHJ
01DJ7P0F6al0724U01HK7`0D6Ad2018G6`04010E6@0=4QH04ADF010D50803Q8C00@03a<D00lC5P0B
5QT051PK0P0@4aP01`0B5AX03Q4F01<G6P0@51D03a<D00hB4`0@51D01@0C5aP01@0B5QL04QHI00hA
5`0@4aX03a8I00803Q4H010041<J01<F7@0A51/041<J014D6`0B5A`04aHK01@E6@0@4AH04A8F01DF
6P0B4aL03a0B01DF600;3@`03Q0?0P0C5A@03@0D5QD03a<F01HJ7@0E61d030lD01LJ7`0V:Bh092L^
00X=500@4aX061/R01TL8`0N8RL00P0<4Q807`0?4A<0410B00l?4@0<2`d03`lA01HF600@4a@020h>
01DK6`2<T9@0TIBI02/^<`082a0041@G014E600@51L06QhO014E5P093@h04QHE00L;300?4aH03A0G
014D6`0C5Q`04A@I00d@5@0>4QH041@G00lC5P0>4Q@00P0=4A80;00<40l051PG00P<2`0420L03Q8A
00dA400A5A@01`/:010D4`0830/02@d<00X>3@0@5AP03QHH00dE5`0<51H03ADG00hF600G7b400@T;
00dE5`0@61X0210B01DM7P0@5QH03Q@B00`B400>51803aDC00dC4@0<4Q003A<A00hD4P0?5A<041HD
014G5P0C61/010T<00lD5`0G71l04QPH01@J600=4a403A<@0P0<4Ph0>00;4P`02A<;014J5@0;5A00
2Q<>00lE4`0@5A@02@d@00hC5`063Q801Q4G01<M9P0R<3L0D5mV0;C6bP1]Oh<062X^018Q900=71h0
00`<010J6`0740h010d800/A3@0F71H06AhJ00X?2`0A5Q802Pl;02T^:P0G71P020d900hC3`0;40`0
3A8>01XO6`0F6aL02a0<00/?400>4Q<03A4B00/?400=4A8041@E00/?400D61T05ATJ018F5`093@h0
3Q8A00`A3P0L8Ad07R<O00T>2P0<4@d041DA1P0=4Ph01@0;40`000D1010E4@021P<09BXV00803A8>
100<4@d04`0=4Ph03a@@010E4@0@5A40314=00/@300?51002@h:00X?2`0E6QH02a0<00P=2@093PT0
<CH`00@90`021`400@H000/@2P0=4P`00`0>4`d00`0;40X02Pl900/@2P0200hC300C00`A2P0;40T0
3A8;00T>1`0H7AH0I6UR02/`:@0H7AH01P/500L<1P093PP0314;00dB300?50h05Q/E00`A2`0:3`T0
20d700X?2@0200/@2P0500T>200=4P`02a0:00hC3@0D6A<00P0=4P`08P062`D041D?00/@2P0>4`d0
3a@>00/@2P0:3`T0314;00<80P0I7QP020d700X?2@0@5@l04aPB010E3`0P9Al0>3dg00`>2`0>40`0
3A0900`?1P0D60/03Q8401/O4@0@50P020/000@7000B5@d010L000X=1P0B5@h02@`5018E3P0930D2
01<F3`08014D3@0=40T03A09010C300B5@h04A<>00lA300@4Pd201<E4003010B3@0?4@`03Q0;0080
3@l:0P0?4@`00`0@4Pd03@l:010B3@02010B3@0401<E400M7aX04A<>00/=20802P`701`02@/600L;
200B5a<04AHB00X?2`0L8Ad03A8>00lD400=4Ph0314=00/@300<4@d03A8>00TA3`0:4Q@00`/=0459
C00_=S`02Q4G010H6`0;4aD051dJ00T?300230@02Q4:00`@3P0<40l03A4@0P0<40l0200=4A006QhM
01<G5P072`X03a<B010D4`0>4Q402Ph=0P0;3`h06@0:3Pd0310?014E500<40l02@d<00hB4@0?4a80
3Q8A00X>3P0=4A802@d>018F5`0;3a000@D601LK700B5QL00042014E5P000@803a<D010D4`0;40`0
51TE00T>2P0>4`l00P0:3`/200/@300500lD400B5a<02Pl;00hC3`0=4Ph00P0@5A402`0:3`/02@h:
00L<20052PH041DA00D:1P1JGe/05AXF00`A3@0?51002a0<00801``801802Pl;01TN6P0E6QH02Pl;
00<810000P003a8?010E3`0730H03Q<=010E3`0A5Q00314;00T>200;40X02@h8014F400<4@/200dB
30803Q<=0`0=4P`200lD3P803Q<=01404AH@018G400?50d06QlH01@J40083@H061dF01<H4@0@5@l0
2Pl:01HK5`0G71P0314=00lD400:3`T03A8<00hC3@0200`A2`0600dB30083@L02a0:00hC3@0=4P`0
2Pl90P093PP0=@0=4P`00PL1014F400320804AH@00dB30011P0000<001dR700;40X05a`F00/A3@0C
61@0314=01@I5@082PL04A<@00/=2P0B4Q005ADC00P81P0E5A<03`l=01@F4@0=3`X06adH01@F4@0Q
8ah01`T4014C3P0F61<020X501@F4@031@0082DO00T@2@0D6A<02a0:01HK5@0E5a80418=01DG4P0:
2`H03@h9014B3@0B4`h061XE00lD3P083@L03Q<=00lD3P0M8Q`05Q/E0080314;00D04AH@00X?2@08
3@L03A8=00dB3P0300`A3@0@00dB3P0<4@d06QlK020U8@0D6AD05AXF01<H500=4Ph03a@@00hC3`0<
4@d03A8>014F4P0>4`l03a@@010E4@803a@@00L03Q<@01`U900B71d05b4R00H>40084A0051dK00<0
3Q@B0`0>4Q403@0<4@d04QLC01<H500<4@d03A8>00hC3`0730P03A8>01LL600m@Sh0724M00dB3P0>
4Q400`0?4a82010D4`0<01@H5`0A5A@0310?00X>3@0B5QD06alN00T>2P0;40`0314=010E4@0C61@0
2a0<0P0@5A4200lD408041DA5?ooool001_ooooo03H040lD01@C600I61d04a8G00L62`0a<3D0=3<h
00T83@0@3a@030/@01PG700O7R<051DG00X;3@00008010D700H72@0C51H02P/=00l@4P0;30h03@h@
00L82P0>40l01PL500H81@0L7Qd03@l>01LH6P0000801`P<00d>4`0>3a@03@hC010@600B4Q`03PhK
00l>70081aD03PhJ01TI8`0000T03PhF01XK800L7B804A8G00/<400K71h03Q0>01DG5P0C5A@01`P;
00`=4P092Pl2010A5@0400l@4P0>40h03Q0=00lA40804A8D00@03a0B014B5P0A4QH03a0E0P0A4QL0
400C4aX04a<K01@D700C5A`04QDL01HI800>4AP04A@K01LJ8@0C5Qd07b8Y010C6P0B5A`03Q4H02<V
;@0<41@201@H6@07018F5`0F6Q/05a/L01PL7@0I7Ah05a/L01HJ6`0201@H6@0I01HJ700C5aX03a<F
018F6@0C5aX04ADH00lC5P0>4QD05ATL01PL7`0D61/04aLJ00L:4@082a80FUeT06IYL00]<3L01PP?
01DH7`0B5A`041<J018E700C5Qd051LN01<H700201@I7@0L018G6`0@5AT03A8F01LL800C61`041DI
01@I7@0F6al04QLL00P<5@093AP051PS00X>6@0[;cX0]KW404I:E@0E6B@04aLR018F8@0@51l06AdV
00`A5@0E6Qh03a@G01DJ7P0D6Ad051TL01@I7@805AXM00L051TM01<H6`0A5QT03A4@00`@3`0=4A00
41@C00804aLH00`04ADH01@H6`0@51L041<H01<F6`0?4aH04QHG00lC500A5AH041@E00hB4`0A5AH5
010D5@13010D5`0?4QP041<J010C6P0>4AP03a8I010C6P0E61l04QDL010C6P0A51/04aHM01@G700A
4QD03a0D010A5@0A4QH0414C00l@4P0@4A<03Q0?00X<2`0>40l051HE018C5@0@4aP061/R01HI7P0;
3Q@061/P02T/<@0c=Sd041<J01DH7`0?4QT01@P?018H6`0<5A@03aDE010E5P0@4A<03`lA010@4P0?
41804A8D018G5`0=5QD041TH03@k?00Z;C802PdB010D5`0A5AP02@d@018F5`052@X02@d>010D4`0?
4a800`L600/?4P0>4AP041<J018E6`0@4aP03Q4F00hB5P02010D5`0L00lC5@0>4Q<03Q8C00hB4@09
3@`05ATH028V9@0830/01@T8010D4`0830/07b<R018F5@0A5A@02Pl?00hC5P0<51H02a<E00`D5P0=
5AL03aLI014I6`0X<3804a/M00`D5P022P`01Ph@00hD5080318@00<041HD014G5@0=4a400P0<4Q00
300>518041HD014G5@0B61L0OX>602T^<P052Ph02PlC00D:3@0;4A40318B00hD4P803aDA03P03A@>
00TC2`0:4`h02A<>00XC3P0B61H05Q/L00hB5@0=4QH041LN01DP9P0@6R<03adU00`M900W>Cd08C<g
01<U9`0=71l000d=01<Q8@0=5aH03QPC01@N5P0B6A803aD>00H;1@0C61@04QLC00lD400=4Ph00`P4
014F4P0?51002@h:00`A3@0J7a/061dI00dA400>4Q<03A4B00`@4@0;3a003Q8C010D5@0<41402@d>
01DI6P0=4A802@d>01DI6P0>4Q00314=01<H500?51003Q<?00P=2@803A8>0P0>4`l0100=4Ph0314=
00lD400B5a<200lD400401TN6P0<4@d03A8>00`A3@<02a0<01<03Q<?00lD400?51003a@@00hC3`0=
4Ph04AHB00dB3P0E6QH0:2dY018G4`0:3`/07B8M06mdKP0P9Al061dG00dB300B5a403a@>00803Q<=
00H03A8<00X?2@083@L02a0900hC300=4P/200X?200A00dB2`0;40T03Q<<01XO60000P004AH?00`A
2P083@L02a0:00`A2`093PP02Pl9014F400;40X02Pl900T>200:3`T00P0<4@/00`0=4P`0314;00/@
2P0200dB300S00X?2@001@001P/501<H4P0<4@/08RLQ01TN600E6Q@020d7010E3`0?50h02@h800/@
2P0730H03a@>01HK5@0>4`d041D?01`Q6`0?4@h03A0:00d@2@0520004A@:014E1`0G6`d04aH;01@G
3P0>4@X0CU1;01/M600930D04A@=00@7000K7QL00P0@4``01`0K7QL05aXC014D3@0?4P/03Q4:00lB
2`0<3PT00P0?4@`00`0>40/03@l:00h@2`0200h@2`803@l:01403a4<010B3@0?4@`02`d800lA300A
4`h0418=01<E400A4`h02`d800T;1P0B50l05aTD01DG4P0G71P010T501PM6@0200hC3`0C00P=2@0>
4`l03a@@00hC3`0=4Ph0314=00dC3`0<51<04QXL00`D5P0@61/010/A014H7P0;4A@01@d?01/T8@0@
6AD0D5YB00`F3P0200/?3P0600`@3`0=4A003A4@00/?3P0420L051PG0P0@51<02`0E6AP01PP700X>
3@0;3`h03A4@00X>3@0<40l041@C00dA400;3`h03A4@00803a<B01805ATI00041@0B5QL0?D5201`P
8@0<41401`T:01TM7P0P92D04ADF02HZ:`0F6Q/07b<S01@I5@062`L04aPD014F4P0>4`l300/@3004
01<H500G71P0314=00lD4080314=00l02Pl;00H;1`0:3`/082DQ00T>2P0;40`05Q/G07^0O00D6AD0
2Pl;00hC3`0;40`0314=014F4P0H7AT00`0=4Ph01P0<4@d020d901PM6@083@L01P/5010E3`8020d7
00d03Q<=00`A2`0<4@/0314;01DJ500>4`d04AH@00hC3@0?50h03Q<=00`A2`0;40X0314;00<03A8<
0P0<4@/02@0<4@X0J6eV07QnM00?5@/0314:00T>20001@008RLQ00/@2`0200`A3@0400L;1`0G71P0
2a0:00dB30803Q<=00<03A8<00/@2P0<4@/00`0>4`d0400;40X02Pl9018G4@0E6Q@01P/500X?2@00
0P0092TS00dB300D6A<082DO05MLEP0?50h0008004aBCP0320@200P=2@0301@F4`041P<03Q0=0080
4a<A00T030`:014A3`0@40h04A<>00D70P0L7QT03a4<00h@2`0<3PT00P0@4Pd01P0:30L01@H301<E
4024RH<09B`U00D:108041D?0P0@4Pd07P0=3`X030d801XK5P0D5A002P/6018D3`0?50h02Pl900dB
30093PP01P/500/@2P0<4@/02a0:010E3`0>4`d0314;00`A300;40`041DA01HK5`0A5Q80314=00/@
300C61@061dI018G4`0D6AD04aPD010E4@803a@@0P0>4`l200lD40<041DA00T03a@@00hC3`002@H0
3aXF09bWX`0j@d006B8O004:1`0A5aD00P0@5Q@01P0?4a803Q8A00dA40093PX041DA014F4P802Pl;
00L0314=00lD400<4@d03A8>02P]:@0B5a<041DA00803a<B100@51<0300;3`h03A4@00lC4P0?4a80
2Ph=00D9200@5A403Q<?00T>2P0<4@d04aPD014F4P803Q<?0P0=4Ph200hC3aCooooo000Kooooo`0O
00`;4@0;2Q001`H<00/;400@3aD0BTU?04I5B`0=3A804A0F00L62`0<2a002`X?00P9300>3a405aPJ
00d>4@0?41801`P:00X;3P0A4Q@030d?010A500:2`h03@l?00lA3P041@<02@/800`>300B51<03a4@
00l@4P0200d>4@0E00d>4P0<3A402`/B00`<6@0;2QH03PhJ00d=5`082140418J010@600E5Q/05QLL
00d>4`0D5AT03PlB010A40082PX02P/<018C5P0?41@0414E00803@hB00X02``>014C4@0;3@X030h;
010B400A4a403a4@014C4`0@4A<03a0C0P0A4QL0<@0@4AL04A4H014A6P0B4a`03A0H014D700@4a/0
3Q4I01DH800@4a/04aHN00`?5`0@4a/08RD]04]>EP0D5ad061/N01HI700@51L04QHH01<G6@0G6ad0
6AdO01@H6P0D61T05QXK01@H6@0C5aT051PJ018F600A5AP04ADG01<G6@0E6A`04ADG01<G6@0D61/0
41@F018F6@0B5Q/07B0V01LJ80082a408RD[01PK8@0E61h051LM01@G700G6Ql00P0H6b002@0A5QT0
4QLK01@I7@0E6Qh051TM01<H700B5a/051TM01HK7`0201<H701E01HK800O8bd03a<O01XN:@0B5R40
3Q8N024U<00L82/041@N01DI8`0@51l04QHQ018G7P0?51P03aDE010F5@0S:BX08RPX01<I600A5aP0
4aTI01@J6@0C6AX04QLH010F5@0F6QT04QLC014F4P0C61@051PF014E500=4A804ADF00hB4`0?4aD0
4QHI00lC5@0C5aP04ADF01HJ6`0E6AX03a<D010D5P0?4aD04ADG01<G6@0F6Q`061`N01TL800@4aP0
4A@K014D6P0?4QT041<J014D6P0A51/04QDL018E6`0A51/03a8I00lB5`0@4Q804a@E018C500@4A<0
4A8D01<D5`0H6A`0;Bha01/L7`0;30l04Q<F00lA5P0>4AX04QDO01@G7`0>4AT041<J01PK8@0A51X0
4ADI018E6@0F6Ad04aLK01PO800200`E500700lD500@51D04Q<E01<D5P0@4A<03A0A014F5P0200dF
5@0F014H6@0>4QD03a<F014E5`0:3Pl03Q8C01`P8@0;3`h05a/J01<H5@0U:RL05a`I00hB500>4AL0
41<I014D6P0@4aT03Q4F00`@500<41<03A4D00dA4`803A4B00d04aLF010D4`0K7ah0:bl^00dA400@
51<04QHE00X>3@0U:BP041@C01<G5P0@5AD03Q<F00802a<F00`0318F00/C5P0=51L02Q4D07=kOP0f
?D001`dA00XB5@0<4QD02a4A00X@3P0=4a4201@J600300dC4@0>51803Q@B00<03Q@B00@03Q@C01lT
:00=4QL02a0D0P0@5AP07`0A5aL03Q@D00dC4P0=4a403A<?00lE4@0?5Q802Q<=00`F400:4`l041HD
01HK6`0>4QD03a@H00`A5`0M9b`00`/C00`I800<6b802a/O00`M7`0141404b4S00/G5`074A001Q4>
00L@300@61402Q4:018G400@5@l00P0B5a<07P0<4@d04AHB01<H500;40`03a@@010E4@0=4Ph03a@@
014F4P0>4Q006QhO010D5`0<41803A4D00hB5@0>4Q@0DEEG00lC5P0C5aT02PhA00/?4P0F6Q/04aPE
00lD400B5a<0314=010E4@0=4Ph0314=00hC3`803a@@0P0<4@d0200N8al03a@@00`A3@0_<c00314=
00dB3P0?51003Q<?0`0=4Ph0100>4`l03A8>00`A3@0<4@d200dB3P0=00`A3@093PX0314=014F4P0;
40`02Pl;00T>2P0T:B<04QLA00dB30021`4041D?00dB300200hC3@0B00lD3P0>4`d03A8<00`A2P0;
40T03A8;00`A2P0:3`P02a0900hC30093PL03A8;01<H4@0F6a@04aPA00`A2`0>4`d03a@>0P093PP0
1@0@5@l03Q<=00`A2`0;40X03A8<00803a@>00d03Q<=00X?2@0?50h03A8<00L<1P0M8Q`0@DI000hC
3@0;40X02Pl:00X?2@0?50h03Q<=00803A8<00<02Pl9024V800:3`T00`0<4@/08P0;40X02Pl900P=
1`0E5a802`d701@G400930@04A@:00lB200<3`D03a8:018E3`0;3@P092HT00h@3@092`H051L@0085
000F6A8041<<014D3@0B5@h04A@=00hA2P0=40T03Q4:00lB2`0@4P`03a8<00hA2`0>40/030h900X<
1`0>40/300d?2P0E00lA3@0@4Pd041<>00X=200=4@/03Q8<00d?2P0>40/04A<>00d?2P0;3@P051HA
01HH4`0?4@`03Q<?00D:1P0;3P/03a@@00T>2P0C61@020d900803a@@0180314=00/@300<4@h02A4@
00L>3`0;4aD031<F00hD6@0941D02A0C00lF5`0<5A80>40l09bTWP0K8ad03a<B00dA4@0<410200/?
3`0;010D4`031PD04ADD02<W9P0=4A002`l>00dA400:3Pd0310?010D4`0<40l00P0>4Q40600<40l0
3Q8A00`@3`0;3`h03A4@014E5P0K7b402@`?02T];`0l@4805ATL00lC5P0830h02`lB01DI6`1oPhD0
92P[00d@400?51005Q/G00dB3P0>4`l03A8>00X?2`803A8>0140314=010E4@0?51003A8?00`@3P0=
4Pl0310>00X?2`0B5a<01P/700`A3@0@5A402Ph:01LL600=4Ph02a0<010E4@0200/@300E01@I5@0N
8al02a0<00`A3@093PX02Pl;00hC3`093@T04AH@00/@2@0<4@/020d700dB300?50h02Pl900P=1`0;
40X04aPB00/@2`0A5Q403A8<008041D?00D03A8<00hC3@0A5Q002@h800`A2`0200lD3P0H00dB300:
3`T09b`U034g;P0>50`01P/400lD3@093PP04AH@01@I500=4Ph03Q<?010E4@062`L04AH@00/@2P0:
3`T03A8<010E3`0<4@/04QLA014F400>4`d0314;0P0;40X04@0730H04AH@00D:100=4P`04QLA06M/
IP0f>cD03Q<=00`?2`0D6A<03a@>01DJ500k@Cd02a0<00hC3`0;40`03Q0=00804aDB01H04a@A010A
3`0D5A<02PX8010A3`0G6A@03a4<00/=20092`H02`d8014C3P0>40/04aD@00L91@0D5Q406adJ08:7
P@0O9Ah01@T500hC3@083@L03@l:0P0@4Pd01P0A4Pd08R<N01/L5`0=3PT0418=00hC3@<041D?0140
3A8<01HK5@0?50h03A8<00`A2`0A5Q0041D?00dB3@0=4Ph041DA01HK5`0?5100314=00lD400=4Ph0
314=00dB3P0200`A3@@03Q<?00<03A8>00X?2`0?51000`0?5100200=4Ph0314=00hG4@0C7QL0?dY3
01HP6@0950d03aPC0P0=5Q401@0?5A<03a<B00hB4@0=4A40314=00803Q<?00X041DA01@I5@0@5A40
4aPD00L<200:3`/04AHB00L<200?510041DB1@0@51<04P0=4A003a<B014E500@51<03a<B00hB4@0=
4Pl06b0K01LL5`0>4`h03a@?01<H4`0@5A003a@?00hC3@0>4`h03a@?010E3aCooooo000Kooooo`0C
010?5`0:2A002`X@010?5@0<2a003PdB00L62`0;2`d020P:014A4@0<30/01`L701lN8`0:2@h061LL
00811`0>3A801@@900H52`0200l>4`0300/:400=31803`hC00<03PdB0`0>3Q0200`<300J00d=3@0>
3P`03Ph<00l?3`0A4A@020L<01<D600=41<00`H;014F6P0>4AH02`hE00l?5`0>3QH030/C00h=5@0<
31H0410H014A6@0@41P03@dE00`=4P0;314030dA00l@4P0C51D2014C4P804aDD00L04Q@C01@F5@0C
5A@03@l>01LH6P0>3a40414C00803@h@0100418F014D6@0H6b002@`A01<F6`0>4AH051LL00d@5@0;
3Q<061/P01DH7@0@4aP04QDM00h@70092aL03@lJ0P0F6B800`0B5A`05APM01TL8@0200lC5P0K00/?
4P0C5aP041@C00lC4`0@51D04QHE01DI6@0@51D041@C014E5@0A5AH04QHE018F5P0=4a404ALE00hD
500C61/06AhQ018G6P0H7Qh000<301PN6`0J8AX04AP@01HM5P0A5aL04QLJ00805AXM00<051TL018G
6P0E6Qd00P0F6ah0800E6Qd04aPK014F6P052Q005QXS00lD6P0E6Qh041DI010E600E6Qd03a@F01/Q
8@0T:RP06R0N00hD4P0A5A@06AhK01LL600830/03a@A01@I5@0M8B005a`I02@Y9@0Q9B@03a@A01HJ
6@0@51<08BDT02<W9P0B5QD04ADD0P0;3`h0CP0J7Qd0310?024U9011ADD051PI01PL7@0G6a`051PI
018F6@0@51L03Q4F00`?500B5A`04aHM010C700=41T030lH01<F6P0520d03A4D01<F6P0?4QL02@d@
01DI7@0>4AH04ADH01<G6`0@4aP04ADH010D5@0<41403A4B01<G6P0=4A@05APM03e0A@2GVZ407R4X
014D7@0F6B801PPD01DJ:00111<05ATT00lD6`0B5aX051XJ00`@400A4a80418B00h?4@0K71h07B4R
00/A4@0D6QX010P901TM7P0F6Q/03a<D00861`0E6AX04aLH00hD500C6AT061dO00lC5P0A5AP04aLJ
00X>4@0<41<06QhQ01TM7P093@h03Q8C00/?400D61T03Q8D010D5`803a<F00<03Q8E00`@4`0D61T0
0P0:3Pl02P0R9RL00PH7014E5P093@h041@E00`@4@0?4a@0310A00dA4P0I7Ah200X>3`0@01@H6@29
SHh09b//01<G600A5aL03a@F00hB5@0=4a<03a@F00hB5@0F71`0314B00hB5@000P804aHH00hB4`80
3a<D0P0=4A806`0>4Q<02Ph?00L;300830d04ADF01<G600>4Q<04QPH01<I6@052`/00PP8010F5P0D
6QP04QPF00X@3P0D6QP02@l=010F50052`T05adK00P>300J8200318B00dC4`0;4A403a@G00dB5@02
00XB500@00dE5`0@61X03aTJ00lI600>61L03QLF00dF5@0=5Q<03aPE00/A3`0A5a<05A/G00@:1P0A
5a<03A<?014H4@802Q4:00<03aH?00hE3P0@5a00100@5a005`0@5Q807B<Q00lE5@0:40h03A<B010F
5P0@5Q@03aDD00lE5@0>51803Q@C00dC4`0=4a4051XH00881P0L8R0051XH018H5P0=4a403aDC00L=
2`0220H03aDC00803Q@B00H02Ph=01LK6P0E6AP02Ph=00hB4@0;3`h201<G5P0<00P<2`072`X0=SXi
010D4`093@`04ADD00/?3P0A5A@020`;00hB4@0830/01`/:0P0@51<00`0;3`h03A8>00lD400200lD
40803A8>00L041DA00hC3`093PX02a0<00dB3P0F6aL02@h800803A<900<02Q0700dB2`0=4P/00P0?
50h0:P0@5@l041DA00lD3P0<4@`01`T400`>2@0B50l02@/601HH4`0@4Pd03a4<00h@2`0<3PT02`d8
00`>2@0?4@`03Q<<01HK500E6Q@01P/500T>200X;BT0JVm[028W8`093PX02`l>00050@0<40h06QlK
00<8100?51008RLS06icK`0@5A400PL301dR7P0320@02a0<00`A3@001@402`d800`>2@803@l:0P0<
3`P0200C5Pl04A<>00X<1`0:30L030h:00D70P0:30L03@l:0P0:30L0200>40/02`d800h@2`0<3PT0
3@l:010B3@0>40/02@`50`0?4PT300lB2`07010B3@0D5Q802`d:00P:1`0?40l000@0010F4P0200`B
3P1S00/A3@0>4`l02Pl;01lT800E5a@04A<@010B3`0?4@h03@l<00dA40052@P0310?01dQ800420L0
5ATH00dA400D61L02@d<00P<2`0F6QT02Ph=00hC4@052@P04QPH00H;300=4A803aDE00lD500<40l0
1P`:00P=300E6AP02Ph=00d@500830l0310C00X>4@093A003A4B00hB4`0=4A003A8?00hC3`0?5100
3Q8@018F5`072``041@E00lC50031`P02Ph?010D5@093@h03Q8C00041@0=4A804QHG00`@3`0830d0
4QHF07YnO@0P92D020`<04U=C01>DU<02@`<00lC4P0D61T02Pl<01LL600N8al04AHB00dB3P0;40`0
2@h:01TN6P0>4`l000D100dB3P0@5A80310A00hB4`0<41408BDV09jRX@0W:b/02Ph=00/?3P0>4Q40
3Q<?00dB3P0:3`/0314;014F400;40X03Q<=00T>200;40X01``600803Q<=01D02Pl901DJ50083@L0
318800/A1`0>50X03A<900T>1`0<4@X01@X400X?2P0>4`l02a0<00T=300C5aH04AHB00X?2@0>4`d0
3A8<00/@2P093PP0100:3`T02@0<4@/03A8<00/@2P0?50d0314;00dB300A5Q003Q<=00`A2`0200dB
300<00T>200=4P`0724K04=8A00@5A403a@@014F4P0<4@d010T500lD400=4Ph02a0<0`093PX01`0@
4Pd04Q@?00h@2`0@4Pd04Q@?00h@2`0?4@`00P0:30L200h@2`0500X?2@093PX02Pl;00/@300>4`l0
0`0?51001`0=4Ph0314=00`?300<3P/02Pl;00hC3`0<4@d00P0:3`/0100=4Ph03a@@00P=2@0=4Ph3
00lD4004018G4P0A4`h03Q0;014C3P803a4<00l0418=00X<1`082PD02`d800lA300>40/0418=00P:
1@092`H03a4<01LI500H6QD0418=00lA300=3`X00P0>40/07@0=3`X02@`800hC3`0A5Q8041DA00/@
300F6aL0<3Da00lD400S:2@02@h:01@I5@0=4Ph02Pl;014F4P0;40`041DA00H;1`0C61@05AXF00/@
300730P051TE02L/:00=4Ph03Q@@00XC3P0A61@06AlK008061hJ00P08RPT018H500630P03aDA014G
4`0;4@d03A8>00`A3@<02a0<00@03A8>00/@300<4@d03A8>0P0?51006@0A5Q802a0<00T>2P0>4`l0
6AhJ01DJ5`0830/03Q8A00dA4@0;3a00310A00lC500B5QT0724T02@Z:`0V;2`03aDE00hD4`0A5aD0
4aTG00H<2P0:40`04ALE05AJE`0=4`l05?ooool001_ooooo01P02@P@01HF70061@/05aHL00l>4`00
00@01PH800h>3`071`L02PX800X;1`0D5180000400`;4@0920h0000500/:400G5Q`051<I00d<4P08
1`d03PdC014@5P0?3Q@300h=4`0400h=4P0>3Q003Ph@00X:2P802PX804402``800/<1`0;2`T04@l@
00L71`0B51<0418D00L<3`0F6ah0>Sm300D83`082a805QDM00d:5@0:21<040lL00d=6@0?3aT04a<M
018B6P0?3aL03PlD00h?4`0?41@04A8E00l@4P0>3a403a4@00h@3`0?4A005ALF01<E500<3Pd03Q0?
014C4P0B51<03Q0?01LI600A51H02@d@01HJ7@0<41<051PK00`@4`0D61/04ADH00hB5@0@51L0310C
00T=400<3QL05QPU01/M:P0A4b001@LC00P:5P0=41P03a8I01HI7P0I72404aLJ018F6@0K7b404aLF
014E500200lC4P03010D4`0A5A@04ADD00804QHE0P0C5aH03P0?5A<05A/G01@J600E6a/06AlO01@J
6P0F71`05A/I01XP6`0E7A804AT<01DM4@0D6QP051TL100C61/00`0H7B005a`O01DJ7@0201<H6`0U
01@I700N8bL0<SLk01@I7@0J7b804ALH00hD500C6AL0318@01@J5P0K8Ad05A`F010F4P0T:BD06QlK
018G4`0<4@d061dI01DJ5P0D6AD041DA01LL600E6QH03A8>01@I5@0;3`h09b/Z02X^;@0>4Q403a<B
01/O7P093@`03a<B00X>3@0E6AP092PW00dA4002010D5@8041@G010041@H010C600@4aX030lH00hA
6P0C5B403a4M00/>5`0>4AD0310C00hB5@0?4aH0720S01HJ7@0@51L03A4D0P0@51L0:P0=4A@03a<F
00hB4`0<41403Q8C01<G6P0=41D05APM00d@5`0O8R/02@`E018D80000Ph07b<_03DiB@001Q@03aHP
01DJ7`0:41000080018G4`0B51404aDC00h@3`0C51H05QTJ00L;300E6AX04ADF01@H6@0=4A804ADF
00lC500<414010L800hB4`052@X05ATK010D5`0<41<04ADH018F6@8041@G00H07B4T00L;3P0E6A`0
2`lB00D9300>4Q@200`@4@0F00dA4P0<41402`l@01/O800T:2T0:2`]03/o@00D61T02@`=01<G600I
7Ah04QHG014E5P0<41402`l@00P<3@0A5AH0;C4b01`P8@0j?Sl04QHG010D5@803a<D0P0>4Q<0200?
4a@01PX;00hB4`0D61T082@U01XN7`0A5AH03Q8C0P0?4a@07@0=4A80310A00dA4P0<41402Ph?00`@
4@0A5AH04QHG00hB4`0<4Q002@l=00`B400>51802Q0>00T?3@0?5A<02Q0>01@J600;4@l04QPF00X@
3P073@d03Q@D00020P0@5QH0318B014G5`0<4Q803A<C00@03Q@D0P0@5Q@0400?5A<03Q@B00dC4@0<
4Q002Q0>00dC4@0;4@l04aTG00`B400=4a402a4=00`C300>5@h03A@=00XA2P083`P500hE3P0800hD
400B61H0318@00X@3P0;4@l0318@00dC4@0>518300dC4@80318@00L041HD014G5@052`T02a4?00L=
2`000P001@T700806AlM01P01`d;00H<2P0<4Q002`l>00T=30052@P03a<B02hb<@0a=C@01`/:00/?
3P0G6aX041@C02@X9`0R9RD020`;010D4`072`X0310?00H:2@0G6aX051PG00`@3`0=4A0200hB4@0=
00hC400<4@d0314=00`A3@0;40`02Pl;00`A3@0?51004QLC00hC3`0;40`04aPD00`A2P02010F300@
00dC2P0@5@h041D>00P=1`0A5Q004aPD00dB3P093PX01``800lA300C5A006Q`G018D3`0K7AP03a4<
00h@2`803@l:01L030h900d?2P0>40/04AH?01<H4@0@5@l020d700T>200G71P082DQ00P=2@0<40l0
61`K00lC4P093@`03Q<?00P=2@0=4Ph00@H2038g<`093PX05AXF00P=2@02014F4P0300T>2P0A5Q80
30h900@03Q0;00/03@l:00/=200<3PT02P`700T;1P0?4@`06Q`G00T;1P0?4@`030h900X<1`0200h@
2`0300X<1`0;3@P03@l:0080418=00<03Q4:00hA200>4@L00P0>4@P02@0>4@T03Q4:00`>2@000P00
418?01<E500=3`h04ADD00H>2@0200@=200600`B3P0=4`l03aDA018G4`0>40d030h;0P0>40d0;@0<
3P/03Q8A00P<2`0:3Pd04aLF00D9200B5QD020`;00lC4P0B5QD04aLF028V9@0Q9B@0720O018F5@0E
6AP03A4@00P<2`062PT0310?00lC4P0K7ah06AdL00`@3`0A5AH041<I00X=4P0<3a@02@`A00P<3`0<
41803Q8C00hB4@0=4Pl03A8>00hC3@0;3`d03a<D00hB4`0F6Q/04aLH00L;300>4Q<05a/L06mcM002
014E5P0R00T=3P093@d01`/:01hR8@0830/0:Bd/00D9200B5QD0>cln03i2@@0F6QT04aLF010D4`0<
4@h082DQ02db;P0D6AD01@X6014F4P0:3`/041DA00/@300730P0314=00dB3`0>4Q<02`lB00`@4`0C
5aP0HfMX01LK700830/02Ph=00dA40803Q<?00l0314=00T>200?50h0314;010E3`0<4@/03A8<01XO
6@0?50h01@X400P=1`0@5@l05AXD00hD2P0>50P00P0B60h03P0>50X03a@=01DJ500@5A003A8>00dA
400D61L092PW01lT800<4@/02Pl9010E3`0=4P`000@0100:3`T0100;40X0314;00/@2P0>4`d200`A
2`0A010E3`0=4P`02Pl900L<1P0:3`T02a0:00`A2`0B5a40:Rl[00D:1P0010001``800lD400I7QX0
41DA00lD400=4Ph00`0<4@d0400?4@`04A<>00d?2P0?4@`04A<>00d?2P0>40/030h900d?2P0?4@`0
3@l:00X<1`0:3`/02a0<00`A3@0=4Ph200hC3`03010E4@0>4`l03A8>00<0314=01403a@@018G4`0?
51002Pl;00lD400E6QH03A8>00hC3`0=4Ph0314=00dB3P0C5Q80418=00d?2P0?4@`030h900/=2002
010B3@0400d?2P0>40/03a4<00d?2P802`d80P0I6aH04`0:30L03Q0;010B3@0@4Pd03Q0;00lA300@
4Pd03a4<00/>2P0<4@d02Pl;00`A3@083@T02a0<01HK5`0D6AD06AhJ01PM6@000`000P0=4Ph03`0B
5a<0314=014F4P083@T0314=018G4`0[<2`07R<O01`Q7@1KH5`03a@@00lE4@0:40`02a4=00lE4@02
00dC3`04010F4P0?5A404QPD00lE4@802@l;0P0=4Ph300`A3@0300dB3P0<4@d03A8>00803Q<?00X0
3a@@010E4@0:3`T02a0:00lD400B5a<03a@A00T=300>4Q403a<C0P0?4a@03P0>4Q@03A4D00T>4P1Z
Kg<06b0S00021@0>4aD01@/;00/A4@0A5aH06b4O00471@0I7ad03A<A5?ooool001_ooooo00l04A0F
040oA@0K6R0030/@00X:3P0A4AD030`>00/;300820P0410>00/;2@0<30`030`>010?500510T00P0@
3a@0100?3Q<02`X?00`;400>3A8200/:3`0500h=4P0>3A<03PdC00h=4`0>3A800P0>3Q00100A4A80
4A4A010@3`0?3`h200l?3@0C014?40092@T03a4@018D5P0;41<05a`O05MLH00=41L01`T@00`;4`0;
21<04a4L018A6`0;2a@030`E014A6P0A4AT03@dE010A5P0200l@5@0^010A5P0>3a@030d@00h?4@0>
3a803PlA018C5@0B4aH04A8D00<41P0E5QT04a@G00l@4P0R8bH07R4T00dA500D61/0310C01<G6P09
3A00310C00lC5P0@51L03A4D01@H6`0G6ah061/R018E7`0:3AL0418M01HI8P0E62404A@L010C6P0A
51/071lV010C6@0F6Al06QhQ018F5`0A5AH041@F010D5@0A5AL04QHH018F5`804aLI040051PI01@I
6@0>5A@04Q/I010I600>5QP041PK01@L7P0G7b003QLE02H`:P2<UXh0KGM]01dW7@0H7Qd05a`O01@I
700B5aX04aPK01DJ7@0H7B005Q/N01<H6`0A5QT04QLJ01DJ7@0Q9RT0A4U;014F6@0L8B@04ALH00lE
5@0B61P041HE014G5@0C6AP04aTG01DK6P0A5AD04QHF01DI600@51@05a/J00hB4@0?4a<04QHF00hB
4@0=4A404aLG01DI6@0A5AH041@E018F5`0=4A<04QHH00`@4@0C5aT03Q8D01@H6@0D61X041@F01HJ
700A5AP04QDI0P0B5AX201<F6`0C01XM900L7bH05QTP00hA6@0D5al06ahV014D600H71l03a<F01DI
7019CE00@DE800dA500A5AP05ATL014E600?4aH04aLJ01@H6@02010D5@0^010D5`072Pl03a8G018E
700?4Q/03Q4J01<F7`0;3AT09BTd06aaO00F7BH02a8I00/@4P0F71/051XH01<H500B51404aDC010B
4@0?41804A@E00/?400A5AH03A4B01<G60093@h03Q8C018F5`0C5aP03Q8C01XN7`093@h05a/M00lC
5P0;3a803Q8E01PL7`0C5aX03A4D00lC5P0>4QD02Pd@01PL7`0b=ST04ADG00lC50@041@E0P0B5QL0
1P0;3a004QHG00X>3`0?4a@04ADF01PL7@804ADF00/03A4B00`@4@0A5AH041@E00lB4`0=4A802Ph?
014E5P0;3a00310A00hB4`0200lC500700hB4`0E6AX03Q8C014E5P0=4A8051PI010C500200hB4`04
00lC500B5QL051PI01@H6@803a<D01@041@E00lC500>4Q<03A4B00lE4`0@5Q@05Q`J010F50073@/0
41HD00T?3@0<4Q004QPF00dC4@0A5aD041HD00T?3`0R:2P0GVAT01DK6`8041HF01H02Q0@00`B4P0>
51@03Q@D00dC4`0;4A402@l=00X@3P0;4@l0318@00hD4P0?5A<03A<A01@J60093`d03Q@B00lE4`0@
5Q@04ALC00`B3P0I7a/05adI0P0:40`600`B3P0300X@3P0>51803Q@B0080318@00D03Q@B00dC4@0=
4a403A<A00`B400200/A3`0T01@J600g?C/06R0N00P>300A5aD0:c4_02dc<@083P`03Q@B00`B400C
6AL02Ph<00`@3`0=4A002`l>00T=300;3`h04ADD00H:2@0?4a8030l>01<G5P0Y:bX0Bdm>01HJ6@0O
8b804ADD00lC4P0830/05a/J018F5@0>4Q4041@C00lC4P0>4Q403Q8@0`0<4@d200/@300700dB3P08
3@T03Q<?00T>2P0?510041DA00/@2@0200hD2P0A00/A200>4``03Q<<014F400=4P`07b@P00X?2`0=
4Ph03a@@00lA300@4Pd06Q`G01TK5P0P8Qd03Q0;00`>2@0=3`X00P0?4@`02`0>40/03@l:018G400=
4P/02Pl900lD3P0@5@l02a0<00P=2@0G71P03Q8A00803a<B00H03A4@00/@300@5A403a@@00L:1`08
3@T200`A3@0600dB3P0<4@d02Pd:00hC3`0;40`03Q0;100?4@`03P0>40/03a4<00d?2P0A4`h03@l:
010B3@0[;BP04A<>01PJ5@0C5A002`d800h@2`0A4`h02`d80P0?4@`200d?2P0300lB2`0>4@P03Q47
00803Q4801@03Q4900hA2P072@@0CDm;01TK6@0?4A00418A00L;2P0<4Ph02a@?00PA300<4Ph020h:
00dC3`0:3`/03Q0=00lA3P0@4Pl03@l<00X<2@<03A4@01h02Ph=00`@3`0;3`h03Q8A00`@3`0@51<0
2@d<00lC4P0@51<08bLV014E50051`H041@C014E500>4Q4041@C01dQ800?4a8061`K00lC4P0O8b@0
5QXN010C600A5AT03A4D00/?4P0?4aD041@E00lC4P0=4@l200`A3@0500dB400<41403a<D00/?400<
41400P0>4Q<02`0H71d0E5QI00lC500:3Pl01@T:00lC4`062PT04aLF010D4`072`X041@C00803A4@
01T03a<B01DI600>4Q401PX900dB3`0A5Q8041DA00`A3@0A5Q80314=014F4P0730P0314=018G4`09
3PX0314>00`@4@0:3Q40310C00X>3`0A5AH03A4@00P<2`0:3Pd03A8>00<03Q<?00h01P/5010E3`0>
4`d04aPB014F400@5@l03Q<=00dB300F6aD0GfAN08:7P@0k@3X02a0:00X@1`803a@=00<02Pl800`A
2`0C61800P0;40X02@0;40/03A8=018G4P0<4@/02Pl900T>200=4P`051TC00dB300300`A2`802a0:
0P0:3`T02@0=4P`02Pl900/@2P0>4`d02a0:00hC3@0;40X03a@>014F4002010E3`0800dB3P0>4`l0
2a0<018G4`0;40`0314=00lD400>4`l300`A3@0900dB3P0>40/03a4<00d?2P0>40/03a4<00d?2P0>
40/03a4<0080418=00@030h900X<1`0=4Ph03A8>100<4@d00`0@5A403Q<?00dB3P0400dB3P0D018G
4`0?51002@h:00dB3P0C61@04AHB00lD400=4Ph02Pl;00/@300A5A003a4<00`>2@0@4Pd03Q0;00d?
2P0A4`h04Q@?014C3P0B50l201<E400:01XL5`0<3PT030h901<E40092`H03@l:018D3`0?4@`03Q0;
00lA30804Q@?02D041@?010E4@093PX03Q<?00lD400:3`/0314=04eBCP13B4@04QLC00lD400I7QX0
2@h:014F4P0?51004QLC00lD400>4`l05Q/G01@I5@0B5a<04AHB00`A3@0H7AT061hJ014G4`0=4`l0
3Q@@00/A3@0>510051XF00dC3`0:40`03Q@@00lE4@0C6AD041DA00803a@@00@03Q<?00lD400@5A40
3a@@1@0>4`l0600=4P`03a@>010E4@0<4@d0310>00hB4@0?4a8041@D014E5P0@51D03Q8D00/?4P0E
6Qh05ATM01@I701MHVD0=C/l018H600?5AD03aDD00lE4`0B61H061hL00/A3aCooooo000Kooooo`0H
00L6300C4QP03PdB00401@0A4A@05aLI010@4P0=3@h02`/;01<C4`0>3Ph05QHF030`<P071P/04Q4F
00D42@0=31404a8G00T83@0510T02`X?00d<4@0<2a0040lD0`0=318200d<4@0500d=3`0?3a403`lA
00h>3P0=3@d00P0<30`0=00D4QD03@d?00/<3P0@4a@01P/>00/@4`0A5QX04QDJ014D6@0B4AT04PlH
014@600@41H051DJ018C600<3A802@X?00X;400?41D03@dE00h>5P0A4AT0410H00d>4`0E5QX06a`Q
014B5`0<3A40414F010A5@0M7R80GUmT03hoA00720`020T>01HH7@072Pl030lD00lB5`0L7b@04A@I
00hA5P0B5AX051LL00hA5P0D5a`05APM00X=4`082a804QDL01TL8`0?4QT200d@5`0O01HI800;3QL0
4aHO00/>5`0E624041<I014E600A5AT04QDJ018F6@0B5QX041<H010D5`0A5AT04QDJ018F6@0B5QX0
3aLI018L7@0B71h03QPJ00`E6P0B6b0051dR00`F601GHF40n?oo0<;=a`0Y<bd05AXM01HK7`0201LL
800501DJ7P0D6Ad04AHJ014F6P0B5a/00P0A5QX02`0@5AT00`T902L]:`0;4A405adM00dC4`0A5aL0
41DH01DJ7@0E6a/04aPK008051TL01T07b<V00dA4`0<41404QHI01hR900>4Q<03A4D01LK7@0?4a@0
3A4D01@H6P0>4QD0310C010D600C5aX01PT>00d@500G6ah05QTN018E6@0>4QD03a8G010C5`0@4aP0
5APM00<05APO04/05APN01DH7@0S9R/082<X01PK800>4AH04aHK01/N8`0@4aP04aHK00@730051P/0
:bhc01DH7@0?4QL051LL01PK800C5Q/04A@I01HJ7@0:3Q402`lB00hB5@0D5a`04QDJ01hQ9P0?4QT0
2`hE01TL8`0B5Ah01`XC00/?600F72802A4D01LO8@0>51<0318@00P>2P0?51004aDD00l@4@0>3a40
4Q<G00lB50093@h04aLH010D5@0?4a@09BTZ05QLG@0>4Q<02@d>00dA4P0<41403A4B00P<3P0=4A@0
4aLJ010D5`0?4aH04ADH010D5`031`X02PhA00`?4P0?4aH092P[00L:300?4a@03Q8C00/?400830d0
2Ph?00/?400?4a@00P0D61T0;@0A5AH04QHG00T=3P0@51D0310A010D5@0=4A803a<D00X>3`0A5AH0
4aLH00X>3`0A5AH03Q8C00/?400<41403a<D014E5P0@51D03a<D00hB4`093@h05QXK00451P000P<0
92PY00lC500=4A803Q8C018F5`0D61T04aLH00lC500@51D03a<D00`@4@0;3a003A4B00hD4P0?5A<0
1P`:00dC4@0J81h03A<A00P>300200dC4@0;00lE4`0<4Q003A<A010F5P0N92@0Q8Z:00`B4P0=4a<0
20h>00hD500<4Q800P0:41002`0<4Q803A<C00X@3P0;4@l0318@00dC4@0>51803aDC00P>300;4@l0
3Q@B00803aDC00<0<3Hd018H50052`L00P0A5a<00`052`L020h:00`B3P0500`B3P0700hD4P0@5Q@0
3Q@B00/A3`0=4a4041HD00lE4`0200hD4P<03A<A01003Q@B00L=2`0=4a4041HD028X9P0O9B<03aDC
00D;2@0F71X0318@01TO7@0A5aD0310?00/?3P0<40l03Q8A0P0@51<03`0J7Qd01`/:00hB4@0I7A`0
2`l>01HJ6@0@51<07b<R01<G5P0=4A0010P700/?3P072`X020`;00hB4@0200`@3`0300dA3`0<4@d0
314=00<0314=00L01``800@91@0M8Qh02@h:00@91@000P001P/40080318800/02@l600`A2P0<4@X0
4AH?01lT7P2`]K40DUMC01dR7P0@5A403Q0;00X<1`02014C3P0401TK5P0<3PT02`d800`>2@803a4<
01/03Q0;00`>2@0=4P/02a0900X?2@0>4`d04AH@00lD40011P803a@@00/?3P0D61L03A4@00P<2`0:
3`/0314=00P=2@0D6AD0314=00hC3`0320@0CU=?01HK5`0B5a<01P/701/P700>40/00P0?4@`05@0>
40/03@l:00/=200C5A002@/600lA300=3`X01`T401LI500?4@`05aTD010B3@092`H030h9018D3`0>
40/04Q@?010B3@0<3PT02`d800lB2`0300d@1`<03A0902H00`D004a>BP2ATi008B<P00d?300@5A40
1Ph900PA300740/01P`800/A3@052`L0314=01<E4P0F61D05ALD010B3`0>40d02Ph=00`@3`0?4a80
2@d<00/?3P0420L03A4@010D4`0;3`h03Q8A01/O7P0?4a805ATH00X>3@0830/04ADD01<G5P0@51<0
51PG02hb<@803a<B00/020`;01TM7P0C5QX03Q8E018F6@0@51L03a<D018F5`0@51D03a<B00`@3`02
00X>3@0C00lC4`093@h02`l@00L;30052@X03Q8C00/?400A5AH00042010D5@052@X04ADF00/?3`0>
4Q40310?014E500830/061`K01<G5P0300lC4P0D00dA400<40l01``900dB3P0A5Q802a0<00X?2`0C
61@05AXF00H;1`0?51003Q<?00L<200=4@l02@d>00hB4`0<41404ADF00@82@0?4a8300dB3P0G00`A
2`0;40X02a0:00T>200E6Q@04AH@018G4@0A5Q00314;01`Q6`0>4`d04AH@09JKU@3Sj>80PHJ0010E
3`0=4P`03A8=00/@2P093PP03a@>00hC3@0<4@X00P0@5@h02@093PP01P/500T>200B5a403A8<010E
3`0E6Q@020d700hC3@0300lD3P0400dB300;40X02@h800`A2`802@h800h0314;00T>200;40X0314;
00dB30093PP020d7018G4@093PX020d900870`062`L02Pl;014F4P80314=00H02a0<00`A3@0=4Ph0
3A8>00d?2P0<3PT200d?2P0400`>2@0=3`X04A<>00h@2`8030h900@03Q0;010B3@0>4`l03A8>0P0<
4@d200X?2`0400dB3P0;40`02Pl;00X?2`<02a0<0P093PX0100;40`02Pl;00X?2`0<4@d200lD400H
00dB3P0<4@d06QdI024S7P0L7QT06Q`G010B3@0;3@P03@l:00lA300@4Pd04A<>01<E400E5a80<S@_
024S7P082PD03@l:00`>2@0>40/03a4<00d?2P0<3PT03Q0;0P0@4Pd06`0@50l05AXF00hC3`0;40`0
314=00X?2`0A5Q808RLS01dR7P0<4@d04QLC00050@0B5a<03a@@010E4@093PX03a@@014F4P083@T0
6b0L00/@30093PX07R<O00X?2`0@5Q802Q0<00P>2P0200`B3P07010F4P0c>CD08RPT00hD400=4`l0
3aDA018H5002010E4@<03a@@00<041DA00lD400>4`l0100>4`l0200?50h03A8<00`A3@0>4`l03a@A
00hB4@0?4a803a<C0P0>4Q<03P0@51H04QHI00/@500G72002PlB03Ll?`0Z;S004QPH00hD500H7Qd0
2@l=014G5@0D6QP05Q`J5?ooool001_ooooo00D02`X@00P7300H5a`03@`@010@4`0200/;3@0A014A
4`0>3Pl02`/<00/;300/;2h0EeMI00/:3P0A4A@04A0D01<C5P0<30l0B4M;01XI7@071PX03`lB00d<
400<2`l00`0<2a4300`;408040lC0P0@4182010@4@04010>4P0@41<02@X=01@G6@<020d@00`01`X?
00H93P0>3A@040dE00X93`0A4Q@05aPK01DF6@0>3a8030dA00h?4`0@4AH200d=5@80410I02X03PhG
01HG7@0J6R404Q8I00d=500@4AL04Q<I00d=500/;3<051@K01HG7@092Q004Q@J00/>4`0D5a`04A@I
01<F6`0:3A804QDJ00`?500:3A802`hC00lB5`0@4aP08BDY01dQ8`0=41@041<G014D6P0@4aT03Q4G
01TL8`0A51d0>Se701lQ;00K7BP04aHN01LJ800F6Al051LM018E6`0@4aT2014D6P<04QDK01<04aLL
00TB500@6Q`04QdQ00lI7`0O:C40GVM_02hh@00L9Rd08B`_04iHF@0nBDL05B0O018J7@0E6Qh061dQ
01TN8P0H7B405a`P00804AHJ0`0B5a/07@0B5aX0728Q014G500C6AH04QPG00dC4`0A5aL03A8E018G
6`0A5QX04AHK018G700=4QL02`hD030d>@0j?T8071lU014D6@0C5a/05APN01/O900I7B405aXP01LJ
7`0B5A/06ahT00d@5P0@4aT03A0F00804A@J02405aXP01@G7@0>4AL03Q4G00lB600:3A@03a8J010C
6`0A51`04QDL01@G7@0E61d07B4T00`@4`0<41805QXK014E5`093@l0310D018E6P0D5a`04aHK01`O
900931403a8G00hA5P0A51T041<H00d@5@0@4aP051PL014E6@0?4QH00P0@4aP06P0N8BH03A0F01lR
:@0M82L03A0H01XM9@0D6Ah02a8C00D>300B6aT03A8?018H500>510041@B01DG5`0@4A<04A8D018C
5`0C5QP02Ph?00/?400>4Q<051PI05IJF`2a]KH0:Rh_0P0=4A803`0A5AH051PI018F600C5aX041@G
01<G6P0<41<03A4D00lC5P0K7b804ADH03Hj?@0K7b802PhA01XN800201@H6@0700lC500<41403a<D
020T9@0=4A804ADF00lC5002010D5@0400hB4`0E6AX041@E018F5`@03Q8C00<02`h?018F5`0;3a00
1`0>4Q<02@0<41403Q8C00lC500>4Q<04aLH04I:B`0B5QL03a<D00`@4@0200lC500500X>3`0@51D0
3Q8C00`@4@0>4Q<00P0@51D0500D6QT02a4@00P>3@0Q9bH0;cDd00P>3@0;4A003A<B00X@3`0F71/0
41HE00lE50083Ph041HF00X@400A5QH03A<C00hD500@5QH03Q@D0P0<4Q80200=4a<03Q@D014G5@0@
5Q@03Q@B00`B400;4@l02Q0>0`0@5Q@01@0>51801@/901lU8`0B61D02a4>00803A<@00<02a4>00dC
400=4a001@0=4a001P0?5A<0318@00X@3P0;4@l0318@00dC4@803aDC0P0>518200dC4@0=00hD4P0=
4a4020h<00`B400O9B<03aDC00`B400=4a404QPF00X?3@0<4Q002Q0>00dA400200hB4@0500`@3`0;
3`h02Ph=00T=300F6QT00P0@51<040072`X02@d<00D9200D61L03Q8A010D4`0830/04ADD00dA400;
3`h0310?00X>3@0<40l03Q8@00X?2`0;40`300`A3@0700/@300E6QH0@TM3020U8@0>4`l01PT600lD
3P0200hD2P0?00/A200>4``03Q<<00hC30042@<0F5eI024V8P083@T03A8>01DG4P0>40/04aD@00d?
2P0B50l02`d800H03@l:01D02Pl800`A2P0>4`d02a0:00X?2@0<4@d03A8>00X?2`0;3`h03Q8A00dA
400;3`h0314=01@I5@0=4Ph010P4014F4P0@5A407b@P08B9Q@0k@3`00P0;40`02`0:3@X03a4<010B
3@0@4Pd03a4<00d?2P0<3PT051HA00h@2`0@4Pd04aD@00804A<>00H02P`7010B3@0:30L020X500lA
300C5A0200lA30803Q0;00<0418=014C3P0>4@X00P0>4@T04P0>4@X03Q4;00hA2`0D5Q4030h903Xl
>00K7AT030h:00D:1@0<4`l02A8=00lH4`0;4@d0>3hj01`R7P0:3`/04A<@01<E4P804Q@A00<04aDB
00`@3`0830/00P0;3`h07@0A5A@0;30_00hB4@0@51<0310?018F5@0O8b804QHE00lC4P0E6AP0FEeL
02<W9P041`H04ADD00`@3`0?4a803Q8A018F5@0Q9B@0@4A500d@50093A003Q8E00hB500>4Q<04ADF
010D5@0>4Q80310@00802Ph>00l0310A00/?400H71d0;30a01HJ6`093@h0310A00X>3`0E6AX03Q8C
014E5P0?4a@0310@00hB4@0=4A000P0<40l06@0>4Q402`l>00X>3@0?4a802`l>01PL6`0R9RD04aLE
00`A3@093PX0314=010E4@0<4@d03a@@00H;1`0@5A402Pl;01lT800<4@d0310A014E5P0?4a@03a<C
01<G5P0;3`d00P0?51002P0>4`h02a0:00/@2P0:3`T0314;01TN600A5Q003Q<=00lD3P0:3`T200/@
2P0<00lD3P0L8A/092TS01/P6`0<4@h02`l=00`A3P0<4@d02@h900dB300@5@l0314:0P0<4@T02P0@
5@`06b0H00hC300C61802@h801@I4`0P9Al02@h800`A2`0>4`d2010E3`0400hC3@0<4@/02a0:00hC
3@802Pl900h0314;00T>200?50h041D?014F400<4@/02Pl901<H4P0<4@d041DA02L/:00C61@0314=
00T>2P<03Q<?00/041DA014F4P0B5a<03Q0;00`>2@0?4@`03Q0;00`>2@0?4@`0418=00lA300200`>
2@04014C3P0E5a803A8>00dB3P<0314=00@02a0<00`A3@0:3`/02Pl;0P0;40`01P0<4@d03Q<?00/@
300<4@d041DA00hC3`802a0<0P0?51000`0>4`l03A8>010C3`0200d?2P04014C3P0?4@`030h900h@
2`804A<>00d0418=00lA300@4Pd06A`G00hA300;3PT03A0;00T<1`0?4Pd041@>00dA2`0<3`X03A0;
00803Q8<00<04AHA01hS7`0H7AT00P0?51001`0<4@d03A8>01XO6`0?4Pl041DA01TN6P0?51000P0>
4`l05`0B5a<03Q<?01XO6`0>4`l03a@@00T=2@0D6AD0>3di00X?2`0=4Ph03A<?00X@300>51004aTE
014G4`0B61@0318>00dC3`0@5Q802Q0<00D;1`0@5Q8041DA00803a@@00@03Q<?00lD400@5A403A8>
0`0>4`l200lD400H00`A2`0>4`d041DA014F4P0?5140310?010D4`0?4a<03Q8C00lC500A5AL04aLJ
00lD600>4aL05a`O03@i?00=4Q@082HV01LM7@0=4a8041HD018H5P0;4@l061hL5?ooool001_ooooo
01P03`hC00h=4P081``02@T;00P82P0000803@d?00H6200=3@l05aLI00P82P092@/03Ph@00/;3@0@
41807QhP00`<3P0A4A<051@F00`<3P0C4aD03@d?00P82P0@418600`;400400/:3`0<2a0030/@00h=
4@803PdB00d020H;00l>4`0:2`l06ahQ010E600>4aH01P/>00H93P0@4aP03@`B00X73P0D4aP03a0@
008030h=00T03PlA00l@500@4AD051DJ00l?5`0=3AD03PhH00d=6@0=3AH00P0>3QH04@0=3AD04Q8J
010@600=3AD071`T03Ph@00?3aL06ATQ00H63P0C5A/020/@01@G70082a003A0E01hQ9P0g>Sl07B0U
00803a8G010030lD00d@5@0C5QT02`l@00`@4@0F6Q`04ADH010C600G6R0051LN00L:4`1?DU`06Q`X
014C800D5R405APO0P0G6R40100F6B0051LN018E700B5A`201<F7@0n01@G7P0D61h03aTK01HQ8`0@
6b0051hW04mIHP3Wl?D0J79l024[=@0E82L082/_01HQ8`0@6Q`051`O01DJ7P0D6Ad05Q/O01PM8@0L
8BD05a`P01DJ7P0B5a/04AHJ01<H700G71l0Ade;00T?2`0G7AT03A<A014G5P0B5aX041DI018G700=
4QP03Q<I01<H7`0<41T08RD^028U;00M82L041<J018E700;3QD051LN01DH7`0F6B005APO018E700E
61l061/R01HI800I72<02PdD00/>5@0G6R404A@K00hA600F6B0051LN00d@5`0H6b8201<F7`0D014D
7@0A51/041<I00lB5`0@51H04aLH018F5@0?4a8041@C01<G600D5a/03A0E018E6P0A51T05APM01LJ
7`0A51T02PdB00d@5@0?4QL200`?500o010C600>4AH03A0E018E6P0I7240:Rdb02HY;P0:3A@03A0G
01<F7@0N8BP02PlC00hF4P0Z<bh0=d0k01HL600=4`l02a4?00`@3`0@4A<051DG01`M7`0F5a/01PT;
01DI6P0I7Ah03a<D018F5`072``0:2`]00/?400<41404QHG01<G60093@h0:Rh`01`P8`0420/04aLJ
018F6@0;3a805a/N028V:@0N8RD0310C00862@0M8B@04QHH01<G600D61T041@E00hB4`0C5aP0=CTj
00dA4P093@h0310A01DI6P0?4a@0310A01<G600?4a@04ADF00803Q8C00D02`l@034e=P0?4a@05ATJ
00<7200200lC500I00hB4`0<41402Ph?00X>3`0<41403A4B01LK70093@h05a/L01PL7@0<3a0041@E
00dA4P0<41404aLH01HJ6`0B5QL04ADF00`@4@0:3Pl04QHG01HJ6`0D61T041HF00dC4`0200`B4P0F
00lE5@0A5aL0318B00dC4`083Ph07R@T01HL700C6AT04QPH00P>3P0H7Qh00`T900L=3@0A5aL03A<C
00lE5@0A5aL041HF00dC4`0;4A402Q0>00/A3`80318@0P0>518020032@L03A<A00L=2`0>51803A<A
00T?3@0:40h03Q@B0P093`d00`0<4Q002Q0>00`B400500`B400600dC4@0:40h0318@010F500>5180
2a4?0P0=4a4200`B40802a4?00`03A8@00X@3P0=4a4051XH0006100C6AL03aDC010F500:40h03Q@B
00D;2@032@L2010D4`0F00dA400;3`h04ADD01<G5P0A5A@0FUiM00`?3P0@51<01PX9010D4`0830/0
3a<B00P<2`0=4A001PX900/?3P0:3Pd03a<B01DI600>4Q402Ph=00`A3P803A8>0`0?51001`0B5a<0
00D101TN6P0730P06b0L00T>2P0<4@/00P0;4@L05`083PD02a0900/@2@083@L04aPB00/>2`0A5Q80
3A8>00/@300=3`X02P`701@F4@0>40/0418=00d?2P0?4@`03Q0;00`>2@0;3@P030h900lA300730D0
2a09008041D?01003Q<=00dB3P083@T01``8018F5@062PT03a<B00X=300;40`04QLC00lD40011P80
9R/W00T>2P0?51001``80P093PX04P0D6AD01``8018D3`0B50l04A<>010B3@0?4@`03@l:00h@2`0?
4@`020X500T;1P0?4@`030h901LI500F61<03Q0;00d?2P804A<>00<05QPC010B3@0=3`X00P0>40/0
0`0;3@P03a8;00lB2`0200lB2`0A00lB300?4@`01@L201LI500:30L03@l:00l@3@0H7AL08RXU014J
5@0C71L01@/7051FDP0Q9b<04AHB01@F4`0A4a000P0=3``0300@4Pl03A4@00H:2@0830/04ADD02X^
;@1^LW4041@C00T=300?4a802`l>00hB4@80310?00h04ADD06EYJ00H71/03Q8A024U900>4Q403A4@
00X>3@0?4a8061`K00`@3`0?4aD02`lB010D5P803a<D00@04ADF00hB4`0=4A80310A0P0;3a00:P0>
4Q<01PX;00D92P0Q8b@01`/<00010P0D61T04ADF00H:2`0@51D0310A010D5@0?4a<0008101DI600>
4Q402Ph=018F5@0I7A`01@T800/?3P0830/04QHE01/O7P072`T02@h:00lD400>4`l02@h:014F4P0<
4@d020d9018G4`0C61@0@DI2014F4P0<40l0310A018F5P0830/061`K00dB3P80314=0P0;40X0>00<
4@/03A8<00`A2`0I7QP03Q<=00/@2P0?50h02a0:00L<1P0=4P`02a0:00P=1`0F6aD03Q<>00`@3`0=
4A805ATH01HK5`0?51003Q<=00hC300>4`/03Q@:00/A1@0>50P06b4G00L<1@0S:2802a0:0003000<
4@/04AH@00L<1P0:3`T03A8<00hC3@0<4@/02Pl900`A2`0?50h02a0:00X?2@0=4P`02@h800hC3@0;
40X041D?014F400:3`T01``6010E4@0A5Q80>Chj00dB3P093PX041DA0P0;40`0400<4@d03Q<?010E
4@0A5Q803Q0;00`>2@0@4Pd03Q0;00`>2@0@4Pd030h9010B3@0?4@`03Q0;014C3P0D5Q4700`A3@80
2a0<00@0314=00dB3P0=4Ph03A8>0P0@5A4200dB3P0;00lD400>4`l03Q<?00`A3@0;40`03A8>018E
4@0?4@`03Q0;018D3`0>40/00P0;3@P03P0=3`X03a4<00lA300@4Pd04aD@01HJ500<4@/03A8<00lD
3P0A5Q003a@>00/@2P0?50h03A8<0P0>4`d09P0=4P`02a0;01<H500?51003Q<?01<H500<4@d041DA
00L<200;40`03a@@018G4`0730P061dI00dB3P0G71P08BHR03@i=@0F6aL02a0<01LL600C61@08bPT
00lD400E6QH041HB00hD400D6QH061hJ01<I5@0=4`l051XF00dC3`0<4Ph04QPD014G4`0?5A403a@@
0P0>4`l01P0=4Ph03Q<?00lD400;40`0314=00dB3P803a@@01804AHB00hC3@0G71H07b@P01PM6@0@
5A804ADD010D4`0B5QH04aLH018F5`0?4aD0310C00462P0E6Qd04QLJ00dB5@093Q0200P>3P0501@J
6@0:40h00`T701<I5`0630X05?ooool001_ooooo01/020P:00/;3@0>3Q003Ph@00/;3@0820X02PX<
00h>400A4A<010<8018A5P0<2a002PX<00d=3`0E5AL06QXL01HF600<30h02PX<00l?4@0<30h03Ph@
00l?4@0;2`d02PT>00`;400=31400`0?3Q<03@0:2@l04Q4G00d<4P081`d051<I00h=4`0=2Q402PT?
01HG700>41D041DH00462@0;41<00P0?4aH05`0@3a@040hC010@4P0>3`d04aDB00<50P0B51<02``>
01HG6`0I6Ql0410H00d=5@0<31@030`F00`<5@0=3AD03PhF010@600B4QX04a<K014A6@0?3aL0410H
00804Q8J00l04a<K010A6@0E61l01@P?01<F7@0G6R404QDL06EXK`0S9Rd02PdD00lB6@0:3A@02`hE
018F6@0>4Q400P0>4Q<01P0?4a@041@G010C6@0?4QT03a8K00lB70803a4M00H03a4L01<F7@0A51/0
41<J01DH7`0D5ah2018E70804A@K02/04QDL01@H7`084Q@02aHH01<N8`0M9c00@4YC09^U/00^>4@0
6B<]014K9@0@6R<04QdS014K8@0E72805a`R01PM8`0D6Al09R/a04A9C`0K82H05Q/Q01DJ800_=3X0
3a@J014F6`0M8b<01P`:01@J60032@T061hO00/@4`0Q9RX02PlD02X_=@0<41T051PR01dQ:P0P8b`0
>ci7014D7@1cMWl06ahW00<04QDN00`041<L00lB6`0C5Ql05aXS00/>5@0G6R404aHM00`?5P0@4aX0
4A@K010C6P0A51/2018E708051LN01<06A`U010C700B5A`03a8I00`?5@0K7R<04ADG014E5P0A5A@0
4AHC014F4P0A5A@041<I01HI800I72<051LN01<F7@0J7B@041<J00803Q4H0P0A51/06@0@4aX04A<J
00`?5P0C5Qd04QDL00X=4P0<3a@071lT01<F6`031P/0A4M<00d@5@0N8bH04QXF0419A012BdH04aTG
018H5P0G7Ad04ADF00/<400C51P04Q<G00l@4P0A4aD00P0A5AH04P0?4a@03Q8C014E5P0B5QL01@T:
01@H6@21QHH06AdN020T9@0>4Q@04aLJ01@H6`0B5QT041@G014E600L82<07R8U01DI70803a<F00`0
41@G00dA4`0=4A8051PI00X>3`0<41404aLH00hB4`0H71d0<CDf024U9P062P/200hB4`0A00/?400>
4Q<02Ph?00@82@0:3Pl02`l@018F5`0=4A801PX;00dA4P0@51D03A4B018F5`0?4a@02@d>00`@4@0:
3Pl00P0<414200dA4P803Q8C0`0=4A80600<41402`l@00/?400@51D04ADF01@H6@0=4A8061`M00X>
3`0630`03A<C00hD500C6AT02@h>01DK6`0630`041HF00T?3`0630`020`<01HL700B61P0318B00X@
4080318B00L020h>00lE5@0<4Q801`d=00P>3P093@d05Q`L00804aTG00H041HD00T?3@0D6QP04QPF
00hD4P0<4Q0200X@3P0300`B400>518041HD00803aDC00l02@l=00lE4`073@/03Q@B00lE4`0=4a40
2a4?00X@3P0;4@l03aDC01<I5`0B61H02a4?00X@3P0=4a400`0>51801P0=4a402a4?00X@3P093`d0
3A<A010F5080318@02D04aTG00hD4P0=4a4041HD00dC4@0B61H02Q0>00lC4P000@002Ph=01<G5P07
2`X02Ph=00L;2P0@51<04ADD00@81`093@`03Q8A00lC4P0:3Pd041@C01DI600=4A002`l>00hB4@0@
51<03Q8A00X>3@0<40l04ADC00P=2@0A5Q805AXF00`A3@001@402Pl;0080314=00@03A8>00/@3009
3PX020d70P093`D02P0:40L02a0900/@2@093PP04QLA01LL600A5Q801P/700X?2`0?4@`2010B3@03
00h@2`0=3`X030h900802`d80P0=3`X200`>2@0J00/@2@0D6A805Q/E00T>200730H0314=00T>2P0:
3`/020`;018F5@000`80@4A300/@300=4Ph02a0<01DJ5P0320@020d900H;1`0A5Q802@h:01TN6P0C
61@02@h:018D3`0A4`h200lA3080418=02P03Q0;00lA300=3`X02P`700/=200@4Pd02P`700d?300E
5a80418=01HH5@0_<B`0;S0[010B3@0>40/04A<>00T;1P0@4Pd01`T401TK5P0620<06Q`G00X<1`0>
40/04Q@?014C3@0<3`P02@`500/>1`0=4P`0:C0/08bET0084@`03A<?0002000C6AD03Q<?00lA3P0>
40d030h;0P0:30T02`0=4A001PX900P<2`0?4a801PX900`@3`0>4Q403A4@00`@3`0;3`h03A4@0080
3a<B00D03A4@00hB4@0E6AP06alN01dQ800600hB4@0<010D5@0=4A802@d>00P<3@0>4Q<02`l@00hB
4`0;3a0041@F00`@4`062Pd041@F0P0=4A80600C5aP02`l@00X>3`0;3a002Ph?00P<3@0?4a@03Q8C
00T=3P0=4A401`/:00/?3P0D61L03a<B00hB4@0@51<03A4@00`@3`0;3`h03A4@00hB4@0>4Q002Pl;
00/@30803a@@03T02@h:00P=2@0@5A403Q<?00P=2@0<4@d020d901<G5P072`X02`l>00L;2P0730P0
5Q/G00hC3@0;40X03A8<00lD3@0<4@X03Q<<00/@2P1AEU00>3dg0004000<4@/03A8<00lD3P0=4P`0
5Q/E00X?2@052P@03Q<>00/?3P0?4a@0CE5@07YoN`0730P03A8<01XO60052`804AL=01<I3@0=4`L0
10X000`A2P0?50h01``6018G4@0A5Q001``600X?2@083@L041D?00H;1@0D6A<0314;010E3`0<4@/0
0P0730H00`0;40X03Q<=00dB300200dB300800`A2`0;40X02Pl900lD400@5A403Q<?00X?2`083@T2
00T>2P0300hC3`0?5100314=00802Pl;00H03Q0;00@60@0R91l02``901<E400<3PT2010B3@0N00/=
200<3PT0418=010B3@0D6AD0008001/P70093PX09BXV00@91@0<4@d04aPD01/P700>4`l041DA028W
8`0=4Ph02Pl;00T>2P0:3`/02a0<00dB3P0:3`/02a0<00`A3@0;40`020d901LJ5P0E5a804Q@?0P0>
40/2010B3@0N018D3`0D5Q403@l:00L9100:30L03Q8<00hE3P0;4P/04QTB014H4@001`005A`E00P?
200:4@X03QD>00L>1`0=50d0318<01HK5`062`L041DA01hS7`083@T02@h:014F4P0>4`l07B8N05YO
F`0C61@03Q<?0P0@5A400`0C61@04QLC00dB3P0201<H500D010E4@0L8Ad05AXF00P=2@0i?c/0:Bl[
00P>2P0M8al03Q@@00lE4@0=4`l051XF014G4`073@T020h:00X@300=4Ph041DA00hC3`0=4Ph2014F
4P0N00/@300<4@d03Q<?00lD400>4`l03A8>01TN600:3`T041DA00D:1P0D61H02@d<00X>3@0H71`0
1PX;01LK700=4A<05ATL00@93@0@5AP03a@G00dB5@0E6a`02a4A00L=3@0A5aH02Q0>02dc<@0S:BL0
1@/95?ooool001_ooooo00d03Ph?00d=3P0<30d030`=00d=3P0>3Q0030`>02PW:P1KFUh06QTN00d<
4@0<2a002`/=00803Ph?00/02`/<00X:2`0<30d03Ph?010@4@0;2``03@d>00h>3`0;2`d030/@00d<
4@0300h=4P0I00d<4P0<2a402@P?00l>5@0@3aH03PdD00/:4@0B3aL010<:01LG7P0=3a@0DeQL01XO
8P0;41<0310B00/?4@0<30l040hB018B500>3`h03a4?01dO7@1MGUl0LgAf01TJ700200h?4`0500d>
4P0=3A@03`lF014B600A4AP00P0@4AL400l@5P0;010A5`0A4QP04Q<I01<C6P0C51/03A0G00lB6@0=
41L07B0W00/>5@0@4aX00P0<3aH01P0E61l03A0G00/>5@0>4QD03a<C010D5@804ADG00@04ADH014D
600A51X04A@J0P0A51`0>P0A4ah041<K018E6`0A51X03a8H018E6`0A51X04aHL014D6P0?4QP04A@J
01<F700B5Q/04a`N018L7P0C7B803aPQ00lI8P0Q:SL07RLd010I9@0?62<031HO00dG800@6B404APN
01`Q9`0H7B<0;34g07f2R03Oi>L0LWMm02`a=`0N8bT0B4eC01lT:P0I7R<051XK00dC4P0E6Q`04AHH
00lD5`0?51P020dA020U:P1RIfd06QlV00hC6P0N8RX04aHN010C6`0?4QX07R4Y01<F7P0A51`04QDM
01@G7`0B5Ad2014D708051LN00D051LM01DH7P0B5A/03Q4G018E6`02014D6P@041<I03D02`hD01dP
9P0H720041<I014D600A5AP04ADF014E5@0A5A@04AHD014F4`0A5AD04A@J00lB6@0A51/041<J00lB
6@0C5Qd03Q4H018E700C5Qd041<J00hA600=41L08bH^018E7@0C5Qh04A@K018E6`0C5Q`051LL01dP
9@0E61d0HVIZ00lC5`083A004a/I030i=`0S;2X03a@F00`A500>4aH041@H00`=4P0C51P04a@F018C
5@0A51D03a<D00hB4`0?4a@041@E00lC5002010D5@0K00P<3@0a=CH02@d>010D5@0>4Q@03a<F010D
5`0>4QD0310C00dA500@51L03a<F00dA500?4aH04ADH010D5`0A5AL01PX;00P<3@0?4a@02`l@014E
5P0@51D0310A01PL7@0C5aP02Ph?00803a<D00L02Ph?00lC500J7Ql061`M010D5@0;3a00310A0080
3a<D00P03Q8C00`@4@0A5AH03a<D00dA4P0C5aP06AdN00lC5080310A0P0=4A8200hB4`803a<D01P0
3Q8C00dA4P0=4A803A4B014E5P0:3Pl0310A01PL7@0Y;Bh051PI010F5`083Pl03Q<E00/@4P0B5aT0
2@l@01@I6`0?4aD03aDF00X@4@0L8B<01@/<00lE5@0>51@400`B4P0>01<I6@0;4A405A/K00H:2P0A
5QH04aLG00lE4`0:40h04aTG00lE4`0>51802@l=010F500>518200`B400600hD4P0@5Q@03Q@C00/A
400B61L02@l>0P0?5A@01`0<4Q403Q@C00H<2`0>51<041HE00/A400<4Q000P0=4a400`0<4Q003A<A
00lE4`0200hD4P803aDC01D03Q@B00dC4@0>51802a4?00`B400=4a404ALE01PN702:T8h07R@R01DK
6@0A5Q@04ALE00L<2P0=40l02`l>010D4`0<40l06AdL00dA400:3Pd00P0;3`h02@0<40l03a<B00dA
400=4A002@d<00lC4P0B5QD02`l>00`@3`0200dA4080310?00P03A4@010D4P0F6aL02Pl;00`@3@09
3PX05AXF00dB3P80314=0P0=4Ph03@0<4@d02a0900/A1`0;4@L0314900`A2P0=4P/02a0:00lD3P0<
4@d02Pl;014F4P0>4`l00P0A4`h03@0@4Pd03Q0;00`>2@0;3@P03Q0;00lA300@4Pd03a4<00h@2`0;
3@P02@h7010E3P0B5a400P0;40X04`0;40`03a@@00dB3P0;3`h0310?034e=01KGeh03A8>00hC3`0K
7a`041DA014F4P083@T04aPD00H91P0U:RH0DUMC00hB3`0@5A400`0>40/01P0@4Pd04Q@?01@F4@0@
4Pd04A<>00lA30803@l:01d0418=01LI500<3PT06adH00D60`0o@C`05QPC01hP6`0=3`X020X500d?
2P0A4`h051HA01DG4`0<3PX03a4=00T;1`0?4@`04Q@?01LI4`0C5Q004QD>018E3@0@4`/02a0900dE
3`0B6aH02a@?00/A3@0200P>2P0300`A3@0>40d03a4>00<0418?00D05ATH00`@3`031`H0310?00/?
3P0200hB4@0600dA400<40l03A4@00dA400?4a803Q8A0P0<40l00`0>4Q4041@C010D4`0600dA400<
00`@400A5AD051PH01<G5`0E6AX03A4B00X>3`0=4A<02@d@014E600D5a/02Ph@0P0=4A803P0>4Q<0
310A00/?40093@h02`l@00X>3`0=4A801`/<00/?400H71`041@C018F5@0F6QT04ADD0P0>4Q4200`@
3`<03A4@01h03Q8@00`A3@0;40`03A8>00hC3`0;40`04AHB00dB3P0:3`/03A8>00lD400@5A403Q8A
00`@3`0>4Q0020d9014F4P0?4`l04AH@00dB300<4@/03A8;00X?200>4``051TC010D3`0?4`h04AH@
010E3`0;40X200dB300J00X?2@0I7QP05AXD00dB300=4@l03Q<@03Di=P1>Ddl03a@?00hC3@0d>C80
5AXC00dB2P073@@02a47010F3@0730H03Q<=00H;1@0;40X0314;00lD3P0C61802@h800hC3@0B5a48
00dB300300`A2`0=4P`03A8<00803A8<00H0314;00dB3P0?51003A8>00/@300:3`/200/@30803Q<?
00H03A8>00hC3`0?51003a4<01DG4P0B50l200`>2@0:00h@2`0@4Pd03Q0;018D3`0>40/03@l:01DG
4P0F6aL04AHB00P=2@@0314=00H04AHB01<H500:3`/02Pl;010E4@0;40`200`A3@0900dB3P0<4@d0
314=01DJ5P0@5A40724M01@I5@0>4`l03a8>00<03a4<00D0418=014C3P0A4`h0418=00lA3002010B
3@0L00lA300:3`T02a8;00lF3`0=50d03QD>00dD3@0<4``01`h700XA2P0;4P/031<<014H4@0=4`d0
3Q<?01DJ5P0<4@d02@h:01<H500?51003A8>014F4P0?51009R/W00<7100C61@03a@@00hC3`803a@@
01/03A8>00hC3`0L8Ad03a@@00/@300@5A40314=01HL600C6AD051XF04I<B00j@3`0318>014G4`0F
71P04aTE00/A3@0=4`l041HB014F4P0C61@041DA00dB3P0?51003Q<?00dB3P0>4`l00`0?51004P0>
4`l02a0:00hC3@0@5A402@h:02T]:`0I7A`051PG00`?3`0C5aP0310A010D5P0;3a804aPL00lD5`0B
5aX03a@G00dC50803aDE00D02a4@01<I5`0P9R@04aTG00lE4`0Dooooo`006oooool04P0?3`l03@d=
00/;2`0;2`/03@d>00l?4@0K6ad03@d@028Q9P0000@020L<01<B5`0B4Q@04a<C00l?3`0;2`/030`<
010@40804A4A00D02@T900X:2P0=3@d02`/;00h=4@0300h=4P0E00`;4@0;2Q002@P>00h=5@0510`0
2PTA00`:5@0:21<04PlI00/:4P0C4a/02P`A03a1A@0731002a0C00`@4@0;3a003@d?00l=400@4180
4Q<D00804a@F00/0NW]m09RIV`0;30h0414E00h?4`0?41804A8F00d>4P0<3A403@hB00h?5002010A
5@09014B5`0@4AH03a0D00l@5@0@4AH04A8F014B5`0E5ad02@`C008041<J00D04aHM01PK8P0>4AP0
41<J01@G7P02010C6P0801<F7@0A51T03a<D018F6@0D61/04aLJ014E600A51P6014D6@0[018F6@0A
5AT041<H010D5`0?4QH04QDJ00hB5@0=41@04QDJ01@H6`0?4aL04a/M010J6`0@6Qd04Q/R014J8`0;
4al04QXW00`D8@0A6BD02a@M00`E7P0@628041@M01/P9P0R9bd0=3To07AiO`35b]00CU=I028W;@0D
6Al061dS010E6`0B5ad03Q<G01HK7`0?51P06QlS018G6`0H7B406QlS00@93P0200lD6P0;01@I7`0A
5Q`030lF01PK8P0D5ah05APO00X=500J7B@03a8I018E700D5ah00P0B5A`04`0C5Q/02@`A00/?4`09
3A003Q4F01DI7@0@51L03a8G00lC5`0?4aH041<H010D600@51L02PhA01HJ7@0>4Q<020`?00hB5@0B
5QT00`0@51D02`0A5AD04ADF014E5P0I72803Q4H00lB6@0B5A`041<J014D6`0B5A`04A@K00803A0G
00<06QdT02<V;@0H6b@00P0=41T0900<3aH051LN010C6P0R9BX0Wj:W01lS9P0>4QD01@T<01LL7`05
30h051`O00lG6P0G728010PA00L;500B5Ad03`lG014B5`0B4aD04Q@C010C4`0<41402Ph?00lC500B
5QL03A4B00P<3@093@h03A4B00T=3P0?4a@0310A00lC5@0A5AP04QHI010D5`803Q8E0P0?4aH01P0@
51L04ADH010D5`0>4QD02`lA00`@4@8061`M01X041@E00hB4`093@h02`l@00dA4P0<41403A4B010D
5@0G6a`04ADF018F5`0M8B80720Q00`@4@0@51D02Ph?014E5P0H71d041@E00`@4@0?4a@0310A00hB
4`0H71d0720Q01@H6@H03A4B1P0?4a@2010D5@0T01DI6P0;3a004QHG00`@4@0<4A@051TL01<H6`0=
4QD04AHI00`A50000@@051TL010E600A5QT0B4e@00lD5`0;4A403Q@D00dC4`0;4A40318B010F5P0=
4a<04ALG00/A4@0?5AD0318B0826QP0h?S`04QPF00X@3P042PP01`d;018H5P0?5A<03Q@B0P0=4a40
4@0>51803aDC00/A4@0<4Q802Q0@00dC4`0H7Qh02a4A00dC4`0D6QX01@/;00hD500B61P03A<C01HL
6P0C6AL03Q@B00803A<A00D02Q0>00dC4@0>51803aDC010F500200lE4`0300`B400?5A<04ALE0080
2a4?00D04QPF0498AP073@/051XH00lE4`0201@J60804ADD00@06QhM02/_;P0j?Sd05QXI0P0>4Q40
3@0=4A004ADD00dA400;3`h0310?00@81`093@`03A4@00T=300@51<03A4@00T=300;3`h00P0>4Q40
100C5aD08RLS01`Q7@1;D4`2010E4@0300L<200<4@d0314=00<03Q<?00@03Q<<00dC2@0=4`T03A<:
0P0=4P/01P0>4`d05AXD00dB3P042@D05AXF00`A3@803Q0;0P0?4@`02P0>40/03@l:00`>2@0>40/0
4A<>010B3@0>40/02P`700L<1@0;40T200dB300H00lD3P093PX00080018G4`0:3Pd041@C00hB4@0<
40l041DA00@91@0F6aL041DA00<8100=4Ph00PL300lD400320@03A8>00X?2`0320@04A<>010B3@0?
4@`03Q0;0P0?4@`2010B3@0_00lA300>40/03Q0;00h@2`000@00DeE@000100082PD061XE010B3@0E
5a804aD@00P:1@092`H0418=00T;1P051`@02P`900`>2`092`P04aDA00d?2P0/;bP06A`E00T<1@0:
3@@03Q4800`A2P094@/0@DY501LP6`0C6AD00@L300`B3P0:3`/03@l<00h@3@0@4Pl04A<@018D4@0Y
;B`07b<R00X>3@0=4A002Ph=00L;2P0>4Q400P0<40l0100>4Q403A4@00dA400>4Q42010D4`0300hB
4@0<40l0310?00H0310?00`020`;00lC4P0C5aH04QHE01@H6@0@51D061`M01/O8P0A5AP0D5AG05II
GP0A5AP201<G600:00dA4P0C5aP04QHG010D5@0E6AX041@E018F5`0830d0310A01TM7@8041@C00H0
4ADD00`@3`0:3Pd02Ph=00`@3`0>4Q4200lC4P0300hB4@0=4Pl0314=00802a0<0P0<4@d0100:3`/0
1P/700lD400E6QH200dB3P0b00@81`072`X04AHB00H;1`052PH00`H201dR700F6aD041D>00`A2P08
3@H02Q0600hC3@083@L041D?00H;1@0>4`d03A8<00H;1@0A5Q0041D?03<h<P0W;2H01``600@90`0@
5@l02@d:0004000D6A<02a0:00T>200730D05AXC00lD3@0;40T010T300L<1P0>4`d02Pl900lD3P0;
40X03A8<00@90`0;40X01``601DJ500:3`T0314;00/@2P0=4P`300hC3@0400`A2`0:3`T02a0:00`A
2`<03A8<00H02a0<00hC3`0>4`l0314=00dB3P0>4`l200dB3P0@00`A3@0=4Ph04AHB01@I5@0;3@P0
1@L200X<1`0<3PT020X501LI500A4`h03@l:00X<1`092`H0418=01DG4P806b0L00L010T500<71006
2`L01@X600/@300@5A403Q<?00803a@@00D02a0<00X?2`0;40`0314=00hC3`0200lD400806EZIP0C
61@03Q<?00T>2P0G71P030l;00`>2@0=3`X2010B3@0F00lA300A4`h0418=00d?2P0<3PT03Q0;00lA
300B614082LP00/B2`0G7QL02A0900890P0D6a@03aH?018I4P0940T051/D028Y8P0I7aT00PL300lD
40804QLC00@06QlK00P=2@062`L05AXF0P0>4`l00`052PH04aPD00lD400200dB3P0J00hC3`0?5100
1``801`Q7@0J7a/04AHB010E4@0C61@04aTE01DK5`073@T04aTE01LM6@0?5A402@l;00dC3`0@5Q80
3A<?00`B3P0;4@d02@h:00dB3P0?51004QLC01PM6@0K81`3010E4@803a@@01T03Q<?010E3`0D6A<0
3a@@00L<200D6AH00`L600H:2@0>4Q807R8S01XN7`0;3a404aLJ04eBEP1RIfX03a@G00H;3P0?51H0
:c4a09:HV00Z<2l0318@014G5@0?5A<05Q`J01Cooooo000Kooooo`802`/900/030`:00`<300;2``0
2`/=00h=4P0<2a0040lD01HE6`0G5Q`02PT>00d=3`0200X:2P8030`<00P02@T9014A4@0A4A402@T9
00X:2P0=3@d02`/;00h>40803PdB03l03@`A00/:400:2@l03PdE00T74P0=2aH04@lJ00h<6@0S8B`0
3``G00h=5@071`l02P`C00462P000`L02PlB00lC500@51D0410@00l=3P0>3Q002PX<00l@500=3Q80
824U01TJ70061`T04A8D00d>400C5A@07QlQ01/L7P0A4Q@03@h@00h?4`0?41<0414C010A5@0@4A@0
3a0B00l@500@4A@0414C010A5@0?4AL05QTR014D7@0D5b003Q4J00`?600A51d04QDN00hA6P082a@0
3Q4J010C700>4AL03a<F018E6P0D5a`04aHK014E600@51L01@0?4aH0>00B5QT04aLH018F600B5QT0
41@E014E5`0@51L03Q8C00hB500B5QT04aLH010E5P0@6AP03aLI00`D5P0:4AT02a8L00dC7`0@5R@0
3A<Q01@J9P0<4ad03A@N010G8@0L82T05ATR01<G800G6b@0;c<l05QLI@0T:3406QhW01LK900:3QL0
51PQ01PL9@0;41H051TO00X?5@0@5A/05AXP01@I7`0B5a/05Q/O00`A5@0>4aL05a`P00dB5P0I7240
3A0E014D6@031P/041<H01PK800=41D04A@I0`0C5Q/05`0E61d0310C01XN800B5QL0720S03@h>P0V
:R/04aLJ018F600A5AH041@G00lC5@0>4Q<03a<D00X>3`0>4Q403a<D00`@4@0C5aP03a<D00lC5P0@
51L04ADG00804ADH00@071lW00lB6`0@4a`04aHO0P0A51d0;@0B5Ah04A@M00d@6@0>4AX06ahW02@W
<0092aL03Q4J018E7P0<3aP04aHM00P;4P031P/06QhQ0001100A5AL051PI00H;3P0A5a`01PdE0089
4@0F6RD041@O01dQ;00=41X03PhF010A5@0F5aT061XI01@G5`0;3a002@d>00lC500A5AH03A4B00X>
3`011@H05QXK018F5`0E6AX041@E00lC5@0B5QT04aLJ014E600200lC5P04010D5`0>4QD03Q8E00dA
50802`lB00@04ADG00020`000@803A4B0P0?4a@02@0=4A804QHG014E5P0>4Q<02Ph?00dA4P0A5AH0
3a<D00dA4P02010D5@0=00P<3@0B5QL02`l@00lC500D61T03A4B00hB4`0A5AH041@E014E5P0?4a@0
2`l@00T=3P0600dA4P@03a<D0P0@51D08P093@h02Ph?01<G60093@h041@E00lC500;41<041DH00X?
4P0>4aH041DH01<H6`0D6A`020d@00T>4@052Pd03Q<F01PM800;4A403aDE00hD500;4A40318B014G
5`001PH02a4A00020P083Ph02Q0@02/a<@0M8b4020h<018H5P0?5A<200X@3P803A<A0P0<4Q0200dC
4@0E00/A4@0B61P01`d=01`R8P0]<c<04ALG00/A4@0D6QX02Q0@00/A4@0=4a<0318B00`B400>5180
2Q0>00`B400@5Q@03A<A00`B400=4a403Q@B00<03aDC01d02a4?01TO7@0L8R003A<A00H<2P0<4Q00
5adK00dC4@0C6AL01@X800X@3P0>518041<B00T=30000P4061`K00/?3P0:3Pd04ADD00`@3`0:3Pd0
310?00L;2P0830/02@d<00L;2P0A5A@03Q8A00D9200200`@3`0;00P<2`0;3`h03Q8A00dA400=4@l0
4aPD00P=2@0g?3P020d9018G4`0=4Ph00P0<4@d0100=4Ph03Q<?00lD400?50d200hD2P0<00dC2P0=
4P/03A8;00`A2P0B5a403a@@00@91@0@5A402Pl;00/=200<3PT03Q0;0`0?4@`07P092`H02P`700d?
2P0?4@`03Q0;00d?2P083@H02Pl800/@2P0=4P`03a@>00T>2P0P9B403a@@00hB4@031`H051PG00/>
3@0=4Ph020d900T>2P052PH000D100lD40062`L04AHB00dB3P0E6QH020d900lD4080418=0`0>40/0
0`0?4@`03Q0;00h@2`0200h@2`0Q00d?2P0<3PT04A<>018D3`0>40/0418=00X;200C5A002`d801@F
4@0>40/0418=01TK5P0B50l03@l<02<U90041PD04A<@018D400;3@P0:B`U01LJ4P072P4020/200`?
1@0;4@L031@>02L`:`012PD0=cdi00`B3P0@5Q802a0<00803@l<0`0>40d201@H5`0;00D9200=4A00
3Q8A00/?3P0=4A002`l>00`@3`0?4a803A4@00/?3P0=4A000P0A5A@00`0>4Q403A4@00hB4@0600`@
3`0<00/@300=4Ph03a<A00hB4@0A5AH03Q8D00hB5@0A5AP01PX>030c>00e>3d020`?0P0D61T00`0?
4a@05ATJ01@H6@0200dA4P0900P<3@0=4A802`l@00T=3P0A5AD03A4@00hB4@0=4A00310?00802Ph=
00H03A4@00lC4P0A5A@041@C00lC4P0=4Pl200`A3@802a0<00<03A8>00`A3@0:3`/00P0C61@0:@0:
3`/041DA02@Y9@0;40`0314=018G4@0@5@l04AH@00hC300:3`P020d600T?1@083P@03Q@:00X?2@0A
5Q0061dG0046000=4P`03a@>00`A2`0C61800`P201/P6P0E6Q@02Pl9010E3`0320404aPB01PM5P0D
6A802Pl901<H4P0=4P`04AH@00T>200<4@`02a0:01<H4P0:3`T000D000802@h800L03Q<=00<80P0G
71H02@h8014F400;40X01``60080314;0P0:3`T01@0<4@/03A8<00X?2@0;40X0314;00<03A8<00<0
2a0<00hC3`0>4`l00P0=4Ph00`0?51003A8>00dB3P0200`A3@04014F4P0E6QH07b4L00`>2@803Q0;
01405aTD00lA300@4Pd05ALB00`>2@0>40/051HA00h@2`1_M700P8F101DJ5P0G71P01P/701HK5`0<
4@d041DA00hC3`02014F4P0X00`A3@0>4`l02a0<00X?2`0=4Ph04AHB01<H500A5Q8041DA01lT8006
2`L03a@@00d@300>40/03a4<010B3@0>40/030h9010B3@0E5a804aD@00h@2`0?4@`061XE010F3`0D
7QH02Q@<00@>1P0c?CD0BeE=018L500C7AD07BLO00lI4@0A6a<07bTQ01XP6P0;40`03A8>01<H5080
5AXF00D0314=00T>2P0B5a<03A8>01<H500200lD4007010E4@0?51003Q<?00lD400B5a<03Q<?014F
4P0200dB3P0E00`A3@0/<Bd03Q@@01HL600?5A402Q0<00/A3@0<4Ph02a4=00lE4@0G7AT061hJ01<I
5@0=4`l04AHB01<H500@5A403Q<?014F4P0@5A404AHB008041DA00<03a@@00hC3`0>4`l00P093PP0
0`0<4@d041DA00`@3P0200H:2@0A010D500=4A801`/<01PL7P031`X0?T=705]PH`0?51L02@hA01@J
6`0b>3P0aL_;03Pn?@093`d05Q`J014G5@093`d05?ooool001_ooooo00l030`900/<2@0;2`T02`/;
00/;300<30h01`L;00h=4P071P`030/A00`<4P0@3aD02`/=00X:2P0<30`00P0?3`l0200:2PX03Ph>
010@400;2`/03@d=00h>3P0;2`/03Ph@0`0>3A8200`;4@0L00`;4`0?3AP06QPS00l=6@10?T/0ZZRe
01PE800@3aL02`/C01<E70000`L04aPL00T>4@0@51D04ADF018B4P0?3@h03Ph@00X:3`0@4AH020T>
014B5P041@L07b0R01@F5@0?4A00418@01<E4P803Q0>00H04A<C010B4P0?4A403@h?00`=3P0>3a03
00lA4@80414B00H03Q0E01XM9P051a003Q4J010C700?4Q/300hA6P0:010C700B5Ah03a8K00hA6@0?
4QP041<I014D6P0A51T04ADH010D5`8041@E05/041@D010D4P0@51@04QHF010D500B5QH04aLG014E
5@0B5QH03A4A010D500C5aL04QHF010D500B5QH04ALF01HN700F7Ah03aDK010E7P0@5R003a@Q00hC
800C62@03Q<N01<I8`0D6B<051PQ00dA6P0E6B806AdV01XN9`0G6b@061`U018F7`0@51d05QXS01PL
9@0B5Ql051PR01LK9@0_<c`04QHO01LL8`0D6Al02PlC014F6P0C61/02@hB01TN800E6a`04A@H01XN
8P0>4QH0=cXn01HI7@0E61`04QDI01<G6`0B5QX041@H018E6@0D61/041@E01DI6@093@d02`l?01DI
6@0;3`l05ATI01@H600A5AD03a<C00dA4@0;3`h04AHC00dB3P0F6QP05a`I00lC4P0@51@03Q8C00hB
5@0?4aH041@H014E6@0A51X06A`T00lB6`0@4a`04A@M00803a8K04003Q4J01<F7`0D5b004QDN010C
700A51d03a4M00lB700=41X06A`U05AGGP1MH6L04aHK014E600F6Qd020`=00dA4P083A00314J00hE
800<4Ql07b8b01dP<00>4B006Q`Y01PH8P0?41@03a4@010B3`0?4Q003A4B00`@4@0>4Q<03a<D00hB
4`0@51D02`l@00lC500E6AX041@E00hB4`0>4Q@03a<F010D5`0>4QD0310C00dA500>4QD03a<F010D
5`0?4aH03Q8E014E600n@T@09b//00L92P0C5aP0310A00T=3P0>4Q<05a/L014E5P0=4A802`l@0P0=
4A800`0?4a@03Q8C00hB4`0201<G600<00/?400>4Q<03a<D00/?400:3Pl03a<D00`@4@0>4Q<051PI
010D5@0=4A806AdN0`0>4Q<200dA4P0300`@4@0>4Q<03Q8C00803a<D0P0@51D0500E6AX02`l@00lC
500?4a@05ATJ00dA4P0A5QT04AHJ03Ll@00;41@051TM00hC5`0E6Qd0:2d`00/@500?51P03Q<F00hA
500@5QH03aDE0`0=4a<03P0>51@041HF00hD500D6QX03Q@D010F5P0:3Ph04QPF00X@3P0A5aD03A<A
00hD4P0;4@l0318@100=4a405`0<4Q0020h>00dB50062`d05adN02T_<00C61X02a4B00T?400E6a`0
4QPI00/A4P0<4Q804QPF01/Q7`0B61H0318@00dC4@0:40h0318@00dC4@0>51803A<A0080318@00D0
3A<A01PN700L8R0041HD00P>300200`B400Y014E4`0T:RP06R0N00hD4P083P`03Q4@00`@3`0B5QD0
CE5@01@H5`0:3Pd04QHE00L;2P0H71/05a/J00D9200=4A003a<B01<G5P0T:2L06AdL00T=300<40l0
2`l>00`@3`0=4A00310?00/?3P093@/04AHB00/@300A5Q80314=018G4`0;40`03A8>00`A3@0;40`0
314=00dB3P0>4``00P0>50X02`0=4`X03A8;00`A2P0<4@/02a0:00/@300:3`/02a0<00hC3`0<3PT0
3@l:00@03a4<01h02P`700/=200<3PT03@l:00h@2`0?4@`02Pl800dB2`0;40X02Pl900dB300<4@d0
1PX702L/:00@51<03A4@00/?3P0<40l01P/701@I5@083@T05Q/G010E4@0<4@d00PD2014F4P0:3P/0
41@@00/@300:3`/200`>2@0500d?2P0>40/04A<>018D3`0?4@`00P0>40/08P0?4@`03Q0;00X<1`0B
50l03Q0<018D3`0=3`X04aD@014C3P0>40/04Q@?00d?2P0;3@P04A<>01@F4@0U9bH0;Bl^00X<2`0D
5Q<03Q0<010B3@0A50d03a8:00hA200?4PT03a8800X@1P094@/03aDA03Ho>P1DFUH04ALC00L=2@0=
4Ph200h@3@0E00d?300<3P/030h;00dA400@51<02Ph=00hB4@0;3`h03a<B00hB4@0;3`h0310?014E
500=4A002Ph=00/?3P0@51<03a<B00/?3P0<40l03Q8A00H03A4@0P0>4`l01@0=4Pl03A4@014E5P0@
51H03A4D00804QHJ00D020/@00hA5`0>4QH03A4B00hB4`0200lC500400hB4`0D61T092PY01hR8`80
4ADF00D02`l@00/?3`0?4a8041@C00`@3`0200hB4@0400`@3`0=4A003A4@00hB4@803a<B00L03A4?
00`A3@0>4`l03A8>00/@300=4Ph02a0<00802Pl;03D03A8>00lD400?5100C55=01hS7`0:3PX04AH@
010E3`0:3`T051TB00lD3@0>50/0318800T?1@0;4@L03A8<00T>200<4@/04AH@00hC3@0?50h02Pl9
00dB300;40X04aPB00dB30093PP041D=00lE2P0=4`X02a0800hC2`0=4P`03Q<=00/@2`0A5Q403A4?
018G500=4@l02Pl:00lD3P0G71H08BHP014F400:3`T04aPB00`A2`093PP02a0:00hC3@0?50h03Q<=
00dB300200/@2P802Pl900<0314;00dB300=4P`00P0=4P`0100<4@/03A8>010E4@0?510200dB3P03
00lD400=4Ph03A8>0080314=01<03a@@018G4`0X:RD06adH00X<1`0?4@`05aTD00X;200>40/03a4<
010B3@0>40/03@l:00lA300f>cL0>Chj018G4`0:3`/04aPD00803a@@01403A8>00hC3`0<4@d02a0<
010E4@0A5Q80314=00X?2`0=4Ph04QLC01@I5@0H7AT02@d:00/@300=4Ph04QLC00lB3P02014C3P0:
010B3@0=3`X02`d800`>2@0>40/03a4<00`>2@0?4@`061XE01LM5`802aD=01P051hF09nYX@3?fM40
6B<K00lI4@0M9al0628J00/E3@0>61002a<=018G4`0>4`l041DA00/@300730P051TE018G4`0@5A40
51TE014F4P0?51003A8>00lD400A5Q8200lD400=018G4`0>4`l03a@@010E4@0D6AD02Pl;01HK5`0A
5a<02a4=00`B3P0>51004ALC00lE4@0200dC3`0=01DK5`0H7QX04ALC00/A3@0=4Ph041DA00dB3P0:
3`/03A8>00`A3@0A5Q8041DA00lD400200dB3P0E00hC3`0=4P`041D?00lD400I7QX03Q8@00hB4@0@
51<04ADE05YNG`0L82402`h@01TM800=4AD041DI01LL7`0@5AP03A8C00lE5@0P9RH04aTH00803Q@B
00<03A<A03@j>?ooool04oooool001_ooooo01X04Q8@00d=300820P020P800d=3`0B4Q@03@`A00<2
200K6R000`8800P73@0D4aT030`>00l?400>3Ph02PX<00/;300A4A402PX<00l?400<30`03Ph?00l?
4@0;2`d03@d?00d<4@803PdB03003@`B00`;4@092@l02PTA00<22P081Q4030XE03Hd?`0B4AP01PD;
01LH7@0520d05APM00462P0;3a80310C00h?4`0=3@l03`d@00l>4`0=3A@020T>01TJ7`0@4AH01@H:
01TJ7P0A4Q@05ALF01<E500<3P`03Q0?010B4@0>40l03PlA00h@400>40l03PlA00l@4@0?4A003a0B
00lA4@0?4A003a0B014C5P082a805aXQ04E8C`0<3aH2014D6`803Q4H00X04A@K00/>5@0<3aH04A@L
00hA6P0>4AP03Q4G00lB5`0@4aP04ADI0P0A5AP4014E5P0E00`@4@0@51D04aLH00lC4P0B5QD02`l>
018F5@0G71P04AHB00hC3`0D6AD04ALE01LM6`0E6a/041DH01<H700C5al04QHO010D7@0F6R<051PQ
00807R<Y00`04AHL01<H7P0>4QX020`E01HK8@0B5ah03a<L024V;00?4a/04QHO01XO9@0A5Ah201PL
9@0/05YNIP0H7B<02a0E00dB5P0J7b804AHI00X@400L8R8010T901LK700D61/01`P<01HJ7@0_<c@0
;S8c01TM7P0H71d05QXK014E5P0>4QD0414E01<D600C5aP01`/;014E500B5QL0310@01XN7@0;3a00
310@00dA400?4a@041@D014E500D61L06b0L00`@3`062PT041@F014E600=41D03Q4F00hA600@4aX2
014D6`1Q01LJ8P0C4ad04QDN014D7@0?4Q/04A@M010C700>4AX03a<N01@G8P0E6B@051PQ00`?5`0N
8BP06QdT00d@5`0a=3/0;S4f00d@5@072Pl051PK010D5`0830l03Q4F00H;5@0K7bX020`H020T<@0h
>dX02@dI01@G8P0F5Qh03PlC018D4`0E5a@04QDD00lC500?4aH03A4C00`@4@0?4aH02`lA01PL7@01
1@P041@F010D5@0:3Q403Q8E00lC5P0@51L03Q8E00`@4`0=4A@02`lB00`@4`0?4aH03A4D00X>4@0;
3a803Q8D01HJ6`0I7Ah02@d>018F5`0F6Q/02`l@01PL7@0<41403A4B01@H6@0F6Q/020`?00/?4P09
3A003A4D01@H6@0?4a@01`/<01DI6P0G6a`02`l@00hB4@0C5aL04QHG010D4`0@51@02`l@00H:2@0A
5AD03Q8C00hB4@0>4Q803A4B00`@3`0<4100310A00dA4P0200hB4`803a<F01D020`?00T=400D61X0
20`=00X>3`0A5QL03A8E03<k?@2PZ:X03ADH00lG6@032`d010T=00lD60001@P061dQ010E6@093Q40
51XJ00hD500<4Q800P0>51@03`0:410061hN04mEE@052`/06R0P010F5P0=4a<02Q0>00dC4@0?5A<0
20h<014G5@0<4Q003A<A00hD4P0200lE4`0C00hD4P0=4a4051XJ00`B4`0@5QH01``>00hC5P0@5QH0
4AHH0005200S:BT09BX/01DJ7@0B61P02@l=01`R800C6AL02a4?00dC4@0400`B400700XA3`093`d0
1Pl<00`B40052`T02@l=00dC400200`A3@0601@I5@000P006QhM00/@3`093`d04aTG0P0>4Q402@07
2`X010P700/?3P0@51<03a<B00dA4010A4<0=c/j00P<2`0200`@3`0600D9200A51<02`l>00D9200<
40l02Ph=0P0?4a803`0:3Pd02@d<00dA3`0320@02a0<00lD400:3`/00PL300hC3`0=4Ph02a0<00X?
2`093PX02Pl;00`B2P0200dC2@0900`B2@0;40T02a0901HK5@0A5Q802@h:01<H500;40`041D@00<0
418=02<03Q0;00d?2P0;3@P04A<>00lA300=3`X02`d800d?2P0@4Pd03A8;010E3P0<4@/01``600X?
2@0=4Ph051TE00T>2P0:3`/041@C0002000?514020d900/@300E6QH0EU]G00hC3`0<4@d02a0<00lD
40052@D05a`H014F4P0<4@d0418=00lA300200d?2P803Q0;00T04A<>00lA300?4@`04Q@?010B3@0:
30L04Q@?00h@2`0@4Pd00P0A4`h00`0B50l04aD@010B3@0200h@2`0801/M600];bX03a4>00@50`0K
7AX051D@00`>2@0>40/200lB2`0;00/>1@0:3@H03A07010F300=5@l05A/G00P>2P093`/020h:00`B
3P0=4Ph01@0?4@h04@0@51<03Q8A00hB4@0>4Q402Ph=01HJ6@0>4Q402Ph=00`@3`0A5A@03A4@00P<
2`0>4Q404QHE010D4`093@`02`l>00L03Q8A00l02@h:00`A3@0=4Pl0310?010D5@0:3Pl05ATL00dA
500830l06QhQ00lB5`072`h020`=00T=3P0A5AH00P0;3a001`0:3Pl0720Q01XN7`031`P03A4B00lC
500<41000P0@51<02`0:3Pd03A4@00`@3`093@`02`l>00X>3@093@`02`l>00`@3`0;3`d02a0<0080
3a@@0P0;40`03P083@T0314=01@I5@0U:RH0:c0/014F4P0>4`l03A8>01DJ5P083@L01``600dB300@
5@l0314:0P0>4``0;00;40T0314:00X?2@0K81X041D?018G4@0?50h02a0:01HK5@0:3`T02a0:00L<
1P0:3`T051TC00lD3@0=4`T041H<01LL5@001@002a09018G4@093PP020d900D:1P0?51402@d<00/A
3@083PX01@`500/B2`0<4``07RDM051GD00B6A8061lH018I4P093`/041HB00dB3P0@5A004QLA010E
4@0:3`T01@X40`0=4P`01P0<4@/02a0:00X?2@0>4`d041D?00lD3P803A8>02403Q<?00`A3@0=4Ph0
314=00X?300;3`h03A8>010B3P0=3`X04A<>01HH4`021000<S@_02DW8P082PD04aD@00`>2@0E5a80
=SPc018G4`0?5100314=00dB3P093PX03Q<?00`A30093PP041D?00`A2`0>4`d07B8L014F4P0?5100
0P0>4`l08P0?510041DA010E4@0A5Q802Pl;014F4P0;40`03A0<014C3P0@4Pd03a4<00h@2`0=3`X0
418=014C3P0?4@`0418=014C3P0?4@`020h701<M5@042`@04Q/C00LA2@0Z<BX0624I00H@200;4P/0
4ATB00TC2`0?5Pl03aH@00hC3`0A5Q8202`a;@0A01PM6@0=4Ph03a@@01LL600_=3003A8>00H;1`0?
51003A8>014F4P0?51003A8>00lD400:3`/04QLC00/@300@5A400P0B5a<0400A5a<0318>01LM6@0=
4`l01P`800hD400@5Q80318>00lE4@0A5a<02a4=00T?2`0?51004AHB00lD400=4Ph2010E4@03014F
4P0@5A403A8>00802a0<01T0314=00/@2P0K81X02Pl;010E4@0A5Q<0310?018F5@0>4Q808RHW00D9
2P0E6A/01@T<00@93@0D6Ad04AHI00/@4`0J7b406b4Q00/A4@0A5aH01@/901XP7P0<51404AXG01Co
oooo000Kooooo`0J00L72@0:2P`030`>00h>400510T05QDJ00T83@071P/0000400T83@0B4AH00P46
018A5P0<2`l03`lA00d<4@081`/04Q8D018A5P0:2Pd03Ph@00`<3`0:2@h040lD00d<4@0?3Q<4010?
508040lE01403PdC00/:400;2Q002``@00T;3@0>4Q<02`l@00T=400;3a800@D800d>4`0;314030/A
00l>5P0@3aL03`hF00`<500200h>5P1C00l?5P0<3A802``A01HG700:2a003PlD00l@500;31404A8F
01<D5P082@d030d@02DV:00H6Ad03PlB00d>400=3Q803PlB00l@4P0?41@04A<G00P<3`0F6Qd0<3@g
00`@4`0010L05ATL00041`0:3Q4061`O00/?4P0>4QD05APN00X=500C5Qd04A@K01@G7P0N8BP04A@L
014D7@0B5Ah05APQ01<F7`0@4a`05APO00852P0D5a`051PK01<G600B5QH03a<B01HK5`0B5a405a`E
01PM5P0<4PT04ALC00`B400:40h03aDE018H600?51H0:c0c01XO8P0:3a8061dP00P>3P0H7Al04QLK
01@I7@0A5Q/04AHL01DJ7P0B5a`04QLM018G6`0A5Q/03Q<I00hC5`0@5AX03A4D010D5`0E6A/00P0I
7Ah0;`0G6a`0EUYK01@H6@0=4A003Q8A018F5@0010D05aHK01DD6@0>3a405aTH024V8P0F7AH04APA
010E4@0@4Q40414C014@5@0?3Q<0414E02DY:`1=DE80720S018F600D61T04QHI01@H6P0A5AH04aLJ
01PL7P0E6A`00`L:018E6009314082<Z00lB70092aL03Q0L00L95@0O8Bd02@XF01DG8`0]<3T06ATP
01TH800D51`04Q8J00804QDN00T04ADP00hB7@0N930020dI03ToB`0?5R005AXL00L;30072`h00P0@
51L09@0<3a@04A@I00hA5P0@4aX03Q4H00d@5`0@4aX05ATN01HI7P062@h02`hC01HI7P0?4QL041<G
00T=400E6A/00PH7014E500=4A<03A4D014D6@0>4QH051PK00852P0;3a<03A4D00lB5`0@51P03a<F
00d@5@0=4A@020`=00`@4@0E6AX0004201@H6@0A5AH00P0@51D2014E5P03010D5@0B5QL041@E0080
41@E02D01`/<01/O800N8R<05QXK00lC500=4A80310A01PL7P0:3A803Q4H01PK800@4aP03a<F00/?
4P093@h04ADF00lC4P0:3Pd041DA00lC4@0@4Q403a4>00lA3`0>40l03a4>010B400C5A@01@L400lA
3`0F61L04Q@A00lC400>4Q4041HD018H600E6Qd03a@H00803A8H01l041DK010E6@0<4Q803A<C01DK
6@0:51<05AlO01XT8`0D7Ql02aDE00TC4P0;4aD05AdN00L@3`063Q004API00D;2`0;4A404aTG00lE
4`083P`02a4?00lE4`0A5aD07bDS00X@3P0;4@l03aDC00D;2@0;4@l03Q@B00802Q0>00@03Q@B00/A
3`0D6QP03A<A0P093`d03P0:40h03A<A00L=2`0>51<02Q0>00X@3`0?5AD04ALE00hD4`0A5aL03Q@B
014G5P0B61P0318@0P0=4Ph05P0B5a<03a@@014G5@0?5A<02A8?01<L6`0=5QD01Pl>00TB4@084Q40
31DD00050P0?5A<020`700`>2@0I6aH0414<00lA300?4@h041<B00dA4P0?4a@600dA400601LK6P08
30/0=SXi01dQ800010<03A4?0`0=4Ph00`0<4@d03Q<?00hC3`0200`A3@0L00lD400@5A404AHB018G
4`083@T04aPD00X?2`0320@04AHB00`A3@0:3`/0314=00X?2`0M8Qh0?dA000H<10093`<0318800lD
300>4`d03A8<00X?2`0M8Qh020d900P=1`0D6A<04AH@00H;10804aPA00D02@h700hC300=4P/02a09
00`A2P0200hC300400`A2P0:3`P02a0:00`A2`803A8<0P0<4@/020062`D04QLA00T>200>4`l02Pl9
00dB3P093PX02Pl;0P0<4@d01@0:3`/01``800hC3`0>4`l03a8?00<02a0<02X02@h800hC3@0C6180
3Q<=00T>200@5@l020d700hC3@0?50h02Pl900`A2`0C61806b0J00hC3@0E6Q@02a0:014F401HGEL0
SY>=02DZ900E6Q@0314;014F400B50l05aPB00X:1`0H6A<08R4L00d>200F5a402Pd600`?200>4@X0
3a4<00dA2P0;40T02Q0900D:10093PP041D?00`A2`083@L200T>200700X?2@0?50h04aPB01DJ5P0<
40l03A4@00/?3P02010D4`0900X>3@0<40l03Q8A00X>3@0<40l03Q8A00T=300830/02Ph=00802`l>
00D02Ph=00T=300>4Q403a<B00hB4@0200`@3`0Q00dA400?4a801`/:00`@3`0?4a801PX900`@3`0>
4Q<05a/L010D5@0?4a@04ADF00P<3@0A5AH04QHG00/?400=4A803Q8C00T=3P0@51D00042018F5`09
3@h02`l@00/?3`0<40l03Q8A00lC4P0>4Q40310?00X>3@0;3`h03A4@00804ADD00@041@C00lC4P0>
4Q403A4@0P0>4Q402P0;3`h03a<B00030P0>4Q40DEED06mcLP0B5QD02@h:00X?2`0<4@d300dB3P0<
00hC3`0>4`d03Q<=00hC3@0=4P`02a0:00X?2`0=4Ph041DA00dB3P0;40`03A8>0P0:3`/300`A3@0V
00/@300=50d06B0I00<:0`0[<R/051/D00`C300:4@T02a8:00dD30001`0041L?00hE3P084@h01a0>
00L@2`084PX02A<:00LA1P0D7QD02A<;01<M5@0740/02a@B01XS8P0U:bT010P601DK5`0<4Q0041HB
00@:1P083PX02A0:00/B2`0=50d041L?014H400<4@X200hC300R00dB300:3`T020d700P=2@0;40d0
3Q8A00dA4@0:3Pl020`=00lD40083@T03A8>00`A3@0:3`/0:BhZ020U8@052PH07R<O024V8P0<4@d0
51TE010D4`0C5aH06AdL00870`0M8Q`010T300hC300=4P/03a@=018G400=4`T02@h700hC3@802a0:
00@0314;00lD3P0A5Q004AH@0P0;40X00`0?50h03Q<=00dB300600dB3080314;01X03A8<00lD3P0A
5Q0041D?00/B2`0=4P`03aD?010G400B5a4041H@00hE3P0?50h03Q@>00`C300<4@/03A<>00/A3@09
3`/03Q@@018H500?5A402Q0<00D;1`0O9B406AlK01@J5P803aDA00L03a@@00`A3@0<4@d03A8>00`A
3@0A5Q8041DA00<03Q<?00d02a0<010E3`0F6aD06AhH01PM5`0C6180314;018G4@0>4`d03a@>01@I
4`0F6aD07R<M00803a@@0P0@5A401P0A5Q804QLC01<H50000`002a0<01/P7080314=00D02A0901`S
700>51000`T500/A3P0200hD4P0A010F5@0J820041HF00/A4P0B5aX03a8G01@G6`0@51L041DH01PM
7`0J82004AXI00`E4`094Pl02a@A00XD400540`05?ooool001_ooooo00<03`hC00`;400:2@h00P0?
3Q<01`0>3A802`X?024P9@0I61d02`X?00X93P0>3A800P0:2@h0300;2Pl030/@00h=4P0=31402`X?
014@5@0:2@h030/@010?500<2a003@`A00h=4P803`hC00<03PdB00d<4@0;2Pl00`0<2a002@0>3A80
3a0C02P];@0<41005a/K00d@4P0;310030dA00d>4`0200`;4P0600l>5@0?3QL03`hE00`<4`0>3aD0
4A4H0P0C51X03P0D51/04a@J00/;4P0>3QD0410G00d=500?41@030dA01`M8@0H6Ad0<34e00l@500@
4AD03a0D0P0@4AD2014B5P0400hA4`0<41403A4B010D5@<03a<D00X01`/<00lC500<41405a/L010D
5@0F6Qh02PdC00lB600F6Al03Q4G0P0E62005P0B51l04A@N010B7P0@4Ql04aDR01@F8P0H6bD03a8L
01<F7@0E61l04QDJ014D5`0=4A803A8@018G500=4Ph04aPD00hD4@0?5A@05Q`K01dS8P0K8B0200lE
500=01HL6`0?5A@02`l>01HL6`0=4a804aTJ01@J6`0@5AP03a@H01@J6`0C61/03a@H010F5`02014F
6@0O018G6@0D6A`05a/L01DI6@0B5QH041@D018F5P0D61P05ATI00/?3`0B5QH02Ph>014E5@0B4aD0
6APN010>500C4aD04Q@C00`B3@0A614051/E014F4P0E5aH071`N01/I7`0@3aD051DI00dA500P92L0
3a<F010D5`02014E600B01<G6P0>4QD03Q8E014E600=4A@051PL01LJ8018Be80EUQT00d?700E5bD0
4A<R00H85`0C5B@04A<P00d?6`0>4AX05QDL0P0E51/0<`0C4a/04A@M014D7@0@51l05adY01HJ9P0S
:CL0YJfj07b3S@0L82804QHF010D500@51H03A4D00T=400A51P03Q4G010C6@0?4QP03A0H010C6@0?
4aD03A4B01<G600<41403Q8C01`P8@0=4A802Ph?00/?400@51D02Ph?00dA4`0<41@04QHJ00/?4`0F
6Qh030lC00hB5P0=4AD03a<G010D600?4aL03A4E00lC5@0T:2T07B4R00dA4P0@51D02Ph?00lC5002
00dA4P0700hB4`0=4A803A4B00lC500;3a007B4R010D5@0200`@4@0[01HJ6`0B5QL02`l@010D5@0A
5AH03Q8D00lB600I7280FemT01/N8P093A404QHI014E5P0?4a@03A4A00lC4P0A5A<04AHC00hC400=
4a003A8?00hA3`0=4Pl03a<@010C4@0>51403Q<@00/>300E6aP03A4?00X@3@0B61H03Q@D00L:3P0E
6Qh0Ad]D00X>5`0<4AL03A8G00T>4@0:410041PE00dG5P02014M6`0@00/G5@0951<02aDD02hg=P0F
7ah04AXI014I600:410041HF01<I5`073@/04aTG00dC4@0>5180318@00dC4@802@l=00D06R0N03Hl
>P0A5aD02a4?00hD4P0200X@3P0=00hD4P0;4@l03aDC00`B40093`d02Q0>00dC4@0?5A<020h<00`B
400>518051XH014G5@0200X@3P0M00hD4P0;4@l02a4?00dC4@0<4Ph041D@014F4P0<4@d041DA00lE
4`0=4a403AHC00<<2`084A006B<R01<M7P033@h02aHE00/E500;51403Q<?010B3@0;3@L03a0;00/;
20092`T03A0@01HJ700;41001P0<40l01`052@P02@d<014E50031`H05QXI00X>300=4Ph00P0?5100
0`0=4Ph03a@@00hC3`0200/@300Q00`A3@0=4Ph03A8>00dB3P0;40`05Q/G02H[9`0@5A401``800hC
3`0;40`02Pl;00`A3@0F6aL0;34]00`A200:4080318800lD300>4`d03A8>02lc<@1fNWT04aPD01<H
4P072PH03a@=010E3P0I7QP05a`F00dB2`0?50h03Q<<00803A8<00<03A8;00`A2P0<4@X00P0;40X0
0`0<4@/03A8<00dB300200`A2`0900dB300;40X03A8<00hC3@0A5Q002`l:00dB3P0<4@d02Pl;0080
2@h:00P02a0<00P;200B5a<03A8>00/>2`0A5Q803a@@00hC3@801``601d04aPB01`Q6`0B5a4041D?
00`A2`093PP02Pl900hC3@0A5Q00EeaF010D400@5@l02@h801PM5`2FViD0b/o902/`:P0G71H07B8L
00dB300<40X0418<00h@2@092`L03Q0:010B30051`<03Q0:00lA3002010B3@0500lB3@0=40/02a0:
00/@2P0<4@/00`0>4`d02`0=4P`03a@>01<H4P0F6aD03Q<=00L<1P0A5A@041@C00/?3P0<40l03a<B
00803A4@00L03a<B00`@3`0>4Q403Q8A00/?3P0>4Q403a<B008041@C0P0?4a8200hB4@0F00dA400:
3Pd02Ph=00/?3P0<40l09BTX03Di>00D61L041@C00hA400:3Pd01`/:00dA400:3Pd0310?00dA4@0?
4a@041@E00`@4@0=4A803a<D00X>3`804ADF00P0310A00H92P0E6AX02`l?00hB4@0=4A00310?00dA
40<03Q8A100=4A00300>4Q403A4@00`@3`0>4Q403a<B00`@3`0;3`h05QXI00dA400F6QT07R8Q00hB
4@803A8>00<03Q<?00dB3P0<4@d00`0;40`02P0<4@d02a0<00/@300;40`02@h:00`A3@0>4`l03A8>
00/@300=4Ph200/@30<0314=02D02a0<00`B3P083PX0=C/g0:>YY@0M8al041L@00H=1@0A61003QD=
00`D2@0<50X02a8:00XC400;5A<02aD?00TC3@0950/02QD:00TD2@0=5Pd02Q<;00dG4`0=5Q@0R96@
05eSH@0E6aT03A<A00lE4`0L8Ql03Q@@00lE4@0>50l031<<00/B2`0940T020l7008041D=02@03Q<<
00dB300=4P/0314;00/@300<40h03A4@00dA4P0;3a402`l@00dA3`0C61@01`/702db;P1>Ddl03Q<?
014F4P0<4@d03Q<?014F4P0>4`l02a0<00lC4P0>4Q402@d<02``;00<4@/02a0:010E3P0>50X03aD;
018H3P0A5`/03aD;00dB2`0>4`d200lD3P80314;0P0?50h200hC3@L03A8<0P0?50h0100>4`d03A8<
00dB300>4`d200lD3PH03Q<=0P0?50h200hC3@0@00hC3P0;4@d02Q0<00lE4@0B61@03Q@@00`B3P09
3`/0:Bl[01TO6`0<4Ph03Q@@00lE4@0?5100314=00lD40804AHB00`051TE018G4`0@5A403a@@010E
4@0?51004AH@02<X8P0C618020d701DJ500<4@/200/@2P0501DJ500H7AL04QLA00dB300<4@d00`0=
4Ph300hC3`0301HK5`0=4Ph03A8>00804AHB01P06B0I00hE3P0A5a<01P`800lE4P0D6QP0@DM5014F
5@0A5aL03Q@D00lD5P0B5aX03A8F010F6@0;4A@02A0B00lE5`0A5aL041LG00`C4P094@h02a8@00`E
4@0:510Dooooo`006oooool02@0<2a0010<801<B5`0:2@h00`8701@C600A41D061LL01<B5`0200h=
4P0=00T83@0?3Q<05QDJ00X93P061@X030/@00T83@081``030/@00h=4P0B4AH03@`A00D42@0300d<
4@0300`;400:2@h02PT>00803`hC00/03PdB00`;400=31403@hB00L<3@0@51L0004403a0@`1ZJfl0
4Q<G00`=4@0200/:400E00h=4`0?3Q@03PdC00l@5@0A4QL04a@I01HG700H6Ah06AXO014B5`0>3a@0
414F01<D6@0A4QL02P/@02LX;00000@06a`P01<D600o@4@07QlS00803a0D0P0@4AD0>@0A4QH03Q4C
014E5P0@51D0310A01DI6P0A5AH02`l@00`@4@0H71d03a<D00T=3P000@8061`N00/?4P0;3Q<03a8G
00/>4`0@4aP04QDL00d@5`0<3aH04QDN01DH8@0B52009bTe05aNJ`0Q8c0051HS01<E8@0;3QP030lH
02P[=00;3QD03Q4F00442@0@4aL03a@G018H600J82407b@W01/Q8@0@5AL041DH018H600G7Ah04aPK
014G5`0@5QL03A<C00lE5@0>51@03aDE018H600?5AD04aTI018H6002014G5`0R010F5P0>51@03a<D
00hB4`0>4Q@04ADH01XN800P92D0720S01<G6@0;3a002`lB014E5`0;310051<K018@5`0B4aL03a<D
00dB4@0B61H03Q@B00/@3`0<41404a@H018@600:2A406AXO00/?4P0A5AP0720S01@H6`0830l02`lB
014E60803Q8E01804ADH00lC5P0830l07B4U00P;4P0=41T04Q@Q00P:5`0<3Qd02`dL00`>6`0A4al0
30lH01DH8@0C4QT04a8J01HE7@0F5Qh2010C700B00hB7@0<4Qh0/kW503HlBP0G7b`03aHP00`@4`0?
4aH04ADH018F6@0C5aX051PK00lC5P0=41D041<H00lB5P0<3a@03a<F0P0?4a@0400A5AH00PH7024U
9P1?De@04QHG00`@4@0;3a00<CDf00`@4@0A5AL03Q8E01LK7P0:3Q4051PK00dA500<41<200hB5@0;
00lC5P0>4QD03Q8E00/?4@0d>3T0=CTj018F5`0G6a`010P901LK700?4a@00P0>4Q<0B@0=4A803Q8C
014E5P0Y;Bh0EEUJ00lC500E6AX0310A010D5@0<41402Ph?01<G600I7Ah051PI00X>4@0C5aX03Q8D
00lC5P0<41<06AdP01LK700:3Pl020`=010D5@0>4Q403a<C00hD500=4a40318A00`B4P0<4Q003Q@C
00dC4`0F71X041HE00061P0:40h02Ph=00hD4P0D6QP0318C00021P042@d092P`00X>5`0<4AL0314E
00X?4P0:41003QDD00<=30074a402aLE00hJ600E81l07BLV0>_dl`1HHF0000T800H<300?5AD05A/K
01@J600@5Q@05Q`J00881P0A5aD061hL00P>300C6AL02@l=014G5@18CT`00P0:40h0<00>51802a4?
00/A3`0>51802Q0>00lE4`0@5Q@02a4?00T?3@0;4@l02Q0>00H<2P0<4Q003aDC01@J600A5aD02@l=
00hD4P0C6AL04ALE00hD4P0A5aD051XF018G4P0:3`/01``801HK5`0=4a40318@00TB3`084A002a@C
010J6@0=5aP0218C00<<300A7Ad031HE00L?3@0:3`/0418=00h@3@0>40l02Ph?018F600Y;S406AhQ
00`@40@0310?00@02`l>01@H5`021PD03Q8A0P011@@0100<4@h0314=00hC3`0>4`l200`A3@@03Q<?
00P03A8>00`A3@0>4`l02a0<010E4@0J7a/0314=00T>2P8041DA01402@h:00X?2`052PH020d900/A
200:4080318800dC2`0=4P`03A8>00X>300a=C@02@h:024V800C618010T200H;1@0200dB300;00T>
200<4@/03A8<00lD3P0>4`d02a0:00X?2@0;40X03A8<00/@2P0<4@/00P0=4P`300`A2`0E01@I4`0?
50h02Pl900H;1@0;40X03A8>00`A3@0:3`/02@h:00X?2`0<4@d0008001@I5@083@T0008000/@3005
2PH01``601PM5`0<4@/00`P200803A8<01T051TC010E3`0<4@/0314;00dB300>4`d03a@>02ld;P0:
3`T000@001hS7@062`D07b@N00`A2`0C61803A8<00hC3@0<4@/0318>00H<200<4Ph03A<?018H500=
4P`0314;00803@l:00P030h900/=200:30L01``600hC3@0:3`T01``600`A2`803a@>00D0314;00dB
300@5@l041D?00lD3P02010D4`0300dA400:3Pd0310?00803Q8A0`0?4a80100>4Q403A4@00dA400=
4A0400hB4@0300dA400>4Q403A4@00802`l>00L03A4@00/?3P0W:bX0F5aK014E50000@004ADD0080
1`/:0P0@51<0100<40l03A4A00`@4@0>4Q<200dA4P0900lC500C5aP04QHG01<G600A5AH01@T:00X>
3`093@d03Q8A00<0310?100>4Q4300lC4P0=00hB4@0;3`h02`l>00hB4@0@51<03Q8A00H:2@0E6AP0
1`/:01lS8P0I7A`03A4@00`A3@0300dB3P0300`A3@0;40`0314=0080314=00@03A8>00hC3`0?5100
2Pl;1@0;40`200`A3@0E00dB3P0<4@d0314=00/@300:40`04aTE00/A3@0D6QH041HB00P>200:4@T0
3QD=010G3`001`002Q8701@K4`063``031DC00`E40084@`0218:00803QP=00h02Q@<010J4P012PL0
31DC01HO7P0L8R001@/900lE4`0=4a403Q@A00T?2`0;4@d02a8<00/B2`802Q4:02H02Q4900lD3@0=
4P/02Pl800T>200:3`T02a0:00dB3P0<40h02`l>00/?400<41403A4@00@91@0;40`01P/7014F4P0V
:bL0008000X?2`0A5Q802@h:00/@300A5Q803A8>00D9200<40l000@3038g<`052P@04aPB00`A2P0:
40H02@l500`B200@5PX04AL=00hC30803a@>00T03Q<=00/@2P0:3`T0314;018G4@0A5Q003A8<00`A
2`0>4`d01@0=4P`300`A2`0500hC3@0@5@l04AH@010E3`0>4`d00P0=4P`200`A2`<03A8<00H03Q<=
00lD3P0@5@l03Q<>00/A3@0<4Ph2010F4P0:00`B3P0B61@05A/G03Lm>@0P9R803aDA01TO6`0G71P0
41DA00`A3@802a0<00<02Pl;01DJ5P0B5a<00P0?5102010E4@0<01DJ500U:R@041D?00L<1P0D6A<0
3a@>010E3`0=4P`041D?018G4@0@5@l04aPB1P0<4@d07P0320@0008002DZ9P1_M7008RLS00D91@0>
5@h00@P100hD400?5A404ALD018H5P0@5Q@05adL00020P0A5aL05Q`M010E600<51L041TK00`D5P0:
4Q@03aHG00lE5@0@5QH03A<B00/A3`0<4Q0041DD018H5QCooooo000Kooooo`0F018A5P0=31404A0E
00T83@0B4AH02`X?018A5P0=314020L<00X93P0=31401`H;01LF6`0P7b@040lD00L62`0>3A804a8G
024P9@0:2@h03`hC01<B5`802PT>0`0=31401P0<2a002PT>00T83@0?3Q<03PdB00d<4@802`X?00d0
30dA014E600D5a`03a8G01dP9@0`<CD02``@00`=4@0:2@h02`X?00h=4@0>3A803@`A00802``@0180
30dA00h?4`0?41@03a0D00h?4`0?41@0414E018C5`0@4AD06AXN04e>DP0P8BD0=3Di00P93@0X:Bd0
2``@00d>4P0>3a<300l@5003010B5@0>4Q<03Q8C00804aLH00/03a<D00X>3`0?4a@041@E01hR8`1N
HV<07b<T00/?400G6a`04QHI00X>4@02010D5`0>01dP9@0P8bP05APM01@G7P0F6B003Q4J00H84`0Z
;3/00P@C00`>7@0E5b@05QPU01dO;01JG6P2020R;P0E010B7P0H6RD03Q<G00hC5P0@5AP04AHJ010E
600=4QH06AhR00X?4P093Q40314E01PM800C61`02a4A00lE5@0B61P051XJ01HL700?5AD04QPH0080
41HF0P0A5aL0@@0=4a<04aLJ01<G6P0B5QX04QDJ01@G6`0D61/02PdB01DI7@0=4A@020/@00`@500H
6Ah02`XB020N9`0D5AX020/@010E600D6QX04QPH018G600>4AH03PlD00l=5P0A41P04a@I00dA500?
4aH0720S018F6@093A002PhA014E600?4aH03A4D00lC5P0>4QD02`lB01@H700>4AP041<L00lA7P0>
41d02P`K01`N:`0=3a`08bDa01/N9`0:3AH051@L014A6@0G5al061PR014D7@0B5Ah04QHQ00`@6`0_
<ch01`dI04Q>FP0941X05ATN01PK800G6Ql04aHK00804ADH0P0=4A@00`0@51L03a<E00`@4`0200hB
4`0@00/?400A5AH04QHG018F5`0G6a`04aLH00010P0D61T0DEEF01lS900@51H000@700dA50093A00
5ATL018F6@H03Q8E00T02`lA01LK700B5QL02Ph?01PL7@062P/02Ph?010D5@0>4Q<00`0=4A80900A
5AH06QhO0455AP0<41403a<D00H:2`0B5QL04aLH014E5P0@51D04ADF010D5@052@X05a/L014E5@0C
5aP02@d>01/O800V:R/061`M014E600C5aX03A4B00/?4@0>4aH031DD00/C500:4Q@02a@C00`E5@09
4A<03aPG00hF5`073a405b0O03Lo@0802a4A00d0314D01@I7@0C61`041DK00dB600>4aT03Q<G00dB
5@0=4a<03aHF00XD4`0<61H03QXH00803aTH01D041XI03Y3@P0L8b<04ALG01DK6`0>51@010X:00L=
2`0?5A<03Q@B00<91`0D6QP03Q@B01DK6@073@/05Q`J00H<2P0=4a400PP600T?3@0>51800P0<4Q00
2P0>51802@l=00D;2@0<4Q0020h<00H<2P0;4@l02Q0>00H<2P0>518200`B400300lE4`0>51802a4?
00803Q@B01`02a4?00`B400@5Q80314<00dB3P0;40`03A8>00/A3`0=4a4031DB00hG5P0=5QD0218A
00H@4@064Q80@e5B010K7@0=5aP04ATG00T?3@0:3`/0310?010D4`0;3a002a4D01/S9P0@61/03Q<B
100>4Q402P0;3`h05ATH0045100<40l0720O01XN7@0:3``02a0<00dB3P0<4@d200X?2`0Q00dB3P0>
4`l03Q<?00dB3P0<4@d02a0<00hC3`093PX03a@@00L<20083@T04aPD00X?2`0=4Ph02a0<00hC3`0<
4@d01``8018G3P0;4@<0318800dB2P0=4P`0314=01<H5@0D61L02Pl;00H;1@0J7aT03Q<<018G4@0D
6A<04AH@00802a0:00T02Pl900lD3P0>4`d02a0:00X?2@0;40X03A8<00/@2P0<4@/00P0=4P`200`A
2`0800X?2@0J7aT010T300`A2`0730H02@h800T>2P0:3`/200dB3P0h00`A3@0;40`02Pl;00`A3@06
2`L04QLC00dB3P0@5A401``6024V800E6Q@01P/500X?2@0>4`d04QLA01HK5@0D6A<03Q<=00X?2@0<
4@/000@005QME`1;D4X03Q<=00@90`0K81X020d700lD3P042@<00PL101@I4`073@T01a0=00TC4P0>
5aH0214>01DN6`0@5Q803aDA010D3`0@4Pd03a8;010B2`0>4@X041D?01PM5`0?50h01``600`A2`0?
50h04AH@010E3`0<4@/02@h800/@2P0=4P`200dA400400hB4@0;3`h02`l>00`@3`803Q8A0P0?4a80
0`0=4A003Q8A00`@3`0200`@3`803A4@00<03Q8A00`@3`0>4Q400P0>4Q406`0?4a804ADD014E500H
71/051PG00H:2@0A5A@02@d<01dQ800K7ah03a<B014E500<40l0310@00/?400=4A803Q8C00`@4@0>
4Q<02@d>00hB4`0=4A803Q8C028V9`0I7Ah041@D00`@3`0300hB4@80310?00@03A4@00lC4P0A5A@0
3Q8A100;3`h02`0>4Q4041@C00hB4@0A5A@092PW00hB4@0;3`h00081014E500:3`/02a0<00D03A8>
0`0<4@d01@0>4`l041DA00`A3@0;40`02Pl;00<02a0<100=4Ph0400<4@d02a0<0088100<4Ph041HB
00`B3P0C6AD02@l901LN5P0940P072<K00XB1`0F7Q<01@`400L=2`0@5QD201DK5`0@01XQ6P0S:R80
5A`D00D:1@0?5Pl020h<00X@3`0=4a<05Q`J00`B400=4a401`d;00P>2`0A5a<02a4=00/B30<02a8;
00<031<;01<H4@0@5@l00P0=4P`01P0>4`h03Q<?00dB3P0=4@l02`l>00`@3`803A4@00L05AXF010E
4@0A5Q803A8>00D:1P0>4`l03A8>0080314=01H03Q<?00lD400A5Q80314=01XO6`0730P041DA01DJ
500b=c403a@=00dB2`0<4@X03Q@:01<I3`0E6a4041D>00dB300<4@/02a0:00`A2`0=4P`0314;0P0A
5Q0200dB300300hC3@0=4P`03A8<00<03A8<00@0314;00/@2P0<4@/03a@>0P0@5@l00`0?50h0314;
00`A2`0200dB30803Q<=0`0=4P`03P0>4`d041D?00lD3`0<4Ph03A<?010F4P0?5A40318>00X@3006
30P08bTU00lE4@042PH02Q0<0P0C61@0200?51003Q<?00lD400>4`l04aPD010E4@0>4`l03a@@0P0@
5A40100A5Q004aPB00/@2P0?50h200/@2P06014F400<4@/02a0:00`A2`0;40X041D?0`0>4`l300dB
3P0J024V8P0320@01PX604E:AP0=4Ph05a`H018I4P0E71D03A<?00lE4@0>51403Q@B01@J600@5QD0
92XZ01<I6@093a005alQ00/E5`0?6Q/031HG00/E5P0@6AT03aPG010F5P0@5A@200lC4P0301<F5@0F
6QWooooo01?ooooo000Kooooo`0600d<4@0>3A8020L<00l>4`0j>Ch030/@0P0>3A804@0:2@h01`H;
00P7300=31403PdB00l>4`0;2Pl020L<00X93P0C4QL0;Rdb00d<4@0<2a003PdB00X93P0C4QL030/@
00803@`A00<03PdB00`;400;2Pl00P0=31403@0<2a002PT>00`;400=3Q80>Si4014D7009318030lD
00T:3`0:2a0030dA00X:3@0;2`d00P0>3Pl00`0=3@h03@hA00`=400200/<3`0;00`=400=3Q402``?
014B5@0?41<0414D00h?4P092Ph04a@H018C5`0@4AD00P0;31000`0A4QH03PlC00h?4`0200l@5007
010A5@0A4aH02`lA00T=3`0?4aD0310B00hB500200lC5@0e018F600J7R00CU9D010C5@0D61T08RHV
01XN7P0?4a@05ATK00dA4`0H71l06AdQ00`?4`0<3a@051LM01<F700=41T051LR018D800H6RH05aTU
00h@70051a<0;2hj00h@700=3a`03a4N01HH900B5ah04QLL014F700@5A`041DJ014F70062A00724V
0497C@0@4a/05AXO00T>500?51P04aPL01HK7`0H7B406QlT01@I7P0@5AX03Q<H010E6P0F6al05Q/P
014F6P0?4QP0100@4aT0500?4QP03Q4G00d@5P0D5ad09bX`01LJ800>3QH061HQ014@6`0;2a@07R4Y
030e>P0A5aX04QPM01<H7@0?4QX030`E00d<5`0C4A/04a@I0P0A5AP0=00C5aX05QXM01HJ7@0C5aX0
6alR01PL7`0C5aX04QHI010D5`0@51H03a<G00d@5@0<3aP051HQ00lA7P0>41h03a4N010B7`0O8B`0
41<L01TL900F62003Q0H01DG7`0F62403a8L01<E800D5b<03a<N028V<@0B5b80:2di00X>6@0C5Qd0
4QDM014D6P0@4aP03Q4F00hB5P0;3a80310B014E5P0?4a@0310@00hB4P0>4Q<051PI014E5P0?4a@0
3A4B00/?400>4Q<200lC500901HI6P0@51D0:2`]00lC5@0B5QP04ADG01<G6@0B5QP041@F00D03Q8D
02H03A4C00X>3`0F6Q/03Q8C01XN7`1LH64082@U010D5@0>4Q<0310A00/?400<41404QHG00441@0?
4a@04QHG00X>3`0830d03a<D00dA4P0<41402`l@014E5P0B5QH04QHD00850@0>4`l02Ph<00P=2P0C
5aL04QHG00lC500=4A@03Q8F010C5`0@51P03ADG00`E5`<02a@F00h031DG00dF600=5QP02Q<E00TB
500M9RP0?4E700`A500:3a402@hA01<H700A5QX03A4F00hC60803Q<G0P0>4aH03@0=51D02A<B00XE
500<5aH03ALF00/E50084Q404APH01<J6P0=4a<02a0@010E5P0D6AX00P0?5A<01@083P`04QPF00/A
3`0?4a403a@B00803Q@B00D01``:00hD4P0;4@l02@l=00hD4P0200dC4@0500hD4P093`d051XH01dS
8@0C6AL00P0;4@l00`052`T0318@010F500200X@3P0Q00dC4@0>51802a4?00X@3P0@5Q@04ALE00/A
3`0<4Ph020d801HK5`0<4@d08RLS03m5@`0C6AL04a`I00PA400;51<031HE00PB4`084aD0DF1S00@B
5@0<5aT0218B00P?3`0A61L02a0?00/@4P083a403QHJ00@=4`043A403a@C00@03a<B00T041@C00X>
3@0?4a802@`;02hb<@1;Cdh0310>00lD400>4`l00P0:3`/00`0<4@d03Q<?00/@300200/@30802Pl;
01X0314=00P=2@0?510020`900/@300D6AD02Pl;00L<200>4`l02@h:00/@300110403A8900`B100<
4PP0318:00`A2`0<4@d03a<A00P:2@0?51001@T401`Q6`0>4``03Q<=00dB3@80314<00<03A8=00lD
3`0=4Pd00P0=4Pd200`A300300/@2`0;40X0314;00803A8<0P0<4@/09`0:3`T0<CH`038g<@0<4@/0
41D?00`A30093PX02a0<00dB3P0>4`l03A8>00`A3@0D6AD0GF9N04I;A`072`P03a@@00P=2@083@L0
3Q<=00`A2`0=4P`03a@>00`A2`0>4`d05AXD01@I4`0?50h0314;00hC3@0?50h04QLA00hC3@0<4@/0
3a@>010E3`0=4P`041D?00dB300200`A2`0A01LN6`095QL03Q`N02<`<P0>6Q/02aHF00dF500<4Q00
2a4<00`>2@0<3`P03a0900lB2`0L7aX08BHP01@I4`0;40X00`0@5@l04P0>4`d041D?01DJ500C6180
41D?01HJ6@0;3`h0310?00dA400:3Pd02`l>00dA400<40l041@C00hB4@0;3`h03Q8A00hB4P80310@
02803Q8B00lC4`0@51@03Q8B010D500?4a<03Q8B00lC4`0@51@041@C00T<2`0=4A002@d<00H:2@0G
6aX0<3@c02<W9P0:3Pd03A4@00P<2`0>4Q80310A00dA4P0?4a@02Ph?00/?400?4Q<04aLH01@G600A
5AH0A4Q902P/;@0<41003A4@0`0>4Q4200dA40<03Q8A01003A4@00`@3`0=4A003A4@00`@3`0>4Q40
3a<B00`@3`0H71/06alN018F5@0>4Q401`/:00lC4P0:3`/02a0<0P0=4Ph03P0>4`l03A8>00dB3P0<
4@d02Pl;00T>2P0;40`03A8>00lD400=4Ph02Pl;00`A3@0>4`l03A8>0`0>4`l0;`0=4Ph0314=00/@
30093`/04QPD00@:1P0C6AD000@0014H4@0:4@T03A@<00/B2P0F7Q@02a<9014H400;40`03Q8@00dC
3`0=4@d03A8<00hD3@0520@0;S<]00T=2P0=40d0310>01@I5`0>51802@l=00/A3`0A5aD03A<@00dC
3`0B61@04ALB00hE3P0<4``02Q4900P?1`0>4`d03Q<<00dB300<4@`02a0<00X?2`0<4@d03Q8?0080
3Q8@00H03A4?00`@3P0A5Q8020d900H;1`0@5A4200X?2`06010E4@0;40`03Q<?00`A3@0;40`04AHB
0P0<4@`0100A5Q408RLR01<H4P0;40X200dB2`0500`A2P0;40P03Q@;014F3`0?50h00P0<4@/0100=
4P`03Q<=00lD3P0=4P`200hC3@803a@>00<03Q<=00dB300=4P`00`0=4P`200hC3@0300lD3P0@5@l0
3Q<=00803A8<100>4`d0200?50h041D?00lD3P0=4P`0314;00hC3@0?50h03aD@0P0>51002P0=4`l0
318>00`B3P0=4`l0318>01LM6@0>51004ALC00P>2P0A5Q8200/@300600dB3P0@5A404AHB014F4P0?
510041DA0P0B5a<02@0?510051TC00`A2`0?50h07b@N00/@2P0?50h04aPB018G4@0201HK5@04010E
3`0>4`d041DA010E4@803a@@0P0>4`l07P0:3`/051TE00dB3P0>4`l04AHB00hC3`0P9b00:C0Y00lE
4@0G7AT07R@Q00lE4`0=4a40=3Xi00lE5@0D6QX02a4B018J700951H03Q/K00/H600:5AH03QLG00dF
5@0=4a<04QHE01<F5@0C51<04a@D01HG5QCooooo000Kooooo`0G01LF6`081``05aHK00D42@0>3A80
2@P=00h=4P061@X020L<00l>4`0>3A8020L<00h=4P040`P03PdB01<B5`0<2a002PT>00811P0920d0
3PdB00l>4`0<2a000P0;2Pl00`0=31403PdB00h=4P0200h=4P0:01LF6`0F5AX04a8G00h=4P0<2a00
30dB061SJ`0l?dP020/D00P;4P803@hC00L02``@00X:300:2P`03@d=00d=2`0=3@d02``>00802@X<
00l02P/=00`=3`0=3Q003a0B01LH6P0D5AL04a@F014B500;30l08B8V00<4200B4aL00@8601dN8P0E
5QX00P0?41@0>P0@4AD04A8F014B5P0>4A@04ADH01@H6`0>4QD02`lB00X>4@0;3a80310C00D9300h
?3l0Zjnb03Di?0093@l05QXI010D4`0G6a/051PI00X>3`0@51H0310C014E600D5a/04QDJ014D6@0I
72401`X?01HI800E61l04QDL014D6`0T9c0010L@01HH90051a<0418N01@F8P0:3QL03A4J018F7`0A
5Ah03A4J00X>5`0F6R<01PXC02<W<00=4AX02PhG01HJ8`0A5B004QHQ00lC7P0@51l05QXU01DI900G
6bH201@H8`8061`W00@041@O01DH8@0D5ah04A@K0P0?4QT07@0@4aX02@`C014D6`0L7bH0:B`c014D
6`0J7B@03PhH01DE800C5Ql03A4J00/@6@0@5ad04APP00lE7@0@51d04aHO01@C7P0?3aT03a8G018F
6@0G6ah03a<F010D5`0830l01`/>018F6@0A5AP0310C00803A4D01D07b<T00H:300@4aP03a8I00h@
6`0D5R804A<P01<E8P0H6RH0X:>/08J9T00H6b805QTR00X=5P0A51d04QDN00`>6P0A4al0418N010D
7`0>4Qd00P0A5B007`0C5b805QTR014D7@0@4a`041<J00lB5`0=41D02PhA00`@4@0A5AH03a<B00`A
3@0=4Ph04aLH00L;300<41404ADF00/?400830d04QHG00861`0@51D020`=01dQ8P0f>S/04ADF00X>
3`0=4A80310A014E5P0B5QL00P0>4Q<0300=4A803Q8C00hB4`0A5AH010P901@H6@0=4A80>3`m0<C8
b@0l@4404aLH014E5P803Q8C01X03a<D00`@4@0N8R<09RX[010D5@062P/05QXK00`@4@0@51D03A4B
00lC500G6a`02`l?00`A2`0G71D01PX601lT800>4`l020`;00dA4P0D61T04ADH00T<4@0>4AH02`lC
00dE60802aDG00l02Q@F00/E5`0<5QP010h@00/E5`0?6A/02A<E01XT9P012`d02@hA018G6P0C61/0
1@X=00@9300>4aL00P0:3a<01P0:3a802a0C00/@4`083Q4041TH00dG5P<031HE01D02a@C010F5P0=
4a<041HF00lC500;3a004ADF00T?3@0<4Q002Q0>01TO7@0B61H0IVaZ02H/:P0;4@l020h<01PN700>
51801`d;00P>300>51800P0=4a406`0>518020h<00D;2@0D6QP03Q@B00X@3P0@5Q@0318@01<I5`0@
5Q@02a4?00lE4`0=4a401`d;00/A3`073@/04ALE01DK6@0;4@l01`d901@I500;40`00`P406I[I`2G
WI/061hL00`E4P0200/D4`0@00D?3P0<5QL05b8T0;k>dP0[>C`04AlP00L=3`0=5QD02a@C00L=3@03
2`d041PJ030i?P0F8BL07RL/00dB4@@03A4@00T03Q8A00dA40062PT04QHE00@81`0;3`h03Q<@018G
4`0@5A400P0;40`00`0?510041DA00`A3@0400`A3@0400hC3`0:3`/01@X600`A3@802Pl;01@041DA
0002000=4Ph01P/701<H50093PX03A8900dC1@0<4PP02a4900/@2P0<4@d02Pl<024U900>4`l061dG
010E3`083@H04QLC00hC3`802a0<0P0:3`/0200;40`0314=00hC3`0>4`l0314=00X?2`0;40X0314;
0P0=4P`200`A2`0800/@2P0>4`d0;c@^020U7`1JGeT041D?00dB3P0<4@d200X?2`0900`A3@0?5100
20d9038g<`0/<Bd03a@@00D:1P0?51004AH@00803a@>00@02a0:00P=1`0A5Q003A8<0P0:3`T07@0=
4P`041D?00lD3P0V:bD0=S/e01DJ50093PP03a@>0005000;40X02@h800D:100B5a404AH@00dF4`06
51D0:3Tm0<?Be@2T/[D07RX[00/E500<4Q80314=00/@2P0?40X04A8;018E300;3`T04aPB00802@h8
0P0C6180600_=2h04QLA00`A2`0E6Q@041D?00L<1P0T:2L02`l>00T=300<40l02`l>00dA400;3`h0
2Ph=00lC4P0=4A002@d<00dA400<41402`l@00X>3`0;3a003A4B00hB4`804ADF02X03a<D00X>3`09
3@h02Ph?00/?3P0C5aH02`l>018F5@0J7Qd00PH501@H5`093@`03A4@010D4`0420L04aLG00`@4@0=
4A803a<D00P<3@093@h061`M00010P0:3Pl08RHW02X^;`0B5QL03Q8B00hB4@0<40l02`l>00`@3`0>
4Q403a<B00dA400;3`h03A4@01DI600M8B0061`K00hB4@0=4A0200hB4@0700/?3P0B5QD01`/:00/?
3P0830/03A4@014E500300dB3P0?00`A3@0;40`02Pl;014F4P0?5100314=00X?2`0;40`03Q<?014F
4P0=4Ph02Pl;00dB3P0?51003Q<?00<03a@@02P03A8>00`A3@0;40`051XF0002000E6aL01P`801DK
5`0/<b`02Q49010G3`0B6A40R92503U1=P0120003Q0;00d?300@4Pl04aDB01DG4`0E5a80828M00/=
2`0?4@h02@/800lA3P011P802`l>010F500:40h03A<A010F4`0Q9b<04aTE018H4`0?5Pl03A@=00/B
2P0940P03a@>0P0@5@l08`0?51003A8>00X?2`0:3`/03A8>010E4@0?5100314=00X?2`093@X03A8>
01LL600:3`/06b0L00H;1`0C61@05AXF00hC3`093PX0314=00hC3`0=4P`03a@>00D:100K81X000D0
01DJ500>4`d04AH?00lD3@0<4@X03A8;010E3P0:3`T03A8<00803a@>00<03A8<00`A2`0?50h00P0:
3`T2010E3`0300hC3@0=4P`03A8<00<03A8<0P0;40X03@0=4P`041D?010E3`0@5@l04AH@018G4@0A
5Q0041D?00dB300<4@/03a@>010E3`0>4`d00P0<4@/02@0>4`d041D@00lE4@0>51002a4=00X@300=
4`l041HB01@J5P0200hD400601XP70042PH04aPD00lD400=4Ph03a@@0P0A5Q82010E4@0501@I5@0F
6aL05AXF010E4@0C61800P0>4`d02P0O91h03A8<00lD3P0A5Q003a@>018G4@0E6Q@04QLA01@I4`0@
5A4200lD400Q00hC3`0=4Ph03A8>01LL60001@402a0<01/P700=4Ph03a@@00L>1`0<4``04aTE02hd
<00k@3d04aTG00L=2`0?5A@000D501@J6P0>4aD0210B00dK700A820031XJ00/G5`0<5QH02A8A00T=
3P0@4a<051HE018B4P0@3`l04@l@01Cooooo000Kooooo`0600L62`0;2Pl040lD010?500>3A802PT>
1P0;2Pl050020@H05A@I03Lf>`0C4QL030/@010?50061@X02`X?00h=4P0=314030/@00d<4@0920d0
40lD00H52P0C4QL0?Se202`[<00>3A803@`A0P0>3A800`0<2a002@X?00`@600200d@6@0K00/>5@0:
2a002@X?010A5@0820X04Q8D00`<30051@<03`l?00T:3@0:2`l01`P<010A5@0E5QX03PlC010A5@07
20`04Q<G0411A@0:2`l051DI00h?4`0<3A405aPL00421P0>3a<0:R/_00D0414E00D030hB01HI7P0D
5a`02PdB00D83@0200lB5`0i00011P0>4AH0<cHk0:2SZ00L7b@03a<E01/O7P1RIVD0310@00P<3@00
0@804aLI00/?4P0?4aH041@H00`?500?4QL05a/N02@X:@0;3a007R8S01PL7@0>4QD04QHI00dA500@
4aP05APM01HI7P0B5A/041@M00`@6`0?4ah051PS018F8@0@51l01`/F00lC7P0J7RT0310K00P<5`0>
4Qd02PdL06Q[O00f>DX02`hO024T=@0E62T051LX00X=7P0b=DH061//01`O<00F6BT05QTR01@G7P0A
51/03Q4H008041<J01@030lF01<F7@0D5ah041<J00lB6@0C5Qd02`/E01DE7`0B5Ah07b<^00lD7`0:
4aX01a0I00hD7P0H72L03Q4J00d>600=3AD04QDJ018F6@805ATL0P0A5AP03@0<41<03a<F00lC5P0=
4A@03a<F01@H6`0@51D03A4C010C600A51/0418M01@F8P082QH00P0F62@0<P2=T9T0GV5X01HI800=
4A/04ADP00X>6@0>4Qd04aDQ00`>6P0@4Qh03A0I00`?600=41T03Q4J00lB6`0C5Ql041<L00X=5P0@
4aX051LL010C600C5aX051PI01<G600A5A@0314=00X?2`0?4a@00`L8010D5@0:3Pl04ADF00lC500>
4Q<041@E00hB4`0A5AH04QHG010D5@0M8B80=3Pi00lC500D61T01`/<01PL7@0<41401@T:01`P8@0C
5aP02@d>0`0>4Q<01P0@51D05ATJ01PL7@0H71d04QHG00lC50803Q8C01H03A4B00T=3P0F6Q/0R8b=
02/_<0072``07R8S03Tm?P021PL06alP00P:2`0@51D02Ph>00P=1`0;40T02@h700/@2P0A5Q002Pl;
00/?3P0<40l03Q8C0P0>4QD03@0;3a@03ADH00TC5@0;4aD01@lA00/E5`0B71h010h@014K7@043Q00
4adO04QBE0043Q000P0>4aL0100?51L03Q<F00`A500:3a8200hC5P05010E600D6A`051TL00hE600;
51<00P0=5QD01@0;51<02Q8A00`B4P0;4A403Q<C008041@E00X03Q8C00`@4@0>51804aTG014G5@0?
5A<04QPF01DK6@0G7A/02a4?0P0<4Q003`0;4@l05adK00`B40083P`04ALE010F500;4@l05adK00T?
3@0A5aD02a4?00D;2@0E6aT01`d;014G5@0200`B400Y014G5@0?5A<02a4?00dC4@0>51803aDC00hD
4P0<4Q00318>01<H4`0>4`l0314=01@I5@0G7A/04QPF00PA3P0330/02a@C018L6`0<5QL02QDG06Ig
NP0M:bh00@l@00LA4P0<5A@010d<00T?3`0841800PX<01@M8P2Y];X0UYnT01@I6@0B5QD01`/:018F
5@0;3`h02Ph=00P<2`062PT00P0=4A002@0;3`h03A8?00T>2P083@T0314=00X?2`093PX02Pl;00T>
2P0200X?2`0500/@300>4`l0314=00T>2P0@5A400P0;40`08@0=4Ph01P/700D:1P0B5a<02a0<0005
0@0@5A404aT@00H<000220003Q<;00/@2P093PX0:2`Z08:6Q@0C61@0314;018G4@0H7AL051TE00hC
3`0=4Ph01@X601lT80062`L01``8010E4@0:3`/082DQ00T>2P0S9b@0>Sli00/@2P0200dB300A00hC
3@0A5Q0010T300`A2`0?50h03A8<00lD3P0<4@/0314=00/@300;3P/061dI00P=2@0?5100314=00hC
3`0?51000P0<4@d01`0>4`l02a0:00dB300:3`T01``600/@2P0B5a400P0;40X0300?50h03A8<00/@
2P0D6A<05a`F02<X8P0A5Q003a@>00`A2`083@L07B8L018G4@803Q<=01/02Pl900L@3@0651D0=DI:
0=k]l030c]405b<T00lI600630`06AhJ014F400D5@l0>c`e014D2`0;3`T061dG01@I4`0<4@/06QlI
05eRG037c<H08RLQ00X?2@0B5a403A8<00T>200>4Q400P0;3`h02@0=4A003Q8A00hB4@0;3`h03Q8A
01TM700@51<03Q8A010D4`0300lC500300dA4P0:3Pl020`=00<03Q8C02L041@E01@H6@0E6AX02`l>
00dA400<40l04QHE010D4`0>4Q403A4@00D9200A5A@02`l>00hB4@0=4A402`l@01DI6P0@51D01PX;
01DI6P093@h04QHG014E5P0C5aP04ADF00dA4P0D61P04QHE00hB4@0:3Pd02`l>00dA400@51<03A4@
01HJ6@062PT082@S075eM00G6aX00P0=4A001`0;3`h02Ph=00dA40072`X02`l>01DI60093@`00P0<
40l01@0B5a<03A8>00T>2P0;40`0314=00803Q<?00L02Pl;00P=2@0>4`l04AHB00dB3P0:3`/02a0<
00803Q<?00D03A8>00/@30062`L020d900`A3@0300dB3P0A014G4`0=4`l02@l;00@:1P0;4@d0;SD^
00dD300940P05ahF03Y2=`0L91T02A08010B3@0A4`l06Q`I01<E4P0=3``00P0B51403@0=3``04A<@
010B3`0;3@T0314=00H:2@0;4@l02Q0>00dC4@083P/061hJ00hD400>5@l00P0530D01@0<4``02Q49
018G4@0:3@X02a0<00802Pl;00P03Q<?010E4@0>4`l04AHB00hC3@083@L02Pl900dB3P80314=00X0
3A8>00hC3`0>4`l04AHB00/@300=4Ph04aPD018G4`0?51003Q<<0P0=4P/0400?50d041D?010E3`0<
4@/02@h800P=1`0D6A<01``600lD3P0A5Q0041D?018G4@0;40X020d700hC3@0A5Q0200/@2P0K00hC
3@0?50h03A8<00hC3@0?50h02a0:00P=1`0;40X04aPB01TN600F6aD041D?018G4@0C61804AH@00`A
2`0:3`T0314;00L<1P0:3`T041D?00lD3P0>4`d0314;00/@2P0<4@/02Q0;00803Q@@02T02@l;018H
500@5Q803aDA01LM6@0D6QH03A<?00hD400E6aL06R0L00<8100C61@0008001DJ5P0D6AD03Q<?018G
4`0:3`/02a0<01DJ5P0>4`l041D?014F400B5a403a@>00hC3@0@5@l03A8<00/@2P0>4`d04AH@00hC
3@0?50h020d901DJ5P0A5Q804aPD01@I5@0B5a<04AHB00lD400200hC3`0J00dB3P0A5Q803A@=00`C
300<4Ph03aDA00lE4P0<4Q005Q`J00`B4@0D6QX02a4A00`A4`0E7Al01aDF02He=@0@7Qh0>DE501XT
900E7Qd04QHG01DH600C5A@04a<C01DD500A3a0Dooooo`006oooool01P0?3Q<03@`A00`;400;2Pl0
3@`A00h=4PH02`X?00T03`hC00T83@0;2Pl05A@I00`;400A41D03`hC00`;400;2Pl00`0<2a005@0>
3A802@P=01TH7@0920d04Q4F014@5@0;2Pl01`H;00`;400E51T051<H00h?4`0;3a@02PdE00X=4`09
31402P/@00T:3`0:2`l030`?010@4P0200l?400C01@D5@1@DED01@H;00`=4@0?41D00`@800h?500>
3a<05AHJ01DF6`0<3A804a@I00T:3P0C51P03@hB00`=4@0@4AD03@hB018C5`05010A5@0K010B5`0<
3a@03A0E00lB5`0G6Ql020/@00d@5@0E61d02`hC00hA5P0V:Bh030lD018F600;3`l04aLG010D5@0C
5aT01`/=00d@4`0<3a<05a/O01LJ7`0=41H04aHL02da=00k?ch061`K00803a@A00X05ATG01@H600:
3Ph04ADE00dA4@093@d0>Cdn028W;P0F6R@03A4K0P0D62805@0>4Q`041@N00dA6`0J7BL0HVI`02@X
<P0V:S@09BPh03m2E00Q93H04aHX01DH:P0B5BL06ah`09:EY`22QIL05aX/018E9`0B5BD03Q4J00hA
5`02014D6P04010C6@0>4AL04A@J010C6@803A0F00P06ahT02X]<`0D51/05ALO01@G800H72L041PR
00XC7@8031@N00D020`G00lB6`0E5al051DK010C5`05010D5`0L018F6@0C5aX04QHI00lC5P0@51L0
4QHI01@H6@0A5AH04QHI018E6P0?4QX04aDP014C7`0:31L04QDN01TL900I72<05QTP01<H8`0G72L0
4QLR01PL9`0M82/05aXU00d?6P0?4AX0414K018D70804aDM02403Q4H00lB6P0=41H04A@I00lB5`0:
3Q803a<F010D5P0A5AH03a<C00/?3`0:3Ph03Q8C00dA4P0D61T020`=00X>3`0?4a@05ATJ01LK700>
4Q<02`l@00`@4@0>4Q809RXZ01hR8P0C5aL02`l?01TM7@0L82006AdM00`@400>4Q800P0<41002P0?
4a@03A4B00`@4@0<41403A4B00lC500@51D03A4B00`@4@0=4A8300lC500C01@H6@0?4a@041@E00hB
4`0G6a`0N7am00lC500;3a003Q8C01dQ8P0>4Q803a@?018G400?50d0314;010E3`0@5A403A4?00hB
400200lC4`0800hB500=4Q@02PlA018K7@0>5aT09Bh`09FNX00c?3h200hG6@0400hF600f?d40FV=U
00lH6P804AHJ00L04QLK018G6P0A5QT03aDF00hC5@0=4Q@03a@G00804QLK00@03Q<H00XB500<5QD0
31DD0P0<4a<0200>51@03A8B00hC500?4a@041<D010B500=4A803Q@B0P0;4@l01@0>51803aDC00/A
3`0;4@l041HD00801`d;00`041HD00/A3`0@5Q@03A<A00hD4P0:40h04QPF02hd<P0@5Q@02Q0>00hD
4P093`d200dC4@803aDC0P0>518200dC4@0800lE4`0<4Q002Q0>00X@3P0<4Q003A<?00dB3@0@5A42
00`A3@0Q014G5@0B61H03A@A00H?3P0<5A@0@de<00/E5P0E82804R0S008@4`033Q0031HF00lF5P07
3`d02@h>01@I6`0@5QT03aLJ03m8CP0W;c<041DD020T8`0A5A@01`/:00H:2@0@51<02Ph=00P<2`0>
4Q403A4@00`@3`0>4a003a@@0080314=00L041DA00`A3@0<4@d03Q<?00/@300>4`l04AHB00803Q<?
00L02Pl;00dB3P0<4@d020d900lD400>4`l03A8>00802Pl;02l05AXF01@I5@0=4`X020h100`B200J
81P051TC00/@300;3`d0=3Pg00X>2P0F6aD04QLA01LL5@0=40d02`l=00lC4@0B5Q@010T600hB400=
4@l041@B00dA3`0=4Pl02Pl<038f<`17C4H061dG00X?2@052P@02@h800dA30083@L03Q<=00lD3P0<
4@/03A8<00`A2`0@5A402Pl;00lD400J7a/02@h:00X?2`0<4@d03A8>00lD400200hC3`03010E4@0=
4P`03Q<=00803a@>00@03Q<=00dB300>4`d041D?0P0;40X0;`0=4P`02a0:00T>200B5a401``600`A
2`0>4`d02Pl900dB300G71H04AH@00/@2P0?50h02Q8>00LD5@0@7Al0=45202Hc=00:5AD02a@B00/A
3`0`=C008R@O010C300C50d02@/700lB3@0;40X0314;00hC3@0T:B<0Be1:09FJU00J7aT04AH@01LL
5P0<4@/04QLA014E500=4A002`l>00dA400<40l02`l>00X>3@0D61L0720O00802`l>00T03a<B00hB
4`0>4Q@03a<E00hB500<41802`lA014E5`0?4aD00P0>4Q@02`0@51H041@E018F5@0>4Q402Ph=014E
500C5aH041@C00dA400;3`h041@C00803A4@00P03Q8B00X>3`0h?3d01PX;01@H6@0:3Pl0310A014E
5P803Q8C00@03A4B00T=3P0?4a<0310?0P0;3`h01P0=4A003Q8A018F5@0;3`h041@C018F5@80310?
00d03a<B00dA400>4Q403A4@00`@3`0?4a804QHE00/?3P0<40l03Q8A00`@3`0>4Q4061dI00803Q<?
00<04aPD00dB3P0<4@d00P0;40`0100=4Ph041DA014F4P0>4`l200`A3@<03A8>03P0314=00hC3`0;
40`020d900/@300>4`l03A8>00T?2`0:40`041HB00hD400;4@d05QdF07AkL`0H7aL02A0800lG300C
6a003QH;01<I4P0;3`X03Q<?00H:1P0B5Q@020h;00X=3@0;3`d04QLC01DH5@0?50h03aD>00/A3@0:
40h04aTG01hT8P0<4Pl020h:00dC3`0=50h04APA01TP6@0L8a`03aH?01`Q7@0<4@h02`l=00dB3`0>
4Ph02Pl;00hC3`0;40`03A8=00/@2P093PP0314;00hC3`80314=0P0;40`200`A3@0600X?2`0<4@d0
4AHB00hC3`0;40X03A8;0P0=4PX02@0>4``03Q<=00hC3@0=4P`02@h901XO6P0;40/061dH01<H4`02
010E3`08014F400<4@/02Pl900lD3P0G71H03a@>00`A2`0=4P`200hC3@8041D?00H03Q<=00dB300?
50h04aPB01LL5P0E6Q@300lD3P80314;00D03a@>018G4@0=4P`03a@>014F400200lD3P8041D?01L0
4AH@00lD3`0D6QH05Q`H00hD400?5A403Q@@00/A3@0B61@05A/G01<I5@0?5A4041HB02T^:P0K81`0
7R<O00X?2`0:3P/041DA01DJ5P0@5A402a0<00lD4002018G4`0>014F400B5a404QLA00lD3P0=4P`0
3a@>018G4@0@5@l04QLA010E3`0<4@/04AH@00X>2`0H7AT2010E4@0:00hC3`0<4@d03A8>00hC3`0@
5A403A8>00/@300=4Ph01`h700XA2P803aDA01@03Q@A00lE4`0A5aD03Q@C01@J6P0630`05adN01@L
7P18DeD0cm_L05MTI00Q;2d07RPX00dF5@0D6QX03a<C018E500B4a<04a@C01lP7aCooooo000Koooo
o`06010?500=31402@P=00P7300:2@h03@`A1P0;2Pl01`0920d02`/?014@5@0/:c004a8G00D42@09
20d00P0<2a004@0:2@h030/@00h=4P020PH06aXO04i=DP0_;S<01PD:0000100>3A802PT>00`;400B
4AH03`hC00T:3P0=4QD02`hC00802PdB0P0=3Q801`0>3a<05aHK00l>4`0<2`l040lD00h=4P0Q8RP0
0P0<31@0300A4AT0410H010@600;2a<0>c]304=3B`0>3QH0000700l@5@0:2`l010D900l@50803@hB
00<04a@H00l@500?41@00`0?41@0EP0=3a@041<H01<F6`0=41D0CE1E01/N8`0B5AX05APM00021`0I
72405APM01@G700?4aL04ADF00L;3P0:3Q406AdP01/O8P0H6b002@`A00X=4P0?4QT041<J018E7P0:
3Q<01`/<00lC500<414041@C014E500:3Pd041@C014E4`0=4Ph04QLC00P=2`0C61`03a<L01DI8P0O
8b`06AdV00/?600K7bP0310I01PL9@1GFf@00@D>04]?F00`=4005a/W018F8`0F6BP0310L00lB800M
82l08RHb03DiAP0E62L051PT01hQ;P0=41L03Q8E010C5`0@4aP03a8F00dA500F6Ah05a/O01DI700C
5Q/04aLK01HJ7@0H6Ah041<H010E6`0>5Ad04aXU01LO:P0>5R402Q8K01HM9@0Q9R`02`dB01DF6P0?
4aH041@G0P0<41<01@0A5AP041@G014E600@51L03a<F00803Q8E01@03a<D014E5P0>4Q804QHI01@G
700C5Qh061/T03@f@P0D5b0041<L01<F7@0R9BX03A8H00hE800A5b<03A<O01<G8P0E6B@04QHQ018E
7P805ADO028051@L014A6@0@4AH03a<G010C600A51T04aHK010D5`0=4A@03a<F010D5`0A5AP04ADG
010D5`0?4a@041@E00P<3@0C5aP07B4R00hB4`093@h05QXK01dQ8P0B5QL0310A00hB4`0B5QH07R8Q
014E500=4A001@T800lC4P0830/03a<B0P0@51<00`0D61L05QXI014E5@0200`@4@0500dA4P0@51D0
4QHG01<G600@51D00`0>4Q<04`0=4A802@d>01TM7P0E6AX04aLH018F5`0:3Pl00PH700L;300S9bP0
4ADF01DI6P0>4Q802a0<00/@2P0;40/03A8<010E3`0?51000P0>4`l0400?51003a<B00hC3`0>4a00
0PP800L@3`053@h03ADG06I_KP0Q:RX031@F018K6P0@61P031@F010I600B6Q`200dB600400hC5`0>
4aH03Q@D00hD5080318B00D03Q<F00lD600>4aL03A8G00TA4`0200/D4`0300`B4P0=4a<041HF00<0
3Q8C0P0@4A<01@0>4Q<03Q8A00/A3`0?5A<04ALE00803aDC01D03A<A00X@3P0?5A<03aDC00X@3P0=
4a402Q0>00hD4P0B61H03A<A00`B400J81h04ALE00P>300;4@l010X800X@3P0;4@l03A<A014G5@0@
5Q@00P0:40h200hD4P802a4?00L03A<A010F500B61@02Pl:00hC3`093PX02Pl;00803A<A01P03QLD
00dF5@0?61L0FVAS00<=3P064Q804AlP00LB50033@h01`l=018H5P0F6aL041@C00dA400420T01`d@
00D=400<51L041DD018F5@0:3Pd03Q8A00/?3P0@51<200/?3P0500lC4P0<40l0310?00/?3@0=4Ph0
0P0<4@d0<`0J7a/05Q/G00`A3@0>4`l0314=010E4@0B5a<03Q<?00T>2P001@40314=01XO6`0:3`/0
2@h:00X?2`0B5a<02a0<00`A3@0=4Ph01``800dB2@0:408041H<01/P600D6A<0314=00X>300A5A@0
2Pl;00`A2`0;40X02Pl90002000:3Pd02`l>014E501FFUT082@S00/?3P0010<0310?00/?3P0@51<0
1P/800@91@011P005Q/E00dB30062`D02a0:00`A2`0200hC3@802Pl901002a0:00P=2@0>4`l01@X6
00hC3`0A5Q801``800/@300<4@d03a@@00hC3`0?51004QLC00dB300:3`T0314;0P0@5@l02P0<4@/0
41D?00X?2@0A5Q005AXD010E3`0>4`d04AH@01@I4`0<4@/201DJ500R010E3`0730H03a@>00lD3P0;
40X0314;00lE4@0:4a001a0?014J6@0@6AH04AXG00P>2P0<4Ph02`h:0001000E61404A<=00/>1`0I
7QP03A8<010E3`0;40X0314;00@90`0B5a403a@>02@Y8`0/<B/041D?00P=1`0@51<0310?00/?3P80
3A4@00L0310?01DI600M8B008RHU01@H5`0C5aH04QHE0080310C00D03A4D00hB5@0>4QD03Q8E00lC
5P0200hB5@803A4D01H03A4B014E5@0:3Pd020`;00/?3P0=4A003Q8A00/?3P0A5A@03Q8A014E500<
40l02Ph>00hB4`093@h020`=01LK700i?Ch04aLH010D5@0;3a002Ph?0P0;3a00100?4a<02Ph=00/?
3P0=4A0200hB4@0E00L:2@0G6aX02Ph=00D9200E6AP010P700`@3`0:3Pd0310?00dA400<40l03Q8A
01@H5`0K7ah04ADD00<71P0=4A0051PG09nTX01QIV8051TE00801@X600P03A8>00X?2`0<4@d03A8>
00`A3@0=4Ph041DA00`A3@D03A8>0P0>4`l0600<4@d02Pl;00X?2`0<4@d03aDA00dC3`0<4Ph02Q0<
00T?2`0;4P/08BPP00H=1P0I81P051`A00hF2`0=5@X041L?00`C30063@H03Q@B00X@3`093`l02a4A
00dC4P8041HB01H03A@=00/B2`0:40`020h<00hD4P0F71X020h;00X@300?5A402Q4;00XA2P0A6140
61lG01HM5P0Y;RX04QHE00P<2`0?4a804QLD00/@300@5A40314<0P0=4P`01P0>4``04QL@01<H500@
5A403a@@00hC3`803A8>0P0;40`01@0>4`l041DA00dB3P0:3`T02a48008031880`0<4@X01P0F6aD0
2a0<0002000S:2@0X:FQ09JKU`803Q<=00d03a@>00hC3@0>4`d03a@>01@I4`0A5Q003a@>00dB300<
4@/04AH@01HK5@0D6A<03a@>00<02a0:00<03Q<=00lD3P0>4`d00P0@5@l200X?2@0B00hC3@0?50h0
314;00dB300>4`d0314;00dB300>4`d03a@>00hC3@0=4`h05A/G01TO6`0A5a<03A<?00`B3P0;4@d0
3aDA0P0D6QH04@0:40`01`d9018H50042@D04QLC01<H500D6AD05AXF01hS7`0B5a<04AHB01@I5@0;
40`03A8>00lD3P0@5@l04AH@00803a@>00d04AH@00dB300=4P`041D?00lD3P0=4P`061dG02H[9`2R
Yj<0=c`h01dR7P0>4`l03A8>00803a@@00H03A8>00hC3`0A5Q803a@@00`C300?5Pl201@J5P0D010F
4`0<4Q001`d;00lE500M8b<00PP801DK700P:2X0:cDg09NRX`12C4d031HG00lH600>5aH02a4A018G
5P0F6QT04aLF01DH5`0I7A`Dooooo`006oooool200`;40802PT>0P0920d600/:3`0J00l>4`0;2Pl0
2`X?014@5@0>3A803`hC00P7300D4aP05QDJ00`;400:2@h03PdB01HE6P0;2Pl05QDJ00T83@0;2Pl0
5A@I00h=4P0?3Q<03PdB00/:3`0:2@h02@X>00dB4`0;3a8200X>4@0J00d>4P0>3a<0414E01XI7`0@
3aD02`X@00h=4`0920h01@D?01<C7@0=3AL030`F00l?6@0:2Q@07QhX0;nob@39bM<0820Z01dM9`0?
3aH02@X>00`=4@0@4AD01PL;00X;3`0A4QH500l@5008018D6@0931<00`H=01DH7`1ZKG@0:B`c01PK
8P0E61l400`?5P0601LJ7`000@@06A`Q01@G700:3A8000870P0=41L0@P0E61l05QTR00d@6@0?4Ad0
4QDM01HI800D5ad02@`A00lB5`0D61/01`/<01<G600C5aL0310?01DI600?4a<051TM010E6`0?51X0
4AHL010E6`0D6Al00@H<00X?5@0>4aT07B8X00/@5P0?51X08bP^00lD6P0D6B004QHO00dB600?51/0
8BD^00011`0G6b<051PQ00L<4P0D62004aLJ018F5`0?4aD03Q8E00hB500?4a@0310C014E5`0D61T0
51PK018F600B5QL06QhQ00X>4P0?51X05A`T00P@6@074AX02aDN01<K901oQXh0PXN=01<G6`0C5aX0
2`lB00hB5@802@d@00<041@G00hB5@0?4aH00P0>4QD05P0?4aH041@G014E5P0A5AH03a<C018F6@0C
5Q/04aHN01PK901<CeP051LP00/>5`0?4QT03A0E014F700>5B403Q@R00/A7@0<4Qh03Q8M00/?6P0C
5Ql201DE7@0701DD700B4AL03a0E014E5`0>4QD03a<F014E6002010D5`0N00/?4P0<3a@030lD00dA
5@0=41D0310C014E5P0=4A801`/<00T=3P0420T04aLH00`@4@0D61T0310A00X>3`0>4Q<03Q8B00@8
1`0?4a802Ph=01DI60093@`0310?018F5@0G6aX04ADD010D4`0?4a803A4A0P0>4Q<01P0@51D04ADF
018F5`0C5aP04ADF010D5@804ADF01003a<D01<G60011@H020`=00lC500830d09b//01<G60052@X0
310A01<G60093@h03a<D014E500=4Ph03A8?0P0D6AD01@0=4Ph03Q<=00hC3@0>4`d03Q<?00803Q<=
00`04aTG01LM6`0B61L010X:00dC4@0<4Q4010X:00881P093`h05adM014G5@0;4A8200`A5`0B00`A
5@0<4A@0318B00dC4P0<4Q003A<A00hC5@0=4QH0314E00`A5`094A<031<C00`B4P0;4A403Q<D018F
5`0>4Q<03a8C0`0@4A<02@0>4Q<03a<B010F500A5aD02a4?00D;2@0<4Q001@/900`B4002014G5@04
00`B40052`T02Q0>00/A3`803aDC0P093`d0300:40h03A<A00P>30032@L05Q`J00lE4`0<4Q004QPF
010F50093`d02Q0>00hD4P80318@0`0=4a407`0=4`l03A8=00/@30093PX03Q<?00hD4P093`d031DB
00dF5@0<5A@04Q`K00092P094a@01Q8B00@@400640l02a8A00hC3`0<3PT04A<@01HH5`0?4a@03a@F
00031P0?51L00@<301DI600D61L03Q8A00H:2@0@51<00P0<40l02`0?4a802`l>00/?3P0<40h041DA
014F4P0?51007B8N01XO6`0<4@d03A8>00@03Q<?00H04QLC00dB3P0I7QX09BXV018G4`0>4`l200lD
400R00L<200B5a<03Q<?00D:1P0@5@`02a4300`B200A5Ph03a@>00dB3P093@/020`;00dB3P062`D0
3a@>00/@2P0J7a/0720O010D4`17BdX0hNGT038f=@0;3`h01PX901<G5P000`802`l>01PM6P0F6aL0
2Pl900T>200<4@/03a@>00X?2@803A8<00`03Q<=00/@2P093PP02a0:00hC3`0;40`02@h:02H[9`0J
7a/041DA00X?2`0<4@d200hC3`0300lD400B5a<03Q<=00802Pl902/03a@>01DJ500D6A<03A8<00/@
2P0Z;bT0;C8/00lD3P093PP03a@>010E3`093PP04AH@00lD3P0;40X04aPB00`A2`0A5Q0041D?00/@
2P0F6aD03A<?00D:1P093`/01P`800`B3P0:3`T01``601<E400<3PT05ALB00P:1@0G6A@07R<M00L<
1P062`D02a0:01DJ500:3`T05AXD01HK5@0>4`d03a@>00804AH@00@03A4@00X>3@0:3Pd03Q8A0P0?
4a8201PL6`0401dQ800F6QT051PG00hB4@<0310C00<03Q8E00lC5P0?4aH00P0=4A@05`0>4QD03a<F
00lC5P0>4Q<03a<C00X>3@0<40l02`l>00X>3@0;3`h01@T8010D4`093@`04aLF00L;2P0?4a<04QHG
00D92P0@51D02`l@02da<P0=4A803a<D00802`l@0P0>4Q<05P0B5QH03Q8A00lC4P0?4a803Q8A00`@
3`0E6AP04QHE0001000Z;Rd0008100X>3@0D61L03A4@00lC4P0@51<03Q8A00lC4P031`H01PX900P<
2`0I7A`200X>3@0602db;P0D6AD02@h:01XO6`0D6AD01@X60P0<4@d01@0;40`02@h:00/@300A5Q80
3Q<?00@03A8>01/03Q<?00T>2P0>4`l04QLC00/@300730P02a0<010F4P0>51002a4=00T?2`0;4@d0
3A@=0003000:4@T01Pd500hF2`0840H04QX?00LA1P0>60l00@/301HO70012PP01Pl>00`E500<5A<0
0P094Pd07P0;5@`02Q@;0088100@5Q@03aDC010F50083P/041HB00hD400;4P`02A0900P?200;4P/0
4QTB00/?3P082P/01`/<018F5@0B5a@01@X6010E3`0<4@/03Q<=00hC300?50d04aPA01<H500@5A40
3a@@00hC3`<03A8>00L03a@@014F4P0C61@03a@@00dB300<4PL0318800803A<900T02a0900X?2008
3@L04aPD00`A3@0C5aH0CE5@024V8P0>4`d00P0=4P`200lD3P0@00hC3@0<4@/03a@>010E3`0>4`d0
2a0:010E3`0D6A<04AH@00hC3@0;40X02Pl900T>200=4P`03Q<=00dB308041D?00<03Q<=010E3`0@
5@l00P0?50h00`0@5@l03a@>00lD3P0200lD3P0800hC3@0=4P`02a0;010F4P0E6aL041HB00`B3P0=
4`l200hD400>018H500D6QH0318>00`B3P0B5a<01P/700dB3P083@T05Q/G00`A3@0J7a/03a@@01<H
500G71P200/@300300`A2`0>4`d041D?008041D?00<04aPB00dB300<4@/00P0>4`d01P0=4P`05Q/E
03@i=@2d^KD0ADY601dR7P802a0<00H04aPD018G4`0<4@d041DA01PM6@0E6QH200`C300F010F4P0F
71P04aTF00/A3`0E6aT03A<B01/Q8@083Ph0314C01@I700=5AP0:S<e01XR900A6A/03QDF01LM7@09
3`l051XI00dC4@0;4@l051TG00lE4aCooooo000Kooooo`0600X93P0<2a003@`A00d<4@0<2a002PT>
1P0;2Pl200h=4P08014@5@071P/03PdB010?500?3Q<05aHK01PG700?3Q<200X93P0500T83@0B4AH0
30/@00d<4@0<2a000P0:2@h200h=4P802`X?00D03@hA00T>3@093@d02@d=00T=3`0200/<400H00d>
4P0C4QT03`hE00h=500=31D02PTB00d=6@0821D03`hK00h>6`0<31T04Q4N018B7`17Ae@0Bd]H00d<
6@0G5R<030`D00T:3P0?41@03@hB00l@500F5a/03@hB1@0>3a<09P0?4AH02`hE00d@5`0B5A`06A`S
00D83`0@4aX02`hE00`?5P0;3QD061/R00T<4`0m@4L07b8X00hA5`0B5A/05aXP01<F7P0>4AT04aDP
02T/=P0S9C402P`I00lA7@0A4R006AXY00h@7`0>41d04Q@O00hA6`0A51/01`XA00lC5`0V:Rd09b/]
010D5P0?51P03a@I0P0E6Ql0600=4QL02a0E01HK800?51T04AHK00H;400@5AX041DI00dC4P0D6QL0
5ahJ00lE4P0B61D04APD00P?2`0H7Q/03aDB01HL6@0G7AX020d:01<G5`0B5QH03a<C00dA4@803Q8B
01@05ATI014E5@0=4A40310@00hB4P0@51@02@d=01@I6`0@5AT03aHL01TS:`2FX:T0CeUR01<L900U
;3808BHZ018F600;3a003Q8E01DI708041@G01/061`O018F6@0B5QT041@G00lC5P0B5QT04aLJ018F
5`0G6aX04QHF01<G600A51T03Q4H014D7@0B5Ah07R4Z00T<5@0>4AL051LL00lD6P0B6BD04ALU010F
900>52003Q8M00dA700@4a`00P0C4a/02P0E51/05A@J01@E6@0?4Q802`l?010D500@51H03A4D00hB
5@0?4QH300hA5`0D00hA6@0?4QP02Ph@00/?400@51D0;30a00hB4`0?4a@02`l@014E5P0=4A803a<D
01<G600D61P02@d<01@H5`0?4a804aLF00L;2P0@51<200lC4P80310?00P03a<B018F5P0A5AH04ADF
00lC500=4A80310A00dA4P803Q8C01004QHG01@H6@0C5aP03a<D01@H6@0@51D041<D00lC500=4A80
2Ph?01@H6@0B5QL02Ph?018F5`0@51D04ADE0P0=4A406P0?4a80310>00dB3P0>4`d03A8<00`A2`0;
40X0318900hC2`0:3`X02a4>018F500=40h02Q0=010E4P0A51802a0=00hC400B5A<020d:00lC4P0@
5A/03a@J00hC5`0<4A@03A<C0P0>51403`0?5A<03aDE00`A5@0;41@03A8I00dD5P0>5A@0318B00/A
4@0=4Q<04QHG00lC500@4Q@03a0B010@4P02014B500300X>3@0;4@l04QPF00803aDC00<08BLU00lE
4`0?5A<00P0A5aD200lE4`0400hD4P0;4@l02Q0>00/A3`803Q@B00L020h<00lE4`0<4Q002@l=01`R
800D6QP02a4?00803aDC00@02Q0>00/A3`0>5180318@0`0=4a40:@0<4Q002a4=00lD3`0>4`l0314=
010E4@0?5A<02@l=00/B3`0<5A@03AHE00hF5@094a@02Q@E00`G5@084Q40214>00hB3`0C5A004Q@>
00l?2P0?3``03@l=00hA4@0B5QP07b@T02L[:P0?4a801@T800hB4@072`X03A4@00`@3`0=4A003Q8A
00P<2`0:3Pd0310>00dB3P0>4`l02a0<00803A8>00<0314=00dB3P0<4@d00P0;40`01`0=4Ph051TE
010E4@0B5a<03a@@00P=2@0=4Ph01@0>4`l06`0;40`02a0700dC1@0<4PP0318:00dB300>4`l03A8?
00/?3P0J7a/041D?01<H4P0<4@X0314=00861@0>4Q404ADD02hb<@0?4a804ADD00H:2@0<3Pd020`;
014E500;40d01``800hC3@0200`A2`0400dB300<4@/02a0:00X?2@803a@>00/02Pl900`A2`0?5100
0PH3010E4@0f>cL05AXF00lD400:3`/0314=00dB3P0200`A3@0C00lD400?50h03Q<=00hC3@0?50h0
51TC01LL5P0F6aD0314;014F400@5@l01P/500hC3@093PP0314;00P=1`0?50h02a0:00hC3@0201@I
4`0I00hC3@0:3`T02Pl900hA300A4`d04Q@>00d?1`082@D05aPC00h@2P0<3PP0418=01<E400F61<0
3A0<00dA2`0=4P`0314;00X?2@0C61802a0:00T>200?50h05AXD01@I4`0200`A2`0500dB300=4A00
2Ph=00X>3@0>4Q400P0@51<01`0A5A@03A4@00lC4P0<40l03a<B00L;300=4A@00P0<41@05`0=4AD0
3a8F00lC5`0?4QH03a<G010D600A51P03a8F00hB5@0=4A402`l>014E500>4Q402`l>014E50072`X0
5QXI00`@3`0Q9B@0310?00dA4@011@H06AdN00802Ph?00<03a<D00X>3`0A5AH00P0=4A807@0?4a@0
3Q8C01@H600A5A@041@C00hB4@0<40l02`l>00hB4@093@`03A4@03i2@@0<40l051PG00hA400B5QD0
51PG01<G5P0A5A@041@C014E50031`H04aHE04iBD@0K7ah04QHE00`A3@0>4`l03a@@00803Q<?00T0
4AHB010E4@0>4`l0314=00lD400A5Q804QLC00lD400>4`l00`0=4Ph0400?51002a0<00hC3`0@5A40
3A8>00/@300<4@d01`d900dC3`0@5Q803Q@@010F4P0>5@h031<;018I4@052P@200lG300?00hF2`07
4@H03AL=00@?1`0@6QL0?TM501lX:00:51@031HD00LA30084P`03AP?00`F3@0@5Q8092XX008051XH
01D04aTF00D91P0>51003A<>00hE3P0;4P/020l800lF3`15BDT0<3@e014E5P0<40l03Q<@00dB3P0=
4P`02a0900hC3@0>4``0318900lD3@0>4`h00P0<4@d200/@300400`A3@0?510041DA014F4P8041DA
00<041D?00hD2@0?5@/00P0?5@/02`0<4@X02Pl800hC3@042@D05Q/G00`@3`0E6AP02a0<00lD3`0>
4`d0314;008041D?00X02a0:00T>200>4`d03a@>00hC3@0=4P`03a@>00`A2`0:3`T03A8<0P0@5@l0
100A5Q0051TC018G4@0=4P`300lD3P07010E3`0=4P`03Q<=01DJ500A5Q003A8<014F400201<H4P04
014F400?50h03A8=00dC3`803Q@@00d03A<?00hD400?5A402Q0<00dC3`0C6AD03aDA01@J5P0L8Qh0
4QLC00dB3P0:3P/05AXF00803a@@00P02@h:00hC3`0B5a<03A8>018G4`0=4P`03Q<=014F408041D?
02/04aPB01DJ500@5@l03a@>018G4@0?50h041D?00/@300S:2@05Q/G00/@300=4Ph03a@@00L<200B
5a<04AHB00T>2P0?51004QLC00P?200;4P/041HB014G4`0A5a@041HD014G5@0C6AP03Q@D010F5P0D
6A/03Q<F01HK7`0>51L04ALJ00/B500>51D03aDE014I600=5A<03ADB00lG500>5a@031HB01Cooooo
000Kooooo`<03@`A00<03PdB010?500@3a@01P0;2Pl0=@0>3A802@P=00H52P0920d03PdB00`;4009
20d01@@900P7300?3Q<03@`A00P7300;2`l06aXO00h=4P0A41D020L<00L62`0>3A8030/@00d<4@0?
3Q<03@`A00T:30093P`0310?00dA400=4A803@hB00`=4@0=3Q<03@`D010?5`0?3AP02@LB00P64@0:
2AL040lM01<B800@3ad02@PF00H54`0B4Al08B0^06MVM00A41h05aHT03Hg?`0N7b<020T=01@E6@07
20`030dA00H03PlC02P030hD010C6P062A001PT@010C6P0I72<020/B020S:P0C5Qd02`hE00H94007
2Q405APO02<V;@0000L04A@K04M:D@1FFF806A`V00/=6@0@4Qh05ALS010B7`0B52405QPY030aAP0A
4RH051DY01@E9`0<3Q`0000=01@G800F6B402PdB01TL8@0@51L06AhR014F6P0<4AD041DI0P0?51P0
2P0=4QH04aPL00/@500<4AD04AHJ00hD5P073PL0620E01@L4@0?5``2018J3`0=01DM4P001@004a/@
00D=0P0840D05A`C00X?2`0;3`h03Q8A00lC4P0>4Q40310?014E5002010D4`804QHE0P0@51<0500@
51D02Q8D01lV;00K9B`0[[S10>7[m00Z=3/03QPJ00H;3`0?51D05a/J00H:3@0@51L02`lB00`@4`0D
61/02`lB01@H6`0?4aH03A4D0P0?4aH05P0<41404aLF010D4`0A5AH041<H00hA600A51d051LP0044
3@0H6b806A`R01XM8P0@5A/031<P00/A7`0=4b402a4M00`@6`0=4A`051LP01<C6`0A4AT2014@5P0:
010A5@0?4Q003Q8A01HJ6@0E6AX0310C00dA500>4AH030lF00/>5@802`hG00X02`hE01DI6`0<4140
00@501@H6@021PL04ADF00dA4P0>4Q<02`l@0P0>4Q<03P0@51@061`K00D9200D61L00`L601HJ6@0A
5A@02@d<00/?3P0@51<02Ph=00T=300?4a<041@E0`0A5AH2010D5@0500hB4`0?4a@04ADF014E5P0>
4Q<00P0?4a@0200:3Pl03A4B01HJ6`000P<04QHG01HJ6`0830d03Q8C0P0:3Pl0:@0;3a003A4B010D
5@0:3Pd02@d<020U8@0<4@/02a0:00X?20093`D02Q0600`B1`0K7AP0008000lA3P082PL09bTV00h@
3@0B51403a4>018D4@0<3P/01@L400lB400B5A`041DK00dB5`0;41<02a4?00`B3`0>510041HB010F
5P0<4AD02a0D00hC6P0@5AP03aDE00`B4P093`l0314A008041@E00L03a8C00h?4@0?3a404A4C018C
5@0C5aH020h<00803A<A00@02a4?01PN700F71X04aTG0P1bN7H0300C6AL05Q`J00T?3@0A5aD041HD
00`B400;4@l0318@01<I5`0;4@l04ALE00X@3P8020h<00H02Q0>00dC4@0<4Q002a4?00`B400=4a42
00/A3`0800dC4@0C6AL06R0N01hT800=4Pd04aPD00lD400=4Ph200dC4@0:00/D4@063`h01@h=00/D
4`0230d031HG00PB4@0>5a@03aDA00X>2@802``600H04A0;00/<1`0@4@`030h=01DI6P0:3Pl201<G
5P05010D4`0>4Q4010P700dA400;3`h00P0=4A002P062PT020`;00dA3`0<4@d03a@@014F4P0;40`0
3a@@01PM6@0@5A4200T>2P0P00hC3`0=4Ph03Q<?00lD400B5a<03A8>01DJ5P0P9B404QLC02db;P14
BDD03a@@00870`0G71P0318900dC1@0B60h04aP@014F400?510041@B00D9200@5A403A8<00<80P0<
4@X01``801`P7`0=4A004aLF00H:2@0=4A0200`@3`0I010D4`0;3`h02Ph=00lC4@0>4`l041D?00D:
100I7QP092TS01@I4`083@L01``600lD3P0A5Q002a0:00`A2`093PX051TE00dB3P0A5Q8061dI018G
4`0:3`/0314=00dB3P0200X?2`0M00/@30083@L03Q<=00lD3P0<4@/02a0:00dB30001@005AXD00hC
3@0;40X04AH@00@90`0<4@/04AH@00dB300?50h020d7010E3`0A5Q00<CH`01LL5P0:3`T06AhH00`?
200>3`T010@001LG3`0E5@d00P0;30H04`0D5a002`d900/=200;3@P05QXD018G4@0?50h04aPB00D:
100B5a402@h801`Q6`0S:2801@X401DJ500<4@/02@h801PM5`0?4a800P0;3`h00`0=4A003Q8A00dA
4002010D4`0800hB4@072`X04ADD00hB4`0?4QH030lD00/>4`0<3a@200hA5P0Q018E6P0C5Q/04QDJ
010C600=41D02`lB00X>3P062PT03Q8A00/?3P0:3Pd041@C00040`0A5A@01PX902<W9P0830/02`l?
01hR8`031`P03a<D01LK7013AdP03a<D01@H6@0@51D03Q8C00`@4@093@h041@D00hB4@0=4A002`l>
00<02Ph=01X01`/:014E500=4A004ADD00P<2`0;3`h041@C018F5@0A5A@0310?00X>3@0A5A@06alN
00dA400J7Qd0310?00/=300D6AD04AHB00<8100:3`/06QlK01<H500@5A403Q<?014F4P806AhJ0P0@
5A40?00?51003A8>00`A3@0=4Ph041DA01@I5@0=4Ph01``800hC3`0B5a<03A8>00T?2`0?5A403Q@@
00L=2@0<4Ph04APA01<J4P0;4@X061lG00D=0P094@H01Q05014K400;5P`051lG00TD402S[J`0D5YK
00dG600B71/031LA00XE3`0;5`d0110600D;1`0?5A<0008001PN700k@Ch082HR01PN6P083PT010/4
00L>1`0>5@d06R4J01/O800N8R@041@E00`@3`0<40h02Pl;00lD3P0>4``04QL@010E3P0=4`T03a@=
00dB3@80314=00<03A8>00hC3`0>4`l00P0<4@d200/@300A00dB3P0?50h03Q@9010F300A5`d03aD;
00`A2P0:3`P0314;00hC3`083@T03A4@00H:2@0F6aL041D@00lD3P0;40X00P0@5@l0;P093PP03Q<=
00hC3@0<4@/02a0:010E3`0B5a40314;00X?2@0=4P`04AH@010E3`0A5Q0051TC018G4@0=4P`04QLA
01@I4`0B5a404AH@00hC3@0G71H08bPR01TN600:3`T0314;00lD3P0B5a404AH@00lD3P0@5Q403Q@@
00/A3@0<4Ph03Q@@00lE4@0>51001`d900P>2P0=4`l01@/700P>2P0B5a<020d9010E4@0K81`200lD
400700hC3`0;40`020d900L<20093PX04aPD014F4002018G4@0400lD3P0=4P`03a@>01HK5@803Q<=
00D061dG01LL5P0A5Q004aPD020U8@0200hC3`0N01XO6`0<4@d01``8024V8P0/<Bd04QLC00hC3`0H
7AT041L@01XQ6P0N92003A<?00X@3@0E6aT01`d;04A:B@0H7Qh01P`<00hC5@0E6Qd06ahS01<F6P0G
6ah01@X=00hD5@0A5aL051dL00H?3@0Z<c00<3/g0P0=61@Dooooo`00oooooooooooooooooooo;Ooo
ool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`00oooooooooooooooo
oooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`00oooooooo
oooooooooooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]ooooo`00
oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003oooooooooooooooooool]
ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003ooooooooooooo
ooooool]ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo003ooooo
ooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?ooooooooooooooooooobgooooo
003oooooooooooooooooool]ooooo`00oooooooooooooooooooo;Oooool00?oooooooooooooooooo
obgooooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{270.188, 270.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Fig. 7.9 The Andromeda galaxy, at a distance of roughly 2 million \
light years, is the nearest galaxy to our own milky way. Photo Credit:  Bill \
Schoening, Vanessa Harvey/REU program/NOAO/AURA/NSF.\
\>", "Caption",
  CellTags->"Fig. 7.9"],

Cell["\<\
\tHowever, stars interact with many other stars at the same time, \
and the net effect of all these weak interactions is that the galaxy is \
gravitationally bound together. We cannot completely neglect gravity in any \
model of galactic  dynamics; without it,  the galaxy would simply fly apart. \
\
\>", "Text"],

Cell[TextData[{
  "\tWe could, of course, try to keep all of the binary interactions between \
the stars, using a molecular dynamics code to model the  evolution. However, \
the number ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " of stars that can be handled with such a code is at most a few thousand, \
even on very fast  computers. This is because the number of interacting pairs \
equals ",
  Cell[BoxData[
      \(TraditionalForm\`N\ \((N - 1)\)/2\)]],
  ". Taking ",
  Cell[BoxData[
      \(TraditionalForm\`N = 10\^3 - 10\^5\)]],
  " is insufficient to handle many problems in galactic dynamics, considering \
that the galaxy contains roughly ",
  Cell[BoxData[
      \(TraditionalForm\`10\^11\)]],
  " stars (not to mention dust, gas, and other material such as \"dark matter\
\")."
}], "Text"],

Cell[TextData[{
  "\t One approach to modeling large collections of self-gravitating material \
is to go back to the picture of a collisionless gas. For simplicity, we \
consider here a system of identical particles  of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ", and with phase-space density ",
  Cell[BoxData[
      FormBox[
        RowBox[{"f", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["p",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". The evolution of this density is determined by the collisionless \
Boltzmann equation,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]f\/\[PartialD]t\), "+", 
            RowBox[{
              FractionBox[
                StyleBox["p",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["m",
                  FontWeight->"Plain"]], "\[CenterDot]", \(\[Del]f\)}], "-", 
            RowBox[{"m", " ", 
              RowBox[{\(\[Del]\[Phi]\), "\[CenterDot]", 
                FractionBox[\(\[PartialD]f\), 
                  RowBox[{"\[PartialD]", 
                    StyleBox["p",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]]}]}]}], "=", "0"}], 
        TraditionalForm]]],
  "."
}], "NE3",
  CellTags->{"i:54", "(7.3.1)"}],

Cell[TextData[{
  "However,  the gravitational potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " is not imposed from some external source; rather,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " is created by the mean density itself via Newton's law of gravitation [in \
differential form, Poissons equation ",
  ButtonBox["(4.3.78)",
    ButtonData:>{"Chapter4.nb", "(4.3.78)"},
    ButtonStyle->"Hyperlink"],
  " ]:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 \[Phi] = 4  \[Pi]\ G\ \[Rho]\)]],
  ","
}], "NE3",
  CellTags->"(7.3.2)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\  = 
        m\ \(\[Integral]f \(\(\[DifferentialD]\^3 p\)\(\ \)\)\)\)]],
  " is the mass density."
}], "Text"],

Cell[TextData[{
  "\tWe should think of  the mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " as a reasonably  smooth function of position. This density does not \
contain information concerning the position of individual stars, but rather \
is the mean density of matter  at any given point, averaged over a \"small\" \
volume element (but one that is much larger than the mean distance between \
stars, so that many stars are contained in an element). Thus, the \
gravitational potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " does not tell us about the interaction between individual pairs of stars. \
 Rather, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " is the mean potential due to the smooth \"fluid\" of stars (and anything \
else that contributes to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  ")."
}], "Text"],

Cell[TextData[{
  "\tThis is, in part,  why it is acceptable to take the mass of all the \
stars to be the same: in our model only the mean mass density of the matter \
is important to the mean potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  ".  Also, the gravitational acceleration of a particle is independent of \
that particle's mass: a heavy and a light star will behave identically in a \
given mean potential.  Therefore, we can safely assume our system consists of \
a distribution of like-mass stars."
}], "Text"],

Cell[TextData[{
  "\tIt is worthwhile to note that Eqs. ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  "  can also be applied to high-temperature plasmas, which are also nearly \
collisionless. Now ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is the phase-space density of some species of charged particle, and the \
Coulomb interaction replaces the gravitational interaction. (However, it is \
now important to follow distributions for each species separately because \
particle acceleration now depends on both mass and charge.) In fact, \
equations of this general form appear in several area of physics. Some \
examples will be discussed in the exercises."
}], "Text"],

Cell[TextData[{
  "\tAlthough Eqs. ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  "  are much easier to deal with than Newton's equations for all ",
  Cell[BoxData[
      \(TraditionalForm\`10\^11\)]],
  " stars in the galaxy, these equations are still difficult to solve. The \
problem is that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " depends on  the momentum integral over ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ", so Eq. ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  "  is  really a nonlinear equation for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ". Analytic  solutions of these equations can only be obtained in certain \
highly simplified cases. "
}], "Text"],

Cell[TextData[{
  "\tIn this section, we will discuss one method for solving this nonlinear \
system numerically, called the particle-in-cell (PIC) method. We will then \
consider a few examples, focusing on the phenomenon of gravitational \
collapse. Our examination of this complex process is necessarily limited in \
scope [for more detail see, for example,  ",
  ButtonBox["Binney and Tremaine (1987)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "], but  it is hoped that the simulation results give some flavor of what \
can be accomplished using the PIC method. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.3.2 Strategy of the PIC Method", "Subsubtitle",
  CellTags->"c:29"],

Cell[TextData[{
  "\tWe will solve Eqs. ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  "   and ",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  "  in periodic boundary conditions in two spatial dimensions. (The \
following code can be easily modified for three spatial dimensions, but runs \
too slowly to be of much utility, unless it is adapted for use with a \
compiled language such a Fortran or C, and run on a fast computer. Modifying \
the code to run in one dimension is left to the exercises.) The simulation \
box contains the ranges  ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < L\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 < y < L\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t The strategy  for solving Eqs. ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  "  in this periodic 2D domain is similar to that used previously in solving \
the collisionless Boltzmann equation: basically, we solve for the dynamics of \
a large number of particles, and determine the density using histograms of \
the particle positions. These particles should not be thought of as \
individual stars. Rather, a single particle  represents  a whole cloud of \
stars, and is located at this cloud's center of mass. The mean density is a \
superposition of these clouds. Thus, we can still model a galaxy or other \
large stellar system using far fewer than ",
  Cell[BoxData[
      \(TraditionalForm\`10\^11\)]],
  " particles."
}], "Text"],

Cell["\t  Broken down into individual steps,  at each time step, ", "Text"],

Cell[TextData[{
  "(1) We make a histogram of the particle positions on an ",
  Cell[BoxData[
      \(TraditionalForm\`M\ by\ M\)]],
  " spatial grid in order to determine the mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " on  the grid."
}], "Text"],

Cell[TextData[{
  "(2) We use this density in Poissons equation to solve for the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " on the grid using Eq. ",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  " . We also determine  the gradient of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " (i.e. the force field), evaluated at the grid positions. "
}], "Text"],

Cell["\<\
(3) We then interpolate the force field  from the values at the \
grid positions back to the particle positions, and update the positions and \
velocities of the particles to the next time step using Newtons second law.\
\
\>", "Text"],

Cell[TextData[{
  " These three tasks are shown schematically in Fig. ",
  ButtonBox["7.10",
    ButtonData:>"Fig. 7.10",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .65625 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.31746 0.015625 0.31746 [
[ 0 0 0 0 ]
[ 1 .65625 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .65625 L
0 .65625 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
% Start of sub-graphic
p
0.0238095 0.015625 0.321429 0.313244 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -10.625 0 ]
[.5 .82364 10.625 12.9375 ]
[.15237 .19707 -5.94882 -9 ]
[.15237 .19707 .05118 0 ]
[.31741 .13214 -11.2392 -9 ]
[.31741 .13214 .76076 0 ]
[.49342 .06293 -10.5808 -9 ]
[.49342 .06293 1.41915 0 ]
[.68156 -0.01098 -9.92245 -9 ]
[.68156 -0.01098 2.07755 0 ]
[.77078 .10213 0 -6.15691 ]
[.77078 .10213 6 2.84309 ]
[.84915 .22213 0 -6.0419 ]
[.84915 .22213 12 2.9581 ]
[.9191 .32925 0 -5.94182 ]
[.9191 .32925 12 3.05818 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 12 3.14607 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -71.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
75.000 14.562 moveto
(j) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(10)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(15)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(20)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75847 .10666 m
.75231 .10893 L
s
[(5)] .77078 .10213 -1 .3682 Mshowa
.83673 .22638 m
.83053 .22851 L
s
[(10)] .84915 .22213 -1 .34264 Mshowa
.9066 .33325 m
.90035 .33526 L
s
[(15)] .9191 .32925 -1 .3204 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(20)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.77486 .13175 m
.77116 .13309 L
s
.79088 .15624 m
.78717 .15756 L
s
.80652 .18016 m
.8028 .18147 L
s
.8218 .20354 m
.81808 .20483 L
s
.85133 .24872 m
.8476 .24998 L
s
.86561 .27055 m
.86188 .2718 L
s
.87957 .29191 m
.87583 .29314 L
s
.89323 .31281 m
.88949 .31402 L
s
.91968 .35327 m
.91593 .35445 L
s
.93249 .37286 m
.92873 .37403 L
s
.94503 .39204 m
.94127 .3932 L
s
.95731 .41083 m
.95355 .41198 L
s
.74167 .08097 m
.73798 .08235 L
s
.72446 .05465 m
.72078 .05604 L
s
.70682 .02766 m
.70315 .02908 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.664 .741 .908 r
.38897 .58867 .40512 .60371 .43216 .5956 .41618 .58041 Metetra
.664 .741 .908 r
.41618 .58041 .43216 .5956 .45948 .58741 .44367 .57206 Metetra
.664 .741 .908 r
.44367 .57206 .45948 .58741 .48707 .57913 .47145 .56362 Metetra
.664 .741 .908 r
.47145 .56362 .48707 .57913 .51495 .57077 .4995 .5551 Metetra
.664 .741 .908 r
.4995 .5551 .51495 .57077 .54311 .56232 .52785 .54649 Metetra
.664 .741 .908 r
.52785 .54649 .54311 .56232 .57156 .55378 .5565 .53779 Metetra
.664 .741 .908 r
.5565 .53779 .57156 .55378 .6003 .54516 .58544 .529 Metetra
.664 .741 .908 r
.58544 .529 .6003 .54516 .62935 .53645 .61469 .52012 Metetra
.664 .741 .908 r
.61469 .52012 .62935 .53645 .6587 .52764 .64425 .51114 Metetra
.664 .741 .908 r
.64425 .51114 .6587 .52764 .68836 .51874 .67412 .50207 Metetra
.664 .741 .908 r
.67412 .50207 .68836 .51874 .71833 .50975 .70431 .4929 Metetra
.664 .741 .908 r
.70431 .4929 .71833 .50975 .74862 .50066 .73483 .48363 Metetra
.664 .741 .908 r
.73483 .48363 .74862 .50066 .77923 .49148 .76568 .47426 Metetra
.664 .741 .908 r
.76568 .47426 .77923 .49148 .81018 .4822 .79686 .46479 Metetra
.664 .741 .908 r
.79686 .46479 .81018 .4822 .84146 .47281 .82838 .45522 Metetra
.664 .741 .908 r
.82838 .45522 .84146 .47281 .87308 .46333 .86025 .44554 Metetra
.664 .741 .908 r
.86025 .44554 .87308 .46333 .90504 .45374 .89247 .43576 Metetra
.664 .741 .908 r
.89247 .43576 .90504 .45374 .93736 .44404 .92505 .42586 Metetra
.664 .741 .908 r
.92505 .42586 .93736 .44404 .97003 .43424 .95799 .41586 Metetra
.664 .741 .908 r
.37251 .57335 .38897 .58867 .41618 .58041 .3999 .56493 Metetra
.664 .741 .908 r
.3999 .56493 .41618 .58041 .44367 .57206 .42757 .55642 Metetra
.664 .741 .908 r
.42757 .55642 .44367 .57206 .47145 .56362 .45552 .54782 Metetra
.664 .741 .908 r
.45552 .54782 .47145 .56362 .4995 .5551 .48377 .53914 Metetra
.664 .741 .908 r
.48377 .53914 .4995 .5551 .52785 .54649 .51231 .53036 Metetra
.664 .741 .908 r
.51231 .53036 .52785 .54649 .5565 .53779 .54115 .52149 Metetra
.544 .699 .941 r
.54115 .52149 .5565 .53779 .58544 .529 .57039 .51998 Metetra
.689 .855 .962 r
.57039 .51998 .58544 .529 .61469 .52012 .59985 .50821 Metetra
.357 .681 .978 r
.59985 .50821 .61469 .52012 .64425 .51114 .63006 .51134 Metetra
.039 .608 .724 r
.63006 .51134 .64425 .51114 .67412 .50207 .66064 .51029 Metetra
.793 .98 .706 r
.66064 .51029 .67412 .50207 .70431 .4929 .69002 .47571 Metetra
.664 .741 .908 r
.69002 .47571 .70431 .4929 .73483 .48363 .72077 .46626 Metetra
.664 .741 .908 r
.72077 .46626 .73483 .48363 .76568 .47426 .75185 .4567 Metetra
.664 .741 .908 r
.75185 .4567 .76568 .47426 .79686 .46479 .78327 .44704 Metetra
.664 .741 .908 r
.78327 .44704 .79686 .46479 .82838 .45522 .81504 .43727 Metetra
.664 .741 .908 r
.81504 .43727 .82838 .45522 .86025 .44554 .84716 .42739 Metetra
.664 .741 .908 r
.84716 .42739 .86025 .44554 .89247 .43576 .87963 .4174 Metetra
.664 .741 .908 r
.87963 .4174 .89247 .43576 .92505 .42586 .91248 .4073 Metetra
.664 .741 .908 r
.91248 .4073 .92505 .42586 .95799 .41586 .94569 .39709 Metetra
.664 .741 .908 r
.35574 .55773 .37251 .57335 .3999 .56493 .3833 .54915 Metetra
.664 .741 .908 r
.3833 .54915 .3999 .56493 .42757 .55642 .41115 .54048 Metetra
.664 .741 .908 r
.41115 .54048 .42757 .55642 .45552 .54782 .43929 .53172 Metetra
.664 .741 .908 r
.43929 .53172 .45552 .54782 .48377 .53914 .46772 .52286 Metetra
.664 .741 .908 r
.46772 .52286 .48377 .53914 .51231 .53036 .49646 .51391 Metetra
.578 .713 .935 r
.49646 .51391 .51231 .53036 .54115 .52149 .5255 .51049 Metetra
.754 .248 0 r
.5255 .51049 .54115 .52149 .57039 .51998 .55532 .54882 Metetra
.55532 .54882 .57039 .51998 .59985 .50821 .58481 .50329 Metetra
.75 .231 0 r
.58481 .50329 .59985 .50821 .63006 .51134 .61614 .53782 Metetra
.255 0 .09 r
.61614 .53782 .63006 .51134 .66064 .51029 .64678 .52206 Metetra
.64678 .52206 .66064 .51029 .69002 .47571 .6777 .50739 Metetra
.128 0 .098 r
.6777 .50739 .69002 .47571 .72077 .46626 .70812 .47929 Metetra
.015 0 0 r
.70812 .47929 .72077 .46626 .75185 .4567 .73945 .46501 Metetra
.7 .946 .659 r
.73945 .46501 .75185 .4567 .78327 .44704 .76967 .43249 Metetra
.706 .802 .924 r
.76967 .43249 .78327 .44704 .81504 .43727 .80142 .41895 Metetra
.664 .741 .908 r
.80142 .41895 .81504 .43727 .84716 .42739 .83379 .40887 Metetra
.664 .741 .908 r
.83379 .40887 .84716 .42739 .87963 .4174 .86653 .39867 Metetra
.664 .741 .908 r
.86653 .39867 .87963 .4174 .91248 .4073 .89965 .38836 Metetra
.664 .741 .908 r
.89965 .38836 .91248 .4073 .94569 .39709 .93314 .37793 Metetra
.664 .741 .908 r
.33865 .54182 .35574 .55773 .3833 .54915 .36639 .53307 Metetra
.664 .741 .908 r
.36639 .53307 .3833 .54915 .41115 .54048 .39441 .52423 Metetra
.664 .741 .908 r
.39441 .52423 .41115 .54048 .43929 .53172 .42274 .5153 Metetra
.664 .741 .908 r
.42274 .5153 .43929 .53172 .46772 .52286 .45136 .50627 Metetra
.664 .741 .908 r
.45136 .50627 .46772 .52286 .49646 .51391 .48029 .49714 Metetra
.468 .667 .949 r
.48029 .49714 .49646 .51391 .5255 .51049 .50948 .49878 Metetra
0 .464 .861 r
.50948 .49878 .5255 .51049 .55532 .54882 .53922 .51022 Metetra
.667 .591 .761 r
.53922 .51022 .55532 .54882 .58481 .50329 .56933 .49653 Metetra
0 .431 .76 r
.56933 .49653 .58481 .50329 .61614 .53782 .60022 .50631 Metetra
.656 .623 .805 r
.60022 .50631 .61614 .53782 .64678 .52206 .63116 .49586 Metetra
.604 .637 .856 r
.63116 .49586 .64678 .52206 .6777 .50739 .66269 .49133 Metetra
.692 .776 .916 r
.66269 .49133 .6777 .50739 .70812 .47929 .69426 .47898 Metetra
0 .574 .714 r
.69426 .47898 .70812 .47929 .73945 .46501 .72694 .47941 Metetra
.407 0 0 r
.72694 .47941 .73945 .46501 .76967 .43249 .76023 .48035 Metetra
0 0 .069 r
.76023 .48035 .76967 .43249 .80142 .41895 .78784 .40419 Metetra
.71 .808 .926 r
.78784 .40419 .80142 .41895 .83379 .40887 .82015 .38995 Metetra
.664 .741 .908 r
.82015 .38995 .83379 .40887 .86653 .39867 .85316 .37954 Metetra
.664 .741 .908 r
.85316 .37954 .86653 .39867 .89965 .38836 .88654 .36901 Metetra
.664 .741 .908 r
.88654 .36901 .89965 .38836 .93314 .37793 .92032 .35836 Metetra
.664 .741 .908 r
.32123 .5256 .33865 .54182 .36639 .53307 .34914 .51668 Metetra
.664 .741 .908 r
.34914 .51668 .36639 .53307 .39441 .52423 .37735 .50766 Metetra
.664 .741 .908 r
.37735 .50766 .39441 .52423 .42274 .5153 .40586 .49855 Metetra
.452 .663 .952 r
.40586 .49855 .42274 .5153 .45136 .50627 .43438 .50055 Metetra
.126 .641 .892 r
.43438 .50055 .45136 .50627 .48029 .49714 .46338 .50321 Metetra
.46338 .50321 .48029 .49714 .50948 .49878 .49301 .49622 Metetra
.562 .911 .968 r
.49301 .49622 .50948 .49878 .53922 .51022 .523 .48572 Metetra
.386 .541 .888 r
.523 .48572 .53922 .51022 .56933 .49653 .55348 .4945 Metetra
.223 0 0 r
.55348 .4945 .56933 .49653 .60022 .50631 .5846 .50166 Metetra
.929 .889 .77 r
.5846 .50166 .60022 .50631 .63116 .49586 .61492 .45518 Metetra
.122 .259 .733 r
.61492 .45518 .63116 .49586 .66269 .49133 .64791 .49006 Metetra
.842 .98 .872 r
.64791 .49006 .66269 .49133 .69426 .47898 .67915 .46146 Metetra
.673 .759 .915 r
.67915 .46146 .69426 .47898 .72694 .47941 .7114 .45034 Metetra
.078 .311 .792 r
.7114 .45034 .72694 .47941 .76023 .48035 .74666 .47888 Metetra
.987 .867 .628 r
.74666 .47888 .76023 .48035 .78784 .40419 .7746 .39764 Metetra
.838 .943 .892 r
.7746 .39764 .78784 .40419 .82015 .38995 .80622 .37064 Metetra
.664 .741 .908 r
.80622 .37064 .82015 .38995 .85316 .37954 .8395 .36001 Metetra
.664 .741 .908 r
.8395 .36001 .85316 .37954 .88654 .36901 .87316 .34925 Metetra
.664 .741 .908 r
.87316 .34925 .88654 .36901 .92032 .35836 .90722 .33837 Metetra
.664 .741 .908 r
.30346 .50906 .32123 .5256 .34914 .51668 .33156 .49996 Metetra
.664 .741 .908 r
.33156 .49996 .34914 .51668 .37735 .50766 .35995 .49077 Metetra
.664 .741 .908 r
.35995 .49077 .37735 .50766 .40586 .49855 .38865 .48148 Metetra
.533 .697 .944 r
.38865 .48148 .40586 .49855 .43438 .50055 .41741 .47991 Metetra
.814 .366 0 r
.41741 .47991 .43438 .50055 .46338 .50321 .44533 .53284 Metetra
.747 .383 .365 r
.44533 .53284 .46338 .50321 .49301 .49622 .47481 .57722 Metetra
.013 0 .217 r
.47481 .57722 .49301 .49622 .523 .48572 .50628 .50429 Metetra
.194 0 0 r
.50628 .50429 .523 .48572 .55348 .4945 .53715 .49369 Metetra
.544 0 0 r
.53715 .49369 .55348 .4945 .5846 .50166 .56871 .51083 Metetra
.926 .972 .697 r
.56871 .51083 .5846 .50166 .61492 .45518 .59962 .46047 Metetra
.856 .434 .224 r
.59962 .46047 .61492 .45518 .64791 .49006 .63388 .52601 Metetra
.63388 .52601 .64791 .49006 .67915 .46146 .66405 .45132 Metetra
.878 .876 .829 r
.66405 .45132 .67915 .46146 .7114 .45034 .69538 .41623 Metetra
.199 .355 .796 r
.69538 .41623 .7114 .45034 .74666 .47888 .73044 .44219 Metetra
.553 .555 .81 r
.73044 .44219 .74666 .47888 .7746 .39764 .76479 .44279 Metetra
.76479 .44279 .7746 .39764 .80622 .37064 .79292 .36191 Metetra
.786 .921 .928 r
.79292 .36191 .80622 .37064 .8395 .36001 .82554 .34005 Metetra
.664 .741 .908 r
.82554 .34005 .8395 .36001 .87316 .34925 .85949 .32906 Metetra
.664 .741 .908 r
.85949 .32906 .87316 .34925 .90722 .33837 .89384 .31795 Metetra
.664 .741 .908 r
.28535 .49219 .30346 .50906 .33156 .49996 .31362 .48291 Metetra
.664 .741 .908 r
.31362 .48291 .33156 .49996 .35995 .49077 .34221 .47354 Metetra
.612 .726 .927 r
.34221 .47354 .35995 .49077 .38865 .48148 .37093 .46761 Metetra
.034 .476 .881 r
.37093 .46761 .38865 .48148 .41741 .47991 .3994 .47844 Metetra
.742 .233 .001 r
.3994 .47844 .41741 .47991 .44533 .53284 .42801 .5076 Metetra
.526 .615 .884 r
.42801 .5076 .44533 .53284 .47481 .57722 .45823 .50822 Metetra
.658 .519 .683 r
.45823 .50822 .47481 .57722 .50628 .50429 .48922 .48666 Metetra
.768 .775 .859 r
.48922 .48666 .50628 .50429 .53715 .49369 .52034 .46548 Metetra
.741 .685 .797 r
.52034 .46548 .53715 .49369 .56871 .51083 .55159 .443 Metetra
.492 .416 .698 r
.55159 .443 .56871 .51083 .59962 .46047 .58358 .45538 Metetra
.729 .2 0 r
.58358 .45538 .59962 .46047 .63388 .52601 .61703 .49121 Metetra
.806 .683 .728 r
.61703 .49121 .63388 .52601 .66405 .45132 .64878 .44747 Metetra
.245 .742 .908 r
.64878 .44747 .66405 .45132 .69538 .41623 .68224 .44525 Metetra
.68224 .44525 .69538 .41623 .73044 .44219 .71406 .40538 Metetra
.42 .48 .816 r
.71406 .40538 .73044 .44219 .76479 .44279 .74928 .41776 Metetra
.842 .753 .765 r
.74928 .41776 .76479 .44279 .79292 .36191 .78112 .37644 Metetra
.723 .881 .481 r
.78112 .37644 .79292 .36191 .82554 .34005 .81189 .3263 Metetra
.74 .851 .932 r
.81189 .3263 .82554 .34005 .85949 .32906 .84552 .30844 Metetra
.664 .741 .908 r
.84552 .30844 .85949 .32906 .89384 .31795 .88016 .29707 Metetra
.664 .741 .908 r
.26687 .47499 .28535 .49219 .31362 .48291 .29533 .46553 Metetra
.664 .741 .908 r
.29533 .46553 .31362 .48291 .34221 .47354 .3241 .45596 Metetra
.454 .665 .953 r
.3241 .45596 .34221 .47354 .37093 .46761 .35261 .45739 Metetra
.427 .76 .996 r
.35261 .45739 .37093 .46761 .3994 .47844 .38175 .45597 Metetra
.51 .635 .909 r
.38175 .45597 .3994 .47844 .42801 .5076 .41129 .45655 Metetra
.168 .246 .701 r
.41129 .45655 .42801 .5076 .45823 .50822 .44052 .4902 Metetra
.035 .427 .867 r
.44052 .4902 .45823 .50822 .48922 .48666 .47121 .50489 Metetra
.47121 .50489 .48922 .48666 .52034 .46548 .50302 .475 Metetra
.744 .282 .152 r
.50302 .475 .52034 .46548 .55159 .443 .53502 .50877 Metetra
.489 .173 .357 r
.53502 .50877 .55159 .443 .58358 .45538 .56774 .50349 Metetra
0 0 .098 r
.56774 .50349 .58358 .45538 .61703 .49121 .60003 .45758 Metetra
.814 .692 .73 r
.60003 .45758 .61703 .49121 .64878 .44747 .63202 .41264 Metetra
.527 .555 .827 r
.63202 .41264 .64878 .44747 .68224 .44525 .66574 .41468 Metetra
.398 .515 .86 r
.66574 .41468 .68224 .44525 .71406 .40538 .70058 .42508 Metetra
.70058 .42508 .71406 .40538 .74928 .41776 .73287 .38268 Metetra
.404 .487 .831 r
.73287 .38268 .74928 .41776 .78112 .37644 .76905 .39511 Metetra
.816 .872 .432 r
.76905 .39511 .78112 .37644 .81189 .3263 .79904 .32549 Metetra
.882 .991 .795 r
.79904 .32549 .81189 .3263 .84552 .30844 .83124 .28735 Metetra
.664 .741 .908 r
.83124 .28735 .84552 .30844 .88016 .29707 .86618 .27574 Metetra
.664 .741 .908 r
.24802 .45744 .26687 .47499 .29533 .46553 .27667 .44778 Metetra
.664 .741 .908 r
.27667 .44778 .29533 .46553 .3241 .45596 .30563 .43802 Metetra
.819 .352 0 r
.30563 .43802 .3241 .45596 .35261 .45739 .33167 .48364 Metetra
.134 0 0 r
.33167 .48364 .35261 .45739 .38175 .45597 .36207 .46768 Metetra
.842 .994 .748 r
.36207 .46768 .38175 .45597 .41129 .45655 .39357 .43019 Metetra
.138 .394 .845 r
.39357 .43019 .41129 .45655 .44052 .4902 .4232 .44751 Metetra
0 .173 .691 r
.4232 .44751 .44052 .4902 .47121 .50489 .45327 .48387 Metetra
.891 .754 .703 r
.45327 .48387 .47121 .50489 .50302 .475 .48583 .41873 Metetra
0 0 .378 r
.48583 .41873 .50302 .475 .53502 .50877 .51735 .5012 Metetra
.88 .447 .136 r
.51735 .5012 .53502 .50877 .56774 .50349 .55102 .57409 Metetra
.55102 .57409 .56774 .50349 .60003 .45758 .58361 .46901 Metetra
.991 .888 .588 r
.58361 .46901 .60003 .45758 .63202 .41264 .61502 .37628 Metetra
.633 .604 .803 r
.61502 .37628 .63202 .41264 .66574 .41468 .64833 .36665 Metetra
.631 .556 .751 r
.64833 .36665 .66574 .41468 .70058 .42508 .68198 .35528 Metetra
.606 .49 .695 r
.68198 .35528 .70058 .42508 .73287 .38268 .71612 .34514 Metetra
.258 .384 .8 r
.71612 .34514 .73287 .38268 .76905 .39511 .75311 .36865 Metetra
.918 .76 .671 r
.75311 .36865 .76905 .39511 .79904 .32549 .7831 .29293 Metetra
.755 .688 .788 r
.7831 .29293 .79904 .32549 .83124 .28735 .81664 .2658 Metetra
.664 .741 .908 r
.81664 .2658 .83124 .28735 .86618 .27574 .85189 .25392 Metetra
.664 .741 .908 r
.22879 .43953 .24802 .45744 .27667 .44778 .25763 .42968 Metetra
.664 .741 .908 r
.25763 .42968 .27667 .44778 .30563 .43802 .28678 .41972 Metetra
.367 .624 .951 r
.28678 .41972 .30563 .43802 .33167 .48364 .31534 .42392 Metetra
.495 .432 .715 r
.31534 .42392 .33167 .48364 .36207 .46768 .34428 .43174 Metetra
.285 .406 .81 r
.34428 .43174 .36207 .46768 .39357 .43019 .37349 .44811 Metetra
.923 .964 .657 r
.37349 .44811 .39357 .43019 .4232 .44751 .40627 .3907 Metetra
.244 .28 .701 r
.40627 .3907 .4232 .44751 .45327 .48387 .4361 .42136 Metetra
.377 .354 .707 r
.4361 .42136 .45327 .48387 .48583 .41873 .46723 .4436 Metetra
.46723 .4436 .48583 .41873 .51735 .5012 .49976 .41703 Metetra
.613 .473 .668 r
.49976 .41703 .51735 .5012 .55102 .57409 .53239 .40279 Metetra
.545 .376 .603 r
.53239 .40279 .55102 .57409 .58361 .46901 .56555 .40485 Metetra
.771 .598 .664 r
.56555 .40485 .58361 .46901 .61502 .37628 .59797 .34589 Metetra
.749 .692 .797 r
.59797 .34589 .61502 .37628 .64833 .36665 .63092 .32091 Metetra
.362 .406 .772 r
.63092 .32091 .64833 .36665 .68198 .35528 .66593 .33966 Metetra
0 .187 .672 r
.66593 .33966 .68198 .35528 .71612 .34514 .70248 .3665 Metetra
.70248 .3665 .71612 .34514 .75311 .36865 .7361 .33017 Metetra
.823 .689 .716 r
.7361 .33017 .75311 .36865 .7831 .29293 .76852 .28018 Metetra
.88 .89 .835 r
.76852 .28018 .7831 .29293 .81664 .2658 .80172 .24376 Metetra
.664 .741 .908 r
.80172 .24376 .81664 .2658 .85189 .25392 .83727 .23161 Metetra
.664 .741 .908 r
.20917 .42126 .22879 .43953 .25763 .42968 .23819 .4112 Metetra
.664 .741 .908 r
.23819 .4112 .25763 .42968 .28678 .41972 .26753 .40103 Metetra
.655 .739 .911 r
.26753 .40103 .28678 .41972 .31534 .42392 .29716 .39141 Metetra
.407 .503 .845 r
.29716 .39141 .31534 .42392 .34428 .43174 .32605 .39948 Metetra
.311 .453 .842 r
.32605 .39948 .34428 .43174 .37349 .44811 .35536 .41225 Metetra
.678 .624 .788 r
.35536 .41225 .37349 .44811 .40627 .3907 .38668 .39674 Metetra
.175 0 0 r
.38668 .39674 .40627 .3907 .4361 .42136 .41777 .39634 Metetra
0 .114 .654 r
.41777 .39634 .4361 .42136 .46723 .4436 .44871 .42641 Metetra
.327 .633 .962 r
.44871 .42641 .46723 .4436 .49976 .41703 .48118 .43109 Metetra
.973 .926 .628 r
.48118 .43109 .49976 .41703 .53239 .40279 .51463 .35536 Metetra
.705 .598 .734 r
.51463 .35536 .53239 .40279 .56555 .40485 .54749 .32984 Metetra
.452 .381 .686 r
.54749 .32984 .56555 .40485 .59797 .34589 .58121 .34659 Metetra
.739 .99 .881 r
.58121 .34659 .59797 .34589 .63092 .32091 .61475 .32194 Metetra
.861 .994 .821 r
.61475 .32194 .63092 .32091 .66593 .33966 .64799 .2864 Metetra
.659 .559 .73 r
.64799 .2864 .66593 .33966 .70248 .3665 .682 .268 Metetra
.576 .435 .653 r
.682 .268 .70248 .3665 .7361 .33017 .71699 .26096 Metetra
.632 .509 .695 r
.71699 .26096 .7361 .33017 .76852 .28018 .7518 .24389 Metetra
.718 .658 .79 r
.7518 .24389 .76852 .28018 .80172 .24376 .78645 .22121 Metetra
.664 .741 .908 r
.78645 .22121 .80172 .24376 .83727 .23161 .82231 .20878 Metetra
.664 .741 .908 r
.18913 .4026 .20917 .42126 .23819 .4112 .21834 .39234 Metetra
.664 .741 .908 r
.21834 .39234 .23819 .4112 .26753 .40103 .24788 .38195 Metetra
.659 .74 .91 r
.24788 .38195 .26753 .40103 .29716 .39141 .27774 .37178 Metetra
.762 .281 0 r
.27774 .37178 .29716 .39141 .32605 .39948 .3044 .4135 Metetra
.485 0 0 r
.3044 .4135 .32605 .39948 .35536 .41225 .3344 .42092 Metetra
.3344 .42092 .35536 .41225 .38668 .39674 .36601 .40999 Metetra
.59 .915 .676 r
.36601 .40999 .38668 .39674 .41777 .39634 .39864 .38252 Metetra
0 .451 .849 r
.39864 .38252 .41777 .39634 .44871 .42641 .43016 .39432 Metetra
.382 .508 .861 r
.43016 .39432 .44871 .42641 .48118 .43109 .46259 .40352 Metetra
.897 .736 .674 r
.46259 .40352 .48118 .43109 .51463 .35536 .49662 .32401 Metetra
.681 .662 .825 r
.49662 .32401 .51463 .35536 .54749 .32984 .52974 .30886 Metetra
.286 .564 .932 r
.52974 .30886 .54749 .32984 .58121 .34659 .56346 .31724 Metetra
.151 .391 .84 r
.56346 .31724 .58121 .34659 .61475 .32194 .5983 .33707 Metetra
.722 .923 .58 r
.5983 .33707 .61475 .32194 .64799 .2864 .63207 .29282 Metetra
.776 .987 .744 r
.63207 .29282 .64799 .2864 .682 .268 .66594 .25715 Metetra
.859 .908 .866 r
.66594 .25715 .682 .268 .71699 .26096 .6999 .22483 Metetra
.653 .629 .814 r
.6999 .22483 .71699 .26096 .7518 .24389 .73517 .21175 Metetra
.663 .661 .838 r
.73517 .21175 .7518 .24389 .78645 .22121 .77083 .19815 Metetra
.664 .741 .908 r
.77083 .19815 .78645 .22121 .82231 .20878 .80701 .18543 Metetra
.664 .741 .908 r
.16868 .38356 .18913 .4026 .21834 .39234 .19808 .37308 Metetra
.664 .741 .908 r
.19808 .37308 .21834 .39234 .24788 .38195 .22782 .36247 Metetra
.664 .741 .908 r
.22782 .36247 .24788 .38195 .27774 .37178 .2579 .35174 Metetra
0 .322 .796 r
.2579 .35174 .27774 .37178 .3044 .4135 .28626 .36856 Metetra
.277 .357 .766 r
.28626 .36856 .3044 .4135 .3344 .42092 .31535 .38764 Metetra
.646 .631 .821 r
.31535 .38764 .3344 .42092 .36601 .40999 .34706 .37661 Metetra
.559 .592 .843 r
.34706 .37661 .36601 .40999 .39864 .38252 .37876 .37394 Metetra
.868 .887 .847 r
.37876 .37394 .39864 .38252 .43016 .39432 .41213 .33982 Metetra
.043 .164 .666 r
.41213 .33982 .43016 .39432 .46259 .40352 .44354 .38021 Metetra
.878 .763 .732 r
.44354 .38021 .46259 .40352 .49662 .32401 .47785 .32475 Metetra
.82 .992 .868 r
.47785 .32475 .49662 .32401 .52974 .30886 .51155 .29488 Metetra
.591 .81 .983 r
.51155 .29488 .52974 .30886 .56346 .31724 .5454 .28648 Metetra
.639 .657 .851 r
.5454 .28648 .56346 .31724 .5983 .33707 .57971 .27588 Metetra
0 .058 .599 r
.57971 .27588 .5983 .33707 .63207 .29282 .61659 .33753 Metetra
.006 0 .046 r
.61659 .33753 .63207 .29282 .66594 .25715 .65145 .29668 Metetra
.724 .766 .267 r
.65145 .29668 .66594 .25715 .6999 .22483 .68325 .20115 Metetra
.675 .739 .899 r
.68325 .20115 .6999 .22483 .73517 .21175 .71879 .18739 Metetra
.663 .731 .9 r
.71879 .18739 .73517 .21175 .77083 .19815 .75484 .17454 Metetra
.664 .741 .908 r
.75484 .17454 .77083 .19815 .80701 .18543 .79135 .16152 Metetra
.664 .741 .908 r
.14779 .36411 .16868 .38356 .19808 .37308 .17739 .3534 Metetra
.664 .741 .908 r
.17739 .3534 .19808 .37308 .22782 .36247 .20732 .34257 Metetra
.664 .741 .908 r
.20732 .34257 .22782 .36247 .2579 .35174 .23761 .33161 Metetra
.631 .732 .92 r
.23761 .33161 .2579 .35174 .28626 .36856 .26806 .32292 Metetra
.603 .548 .765 r
.26806 .32292 .28626 .36856 .31535 .38764 .29884 .31514 Metetra
.575 .462 .687 r
.29884 .31514 .31535 .38764 .34706 .37661 .32995 .30891 Metetra
.238 .25 .67 r
.32995 .30891 .34706 .37661 .37876 .37394 .35953 .34112 Metetra
.818 .702 .736 r
.35953 .34112 .37876 .37394 .41213 .33982 .39363 .29581 Metetra
.55 .531 .788 r
.39363 .29581 .41213 .33982 .44354 .38021 .42605 .29406 Metetra
.374 .31 .656 r
.42605 .29406 .44354 .38021 .47785 .32475 .45848 .32081 Metetra
.548 .907 .965 r
.45848 .32081 .47785 .32475 .51155 .29488 .49256 .30873 Metetra
.664 .93 .643 r
.49256 .30873 .51155 .29488 .5454 .28648 .52704 .27309 Metetra
.432 .756 .995 r
.52704 .27309 .5454 .28648 .57971 .27588 .56183 .27078 Metetra
.776 .965 .925 r
.56183 .27078 .57971 .27588 .61659 .33753 .59677 .24632 Metetra
.659 .497 .654 r
.59677 .24632 .61659 .33753 .65145 .29668 .63162 .21401 Metetra
.683 .522 .662 r
.63162 .21401 .65145 .29668 .68325 .20115 .66625 .17744 Metetra
.673 .744 .903 r
.66625 .17744 .68325 .20115 .71879 .18739 .70211 .16354 Metetra
.664 .741 .908 r
.70211 .16354 .71879 .18739 .75484 .17454 .73848 .15038 Metetra
.664 .741 .908 r
.73848 .15038 .75484 .17454 .79135 .16152 .77531 .13705 Metetra
.664 .741 .908 r
.12646 .34425 .14779 .36411 .17739 .3534 .15624 .33331 Metetra
.664 .741 .908 r
.15624 .33331 .17739 .3534 .20732 .34257 .18638 .32224 Metetra
.664 .741 .908 r
.18638 .32224 .20732 .34257 .23761 .33161 .21688 .31104 Metetra
.664 .741 .908 r
.21688 .31104 .23761 .33161 .26806 .32292 .24773 .29971 Metetra
.662 .717 .89 r
.24773 .29971 .26806 .32292 .29884 .31514 .27896 .28824 Metetra
.657 .686 .865 r
.27896 .28824 .29884 .31514 .32995 .30891 .31056 .27663 Metetra
.385 .514 .865 r
.31056 .27663 .32995 .30891 .35953 .34112 .34141 .28404 Metetra
.533 .475 .736 r
.34141 .28404 .35953 .34112 .39363 .29581 .3734 .28397 Metetra
.433 .773 .997 r
.3734 .28397 .39363 .29581 .42605 .29406 .40615 .28092 Metetra
.013 .501 .871 r
.40615 .28092 .42605 .29406 .45848 .32081 .43915 .2906 Metetra
.806 .724 .774 r
.43915 .2906 .45848 .32081 .49256 .30873 .47383 .25342 Metetra
.691 .577 .721 r
.47383 .25342 .49256 .30873 .52704 .27309 .50832 .22707 Metetra
.753 .636 .731 r
.50832 .22707 .52704 .27309 .56183 .27078 .54287 .19132 Metetra
.591 .467 .679 r
.54287 .19132 .56183 .27078 .59677 .24632 .57776 .17988 Metetra
.613 .505 .707 r
.57776 .17988 .59677 .24632 .63162 .21401 .61306 .16606 Metetra
.634 .572 .767 r
.61306 .16606 .63162 .21401 .66625 .17744 .64881 .15241 Metetra
.663 .732 .901 r
.64881 .15241 .66625 .17744 .70211 .16354 .68503 .13911 Metetra
.664 .741 .908 r
.68503 .13911 .70211 .16354 .73848 .15038 .72172 .12564 Metetra
.664 .741 .908 r
.72172 .12564 .73848 .15038 .77531 .13705 .75889 .11199 Metetra
.664 .741 .908 r
.10466 .32395 .12646 .34425 .15624 .33331 .13464 .31277 Metetra
.664 .741 .908 r
.13464 .31277 .15624 .33331 .18638 .32224 .16498 .30146 Metetra
.664 .741 .908 r
.16498 .30146 .18638 .32224 .21688 .31104 .19568 .29001 Metetra
.664 .741 .908 r
.19568 .29001 .21688 .31104 .24773 .29971 .22676 .27843 Metetra
.664 .741 .908 r
.22676 .27843 .24773 .29971 .27896 .28824 .2582 .26671 Metetra
.664 .741 .908 r
.2582 .26671 .27896 .28824 .31056 .27663 .29003 .25484 Metetra
.664 .741 .908 r
.29003 .25484 .31056 .27663 .34141 .28404 .32225 .24283 Metetra
.586 .568 .801 r
.32225 .24283 .34141 .28404 .3734 .28397 .35454 .23655 Metetra
.614 .557 .767 r
.35454 .23655 .3734 .28397 .40615 .28092 .38753 .22618 Metetra
.649 .553 .733 r
.38753 .22618 .40615 .28092 .43915 .2906 .42122 .20865 Metetra
.565 .445 .675 r
.42122 .20865 .43915 .2906 .47383 .25342 .45497 .20191 Metetra
.652 .567 .746 r
.45497 .20191 .47383 .25342 .50832 .22707 .4894 .18458 Metetra
.666 .611 .783 r
.4894 .18458 .50832 .22707 .54287 .19132 .52416 .16755 Metetra
.664 .741 .908 r
.52416 .16755 .54287 .19132 .57776 .17988 .55932 .15444 Metetra
.662 .728 .898 r
.55932 .15444 .57776 .17988 .61306 .16606 .59493 .14117 Metetra
.663 .736 .904 r
.59493 .14117 .61306 .16606 .64881 .15241 .631 .12772 Metetra
.664 .741 .908 r
.631 .12772 .64881 .15241 .68503 .13911 .66754 .1141 Metetra
.664 .741 .908 r
.66754 .1141 .68503 .13911 .72172 .12564 .70456 .10029 Metetra
.664 .741 .908 r
.70456 .10029 .72172 .12564 .75889 .11199 .74207 .08631 Metetra
.664 .741 .908 r
.08238 .30321 .10466 .32395 .13464 .31277 .11256 .29178 Metetra
.664 .741 .908 r
.11256 .29178 .13464 .31277 .16498 .30146 .14311 .28022 Metetra
.664 .741 .908 r
.14311 .28022 .16498 .30146 .19568 .29001 .17402 .26852 Metetra
.664 .741 .908 r
.17402 .26852 .19568 .29001 .22676 .27843 .20531 .25667 Metetra
.664 .741 .908 r
.20531 .25667 .22676 .27843 .2582 .26671 .23698 .24468 Metetra
.664 .741 .908 r
.23698 .24468 .2582 .26671 .29003 .25484 .26904 .23255 Metetra
.664 .741 .908 r
.26904 .23255 .29003 .25484 .32225 .24283 .3015 .22026 Metetra
.664 .741 .908 r
.3015 .22026 .32225 .24283 .35454 .23655 .33436 .20782 Metetra
.657 .687 .866 r
.33436 .20782 .35454 .23655 .38753 .22618 .36763 .19522 Metetra
.654 .671 .854 r
.36763 .19522 .38753 .22618 .42122 .20865 .40132 .18247 Metetra
.661 .715 .888 r
.40132 .18247 .42122 .20865 .45497 .20191 .43544 .16955 Metetra
.653 .665 .849 r
.43544 .16955 .45497 .20191 .4894 .18458 .47 .15647 Metetra
.659 .703 .879 r
.47 .15647 .4894 .18458 .52416 .16755 .505 .14322 Metetra
.664 .741 .908 r
.505 .14322 .52416 .16755 .55932 .15444 .54045 .1298 Metetra
.664 .741 .908 r
.54045 .1298 .55932 .15444 .59493 .14117 .57637 .1162 Metetra
.664 .741 .908 r
.57637 .1162 .59493 .14117 .631 .12772 .61276 .10243 Metetra
.664 .741 .908 r
.61276 .10243 .631 .12772 .66754 .1141 .64962 .08847 Metetra
.664 .741 .908 r
.64962 .08847 .66754 .1141 .70456 .10029 .68698 .07433 Metetra
.664 .741 .908 r
.68698 .07433 .70456 .10029 .74207 .08631 .72483 .06 Metetra
.664 .741 .908 r
.05962 .28201 .08238 .30321 .11256 .29178 .08999 .27033 Metetra
.664 .741 .908 r
.08999 .27033 .11256 .29178 .14311 .28022 .12074 .25851 Metetra
.664 .741 .908 r
.12074 .25851 .14311 .28022 .17402 .26852 .15187 .24654 Metetra
.664 .741 .908 r
.15187 .24654 .17402 .26852 .20531 .25667 .18337 .23442 Metetra
.664 .741 .908 r
.18337 .23442 .20531 .25667 .23698 .24468 .21527 .22216 Metetra
.664 .741 .908 r
.21527 .22216 .23698 .24468 .26904 .23255 .24756 .20974 Metetra
.664 .741 .908 r
.24756 .20974 .26904 .23255 .3015 .22026 .28026 .19717 Metetra
.664 .741 .908 r
.28026 .19717 .3015 .22026 .33436 .20782 .31337 .18444 Metetra
.664 .741 .908 r
.31337 .18444 .33436 .20782 .36763 .19522 .3469 .17155 Metetra
.664 .741 .908 r
.3469 .17155 .36763 .19522 .40132 .18247 .38086 .1585 Metetra
.664 .741 .908 r
.38086 .1585 .40132 .18247 .43544 .16955 .41525 .14527 Metetra
.664 .741 .908 r
.41525 .14527 .43544 .16955 .47 .15647 .45009 .13188 Metetra
.664 .741 .908 r
.45009 .13188 .47 .15647 .505 .14322 .48538 .11831 Metetra
.664 .741 .908 r
.48538 .11831 .505 .14322 .54045 .1298 .52114 .10456 Metetra
.664 .741 .908 r
.52114 .10456 .54045 .1298 .57637 .1162 .55736 .09063 Metetra
.664 .741 .908 r
.55736 .09063 .57637 .1162 .61276 .10243 .59407 .07652 Metetra
.664 .741 .908 r
.59407 .07652 .61276 .10243 .64962 .08847 .63126 .06222 Metetra
.664 .741 .908 r
.63126 .06222 .64962 .08847 .68698 .07433 .66896 .04773 Metetra
.664 .741 .908 r
.66896 .04773 .68698 .07433 .72483 .06 .70716 .03304 Metetra
.664 .741 .908 r
.03634 .26033 .05962 .28201 .08999 .27033 .06692 .24839 Metetra
.664 .741 .908 r
.06692 .24839 .08999 .27033 .12074 .25851 .09787 .2363 Metetra
.664 .741 .908 r
.09787 .2363 .12074 .25851 .15187 .24654 .12921 .22406 Metetra
.664 .741 .908 r
.12921 .22406 .15187 .24654 .18337 .23442 .16094 .21167 Metetra
.664 .741 .908 r
.16094 .21167 .18337 .23442 .21527 .22216 .19306 .19912 Metetra
.664 .741 .908 r
.19306 .19912 .21527 .22216 .24756 .20974 .22559 .18641 Metetra
.664 .741 .908 r
.22559 .18641 .24756 .20974 .28026 .19717 .25853 .17355 Metetra
.664 .741 .908 r
.25853 .17355 .28026 .19717 .31337 .18444 .29189 .16051 Metetra
.664 .741 .908 r
.29189 .16051 .31337 .18444 .3469 .17155 .32568 .14732 Metetra
.664 .741 .908 r
.32568 .14732 .3469 .17155 .38086 .1585 .35991 .13395 Metetra
.664 .741 .908 r
.35991 .13395 .38086 .1585 .41525 .14527 .39458 .12041 Metetra
.664 .741 .908 r
.39458 .12041 .41525 .14527 .45009 .13188 .4297 .10669 Metetra
.664 .741 .908 r
.4297 .10669 .45009 .13188 .48538 .11831 .46529 .09279 Metetra
.664 .741 .908 r
.46529 .09279 .48538 .11831 .52114 .10456 .50134 .0787 Metetra
.664 .741 .908 r
.50134 .0787 .52114 .10456 .55736 .09063 .53788 .06443 Metetra
.664 .741 .908 r
.53788 .06443 .55736 .09063 .59407 .07652 .57491 .04997 Metetra
.664 .741 .908 r
.57491 .04997 .59407 .07652 .63126 .06222 .61244 .03531 Metetra
.664 .741 .908 r
.61244 .03531 .63126 .06222 .66896 .04773 .65049 .02045 Metetra
.664 .741 .908 r
.65049 .02045 .66896 .04773 .70716 .03304 .68905 .00539 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(10)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(15)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(20)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.015625 0.64881 0.313244 MathSubStart
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.5 .82364 -10.625 0 ]
[.5 .82364 10.625 12.9375 ]
[.15237 .19707 -5.94882 -9 ]
[.15237 .19707 .05118 0 ]
[.31741 .13214 -11.2392 -9 ]
[.31741 .13214 .76076 0 ]
[.49342 .06293 -10.5808 -9 ]
[.49342 .06293 1.41915 0 ]
[.68156 -0.01098 -9.92245 -9 ]
[.68156 -0.01098 2.07755 0 ]
[.77078 .10213 0 -6.15691 ]
[.77078 .10213 6 2.84309 ]
[.84915 .22213 0 -6.0419 ]
[.84915 .22213 12 2.9581 ]
[.9191 .32925 0 -5.94182 ]
[.9191 .32925 12 3.05818 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 12 3.14607 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .82364 -71.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(f) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(i) show
75.000 14.562 moveto
(j) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(10)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(15)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(20)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75847 .10666 m
.75231 .10893 L
s
[(5)] .77078 .10213 -1 .3682 Mshowa
.83673 .22638 m
.83053 .22851 L
s
[(10)] .84915 .22213 -1 .34264 Mshowa
.9066 .33325 m
.90035 .33526 L
s
[(15)] .9191 .32925 -1 .3204 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(20)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.77486 .13175 m
.77116 .13309 L
s
.79088 .15624 m
.78717 .15756 L
s
.80652 .18016 m
.8028 .18147 L
s
.8218 .20354 m
.81808 .20483 L
s
.85133 .24872 m
.8476 .24998 L
s
.86561 .27055 m
.86188 .2718 L
s
.87957 .29191 m
.87583 .29314 L
s
.89323 .31281 m
.88949 .31402 L
s
.91968 .35327 m
.91593 .35445 L
s
.93249 .37286 m
.92873 .37403 L
s
.94503 .39204 m
.94127 .3932 L
s
.95731 .41083 m
.95355 .41198 L
s
.74167 .08097 m
.73798 .08235 L
s
.72446 .05465 m
.72078 .05604 L
s
.70682 .02766 m
.70315 .02908 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.663 .722 .893 r
.38107 .78681 .39811 .80437 .42673 .79589 .40987 .77812 Metetra
.69 .729 .88 r
.40987 .77812 .42673 .79589 .45569 .78513 .43901 .76687 Metetra
.71 .73 .866 r
.43901 .76687 .45569 .78513 .48492 .77233 .46845 .75328 Metetra
.724 .728 .853 r
.46845 .75328 .48492 .77233 .5144 .75787 .49813 .73777 Metetra
.731 .722 .842 r
.49813 .73777 .5144 .75787 .54408 .74229 .52801 .72087 Metetra
.732 .712 .832 r
.52801 .72087 .54408 .74229 .57394 .72628 .55806 .7033 Metetra
.726 .699 .825 r
.55806 .7033 .57394 .72628 .60401 .71063 .58828 .68599 Metetra
.71 .683 .822 r
.58828 .68599 .60401 .71063 .63432 .69624 .61873 .67024 Metetra
.693 .668 .822 r
.61873 .67024 .63432 .69624 .66493 .68375 .64945 .65649 Metetra
.666 .65 .825 r
.64945 .65649 .66493 .68375 .69594 .67377 .68058 .64588 Metetra
.634 .633 .832 r
.68058 .64588 .69594 .67377 .72743 .66656 .71222 .63889 Metetra
.608 .624 .841 r
.71222 .63889 .72743 .66656 .75947 .66177 .74442 .63461 Metetra
.584 .618 .851 r
.74442 .63461 .75947 .66177 .79209 .65896 .77724 .63255 Metetra
.564 .615 .862 r
.77724 .63255 .79209 .65896 .82532 .65754 .8107 .63215 Metetra
.551 .619 .873 r
.8107 .63215 .82532 .65754 .85913 .65677 .8448 .63254 Metetra
.55 .63 .884 r
.8448 .63254 .85913 .65677 .89348 .65583 .87945 .63269 Metetra
.56 .648 .894 r
.87945 .63269 .89348 .65583 .92827 .65395 .91457 .63168 Metetra
.579 .668 .9 r
.91457 .63168 .92827 .65395 .96342 .65048 .95005 .62882 Metetra
.605 .689 .902 r
.95005 .62882 .96342 .65048 .99883 .64493 .98577 .62359 Metetra
.664 .702 .875 r
.36382 .76701 .38107 .78681 .40987 .77812 .39277 .75802 Metetra
.692 .709 .861 r
.39277 .75802 .40987 .77812 .43901 .76687 .4221 .74603 Metetra
.713 .71 .845 r
.4221 .74603 .43901 .76687 .46845 .75328 .45174 .73126 Metetra
.727 .705 .83 r
.45174 .73126 .46845 .75328 .49813 .73777 .48162 .71413 Metetra
.734 .696 .815 r
.48162 .71413 .49813 .73777 .52801 .72087 .51169 .6952 Metetra
.734 .684 .802 r
.51169 .6952 .52801 .72087 .55806 .7033 .54189 .67516 Metetra
.728 .668 .791 r
.54189 .67516 .55806 .7033 .58828 .68599 .57223 .65489 Metetra
.705 .643 .785 r
.57223 .65489 .58828 .68599 .61873 .67024 .60276 .63735 Metetra
.693 .63 .781 r
.60276 .63735 .61873 .67024 .64945 .65649 .63352 .62118 Metetra
.661 .604 .781 r
.63352 .62118 .64945 .65649 .68058 .64588 .66467 .60947 Metetra
.619 .579 .787 r
.66467 .60947 .68058 .64588 .71222 .63889 .69643 .60361 Metetra
.598 .575 .799 r
.69643 .60361 .71222 .63889 .74442 .63461 .72875 .60033 Metetra
.576 .57 .809 r
.72875 .60033 .74442 .63461 .77724 .63255 .76173 .59954 Metetra
.553 .566 .821 r
.76173 .59954 .77724 .63255 .8107 .63215 .79543 .601 Metetra
.538 .572 .836 r
.79543 .601 .8107 .63215 .8448 .63254 .82984 .60356 Metetra
.538 .588 .853 r
.82984 .60356 .8448 .63254 .87945 .63269 .86483 .60563 Metetra
.55 .611 .867 r
.86483 .60563 .87945 .63269 .91457 .63168 .9003 .60615 Metetra
.571 .637 .878 r
.9003 .60615 .91457 .63168 .95005 .62882 .93612 .60433 Metetra
.6 .663 .883 r
.93612 .60433 .95005 .62882 .98577 .62359 .97217 .59968 Metetra
.664 .688 .862 r
.34635 .74537 .36382 .76701 .39277 .75802 .37545 .736 Metetra
.696 .696 .846 r
.37545 .736 .39277 .75802 .4221 .74603 .40497 .72303 Metetra
.719 .696 .828 r
.40497 .72303 .4221 .74603 .45174 .73126 .43482 .70667 Metetra
.733 .691 .81 r
.43482 .70667 .45174 .73126 .48162 .71413 .46491 .68735 Metetra
.739 .68 .793 r
.46491 .68735 .48162 .71413 .51169 .6952 .49516 .66573 Metetra
.74 .666 .777 r
.49516 .66573 .51169 .6952 .54189 .67516 .52552 .64236 Metetra
.736 .649 .763 r
.52552 .64236 .54189 .67516 .57223 .65489 .55595 .61788 Metetra
.697 .614 .76 r
.55595 .61788 .57223 .65489 .60276 .63735 .58654 .59931 Metetra
.697 .611 .757 r
.58654 .59931 .60276 .63735 .63352 .62118 .6173 .58037 Metetra
.656 .58 .758 r
.6173 .58037 .63352 .62118 .66467 .60947 .64846 .56801 Metetra
.622 .561 .765 r
.64846 .56801 .66467 .60947 .69643 .60361 .68016 .56095 Metetra
.588 .539 .767 r
.68016 .56095 .69643 .60361 .72875 .60033 .71253 .55875 Metetra
.566 .532 .776 r
.71253 .55875 .72875 .60033 .76173 .59954 .74561 .55944 Metetra
.534 .521 .787 r
.74561 .55944 .76173 .59954 .79543 .601 .77955 .56389 Metetra
.512 .525 .806 r
.77955 .56389 .79543 .601 .82984 .60356 .81431 .57008 Metetra
.514 .548 .828 r
.81431 .57008 .82984 .60356 .86483 .60563 .84968 .57511 Metetra
.531 .578 .848 r
.84968 .57511 .86483 .60563 .9003 .60615 .88553 .57781 Metetra
.558 .611 .862 r
.88553 .57781 .9003 .60615 .93612 .60433 .92172 .57748 Metetra
.591 .642 .87 r
.92172 .57748 .93612 .60433 .97217 .59968 .9581 .57365 Metetra
.666 .681 .854 r
.32865 .72247 .34635 .74537 .37545 .736 .3579 .71264 Metetra
.702 .69 .835 r
.3579 .71264 .37545 .736 .40497 .72303 .38762 .69845 Metetra
.727 .69 .814 r
.38762 .69845 .40497 .72303 .43482 .70667 .4177 .68008 Metetra
.743 .683 .793 r
.4177 .68008 .43482 .70667 .46491 .68735 .44801 .65794 Metetra
.747 .669 .775 r
.44801 .65794 .46491 .68735 .49516 .66573 .47847 .63316 Metetra
.744 .654 .761 r
.47847 .63316 .49516 .66573 .52552 .64236 .50898 .60709 Metetra
.733 .639 .754 r
.50898 .60709 .52552 .64236 .55595 .61788 .53953 .5818 Metetra
.713 .627 .76 r
.53953 .5818 .55595 .61788 .58654 .59931 .57019 .56055 Metetra
.696 .609 .755 r
.57019 .56055 .58654 .59931 .6173 .58037 .60101 .54136 Metetra
.662 .591 .766 r
.60101 .54136 .6173 .58037 .64846 .56801 .6322 .52826 Metetra
.634 .575 .771 r
.6322 .52826 .64846 .56801 .68016 .56095 .66385 .51939 Metetra
.592 .546 .772 r
.66385 .51939 .68016 .56095 .71253 .55875 .69618 .51633 Metetra
.567 .53 .773 r
.69618 .51633 .71253 .55875 .74561 .55944 .72922 .51666 Metetra
.534 .511 .776 r
.72922 .51666 .74561 .55944 .77955 .56389 .76313 .52111 Metetra
.47 .475 .781 r
.76313 .52111 .77955 .56389 .81431 .57008 .79833 .53293 Metetra
.48 .51 .811 r
.79833 .53293 .81431 .57008 .84968 .57511 .83412 .54194 Metetra
.504 .549 .835 r
.83412 .54194 .84968 .57511 .88553 .57781 .87037 .5474 Metetra
.539 .589 .852 r
.87037 .5474 .88553 .57781 .92172 .57748 .90693 .54893 Metetra
.58 .626 .862 r
.90693 .54893 .92172 .57748 .9581 .57365 .94366 .54612 Metetra
.669 .68 .852 r
.31068 .69901 .32865 .72247 .3579 .71264 .34009 .68867 Metetra
.71 .691 .829 r
.34009 .68867 .3579 .71264 .38762 .69845 .37002 .6731 Metetra
.739 .691 .804 r
.37002 .6731 .38762 .69845 .4177 .68008 .40035 .65231 Metetra
.758 .683 .779 r
.40035 .65231 .4177 .68008 .44801 .65794 .43095 .62628 Metetra
.759 .665 .757 r
.43095 .62628 .44801 .65794 .47847 .63316 .46165 .59706 Metetra
.744 .64 .746 r
.46165 .59706 .47847 .63316 .50898 .60709 .49231 .56872 Metetra
.724 .624 .746 r
.49231 .56872 .50898 .60709 .53953 .5818 .52297 .54382 Metetra
.716 .622 .751 r
.52297 .54382 .53953 .5818 .57019 .56055 .5537 .52093 Metetra
.695 .606 .753 r
.5537 .52093 .57019 .56055 .60101 .54136 .5846 .50152 Metetra
.654 .585 .765 r
.5846 .50152 .60101 .54136 .6322 .52826 .61586 .48934 Metetra
.648 .587 .772 r
.61586 .48934 .6322 .52826 .66385 .51939 .64747 .47823 Metetra
.581 .543 .777 r
.64747 .47823 .66385 .51939 .69618 .51633 .67985 .47626 Metetra
.552 .532 .787 r
.67985 .47626 .69618 .51633 .72922 .51666 .71296 .47778 Metetra
.53 .527 .797 r
.71296 .47778 .72922 .51666 .76313 .52111 .74684 .48154 Metetra
.437 .472 .798 r
.74684 .48154 .76313 .52111 .79833 .53293 .78213 .4948 Metetra
.439 .482 .807 r
.78213 .4948 .79833 .53293 .83412 .54194 .81827 .50742 Metetra
.471 .524 .831 r
.81827 .50742 .83412 .54194 .87037 .5474 .85491 .51589 Metetra
.515 .571 .85 r
.85491 .51589 .87037 .5474 .90693 .54893 .89186 .51951 Metetra
.566 .616 .862 r
.89186 .51951 .90693 .54893 .94366 .54612 .92893 .51787 Metetra
.673 .687 .855 r
.29238 .67583 .31068 .69901 .34009 .68867 .32196 .66494 Metetra
.72 .698 .828 r
.32196 .66494 .34009 .68867 .37002 .6731 .35213 .64798 Metetra
.752 .698 .8 r
.35213 .64798 .37002 .6731 .40035 .65231 .38274 .62488 Metetra
.774 .691 .772 r
.38274 .62488 .40035 .65231 .43095 .62628 .41365 .5955 Metetra
.784 .678 .748 r
.41365 .5955 .43095 .62628 .46165 .59706 .44467 .56046 Metetra
.759 .646 .737 r
.44467 .56046 .46165 .59706 .49231 .56872 .47554 .52782 Metetra
.711 .61 .742 r
.47554 .52782 .49231 .56872 .52297 .54382 .50627 .50445 Metetra
.709 .615 .749 r
.50627 .50445 .52297 .54382 .5537 .52093 .5371 .48228 Metetra
.7 .613 .757 r
.5371 .48228 .5537 .52093 .5846 .50152 .56808 .46238 Metetra
.658 .592 .769 r
.56808 .46238 .5846 .50152 .61586 .48934 .59937 .44954 Metetra
.652 .586 .769 r
.59937 .44954 .61586 .48934 .64747 .47823 .631 .43755 Metetra
.554 .531 .784 r
.631 .43755 .64747 .47823 .67985 .47626 .6635 .43852 Metetra
.524 .529 .803 r
.6635 .43852 .67985 .47626 .71296 .47778 .69676 .44233 Metetra
.515 .539 .819 r
.69676 .44233 .71296 .47778 .74684 .48154 .73071 .44649 Metetra
.449 .506 .825 r
.73071 .44649 .74684 .48154 .78213 .4948 .76578 .45637 Metetra
.396 .457 .806 r
.76578 .45637 .78213 .4948 .81827 .50742 .80221 .47228 Metetra
.427 .497 .829 r
.80221 .47228 .81827 .50742 .85491 .51589 .83925 .48424 Metetra
.483 .555 .854 r
.83925 .48424 .85491 .51589 .89186 .51951 .8766 .4902 Metetra
.548 .611 .868 r
.8766 .4902 .89186 .51951 .92893 .51787 .91402 .48979 Metetra
.678 .701 .864 r
.27367 .65373 .29238 .67583 .32196 .66494 .30344 .6423 Metetra
.732 .712 .833 r
.30344 .6423 .32196 .66494 .35213 .64798 .33387 .62403 Metetra
.767 .712 .801 r
.33387 .62403 .35213 .64798 .38274 .62488 .36479 .59883 Metetra
.787 .705 .773 r
.36479 .59883 .38274 .62488 .41365 .5955 .39602 .56736 Metetra
.795 .696 .756 r
.39602 .56736 .41365 .5955 .44467 .56046 .4273 .53194 Metetra
.786 .693 .761 r
.4273 .53194 .44467 .56046 .47554 .52782 .45842 .49892 Metetra
.761 .684 .778 r
.45842 .49892 .47554 .52782 .50627 .50445 .48938 .47201 Metetra
.73 .655 .775 r
.48938 .47201 .50627 .50445 .5371 .48228 .52036 .44926 Metetra
.712 .646 .781 r
.52036 .44926 .5371 .48228 .56808 .46238 .55148 .42948 Metetra
.686 .636 .794 r
.55148 .42948 .56808 .46238 .59937 .44954 .58284 .41396 Metetra
.64 .602 .795 r
.58284 .41396 .59937 .44954 .631 .43755 .61461 .40421 Metetra
.538 .563 .828 r
.61461 .40421 .631 .43755 .6635 .43852 .64719 .40547 Metetra
.512 .553 .834 r
.64719 .40547 .6635 .43852 .69676 .44233 .68049 .40895 Metetra
.471 .53 .836 r
.68049 .40895 .69676 .44233 .73071 .44649 .71467 .41586 Metetra
.431 .529 .857 r
.71467 .41586 .73071 .44649 .76578 .45637 .74977 .42474 Metetra
.363 .484 .848 r
.74977 .42474 .76578 .45637 .80221 .47228 .78612 .4389 Metetra
.371 .478 .839 r
.78612 .4389 .80221 .47228 .83925 .48424 .8235 .4537 Metetra
.44 .543 .865 r
.8235 .4537 .83925 .48424 .8766 .4902 .86126 .46212 Metetra
.527 .614 .882 r
.86126 .46212 .8766 .4902 .91402 .48979 .89904 .46286 Metetra
.685 .724 .879 r
.25447 .6335 .27367 .65373 .30344 .6423 .28444 .62149 Metetra
.744 .733 .841 r
.28444 .62149 .30344 .6423 .33387 .62403 .31516 .60202 Metetra
.783 .732 .805 r
.31516 .60202 .33387 .62403 .36479 .59883 .34643 .57499 Metetra
.795 .722 .784 r
.34643 .57499 .36479 .59883 .39602 .56736 .37792 .54373 Metetra
.806 .727 .777 r
.37792 .54373 .39602 .56736 .4273 .53194 .40945 .50983 Metetra
.818 .74 .778 r
.40945 .50983 .4273 .53194 .45842 .49892 .44092 .47463 Metetra
.796 .724 .785 r
.44092 .47463 .45842 .49892 .48938 .47201 .4722 .44357 Metetra
.752 .687 .79 r
.4722 .44357 .48938 .47201 .52036 .44926 .5034 .419 Metetra
.741 .674 .786 r
.5034 .419 .52036 .44926 .55148 .42948 .53467 .39547 Metetra
.681 .63 .792 r
.53467 .39547 .55148 .42948 .58284 .41396 .56615 .38032 Metetra
.585 .587 .821 r
.56615 .38032 .58284 .41396 .61461 .40421 .59818 .3768 Metetra
.479 .58 .878 r
.59818 .3768 .61461 .40421 .64719 .40547 .63096 .3807 Metetra
.465 .6 .901 r
.63096 .3807 .64719 .40547 .68049 .40895 .66442 .38449 Metetra
.437 .59 .906 r
.66442 .38449 .68049 .40895 .71467 .41586 .69867 .38977 Metetra
.376 .541 .891 r
.69867 .38977 .71467 .41586 .74977 .42474 .73395 .39937 Metetra
.347 .534 .896 r
.73395 .39937 .74977 .42474 .78612 .4389 .7702 .41024 Metetra
.299 .475 .866 r
.7702 .41024 .78612 .4389 .8235 .4537 .80781 .42618 Metetra
.381 .538 .887 r
.80781 .42618 .8235 .4537 .86126 .46212 .84594 .43661 Metetra
.502 .628 .907 r
.84594 .43661 .86126 .46212 .89904 .46286 .88406 .43803 Metetra
.692 .754 .899 r
.23466 .61571 .25447 .6335 .28444 .62149 .26488 .60314 Metetra
.758 .761 .854 r
.26488 .60314 .28444 .62149 .31516 .60202 .29591 .58262 Metetra
.804 .757 .809 r
.29591 .58262 .31516 .60202 .34643 .57499 .32762 .55298 Metetra
.8 .738 .795 r
.32762 .55298 .34643 .57499 .37792 .54373 .35937 .52223 Metetra
.806 .745 .796 r
.35937 .52223 .37792 .54373 .40945 .50983 .39112 .49082 Metetra
.826 .767 .797 r
.39112 .49082 .40945 .50983 .44092 .47463 .4229 .45702 Metetra
.83 .782 .807 r
.4229 .45702 .44092 .47463 .4722 .44357 .45457 .42415 Metetra
.786 .766 .835 r
.45457 .42415 .4722 .44357 .5034 .419 .48607 .39909 Metetra
.791 .765 .83 r
.48607 .39909 .5034 .419 .53467 .39547 .51764 .37299 Metetra
.722 .729 .856 r
.51764 .37299 .53467 .39547 .56615 .38032 .54934 .35589 Metetra
.518 .63 .901 r
.54934 .35589 .56615 .38032 .59818 .3768 .5816 .35607 Metetra
.341 .581 .931 r
.5816 .35607 .59818 .3768 .63096 .3807 .61466 .36348 Metetra
.343 .629 .959 r
.61466 .36348 .63096 .3807 .66442 .38449 .6484 .36868 Metetra
.315 .635 .964 r
.6484 .36868 .66442 .38449 .69867 .38977 .68291 .37399 Metetra
.266 .607 .955 r
.68291 .37399 .69867 .38977 .73395 .39937 .71829 .38114 Metetra
.272 .578 .942 r
.71829 .38114 .73395 .39937 .7702 .41024 .75464 .39008 Metetra
.162 .485 .9 r
.75464 .39008 .7702 .41024 .80781 .42618 .79242 .40534 Metetra
.305 .57 .932 r
.79242 .40534 .80781 .42618 .84594 .43661 .83074 .41502 Metetra
.477 .662 .943 r
.83074 .41502 .84594 .43661 .88406 .43803 .86912 .41606 Metetra
.695 .788 .922 r
.21418 .60056 .23466 .61571 .26488 .60314 .24464 .58771 Metetra
.765 .794 .877 r
.24464 .58771 .26488 .60314 .29591 .58262 .27593 .5674 Metetra
.812 .798 .838 r
.27593 .5674 .29591 .58262 .32762 .55298 .30788 .53942 Metetra
.838 .814 .827 r
.30788 .53942 .32762 .55298 .35937 .52223 .34008 .50737 Metetra
.838 .804 .818 r
.34008 .50737 .35937 .52223 .39112 .49082 .37228 .47427 Metetra
.82 .793 .827 r
.37228 .47427 .39112 .49082 .4229 .45702 .40429 .44437 Metetra
.847 .833 .833 r
.40429 .44437 .4229 .45702 .45457 .42415 .43635 .41208 Metetra
.829 .847 .861 r
.43635 .41208 .45457 .42415 .48607 .39909 .46828 .38415 Metetra
.768 .818 .892 r
.46828 .38415 .48607 .39909 .51764 .37299 .50018 .36371 Metetra
.65 .873 .982 r
.50018 .36371 .51764 .37299 .54934 .35589 .53227 .35187 Metetra
.291 .771 .924 r
.53227 .35187 .54934 .35589 .5816 .35607 .56484 .34848 Metetra
.112 .619 .897 r
.56484 .34848 .5816 .35607 .61466 .36348 .59812 .35268 Metetra
.202 .641 .948 r
.59812 .35268 .61466 .36348 .6484 .36868 .63215 .35731 Metetra
.253 .666 .964 r
.63215 .35731 .6484 .36868 .68291 .37399 .66688 .36092 Metetra
.253 .643 .963 r
.66688 .36092 .68291 .37399 .71829 .38114 .70245 .36596 Metetra
.16 .555 .929 r
.70245 .36596 .71829 .38114 .75464 .39008 .73917 .37607 Metetra
.063 .503 .895 r
.73917 .37607 .75464 .39008 .79242 .40534 .77704 .38873 Metetra
.251 .597 .95 r
.77704 .38873 .79242 .40534 .83074 .41502 .81555 .39701 Metetra
.456 .701 .973 r
.81555 .39701 .83074 .41502 .86912 .41606 .85418 .39699 Metetra
.694 .82 .943 r
.19297 .58772 .21418 .60056 .24464 .58771 .22369 .57471 Metetra
.766 .825 .899 r
.22369 .57471 .24464 .58771 .27593 .5674 .25525 .55489 Metetra
.813 .829 .862 r
.25525 .55489 .27593 .5674 .30788 .53942 .28747 .5283 Metetra
.847 .84 .838 r
.28747 .5283 .30788 .53942 .34008 .50737 .3201 .49591 Metetra
.852 .839 .832 r
.3201 .49591 .34008 .50737 .37228 .47427 .35273 .46244 Metetra
.839 .843 .848 r
.35273 .46244 .37228 .47427 .40429 .44437 .38517 .43199 Metetra
.836 .842 .851 r
.38517 .43199 .40429 .44437 .43635 .41208 .41757 .40218 Metetra
.831 .876 .877 r
.41757 .40218 .43635 .41208 .46828 .38415 .44992 .37468 Metetra
.758 .889 .937 r
.44992 .37468 .46828 .38415 .50018 .36371 .4822 .35556 Metetra
.515 .844 .998 r
.4822 .35556 .50018 .36371 .53227 .35187 .51465 .34861 Metetra
.257 .755 .899 r
.51465 .34861 .53227 .35187 .56484 .34848 .5476 .34523 Metetra
.18 .705 .867 r
.5476 .34523 .56484 .34848 .59812 .35268 .58115 .34366 Metetra
.211 .673 .944 r
.58115 .34366 .59812 .35268 .63215 .35731 .61544 .34624 Metetra
.159 .614 .933 r
.61544 .34624 .63215 .35731 .66688 .36092 .6506 .3521 Metetra
.038 .554 .87 r
.6506 .3521 .66688 .36092 .70245 .36596 .68666 .3596 Metetra
0 .483 .78 r
.68666 .3596 .70245 .36596 .73917 .37607 .72369 .36848 Metetra
0 .517 .827 r
.72369 .36848 .73917 .37607 .77704 .38873 .76166 .37715 Metetra
.209 .644 .951 r
.76166 .37715 .77704 .38873 .81555 .39701 .80028 .38218 Metetra
.443 .743 .992 r
.80028 .38218 .81555 .39701 .85418 .39699 .83915 .38043 Metetra
.689 .844 .957 r
.17102 .57657 .19297 .58772 .22369 .57471 .20202 .56348 Metetra
.762 .849 .916 r
.20202 .56348 .22369 .57471 .25525 .55489 .23386 .54416 Metetra
.813 .853 .878 r
.23386 .54416 .25525 .55489 .28747 .5283 .2664 .51827 Metetra
.854 .853 .84 r
.2664 .51827 .28747 .5283 .3201 .49591 .29953 .48499 Metetra
.851 .849 .84 r
.29953 .48499 .3201 .49591 .35273 .46244 .33257 .45205 Metetra
.839 .863 .861 r
.33257 .45205 .35273 .46244 .38517 .43199 .3654 .42231 Metetra
.825 .879 .883 r
.3654 .42231 .38517 .43199 .41757 .40218 .39813 .39542 Metetra
.813 .919 .909 r
.39813 .39542 .41757 .40218 .44992 .37468 .43087 .37053 Metetra
.722 .948 .953 r
.43087 .37053 .44992 .37468 .4822 .35556 .46358 .35195 Metetra
.381 .827 .942 r
.46358 .35195 .4822 .35556 .51465 .34861 .49643 .34559 Metetra
.288 .777 .904 r
.49643 .34559 .51465 .34861 .5476 .34523 .52979 .34104 Metetra
.293 .773 .922 r
.52979 .34104 .5476 .34523 .58115 .34366 .56371 .33718 Metetra
.265 .738 .94 r
.56371 .33718 .58115 .34366 .61544 .34624 .59828 .33588 Metetra
.165 .63 .932 r
.59828 .33588 .61544 .34624 .6506 .3521 .63372 .34065 Metetra
.066 .548 .894 r
.63372 .34065 .6506 .3521 .68666 .3596 .67017 .34949 Metetra
0 .503 .85 r
.67017 .34949 .68666 .3596 .72369 .36848 .70766 .35981 Metetra
.058 .574 .877 r
.70766 .35981 .72369 .36848 .76166 .37715 .7459 .36664 Metetra
.248 .688 .959 r
.7459 .36664 .76166 .37715 .80028 .38218 .78474 .36896 Metetra
.448 .773 .997 r
.78474 .36896 .80028 .38218 .83915 .38043 .8239 .3655 Metetra
.68 .858 .967 r
.14837 .56641 .17102 .57657 .20202 .56348 .17964 .55343 Metetra
.751 .866 .933 r
.17964 .55343 .20202 .56348 .23386 .54416 .21173 .53498 Metetra
.802 .876 .9 r
.21173 .53498 .23386 .54416 .2664 .51827 .24452 .51086 Metetra
.846 .888 .87 r
.24452 .51086 .2664 .51827 .29953 .48499 .27789 .4806 Metetra
.858 .92 .87 r
.27789 .4806 .29953 .48499 .33257 .45205 .31134 .44906 Metetra
.84 .945 .889 r
.31134 .44906 .33257 .45205 .3654 .42231 .34463 .42022 Metetra
.818 .962 .903 r
.34463 .42022 .3654 .42231 .39813 .39542 .37786 .39353 Metetra
.753 .968 .93 r
.37786 .39353 .39813 .39542 .43087 .37053 .41099 .37166 Metetra
.671 .971 .908 r
.41099 .37166 .43087 .37053 .46358 .35195 .44426 .35174 Metetra
.381 .843 .885 r
.44426 .35174 .46358 .35195 .49643 .34559 .47759 .3424 Metetra
.318 .795 .915 r
.47759 .3424 .49643 .34559 .52979 .34104 .51136 .33701 Metetra
.277 .765 .912 r
.51136 .33701 .52979 .34104 .56371 .33718 .54571 .33324 Metetra
.206 .72 .884 r
.54571 .33324 .56371 .33718 .59828 .33588 .58069 .3312 Metetra
.188 .703 .887 r
.58069 .3312 .59828 .33588 .63372 .34065 .61638 .33021 Metetra
.061 .56 .887 r
.61638 .33021 .63372 .34065 .67017 .34949 .65313 .33798 Metetra
0 .471 .841 r
.65313 .33798 .67017 .34949 .70766 .35981 .69106 .3502 Metetra
.113 .608 .906 r
.69106 .3502 .70766 .35981 .7459 .36664 .72965 .35585 Metetra
.299 .721 .973 r
.72965 .35585 .7459 .36664 .78474 .36896 .76878 .35623 Metetra
.463 .793 .999 r
.76878 .35623 .78474 .36896 .8239 .3655 .8083 .35132 Metetra
.67 .862 .972 r
.12503 .55647 .14837 .56641 .17964 .55343 .15656 .54373 Metetra
.734 .874 .946 r
.15656 .54373 .17964 .55343 .21173 .53498 .18888 .52642 Metetra
.78 .888 .923 r
.18888 .52642 .21173 .53498 .24452 .51086 .22185 .50466 Metetra
.814 .912 .906 r
.22185 .50466 .24452 .51086 .27789 .4806 .25532 .47894 Metetra
.823 .958 .901 r
.25532 .47894 .27789 .4806 .31134 .44906 .28902 .45143 Metetra
.798 .989 .887 r
.28902 .45143 .31134 .44906 .34463 .42022 .32279 .42392 Metetra
.779 .994 .873 r
.32279 .42392 .34463 .42022 .37786 .39353 .35663 .39647 Metetra
.66 .971 .887 r
.35663 .39647 .37786 .39353 .41099 .37166 .39027 .37565 Metetra
.585 .946 .856 r
.39027 .37565 .41099 .37166 .44426 .35174 .42407 .35646 Metetra
.418 .862 .795 r
.42407 .35646 .44426 .35174 .47759 .3424 .45804 .34161 Metetra
.325 .809 .875 r
.45804 .34161 .47759 .3424 .51136 .33701 .4923 .33386 Metetra
.214 .729 .874 r
.4923 .33386 .51136 .33701 .54571 .33324 .52708 .33087 Metetra
.139 .681 .827 r
.52708 .33087 .54571 .33324 .58069 .3312 .56253 .32911 Metetra
.021 .592 .762 r
.56253 .32911 .58069 .3312 .61638 .33021 .59874 .33033 Metetra
.174 0 0 r
.59874 .33033 .61638 .33021 .65313 .33798 .63589 .33572 Metetra
.148 0 0 r
.63589 .33572 .65313 .33798 .69106 .3502 .67403 .34257 Metetra
.143 .652 .9 r
.67403 .34257 .69106 .3502 .72965 .35585 .71289 .34518 Metetra
.344 .753 .981 r
.71289 .34518 .72965 .35585 .76878 .35623 .75235 .34341 Metetra
.485 .808 1 r
.75235 .34341 .76878 .35623 .8083 .35132 .79224 .3371 Metetra
.663 .857 .974 r
.10108 .54591 .12503 .55647 .15656 .54373 .13287 .53342 Metetra
.717 .869 .953 r
.13287 .53342 .15656 .54373 .18888 .52642 .1654 .51715 Metetra
.756 .885 .937 r
.1654 .51715 .18888 .52642 .22185 .50466 .19856 .49738 Metetra
.783 .908 .927 r
.19856 .49738 .22185 .50466 .25532 .47894 .23219 .47474 Metetra
.794 .941 .923 r
.23219 .47474 .25532 .47894 .28902 .45143 .26614 .45041 Metetra
.785 .97 .917 r
.26614 .45041 .28902 .45143 .32279 .42392 .30027 .42542 Metetra
.765 .986 .901 r
.30027 .42542 .32279 .42392 .35663 .39647 .33455 .4001 Metetra
.669 .975 .879 r
.33455 .4001 .35663 .39647 .39027 .37565 .36882 .378 Metetra
.61 .955 .89 r
.36882 .378 .39027 .37565 .42407 .35646 .40317 .359 Metetra
.482 .9 .861 r
.40317 .359 .42407 .35646 .45804 .34161 .43768 .34396 Metetra
.221 .743 .771 r
.43768 .34396 .45804 .34161 .4923 .33386 .47245 .33625 Metetra
.47245 .33625 .4923 .33386 .52708 .33087 .50774 .33263 Metetra
.017 0 0 r
.50774 .33263 .52708 .33087 .56253 .32911 .54371 .33168 Metetra
.064 0 0 r
.54371 .33168 .56253 .32911 .59874 .33033 .58043 .33146 Metetra
.075 0 0 r
.58043 .33146 .59874 .33033 .63589 .33572 .61798 .33283 Metetra
.034 .6 .782 r
.61798 .33283 .63589 .33572 .67403 .34257 .65639 .33433 Metetra
.251 .723 .942 r
.65639 .33433 .67403 .34257 .71289 .34518 .69555 .33359 Metetra
.406 .783 .992 r
.69555 .33359 .71289 .34518 .75235 .34341 .73534 .32965 Metetra
.514 .816 1 r
.73534 .32965 .75235 .34341 .79224 .3371 .77564 .322 Metetra
.661 .844 .971 r
.07661 .53394 .10108 .54591 .13287 .53342 .10865 .52162 Metetra
.705 .855 .954 r
.10865 .52162 .13287 .53342 .1654 .51715 .1414 .50613 Metetra
.738 .869 .942 r
.1414 .50613 .1654 .51715 .19856 .49738 .17477 .48779 Metetra
.76 .888 .935 r
.17477 .48779 .19856 .49738 .23219 .47474 .20861 .46715 Metetra
.772 .912 .934 r
.20861 .46715 .23219 .47474 .26614 .45041 .2428 .44506 Metetra
.771 .937 .937 r
.2428 .44506 .26614 .45041 .30027 .42542 .27724 .42241 Metetra
.753 .959 .937 r
.27724 .42241 .30027 .42542 .33455 .4001 .31186 .40006 Metetra
.69 .97 .926 r
.31186 .40006 .33455 .4001 .36882 .378 .34659 .37936 Metetra
.591 .946 .904 r
.34659 .37936 .36882 .378 .40317 .359 .38143 .36165 Metetra
.435 .875 .848 r
.38143 .36165 .40317 .359 .43768 .34396 .41646 .34782 Metetra
.251 .761 .754 r
.41646 .34782 .43768 .34396 .47245 .33625 .45182 .33799 Metetra
.162 .701 .756 r
.45182 .33799 .47245 .33625 .50774 .33263 .48766 .33213 Metetra
.134 .681 .787 r
.48766 .33213 .50774 .33263 .54371 .33168 .52412 .32873 Metetra
.163 .696 .843 r
.52412 .32873 .54371 .33168 .58043 .33146 .56131 .32641 Metetra
.191 .707 .885 r
.56131 .32641 .58043 .33146 .61798 .33283 .59927 .32486 Metetra
.27 .739 .944 r
.59927 .32486 .61798 .33283 .65639 .33433 .63802 .32308 Metetra
.378 .773 .987 r
.63802 .32308 .65639 .33433 .69555 .33359 .67753 .31975 Metetra
.471 .796 .999 r
.67753 .31975 .69555 .33359 .73534 .32965 .7177 .31398 Metetra
.546 .814 .996 r
.7177 .31398 .73534 .32965 .77564 .322 .75841 .30516 Metetra
.66 .825 .963 r
.05171 .51988 .07661 .53394 .10865 .52162 .08399 .50763 Metetra
.697 .834 .948 r
.08399 .50763 .10865 .52162 .1414 .50613 .11697 .49262 Metetra
.725 .845 .938 r
.11697 .49262 .1414 .50613 .17477 .48779 .15056 .47516 Metetra
.744 .859 .933 r
.15056 .47516 .17477 .48779 .20861 .46715 .18465 .45574 Metetra
.756 .875 .933 r
.18465 .45574 .20861 .46715 .2428 .44506 .21911 .43508 Metetra
.758 .894 .938 r
.21911 .43508 .2428 .44506 .27724 .42241 .25385 .41398 Metetra
.748 .913 .948 r
.25385 .41398 .27724 .42241 .31186 .40006 .28879 .3933 Metetra
.719 .929 .96 r
.28879 .3933 .31186 .40006 .34659 .37936 .3239 .37407 Metetra
.662 .934 .969 r
.3239 .37407 .34659 .37936 .38143 .36165 .35919 .35722 Metetra
.578 .917 .968 r
.35919 .35722 .38143 .36165 .41646 .34782 .39471 .34338 Metetra
.485 .88 .961 r
.39471 .34338 .41646 .34782 .45182 .33799 .43057 .33273 Metetra
.405 .836 .954 r
.43057 .33273 .45182 .33799 .48766 .33213 .46689 .32505 Metetra
.369 .804 .963 r
.46689 .32505 .48766 .33213 .52412 .32873 .50382 .31957 Metetra
.367 .787 .976 r
.50382 .31957 .52412 .32873 .56131 .32641 .54143 .31537 Metetra
.381 .777 .987 r
.54143 .31537 .56131 .32641 .59927 .32486 .5798 .31176 Metetra
.417 .776 .995 r
.5798 .31176 .59927 .32486 .63802 .32308 .61893 .30786 Metetra
.468 .781 .998 r
.61893 .30786 .63802 .32308 .67753 .31975 .6588 .30274 Metetra
.522 .79 .994 r
.6588 .30274 .67753 .31975 .7177 .31398 .69936 .29559 Metetra
.572 .801 .986 r
.69936 .29559 .7177 .31398 .75841 .30516 .7405 .28585 Metetra
.661 .801 .95 r
.02646 .50322 .05171 .51988 .08399 .50763 .05898 .49092 Metetra
.692 .809 .937 r
.05898 .49092 .08399 .50763 .11697 .49262 .0922 .47609 Metetra
.716 .817 .928 r
.0922 .47609 .11697 .49262 .15056 .47516 .12604 .45901 Metetra
.734 .826 .922 r
.12604 .45901 .15056 .47516 .18465 .45574 .16039 .44015 Metetra
.744 .835 .921 r
.16039 .44015 .18465 .45574 .21911 .43508 .19514 .42014 Metetra
.747 .846 .924 r
.19514 .42014 .21911 .43508 .25385 .41398 .23019 .39974 Metetra
.742 .856 .933 r
.23019 .39974 .25385 .41398 .28879 .3933 .26547 .37977 Metetra
.725 .865 .947 r
.26547 .37977 .28879 .3933 .3239 .37407 .30095 .3611 Metetra
.695 .87 .964 r
.30095 .3611 .3239 .37407 .35919 .35722 .33662 .34449 Metetra
.651 .865 .98 r
.33662 .34449 .35919 .35722 .39471 .34338 .37255 .33045 Metetra
.598 .85 .992 r
.37255 .33045 .39471 .34338 .43057 .33273 .40883 .31916 Metetra
.546 .827 .998 r
.40883 .31916 .43057 .33273 .46689 .32505 .44557 .31042 Metetra
.507 .801 .998 r
.44557 .31042 .46689 .32505 .50382 .31957 .48289 .30368 Metetra
.486 .78 .997 r
.48289 .30368 .50382 .31957 .54143 .31537 .52089 .29824 Metetra
.482 .766 .994 r
.52089 .29824 .54143 .31537 .5798 .31176 .55962 .29335 Metetra
.494 .76 .99 r
.55962 .29335 .5798 .31176 .61893 .30786 .59912 .28819 Metetra
.52 .762 .985 r
.59912 .28819 .61893 .30786 .6588 .30274 .63936 .28194 Metetra
.554 .768 .978 r
.63936 .28194 .6588 .30274 .69936 .29559 .68031 .27389 Metetra
.59 .778 .97 r
.68031 .27389 .69936 .29559 .7405 .28585 .72188 .26349 Metetra
.661 .776 .934 r
.00095 .48363 .02646 .50322 .05898 .49092 .03369 .47117 Metetra
.689 .782 .922 r
.03369 .47117 .05898 .49092 .0922 .47609 .06717 .45623 Metetra
.711 .788 .912 r
.06717 .45623 .0922 .47609 .12604 .45901 .10129 .43907 Metetra
.727 .792 .904 r
.10129 .43907 .12604 .45901 .16039 .44015 .13593 .42013 Metetra
.736 .796 .9 r
.13593 .42013 .16039 .44015 .19514 .42014 .171 .40003 Metetra
.739 .799 .9 r
.171 .40003 .19514 .42014 .23019 .39974 .20638 .37951 Metetra
.734 .8 .904 r
.20638 .37951 .23019 .39974 .26547 .37977 .24201 .35939 Metetra
.721 .8 .913 r
.24201 .35939 .26547 .37977 .30095 .3611 .27783 .34053 Metetra
.699 .796 .925 r
.27783 .34053 .30095 .3611 .33662 .34449 .31386 .32362 Metetra
.668 .789 .938 r
.31386 .32362 .33662 .34449 .37255 .33045 .35013 .3092 Metetra
.631 .776 .951 r
.35013 .3092 .37255 .33045 .40883 .31916 .38674 .29745 Metetra
.592 .761 .959 r
.38674 .29745 .40883 .31916 .44557 .31042 .4238 .28816 Metetra
.559 .744 .963 r
.4238 .28816 .44557 .31042 .48289 .30368 .46144 .28084 Metetra
.535 .731 .965 r
.46144 .28084 .48289 .30368 .52089 .29824 .49975 .27485 Metetra
.525 .724 .964 r
.49975 .27485 .52089 .29824 .55962 .29335 .53881 .26943 Metetra
.528 .723 .962 r
.53881 .26943 .55962 .29335 .59912 .28819 .57864 .26375 Metetra
.544 .728 .96 r
.57864 .26375 .59912 .28819 .63936 .28194 .61924 .25702 Metetra
.569 .738 .956 r
.61924 .25702 .63936 .28194 .68031 .27389 .66056 .24852 Metetra
.598 .751 .95 r
.66056 .24852 .68031 .27389 .72188 .26349 .70254 .23773 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(10)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(15)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(20)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.678571 0.015625 0.97619 0.313244 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[0 1.025 -5 0 ]
[0 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
0 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.0001 w
.76704 .46948 m
.71545 .47993 L
s
% Start of user PostScript
0.76704 0.46948 0.715445 0.479928 MAarrowhead1
% End of user PostScript
.51511 .50359 m
.51761 .49714 L
s
% Start of user PostScript
0.515112 0.503592 0.517615 0.497136 MAarrowhead1
% End of user PostScript
.67112 .56246 m
.62536 .54887 L
s
% Start of user PostScript
0.671121 0.56246 0.625365 0.548873 MAarrowhead1
% End of user PostScript
.64281 .47418 m
.60064 .48496 L
s
% Start of user PostScript
0.64281 0.474181 0.600638 0.484956 MAarrowhead1
% End of user PostScript
.62936 .33058 m
.59457 .36765 L
s
% Start of user PostScript
0.629358 0.330578 0.594572 0.36765 MAarrowhead1
% End of user PostScript
.66175 .745 m
.62506 .69447 L
s
% Start of user PostScript
0.661746 0.744997 0.625062 0.69447 MAarrowhead1
% End of user PostScript
.76889 .46261 m
.7172 .47476 L
s
% Start of user PostScript
0.768889 0.462608 0.717195 0.474763 MAarrowhead1
% End of user PostScript
.3357 .2376 m
.3669 .28333 L
s
% Start of user PostScript
0.335704 0.237599 0.366905 0.283335 MAarrowhead1
% End of user PostScript
.82982 .48202 m
.77829 .48682 L
s
% Start of user PostScript
0.829824 0.482023 0.77829 0.48682 MAarrowhead1
% End of user PostScript
.30921 .4263 m
.35936 .44003 L
s
% Start of user PostScript
0.309205 0.426297 0.359364 0.440033 MAarrowhead1
% End of user PostScript
.27372 .6541 m
.31817 .62934 L
s
% Start of user PostScript
0.273721 0.654104 0.31817 0.62934 MAarrowhead1
% End of user PostScript
.75811 .61384 m
.70491 .59253 L
s
% Start of user PostScript
0.758111 0.613843 0.704915 0.592527 MAarrowhead1
% End of user PostScript
.48847 .47807 m
.50463 .48478 L
s
% Start of user PostScript
0.488469 0.478071 0.50463 0.484776 MAarrowhead1
% End of user PostScript
.44937 .77505 m
.47204 .72945 L
s
% Start of user PostScript
0.449368 0.775045 0.472043 0.729451 MAarrowhead1
% End of user PostScript
.67112 .31136 m
.62594 .35069 L
s
% Start of user PostScript
0.671121 0.311356 0.625937 0.350695 MAarrowhead1
% End of user PostScript
.30849 .42772 m
.35878 .44103 L
s
% Start of user PostScript
0.30849 0.427717 0.358782 0.441029 MAarrowhead1
% End of user PostScript
.49182 .59647 m
.5077 .55783 L
s
% Start of user PostScript
0.491817 0.596465 0.507697 0.557831 MAarrowhead1
% End of user PostScript
.34502 .28582 m
.37666 .32672 L
s
% Start of user PostScript
0.34502 0.285818 0.376663 0.326719 MAarrowhead1
% End of user PostScript
.3026 .45528 m
.3531 .46048 L
s
% Start of user PostScript
0.302599 0.455276 0.353097 0.46048 MAarrowhead1
% End of user PostScript
.52022 .80144 m
.52139 .74947 L
s
% Start of user PostScript
0.520219 0.801438 0.521391 0.749466 MAarrowhead1
% End of user PostScript
.56038 .28783 m
.55145 .34113 L
s
% Start of user PostScript
0.560379 0.287834 0.551449 0.341134 MAarrowhead1
% End of user PostScript
.65916 .42592 m
.61595 .44647 L
s
% Start of user PostScript
0.659159 0.425923 0.615947 0.446468 MAarrowhead1
% End of user PostScript
.30896 .27118 m
.35027 .31182 L
s
% Start of user PostScript
0.308961 0.271181 0.350272 0.311821 MAarrowhead1
% End of user PostScript
.68909 .66578 m
.6486 .63248 L
s
% Start of user PostScript
0.689095 0.665779 0.648596 0.632482 MAarrowhead1
% End of user PostScript
.56159 .78676 m
.55045 .73444 L
s
% Start of user PostScript
0.561592 0.786763 0.550454 0.734441 MAarrowhead1
% End of user PostScript
.77441 .66365 m
.72241 .63391 L
s
% Start of user PostScript
0.774409 0.663647 0.722415 0.633907 MAarrowhead1
% End of user PostScript
.42102 .44332 m
.45055 .45417 L
s
% Start of user PostScript
0.421025 0.443321 0.450554 0.454166 MAarrowhead1
% End of user PostScript
.5348 .30527 m
.53247 .3576 L
s
% Start of user PostScript
0.534799 0.305266 0.532468 0.357597 MAarrowhead1
% End of user PostScript
.4972 .49833 m
.5115 .49391 L
s
% Start of user PostScript
0.497203 0.498332 0.511499 0.493915 MAarrowhead1
% End of user PostScript
.29286 .69988 m
.33124 .66685 L
s
% Start of user PostScript
0.292864 0.699882 0.331235 0.666855 MAarrowhead1
% End of user PostScript
.42821 .72027 m
.45233 .68104 L
s
% Start of user PostScript
0.428209 0.720272 0.45233 0.681041 MAarrowhead1
% End of user PostScript
.24667 .71364 m
.29358 .67972 L
s
% Start of user PostScript
0.246672 0.713636 0.293582 0.679718 MAarrowhead1
% End of user PostScript
.5015 .46034 m
.51008 .47968 L
s
% Start of user PostScript
0.5015 0.460339 0.510077 0.479675 MAarrowhead1
% End of user PostScript
.43727 .26886 m
.45083 .31647 L
s
% Start of user PostScript
0.437274 0.268859 0.450827 0.316465 MAarrowhead1
% End of user PostScript
.41214 .5975 m
.44107 .56902 L
s
% Start of user PostScript
0.412138 0.597497 0.441065 0.569019 MAarrowhead1
% End of user PostScript
.68501 .22129 m
.64887 .26777 L
s
% Start of user PostScript
0.68501 0.221285 0.64887 0.267773 MAarrowhead1
% End of user PostScript
.33591 .61857 m
.37184 .59585 L
s
% Start of user PostScript
0.335915 0.618574 0.371845 0.595848 MAarrowhead1
% End of user PostScript
.55492 .50265 m
.53139 .49958 L
s
% Start of user PostScript
0.554917 0.502653 0.531392 0.499575 MAarrowhead1
% End of user PostScript
.64661 .549 m
.60487 .53841 L
s
% Start of user PostScript
0.646615 0.549001 0.604869 0.538407 MAarrowhead1
% End of user PostScript
.24904 .53244 m
.29669 .52292 L
s
% Start of user PostScript
0.249039 0.532443 0.296688 0.522916 MAarrowhead1
% End of user PostScript
.46704 .34929 m
.48226 .39388 L
s
% Start of user PostScript
0.467038 0.349291 0.482264 0.393884 MAarrowhead1
% End of user PostScript
.31323 .75137 m
.34364 .70483 L
s
% Start of user PostScript
0.313232 0.751365 0.343641 0.704827 MAarrowhead1
% End of user PostScript
.35626 .25489 m
.3834 .30054 L
s
% Start of user PostScript
0.356258 0.254889 0.383396 0.300536 MAarrowhead1
% End of user PostScript
.57489 .81816 m
.55929 .76518 L
s
% Start of user PostScript
0.57489 0.818157 0.559286 0.765178 MAarrowhead1
% End of user PostScript
.64754 .73109 m
.61466 .684 L
s
% Start of user PostScript
0.647536 0.731093 0.61466 0.684001 MAarrowhead1
% End of user PostScript
.50572 .33081 m
.51141 .37786 L
s
% Start of user PostScript
0.505723 0.330805 0.511409 0.377863 MAarrowhead1
% End of user PostScript
.70213 .55575 m
.64999 .54644 L
s
% Start of user PostScript
0.702131 0.555752 0.649988 0.546436 MAarrowhead1
% End of user PostScript
.59621 .65616 m
.5763 .61939 L
s
% Start of user PostScript
0.596214 0.656158 0.576301 0.61939 MAarrowhead1
% End of user PostScript
.52258 .48189 m
.51878 .48785 L
s
% Start of user PostScript
0.522585 0.481889 0.518776 0.487852 MAarrowhead1
% End of user PostScript
.36571 .59196 m
.40042 .5706 L
s
% Start of user PostScript
0.365714 0.591963 0.400421 0.570603 MAarrowhead1
% End of user PostScript
.73365 .65054 m
.68507 .62253 L
s
% Start of user PostScript
0.733648 0.650535 0.685071 0.62253 MAarrowhead1
% End of user PostScript
.623 .74101 m
.5966 .69217 L
s
% Start of user PostScript
0.623005 0.741011 0.596602 0.692166 MAarrowhead1
% End of user PostScript
.36261 .36198 m
.39724 .39504 L
s
% Start of user PostScript
0.36261 0.361984 0.397238 0.395044 MAarrowhead1
% End of user PostScript
.77272 .63508 m
.71966 .61027 L
s
% Start of user PostScript
0.772722 0.635077 0.719663 0.610271 MAarrowhead1
% End of user PostScript
.56641 .75713 m
.55685 .70825 L
s
% Start of user PostScript
0.566407 0.757132 0.556852 0.708253 MAarrowhead1
% End of user PostScript
.74876 .70575 m
.69852 .66512 L
s
% Start of user PostScript
0.748756 0.705749 0.698523 0.665119 MAarrowhead1
% End of user PostScript
.39543 .82042 m
.42184 .77863 L
s
% Start of user PostScript
0.395428 0.820422 0.421836 0.778625 MAarrowhead1
% End of user PostScript
.31413 .35656 m
.35821 .38592 L
s
% Start of user PostScript
0.314128 0.356564 0.35821 0.385918 MAarrowhead1
% End of user PostScript
.28526 .49004 m
.33156 .48627 L
s
% Start of user PostScript
0.285265 0.490044 0.331561 0.486267 MAarrowhead1
% End of user PostScript
.46202 .39951 m
.47621 .43198 L
s
% Start of user PostScript
0.462021 0.399515 0.47621 0.431977 MAarrowhead1
% End of user PostScript
.63738 .34406 m
.59905 .37718 L
s
% Start of user PostScript
0.637385 0.344064 0.599045 0.377183 MAarrowhead1
% End of user PostScript
.1996 .42677 m
.25069 .4415 L
s
% Start of user PostScript
0.199597 0.426769 0.250692 0.441503 MAarrowhead1
% End of user PostScript
.77988 .54227 m
.72467 .53441 L
s
% Start of user PostScript
0.779884 0.542269 0.724665 0.534407 MAarrowhead1
% End of user PostScript
.42494 .43535 m
.45292 .45016 L
s
% Start of user PostScript
0.424939 0.43535 0.452919 0.450163 MAarrowhead1
% End of user PostScript
.40408 .37057 m
.43109 .40669 L
s
% Start of user PostScript
0.404083 0.370574 0.43109 0.40669 MAarrowhead1
% End of user PostScript
.54045 .34233 m
.53258 .38589 L
s
% Start of user PostScript
0.540451 0.342335 0.532584 0.385893 MAarrowhead1
% End of user PostScript
.40352 .26194 m
.42114 .30933 L
s
% Start of user PostScript
0.40352 0.261939 0.421137 0.309329 MAarrowhead1
% End of user PostScript
.67442 .41791 m
.62859 .44032 L
s
% Start of user PostScript
0.67442 0.417906 0.628592 0.440319 MAarrowhead1
% End of user PostScript
.32879 .29693 m
.36592 .33561 L
s
% Start of user PostScript
0.328785 0.296934 0.365915 0.335611 MAarrowhead1
% End of user PostScript
.22342 .35824 m
.27409 .38378 L
s
% Start of user PostScript
0.223422 0.358236 0.274093 0.383778 MAarrowhead1
% End of user PostScript
.41819 .57573 m
.45057 .54953 L
s
% Start of user PostScript
0.418188 0.575733 0.450568 0.549526 MAarrowhead1
% End of user PostScript
.67928 .69801 m
.64175 .6577 L
s
% Start of user PostScript
0.679281 0.698014 0.641755 0.657703 MAarrowhead1
% End of user PostScript
.52801 .22559 m
.52344 .27796 L
s
% Start of user PostScript
0.528012 0.225593 0.523441 0.277958 MAarrowhead1
% End of user PostScript
.67123 .2475 m
.63244 .29863 L
s
% Start of user PostScript
0.671226 0.247502 0.632445 0.298633 MAarrowhead1
% End of user PostScript
.83778 .48372 m
.78672 .48775 L
s
% Start of user PostScript
0.837782 0.48372 0.786722 0.487747 MAarrowhead1
% End of user PostScript
.23558 .53058 m
.28469 .52158 L
s
% Start of user PostScript
0.235584 0.530576 0.28469 0.521583 MAarrowhead1
% End of user PostScript
.28453 .35585 m
.33321 .38364 L
s
% Start of user PostScript
0.284526 0.355846 0.333214 0.383637 MAarrowhead1
% End of user PostScript
.66108 .43821 m
.61751 .45593 L
s
% Start of user PostScript
0.661077 0.438214 0.617513 0.455933 MAarrowhead1
% End of user PostScript
.50835 .51231 m
.51601 .5006 L
s
% Start of user PostScript
0.508349 0.512305 0.516014 0.500597 MAarrowhead1
% End of user PostScript
.47574 .82891 m
.48788 .77932 L
s
% Start of user PostScript
0.475736 0.828913 0.487875 0.779321 MAarrowhead1
% End of user PostScript
.51724 .33543 m
.51859 .38124 L
s
% Start of user PostScript
0.517239 0.335434 0.518592 0.381236 MAarrowhead1
% End of user PostScript
.55883 .47513 m
.53428 .48472 L
s
% Start of user PostScript
0.558826 0.475128 0.534282 0.484721 MAarrowhead1
% End of user PostScript
.43625 .42725 m
.46106 .44678 L
s
% Start of user PostScript
0.436247 0.427252 0.461064 0.446779 MAarrowhead1
% End of user PostScript
.67598 .56142 m
.62919 .54856 L
s
% Start of user PostScript
0.675983 0.561416 0.629186 0.548563 MAarrowhead1
% End of user PostScript
.6444 .63438 m
.60975 .60254 L
s
% Start of user PostScript
0.644395 0.634376 0.609752 0.602537 MAarrowhead1
% End of user PostScript
.27234 .56059 m
.31606 .54464 L
s
% Start of user PostScript
0.272336 0.560593 0.316059 0.544637 MAarrowhead1
% End of user PostScript
.35274 .6437 m
.38391 .61506 L
s
% Start of user PostScript
0.352739 0.643701 0.383914 0.615058 MAarrowhead1
% End of user PostScript
.54596 .81476 m
.53858 .76175 L
s
% Start of user PostScript
0.545961 0.814759 0.538583 0.761752 MAarrowhead1
% End of user PostScript
.79282 .5618 m
.73672 .54936 L
s
% Start of user PostScript
0.792819 0.561803 0.736724 0.549356 MAarrowhead1
% End of user PostScript
.27909 .4503 m
.33213 .45931 L
s
% Start of user PostScript
0.279086 0.450303 0.332131 0.45931 MAarrowhead1
% End of user PostScript
.70608 .71395 m
.66292 .66994 L
s
% Start of user PostScript
0.706077 0.713951 0.662916 0.669945 MAarrowhead1
% End of user PostScript
.25838 .46407 m
.31089 .47131 L
s
% Start of user PostScript
0.258382 0.464066 0.310889 0.471311 MAarrowhead1
% End of user PostScript
.34118 .36629 m
.38082 .39618 L
s
% Start of user PostScript
0.34118 0.36629 0.380824 0.396178 MAarrowhead1
% End of user PostScript
.61559 .31048 m
.58782 .35355 L
s
% Start of user PostScript
0.615586 0.310479 0.587816 0.353551 MAarrowhead1
% End of user PostScript
.52427 .65901 m
.53159 .62217 L
s
% Start of user PostScript
0.524265 0.659011 0.531592 0.62217 MAarrowhead1
% End of user PostScript
.58161 .51756 m
.55383 .51278 L
s
% Start of user PostScript
0.581611 0.517555 0.553827 0.512782 MAarrowhead1
% End of user PostScript
.30258 .74925 m
.33498 .70266 L
s
% Start of user PostScript
0.302576 0.749248 0.334979 0.702657 MAarrowhead1
% End of user PostScript
.60574 .29286 m
.58365 .3407 L
s
% Start of user PostScript
0.605741 0.292863 0.583655 0.340696 MAarrowhead1
% End of user PostScript
.52481 .69319 m
.5309 .65357 L
s
% Start of user PostScript
0.524813 0.693191 0.530902 0.653575 MAarrowhead1
% End of user PostScript
.65236 .28522 m
.6131 .33167 L
s
% Start of user PostScript
0.652363 0.285218 0.613098 0.33167 MAarrowhead1
% End of user PostScript
.26442 .58221 m
.30949 .56388 L
s
% Start of user PostScript
0.264424 0.582207 0.309487 0.563878 MAarrowhead1
% End of user PostScript
.41617 .46498 m
.44965 .4665 L
s
% Start of user PostScript
0.416169 0.464979 0.449654 0.466497 MAarrowhead1
% End of user PostScript
.22655 .37429 m
.27767 .39729 L
s
% Start of user PostScript
0.226545 0.374288 0.277674 0.39729 MAarrowhead1
% End of user PostScript
.44396 .72125 m
.46683 .68304 L
s
% Start of user PostScript
0.443958 0.72125 0.466825 0.683042 MAarrowhead1
% End of user PostScript
.54534 .66455 m
.54584 .62754 L
s
% Start of user PostScript
0.545339 0.66455 0.545839 0.627538 MAarrowhead1
% End of user PostScript
.49202 .47416 m
.50617 .48368 L
s
% Start of user PostScript
0.492018 0.474157 0.506172 0.483678 MAarrowhead1
% End of user PostScript
.50387 .5328 m
.51507 .50911 L
s
% Start of user PostScript
0.50387 0.532804 0.515073 0.509106 MAarrowhead1
% End of user PostScript
.78079 .3424 m
.73521 .37344 L
s
% Start of user PostScript
0.78079 0.3424 0.735208 0.373442 MAarrowhead1
% End of user PostScript
.56702 .56676 m
.55324 .54158 L
s
% Start of user PostScript
0.567018 0.566761 0.553242 0.541584 MAarrowhead1
% End of user PostScript
.40538 .64214 m
.42944 .60838 L
s
% Start of user PostScript
0.405377 0.642139 0.429442 0.60838 MAarrowhead1
% End of user PostScript
.66953 .71863 m
.63312 .67416 L
s
% Start of user PostScript
0.669533 0.718629 0.633117 0.674161 MAarrowhead1
% End of user PostScript
.49209 .23331 m
.49437 .28344 L
s
% Start of user PostScript
0.492088 0.233314 0.494366 0.283437 MAarrowhead1
% End of user PostScript
.5719 .47587 m
.54375 .48583 L
s
% Start of user PostScript
0.571901 0.475866 0.54375 0.485831 MAarrowhead1
% End of user PostScript
.29034 .59498 m
.33224 .5757 L
s
% Start of user PostScript
0.29034 0.594984 0.332236 0.575698 MAarrowhead1
% End of user PostScript
.39716 .39065 m
.42736 .42122 L
s
% Start of user PostScript
0.397157 0.39065 0.427359 0.421217 MAarrowhead1
% End of user PostScript
.49027 .50776 m
.5082 .49783 L
s
% Start of user PostScript
0.490268 0.507765 0.508203 0.497828 MAarrowhead1
% End of user PostScript
.34565 .20772 m
.37211 .25645 L
s
% Start of user PostScript
0.345646 0.207719 0.372114 0.256454 MAarrowhead1
% End of user PostScript
.81765 .37537 m
.77168 .3992 L
s
% Start of user PostScript
0.817654 0.375374 0.771678 0.399203 MAarrowhead1
% End of user PostScript
.38347 .19818 m
.4029 .24808 L
s
% Start of user PostScript
0.383474 0.198177 0.402902 0.248082 MAarrowhead1
% End of user PostScript
.49107 .56449 m
.50798 .52993 L
s
% Start of user PostScript
0.491071 0.564489 0.507982 0.529928 MAarrowhead1
% End of user PostScript
.61733 .23647 m
.59383 .29212 L
s
% Start of user PostScript
0.61733 0.236472 0.593833 0.292121 MAarrowhead1
% End of user PostScript
.62188 .75247 m
.59543 .7017 L
s
% Start of user PostScript
0.621881 0.752466 0.595433 0.701695 MAarrowhead1
% End of user PostScript
.53929 .47892 m
.52422 .48637 L
s
% Start of user PostScript
0.539295 0.478923 0.524218 0.486374 MAarrowhead1
% End of user PostScript
.48029 .45587 m
.4967 .4733 L
s
% Start of user PostScript
0.480288 0.455871 0.496697 0.473299 MAarrowhead1
% End of user PostScript
.5556 .82686 m
.54567 .7741 L
s
% Start of user PostScript
0.555603 0.826862 0.545674 0.774101 MAarrowhead1
% End of user PostScript
.28086 .49884 m
.32628 .49308 L
s
% Start of user PostScript
0.280865 0.498845 0.326279 0.493084 MAarrowhead1
% End of user PostScript
.64397 .28322 m
.60774 .3308 L
s
% Start of user PostScript
0.64397 0.283218 0.607742 0.330801 MAarrowhead1
% End of user PostScript
.36367 .66903 m
.39064 .63446 L
s
% Start of user PostScript
0.363669 0.669028 0.390644 0.634464 MAarrowhead1
% End of user PostScript
.25749 .63207 m
.30426 .6087 L
s
% Start of user PostScript
0.257491 0.632068 0.304262 0.608703 MAarrowhead1
% End of user PostScript
.39028 .30757 m
.41254 .3503 L
s
% Start of user PostScript
0.390285 0.30757 0.412536 0.350298 MAarrowhead1
% End of user PostScript
.79643 .46117 m
.74354 .47312 L
s
% Start of user PostScript
0.796432 0.461175 0.743544 0.473117 MAarrowhead1
% End of user PostScript
.37969 .34362 m
.40874 .38215 L
s
% Start of user PostScript
0.37969 0.343619 0.408742 0.382147 MAarrowhead1
% End of user PostScript
.46438 .52179 m
.49438 .50538 L
s
% Start of user PostScript
0.464383 0.521793 0.494384 0.50538 MAarrowhead1
% End of user PostScript
.44443 .23409 m
.45584 .28302 L
s
% Start of user PostScript
0.444433 0.234086 0.45584 0.283016 MAarrowhead1
% End of user PostScript
.48049 .15685 m
.4852 .20278 L
s
% Start of user PostScript
0.480495 0.156848 0.485198 0.202779 MAarrowhead1
% End of user PostScript
.44521 .752 m
.46843 .70988 L
s
% Start of user PostScript
0.445206 0.752002 0.468427 0.709875 MAarrowhead1
% End of user PostScript
.50538 .45208 m
.5109 .47619 L
s
% Start of user PostScript
0.505375 0.452084 0.510899 0.476189 MAarrowhead1
% End of user PostScript
.59102 .51929 m
.56084 .51555 L
s
% Start of user PostScript
0.591022 0.519289 0.560844 0.515554 MAarrowhead1
% End of user PostScript
.58499 .66545 m
.5699 .62779 L
s
% Start of user PostScript
0.584987 0.665452 0.569897 0.627785 MAarrowhead1
% End of user PostScript
.72831 .38406 m
.67868 .41226 L
s
% Start of user PostScript
0.728307 0.384057 0.67868 0.412265 MAarrowhead1
% End of user PostScript
.76632 .50643 m
.71438 .50764 L
s
% Start of user PostScript
0.766319 0.506435 0.714384 0.507644 MAarrowhead1
% End of user PostScript
.41388 .49584 m
.4527 .48541 L
s
% Start of user PostScript
0.413875 0.495838 0.4527 0.485408 MAarrowhead1
% End of user PostScript
.45163 .81081 m
.47222 .76178 L
s
% Start of user PostScript
0.451628 0.810811 0.472224 0.761779 MAarrowhead1
% End of user PostScript
.70557 .67458 m
.6623 .63958 L
s
% Start of user PostScript
0.705573 0.674581 0.662299 0.63958 MAarrowhead1
% End of user PostScript
.73207 .69687 m
.684 .65701 L
s
% Start of user PostScript
0.732074 0.696868 0.683999 0.657011 MAarrowhead1
% End of user PostScript
.28952 .22921 m
.32935 .27049 L
s
% Start of user PostScript
0.289516 0.229209 0.329352 0.270493 MAarrowhead1
% End of user PostScript
.2787 .28954 m
.32541 .32648 L
s
% Start of user PostScript
0.278699 0.289544 0.32541 0.326479 MAarrowhead1
% End of user PostScript
.36978 .39122 m
.40653 .41896 L
s
% Start of user PostScript
0.369781 0.391216 0.406528 0.418959 MAarrowhead1
% End of user PostScript
.7331 .67667 m
.68474 .642 L
s
% Start of user PostScript
0.733096 0.676674 0.684737 0.641996 MAarrowhead1
% End of user PostScript
.55612 .39405 m
.53978 .42683 L
s
% Start of user PostScript
0.55612 0.394053 0.539778 0.426835 MAarrowhead1
% End of user PostScript
.579 .66451 m
.56631 .62706 L
s
% Start of user PostScript
0.579002 0.66451 0.566314 0.62706 MAarrowhead1
% End of user PostScript
.63567 .69256 m
.60733 .65348 L
s
% Start of user PostScript
0.635671 0.692564 0.60733 0.653483 MAarrowhead1
% End of user PostScript
.25659 .62421 m
.30334 .60149 L
s
% Start of user PostScript
0.256595 0.624213 0.303337 0.601494 MAarrowhead1
% End of user PostScript
.65723 .37745 m
.61421 .40595 L
s
% Start of user PostScript
0.657233 0.37745 0.614207 0.405952 MAarrowhead1
% End of user PostScript
.25251 .67903 m
.30077 .6494 L
s
% Start of user PostScript
0.252512 0.679032 0.30077 0.649397 MAarrowhead1
% End of user PostScript
.77805 .55772 m
.72256 .54663 L
s
% Start of user PostScript
0.778049 0.557719 0.722561 0.546634 MAarrowhead1
% End of user PostScript
.49072 .49772 m
.50821 .4933 L
s
% Start of user PostScript
0.490721 0.497719 0.50821 0.493303 MAarrowhead1
% End of user PostScript
.31466 .28234 m
.35505 .32204 L
s
% Start of user PostScript
0.314656 0.282338 0.355046 0.322038 MAarrowhead1
% End of user PostScript
.55264 .5921 m
.54751 .55995 L
s
% Start of user PostScript
0.552641 0.5921 0.547515 0.559954 MAarrowhead1
% End of user PostScript
.46792 .68749 m
.48707 .65137 L
s
% Start of user PostScript
0.467918 0.687493 0.487071 0.651375 MAarrowhead1
% End of user PostScript
.42795 .66902 m
.45061 .63334 L
s
% Start of user PostScript
0.427947 0.669016 0.450609 0.633337 MAarrowhead1
% End of user PostScript
.46259 .38622 m
.47724 .422 L
s
% Start of user PostScript
0.462592 0.386225 0.477242 0.422001 MAarrowhead1
% End of user PostScript
.49355 .50566 m
.50986 .49693 L
s
% Start of user PostScript
0.493552 0.505657 0.509863 0.496933 MAarrowhead1
% End of user PostScript
.5747 .25517 m
.56277 .31111 L
s
% Start of user PostScript
0.574696 0.255167 0.562767 0.311108 MAarrowhead1
% End of user PostScript
.5378 .64911 m
.54108 .61352 L
s
% Start of user PostScript
0.537795 0.649108 0.541076 0.613523 MAarrowhead1
% End of user PostScript
.56781 .59649 m
.55753 .56492 L
s
% Start of user PostScript
0.567813 0.596487 0.557533 0.564917 MAarrowhead1
% End of user PostScript
.692 .57624 m
.64368 .56011 L
s
% Start of user PostScript
0.692001 0.576244 0.643677 0.560115 MAarrowhead1
% End of user PostScript
.36101 .64815 m
.39048 .61776 L
s
% Start of user PostScript
0.361013 0.648148 0.390481 0.617763 MAarrowhead1
% End of user PostScript
.52802 .29671 m
.52791 .35028 L
s
% Start of user PostScript
0.528021 0.296708 0.527914 0.350284 MAarrowhead1
% End of user PostScript
.76932 .46973 m
.71761 .48006 L
s
% Start of user PostScript
0.769316 0.469732 0.717609 0.480055 MAarrowhead1
% End of user PostScript
.59185 .38072 m
.56445 .41144 L
s
% Start of user PostScript
0.591852 0.380723 0.564451 0.411439 MAarrowhead1
% End of user PostScript
.64415 .45833 m
.6028 .47219 L
s
% Start of user PostScript
0.644149 0.458333 0.602799 0.472189 MAarrowhead1
% End of user PostScript
.58048 .18904 m
.56428 .24037 L
s
% Start of user PostScript
0.580476 0.189042 0.564281 0.240372 MAarrowhead1
% End of user PostScript
.43477 .49763 m
.47319 .48906 L
s
% Start of user PostScript
0.434772 0.497633 0.473192 0.48906 MAarrowhead1
% End of user PostScript
.31984 .23521 m
.355 .27974 L
s
% Start of user PostScript
0.31984 0.235209 0.355 0.279739 MAarrowhead1
% End of user PostScript
.69345 .44857 m
.64413 .46339 L
s
% Start of user PostScript
0.693446 0.448571 0.644127 0.463388 MAarrowhead1
% End of user PostScript
.41634 .27023 m
.43259 .3173 L
s
% Start of user PostScript
0.416338 0.270232 0.432589 0.317296 MAarrowhead1
% End of user PostScript
.62575 .5463 m
.59046 .53521 L
s
% Start of user PostScript
0.625752 0.546298 0.590464 0.535207 MAarrowhead1
% End of user PostScript
.56727 .44014 m
.54236 .46215 L
s
% Start of user PostScript
0.567266 0.440141 0.542361 0.462154 MAarrowhead1
% End of user PostScript
.77124 .38509 m
.72209 .41113 L
s
% Start of user PostScript
0.771241 0.385086 0.722086 0.411132 MAarrowhead1
% End of user PostScript
.32792 .70157 m
.3572 .6641 L
s
% Start of user PostScript
0.327922 0.701573 0.357198 0.664096 MAarrowhead1
% End of user PostScript
.52014 .56777 m
.5252 .53479 L
s
% Start of user PostScript
0.520136 0.56777 0.525202 0.534795 MAarrowhead1
% End of user PostScript
.5092 .31763 m
.51408 .36736 L
s
% Start of user PostScript
0.5092 0.317627 0.51408 0.367361 MAarrowhead1
% End of user PostScript
.20154 .50222 m
.2552 .5004 L
s
% Start of user PostScript
0.20154 0.502218 0.255202 0.500398 MAarrowhead1
% End of user PostScript
.54293 .70874 m
.54279 .6667 L
s
% Start of user PostScript
0.542931 0.708735 0.542787 0.666702 MAarrowhead1
% End of user PostScript
.51214 .77749 m
.51691 .72945 L
s
% Start of user PostScript
0.512135 0.777491 0.516912 0.729446 MAarrowhead1
% End of user PostScript
.59328 .27601 m
.576 .32799 L
s
% Start of user PostScript
0.593277 0.276014 0.576003 0.32799 MAarrowhead1
% End of user PostScript
.35562 .4683 m
.39666 .46538 L
s
% Start of user PostScript
0.355623 0.468299 0.396662 0.46538 MAarrowhead1
% End of user PostScript
.26768 .7525 m
.30618 .7112 L
s
% Start of user PostScript
0.267682 0.752502 0.30618 0.711202 MAarrowhead1
% End of user PostScript
.49465 .46111 m
.5063 .47889 L
s
% Start of user PostScript
0.494654 0.461114 0.506303 0.478888 MAarrowhead1
% End of user PostScript
.46895 .18992 m
.47615 .23858 L
s
% Start of user PostScript
0.468949 0.18992 0.476154 0.238576 MAarrowhead1
% End of user PostScript
.6315 .53556 m
.59326 .52865 L
s
% Start of user PostScript
0.631501 0.535562 0.59326 0.52865 MAarrowhead1
% End of user PostScript
.4191 .42243 m
.44678 .44219 L
s
% Start of user PostScript
0.4191 0.422433 0.446775 0.442188 MAarrowhead1
% End of user PostScript
.58484 .55236 m
.56353 .53411 L
s
% Start of user PostScript
0.584844 0.552361 0.563528 0.534113 MAarrowhead1
% End of user PostScript
.72448 .6945 m
.67782 .65499 L
s
% Start of user PostScript
0.724481 0.6945 0.677823 0.654991 MAarrowhead1
% End of user PostScript
.59097 .35502 m
.56504 .39025 L
s
% Start of user PostScript
0.590966 0.355024 0.565035 0.390255 MAarrowhead1
% End of user PostScript
.59683 .62632 m
.57612 .59312 L
s
% Start of user PostScript
0.59683 0.626324 0.576121 0.593116 MAarrowhead1
% End of user PostScript
.64336 .29226 m
.60652 .33756 L
s
% Start of user PostScript
0.643364 0.292263 0.60652 0.337562 MAarrowhead1
% End of user PostScript
.25928 .36147 m
.31085 .38751 L
s
% Start of user PostScript
0.259278 0.361466 0.31085 0.387507 MAarrowhead1
% End of user PostScript
.34281 .43577 m
.38676 .44502 L
s
% Start of user PostScript
0.342805 0.435766 0.386755 0.445016 MAarrowhead1
% End of user PostScript
.22732 .56143 m
.2762 .5459 L
s
% Start of user PostScript
0.227325 0.56143 0.276201 0.545895 MAarrowhead1
% End of user PostScript
.63588 .57862 m
.60022 .55684 L
s
% Start of user PostScript
0.635879 0.578622 0.600219 0.556843 MAarrowhead1
% End of user PostScript
.81196 .46182 m
.75973 .4728 L
s
% Start of user PostScript
0.81196 0.461821 0.759727 0.472799 MAarrowhead1
% End of user PostScript
.48656 .55043 m
.50574 .51832 L
s
% Start of user PostScript
0.486562 0.550426 0.505736 0.518324 MAarrowhead1
% End of user PostScript
.29246 .33057 m
.33946 .36255 L
s
% Start of user PostScript
0.292464 0.330571 0.339459 0.362554 MAarrowhead1
% End of user PostScript
.19156 .59288 m
.23958 .57369 L
s
% Start of user PostScript
0.191556 0.592884 0.239583 0.573691 MAarrowhead1
% End of user PostScript
.49069 .1823 m
.49264 .22976 L
s
% Start of user PostScript
0.490686 0.182305 0.492636 0.229762 MAarrowhead1
% End of user PostScript
.65287 .32498 m
.61111 .36166 L
s
% Start of user PostScript
0.652866 0.324979 0.611113 0.361663 MAarrowhead1
% End of user PostScript
.63885 .30742 m
.60259 .3493 L
s
% Start of user PostScript
0.638851 0.307419 0.602586 0.349304 MAarrowhead1
% End of user PostScript
.46277 .82559 m
.47851 .77665 L
s
% Start of user PostScript
0.462766 0.825586 0.478511 0.776648 MAarrowhead1
% End of user PostScript
.1927 .4684 m
.24448 .47467 L
s
% Start of user PostScript
0.192703 0.468399 0.244481 0.47467 MAarrowhead1
% End of user PostScript
.7311 .43503 m
.68034 .4534 L
s
% Start of user PostScript
0.731104 0.435029 0.680341 0.453399 MAarrowhead1
% End of user PostScript
.47356 .57871 m
.49526 .54438 L
s
% Start of user PostScript
0.473562 0.578708 0.495258 0.544384 MAarrowhead1
% End of user PostScript
.60414 .60142 m
.58053 .57151 L
s
% Start of user PostScript
0.604136 0.601421 0.580525 0.571514 MAarrowhead1
% End of user PostScript
.37736 .44138 m
.41455 .44915 L
s
% Start of user PostScript
0.377356 0.441384 0.414552 0.44915 MAarrowhead1
% End of user PostScript
.60784 .56057 m
.57978 .54348 L
s
% Start of user PostScript
0.607843 0.560572 0.57978 0.543477 MAarrowhead1
% End of user PostScript
.55556 .72821 m
.55081 .68333 L
s
% Start of user PostScript
0.555559 0.728209 0.55081 0.683331 MAarrowhead1
% End of user PostScript
.61412 .39011 m
.58045 .41796 L
s
% Start of user PostScript
0.61412 0.390106 0.580451 0.417956 MAarrowhead1
% End of user PostScript
.44472 .24002 m
.45595 .28867 L
s
% Start of user PostScript
0.444722 0.240015 0.45595 0.288674 MAarrowhead1
% End of user PostScript
.47529 .78553 m
.49064 .73763 L
s
% Start of user PostScript
0.47529 0.785526 0.490644 0.737626 MAarrowhead1
% End of user PostScript
.55701 .5517 m
.5445 .52765 L
s
% Start of user PostScript
0.557008 0.551701 0.544497 0.527646 MAarrowhead1
% End of user PostScript
.50839 .80461 m
.51339 .75324 L
s
% Start of user PostScript
0.50839 0.804608 0.513393 0.753244 MAarrowhead1
% End of user PostScript
.58258 .38771 m
.55788 .41837 L
s
% Start of user PostScript
0.582583 0.387714 0.557883 0.41837 MAarrowhead1
% End of user PostScript
.36735 .46662 m
.40694 .4645 L
s
% Start of user PostScript
0.367348 0.46662 0.40694 0.464502 MAarrowhead1
% End of user PostScript
.52821 .41195 m
.52138 .44319 L
s
% Start of user PostScript
0.528212 0.411951 0.521375 0.443186 MAarrowhead1
% End of user PostScript
.32979 .2066 m
.35965 .25364 L
s
% Start of user PostScript
0.329791 0.206595 0.359648 0.253643 MAarrowhead1
% End of user PostScript
.18369 .54321 m
.23337 .53243 L
s
% Start of user PostScript
0.183688 0.54321 0.23337 0.532435 MAarrowhead1
% End of user PostScript
.64611 .25254 m
.61203 .30799 L
s
% Start of user PostScript
0.646111 0.252542 0.612027 0.307991 MAarrowhead1
% End of user PostScript
.33664 .48311 m
.37898 .47639 L
s
% Start of user PostScript
0.336643 0.483107 0.378978 0.47639 MAarrowhead1
% End of user PostScript
.55414 .69493 m
.55078 .6541 L
s
% Start of user PostScript
0.554135 0.694927 0.55078 0.6541 MAarrowhead1
% End of user PostScript
.74657 .57968 m
.69313 .56497 L
s
% Start of user PostScript
0.746572 0.579677 0.693135 0.564968 MAarrowhead1
% End of user PostScript
.59426 .75254 m
.57628 .70296 L
s
% Start of user PostScript
0.594257 0.752543 0.576285 0.702957 MAarrowhead1
% End of user PostScript
.59478 .70995 m
.57682 .66657 L
s
% Start of user PostScript
0.594782 0.709947 0.576821 0.666573 MAarrowhead1
% End of user PostScript
.60095 .79503 m
.57679 .74026 L
s
% Start of user PostScript
0.600951 0.795031 0.576788 0.740264 MAarrowhead1
% End of user PostScript
.36864 .42608 m
.40726 .44025 L
s
% Start of user PostScript
0.368644 0.426077 0.407261 0.440253 MAarrowhead1
% End of user PostScript
.70799 .36485 m
.6587 .39624 L
s
% Start of user PostScript
0.707994 0.364855 0.658702 0.396237 MAarrowhead1
% End of user PostScript
.59542 .51959 m
.56401 .51656 L
s
% Start of user PostScript
0.595424 0.519594 0.56401 0.51656 MAarrowhead1
% End of user PostScript
.24585 .51285 m
.2947 .50846 L
s
% Start of user PostScript
0.245854 0.512853 0.294704 0.508465 MAarrowhead1
% End of user PostScript
.54648 .36789 m
.53462 .40624 L
s
% Start of user PostScript
0.546476 0.367894 0.53462 0.406241 MAarrowhead1
% End of user PostScript
.76272 .32641 m
.71718 .36056 L
s
% Start of user PostScript
0.762719 0.326408 0.717185 0.360556 MAarrowhead1
% End of user PostScript
.18059 .42345 m
.2286 .43738 L
s
% Start of user PostScript
0.180592 0.423447 0.2286 0.437384 MAarrowhead1
% End of user PostScript
.68495 .44014 m
.63718 .45715 L
s
% Start of user PostScript
0.684947 0.440143 0.637182 0.457155 MAarrowhead1
% End of user PostScript
.48865 .35349 m
.49862 .39658 L
s
% Start of user PostScript
0.48865 0.353487 0.498619 0.396584 MAarrowhead1
% End of user PostScript
.7797 .51238 m
.72646 .51156 L
s
% Start of user PostScript
0.779698 0.512375 0.726459 0.511559 MAarrowhead1
% End of user PostScript
.59516 .23667 m
.57797 .2926 L
s
% Start of user PostScript
0.595158 0.236665 0.577971 0.292596 MAarrowhead1
% End of user PostScript
.7928 .61488 m
.73806 .5932 L
s
% Start of user PostScript
0.792801 0.614882 0.73806 0.593202 MAarrowhead1
% End of user PostScript
.30245 .53307 m
.3431 .51949 L
s
% Start of user PostScript
0.302448 0.533065 0.343097 0.519491 MAarrowhead1
% End of user PostScript
.38542 .58192 m
.41955 .55929 L
s
% Start of user PostScript
0.385419 0.581921 0.419547 0.559292 MAarrowhead1
% End of user PostScript
.44528 .35823 m
.46496 .40072 L
s
% Start of user PostScript
0.44528 0.358229 0.464961 0.400724 MAarrowhead1
% End of user PostScript
.63629 .71256 m
.60762 .66974 L
s
% Start of user PostScript
0.636293 0.71256 0.60762 0.669736 MAarrowhead1
% End of user PostScript
.52338 .52739 m
.52296 .50911 L
s
% Start of user PostScript
0.523379 0.527386 0.522957 0.509109 MAarrowhead1
% End of user PostScript
.2145 .49608 m
.26702 .49586 L
s
% Start of user PostScript
0.214505 0.496079 0.267025 0.495862 MAarrowhead1
% End of user PostScript
.54475 .43849 m
.52775 .4627 L
s
% Start of user PostScript
0.544748 0.438488 0.52775 0.462697 MAarrowhead1
% End of user PostScript
.55287 .34398 m
.54024 .38646 L
s
% Start of user PostScript
0.552871 0.343984 0.540237 0.386456 MAarrowhead1
% End of user PostScript
.30317 .73075 m
.33676 .68906 L
s
% Start of user PostScript
0.303169 0.730751 0.336762 0.689062 MAarrowhead1
% End of user PostScript
.73508 .56824 m
.68209 .55584 L
s
% Start of user PostScript
0.735076 0.568239 0.682087 0.55584 MAarrowhead1
% End of user PostScript
.52493 .43365 m
.51896 .46058 L
s
% Start of user PostScript
0.524934 0.433653 0.518956 0.460583 MAarrowhead1
% End of user PostScript
.52543 .77749 m
.52624 .72851 L
s
% Start of user PostScript
0.525427 0.777488 0.526242 0.728511 MAarrowhead1
% End of user PostScript
.27615 .37025 m
.32664 .39535 L
s
% Start of user PostScript
0.276148 0.370246 0.32664 0.395355 MAarrowhead1
% End of user PostScript
.67873 .60456 m
.63566 .57888 L
s
% Start of user PostScript
0.678735 0.60456 0.635656 0.578883 MAarrowhead1
% End of user PostScript
.60881 .63535 m
.5844 .60155 L
s
% Start of user PostScript
0.60881 0.63535 0.5844 0.601551 MAarrowhead1
% End of user PostScript
.63919 .77313 m
.60786 .72059 L
s
% Start of user PostScript
0.639195 0.773134 0.607864 0.720586 MAarrowhead1
% End of user PostScript
.4952 .66248 m
.51074 .62523 L
s
% Start of user PostScript
0.495204 0.662483 0.510736 0.62523 MAarrowhead1
% End of user PostScript
.55887 .46897 m
.53449 .48125 L
s
% Start of user PostScript
0.55887 0.468973 0.534493 0.481248 MAarrowhead1
% End of user PostScript
.42909 .39622 m
.45179 .4274 L
s
% Start of user PostScript
0.429092 0.396224 0.45179 0.427403 MAarrowhead1
% End of user PostScript
.30339 .70727 m
.33858 .67176 L
s
% Start of user PostScript
0.303395 0.707265 0.338577 0.671762 MAarrowhead1
% End of user PostScript
.32095 .45138 m
.36877 .45629 L
s
% Start of user PostScript
0.320954 0.451382 0.368774 0.456294 MAarrowhead1
% End of user PostScript
.41121 .45417 m
.4435 .45902 L
s
% Start of user PostScript
0.411206 0.454168 0.443503 0.459019 MAarrowhead1
% End of user PostScript
.65434 .4854 m
.60983 .49375 L
s
% Start of user PostScript
0.654345 0.485397 0.609833 0.493754 MAarrowhead1
% End of user PostScript
.33462 .3945 m
.3794 .41878 L
s
% Start of user PostScript
0.334625 0.394497 0.379399 0.418775 MAarrowhead1
% End of user PostScript
.34958 .28914 m
.38006 .32984 L
s
% Start of user PostScript
0.34958 0.289144 0.380059 0.329839 MAarrowhead1
% End of user PostScript
.51296 .16393 m
.50959 .21039 L
s
% Start of user PostScript
0.512961 0.163935 0.509592 0.210386 MAarrowhead1
% End of user PostScript
.50875 .34793 m
.51282 .39135 L
s
% Start of user PostScript
0.50875 0.347932 0.512817 0.391351 MAarrowhead1
% End of user PostScript
.54207 .42477 m
.52794 .45224 L
s
% Start of user PostScript
0.542067 0.42477 0.527944 0.452239 MAarrowhead1
% End of user PostScript
.50944 .16237 m
.50691 .20873 L
s
% Start of user PostScript
0.509444 0.162374 0.506907 0.208735 MAarrowhead1
% End of user PostScript
.52203 .53394 m
.52315 .51208 L
s
% Start of user PostScript
0.522034 0.533935 0.523148 0.512082 MAarrowhead1
% End of user PostScript
.333 .73031 m
.36037 .68732 L
s
% Start of user PostScript
0.333001 0.730309 0.360366 0.687319 MAarrowhead1
% End of user PostScript
.64541 .53495 m
.60323 .52896 L
s
% Start of user PostScript
0.645405 0.534952 0.603225 0.52896 MAarrowhead1
% End of user PostScript
.66157 .56123 m
.61754 .54731 L
s
% Start of user PostScript
0.661572 0.561228 0.61754 0.547311 MAarrowhead1
% End of user PostScript
.47896 .41423 m
.4905 .4441 L
s
% Start of user PostScript
0.478957 0.41423 0.490499 0.444104 MAarrowhead1
% End of user PostScript
.47849 .5438 m
.50124 .51604 L
s
% Start of user PostScript
0.478489 0.543796 0.50124 0.51604 MAarrowhead1
% End of user PostScript
.31225 .69662 m
.34596 .66245 L
s
% Start of user PostScript
0.312247 0.696615 0.345957 0.662446 MAarrowhead1
% End of user PostScript
.66524 .41089 m
.62101 .43491 L
s
% Start of user PostScript
0.665242 0.410886 0.621009 0.434907 MAarrowhead1
% End of user PostScript
.6862 .28932 m
.63893 .33154 L
s
% Start of user PostScript
0.686205 0.289315 0.63893 0.331536 MAarrowhead1
% End of user PostScript
.43336 .54105 m
.46984 .51943 L
s
% Start of user PostScript
0.433356 0.541049 0.469837 0.519426 MAarrowhead1
% End of user PostScript
.44727 .74272 m
.47014 .7019 L
s
% Start of user PostScript
0.447266 0.742724 0.470138 0.701902 MAarrowhead1
% End of user PostScript
.57711 .44948 m
.5485 .46886 L
s
% Start of user PostScript
0.577108 0.449478 0.5485 0.46886 MAarrowhead1
% End of user PostScript
.33141 .66711 m
.36381 .63648 L
s
% Start of user PostScript
0.331409 0.667108 0.363809 0.636475 MAarrowhead1
% End of user PostScript
.56524 .32843 m
.55084 .37308 L
s
% Start of user PostScript
0.565243 0.328433 0.550841 0.373085 MAarrowhead1
% End of user PostScript
.37283 .42134 m
.41043 .4379 L
s
% Start of user PostScript
0.37283 0.421345 0.410426 0.4379 MAarrowhead1
% End of user PostScript
.53596 .50004 m
.52325 .49658 L
s
% Start of user PostScript
0.535957 0.500042 0.523245 0.496579 MAarrowhead1
% End of user PostScript
.57 .57128 m
.55577 .5456 L
s
% Start of user PostScript
0.569996 0.571282 0.555766 0.545598 MAarrowhead1
% End of user PostScript
.80553 .35037 m
.76009 .37851 L
s
% Start of user PostScript
0.805527 0.350373 0.760094 0.378506 MAarrowhead1
% End of user PostScript
.704 .50656 m
.65389 .50935 L
s
% Start of user PostScript
0.704003 0.506562 0.653892 0.509347 MAarrowhead1
% End of user PostScript
.49062 .73914 m
.50282 .69761 L
s
% Start of user PostScript
0.490625 0.739142 0.502818 0.697614 MAarrowhead1
% End of user PostScript
.28693 .67644 m
.32802 .648 L
s
% Start of user PostScript
0.286933 0.67644 0.328022 0.647997 MAarrowhead1
% End of user PostScript
.67308 .6162 m
.63188 .58864 L
s
% Start of user PostScript
0.673079 0.616198 0.63188 0.588638 MAarrowhead1
% End of user PostScript
.45197 .56123 m
.48346 .53254 L
s
% Start of user PostScript
0.451965 0.561229 0.48346 0.532537 MAarrowhead1
% End of user PostScript
.34774 .56429 m
.3854 .54699 L
s
% Start of user PostScript
0.347738 0.56429 0.385398 0.546986 MAarrowhead1
% End of user PostScript
.52826 .72564 m
.53152 .68279 L
s
% Start of user PostScript
0.52826 0.725642 0.531515 0.682788 MAarrowhead1
% End of user PostScript
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.35119 0.343006 0.64881 0.640625 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[0 1.025 -5 0 ]
[0 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
0 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.76704 .46948 Mdot
.51511 .50359 Mdot
.67112 .56246 Mdot
.64281 .47418 Mdot
.62936 .33058 Mdot
.66175 .745 Mdot
.76889 .46261 Mdot
.3357 .2376 Mdot
.82982 .48202 Mdot
.30921 .4263 Mdot
.27372 .6541 Mdot
.75811 .61384 Mdot
.48847 .47807 Mdot
.44937 .77505 Mdot
.67112 .31136 Mdot
.30849 .42772 Mdot
.49182 .59647 Mdot
.34502 .28582 Mdot
.3026 .45528 Mdot
.52022 .80144 Mdot
.56038 .28783 Mdot
.65916 .42592 Mdot
.30896 .27118 Mdot
.68909 .66578 Mdot
.56159 .78676 Mdot
.77441 .66365 Mdot
.42102 .44332 Mdot
.5348 .30527 Mdot
.4972 .49833 Mdot
.29286 .69988 Mdot
.42821 .72027 Mdot
.24667 .71364 Mdot
.5015 .46034 Mdot
.43727 .26886 Mdot
.41214 .5975 Mdot
.68501 .22129 Mdot
.33591 .61857 Mdot
.55492 .50265 Mdot
.64661 .549 Mdot
.24904 .53244 Mdot
.46704 .34929 Mdot
.31323 .75137 Mdot
.35626 .25489 Mdot
.57489 .81816 Mdot
.64754 .73109 Mdot
.50572 .33081 Mdot
.70213 .55575 Mdot
.59621 .65616 Mdot
.52258 .48189 Mdot
.36571 .59196 Mdot
.73365 .65054 Mdot
.623 .74101 Mdot
.36261 .36198 Mdot
.77272 .63508 Mdot
.56641 .75713 Mdot
.74876 .70575 Mdot
.39543 .82042 Mdot
.31413 .35656 Mdot
.28526 .49004 Mdot
.46202 .39951 Mdot
.63738 .34406 Mdot
.1996 .42677 Mdot
.77988 .54227 Mdot
.42494 .43535 Mdot
.40408 .37057 Mdot
.54045 .34233 Mdot
.40352 .26194 Mdot
.67442 .41791 Mdot
.32879 .29693 Mdot
.22342 .35824 Mdot
.41819 .57573 Mdot
.67928 .69801 Mdot
.52801 .22559 Mdot
.67123 .2475 Mdot
.83778 .48372 Mdot
.23558 .53058 Mdot
.28453 .35585 Mdot
.66108 .43821 Mdot
.50835 .51231 Mdot
.47574 .82891 Mdot
.51724 .33543 Mdot
.55883 .47513 Mdot
.43625 .42725 Mdot
.67598 .56142 Mdot
.6444 .63438 Mdot
.27234 .56059 Mdot
.35274 .6437 Mdot
.54596 .81476 Mdot
.79282 .5618 Mdot
.27909 .4503 Mdot
.70608 .71395 Mdot
.25838 .46407 Mdot
.34118 .36629 Mdot
.61559 .31048 Mdot
.52427 .65901 Mdot
.58161 .51756 Mdot
.30258 .74925 Mdot
.60574 .29286 Mdot
.52481 .69319 Mdot
.65236 .28522 Mdot
.26442 .58221 Mdot
.41617 .46498 Mdot
.22655 .37429 Mdot
.44396 .72125 Mdot
.54534 .66455 Mdot
.49202 .47416 Mdot
.50387 .5328 Mdot
.78079 .3424 Mdot
.56702 .56676 Mdot
.40538 .64214 Mdot
.66953 .71863 Mdot
.49209 .23331 Mdot
.5719 .47587 Mdot
.29034 .59498 Mdot
.39716 .39065 Mdot
.49027 .50776 Mdot
.34565 .20772 Mdot
.81765 .37537 Mdot
.38347 .19818 Mdot
.49107 .56449 Mdot
.61733 .23647 Mdot
.62188 .75247 Mdot
.53929 .47892 Mdot
.48029 .45587 Mdot
.5556 .82686 Mdot
.28086 .49884 Mdot
.64397 .28322 Mdot
.36367 .66903 Mdot
.25749 .63207 Mdot
.39028 .30757 Mdot
.79643 .46117 Mdot
.37969 .34362 Mdot
.46438 .52179 Mdot
.44443 .23409 Mdot
.48049 .15685 Mdot
.44521 .752 Mdot
.50538 .45208 Mdot
.59102 .51929 Mdot
.58499 .66545 Mdot
.72831 .38406 Mdot
.76632 .50643 Mdot
.41388 .49584 Mdot
.45163 .81081 Mdot
.70557 .67458 Mdot
.73207 .69687 Mdot
.28952 .22921 Mdot
.2787 .28954 Mdot
.36978 .39122 Mdot
.7331 .67667 Mdot
.55612 .39405 Mdot
.579 .66451 Mdot
.63567 .69256 Mdot
.25659 .62421 Mdot
.65723 .37745 Mdot
.25251 .67903 Mdot
.77805 .55772 Mdot
.49072 .49772 Mdot
.31466 .28234 Mdot
.55264 .5921 Mdot
.46792 .68749 Mdot
.42795 .66902 Mdot
.46259 .38622 Mdot
.49355 .50566 Mdot
.5747 .25517 Mdot
.5378 .64911 Mdot
.56781 .59649 Mdot
.692 .57624 Mdot
.36101 .64815 Mdot
.52802 .29671 Mdot
.76932 .46973 Mdot
.59185 .38072 Mdot
.64415 .45833 Mdot
.58048 .18904 Mdot
.43477 .49763 Mdot
.31984 .23521 Mdot
.69345 .44857 Mdot
.41634 .27023 Mdot
.62575 .5463 Mdot
.56727 .44014 Mdot
.77124 .38509 Mdot
.32792 .70157 Mdot
.52014 .56777 Mdot
.5092 .31763 Mdot
.20154 .50222 Mdot
.54293 .70874 Mdot
.51214 .77749 Mdot
.59328 .27601 Mdot
.35562 .4683 Mdot
.26768 .7525 Mdot
.49465 .46111 Mdot
.46895 .18992 Mdot
.6315 .53556 Mdot
.4191 .42243 Mdot
.58484 .55236 Mdot
.72448 .6945 Mdot
.59097 .35502 Mdot
.59683 .62632 Mdot
.64336 .29226 Mdot
.25928 .36147 Mdot
.34281 .43577 Mdot
.22732 .56143 Mdot
.63588 .57862 Mdot
.81196 .46182 Mdot
.48656 .55043 Mdot
.29246 .33057 Mdot
.19156 .59288 Mdot
.49069 .1823 Mdot
.65287 .32498 Mdot
.63885 .30742 Mdot
.46277 .82559 Mdot
.1927 .4684 Mdot
.7311 .43503 Mdot
.47356 .57871 Mdot
.60414 .60142 Mdot
.37736 .44138 Mdot
.60784 .56057 Mdot
.55556 .72821 Mdot
.61412 .39011 Mdot
.44472 .24002 Mdot
.47529 .78553 Mdot
.55701 .5517 Mdot
.50839 .80461 Mdot
.58258 .38771 Mdot
.36735 .46662 Mdot
.52821 .41195 Mdot
.32979 .2066 Mdot
.18369 .54321 Mdot
.64611 .25254 Mdot
.33664 .48311 Mdot
.55414 .69493 Mdot
.74657 .57968 Mdot
.59426 .75254 Mdot
.59478 .70995 Mdot
.60095 .79503 Mdot
.36864 .42608 Mdot
.70799 .36485 Mdot
.59542 .51959 Mdot
.24585 .51285 Mdot
.54648 .36789 Mdot
.76272 .32641 Mdot
.18059 .42345 Mdot
.68495 .44014 Mdot
.48865 .35349 Mdot
.7797 .51238 Mdot
.59516 .23667 Mdot
.7928 .61488 Mdot
.30245 .53307 Mdot
.38542 .58192 Mdot
.44528 .35823 Mdot
.63629 .71256 Mdot
.52338 .52739 Mdot
.2145 .49608 Mdot
.54475 .43849 Mdot
.55287 .34398 Mdot
.30317 .73075 Mdot
.73508 .56824 Mdot
.52493 .43365 Mdot
.52543 .77749 Mdot
.27615 .37025 Mdot
.67873 .60456 Mdot
.60881 .63535 Mdot
.63919 .77313 Mdot
.4952 .66248 Mdot
.55887 .46897 Mdot
.42909 .39622 Mdot
.30339 .70727 Mdot
.32095 .45138 Mdot
.41121 .45417 Mdot
.65434 .4854 Mdot
.33462 .3945 Mdot
.34958 .28914 Mdot
.51296 .16393 Mdot
.50875 .34793 Mdot
.54207 .42477 Mdot
.50944 .16237 Mdot
.52203 .53394 Mdot
.333 .73031 Mdot
.64541 .53495 Mdot
.66157 .56123 Mdot
.47896 .41423 Mdot
.47849 .5438 Mdot
.31225 .69662 Mdot
.66524 .41089 Mdot
.6862 .28932 Mdot
.43336 .54105 Mdot
.44727 .74272 Mdot
.57711 .44948 Mdot
.33141 .66711 Mdot
.56524 .32843 Mdot
.37283 .42134 Mdot
.53596 .50004 Mdot
.57 .57128 Mdot
.80553 .35037 Mdot
.704 .50656 Mdot
.49062 .73914 Mdot
.28693 .67644 Mdot
.67308 .6162 Mdot
.45197 .56123 Mdot
.34774 .56429 Mdot
.52826 .72564 Mdot
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{520.688, 341.688},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000::0001Zb000`400?l00000o`00003ooooooooo
ooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo
003oooooooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003ooooooooo
ooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool0
0?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooo
oon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?ooooooiOooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00002_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`02_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`04_ooool4o`00
0003oa0@4?oooooooooo01cooooo003oooooonGooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400[ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`08ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0:ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@0Dooooo`03o`000?oooooo
oooo01kooooo003oooooonGooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7o
k^k^00_ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00002Oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go0000ooooooooooooooooo`00000:ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000001Cooooo00?o0000ooooooooool07_ooool0
07oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0aoooool5o`0000?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP24ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP0:ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000:oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00[ooooo00Go
0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S805?ooool00ol0003o
ooooooooo`0Nooooo`00Ooooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`37ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg08Cooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Wooooo
00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000[ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`02_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00Dooooo`03o`000?oooooooooo01ko
oooo0020ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4038ooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4024ooooo`05oa0@4?oooooooooo
ooooool@41003oooool00ol0003oooooooooo`08ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00omgMgOoc<c<o`00000:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7
ooooo`0<ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@
01Cooooo00?o0000ooooooooool07_ooool0087ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003o
oooooooooooooooo00000<Wooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000008Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
2_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000002_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P03?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000Dooooo`03o`000?oooooooooo01kooooo0022
ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00003:ooooo`03ogMgMomV
IVKooooo00;ooooo00Go0000ooooooooooooooooo`000024ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=
ooooo`03ogMgMol0003ooooo00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4
A4Co0000oa0@40[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT04_ooool00omEEEGoIVIVo`00000Pooooo`00Poooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0bOooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool0ooooool@ooooo`;o00000_ooool2o`0001?ooooo001oooooo`05o`000?nj^[[ooooo
oiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg0<Oooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0oooooolBooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM4oooool007oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0aoooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP3ooooooa?ooooo00CogMgMo`000?l@413oc<c<5?ooool00?ooooood_oooonIo`0000So
oooo00Cok^k^ob4Q8Ol@413ok^k^5?ooool00?ooooood_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool01?lQ8B7oMgMgogMgMolb<S8Doooo
o`00oooooooBooooo`03o`000?oooooooooo09gooooo0_l00002ooooo`;o00004oooool008_ooooo
0_l0003Cooooo`;o0000Koooool00ol0003oooooooooo`2fooooo`00R?ooool6o`000<oooooo0ol0
00000ooooooo0000ooooo`1^ooooo`03o`000?oooooooooo0;Kooooo001Mooooo`Co000000Go410@
ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo01_ooooo1Ol000000onY_NSo0000o`00
002Sooooo`Co000000Go410@ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo01cooooo
0_l00004ooooo`;o0000K_ooool00ol0003oooooooooo`2fooooo`00Goooool00ol0003ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo01Sooooo1Ol00004ojVmj0?o0000Y?ooool00ol0003ooooooooo
o`06ooooo`03ogMgMolb<S;ooooo01Wooooo0ol00006ooooo`03o`000?oooooo000006gooooo00?o
0000ooooooooool0]_ooool005oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0D
ooooo`Ko00001_nY_NP00ol0003oZKgXo`00002Tooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool05Oooool3o`0000Wooooo00?o0000ooooool00000KOooool00ol0003oooooooooo`2f
ooooo`00Goooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01?ooooo1Ol00002ojVm
j003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00_l0002Rooooo`03o`000?oooooooooo
00Kooooo00?oMgMgoc8b<_ooool05?ooool2o`0000cooooo00Co0000ooooool0003o0000K?ooool0
0ol0003oooooooooo`2fooooo`00Goooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`04Oooool5o`0000KoZKgX00?o0000ojVmj?nY_NP00onY_NP00ol0003oZKgXojVmj002
o`000:;ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01;ooooo1?l0
000=ooooo`05o`000?ooooooooooooooool00000Joooool00ol0003oooooooooo`2fooooo`00Gooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo1?l000000onY_NSo0000ojVm
j007ojVmj003o`000?nY_NSoZKgX00;oZKgX0ol000000onY_NSo0000ooooo`2Qooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool04_ooool2o`00017ooooo00Go0000oooooooooooooooo
o`00001[ooooo`03o`000?oooooooooo0;Kooooo001Oooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03_ooool5o`0000CoZKgX00?o0000ojVmj?nY_NP01_nY_NP01_l0003oZKgXo`00
0?l0003oZKgXo`0000?oZKgX00?o0000ooooooooool0Woooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00oooooo0ol0000Cooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0J?ooool00ol0003oooooooooo`2fooooo`00GOooool00omEEEGoIVIVo`000005ooooo`Co0000
2oooool2o`000003ooooool0003o000000OoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000?oZKgX
00?o0000ojVmj?nY_NP00_nY_NP00ol0003oooooooooo`2Looooo`03oeEEEOmVIVKo000000Gooooo
1?l0000;ooooo`?o00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0Ioooool00ol0003oooooooooo`2fooooo`00LOooool6o`000003ojVmj?l0
003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj005o`000?nY_NSoZKgXojVmj?l00000
1?nY_NP2o`000;;ooooo0_l0000Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`2fooooo`00K_ooool6o`0000GoZKgX00?o0000ojVmj?nY_NP01OnY
_NP3o`0000KoZKgX00Co0000ojVmj?nY_NSo00001?nY_NP2o`000:oooooo1?l0000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`2fooooo`00K?oo
ool2o`000004ooooool0003o0000o`0000SoZKgX00Co0000ojVmj?nY_NSoZKgX0ol000000onY_NSo
0000ojVmj007ojVmj004o`000?nY_NSo0000ojVmj0?o000000?oZKgXo`000?l00000[?ooool2o`00
01oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo
0;Kooooo001Yooooo`Ko00000_nY_NP00ol0003oZKgXojVmj006ojVmj004o`000?nY_NSo0000o`00
00GoZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgXo`000?l00005ojVmj003o`000?oooooo
oooo0:Oooooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`2fooooo`00Ioooool5o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`00
00SoZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000OoZKgX00?o0000ooooooooool01Oooool01Om4
A4Co0000o`000?lb<S;ogMgM09Wooooo0ol000000ooooooo0000ooooo`0Qooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool01Om4A4Co0000o`000?lb<S;ogMgM05[ooooo00?o
0000ooooooooool0]_ooool003cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^7?ooool5o`000003ojVmj?l0003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003
o`000?nY_NSoZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj0;o00001onY_NP2o`0000Wo
oooo00?oMgMgoc8b<_ooool0KOooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^hMooooo`;o00009oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o
MgMgoc8b<_ooool0FOooool00ol0003oooooooooo`2fooooo`00?_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool5o`0000CoZKgX00?o0000ojVmj?nY_NP01OnY
_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY
_NP3o`0000[ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL06_ooool4o`0002Sooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0]_ooool003kooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Oooooo1_l00007ojVmj003o`00
0?nY_NSoZKgX00;oZKgX0_l000000onY_NSo0000ojVmj007ojVmj004o`000?nY_NSoZKgXojVmj0?o
000000?oZKgXo`000?nY_NP01_nY_NP2o`0000;oZKgX0ol00002ojVmj0;o00002?ooool00omgMgOo
<S8booooo`1_ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Hoooo
o`;o0000;?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b
<_ooool0FOooool00ol0003oooooooooo`2fooooo`00?_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000005Oooool5o`0000;oZKgX00?o0000ojVmj?nY_NP01_nY_NP01?l0
003oZKgXo`000?l00004ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001OnY
_NP00ol0003oZKgXojVmj004ojVmj0Co00001_nY_NP00ol0003oooooooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`0L?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00005Oooool3o`0002kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`0F_ooool00ol0003oooooooooo`2fooooo`00?_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000004_ooool5o`0000KoZKgX00?o0000ojVm
j?nY_NP01?nY_NP3o`0000OoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000SoZKgX00Co0000ojVm
j?nY_NSoZKgX0ol000000onY_NSo0000ojVmj007ojVmj0;o00000oooool00ol0003oooooooooo`1b
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`;o000000?o
ooooo`000?ooool0;_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0G?ooool00ol0003oooooooooo`2fooooo`00?_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41003oooool5o`000003ojVmj?l0003oZKgX00OoZKgX00?o
0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00KoZKgX00?o0000ojVmj?nY_NP00ol0
0002ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00000_nY_NP01?l0003oZKgX
ojVmj?l00007ojVmj0;o00000oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`?o0000<oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`2foooo
o`00?_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool5o`00
00CoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`00
00KoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000CoZKgX00Go0000ojVmj?nY_NSoZKgXo`000003
ojVmj0?o000000?oZKgXo`000?ooool00_ooool4o`00077ooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00gooooo1?l0000eooooo`03o`000?oooooooooo00Wooooo00Co
0000oooooooooooooooo1?l0001Kooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
KOooool003cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00[ooooo
0ol000000ooooooo0000o`000007ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l000000onY_NSo0000
ojVmj007ojVmj004o`000?nY_NSoZKgXojVmj0?o000000?oZKgXo`000?nY_NP01onY_NP00ol0003o
ZKgXojVmj003o`0000;oZKgX00Go0000ojVmj?nY_NSoZKgXo`000003ojVmj004o`000?nY_NSo0000
o`0000GoZKgX00?o0000ooooooooool0Loooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool2o`0003Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1Oooooo`03o`000?oooooooooo04Kooooo00Co0000oooooooooooooooo0_l0001Zooooo`00D?oo
ool2o`000004ooooool0003o0000o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgX
o`000?l00004ojVmj003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001OnY_NP00ol0
003oZKgXojVmj005ojVmj0?o00001_nY_NP01Ol0003oZKgXojVmj?nY_NSo000000;oZKgX0_l00008
ojVmj003o`000?oooooooooo08Kooooo0ol0000kooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`16ooooo`04o`000?ooooooooooooooo`;o0000J_oo
ool004gooooo1_l00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00007ojVmj003o`000?nY_NSo
ZKgX00CoZKgX0_l00008ojVmj004o`000?nY_NSoZKgXojVmj0?o000000?oZKcWo`000?nY_NP01onY
_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003oZKgX00OoZKgX0_l00025ooooo`;o00000_oo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`16ooooo`04o`000?ooooooooooooooo`;o0000J_ooool004_ooooo1Ol0
00000onY_NSo0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVm
j005ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY
_NSo0000o`0000GoZKcW00?o0000ojVmj?nY_NP01OnY_NP4o`0000CoZKgX00?o0000ojVmj?nY_NP0
1?nY_NP3o`0008;ooooo0ol00010ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
A?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool00ol0003o
ooooooooo`16ooooo`?o000000?oooooo`000?l00000J_ooool004Sooooo1Ol00005ojVmj003o`00
0?nY_NSoZKgX00GoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00006ojVmj003o`00
0?nY_NSoZKgX00CoZKgX0_l00008ojVli`04o`000?nY_NSoZKgXojVmj0?o000000CoZK_Vo`000?nY
_NSo00001OnY_NP00ol0003oZKgXojVmj003o`0000;oZKgX0_l0001nooooo`Co0000@_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo04?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Cooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooo`000005o`0000Wooooo00?o0000ooooooooool0G_ooool002Gooooo00GoA4A4
o`000?l0003o<S8bomgMg@0Kooooo`?o000000Coooooo`000?l0003o00001onY_NP01?l0003oZKgX
ojVmj?nY_NP3o`000003ojVmj?l0003oZKgX00OoZKgX00?o0000ojVmj?nY_NP00ol000000onX/n7o
0000ojVmj007ojVmj003o`000?nY_NSoZKgX00?o00000_nY^^D00ol0003oZKcWojVli`05ojVli`04
o`000?nY_NSo0000o`0000GoZK_V0_l00005ojVmj0?o00001_nY_NP00ol0003oooooooooo`1Ioooo
o`05odA4A?l0003o0000oc8b<_oMgMd07?ooool2o`0000Cooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04?ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Go00002Oooool00ol0003oooooooooo`1Nooooo`00:?ooool0
0omgMgOo<S8booooo`0Hooooo`;o000000Coooooo`000?l0003o00000_nY_NP00ol0003oZKgXojVm
j005ojVmj004o`000?nY_NSo0000o`0000GoZKgX00?o0000ojVmj?nY_NP01OnY_NP3o`0000GoZ;?Q
00?o0000ojVmj?nY_NP01?nY_NP4o`0000KoZK[U00?o0000ojVlionY_>L01?nY_>L2o`0000SoZK_V
00Co0000ojVmj?nY_NSoZKgX0_l000000onY_NSo0000ojVmj007ojVmj0;o0000G?ooool00omgMgOo
<S8booooo`0Hooooo`?o0000B?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04;o
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Cooooo0_l0000hoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`09oooo
o`03o`000?oooooooooo05kooooo000Yooooo`03o`000?oooooooooo01Cooooo1_l00006ojVmj003
o`000?nY_NSoZKgX00CoZKgX0_l00008ojVmj004o`000?nY_NSoZKgXojVmj0?o000000?oYj[Io`00
0?nX/n401_nX/n400ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVjiOnY^^D01_nY^^D00ol0
003oZKcWojVli`03o`000003oj:Ba?l0003oZK_V00OoZK_V00Co0000ojVmj?l0003o00001?nY_NP0
0ol0003oZKgXojVmj005ojVmj0;o0000GOooool00ol0003oooooooooo`0Eooooo`;o00000_ooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo00kooooo0_l00013ooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooool000001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;o000000?o
ooooo`000?ooool02?ooool00ol0003oooooooooo`1Oooooo`00:?ooool00omgMgOo<S8booooo`0C
ooooo`;o000000?oooooo`000?l000000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo
ZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY_NSo0000o`0000GoYj[I00?o
0000ojRchOnX/n401?nX/n43o`0000KoZKgX00?o0000ojVjiOnY^^D01OnY^^D3o`0000GoXY;400?o
0000ojVki_nY^nH01?nY^nH3o`0000OoZKgX00Co0000ojVmj?nY_NSoZKgX0ol000000onY_NSo0000
ooooo`1Kooooo`03ogMgMolb<S;ooooo01?ooooo0ol0001=ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0@Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo000000Kooooo00?o0000oooooooo
ool02Oooool5o`0000_ooooo00?o0000ooooooooool0Goooool002Gooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00Aooooo`Ko00001OnY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003o
ZKgXojVmj004ojVmj0;o00001onWZ]T00ol0003oZ;?QojRch@03ojRch@03o`000?nZW<So000000So
ZKgX00Co0000ojVjiOnY^^GoZK[U0ol000000onLPKCo0000oj:Ba006oj:Ba003o`000?nY^nKoZK_V
00?o000000?o[;kWo`000?l000001onY_NP01?l0003oZKgXo`000?l00005ojVmj003o`000?oooooo
oooo05Kooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Booooo`;o000000?oooooo`000?ooool0COoo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo043ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooo000000Gooooo00?o0000ooooooooool02Oooool3o`000003ooooool0003ooooo00Wo
oooo0_l0000@ooooo`03o`000?oooooooooo04kooooo000Uooooo`03o`000?oooooooooo017ooooo
0_l00002ooooo`;o00002?nY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP0
1OnY_NP00ol0003oZKgXojVmj003o`000003ojVghol0003oYj[I00OoYj[I00?o0000ojRchOnX/n40
0_l00003ojZLb003o`000?nY_NSoZKgX00GoZKgX00Co0000ojVjiOl0003o00001OnLPK@00ol0003o
XY;4oj:Ba005oj:Ba0;o00001?n/_^L00ol0003o[;kWo`000006ojVmj0;o00002?nY_NP00ol0003o
ooooooooo`1Eooooo`03o`000?oooooooooo017ooooo0ol0001Booooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0?oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c004ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Oooool2
o`0000Gooooo0ol00009ooooo`?o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`03
ooooo`;o00004?ooool00ol0003oooooooooo`1>ooooo`009Oooool00ol0003oooooooooo`0>oooo
o`Oo00000_nY_NP00ol0003oZKgXojVmj005ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVm
j0?o00001OnY]n<00ol0003oYj[IojNZf@05ojNZf@03o`000?nX/n7o000000KoZYc800?o0000ojVm
j?nY_NP01?nY_NP2o`0000OoW86d00?o0000oj:Ba?nRT/@01OnRT/@00ol0003o[;kWojbni`03ojbn
i`04o`000?n/_^Oo[;kWo`0000;oZKgX0ol000000onY^nKo0000ojVmj007ojVmj0;o0000E_ooool0
0ol0003oooooooooo`0>ooooo`Co0000E?ooool00ol0003oooooooooo`0@ooooo`;o0000F_ooool0
0ol0003oooooooooo`0Zooooo`08o`000?ooooooooooooooool0003oooooo`000?ooool4o`0000;o
oooo0ol00006ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00008
ooooo`03o`000?oooooooooo04oooooo000Uooooo`Co00002_ooool3o`000004ooooool0003o0000
o`0000KoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`000003ojVmj?l0003oZKgX00OoZKgX00?o0000
ojVmj?nY_NP00ol000000onWZm[o0000ojVgh`06ojVgh`03o`000?nWZ]WoYj[I00CoYj[I0_l00008
ojZLb003o`000?nY_NSoZKgX00?o000000?oUgN]o`000?nLPK@01_nLPK@00ol0003oXY;4oj:Ba004
oj:Ba003o`000?n^QJWo000000Co[;kW00?o0000ojbnion/_^L00ol00005ojVkiP03o`000?nY_NSo
ZKgX00CoZKgX0ol0001Fooooo`Co00002oooool2o`0005Sooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo02_ooooo00Go0000oooooooooooo0000oooo
o`06o`0000?ooooo0_l00006ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo053ooooo000aooooo`;o000000Coooooo`000?l0003o
00000_nY_NP00ol0003oZKgXojVmj005ojVmj004o`000?nY_NSo0000o`0000CoZKgX00?o0000ojVm
j?nY_NP01OnY_NP3o`0000GoYj_J00?o0000ojVghonY]n<01?nY]n<00ol0003oYj[IojNZf@02ojNZ
f@;o000000?oYY6no`000?nZW<P01onZW<P3o`0000GoUgN]00?o0000oib1]?nLPK@01OnLPK@00ol0
003oXY;4oj:Ba002oj:Ba005o`000?n^QJWo[XFYojj5ZOl000000on/_^L3o`000003ojbmi_l0003o
ZK_V00KoZK_V00?o0000ojVmj?nY_NP00ol00002ojVmj0;o0000HOooool3o`0005_ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo02cooooo00Oo0000
oooooooooooo0000ooooool0003ooooo00?o00001?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`04o`00
0?ooooooooooo`0000Kooooo0ol0001Booooo`00;_ooool6o`0000KoZKgX00?o0000ojVmj?nY_NP0
1?nY_NP2o`0000OoZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`000003ojR_gOl0003oYj_J00KoYj_J
00?o0000ojVghonY]n<01?nY]n<01?l0003oYj[Io`000?l00004ojJA_P03o`000?nZW<SoZYc800Co
ZYc800?o0000ol2R^ol000001_nGMjd00ol0003oW86doib1]005oib1]005o`000?nRT/CoXY;4oj:B
a?l000001?n^QJT00ol0003o[;kWo`000002o`0000Co[;gV00?o0000ojVki_nY^nH01?nY^nH3o`00
00KoZKgX00?o0000ooooooooool01Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^i<ooooo`;o00000_ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool01Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^i5
ooooo`03o`000?oooooooooo02gooooo00Go0000oooooooooooo0000ooooo`04o`0000_ooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooooooool2o`0000Kooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;o0000D_ooool002cooooo
1Ol00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`00
0?nY_NSoZKgX00GoZKgX00Co0000ojVmj?l0003o00001?nX[md00ol0003oYj_JojN[fP05ojN[fP04
o`000?nY]n?oZKOSojVgh`Co00001_nVTKh00ol0003oZYc8ojZLb003ojZLb004o`000?o0X[_o`::k
o`0000KoUgN]00?o0000oib1]?nLPK@01OnLPK@01?l0003oXY;4oj:Ba?l00006ojj5Z@04o`000?n/
_NKo[;gVo`0000Go[;gV00?o0000ojVki_nY^nH00ol000000onYZMKo0000ojVmj006ojVmj0;o0000
2?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0BOooool3o`00063o
oooo00?o0000ooooooooool04_ooool2o`0000Sooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg04Gooooo00?o0000ooooooooool0;?ooool3o`0000;ooooo1?l00005oooo
o`03o`000?oooooooooo00Cooooo0_l00004ooooo`?o00000_ooool3o`0000Gooooo00Ko0000oooo
oooooooo0000ooooool00005ooooo`Co0000Doooool002Wooooo1Ol00006ojVmj003o`000?nY_NSo
ZKgX00CoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00007ojR_g@03o`000?nWZm[o
Yj_J00CoYj_J1?l00003oi1a[003o`000?nVTKkoYY6n00GoYY6n00Go0000ojZLb?nZW<SoZYc8o`00
0004ol2R^`03o`000?nGMjgoUgN]00CoUgN]00?o0000oib1]?nLPK@01OnLPK@2o`0000Oo[XFY00Go
0000ojbmi_n/_NKo[;gVo`000004ojbmiP?o00001OnYZMH00ol0003oZKgXojVmj004ojVmj0?o0000
1oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100A_ooool3o`0000;o
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@04Gooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`06o`0000Gooooo00?o0000ooooool000000_ooool01?l0
003oooooo`000?l00004ooooo`?o00000_ooool3o`0000Gooooo00?o0000ooooool000000_ooool0
0ol0003oooooooooo`02ooooo`04o`000?oooooo0000o`0005Cooooo000Wooooo`Co00000_nY_NP0
0ol0003oZKgXojVmj005ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005
ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?nX[md01_nX[md00ol0003oYj_JojN[fP02
ojN[fP;o000000?oYXfko`000?n@LJ`01On@LJ`00ol0003oYY6nojJA_P04ojJA_P04o`000?nZW<So
ZYc8o`0000Go`::k00?o0000oiMg[OnGMjd01?nGMjd00ol0003oW86doib1]005oib1]003o`000?n^
QJWo[XFY00Go[XFY00?o0000okW4A?l000000_n/_NH00ol0003o[;gVo`000002o`000003ojNQd?l0
003oZJWF00KoZJWF00?o0000ojVmj?nY_NP00ol000000onY_NSo0000o`000007ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000014ooooo`;o0000I_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000004Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`03ooooo`Co
00001Oooool2o`0000;ooooo00Co0000ooooool0003o00001Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo1_l00003ooooo`04o`000?ooooooooooo`0005Gooooo000Toooo
o`Go00001OnY_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVm
j0?o00001OnY_NP00ol0003oZ:oMojR_g@05ojR_g@04o`000?nWZm[o0000o`0000?oYXfk00?o0000
oi1a[?n@LJ`01?n@LJ`00ol0003oYY6nojJA_P04ojJA_P03o`000?nZW<So000000Ko`::k00?o0000
oiMg[OnGMjd01?nGMjd00ol0003oW86doib1]004oib1]0;o00001on^QJT01Ol0003o^LA4okW4A?l0
003o[;gV00;o00001OnWXM000ol0003oZJWFojVYeP04ojVYeP?o00001OnY_NP2o`0000Kooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000047ooooo1Ol0001Vooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000AOooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00?o
oooo00Co0000ooooool0003o00001?ooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo1_l00003
ooooo`Co0000EOooool002;ooooo0_l00002ooooo`;o00001onY_NP01?l0003oZKgXojVmj?nY_NP2
o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000
ojVmj?nY_NP01?nY_NP00ol0003oZ:oMojR_g@04ojR_g@;o00001_nVSK/00ol0003oT76/oi1a[003
oi1a[003o`000?nVTKkoYY6n00CoYY6n0_l00007ol2R^`03o`000?nGMjgoUgN]00GoUgN]00?o0000
oib1]?nLPK@00_nLPK@00ol0003oZ7nWo`000007ojj5Z@04o`000?nia4Co^LA4okW4A0;o00001_nW
XM000ol0003oZJWFojVYeP03ojVYeP03o`000?ngZ<[o000000OoZKgX0_l00005ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400oooooo`;o0000Joooool00ol0003ooooo
ooooo`0Eooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
4100AOooool00ol0003oooooooooo`0Wooooo`;o00001Oooool00ol0003oooooooooo`02o`0000;o
oooo0_l00005ooooo`;o00000_ooool00ol0003oooooo`00000?ooooo`;o000000?oooooo`000?l0
00000_l00002ooooo`;o000000Coooooo`000?l0003o00001?ooool00ol0003oooooooooo`1>oooo
o`007oooool7o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP00ol0003oZKgXo`000005ojVmj003
o`000?nY_NSoZKgX00CoZKgX0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojR_gOnX
[md00ol000000onMS/Co0000ojJ=^`05ojJ=^`03o`000?n@LJcoT76/00CoT76/00?o0000ojJA__nV
TKh00_nVTKh00ol0003o/9>ho`000007ol2R^`03o`000?nGMjgoUgN]00GoUgN]00Go0000oib1]?nL
PKCoW86do`000003ojQoY`03o`000?n^QJWo[XFY00?o[XFY00Co0000okW4A?nia4Co^LA40ol00007
ojNQd003o`000?nYZMKoZJWF00;o00000ongZ<X00ol0003oZKgXojVmj004ojVmj0;o00001Oooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0??ooool4o`0006cooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`15ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
0oooool4o`0000?ooooo0_l00003ooooo`Co000000?oooooo`000?l000002oooool00ol0003ooooo
ooooo`02ooooo`Ko000000?oooooo`000?ooool01_l00003ooooo`03o`000?oooooooooo04oooooo
000Looooo`?o000000Coooooo`000?l0003o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0;o0000
1onY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01OnY_NP01?l0003oZKgX
ojVmj?nY_NP5o`0000CoWHk400?o0000ojJ=^onVSK/01?nVSK/00ol0003oT76/oi1a[004oi1a[005
o`000?nVTKkoYY6nojJA__l000000on`TkP00ol0003o`::kol2R^`05ol2R^`03o`000?nGMjgoUgN]
00CoUgN]00Co0000oib1]?nLPKCo00001?nXOjL00ol0003o[XFYojj5Z@03ojj5Z@04o`000?nia4Co
^LA4o`0000;ofnSM00?o0000ojNQd?nWXM001OnWXM000ol0003oZJWFo`000006okNXbP03o`000?nY
_NSoZKgX00?o000000?oZKgXo`000?l000000_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h0>Oooool3o`0006kooooo0ol0000Iooooo`06o`000?oooooooooooeEEEOmV
IVKo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^04Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`02ooooo`;o000000?oooooo`000?l000000oooool00ol0003oooooooooo`02
ooooo`?o000000?oooooo`000?l000002oooool00ol0003oooooooooo`02ooooo`?o000000Cooooo
o`000?oooooooooo0ol000001?oooooo0000ooooool00003ooooo`03o`000?oooooooooo053ooooo
000Jooooo`Ko00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSoZKgX00?o00000_nY
_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj004ojVmj0Co00000onF
TLd00ol0003oWHk4oif>a004oif>a003o`000?nVSK_oYXfk00?oYXfk00?o0000oi1a[?n@LJ`01?n@
LJ`01?l0003oYY6nojJA__l00004ok2C^003o`000?o0X[_o`::k00Go`::k00?o0000oiMg[OnGMjd0
1OnGMjd2o`0000GoZ7nW00?o0000ojj5ZOn^QJT00on^QJT00ol0003o^LA4o`000003om_Xg@03o`00
0?nWXM3oYj7@00GoYj7@0_l00008okNXbP;o00001OnY_NP00ol0003oooooooooo`13ooooo`?o0000
KOooool3o`0000;oVL3c00?o0000ooooooooool05oooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo02_ooooo0_l00004ooooo`03o`000?oooooo000000;o00000_ooool00ol0003ooooo
ooooo`02ooooo`;o000000?oooooo`000?l000002oooool2o`0000?ooooo0_l000001_oooooo0000
o`000?oooooo0000ooooo`?o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`1Aoooo
o`005oooool6o`0000KoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000KoZKgX00Co0000ojVmj?nY
_NSoZKgX0_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol000000onY
_NSo0000oiJAc@05oiJAc@03o`000?nMS/CoWHk400?oWHk400?o0000ojJ=^onVSK/00onVSK/00ol0
003oT76/oi1a[005oi1a[0;o00001_n`TkP00ol0003o`::kol2R^`04ol2R^`03o`000?nGMjgoUgN]
00CoUgN]0_l00006ojQoY`03o`000?n^QJWo[XFY00;o[XFY00?o0000okW4A?l000000ooKj=d3o`00
00?oYj7@0ol000000onQP[7o0000okNXbP07okNXbP03o`000?nY_NSoZKgX00GoZKgX0_l00010oooo
o`?o00000oooool00ol0003oooooooooo`1Vooooo`Co00001?nI`?<3o`0001Wooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`0/ooooo`04o`000?ooooooooooooooo`?o000000?ooooo
o`000?l000000_ooool00ol0003oooooooooo`03ooooo`;o000000?oooooo`000?ooool02_ooool2
o`0000?ooooo0_l000001Ooooooo0000o`000?oooooo000000;ooooo1?l000000ooooooo0000o`00
0002o`0005;ooooo000Fooooo`Co00000onY_NP00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo
ZKgX00?o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSo000000GoZKgX00?o0000
ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000oiJAcOnFTLd00onFTLd00ol0003oWHk4oif>a003
oif>a003o`000?nVSK_oYXfk00CoYXfk00?o0000oi1a[?n@LJ`01?n@LJ`00ol0003o/9>hok2C^005
ok2C^003o`000?o0X[_o`::k00Co`::k00?o0000oiMg[OnGMjd00_nGMjd2o`000003olKgk?l0003o
Z7nW00GoZ7nW00?o0000ojj5ZOn^QJT00_n^QJT2o`000005om_XgOl0003o0000o`000?oKj=d00_l0
00000onWXM3o0000o`000005oj62/@03o`000?ngZ<[o]jS:00Co]jS:00?o0000on7SeOl000001OnY
_NP3o`0003oooooo0_l0001Zooooo`Co00000_nA_?@00ol0003oVL3coiW0l`03o`000004oiW0lol0
003oVL3co`0001Wooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0[ooooo`?o0000
1Oooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`02o`0000;ooooo0_l00002ooooo`?o00000_ooool4o`0000;o
oooo0_l0001Dooooo`005_ooool00ol0003oZKgXojVmj005ojVmj003o`000?nY_NSoZKgX00?oZKgX
0ol00006ojVmj003o`000?nY_NSoZKgX00CoZKgX0_l00007ojVmj003o`000?nY_NSoZKgX00?o0000
0_nY_NP00ol0003oZKgXojVmj003ojVmj003o`000?nFTLgoUY7=00?oUY7=00?o0000oif>a?nMS/@0
1?nMS/@00ol0003oYXfkojJ=^`03ojJ=^`03o`000?n@LJcoT76/00CoT76/00?o0000ok2C^?n`TkP0
1On`TkP00ol0003o`::kol2R^`04ol2R^`05o`000?nGMjgoUgN]oiMg[Ol000000oo6mn`00ol0003o
Z7nWojQoY`05ojQoY`04o`000?n^QJWo[XFYojj5Z@?o00001OoKj=d2o`0000OoXH:a00?o0000okNX
b_ngZ<X00ongZ<X01?l0003ohN?Eon7SeOl00002ojVmj0?o00000_nY_NP00ol0003oooooooooo`0m
ooooo`03o`000?oooooo000006Cooooo1Ol00006oi6lm0?o00001OnI`?<00ol0003oVL3co`00000H
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0;_ooool01?l0003ooooooooooooo
ool3o`000005ooooool0003o0000ooooool000004?ooool00ol0003oooooooooo`02o`0000;ooooo
0ol000000ooooooo0000o`000006o`0000;ooooo0_l0000?ooooo`;o0000A?ooool001Kooooo0_l0
0007ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZKgXojVmj005ojVmj003o`000?nY
_NSoZKgX00?o000000?oZKgXo`000?nY_NP01_nY_NP3o`0000KoZKgX00?o0000ojVmj?nY_NP00_nY
_NP00ol0003oUY7=oiJAc@04oiJAc@03o`000?nMS/CoWHk400?oWHk400?o0000ojJ=^onVSK/00onV
SK/00ol0003oT76/oi1a[003oi1a[003o`000?o>^LKo000000Oo/9>h00?o0000ol2R^oo0X[/01?o0
X[/3o`0000Coa_O/00?o0000ojQoYonXOjL01OnXOjL5o`000004olKl__l0003ofnSMom_Xg@?o0000
00?oTfnWo`000?nQP[401onQP[401Ol0003o]jS:okNXb_ngZ<[o000000?ohN?E0ol00006ojVmj003
o`000?oooooooooo03cooooo00Co0000oooooooooooo0000G?ooool7o`0000CoRk[e00Co0000oi6l
m?nA_?CoTKcd0ol00002oi6lm003o`000?nI`??oVL3c00CoVL3c0ol0000Hooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool0:Oooool2o`0000[ooooo00?o0000ooooooooool00_ooool2
o`0000kooooo00?o0000ooooool000000_l00002ooooo`03o`000?oooooo000000;ooooo2_l0000?
ooooo`03o`000?oooooooooo04Cooooo000Fooooo`03o`000?oooooo000000KoZKgX0_l00006ojVm
j003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00;oZKgX0_l00002ojVm
j003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?nY_NP00_nY_NP00ol0003oUY7=oiJAc@03oiJA
c@03o`000?nMS/CoWHk400?oWHk400?o0000ojJ=^onVSK/00onVSK/00ol0003oT76/oi1a[002oi1a
[004o`000?o>^LKoc[W6o`0000Oo/9>h00Co0000ol2R^oo0X[_o`::k1_l00005olKgk003o`000?nX
OjOoZ7nW00;oZ7nW0ol00002ojj5Z@03o`000?o6o;koa_bn00?o00001?nCKjL2o`0000OoXH:a00Co
0000okNXb_ngZ<[o00000ooQhmD00ol0003o`K39o`000007ojVmj0;o0000?Oooool01Ol0003ooooo
oooooooooooo000005?ooooo2?l00004ohNimP03o`000?n;^_GoRk[e00GoRk[e0ol00005oi6lm003
o`000?nI`??oVL3c00Co000000?oUlOho`000?l000006?ooool2o`0004oooooo00?o0000oooooooo
ool0:oooool2o`0000gooooo0_l0000>ooooo`03o`000?oooooo000000?o000000Coooooo`000?oo
oooo00000_ooool6o`000004ooooool0003o0000o`0000gooooo0_l00004ooooo`;o0000@Oooool0
01Gooooo00Go0000ooooooooooooooooo`000002ojVmj0?o00000_nY_NP00ol0003oZKgXojVmj004
ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP00ol0003oZKgXojVmj004ojVmj004o`000?nY_NSo
0000o`0000GoZKgX00?o0000ojVmj?nY_NP01?nY_NP3o`0000;oZKgX00?o0000oiJAcOnFTLd00onF
TLd00ol0003oWHk4oif>a004oif>a003o`000?nVSK_oYXfk00;oYXfk00Go0000oi1a[?n@LJcoT76/
o`000003oljiaP03o`000?n`TkSo/9>h00Ko/9>h0ol00005ofk1oP;o00001?o6mn`00ol0003oZ7nW
o`000002o`0000;oZ7nW00?o0000ojj5ZOn^QJT00ol000000onXSk[o0000oi=_Y`05oi=_Y`03o`00
0?nQP[7oXH:a00GoXH:a00?o0000okNXb_l000000ooQhmD01Ol0003o`K39ol6`bOo1/<Wo000000Ko
ZKgX0_l0000mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0BOooool7o`0000Co
Q[Wf00?o0000ohNim_n7^OH01_n7^OH01?l0003oRk[eoh^jmOn;^_D3o`000003oh^jmOl0003oTKcd
00?oTKcd1Ol00005oiO7n003o`000?nGaoSo000001Sooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`0]ooooo`;o00002?ooool01?l0003oooooooooooooool2o`0000Oooooo00?o0000
ooooooooool00oooool6o`000003ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?oo
ool3o`0000gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`11ooooo`005Oooool0
0ol0003oooooooooo`02ooooo`;o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00001_nY_NP0
0ol0003oZKgXojVmj003ojVmj0?o00001onY_NP00ol0003oZKgXojVmj003o`000003ojR_gOl0003o
HX?M00?o00001_nFTLd00ol0003oWHk4oif>a006o`0000?oYXfk00?o0000oi1a[?l000001Oo>^LH0
0ol0003o/9>hok2C^004ok2C^004o`000?nYkZCoZNjTo`0000;oK/7n0ol000000onSZ=Wo0000olKg
k002olKgk0?o00001OnXOjL01?l0003o[XFYo`000?l00003ojR?^P03o`000?nCKjOoTfnW00CoTfnW
0_l00007oj62/@05o`000?oQhmGohN?Eon7SeOl000001Oo1/<T00ol0003oZKgXojVmj003o`000003
ojVmj?l0003o000003_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`Ko
00001?n8^oL00ol0003oQ[WfohJimP05ohJimP03o`000?n7^OKoQkWf00KoQkWf0ol00002oh^jm@Oo
00001?n=a?X00ol0003oUlOhoiO7n004oiO7n003o`000?nGaoSo000001Sooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`0Xooooo`;o00000oooool3o`0000Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo1_l000000ooo
oooo0000o`000003ooooo`;o000000?oooooo`000?ooool00ol0000=ooooo`?o00000_ooool2o`00
00Gooooo0_l0000mooooo`005Oooool00ol0003oooooooooo`03ooooo`03o`000?nY_NSoZKgX00Go
ZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?l0
00000_l00003ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojR_g@04o`000?mRPmgoHX?Mof:3
g@Wo00001Om^aOl6o`0000Koc[W600?o0000ok2C^?n`TkP00on`TkP01?l0003oZNjTojW^Y?nYkZ@3
o`0000GoXjSI0ol000000oo6mnco0000ojQoY`06ojQoY`;o00001OnXSkX00ol0003oTfnWoi=_Y`03
oi=_Y`03o`000?nQP[7o000000KoXH:a0_l000000ooQhmGo0000ol6`b@06ol6`b@;o00001OnY_NP2
o`0003[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0kooooo`Ko00000on?__H0
0ol0003oR;_gohRkm`05ohRkm`03o`000?n6^OKoQ[Wf00GoQ[Wf00?o0000ohNim_n7^OH00_n7^OH8
o`0000?oQL?l00?o0000ohg4n_n=a?X01_n=a?X00ol0003oUlOhoiO7n004oiO7n0?o00006?ooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01oooooo0_l00003ooooo`;o00001?ooool0
0ol0003oooooooooo`02o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`00
0008ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00ol000000ooooooo0000
o`000003o`0000Cooooo1Ol0000>ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`;o0000
?oooool001Gooooo00?o0000ooooooooool01?ooool00ol0003oZKgXojVmj004ojVmj0;o00001_nY
_NP00ol0003oZKgXojVmj004ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003o`000003ojVghol0
003oZ:oM00GoZ:oM00Go0000of:3gOmRPmgoHX?Mo`000007ohQi_0;o00000om^aOl4o`000003o`>0
g_l0003oc[W600Ooc[W600Ko0000ok2C^?n`TkSo/9>ho`000?nYkZ@3o`000003oiO?nol0003oXjSI
00;oXjSI1Ol00002olKgk003o`000?nXOjOoZ7nW00GoZ7nW0_l00005ojR?^P03o`000?nCKjOoTfnW
00CoTfnW0_l00005oj62/@04o`000?oB/;Ood[2go`0000So`K3900?o0000ojVmj?nY_NP01OnY_NP2
o`0003Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0gooooo`?o00000onG`_D0
0ol0003oSkkfohnnmP04ohnnmP03o`000?n8^oOoR;_g00GoR;_g00?o0000ohJim_n6^OH00_n6^OH7
o`0000CoO/;m00?o0000ohG3o?n5`o`01On5`o`00ol0003oSLCjohg4nP06ohg4nP03o`000?nGaoSo
UlOh00Co00000_nBcO`00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool08Oooool2o`0000?ooooo0_l00003ooooo`;o00000_ooool01?l0003oooooo`000?l0
0002ooooo`04o`000?ooooooooooooooo`;o00001_ooool01ol0003ooooooooooooooooo0000oooo
ool000000_ooool3o`000003ooooool0003o000000;o00001?ooool3o`000003ooooool0003o0000
00cooooo0_l00004ooooo`?o00000_ooool2o`00047ooooo000Eooooo`03o`000?oooooooooo00Go
oooo00?o0000ojVmj?nY_NP00ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY
_NP00ol00003ojVmj003o`000?nY_NSoZKgX00?oZKgX0ol00005ojVgh`03o`000?nX[mgoZ:oM00Co
Z:oM00Co0000of:3gOmRPmgo00002On8NK`3o`0000?oS8O90ol00008oljiaP03o`000?n`TkSo/9>h
00?o00001OnGco/3o`0000?oXjSI0_l00003olKgk003o`000?nXOjOoZ7nW00CoZ7nW00?o0000ojR?
^_nXSkX01?nXSkX00ol0003oTfnWoi=_Y`04oi=_Y`03o`000?nQP[7o000000?oXH:a00Go0000om:`
]ooB/;Ood[2go`000007ol6`b@03o`000?oQoL_o000000KoZKgX0_l0000iooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0<_ooool4o`0000OoUl;e00?o0000ohnnm_n?__H01?n?__H0
0ol0003oR;_gohRkm`02ohRkm`Oo00000_mka?h3o`0000OoO/;m00?o0000ohG3o?n5`o`01On5`o`0
0ol0003oSLCjohg4nP02ohg4nPKo00001?nBcO`01?l0003oT/gloi;=o?l0000Gooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool07oooool2o`0000;ooooo0ol000000ooooooo0000o`00
0002o`0000;ooooo0_l000001Ooooooo0000o`000?oooooo000000;ooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00;o000000?oooooo`000?l000000ol000000ooooooo
0000o`000002o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool00oooool2o`0000?ooooo0ol00003ooooo`;o0000??ooool001Gooooo00?o0000ooooooooool0
1_ooool2o`0000KoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000OoZKgX00?o0000ojVmj?l00000
0_l000000onY_NSo0000ojVgh`06ojVgh`03o`000?nX[mgoZ:oM00?oZ:oM00Go0000of:3gOmRPmgo
HX?Mo`000008ohQi_003o`000?n<QlWoS8O900?oS8O900Co0000oem?Yol0003o00001oo>^LH00ol0
003o/9>ho`000003om7mgP03o`000?nGco_o000000;o000000?oUloko`000?nSZ=T01?nSZ=T2o`00
00;oa_O/00?o0000ojQoYonXOjL01?nXOjL2o`0000GoZ8nj00?o0000oi=_YonCKjL01?nCKjL01?l0
003oXH:aoj62/Ol00002oj62/@06o`000?oB/;Ood[2go`000?o[`Z_o00001Oo1/<T01Ol0003ohOg;
on7mbooQoL_o000000;oZKgX0ol000000onY_NSo0000o`000007ooooo`Co000000Go410@oooooooo
ooooooooodA4A002o`000003oc8b<_oMgMgooooo02?ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0^ooooo`?o00000onQa_<00ol0003oUl;eoiO2m@06oiO2m@04o`000?n?__KoSkkf
ohnnmPOo00001Omlaol4o`0000?oNlCn00?o0000ogk2oOmn`_d01Omn`_d00ol0003oQL?lohG3o002
ohG3o0Oo00001On5b_h00ol0003oT/gloi;=o003oi;=o0Go00005_ooool00ol0003oooooooooo`05
ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo03Kooooo00?o
0000ooooooooool08Oooool6o`0000;ooooo2_l000001?oooooo0000o`000?ooool2o`000003oooo
ool0003o000000Kooooo0_l000000ooooooo0000o`000006o`000004ooooool0003o0000o`0000?o
oooo0_l000000ooooooo0000o`000007ooooo`;o000000?oooooo`000?ooool00_l0000:ooooo`;o
00000oooool2o`0003kooooo000Dooooo`03o`000?oooooooooo00Sooooo00?o0000ojVmj?nY_NP0
1OnY_NP00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000GoZKgX
00?o0000ojVghonY]n<01?nY]n<01?l0003oZ:oMojR_gOnX[md4o`0000;oHX?M00?o0000ohQi_?n8
NK`01On8NK`00ol0003odK>lo`000004ohb7b@03o`000?mOCjOoGdnW00;o00001Oo>^LH3o`0000Co
dOgN1?l00002oiO?n`03o`000?nSZ=WoXjSI00?oXjSI00Go0000o`0>VOl0003oa_O/o`000005ojQo
Y`03o`000?oLo];o000000GoZ8nj00?o0000oi=_YonCKjL01OnCKjL00ol0003oXH:aoj62/@02o`00
00?od[2g00?o0000on_2Zol000001?o1/<T00ol0003ohOg;on7mb`02on7mb`?o00001OnY_NP00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool08oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02[ooooo0ol00007oj76l`03o`000?nG`_GoUl;e
00CoUl;e1Ol00005oh7=o`03o`000?mlaoooO<Oo00;oO<Oo1?l00006og_4oP03o`000?mn`_goO/;m
00;oO/;m1ol00005ogO7o`03o`000?n5b_koQL[n00GoQL[n00?o0000oi;=o?nBcO`01?l00003oh_@
oP03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo01gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2
o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool08oooool5o`000003ooooool0003o
000000Ko00000_ooool3o`000003ooooool0003o000000;ooooo00?o0000ooooool000001?ooool2
o`000003ooooool0003o000000?o000000Coooooo`000?oooooooooo0ol00002ooooo`;o000000?o
ooooo`000?l000001_ooool2o`0000?ooooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0
003o0000043ooooo000Dooooo`03o`000?oooooooooo00Wooooo00?o0000ojVmj?nY_NP01?nY_NP2
o`0000OoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj003o`000?nY]n?o
ZKOS00?oZKOS1?l00003oi=f[`04o`000?mRPmgoHX?Mo`0000KoR7Vl00Co0000om6c_?oA/kco0000
1On<QlT01?l0003oGdnWoem?Yol00002oljiaP?o000000CoS>Sgo`000?oAoMkodOgN0ol00002ojjY
d`03o`000?m9T>ko000000?o00001?nSZ=T01Ol0003o00jIo`000?o6mnco000000CoZ7nW00Co0000
omcnd_oLo];o00001_nXSkX00ol0003oTfnWoi=_Y`04oi=_Y`04o`000?nQP[7oXH:ao`0000Cod[2g
00Co0000on_2Zoo[`Z_o00000_o1/<T01?l0003ohOg;on7mbooQoL/2o`000003okgIk_l0003oZKgX
00GoZKgX0_l00008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo0_l00002oj_9l003o`000?nQa_?oXLKc
00KoXLKc00?o0000oiO2mOnG`_D00ol00004oh_Co`03o`000?n1cOooPLgo00CoPLgo1?l000000oml
aooo0000o`00000<o`0000GoJ/Kn00?o0000ogO7oomgaol01Omgaol00ol0003oQL[nohG:oP02ohG:
oPGo00000on;d?h00ol0003oRm3noh_@oP02oh_@oP03o`000?oooooooooo01;ooooo0_l00008oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool3
o`0000Cooooo1ol00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Gooooo0_l00000
0ooooooo0000ooooo`02o`000004ooooool0003oooooooooo`?o000000Koooooo`000?l0003o0000
ooooool00002ooooo`;o000000?oooooo`000?l000001?ooool3o`0000Cooooo0_l00004ooooo`;o
00000_ooool3o`00043ooooo000Dooooo`03o`000?oooooooooo00[ooooo00?o0000ojVmj?nY_NP0
0ol00002ojVmj003o`000?nY_NSoZKgX00CoZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00CoZKgX
00?o0000ojVghol000000_l000000onJS<?o0000oi=f[`04oi=f[`;o00000_mRPmd00ol0003oR7Vl
ohQi_002ohQi_005o`000?oA/kcodK>lom6c_?l000001On<QlT01?l0003oGdnWoem?YomOCjL3o`00
00;oS>Sg1Ol00005ojjYd`04o`000?m9T>koBI3^odV@kP?o00000onSZ=T01?l0003o00jIo`000?l0
0003ojQoY`;o00000ooLo]800ol0003oZ8njojR?^P03ojR?^P03o`000?nCKjOoTfnW00CoTfnW00?o
0000oj62/OnQP[400_l00002om:`]`07o`000?o[`Z_ojl:[on_2Zol0003o`K39o`000002on7mb`;o
00001?nmfNh00ol0003oZKgXojVmj003ojVmj0?o00001oooool00ol0003oooooooooo`06ooooo`03
ogMgMolb<S;ooooo02;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Tooooo`;o
00001On[bO000ol0003oXLKcoj76l`04oj76l`Co00002?n;dol01?l0003oPLgooh7=oon1cOl7o`00
00GoGLWi0_l00005of76o0;o00001_mZa_h00ol0003oMlOoogO7o`02ogO7o`Oo00001?mhbol00ol0
003oRm3noh_@oP02oh_@oP03o`000?n;d?koRm3n00?o00005Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool07Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol00004ooooo`;o0000:?ooool00ol0003oooooooooo`08ooooo`;o00000oooool0
1_l0003ooooooooooooooooo0000ooooo`;o00001?ooool3o`0000?ooooo00?o0000ooooooooool0
0_ooool2o`0000;ooooo1?l000000ooooooo0000o`000002ooooo`?o00000oooool2o`0000?ooooo
0ol00004ooooo`;o00000oooool2o`0004;ooooo000Dooooo`03o`000?oooooooooo00_ooooo0_l0
0006ojVmj004o`000?nY_NSoZKgXojVmj0;o00000_nY_NP00ol0003oZKgXojVmj004ojVmj004o`00
0?nY_NSoZKgXojVmj0Co00001?nJS<<00ol0003oTgJ_oi=f[`04oi=f[`;o000000?oHX?Mo`000?n8
NK`00_n8NK`00ol0003odK>lom6c_003om6c_003o`000?n<QlWoS8O900;oS8O900?o0000oem?YomO
CjL01?mOCjL5o`0000So[ZWC00Ko0000odV@k_m9T>koBI3^o`000?lVI=L2o`000007oj>XfOl0003o
00jIo`000?o6mnco0000ojQoY`02o`000005oeaWaOl0003og?kBomcnd_l000001OnXSkX00ol0003o
TfnWoi=_Y`05oi=_Y`;o00000_oB/;L00ol0003od[2go`000004on_2Z`Co00001_nmfNh00ol0003o
ZKgXojVmj003o`0000;oZKgX00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`08oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
027ooooo0_l00008oj_9l003o`000?nQa_?oXLKc00?o00001?nIfOd2o`0000CoRm?o1_l00005oek=
mP;o00001?mMbOTEo`0000CoH<Gl00?o0000ogS;oomhbol01Omhbol00ol0003oRm3noh_@oP04o`00
00?oPm3o00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Nooooo`05o`000?ooooooooooooooool000002ooo
ool01?m4A4CogMgMooooool00005ooooo`03o`000?oooooooooo03Cooooo0_l00002ooooo`;o0000
0_ooool00ol0003oooooo`000002o`0000;ooooo0ol00008ooooo`05o`000?oooooo0000o`000?oo
ool00_l00002ooooo`03o`000?oooooooooo00;o00002Oooool3o`0000Cooooo0ol00017ooooo`00
5?ooool00ol0003oooooooooo`0=ooooo`03o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?l00000
1OnY_NP00ol0003oZKgXojVmj003ojVmj0Co00000onQ^n/00ol0003oVXc3oiZ<``03oiZ<``03o`00
0?nCMZooTgJ_00?oTgJ_00Co0000oc`oZol0003o00000_n8NK`00ol0003odK>lom6c_004om6c_003
o`000?n<QlWoS8O900;oS8O900Co0000oem?YomOCjOoGdnW0ol000001OmOCjOo0000on33^ooP`k_o
000000So[ZWC0ol00002odV@kP03o`000?lVI=Oo9VCG00;o000000?o00jIo`000?l000000_l00002
oknac003o`000?mLIlGo000000;o00001OnXSkX00ol0003oTfnWoi=_Y`05oi=_Y`03o`000?oB/;Oo
d[2g00;od[2g0_l00004on_2Z`04o`000?o@gfkod=m^o`0000Ko_MW^0ol00006ojVmj0;o00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Mooooo`?o00000_nbbn`00ol0003oZlW`oj_9l005oj_9l0?o00001onI
fOdYo`000003odFmlOl0003oH<Gl00GoH<Gl00?o0000ogS;oomhbol00_mhbol5o`0000?oPm3o00?o
0000oh?@oon3d?l00_n3d?l00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool00000
2oooool01?oMgMgoEEEEooooool00005ooooo`03o`000?oooooooooo03Cooooo0ol000000ooooooo
0000o`000004o`000003ooooool0003o000000?ooooo0ol00006ooooo`03o`000?oooooooooo00Co
00000_ooool3o`0000Sooooo0_l000000ooooooo0000o`000005ooooo`;o0000BOooool001Cooooo
00?o0000ooooooooool03_ooool01?l0003oZKgXojVmj?nY_NP4o`0000OoZKgX00?o0000ojVmj?l0
00000_l00002ojVmj003o`000?nQ^n_oXK_[00?oXK_[00?o0000oiZ<`onJS<<00_nJS<<00ol0003o
TgJ_oi=f[`03oi=f[`03o`000?ll?j_o?3n[00?o00001ooA/k`00ol0003oS8O9ohb7b@02ohb7b@Co
00000omOCjL01_l0003oh<>kon33^ol0003oiKb/o`0000Ko[ZWC00Co0000okBI^ol0003oLf6_0_l0
00001?m9T>ko0000obITeolVI=L2o`000003okgmhOl0003o000000?o_k7<00Co0000oeaWaOmLIlGo
G6O50_l00005ojR?^P03o`000?nCKjOoTfnW00CoTfnW00?o0000om:`]ooB/;L00_oB/;L00ol0003o
jl:[on_2Z`02on_2Z`06o`000?o@gfkod=m^o`000?nihG_o00000_nmfNh3o`0000;oZKgX00?o0000
ojVmj?nY_NP01?nY_NP2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool2o`0000Ko//_/00?o0000
oj_9l?n[bO000_n[bO02o`0000?oY]gj0_l00002oiWIo@?o00000omlhOHAo`0000?oA/?Y7ol00005
ofO8o@05o`000?n3d?ooPm3oo`000?n3d?l01Ol0000Booooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Pooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00omgMgOoc<c<o`000005ooooo`03o`000?oooooooooo03Kooooo0_l00003ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooool000000ol00006ooooo`06o`000?oooooo0000o`00
0?oooooo00000_ooool2o`0000Kooooo1?l00002ooooo`;o0000DOooool001?ooooo00?o0000oooo
ooooool04?ooool3o`0000CoZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00?o0000oj6k
jonQ^n/00_nQ^n/00ol0003oVXc3oiZ<``02oiZ<``03o`000?nCMZooTgJ_00?oTgJ_00Go0000oc`o
Zoll?j_o?3n[o`000009om6c_003o`000?n<QlWo000000?o00001?mOCjL01Ol0003oh<>kon33^ooP
`k_o000000;oiKb/00?o0000ojjYdon^ZM<00_n^ZM<01?l0003o]9VkokBI^ol00003og=Q[`;o0000
00Go9VCGo`000?nmoN7o_OgQo`000005oknac003o`000?mLIlGoG6O500;oG6O50_l00004ojR?^P03
o`000?nCKjOoTfnW00?oTfnW0ol00003om:`]`;o00000oo[`Z/00ol0003od=m^o`000002okWQN`?o
00001_nY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003ooooo00;ooooo00?oEEEEofIVI_l0
00001Oooool4o`0002Cooooo00?o0000ooooooooool04?ooool2o`0001Sooooo0_l00009ok;;k004
o`000?n[bO3o0000o`0000KoY]gj1?l00002ogcQmPko00000omAbnX6o`0000?oBlG/1ol000001?m3
_?3o0000obZQk_lZXNh6o`000003o`n?hol0003o000000Go000000?o@;Wao`000?mWb?d00omWb?d7
o`0000CoO<ko00?o0000ooooooooool04_ooool01ol0003oooooooooooooooooEEEEofIVI_l00000
1Oooool4o`0001oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Go
oooo00?o0000ooooooooool06?ooool7o`0000gooooo0ol00006ooooo`Go00000oooool4o`000003
ooooool0003ooooo00Co00001?ooool4o`0000cooooo1ol0001Cooooo`004oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?nY_NSoZKgX00CoZKgX00?o0000ojVmj?nY_NP00ol00002ojVmj003o`00
0?nY_NSoZKgX00CoZKgX00Go0000oj6kjonQ^n_oXK_[o`000004oiZ<``03o`000?nCMZooTgJ_00Co
TgJ_00Co0000oc`oZoll?j_o00002?oA/k`3o`0000?oS8O900?o0000oem?YomOCjL00_mOCjL01?l0
003oh<>kon33^ol00003onFl[005o`000?n^ZM?o[ZWCojjYdol000001?ndVK/00ol0003oLf6_og=Q
[`02og=Q[`Co00001ono/L`00ol0003oG6O5oeaWa@03oeaWa@05o`000?nXSk[oZ8njojR?^_l00000
1?nCKjL4o`0000?od[2g00?o0000on_2Zol000000_o[`Z/01Ol0003od=m^o`000?nihG_o000000;o
bN_]00?o0000ojVmj?nY_NP01?nY_NP3o`0000GoZKgX00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01?ooooo0_l00002okS<j@03o`000?nbbnco//_/00Ko
//_/0ol00005ojKMnP;o00001?nCj_L4o`0000;oNnKL1Ol00002of7GhQ?o000000?o;[CMo`000?lf
[?401ol000000olZXNko0000oa2<i006o`0000;o9:KV1_l00004oeS0n`04o`000?mlc_ooO<koo`00
00CoO<ko00?o0000ooooooooool04_ooool00ol0003oooooooooo`0[ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`04ooooo`03o`000?oooooooooo01_ooooo2?l0000<
ooooo`Go00001?ooool3o`0000?ooooo0_l000000ooooooo0000ooooo`02ooooo`?o00001?ooool4
o`0000_ooooo1Ol0000;ooooo`;o0000BOooool001?ooooo00?o0000ooooooooool04_ooool00ol0
003oZKgXojVmj003ojVmj0?o00001_nY_NP00ol0003oZKgXojVmj003ojVmj0?o00000_nQ^n/00ol0
003oVXc3oiZ<``02oiZ<``03o`000?nCMZooTgJ_00?oTgJ_00Go0000oc`oZoll?j_o?3n[o`000004
om6c_0?o000000?og^?Ho`000?l000000on<QlT01Ol0003oGdnWoem?YomOCjOo000000?oh<>k00?o
0000onFl[?oU_:`00_oU_:`00ol0003o[ZWCo`000005okBI^`03o`000?mcHJooLf6_00GoLf6_00?o
0000oknac?no/L`01Ono/L`00ol0003oG6O5oeaWa@03oeaWa@?o000000?oZ8njo`000?nCKjL00_nC
KjL6o`000003om:`]ol0003ojl:[00;ojl:[0_l000001?o@gfko0000o`000?l00004olW[k@03o`00
0?nY_NSoZKgX00?o000000?oZKgXo`000?nY_NP01OnY_NP2o`00037ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0@ooooo`;o00001Onhc>T00ol0003o//_/ok;;k002ok;;k0?o0000
0onag_H2o`000003ojKMn_l0003o000000?oTn[g1Ol00002og_Vg0Wo00000_mQdo43o`0000?oPmSo
1?l00005od[5k003o`000?lLW^Go000000So000000?o:9g^o`000?l000001?l000000ol@S>Co0000
o`000005o`000003obBVi_l0003oF<3k00GoF<3k00Go0000ogc>oomlc_oo0000ogc>o`05o`0001;o
oooo0_l00015ooooo`03o`000?oooooooooo01cooooo2?l0000<ooooo`co00000_ooool5o`0000Co
oooo0_l00003ooooo`Go00000_ooool00ol0003oooooooooo`06ooooo`Oo000000?oooooo`000?l0
00000_ooool3o`0004_ooooo000Cooooo`03o`000?oooooooooo01?ooooo00?o0000ojVmj?l00000
0_l00002ojVmj003o`000?nY_NSoZKgX00GoZKgX00?o0000ojVmj?l000000_l00003ojVmj0?o0000
1?nJS<<00ol0003oTgJ_oi=f[`03oi=f[`03o`000?ll?j_o?3n[00;o?3n[1?l000000ooA/kco0000
omkSf002omkSf0;o00000_n<QlT01Ol0003oGdnWoem?YomOCjOo000000?oh<>k00?o0000onFl[?oU
_:`00ooU_:`00ol0003o]9VkokBI^`04okBI^`03o`000?mcHJooLf6_00CoLf6_00?o0000olFIZOl0
00001_no/L`01?l0003oG6O5oeaWaOmLIlD2o`000003oj6>`?l0003oVgfa00;o00000_nCKjL2o`00
00;o@V;<0ol000000ooB/;Oo0000on_2Z`02on_2Z`Co00001_o9jnd3o`0000GoZKgX00?o0000ojVm
j?nY_NP00onY_NP2o`00033ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=oooo
o`;o00002?nhc>T01?l0003o//_/o`000?l00007ok7NmPoo00000_n[n>P2o`0000?o^?;c1?l00002
oh?Ho`?o00000onVgo/;o`000004oabNiOl0003o<jCboc>TlPKo000000?o:9g^o`000?l9SMh05Ol0
0005ogK;o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0eooooo`Oo000000?oooooo`000?l000000ol000000ooooooo0000ooooo`03ooooo`04o`000?oo
ooooooooooooo`Oo00002?ooool9o`000004ooooool0003o0000o`0004kooooo000Cooooo`03o`00
0?oooooooooo01Cooooo00?o0000ojVmj?nY_NP01?nY_NP00ol0003oZKgXojVmj004ojVmj0;o0000
1onY_NP2o`0000CoVXc300?o0000oi=f[onCMZl00onCMZl00ol0003o?3n[oc`oZ`03o`0000?odK>l
00?o0000omkSf?oNhmP00_oNhmP01Ol0003o2bVZo`000?n<QlWo000000;oGdnW00Go0000on33^ooP
`k_oh<>ko`000006onFl[003o`000?ndVK_o]9Vk00Co]9Vk00?o0000og=Q[omcHJl00omcHJl01Ol0
003oaIVYolFIZOo5VJWo000000Ko_k7<0ol00003oj6>`003o`000?nKOK7oVgfa00?o000000?oVgfa
o`000?m2H/`00_m2H/`2o`000003om:`]ol0003ojl:[00;ojl:[1Ol00002olW[k@?o000000?oZKgX
o`000?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`000003ojVmj?l0003o000002oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0:ooooo`;o00000_nkc>L00ol0003o^<cYokS<j@05
okS<j@?o00001_nag_H2o`000003ojW_n?l0003o000000Go00000_nLm><3o`0000;oZoSX0_l00003
okSbl`;o00001?o2hnl3o`0000?oY]ok0_l00002okRjf`03o`000?n4XNKoQ:7V00?oQ:7V00?o0000
oeNDk_mGU>h01_l000001?lcY?;o0000od2Zm_m0Z_H@o`0000KoC;Si0_l00003ogK;o`Co00004_oo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo02Oooooo3_l00004ooooo`[o00001ooo
ool00ol0003oooooo`000006o`000003ooooool0003o000000Kooooo1ol000000ooooooo0000o`00
0003o`0004gooooo000Cooooo`03o`000?oooooooooo01Gooooo00?o0000ojVmj?nY_NP01?nY_NP0
0ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP4o`0000;oVXc300?o0000
oi=f[onCMZl01?nCMZl2o`0000?o?3n[00?o0000om6c_?l000001OoNhmP01Ol0003o2bVZo`/YZ_l0
003oS8O900;o00001?oP`k/00ol0003oiKb/onFl[003onFl[003o`000?oikJ3o000000Ko]9Vk00?o
0000og=Q[omcHJl00_mcHJl01Ol0003oaIVYolFIZOo5VJWo000000?o_k7<1?l00006oj6>`004o`00
0?nKOK7oVgfao`0000?oVgfa00?o0000od9Rc?m2H/`00_m2H/`00ol0003ojl:[on_2Z`02on_2Z`Oo
00001OnY_NP00ol0003oZKgXojVmj003ojVmj0?o00001OnY_NP00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool02?ooool00ol0003o^lcWok_<i`03ok_<i`03
o`000?nhc>Wo^<cY00;o^<cY0_l00003okWMlP?o000000?o/Mkfo`000?l000000ol000001?nYkoSo
0000o`000?nGl^L2o`000003oicdhol0003o000000Oo000000?o^?;co`000?l000001Oo2hnl01ol0
003oa=7TolCAi?o4dNCo0000ojKOnol000001Onh^]/00ol0003oQ:7VohBQiP03ohBQiP03o`000?mG
U>koEiC^00;oEiC^00?o0000oeNQmOmGXOD01ol000000om0Z_Ko0000od2TmP03od2TmP03o`000?lX
S^go000000oo00001?mbaOl00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool0:oooool;o`0000;ooooo0ol00002ooooo`Co00001Oooool9o`000003ooooool0
003ooooo00;o00001oooool2o`000003ooooool0003o000000Co00004?ooool3o`0003oooooo000B
ooooo`03o`000?oooooooooo01Oooooo00?o0000ojVmj?nY_NP00onY_NP3o`0000KoZKgX00?o0000
ojVmj?nY_NP00ol000001?nX_NSo0000o`000?m6Fl@3o`0000?oTgJ_3?l00005omkSf003o`000?l;
:J[o2bVZ00?o00000ooP`k/00ol0003oiKb/onFl[004onFl[003o`000?oikJ3o000000Ko]9Vk00Go
0000og=Q[omcHJooLf6_o`000005olFIZ@?o00000onRV/d00ol0003oXHk0oj6>`004oj6>`003o`00
0?nKOK7oVgfa00CoVgfa00?o0000od9Rc?m2H/`00_m2H/`00ol0003ojl:[on_2Z`02on_2Z`Co0000
00?oe_7To`000?nY_NP01OnY_NP00ol0003oZKgXojVmj003o`0000;oZKgX00?o0000ojVmj?nY_NP0
1?nY_NP00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
1Oooool2o`0000Oo^lcW00Co0000okS<jOl0003o00001onigO84o`0000;oZNoh0_l00002oiObi`Go
00000oo0mnh00ol0003od>_Xom3[j002om3[j0;o00001?o2hnl2o`0000Coa=7T0_l00007okRjf`04
o`000?n4XNKoQ:7VohBQiPKo000000?oEiC^o`000?mGXOD00omGXOD01?l0003oD:;foe2Rm_m@X_H6
o`000003od2Tm_l0003o:8k]00;o:8k]3?l00006og;5o`03o`000?oooooooooo00kooooo0_l00013
ooooo`03o`000?oooooooooo01oooooo0_l00003ooooo`So00000oooool2o`0000Cooooo3Ol00004
ooooo`Ko000000Goooooo`000?oooooo0000ooooo`03o`0000Kooooo1?l000000ooooooo0000o`00
0002o`0000Wooooo0_l00002ooooo`Co000000?oooooo`000?l000000ol0000looooo`004_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?nY_NSo000000;o00000onY_NP00ol0003oZKgXojVmj003
ojVmj0?o00001OnX_NP2o`0000;oAU_41_l000000onUXM;o0000ohnGe`07ohnGe`?o00000_oNhmP0
1Ol0003o2bVZo`/YZ_l;:J[o000000Coh<>k00?o0000onFl[?oU_:`00ooU_:`01?l0003onNfPooW]
X?l00006okBI^`05o`000?mcHJooLf6_og=Q[ol000001Oo5VJT00ol0003oXY[=oj:Jc@04oj:Jc@03
o`000?nQS/3oXHk000?oXHk000?o0000oi]m/OnKOK401OnKOK42o`0000?o@V;<00?o0000on_2Zoo[
`Z/01Ol00002omKai003o`000?nY_NSoZKgX00?oZKgX0ol00006ojVmj004o`000?nY_NSoZKgXojVm
j0Co0000;Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo0ol00008ok_<
i`?o00001OnigO84o`0000?o^>ge2_l00003ol3gkP03o`000?o@jnSod>_X00;od>_X00?o0000omCP
h?oDh>000_l000000oo2hnoo0000olCAi004olCAi003o`000?o:`mCo000000Oo^;[K1?l00002oiFF
dP04o`000?mjU>3oNYCPogZDh0Ko000000?oEj7eo`000?m@X_H01?m@X_H00ol0003oA9_dodBKm005
o`0000;o:8k]1Ol00003ocFTl`[o00004Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo01[ooooo2?l00007ooooo`Co00001_ooool7o`0000Cooooo0_l00007ooooo`Go000000?ooooo
o`000?l000001?l00006ooooo`Oo00002oooool:o`00047ooooo000Booooo`03o`000?oooooooooo
01Wooooo0_l00006ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0003oZ;gXojRmj003ojRm
j0Oo00001OnUXM800ol0003oSiOGohnGe`04ohnGe`03o`000?nGjZgoUnZ]00Co00000ol;:JX01Ol0
003oh<>kon33^ooP`k_o000000KoiKb/00Go0000ooW]X?oikJ3onNfPo`000005okBI^`04o`000?mc
HJooLf6_o`0000GoaIVY00?o0000oogSU_l000001OnRV/d00ol0003oXHk0oj6>`003oj6>`003o`00
0?nKOK7oVgfa00GoVgfa00?o0000ofMle?l000000_l000001_m2H/co0000on_2Zol0003oel33o`00
00;oe_7T00?o0000omKai?l000000_nY_NP3o`0000;oZKgX00?o0000ojVmj?nY_NP01?nY_NP4o`00
00?oZKgX00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Jooooo`04o`000?oooooooooo
o`0000?o_LcV00?o0000ok_<ionkc>L01?nkc>L01?l0003o_M_^okgKk_nmfnh2o`000004okWMl_l0
003o0000o`0000Co^>ge0_l00002ok3hk@;o000000CoZoWQo`000?nXn>?o00001?o0mnh00ol0003o
d>_Xom3[j002om3[j003o`000?oDh>3oe>3P00;oe>3P0ol00003olCAi0;o00000oo:`m@00ol0003o
^;[KokRjf`02okRjf`;o000000?o[Z7:o`000?nEU]801?nEU]800ol0003oNYCPogZDh002ogZDh004
o`000?mgVNKoMiWVogNIiPOo000000?oD:;fo`000?m4Vo@00om4Vo@00ol0003oAI?ao`000003o`00
00;o483U0_l00004ocFTl`;o00001_ma__d00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool07oooool4o`00013ooooo1Ol0000?ooooo`Go000000?oooooo`00
0?l000001_l00005ooooo`?o00003Oooool4o`0000Oooooo0_l0000oooooo`004_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?nY_NSoZKgX00?oZKgX0_l00006ojVmj004o`000?nX_NSoZ;gXojRm
j0?o00000om6Fl@00ol0003oYJ7BojFQdP05ojFQdP03o`000?n?UmOoSiOG00;oSiOG00?o0000oiOZ
[OnGjZd00_nGjZd01?l0003o07?Io`000?l00003o`/YZP04o`000?oP`k_oh<>ko`0000GoiKb/00?o
0000ooW]X?oikJ000_oikJ000ol0003o]9VkokBI^`03okBI^`03o`000?mcHJoo000000KoaIVY00?o
0000oogSU_l000001OnRV/d00ol0003oXHk0oj6>`004oj6>`003o`000?nKOK7oVgfa00?oVgfa0ol0
0003ofMle0;o000000?ojl:[o`000?l000001?oFlN@4o`0000KoZKgX00?o0000ojVmj?nY_NP00ol0
00000onY_NSo0000ojVmj005ojVmj0;o0000:oooool00ol0003oooooooooo`0Kooooo`;o00001Onm
c>H01?l0003o^lcWok_<ionkc>L2o`0000Go_M_^0ol00005okS]m@06o`000?n`n>go/?S]ok3hkOl0
003oZoWQ1_l00002ol3gkP03o`000?o@jnSod>_X00;od>_X00?o0000omCPh?oDh>000_oDh>001ol0
003oe=SLomCHg?oDf=co0000olCAi?l000001_o:`m@01?l0003o^;[Ko`000?l00004ojjQbP03o`00
0?nEU];oUIKB00?oUIKB00?o0000ogZDh?mjU>000_mjU>000ol0003oMiWVogNIiP02ogNIiP03o`00
0?m_UnOoKiOW00;oKiOW1_l000000om4VoCo0000odFCl@02odFCl@?o00000_l@P>D7o`0000KoLKkm
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo02cooooo
2_l00009ooooo`Co00001?ooool4o`000003ooooool0003o000000Ko00001?ooool:o`0000_ooooo
00?o0000ooooooooool00oooool;o`0003Sooooo000Booooo`03o`000?oooooooooo01cooooo00?o
0000ojVmj?l000000_l000000onY_NSo0000ojVmj006ojVmj0Oo00000om6Fl@00ol0003oYJ7BojFQ
dP04ojFQdP04o`000?n?UmOoSiOGohnGe`go000000Co2bVZo`000?oP`k_o00001OoU_:`00ol0003o
nNfPooW]X002ooW]X003o`000?ndVK_o]9Vk00Co]9Vk0_l00006olFIZ@04o`000?omhiKooN>Fo`00
00GoXY[=00?o0000oj6>`?nQS/000onQS/000ol0003oVgfaoi]m/@02oi]m/@Co00001?mWO=@2o`00
0004omO0`ol0003oe_7TomKai0?o00000_nec^d00ol0003oZKgXojVmj004ojVmj0?o00001OnY_NP0
0ol0003oZKgXojVmj003ojVmj0;o0000:_ooool00ol0003oooooooooo`0Kooooo`03o`000?nmc>Ko
_LcV00Ko_LcV00?o0000ok_<iol000001?nmfnh3o`0000?o_nWb0_l000000onhkOGo0000o`000002
ok3hk@Ko00001?oAm^L4o`0000;od>_X00?o0000omCPh?oDh>000_oDh>000ol0003oe=SLomCHg002
omCHg0;o00001oo:`m@2o`0000Ko[Z7:00?o0000oiFFd_nEU]800onEU]800ol0003oNYCPogZDh003
ogZDh003o`000?mgVNKoMiWV00;oMiWV00?o0000ofnGiom_UnL00om_UnL01?l0003oH8[Tof2:i?mP
R^@5o`0000;oAI?a1Ol00003od2Hl`[o00004?ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo02;ooooo0ol00003ooooo`Oo00003oooool3o`000003ooooool0003o000000;o000000?o
ooooo`000?l000001?l0000=ooooo`Co00005oooool4o`0003gooooo000Booooo`03o`000?oooooo
oooo01gooooo00?o0000ojVmj?nY_NP00onY_NP01?l0003oZKgXojVmj?nY_NP5o`0000CoYkgY00?o
0000odIKa?m6Fl@00_m6Fl@00ol0003oYJ7BojFQdP04ojFQdP03o`000?n?UmOo000000Co[Io90_l0
00001?lnAk?o0000o`0MYol00003of62g0?o00001_oU_:`00ol0003onNfPooW]X002ooW]X0So0000
1_o5VJT01Ol0003ooN>FoogSU_omhiKo000000GoXY[=00?o0000oj6>`?nQS/000onQS/001?l0003o
Vgfaoi]m/OnKOK46o`0000?oIgcD00?o0000omO0`ooG`<<00ol00003okG>k@04o`000?nec^go]Lk]
o`0000;oZKgX0ol000000onY_NSo0000ojVmj005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgX
o`000?ooool01Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Gooooo`03o`000?oo
oooooooo01Wooooo0ol00008okg<iP?o000000?o_M_^o`000?l000000ol00005okoYlPSo00000_o7
o]l00ol0003odOKWom7fi`02om7fi`03o`000?oChN;odn7R00;odn7R0ol00003omCPh003o`000?oD
f=coe=SL00;oe=SL00?o0000olW4eOl000001_o:`m@00ol0003o_Jc9o`000007ojjQbP03o`000?nE
U];oUIKB00;oUIKB1Ol000000omjU>3o0000ogNIiP04ogNIiP03o`000?m_UnOoKiOW00?oKiOW00?o
0000of2:i?mPR^@00_mPR^@00ol0003oF8SUoeR8i@04o`0000;o:GcV0_l00003od2Hl`03o`000?m0
V??o000000GoM;?i00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`Go00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^02gooooo00?o0000ooooooooool07Oooool9o`0000;ooooo
1_l0000>ooooo`;o000000?oooooo`000?l000000ol00003ooooo`_o00002oooool00ol0003ooooo
ooooo`1Fooooo`004_ooool00ol0003oooooooooo`0Nooooo`03o`000?nY_NSoZKgX00?oZKgX1_l0
0002ojVmj005o`000?nW_NWoYkgYojNmjOl000001?m6Fl@00ol0003oYJ7BojFQdP04ojFQdP;o0000
1?n]WlT02?l0003ok?JXoncfZ?l0003o?TNco`000?l07JOo00001?mQP]`00ol0003oiKb/onFl[003
onFl[004o`000?oikJ3onNfPooW]X0;o000000?oW7V[o`000?n;H9X01?n;H9X00ol0003oaIVYolFI
Z@04olFIZ@05o`000?omhiKooN>FoogSU_l000001OnRV/d00ol0003oXHk0oj6>`003oj6>`004o`00
0?nKOK7oVgfaoi]m/@Ko00000_mWO=@01Ol0003oel33omO0`ol0003oo=fP00;o00001?nec^d00ol0
003o]Lk]o`000002o`0000GoZKgX00?o0000ojVmj?nY_NP00onY_NP3o`0000GoZKgX00?o0000oooo
ooooool00oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Gooooo`03o`000?oooooooooo01Kooooo0ol00003okc;iP03o`000?nmc>Ko_LcV00;o_LcV0ol0
00000onof>co0000o`000002o`000003okgKk_l0003o_nWb00Go_nWb00Go0000ol3ekoo0mNoo`?G_
o`000002ol?liP04o`000?o7o]ooaokOo`0000CodOKW00?o0000om?Qh_oChN800_oChN801ol0003o
e]OIomKGfOoFemWo0000omCPh?l000001?oDf=`01Ol0003obLCEolW4eOo9a=Go000000?ob/?D0_l0
0003okf/b@03o`000?n^XL[o[Z7:00Co[Z7:00?o0000oiFFd_l000000_l000000onSV/_o0000ohV@
d`02ohV@d`co000000?oKiOWo`000?mPR^@01?mPR^@00ol0003oF8SUoeR8i@02oeR8i@?o00000_lY
O>H5o`000003od2Hlol0003oM;?i00CoM;?i00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02go
oooo00?o0000ooooooooool06oooool5o`000004ooooool0003o0000o`0000?ooooo0ol00002oooo
o`03o`000?oooooooooo01Sooooo0ol000000ooooooo0000o`000002ooooo`?o00004?ooool7o`00
00?ooooo1ol00013ooooo`004Oooool00ol0003oooooooooo`0Pooooo`03o`000?nY_NSo000000Go
00001_nY_NP01?l0003oYkgYojNmjOnW_NT4o`000004odIKa?l0003oYJ7BojFQdP?o00001_n]WlT0
1?l0003ok?JXoncfZ?l00002oci7/`03o`000?l07JOo000000CoHH;L00?o0000onFl[?oU_:`00_oU
_:`01?l0003onNfPo`000?l00003oiaiZ`03o`000?n;H9[oRf2J00?oRf2J00?o0000olFIZOo5VJT0
1?o5VJT00ol0003ooN>FoogSUP02oogSUPWo00000_nQS/000ol0003oVgfaoi]m/@02o`0000;oJg[@
0ol000000omWO=Co0000omO0``02omO0``;o00000_l001400ol0003o]Lk]okG>k@03o`000003ojVm
j?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj0;o0000
1Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41005oooool00ol0003o
ooooooooo`0Dooooo`;o00001onlbnH01Ol0003o_LcVo`000?l0003o_mS/00?o00000onof>`3o`00
00Co_nWb0_l00002ol3ek`;o00000_o3o>H01?l0003oaokOolOngol00004om7fi`03o`000?oChN;o
dn7R00;odn7R00?o0000omKGfOoFemT00ooFemT2o`0000?oe=SL00?o0000olW4eOo9a=D00oo9a=D0
0ol0003ob/?Do`000005okf/b@03o`000?n^XL[o[Z7:00Co[Z7:0_l00005oj>Jb`03o`000?n9T=?o
RI3C00;oRI3C00?o0000oh>=eOn3SMD00on3SMD01?l0003oN8OFogR7e_mhQmH5o`0000?oH8[T00?o
0000oeR8iOmHR>D00_mHR>D00ol0003oC7WMo`000002o`0000CoCY7^1ol000000omd/oWo0000oooo
o`0>ooooo`;o00001Oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@4100
;Oooool00ol0003oooooooooo`0Rooooo`Wo00006_ooool4o`000003ooooool0003o000000;o0000
0oooool6o`0000Wooooo1Ol00005ooooo`_o0000@Oooool0017ooooo00?o0000ooooooooool07ooo
ool5o`0000CoZKgX00?o0000ojVmj?nY_NP00onY_NP6o`0000;oJ83H1?l00002odmce`03o`000?n]
WlWo[Io900?o[Io900Go0000oncfZ?o/mZSok?JXo`000003oci7/`?o00001?mQP]`00ol0003oiKb/
onFl[003o`0000GoW7V[00?o0000oh]PV_n;H9X01?n;H9X00ol0003oaIVYolFIZ@02olFIZ@03o`00
0?omhiKooN>F00?ooN>F00?o0000ohJ>don6S]<00on6S]<00ol0003oIH?LofF3g008o`0000CoJg[@
00?o0000omO0`ooG`<<00_oG`<<2o`0000;o000A0ol00002ojVmj004o`000?nY_NSoZKgXo`0000Go
ZKgX0ol00005ojVmj003o`000?nY_NSoZKgX00?o000000?oZKgXo`000?ooool01Oooool00onHV9So
8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000005oooool00ol0003oooooooooo`0Boooo
o`?o00002?nlbnH5o`0000Go_mS/00Co0000ol;Tl?o2i?3o`^C`0_l000000onojO;o0000ol3ek`02
ol3ek`04o`000?o3o>Ko`ocVol?liPKo00000_oAm^L00ol0003odn7Rom?QhP02om?QhP03o`000?oF
emWoe]OI00?oe]OI00Ko0000omSEeOoHeMGo0000omCHg?l00006olW4e@;o00001onm[<T01?l0003o
[Z7:ojjQb_n^XLX2o`000003ojnRbol0003oXi[;00CoXi[;00?o0000ohV@don9T=<00on9T=<00ol0
003oPhgEoh>=e@03oh>=e@03o`000?mhQmKoN8OF00;oN8OF00?o0000ofj7fom^Qm/01?l00005oeR8
i@03o`000?m<NMgoC7WM00;o00000om>TNh00ol0003oCY7^o`000004ogZYl@?o00003oooool00ol0
003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000]
ooooo`03o`000?oooooooooo02Gooooo1?l00007ooooo`;o00004Oooool4o`0000;ooooo1Ol00004
ooooo`Oo00005_ooool00ol0003oooooooooo`14ooooo`004Oooool00ol0003oooooooooo`0Loooo
o`?o00000oooool00ol0003oZKgXojVmj004ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0
003oGIocoefOl`05o`000003ofR0f?l0003oCg?G00;oCg?G00?o0000ojfObOn]WlT00_n]WlT00ol0
003ok?JXoncfZ002oncfZ005o`000?lnAk?o?TNco`000?mPF[@01Ol000000omQP]co0000onFl[003
o`0000GoW7V[00?o0000oh]PV_n;H9X01?n;H9X00ol0003oaIVYolFIZ@02olFIZ@03o`000?omhiKo
oN>F00;ooN>F00?o0000om2a^_l000001On6S]<00ol0003oIH?LofF3g002ofF3g0Go00001?m[N]00
1_l0003oel33omO0`ooG`<?o0000oocMX0?o000000?o]<g/o`000?nY_NP00onY_NP00ol0003oZKgX
o`000002ojVmj0?o000000?oZKgXo`000?nY_NP01OnY_NP3o`0000GoZKgX00?o0000ooooooooool0
1?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000005oooool00ol0003o
ooooooooo`0Aooooo`05o`000?njb^Oo^/[Wok[:iol000001_nlbnH3o`000003okkEjol0003o0000
00?o_mS/0_l00005ol;Tl0_o000000?oc?gSo`000?oGlN<00_oGlN<4o`0000;odn7R00?o0000omKG
fOoFemT00ooFemT00ol0003of=GEomSEe@02omSEe@03o`000?o9a=GobLCE00CobLCE00?o0000ol2_
b_l000001onm[<T01?l0003o[Z7:o`000?l00004ojnRb`03o`000?nSV/_oXi[;00?oXi[;00?o0000
ohV@don9T=<00_n9T=<00ol0003oPhgEoh>=e@03oh>=e@03o`000?mhQmKoN8OF00?oN8OF00?o0000
ofj7fom^Qm/00_m^Qm/3o`0000?oF8SU00?o0000odaigOm<NMd00_m<NMd3o`000004odjAk_l0003o
CY7^o`0000GoNZWa00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03ogMgMomV
IVKooooo00;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03o`000?oooooooooo02Gooooo
1_l00002ooooo`?o00004Oooool4o`0000?ooooo1_l00006ooooo`?o00001?ooool2o`0005Wooooo
000Aooooo`03o`000?oooooooooo01[ooooo0_l00007ooooo`03o`000?nY_NSoZKgX00?oZKgX0_l0
0006ojVmj004o`000?mMWo?oGIoco`0000?oOVjg1?l000000om?LmOo0000ojfOb@02ojfOb@Co0000
0_o/mZP01ol0003o?TNcoci7/olnAk?o0000of1J]?l000000omCX_H6o`0000GoW7V[00?o0000oh]P
V_n;H9X01?n;H9X00ol0003oaIVYolFIZ@02olFIZ@05o`000?omhiKooN>FoogSU_l000000_o@/KX0
0ol0003oQXkCohJ>d`03ohJ>d`03o`000?mUPmcoIH?L00;oIH?L00?o0000oc9JbolbF//00ol00004
of]jd003o`000?oG`<?oel3300?o00001?ndcN`01?l0003oZKgXojVmj?nY_NP5o`0000GoZKgX00?o
0000ojVmj?nY_NP00ol000000onY_NSo0000ojVmj005ojVmj0;o00001_ooool01Ol0003ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool05Oooool00ol0003oooooooooo`0?ooooo`;o0000
1Onjb^L00ol0003o_<_Vokc;iP03o`0000Ko_]G[00?o0000okoHk?l000001_o2i?001Ol0003oaNo_
olG_koo5knoo000000?ob?SZ00Go0000olcmhoo<oN?oc?gSo`000003omOah`03o`000?oFg=coe]cL
00;oe]cL0_l00005omKGf@03o`000?oHeMGof=GE00?of=GE00?o0000olW4eOo9a=D00oo9a=D01Ol0
003o`:o:ol2_b_o0[l[o000000Ko_Jc90_l00006ojnRb`03o`000?nSV/_oXi[;00?oXi[;00?o0000
ohV@don9T=<00on9T=<00ol0003oPhgEoh>=e@03oh>=e@03o`000?mhQmKoN8OF00;oN8OF00?o0000
ofj7fom^Qm/00om^Qm/01_l0003oG7_Io`000?l0003oF8SUo`0000CoC7WM00?o0000of69homQRN<0
1?l00006ogZYl@03o`000?oooooooooo00cooooo0ol00006ooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`0[ooooo`03o`000?oooooooooo01gooooo3?l00002ooooo`;o
000000?oooooo`000?ooool04Oooool3o`0000;ooooo2?l00002ooooo`03o`000?oooooooooo00Co
oooo1_l0000@ooooo`;o0000Aoooool0017ooooo00?o0000ooooooooool05oooool3o`0000[ooooo
00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00CoZKgX00?o0000oefOlol00000
1OmnK[L00ol0003oB6O?o`000002o`000006ojfObOl0003o0000odQWcol0003o8fCH0ol00003oci7
/`04o`000?mPF[CoH5Zdo`0000?oDj;f00?o0000onC1/ol000000ol00005oiaiZ`03o`000?n;H9[o
Rf2J00?oRf2J00Go0000olFIZOo5VJWoaIVYo`000003oogSUP03o`000?o@/K[od;6j00;od;6j00?o
0000ohJ>don6S]<00on6S]<00ol0003oIH?LofF3g002o`0000?o<U[;0_l00005of]jd004o`000?oG
`<?o0000o`0000Go]<g/1?l000001?nY_NSo0000ojVmj?l00006ojVmj0?o00001OnY_NP00ol0003o
ZKgXojVmj003ojVmj0;o00000_ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Fooooo`03o`000?oooooooooo00oooooo00?o0000ok[:ionjb^L01Onjb^L4
o`0000So_]G[0ol00004ol;Tl0;o00000oo5knl01Ol0003ob?SZolShj_o8n>[o000000?oc?gS00Go
0000omOahooGlN?oeo7So`000005omKLg003o`000?oFemWo000000?oe]OI00?o0000omSEeOoHeMD0
0ooHeMD00ol0003oe<S>o`000003olW4e@03o`000?o0[l[o`:o:00;o`:o:00?o0000okf/bOnm[<T0
0onm[<T00ol0003o]ZG7o`000007ojnRb`03o`000?nSV/_oXi[;00;oXi[;1Ol000000on9T=?o0000
oh>=e@04oh>=e@03o`000?mhQmKoN8OF00?oN8OF00?o0000ofj7fom^Qm/00om^Qm/00ol0003oG7_I
oeakf@03o`0000CoC7WM00Co0000of69homQRN?oHHWS1ol000000omjZO7o0000ooooo`0:ooooo`?o
00000_ooool02?l0003oooooooooool0003o^[ZjoooooonHV9So410@0oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg02gooooo00?o0000ooooooooool06oooool4o`00027ooooo00?o0000ooooool00000
0_ooool6o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000002ooooo`Wo0000
2oooool6o`0004Gooooo000Aooooo`03o`000?oooooooooo01Cooooo0ol0000>ooooo`03o`000?nY
_NSoZKgX00CoZKgX00Co0000ojVmj?nY_NSoZKgX1?l000000omMWo?o0000ogi^]`04ogi^]`0:o`00
0?m8IlooB6O?o`000?n]WlWo0000odQWcol0003oeojoo`0000;o8fCH0_l00002oci7/`06o`000?mP
F[CoH5Zdof1J]?l0003oDj;f0_l000000ooT`K?o0000o`000002o`0000GoW7V[00?o0000oh]PV_n;
H9X01?n;H9X01?l0003oaIVYolFIZOl00003oogSUP03o`000?o@/K[od;6j00;od;6j00?o0000ohJ>
don6S]<00on6S]<00ol0003oIH?Lo`000002on3Pe003o`000?lbF/_o<U[;00;o<U[;1ol000001?ol
gJ3o0000okC=k?ndcN`3o`000003ojVmj?l0003oZKgX00?oZKgX00?o0000ojVmj?l000000_nY_NP3
o`000003ojVmj?l0003oZKgX00GoZKgX00?o0000ojVmj?nY_NP00ol000002Ooooooo0000oooooooo
ooooV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05_ooool00ol0
003oooooooooo`0=ooooo`?o00001Onjb^L2o`000004ok[:iol0003o0000o`0000Ko_]G[0_l00003
ol7OkP;o000000?o`^C`o`000?o5knl00oo5knl01Ol0003ob?SZolShj_o8n>[o000000?oc?gS00Go
0000omOahooGlN?oeo7So`000005omKLg007o`000?oFemWoe]OIomKGfOl0003oe]OIo`000005omSE
e@07o`000?oDb<koe<S>omC8c_l0003obLCEo`000006ol2_bP03o`000?nm[<Wo_Jc900;o00000onf
YLL00ol0003o[j;;ojnRb`04ojnRb`03o`000?nSV/_oXi[;00;o000000?oYYK4o`000?n=QlP00_n=
QlP<o`000003ogR7e_l0003oKXOK00CoKXOK00?o0000oeakfOmLNmT00_mLNmT3o`0000?oC7WM00Co
0000of69homQRN?oHHWS0_l00004oh2Pj0?o00001oooool3o`0000Gooooo00So0000oooooooooooo
V9RHoa0@4?l0003o8B4Qolc<c0?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0]ooooo`03o`000?oo
oooooooo01Wooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo0_l00004ooooo`;o00004Ooo
ool00ol0003oooooooooo`02ooooo`?o000000Coooooo`000?l0003o00000_ooool00ol0003ooooo
ooooo`08o`000003ooooool0003ooooo00Co000000?oooooo`000?l000000_l00009ooooo`;o0000
0_ooool4o`00047ooooo000@ooooo`03o`000?oooooooooo01;ooooo0ol0000Booooo`03o`000?nY
_NSoZKgX00?oZKgX1?l00003ojVmj003o`000?mMWo?o000000GoOVjg00Oo0000odQWcom8IlooB6O?
o`000?m8Iloo000000?oeojo00Co0000ob=Tf?lSI=So00000olnAk<01?l0003oH5Zdof1J]?mPF[@2
o`0000?oi<6c0ol00005oiaiZ`03o`000?n;H9[oRf2J00CoRf2J00Co0000olFIZOo5VJWo00000_om
hiH00ol0003od;6jom2a^P04om2a^POo00000ooPh=@00ol0003o<U[;oc9Jb`02oc9Jb`03o`000?n=
S/ooSHk?00;oSHk?00?o0000oocMX?l000000ol00005ojVmj003o`000?nY_NSoZKgX00;oZKgX1?l0
0005ojVmj004o`000?nY_NSoZKgXojVmj0Go00001?ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00_ooooo0_l00003okK9j@Go000000?o^/[Wo`000?l000000onkdn`00ol0003o_]G[
okkEj`02okkEj`03o`000?o1gnko`Mo^00Co`Mo^1?l00002olG_k`05o`000?o8n>[ob?SZolShj_l0
00000oo<oN<01Ol0003oeo7SomOahooGlN?o000000Goe]cL00?o0000omKGfOoFemT00_oFemT3o`00
00Cof=GE00?o0000omC8c_oDb<h00ooDb<h00ol0003o`:o:ol2_bP05ol2_bP03o`000?nm[<Wo0000
00Go]ZG700?o0000ojnRbon_X//01?n_X//00ol0003oXi[;o`000004ojJFa003o`000?n=QlSoSHO8
00;oSHO800?o0000ohJ7cOn6Qld00on6Qld01?l0003oPhWAoh>9dOn3RM45o`0000?oKXOK00Go0000
oeakfOmLNmWoG7_Io`000002oeijePCo00001?mQRN<2o`0000GoP:3X00Co0000oooooooooooooooo
1?l00008ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool3o`0000?ooooo
0ol00008ooooo`Go00001oooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`000003oooo
ool0003o000000;ooooo0ol000000ooooooo0000ooooo`03o`0000;ooooo1_l000000ooooooo0000
o`000003o`0000Cooooo1_l00015ooooo`004?ooool00ol0003oooooooooo`0?ooooo`?o00005_oo
ool00ol0003oZKgXo`000002o`0000?oZKgX00?o0000ojVmj?nY_NP00_nY_NP2o`0000KoOVjg00Go
0000odQWcom8IlooB6O?o`000004omOn_`04o`000?lSI=So8fCHo`0000?o?TNc00?o0000of1J]?mP
F[@00_mPF[@01?l0003oi<6conC1/ooT`K<3o`0000GoW7V[00?o0000oh]PV_n;H9X01?n;H9X00ol0
003oaIVYo`000002oogSUP03o`000?o@/K[od;6j00God;6j00Co0000olj^^_o>[[[o00001_oPh=@3
o`0000?o<U[;00Oo0000ohf>con=S/ooSHk?o`000?olgJ3o000000;oZKgX00?o0000ojVmj?nY_NP0
1?nY_NP00ol0003oZKgXo`000003o`000003ojVmj?l0003oZKgX00CoZKgX1?l0000:ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool02Oooool2o`0000Co]/WY1?l000000onjb^Oo0000
o`000006ok_Ck004o`000?nneN_o0000o`0000Ko`Mo^00?o0000olGYkoo5jNl00_o5jNl?o`0000Co
e]cL00?o0000omKGfOoFemT00_oFemT01?l0003odL_Com7;dooAbm<2o`000003omSEeOl0003oe<S>
00Coe<S>0_l00007ol2_bP;o00001onfYLL00ol0003o[j;;ojnRb`03ojnRb`;o00001OnVU/@00ol0
003oSHO8ohf7b003ohf7b003o`000?n6QlgoQXO=00?oQXO=00?o0000oh>9dOn3RM400_n3RM400ol0
003oLX7Cog:1d`04o`0000CoG7_I00?o0000oeije_mNN]H00_mNN]H4o`0000;oHHWS0_l00005oh2P
j0?o00003?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo023ooooo0ol000001?oo
oooo0000ooooooooool2o`000003ooooool0003ooooo00Sooooo0ol00005ooooo`;o000000Kooooo
o`000?l0003o0000ooooool00002ooooo`;o000000Coooooo`000?l0003ooooo0_l00004ooooo`;o
00000oooool4o`0000?ooooo1_l000000ooooooo0000o`000002o`0000Gooooo00?o0000ooooool0
00001?l00011ooooo`004?ooool00ol0003oooooooooo`0<ooooo`?o00006_ooool2o`0000KoZKgX
00Oo0000ojVmj?nY_NSoZKgXo`000?mMWo?o000000GoOVjg00?o0000odQWcom8Ill02?l00002ob=T
f004o`000?lnAk?o?TNco`0000?oH5Zd00?o0000onC1/ooT`K<00ooT`K<2o`0000GoW7V[00?o0000
oh]PV_n;H9X01?n;H9X00ol0003oaIVYo`000002o`0000Ood;6j00Co0000olj^^_o>[[[ocZjj0_l0
0002on3Pe0?o000000Co[<;Zo`000?lCCl[o00000_lbF//01?l0003oSHk?ohf>col00002oocMX005
o`000?nY_NSoZKgXojVmj?l000000onY_NP4o`0000?oZKgX00Go0000ojVmj?nY_NSo0000ojVmj003
o`0000kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`?o00000_nfbNT3
o`0000?o]/WY0ol00007ok_Ck0?o00001Oo1gnh2o`0000CoaNW_00Go0000ol_`k?o;l>cobo3/o`00
0003om;eiP03o`000?oKjmkofn_N00;ofn_N00?o0000omWIeooIfML00_l000000ooFg=co0000omKG
f@03omKGf@03o`000?oAbm?odL_C00CodL_C00?o0000omC8c_oDb<h00ooDb<h01?l0003obkW8ol^i
b?l00005ol2_bP03o`000?njYlKo000000Oo]ZG700?o0000ojnRbon_X//00ol000000onXUlCo0000
ojJFa004ojJFa003o`000?n=QlSoSHO800?oSHO800?o0000ohJ7cOn6Qld00on6Qld00ol0003oPhWA
oh>9d@03oh>9d@03o`000?mbPM?oLX7C00;oLX7C0ol00002oeakf@03o`000?mNN]KoGW[F00?oGW[F
00?o0000og2;gOm`Rmd01?l00006oh2Pj003o`000?oooooooooo00cooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool2o`0000Gooooo0_l000000ooooooo0000ooooo`04ooooo`?o000000Goooooo`000?l0003o
ooooo`000003ooooo`?o000000Coooooo`000?oooooo00000oooool00ol0003oooooo`000002o`00
00Cooooo0ol00003ooooo`Ko000000?oooooo`000?l000001?l00009ooooo`;o0000?oooool0013o
oooo00?o0000ooooooooool02Oooool3o`0001oooooo00?o0000ojVmj?nY_NP00onY_NP4o`000003
ojVmj?l0003o000000GoOVjg00Ko0000odQWcol0003o0000ofg2o_l00004oh:Rj003o`000?lSI=So
8fCH00;o00000_lnAk<01?l0003oH5Zdof1J]?l00005onC1/`?o00001?nLNJ/00ol0003oRf2Joh]P
VP05oh]PVPCo00001_o@/KX01?l0003ocZjjolj^^_o>[[X5o`0000Go[<;Z00[o0000oa=?b_l0003o
0000oc9Jbol0003oSHk?o`000?olgJ3o00001?nY_NP4o`0000?oZKgX00?o0000ojVmj?nY_NP00_nY
_NP01?l0003oZKgXo`000?l0000Aooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
1Oooool2o`0000;o/<S/0ol00003okK9j@?o00000ongdNd00ol0003o^m?/ok_Ck002ok_Ck0;o0000
0onnfnh3o`000003ol7Ok_l0003oaNW_00?oaNW_0_l00003ol_`k005o`000?oBmNKod_GVom;ei_l0
00001?oKjmh00ol0003ofMWGomWIe`03omWIe`;o00000ooFemT00ol0003odL_Com7;d`04om7;d`03
o`000?oCa<co000000?oe<S>00?o0000ol^ib?o;^LP00_o;^LP01Ol0003o`:o:ol2_b_o0[l[o0000
00?o^ZO600?o0000okJUaonfYLL01?nfYLL3o`0000GoZ9O400?o0000ojJFa?nVU/@00onVU/@00ol0
003oSHO8ohf7b003ohf7b003o`000?n6QlgoQXO=00?oQXO=00?o0000oh>9dOn3RM400_n3RM400ol0
003oLX7Cog:1d`03og:1d`06o`000?mUM<ko0000o`000?mLNmWo00001OmNN]H00ol0003oL8_Mog2;
g@02og2;g@Wo00003Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Sooooo0ol0
000>ooooo`Co000000Coooooo`000?l0003o00001Oooool00ol0003oooooooooo`02o`000003oooo
ool0003ooooo00;ooooo00?o0000ooooool000001?l00003ooooo`04o`000?oooooo0000o`0000Co
oooo0ol00003ooooo`Ko0000B?ooool0013ooooo00?o0000ooooooooool01_ooool3o`0002?ooooo
00?o0000ojVmj?l000000_l000000onY_NSo0000ojVmj002ojVmj0;o00001OmnK[L5o`000003ofg2
o_l0003oPZ;X00?oPZ;X00Wo0000ob=Tf?l0003o02b`o`000?lnAk?o0000of1J]?l000001_oT`K<3
o`0000CoW7V[00?o0000oh]PV_n;H9X01On;H9X3o`000003o`006Ol0003od;6j00?od;6j00?o0000
olj^^_o>[[X00_o>[[X3o`000003omOjgol0003o[<;Z00Go[<;Z00?o0000oa=?b_lCClX00_l00000
1On=S/oo0000oocMX?l0003oZKgX00?o000000?oZKgXo`000?nY_NP01OnY_NP00ol0003oZKgXojVm
j003o`0001?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`;o000000Co
/<S/o`000?l0003o00000_n`b>`01?l0003o]/WYo`000?l00007okOAk@04o`000?nkdnco0000o`00
00Oo_]_^1?l00002olGYk`03o`000?o;l>cobo3/00;obo3/00Go0000om;ei_oBmNKod_GVo`000004
om_[gP03o`000?oIfMOofMWG00?ofMWG00Ko0000om[Fe?oJe]Co0000omKGfOl00006om7;d`07o`00
0?oCa<codlC<om?4c?l0003oe<S>o`000006ol^ib003o`000?o0[l[o000000Co^ZO600?o0000okJU
aonfYLL00onfYLL00ol0003o/ic1o`000006ojRGa003o`000?nVU/CoYYK400?oYYK400?o0000ohf7
b?n=QlP00on=QlP00ol0003oQXO=ohJ7c@03ohJ7c@03o`000?n3RM7oPhWA00?oPhWA00?o0000og:1
dombPM<00ombPM<00ol0003oIGC>ofEdcP02o`0000GoGW[F00?o0000og2;gOm`Rmd00om`Rmd00ol0
003oQYgQohJMh@04ohJMh@03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0Nooooo`Co00001?ooool2o`000003ooooool0003ooooo00?ooooo0_l00007oooo
o`?o000000?oooooo`000?ooool01?l00004ooooo`03o`000?oooooooooo00?o00001Oooool4o`00
0004ooooool0003o0000o`0000Kooooo0ol00004ooooo`;o00000_ooool00ol0003oooooooooo`03
o`0004Oooooo000@ooooo`03o`000?oooooooooo00?ooooo0ol0000Wooooo`03o`000?nY_NSoZKgX
00?oZKgX00Go0000ojVmj?nY_NSoZKgXo`000003ogi^]`;o00001OnL^Nd3o`0000?oPZ;X0_l00000
0olSI=So0000o`0//002o`000003of1J]?l0003oi<6c00Koi<6c0_l00004oiaiZ`03o`000?n;H9[o
Rf2J00GoRf2J1Ol00004om2a^P04o`000?o>[[[ocZjjolj^^P?o00000ooGn]l00ol0003o[<;Zojc2
jP03ojc2jP04o`000?lCCl[o4do:oa=?bP;o00000_olgJ02o`0000GoZKgX00?o0000ojVmj?nY_NP0
0onY_NP3o`0000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00;ooooo1Ol00005ok38k0?o00002?ngdNd3o`0000Ko_]_^0_l00004ol;Sk`Co0000
0_o;l>`01Ol0003od_GVom;ei_oBmNKo000000Cofn_N00?o0000omWIeooIfML00ooIfML00ol0003o
f]KDom[Fe002om[Fe0;o00001OoAbm<00ol0003odlC<om?4c003om?4c003o`000?o;^LSobkW800Go
bkW80_l00006okZWaP03o`000?nfYLOo]ZG700;o00000oncW<400ol0003oZ9O4ojRGa004ojRGa003
o`000?nVU/CoYYK400;oYYK400Co0000ohf7b?n=QlSoSHO81ol000000on6Qlgo0000oh>9d@04oh>9
d@03o`000?mbPM?oLX7C00?oLX7C00?o0000ofEdc_mUM<h00_mUM<h3o`0000?oGW[F00?o0000og2;
gOm`Rmd00om`Rmd00ol0003oQYgQohJMh@04ohJMh@03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool08?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`01?ooool00ol0003oooooooooo`0Mooooo`Co00001?ooool00ol0003ooooooooo
o`04ooooo`?o00001oooool00ol0003oooooo`000004ooooo`?o00002Oooool00ol0003ooooooooo
o`04ooooo`Co00000_ooool3o`0000Gooooo1?l0000=ooooo`03o`000?oooooooooo04Cooooo000?
ooooo`04o`000?ooooooooooooooo`?o0000:oooool00ol0003oZKgXojVmj003ojVmj003o`000?nY
_NSo000000Co000000?oZKgXo`000?nL^Nd01?nL^Nd4o`0000;oPZ;X00Co0000ob/n/ol0003o0000
0_l0;;03o`0000Koi<6c0ol00004oiaiZ`03o`000?n;H9[oRf2J00GoRf2J0_l000001?o]n;;o0000
o`000?l00002om2a^P03o`000?o>[[[ocZjj00;ocZjj0_l00004omOjg`ko000000?oZKgXo`000?nY
_NP01?nY_NP00ol0003oZKgXojVmj003o`0000Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooo000000Co000000?oZLK_o`000?n`b>`00on`b>`2o`0000?o
/Lo_0_l00004okOAk@;o00000onif?000ol0003o_]_^okkKkP02okkKkP03o`000?o2hnoo`^?_00?o
`^?_00?o0000olSXkOo8j>d00_o8j>d8o`0000;ofn_N00?o0000omWIeooIfML00ooIfML00ol0003o
f]KDom[Fe002om[Fe004o`000?oFcM7oe/gAo`0000?odL_C00?o0000om?4c?oCa<`01?oCa<`00ol0
003obkW8ol^ib004ol^ib003o`000?o2[lOo000000Ko^ZO600?o0000okJUaol000001OncW<400ol0
003oZ9O4ojRGa004ojRGa003o`000?nVU/CoYYK400;oYYK41?l00003oiB;aP04o`000?n=R<WoSHS9
ohf8b@[o00001?mbPM<01Ol0003oIGC>ofEdc_mUM<ko000000;oKGoD1?l00005og2;g@;o00001_n6
WN400ol0003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Cooooo00?o0000oooooooo
ool06oooool2o`0000;ooooo00?o0000ooooooooool02?ooool2o`000003ooooool0003ooooo00Ko
oooo00?o0000ooooooooool01Oooool2o`0000Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooo`000003ooooo`03o`000?oooooooooo00?ooooo1_l0001Cooooo`003oooool4o`0002oooooo
00Co0000ojVmj?nY_NSoZKgX0ol00002ojVmj003o`000?nY_NSoZKgX00;oZKgX00?o0000oibikOl0
00000_l00002ojVmj003o`000?n8/_7o000000;oPZ;X00?o0000ob/n/ol000000ol0;;000ol0003o
i<6conC1/`04onC1/`04o`000?o4a]_oa<KKo`0000CoW7V[00?o0000oh]PV_n;H9X01?n;H9X3o`00
0006ongh/_l0003okN?5o`000?o@/K[o00001?o>[[X2o`0000;oeo[O0ol00002ok76jP04o`000?nY
_NSoZKgXojVmj0Co00001_nY_NP01?l0003oZKgXojVmj?nY_NP4o`0000[ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Qooooo`Co00001OnYa^l01?l0003o/<S/o`000?l00007ok7?
k`04o`000?ngdNgo0000o`0000Ko^MS`00Co0000okkKk_l0003o00001?o2hnl2o`0000Cob>S]00?o
0000om3Yioo@jNL00_o@jNL01?l0003of>?NomSSg_oHhmh3o`0000CofMWG00?o0000om[Fe?oJe]@0
0_oJe]@00ol0003oe/gAomK=d@02omK=d@03o`000?oAbm?o000000KodlC<00?o0000om6maol00000
1?o;^LP01Ol0003o`Zo7ol:_aoo2[lOo000000Go^ZO60_l00007ok>L`@03o`000?nXUlCoZ9O400?o
Z9O400?o0000ojJFa?l000000_l000000onUU/Go0000oiB;aP05oiB;aP03o`000?n=R<WoSHS900;o
SHS900?o0000ohN6c?n7Q/`00on7Q/`00ol0003oKgS<o`000002o`000003og:1dol0003oIGC>00?o
IGC>00?o0000ofeoe?m]Om@00_m]Om@6o`000003og2;gOl0003oQYgQ00GoQYgQ00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Pooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Sooooo0_l00006ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00?ooooo0ol00002
ooooo`03o`000?oooooooooo00;ooooo1?l000000ooooooo0000o`000002o`0004Gooooo000?oooo
o`;o0000<_ooool3o`0000?oZKgX00?o0000ojVmj?nY_NP01?nY_NP2o`0000KoZKgX00Go0000ohRb
lOl0003oPZ;Xo`000002ob/n/`;o000000?o02b`o`000?oT`K<01?oT`K<01?l0003oa<KKolC6foo4
a]/2o`0000CoW7V[00?o0000oh]PV_n;H9X00on;H9X2o`000004ongh/_l0003okN?5ongSa@;o0000
1Oo>[[X4o`0000Co/LKZ1Ol00003ojVmj003o`000?nY_NSoZKgX00CoZKgX1?l0000?ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool08?ooool4o`0000GoZLK_0ol00008ok7?k`?o0000
1onif?05o`0000;o`^?_00?o0000olSXkOo8j>d00oo8j>d00ol0003od>WWom3Yi`02om3Yi`03o`00
0?oHhmkof>?N00;of>?N00?o0000om[JeooJf]L00_l000000ooIfMOo0000om[Fe003om[Fe003o`00
0?oFcM7oe/gA00Coe/gA00?o0000om?4c?oCa<`01?oCa<`01Ol0003odKg7om6maooA_LOo000000;o
bkW800?o0000ol:_aoo2[lL00_o2[lL00ol0003o^ZO6okZWaP02okZWaP03o`000?neWKoo000000Oo
/ic100?o0000ojRGa?nXUl@00onXUl@2o`0000GoYIK500?o0000oiB;a_nDRlH00onDRlH00ol0003o
SHS9ohf8b@03ohf8b@03o`000?n7Q/coQhK<00?oQhK<00Co0000ofmhc?m_N<coKgS<0_l00004ofEd
cP03o`000?m]OmCoKGoD00?oKGoD00?o0000og^>f_mkS]X00_mkS]X:o`0000[ooooo00?o0000oooo
ooooool08?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q
8@04ooooo`;o0000:oooool2o`0000Kooooo0ol0000Pooooo`;o00000_ooool2o`0000Cooooo0ol0
0002ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`?o0000@oooool0017ooooo00?o0000
ooooooooool0<?ooool00ol0003oZKgXojVmj003ojVmj003o`000?nY_NSoZKgX00?o00000_nY_NP0
0ol0003oZKgXojVmj003ojVmj0Go00000ol[?[<4o`0000?oi<6c00?o0000ojR4[_l000000_o4a]/2
o`0000CoW7V[00?o0000oh]PV_n;H9X00on;H9X00ol0003okORbo`000004ongSa@03o`000?o>[[[o
cZjj00?ocZjj00Co0000oiZSfonJXm_o00000onaa^X2o`000003ojVmj?l0003oZKgX00GoZKgX00?o
0000ojVmj?nY_NP00ol0000Cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08_oo
ool01?l0003oooooo`000?nYa^l3o`0000?oZLgc0_l00004ok7?k`;o00000onbeO800ol0003o^MS`
okWHl002okWHl0;o00001Onlg_43o`0000Cob>S]00?o0000om3Yioo@jNL00_o@jNL00ol0003of>?N
omSSgP02omSSgP03o`000?oJf]Oof][G00?of][G0_l00003om[Fe003o`000?oFcM7oe/gA00Coe/gA
0_l00005om?4c003o`000?oA_LOodKg700;odKg700?o0000ol^ib?l000001_o2[lL01?l0003o^ZO6
okZWa_l00003okFM_`03o`000?ncW<7o/ic100Co/ic100?o0000ojRGa?nXUl@00ol000000onWUL?o
0000ojFFa@04ojFFa@03o`000?nDRlKoU8_600?oU8_600?o0000ohf8bOn=R<T00on=R<T00ol0003o
QhK<ohN6c003ohN6c003o`000?m_N<coKgS<00?oKgS<0ol00002ofEdcP03o`000?m]OmCoKGoD00?o
KGoD00?o0000og^>f_mkS]X00omkS]X00ol0003oS9cNohbLgP04ohbLgP03o`000?oooooooooo00So
oooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEE
EOl0003o410@olc<c004ooooo`03o`000?oooooooooo02Oooooo1Ol00005ooooo`03o`000?oooooo
000000[ooooo00?o0000ooooooooool05Oooool2o`0000;ooooo0_l00006ooooo`03o`000?oooooo
oooo00Gooooo1_l00003ooooo`?o0000@?ooool001;ooooo00?o0000ooooooooool0<?ooool01?l0
003oZKgXojVmj?nY_NP4o`0000KoZKgX00?o0000ojVmj?l000000_l000001?nY_NSo0000og>Ylomc
ZO<2o`0000?o:cjc00Ko0000o`Q]gOl0003o0000onC1/ol00003ojR4[P04o`000?o4a]_oa<KKo`00
00CoW7V[00?o0000oh]PV_n;H9X00_n;H9X5o`0000;okN?50ol00003olj^^P03o`000?nJXm_oVZ?K
00;oVZ?K00?o0000ok76j_l000001?nY_NP00ol0003oZKgXojVmj003ojVmj0?o00005oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo00Co0000ooooool0003o00001onYcO<0
1?l0003o/Lo_o`000?l00006ok;ElP04o`000?nif?3o0000o`0000Ko_=ka00Co0000ol7Rkoo1h^oo
`N;_0_l000000oo8j>go0000om3Yi`03om3Yi`03o`000?oHhmkof>?N00;of>?N00?o0000om[JeooJ
f]L00ooJf]L01_l0003of=OFomSGe_l0003of]KDo`0000Koe/gA00Co0000oljnboo>_/_o00000ooC
a<`00ol0003odKg7om6ma`04om6ma`03o`000?o2[lOo`Zo700Go`Zo700?o0000okZWa_l000001?ne
WKl00ol0003o/ic1ok>L`@04ok>L`@?o00001OnWUL<00ol0003oYIK5ojFFa@03ojFFa@03o`000?nD
RlKoU8_600?oU8_600?o0000ohf8bOn=R<T00on=R<T00ol0003oQhK<ohN6c002ohN6c003o`000?m_
N<coKgS<00?oKgS<00?o0000og1kc_m`Nlh00ol00005ofeoe003o`000?mkS][oNhkJ00CoNhkJ00?o
0000ohbLg_n<W=h01?n<W=h00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00Go
410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Kooooo00?o0000ooooooooool0
9Oooool2o`000004ooooool0003o0000o`0000Gooooo00?o0000ooooooooool00oooool3o`0000Co
oooo0_l0000@ooooo`03o`000?oooooooooo00Cooooo0ol00002ooooo`;o00001_ooool00ol0003o
ooooooooo`06ooooo`?o000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`0mooooo`00
4oooool00ol0003oooooooooo`0`ooooo`?o00001?nY_NP00ol0003oZKgXojVmj003ojVmj0;o0000
1OnY_NP00ol0003oLjWcog>Yl`06o`0000;oZ8B^00?o0000ojR4[_nXQ:h00onXQ:h3o`0000CoW7V[
00?o0000oh]PV_n;H9X00_n;H9X00ol0003oZYO2o`000002o`1^`P;o00000_nWWlh01Ol0003ocZjj
olj^^_o>[[[o000000CoVZ?K0_l00006ojVmj003o`000?nY_NSo000000;o00006oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo00001_nYcO<3o`00
00Oo/]Gb0ol00005okcNl@;o00001Oo1h^l4o`0000;od>WW00?o0000omSSg_oHhmh00_oHhmh00ol0
003of][Gom[Je`03om[Je`03o`000?oHemKof=OF00;of=OF0_l00005omK=d@03o`000?o>_/_oc[k;
00;oc[k;00?o0000om?4c?l000001_oA_LL2o`0000Oo`Zo70_l00006okFM_`03o`000?ncW<7o/ic1
00;o/ic100?o0000ok6K`?l000001_nWUL<00ol0003oYIK5ojFFa@03ojFFa@03o`000?nDRlKoU8_6
00?oU8_600?o0000ohf8bOn=R<T00on=R<T00ol0003oQhK<ohN6c003ohN6c003o`000?m_N<coKgS<
00?oKgS<00?o0000og1kc_m`Nlh00_m`Nlh3o`0000?oKGoD00?o0000og^>f_mkS]X01?mkS]X00ol0
003oS9cNohbLgP03ohbLgP03o`000?oooooooooo00Sooooo00?o0000ooooooooool07oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P01_ooool00ol0003oooooooooo`0T
ooooo`06o`000?ooooooooooo`000?oooooo00002_ooool5o`0000?ooooo0_l0000=ooooo`03o`00
0?oooooooooo00;o00001Oooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooo000000Oo
oooo0ol00005ooooo`Co0000AOooool001Cooooo0_l0000booooo`03o`000?nY_NSoZKgX00?oZKgX
00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX00?o0000og>Ylol00000
1?n6WN800ol0003oZ8B^ojR4[P06ojR4[PCo00000onLNJ/00ol0003oRf2Joh]PVP02oh]PVPCo0000
00?o06k2o`000?nWWlh00onWWlh01?l0003ocZjjo`000?l00002oiZSf`;o00000_nY_NP01?l0003o
ZKgXojVmj?nY_NP4o`0001oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Uoooo
o`;o000000Coooooo`000?nYcO?oZLgc0ol00003ojSCmP03o`000?nbeO;o/]Gb00;o/]Gb0_l00003
okCJm0?o000000?o_=kao`000?o1h^l01Oo1h^l00ol0003oan?/olOSk002olOSk0Co00000_oHhmh0
0ol0003of][Gom[Je`03om[Je`03o`000?oHemKof=OF00?of=OF00?o0000omK@dol000000ooFcM40
0ol0003oc[k;oljnb`04oljnb`03o`000?oA_LOodKg700CodKg700Co0000olVa`_o9/L;o00001Oo2
[lL00ol0003o]Ybmo`000006okFM_`03o`000?ncW<7o/ic100;o00000onaVl000ol0003oYiG3ojNE
``04ojNE``03o`000?nUU/GoYIK500;oYIK500?o0000oiB;a_nDRlH00onDRlH00ol0003oSHS9ohf8
b@03ohf8b@03o`000?n7Q/coQhK<00?oQhK<00?o0000ofmhc?m_N<`00om_N<`00ol0003oL7_>og1k
cP02og1kcP03o`000?mhQ]CoN8KD00Co00001_mkS]X2o`0000CoS9cN00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Oooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4
o`000?l@4104ooooo`03o`000?oooooooooo02Gooooo0_l00005ooooo`;o00001oooool3o`0000Co
oooo0_l0000=ooooo`03o`000?oooooooooo00?o00000_ooool4o`000003ooooool0003o000000Co
oooo00?o0000ooooooooool01Oooool3o`0000Sooooo0_l00013ooooo`005_ooool00ol0003ooooo
ooooo`0`ooooo`04o`000?nY_NSoZKgXojVmj0?o00001_nY_NP01?l0003oZKgXojVmj?nY_NP3o`00
0003ojVmj?l0003oQYgR00;oQYgR00?o0000ojR4[_nXQ:h01OnXQ:h01Ol0003oTkK_oi>fkonC]^oo
000000?oW7V[00Oo0000oh]PV_n;H9[oRf2Jo`000?nZUl;o000000;o/=[f00?o0000o`1^`_l00000
0onWWlh01_l0003ocZjjo`000?l0003oVZ?Ko`0000CoZKgX1?l0000Sooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool09oooool01?l0003oooooo`000?l00007ojSCmP04o`000?nbeO;o
0000o`0000Oo]=[d0ol00004ol7Rk`;o00001?o7hn`00ol0003ocN3VolgPiP02olgPiP?o00001?oJ
f]L00ol0003of=OFomSGeP03omSGeP07o`000?oFd=?oe]3ComK@dol0003oe/gAo`000006oljnb`;o
00001OoA_LL00ol0003obK72olVa`P02olVa`P03o`000?o2[lOo`Zo700;o00000onfW;d00ol0003o
]IfookFM_`03okFM_`03o`000?ncW<7o000000Go/I_000?o0000ojNE`onWUL<01?nWUL<00ol0003o
YIK5ojFFa@02ojFFaA7o000000?oQhK<o`000?m_N<`01Om_N<`00ol0003oL7_>og1kcP02og1kcP03
o`000?mhQ]CoN8KD00;oN8KD3ol00009ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`03ooooo`?o00001_ooool2o`000004ooooool0003o0000o`00
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`;o000000?oooooo`00
0?l000000_l00002ooooo`Go00000_ooool00ol0003oooooooooo`02ooooo`?o00001Oooool00ol0
003oooooo`000004o`0000Gooooo00?o0000ooooooooool0@?ooool001Oooooo00?o0000oooooooo
ool0<?ooool3o`0000?oZKgX00?o0000ojVmj?nY_NP00onY_NP4o`0000?oZKgX00?o0000ojVmj?l0
00000on6WN800ol0003oZ8B^ojR4[P04ojR4[P;o00000onC]^l01?l0003oW7V[oiaiZol00003oh]P
VP?o00000_n`f_H3o`0000CoYio>00?o0000ojNOc_l000000_l000001?nY_NSo0000o`000?l0000X
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02
o`0000GoZ=?f0ol00006okCJm0;o00000ongg_<2o`000003ol7Rkol0003oan?/00?oan?/0_l00004
olgPiP04o`000?o@f^3od=[Pom3Jh0;o000000?of][Go`000?oHemH01?oHemH00ol0003oe]3ComK@
d`02omK@d`;o00001_o>_//01?l0003oc[[6oljja_l00003om6ma`03o`000?o9/L;obK7200?obK72
00?o0000ol:_aol000001OnfW;d00ol0003o]IfookFM_`03okFM_`;o00001onaVl000ol0003oYiG3
ojNE``03ojNE``03o`000?nUU/Go000000;o000000?oXY?5o`000?nGRlD01?nGRlD00ol0003oTHO5
oi67a@03oi67a@04o`000?n8P/KoR8;6ohR2aPGo00000om_N<`00ol0003oL7_>og1kcP02og1kcP03
o`000?mhQ]CoN8KD00?oN8KD00?o0000oh>BfOn3T]T01?n3T]T2o`0000CoT9gL00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Wooooo00?o0000ooooool0
00001_ooool4o`000003ooooool0003o000000;ooooo00?o0000ooooooooool00_ooool2o`0000Oo
oooo0_l000000ooooooo0000o`000004o`000006ooooool0003o0000o`000?oooooo00002Oooool7
o`0000?ooooo1?l00017ooooo`006?ooool00ol0003oooooooooo`0`ooooo`03o`000?nY_NSoZKgX
00?oZKgX00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00003ohJM
hP03o`000?nXQ:koZ8B^00?oZ8B^00?o0000ojVmj?l000001?l00002oiaiZ`06o`000?n;H9[oRf2J
oh]PV_l0003oRk;`0ol00002ojVmj0;o00000onWWlh6o`0002cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Xooooo`06o`000?ooooooooooooooool0003oZ=?f0ol00003ojWHn0?o
000000?o]=[do`000?l000001_ngg_<4o`0000;oan?/00?o0000olgPi_o=h>H00oo=h>H00ol0003o
d=[Pom3Jh003om3Jh0?o00001?oHemH00ol0003oe]3ComK@d`02omK@d`03o`000?o<_<_o000000Go
c[k;00?o0000oljja_o>^/H00_o>^/H00ol0003odKg7o`000007olVa`P03o`000?nfW;go]Ybm00Go
]Ybm00Oo0000okFM_oneWKoo]Ifoo`000?ngWl3o000000Oo/I_000?o0000ojNE`onWUL<00onWUL<2
o`0000GoXY?500?o0000oiN;aOnGRlD00onGRlD00ol0003oTHO5oi67a@03oi67a@03o`000?n8P/Ko
R8;600;oR8;600?o0000ogQiaomhNLL01?l00005og1kcP03o`000?mhQ]CoN8KD00?oN8KD00?o0000
oh>BfOn3T]T01?n3T]T2o`0000CoT9gL00?o0000ooooooooool01_ooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo02Oooooo0_l000000ooooooo0000o`000002ooooo`;o000000?ooooo
o`000?l000000_l000000ooooooo0000o`000007ooooo`;o00001_ooool01?l0003oooooo`000?l0
0002ooooo`03o`000?oooooo000000;o000000Koooooo`000?l0003o0000ooooool0000:ooooo`Oo
00001?ooool01?l0003oooooo`000?l00015ooooo`006Oooool2o`00037ooooo00Co0000ojVmj?nY
_NSoZKgX0ol00006ojVmj004o`000?nY_NSoZKgXojVmj0Co00000_n6WN800ol0003oZ8B^ojR4[P03
ojR4[P;o00000_nY_NP01_l0003oZKgXojVmj?l0003oW7V[o`0000;oRf2J0ol00002ojVmj006o`00
0?nY_NSoZKgXojVmj?l0003oYio>1?l0000aooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0:Oooool2o`0000;ooooo0_l00007ojWHn0?o00001Ongg_<2o`0000Co^mob0ol00004olgP
iP03o`000?o@f^3od=[P00?od=[P00Co0000om3Dg?o@e=cod=CL0_l000000ooHemKo0000omK@d`03
omK@d`05o`000?o<_<_oc;c;olblbol000000oo>_//00ol0003oc[[6oljjaP04oljjaP03o`000?o9
/L;obK7200GobK720_l00007okJL_@04o`000?neWKoo]Ifoo`0000?o]io000?o0000ok6K`?naVl00
1?naVl000ol0003oYiG3ojNE``03o`000003ojVGa?l0003oXY?500CoXY?500?o0000oiN;aOnGRlD0
0onGRlD00ol0003oTHO5oi67a@03oi67a@03o`000?n8P/KoR8;600?oR8;600?o0000ogQiaomhNLL0
0_mhNLL5o`000003og1kc_l0003oN8KD00GoN8KD00?o0000oh>BfOn3T]T00on3T]T00ol0003oT9gL
o`000004oi2Mg003o`000?oooooooooo00Gooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`0Vooooo`04o`000?oooooo0000o`0000;ooooo0ol00002ooooo`03o`000?oooooo000000;o
oooo0_l00007ooooo`;o00001_ooool00ol0003oooooo`000003ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000;ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo1_l00007ooooo`;o
0000@oooool001_ooooo00?o0000ooooooooool0;oooool3o`0000?oZKgX00?o0000ojVmj?nY_NP0
0onY_NP4o`0000?oZKgX00Co0000ohJMh_n6WN;o00001?nXQ:h00ol0003oZKgXojVmj003ojVmj005
o`000?nY_NSo0000oiaiZol000000_n;H9X00ol0003oZKgXojVmj003ojVmj003o`000?nY_NSo0000
00;o0000=Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02_ooooo00Co0000oooo
oooooooooooo0_l00002ojWHn0?o00000onYfoT2o`000003okONlol0003o000000Co^mob0_l00003
ol3MkP;o000000?ocN3Vo`000?o@f^001?o@f^000ol0003od=CLom3Dg003om3Dg0?o00000ooFd=<0
0ol0003oc;c;olblb`03olblb`03o`000?o>_/_o000000Ooc[[600?o0000olVa`_o9/L801?o9/L80
1?l0003o`ZFlol:U_?l00006okJL_@03o`000?neWKoo000000Co]io000?o0000ok6K`?naVl001?na
Vl03o`0000CoZIO400?o0000oj:CaOnRTlD00onRTlD00ol0003oUh_5oiN;a@04oiN;a@03o`000?nA
QlGoTHO500;oTHO500?o0000ohR2a_n8P/H00on8P/H00ol0003oN7W7ogQia`03ogQia`04o`000?mj
P/ooNX;?ogZ2c`Oo000000?oN8KDo`000?n3T]T01?n3T]T00ol0003oT9gLo`000004oi2Mg003o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Wooooo`;o0000
0_ooool00ol0003oooooo`000002ooooo`;o000000Coooooo`000?oooooo00002Oooool00ol0003o
ooooooooo`04ooooo`?o00001?ooool2o`000003ooooool0003o000000?ooooo0_l00002ooooo`?o
00000oooool2o`0000?ooooo1?l00002ooooo`;o00001oooool00ol0003oooooooooo`10ooooo`00
7?ooool00ol0003oooooooooo`0_ooooo`03o`000?nY_NSoZKgX00?oZKgX00?o0000ojVmj?l00000
0_l00002ojVmj003o`000?nY_NSoZKgX00?oZKgX00Co0000ohJMh_n6WN;o00000onXQ:h00ol0003o
ZKgXojVmj003ojVmj0?o000000GoW7V[o`000?n;H9[oRf2Jo`000005ojVmj0;o0000>Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool00_ooool2o`00
00OoZM_i1?l00002ok_OlP;o00001_o0gNh3o`0000Cod=[P00?o0000om3Dg?o@e=`00oo@e=`01ol0
003oclcFolo<e_o?c=Ko0000omK@dol000001oo<_</00ol0003oc[[6oljjaP05oljjaP03o`000?o;
//7o000000CobK7200Go0000ol:U_?o2YKco`ZFlo`000006okJL_@;o00001_ngWl000ol0003o/I_0
ok6K`002ok6K`003o`000?nbVl7o000000KoZIO400?o0000oj:CaOnRTlD00onRTlD00ol0003oUh_5
oiN;a@03oiN;a@03o`000?nAQlGoTHO500?oTHO500?o0000ohR2a_n8P/H00on8P/H00ol0003oN7W7
ogQia`03ogQia`03o`000?mjP/ooNX;?00;oNX;?00?o0000oh6<eOn1S=D00_n1S=D6o`0000;oPi;I
00Co0000oi2Mg?l0003oT9gL1?l00007ooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool09Oooool2o`0000;ooooo0_l00003ooooo`Oo00002Oooool00ol0003oooooooooo`04ooooo`;o
00001_ooool2o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`Co00000oooool3o`00
00;ooooo1Ol00002ooooo`03o`000?oooooooooo04Oooooo000Mooooo`03o`000?oooooooooo02oo
oooo00Co0000ojVmj?nY_NSoZKgX0ol00006ojVmj003o`000?nY_NSo000000;o000000CoZKgXo`00
0?n6WN;o00000onXQ:h2o`000004ojVmj?l0003o0000o`0000;oZKgX0_l000001_nLNJ_o0000o`00
0?nY_NSo0000ojVmj0?o0000??ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool00oooool2o`0000;oZM_i0ol00004oj_Ln0?o00001Oo0gNh2o`0000?o
`mWZ0_l000000oo@f^3o0000om3Dg004om3Dg003o`000?o?c=KoclcF00?oclcF00?o0000olblboo<
_</01Oo<_</00ol0003obkS8o`000005oljjaP05o`000?o;//7obk;1ol^b`Ol000000_o9/L800ol0
003o`ZFlol:U_003ol:U_003o`000?nfW;go]Ybm00;o]Ybm00?o0000okVO__l000001_ngWl000ol0
003o/I_0ok6K`002o`0000?o/Y_100?o0000ojVGa?nYUl@00onYUl@00ol0003oXY?5oj:Ca@03oj:C
a@03o`000?nGRlGoUh_500?oUh_500?o0000oi67aOnAQlD00onAQlD00ol0003oR8;6ohR2aP03ohR2
aP03o`000?mhNLOoN7W700?oN7W700?o0000ogZ2comjP/l00omjP/l00ol0003oPHcEoh6<e@03oh6<
e@04o`000?n9U][oRIKJohVFfPKo00000onDX=`00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool09?ooool01Ol0003ooooooooooooooooo000000?ooooo1ol0
000Booooo`;o00001Oooool3o`000004ooooool0003o0000o`0000;ooooo0_l00002ooooo`?o0000
00Coooooo`000?l0003ooooo1?l00002ooooo`Go00000_ooool00ol0003oooooooooo`16ooooo`00
7_ooool2o`00033ooooo0ol00003ojVmj003o`000?nY_NSoZKgX00?oZKgX0_l00004ojVmj003o`00
0?n6WN;o000000;oZ8B^1?l00006ojVmj003o`000?nLNJ_o000000Co0000@?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo02kooooo0_l00005ooooo`;o00001On[g?P2o`0000?o[]_g
0_l000000oo0gNko0000o`000006ol?IjP?o00001?o@e=`00ol0003oclcFolo<eP03olo<eP03o`00
0?o=`Loo000000Goc;c;00Go0000ol^hb?o;^<SobkS8o`000003oljjaP03o`000?o;//7obk;100;o
bk;100?o0000olVa`_l000001_o2YK`00ol0003o]YbmokJL_@02o`0000?o^Inn00?o0000okNO`?ng
Wl000ongWl000ol0003o/I_0o`000005ok:K`@03o`000?nYUlCoZIO400?oZIO400?o0000oj:CaOnR
TlD00onRTlD01?l0003oUh_5oiN;aOnGRlD7o`000003oi67aOl0003oR8;600CoR8;600?o0000ogQi
aomhNLL01?mhNLL00ol0003oNX;?ogZ2c`02ogZ2c`03o`000?n1S=GoPHcE00CoPHcE00?o0000ohVF
f_n9U]X00_n9U]X01Ol0003oU:3LoiBPg?nDX=co000000?oU:3L00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool2
o`000003ooooool0003o000000Go00003_ooool2o`000003ooooool0003o000000Oooooo1Ol00003
ooooo`?o00000_ooool6o`0000;ooooo0ol00004ooooo`;o0000Boooool0023ooooo00?o0000oooo
ooooool0;_ooool00ol0003oZKgXojVmj003ojVmj003o`000?nY_NSo000000;o00000_nY_NP00ol0
003oZKgXojVmj002ojVmj0;o00000_nXQ:h01Ol0003oZKgXojVmj?nY_NSo000000GoZKgX1?l00013
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`04
ooooo`?o000000?oZmcho`000?n^foL01On^foL3o`0000Go`mWZ0_l00003olCCiP;o000000?od=CL
o`000?o?c=H01?o?c=H01Ol0003ocL7?olg1coo=`Loo000000?oc;c;00?o0000ol^hb?o;^<P00oo;
^<P00ol0003oc[[6o`000006ol^b`@03o`000?o2YKco`ZFl00Go`ZFl00?o0000okJL_Ol000001Oni
Wkh00ol0003o]io0okNO`003okNO`0;o00001onbVl400ol0003oZIO4ojVGa003ojVGa003o`000?nR
TlGoXY?500Ko00000onFRL@01?l0003oT8S6oi28a_n@R<H=o`000003ogQiaol0003oNX;?00CoNX;?
00?o0000oh6<eOn1S=D00on1S=D00ol0003oRIKJohVFfP03ohVFfP04o`000?nDX=coU:3Lo`0000Co
U:3L00?o0000ooooooooool00oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Oo
oooo0_l00002ooooo`03o`000?oooooo000000Co000000?oooooo`000?l000002oooool3o`000003
ooooool0003ooooo00Oooooo1Ol00003ooooo`;o00000oooool2o`000003ooooool0003o000000;o
000000Coooooo`000?l0003o00001Oooool3o`0004Wooooo000Qooooo`03o`000?oooooooooo02ko
oooo00Co0000ojVmj?nY_NSoZKgX1?l00005ojVmj003o`000?nY_NSo000000?o000000?oZ8B^o`00
0?nY_NP01?nY_NP00ol0003oZKgXo`000002o`000003ooooool0003o000004Gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Kooooo0_l00004ojkK
m`;o00000on`f?@2o`000003ol?Ij_l0003o000000Koa=?V0_l00005olo<eP03o`000?o=`LoocL7?
00?ocL7?00?o0000olblbol000001oo;^<P00ol0003obk;1ol^b`@05ol^b`@03o`000?o2YKco`ZFl
00Ko`ZFl00?o0000okVO__niWkh01OniWkh01ol0003o]io0okNO`?ngWl3o0000okJP`_l000001onb
Vl400ol0003oZIO4ojVGa002ojVGa0Co00000onOSl<00ol0003oUXW4oiJ9a004oiJ9a003o`000?n@
R<KoT8S600;oT8S600?o0000ohR5bOn8QLT00on8QLT00ol0003oPhK>oh>6cP02oh>6cPKo000000?o
NX;?o`000?n1S=D01On1S=D00ol0003oRIKJohVFfP03ohVFfP04o`000?nDX=coU:3Lo`0000?oU:3L
00?o0000ooooooooool00oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo
0_l00002ooooo`05o`000?oooooo0000o`000?ooool00_l000001?oooooo0000o`000?l0000:oooo
o`?o000000?oooooo`000?ooool02?ooool2o`000004ooooool0003o0000o`0000?ooooo00?o0000
ooooool000000_ooool2o`000003ooooool0003o000000?ooooo00?o0000ooooool000001Oooool3
o`0004Sooooo000Rooooo`03o`000?oooooooooo02kooooo0ol00004ojVmj004o`000?nY_NSoZKgX
ojVmj0?o00000onY_NP4o`0000?oZKgX0ol00005ooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo0_l00000
0on^foOo0000ok3Hm005ok3Hm0?o00001_o4dnH01?l0003o`l_Pol?;h?l00003olo<eP03o`000?o=
`LoocL7?00CocL7?0_l00007ol^hb0;o00001_o;//400ol0003ob:foo`000006ol:U_0;o00001oni
Wkh01?l0003o]io0okNO`?l00003okJP`P03o`000?nbVl7o/Y_100Co/Y_100?o0000ojVGa?l00000
0_l000000onWU<;o0000oin?``05oin?``03o`000?nFRLCoUXW400?oUXW400?o0000oi28a_n@R<H0
0on@R<H00ol0003oR8G9ohR5b@03ohR5b@03o`000?n3Q/koPhK>00?oPhK>00Co0000oh><don3S=?o
PhcC1ol000000on1S=Go0000ohVFfP04ohVFfP04o`000?nDX=coU:3LoiBPg0Go00001?ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo02Cooooo0_l00003ooooo`05o`000?oooooooooo
o`000?ooool01_l0000<ooooo`Go00001?ooool01?l0003oooooooooooooool2o`000004ooooool0
003o0000o`0000;ooooo00?o0000ooooool000000_l00002ooooo`;o00000_ooool01ol0003ooooo
oooooooooooo0000ooooool000001oooool00ol0003oooooooooo`15ooooo`008oooool00ol0003o
ooooooooo`0^ooooo`03o`000?nY_NSoZKgX00?oZKgX1?l00003ojVmj006o`000?nY_NSoZKgXojVm
j?l0003oZKgX1?l0001?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`08ooooo`;o00001?n`f?@2o`0000?o/M7a00Co0000olCCi_o4dnKoa=?V0_l0
0004ol?;h003o`000?o?c=Ko000000KocL7?00?o0000olRkc_l000001_o;^<P01?l0003obKC5olVd
aOl00004ol^b`@05o`000?o8[Koob:foolR]_ol000001?o2YK`01?l0003o_Z>nokjS__l00006okVO
_P03o`000?ngWl3o000000Co]Z3200?o0000ok:K`OnbVl401?nbVl42o`0000GoYiC200?o0000oin?
`onOSl<00onOSl<00ol0003oUXW4oiJ9a003oiJ9a003o`000?n@R<KoT8S600?oT8S600?o0000ohR5
bOn8QLT00on8QLT00ol0003oPhK>oh>6cP03oh>6cP03o`000?n3S=?oPhcC00?oPhcC00?o0000ohNC
fOn7TmT00_n7TmT<o`0000?oUjCN00?o0000ooooooooool00_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04o`00
0003ooooool0003ooooo00_ooooo00?o0000ooooool000000_l00004ooooo`05o`000?oooooooooo
ooooool000000_ooool3o`0000;ooooo00?o0000ooooool000000ol000001?oooooo0000o`000?l0
0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`14ooooo`009?ooool2o`0002oooooo00?o0000ojVmj?l000000_l00002ojVmj003o`000?nY_NSo
ZKgX00?oZKgX00?o0000ojVmj?l000000_l0001Dooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0<oooool2o`0000[ooooo0_l000000on`f?Co0000ok7Al@05ok7Al@03o`000?o4dnKo
000000Ko`l_P0ol00005olg1c`05o`000?o8^lkob;_>olRkc_l000001?o;^<P00ol0003obKC5olVd
a@02olVda@04o`000?o;//7obk;1o`0000Cob:fo00Go0000ol:U_?o2YKco`ZFlo`000003okjS_P03
o`000?niWkko^Inn00Co^Inn0_l00006okJP`P03o`000?nbVl7o/Y_100;o/Y_100?o0000ok:L`Ol0
00001OnWU<800ol0003oWho3oin?``03oin?``03o`000?nFRLCoUXW400CoUXW400?o0000oi28a_n@
R<H00on@R<H00ol0003oR8G9ohR5b@03ohR5b@03o`000?n3Q/koPhK>00?oPhK>00?o0000oh><don3
S=<00on3S=<00ol0003oQi?IohNCf@03ohNCf@03o`000?n>W=coSYcL00?oSYcL00Go0000oiNTg_nG
Y=koUjCNo`000003oiNTgP05o`000?ooooooooooooooool00000>Oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00Gooooo0_l000000ooooooo0000o`000004o`0000cooooo00?o0000
ooooool000000ol00003ooooo`;o00000oooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
00000ooooooo0000o`000003ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo04_ooooo000Vooooo`03o`000?oooooooooo02gooooo00?o0000ojVmj?nY_NP01?nY_NP0
1?l0003oZKgXojVmj?nY_NP3o`0005Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00Wooooo0_l00006ok7Al@?o00001?o3bn02o`0000?o`/;J00Go
0000olg1coo=`LoocL7?o`000005olRkcP04o`000?o;^<SobkS8o`0000GobKC500?o0000ol^b`Ol0
00001_o8[Kl00ol0003o`ZFlo`000005okjS_P03o`000?niWkko^Inn00;o^Inn00?o0000ok^S`Ol0
00001_nfX<800ol0003o/Y_1ok:K`@02o`0000?o/Yc100?o0000ojND`_nWU<800_nWU<800ol0003o
Who3oin?``04oin?``03o`000?nFRLCoUXW400?oUXW400?o0000oi28a_n@R<H00on@R<H00ol0003o
R8G9ohR5b@03ohR5b@03o`000?n3Q/koPhK>00?oPhK>00?o0000oh><don3S=<00on3S=<00ol0003o
Qi?IohNCf@04ohNCf@03o`000?n>W=coSYcL00?oSYcL00Go0000oiNTg_nGY=koUjCNo`000002oiNT
gP05o`000?ooooooooooooooool00000>Oooool00ol0003oooooooooo`0Yooooo`?o000000?ooooo
o`000?l000000ol0000<ooooo`03o`000?oooooo000000;ooooo0_l00004ooooo`05o`000?oooooo
ooooooooool000000oooool3o`000004ooooool0003o0000ooooo`?o00000_ooool00ol0003ooooo
o`000003ooooo`03o`000?oooooooooo053ooooo000Wooooo`03o`000?oooooooooo02gooooo00?o
0000ojVmj?nY_NP00onY_NP4o`0005cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00[ooooo0_l000001?nadO7o0000o`000?l00003ok79k0;o0000
00?o`l_Po`000?o2`]X01Oo2`]X00ol0003ocL7?o`000006olRkcP03o`000?o;^<So000000KobKC5
0_l00008olR]_`03o`000?nnXkko_Z>n00Co_Z>n00?o0000okVO__niWkh00_l00003ok^S`@03o`00
0?nfX<;o]Z3200?o]Z3200?o0000ok:K`Ol000001OnbW<400ol0003oYiC2ojND`P03ojND`P03o`00
0?nOSl?oWho300?oWho300?o0000oiJ9a?nFRL@00onFRL@00ol0003oT8S6oi28aP03oi28aP03o`00
0?n8QLWoR8G900?oR8G900?o0000oh>6c_n3Q/h00on3Q/h00ol0003oPhcCoh><d`04oh><d`03o`00
0?n7TmWoQi?I00?oQi?I00?o0000ohjLg?n>W=`01?n>W=`01ol0003oUjCNoiNTg_nGY=ko0000oiNT
g_l000001?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02[ooooo00Go0000oooo
ool0003o0000ooooo`03o`00013ooooo0_l000001Ooooooo0000oooooooooooo000000?ooooo0_l0
0003ooooo`?o000000?oooooo`000?l000000_ooool3o`0000;ooooo0_l0001Fooooo`00:?ooool0
0ol0003oooooooooo`0]ooooo`03o`000?nY_NSo000000;o0000H?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02oooool00ol0003o/LW/ok79k005
ok79k0;o00001oo2`]X2o`0000Oob;_>0_l00006olVda@03o`000?o6/<Go000000Oob:fo0_l00006
okjS_P03o`000?niWkko000000Go^j?100?o0000okJP`_nfX<800onfX<82o`0000Ko/Yc100?o0000
ojND`_nWU<800onWU<800ol0003oWho3oin?``03oin?``04o`000?nFRLCoUXW4oiJ9a1?o00000_n3
Q/h00ol0003oPhcCoh><d`03oh><d`03o`000?n7TmWoQi?I00?oQi?I00?o0000ohjLg?n>W=`01?n>
W=`01?l0003oUjCNoiNTg_nGY=h4o`0000?ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Yooooo`04o`000?oooooo0000ooooo`;o000000?oooooo`000?ooool04?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooooooo`;o00000oooool2o`0000?ooooo00Co0000
oooooooooooooooo0ol00002ooooo`;o0000EOooool002Wooooo0_l0000^ooooo`03o`000?oooooo
oooo06;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0gooooo`;o00003?ooool0
0ol0003o/LW/ok79k002ok79k0;o000000?o/L7Vo`000?o2`]X01Oo2`]X00ol0003o_[_Go`000006
olRkcP03o`000?o4]/go000000GobKC500Go0000olJ`aOo6/<Goa[35o`000005olR]_`04o`000?o2
Z/7o`Z[1o`0000Ko_Z>n00?o0000ok^S`OnkXl401OnkXl400ol0003o]Z32okJP`P02o`000003ok:M
`_l0003o/Yc100Ko/Yc100?o0000ojND`_nWU<800_nWU<801?l0003oWho3oin?`onOSl<6o`0000?o
VI?<00?o0000oi>AconCTLl00onCTLl00ol0003oSI3Bohf@dP03ohf@dP04o`000?n9T]KoRI;FohVB
eQWo000000CoVJWRo`000?nIZN;o00000oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo02Sooooo00Oo0000ooooooooooooooooo`000?oooooo000001;ooooo0_l000000ooooooo0000
o`000002ooooo`03o`000?oooooooooo00Co00000_ooool01?l0003oooooo`000?ooool2o`0000?o
oooo0ol00004ooooo`03o`000?oooooooooo05;ooooo000[ooooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool0Hoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool02_ooool01?l0003o/LW/o`000?l00004ok71iP04o`000?o2`][o`/;Jol;2
fP;o00000onn^mL01?l0003ob;_>olRkc_o8^lh2o`0000?oa;K=00Go0000olVdaOo9]<GobKC5o`00
0004olJ`a@03o`000?o8[Koob:fo00;ob:fo00Go0000ol:Z`Oo2Z/7o`Z[1o`000005okjS_P;o0000
1onkXl400ol0003o]Z32o`000004ok:M`P03o`000?nbW<7o/Yc100Co/Yc100?o0000ojND`_nWU<80
0_nWU<84o`0000?oWYC900?o0000oiVCc?nITl`01?nITl`00ol0003oTi7?oi>Ac`03oi>Ac`03o`00
0?n=T=;oSI3B00?oSI3B00?o0000ohVBe_n9T]H00_n9T]H00ol0003oRIKJohVFfP04ohVFfP03o`00
0?n<W=goS9cM00?oS9cM00?o0000oi:Sh?nBXn001?nBXn000ol0003oVJWRoiVYhP02oiVYhP03o`00
0?nIZN;o000000;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`07o`00
0?ooooooooooooooool0003oooooo`00000Dooooo`?o00000_ooool2o`000003ooooool0003o0000
00?o00000_ooool3o`000004ooooool0003oooooo`0000?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Aooooo`00;?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
06Cooooo00Go0000ooooooooooooooooo`00000looooo`03o`000?oooooooooo00[ooooo0_l00006
ok71iP03o`000?o2`][o000000Ko_[_G00?o0000olRkc_l000001_o4]/d00ol0003obKC5o`000006
olJ`a@04o`000?o8[Koob:foo`0000Go`Z[100Go0000okjS__nnXkko_Z>no`000002okjW`P03o`00
0?nkXl7o^j?100Co^j?10_l00005ok:M`P03o`000?nbW<7o/Yc100Co/Yc100?o0000ojND`_l00000
0_l000000onYV/Oo0000oijDb@05oijDb@03o`000?nITlcoVI?<00?oVI?<00?o0000oi>AconCTLl0
0onCTLl00ol0003oSI3Bohf@dP03ohf@dP03o`000?n9T]KoRI;F00?oRI;F00?o0000ohVFf_n9U]X0
1?n9U]X00ol0003oS9cMohbLg@03ohbLg@03o`000?nBXn3oTZ?P00CoTZ?P00?o0000oiVYh_nIZN80
0_nIZN801Ol0003oVJWRo`000?oooooo000003Sooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00Go0000ooooool0003o0000ooooo`02o`00
00?ooooo0ol00003ooooo`?o000000Coooooo`000?l0003o00001?ooool00ol0003oooooooooo`1G
ooooo`00;Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06Cooooo00Go0000oooo
ooooooooooooo`00000mooooo`03o`000?oooooooooo00_ooooo00?o0000ok71i_na`NH00ona`NH2
o`0000Oo_[_G0_l00008olBfc@03o`000?o6/<Goa[3500Goa[3500?o0000olR]_ol000001_o2Z/40
1?l0003o_Z>nokjS__l00003okjW`P03o`000?nkXl7o^j?100?o^j?100?o0000okbV`ol000001_nb
WL800ol0003o/Yc1ok:L`@03ok:L`@;o00001OnYV/L00ol0003oWYC9oijDb@03oijDb@03o`000?nI
TlcoVI?<00CoVI?<00?o0000oi>AconCTLl00onCTLl00ol0003oSI3Bohf@dP03ohf@dP03o`000?n9
T]KoRI;F00?oRI;F00?o0000ohVFf_n9U]X00on9U]X00ol0003oS9cMohbLg@04ohbLg@03o`000?nB
Xn3oTZ?P00?oTZ?P00?o0000oiVYh_nIZN800_nIZN85o`0003Sooooo00?o0000ooooooooool0@_oo
ool01_l0003oooooooooool0003oooooo`0000?ooooo0ol000001ooooooo0000ooooool0003ooooo
o`000?ooool00ol00004ooooo`03o`000?oooooooooo05Oooooo000^ooooo`;o0000:Oooool00ol0
003oooooooooo`1Uooooo`04o`000?ooooooooooo`0003kooooo0_l0000<ooooo`03o`000?na`NKo
000000;o00000_n_^N400ol0003o_[_Gokjke`03okjke`03o`000?nk]]Go000000Ooa;K=0_l00007
olJ`a@;o00001oo2Z/400ol0003o_Z>no`000005okjW`P05o`000?nkXl7o^j?1ok^S`Ol000000onl
Y/<00ol0003o/Yg2ok:M`P03ok:M`P04o`000?nbW<7o/Yc1ok:L`@;o000000?o/J77o`000?nYV/L0
1?nYV/L00ol0003oWYC9oijDb@04oijDb@03o`000?nITlcoVI?<00?oVI?<00?o0000oi>AconCTLl0
0onCTLl00ol0003oSI3Bohf@dP03ohf@dP03o`000?n9T]KoRI;F00?oRI;F00?o0000ohVFf_n9U]X0
0on9U]X00ol0003oS9cMohbLg@04ohbLg@04o`000?nBXn3oTZ?Poi:Sh0Oo000000?oV[3Vo`000?nJ
/>H00_l0000hooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool00_l00003ooooo`Co
000000Goooooo`000?ooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0E_ooool0033ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Vooooo`03
o`000?oooooo0000043ooooo00?o0000ooooooooool02_ooool00ol0003o[kWQojnih@04ojnih@05
o`000?nn^mOo_[_Gokjkeol000000onk]]D00ol0003oa;K=olBfc@03olBfc@04o`000?o0//co`;;<
o`0000Goa[3500?o0000ol:^aol000001oo2Z/42o`0000Ko_ZO200Co0000ok^S`OnkXl7o00001?nl
Y/<00ol0003o/Yg2ok:M`P03ok:M`P04o`000?nbW<7o0000o`0000Co/J7700?o0000ojVJaonYV/L0
0onYV/L00ol0003oWYC9oijDb@03oijDb@04o`000?nITlcoVI?<oiVCc2Go00000onDZnH00ol0003o
V[3VoiZ`iP03oiZ`iP03o`000?nJ/>Ko000003Sooooo00?o0000ooooooooool0@Oooool01_l0003o
ooooooooool0003oooooo`0000?ooooo1ol000000ooooooo0000ooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0EOooool0037ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`1Vooooo`03o`000?oooooo0000047ooooo00?o0000ooooooooool02Oooool00ol0
003o[kWQojnih@05ojnih@03o`000?nn^mOo000000Go^kKE00Go0000olBfcOo4]/goa;K=o`000004
ol2bc003o`000?o6/<Goa[3500;o00000oo2[/L00ol0003o`Z[1ol:Z`@03ol:Z`@03o`000?noZlKo
000000Ko_ZO200?o0000ok^S`Ol000001_nlY/<00ol0003o/Yg2ok:M`P02ok:M`P;o00001_naXLL0
0ol0003oZI[7ojVJa`03ojVJa`04o`000?nNU<WoWYC9oijDb@Ko00000onKWmL00ol0003oUIkIoiFN
f@03oiFNf@03o`000?n@WMcoT9gL00?oT9gL00?o0000ohfNgon=W]l00on=W]l00ol0003oS:7RohbQ
hP03ohbQhP03o`000?n?YNCoSjGT00CoSjGT00?o0000oiB[i_nDZnH01?nDZnH00ol0003oV[3VoiZ`
iP02oiZ`iP04o`000?nJ/>Ko0000o`0003Oooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`03ooooo`;o000000?oooooo`000?l000000oooool6o`000003ooooool0003o000000?ooooo
00?o0000ooooooooool0G?ooool003;ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooo0000047ooooo00?o0000ooooooooool02Oooool00ol0003o[kWQojni
h@04ojnih@;o00001onk]]D00ol0003oa;K=o`000005ol2bc003o`000?o6/<Go000000Ko`Zk700?o
0000ol:Z`Oo2Z/400_l00003okn[aP03o`000?nnYl;o_ZO200?o_ZO20_l00007okbV``03o`000?nb
WL;o/Yg200;o000000?o]:C8o`000?naXLL01_naXLL00ol0003oZI[7ojVJa`02ojVJa`Co00000onR
X]@00ol0003oVioGoi^Oe`04oi^Oe`03o`000?nEW]WoUIkI00?oUIkI00?o0000oi2Mg?n@WM`00on@
WM`00ol0003oSIkOohfNg`03ohfNg`03o`000?n<XN;oS:7R00?oS:7R00?o0000ohnUi?n?YN@01?n?
YN@00ol0003oU:_VoiB[iP04oiB[iP04o`000?nJ/>KoV[3VoiZ`iPCo00007_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01?ooool00ol0
003oooooooooo`0looooo`;o00001_ooool4o`0000;ooooo00?o0000ooooool000000_ooool6o`00
00;ooooo00?o0000ooooooooool0G?ooool003?ooooo0_l0000Tooooo`03o`000?oooooooooo06So
oooo0_l00012ooooo`;o00002_ooool00ol0003o[kWQojnih@03o`000003ojfcgOl0003o^kKE00Ko
^kKE0_l00006ol2bc0;o00001oo2[/L00ol0003o`Z[1o`000005okn[aP03o`000?nnYl;o_ZO200;o
_ZO200?o0000okfZa_l000001onlY/<00ol0003o/Yg2o`000004okBTb003o`000?naXLOo/J7700Co
/J7700?o0000ojVJaol000000_l000000onZY]?o0000oj:Re005oj:Re003o`000?nKWmOoVioG00Co
VioG00?o0000oiFNfOnEW]T00onEW]T00ol0003oT9gLoi2Mg003oi2Mg003o`000?n=W]ooSIkO00?o
SIkO00?o0000ohbQh_n<XN800on<XN800ol0003oSjGTohnUi003ohnUi003o`000?nDZnKoU:_V00;o
U:_V1_l00002ooooo`;o00007_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B401?ooool00ol0003oooooooooo`0kooooo`;o00001_ooool5
o`0000;ooooo00?o0000ooooool000000oooool2o`000003ooooool0003ooooo00?ooooo00?o0000
ooooooooool0Foooool003Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Xoooo
o`?o0000A?ooool00ol0003oooooooooo`08ooooo`;o00001On]/md00ol0003o^kKEok^fe@02ok^f
e@;o000000?o^;;Co`000?o0//`01?o0//`00ol0003o_K3=o`000007ol:^a`;o00001onoZlH01?l0
003o_ZO2okjW`_l00003okfZaP03o`000?nlY/?o_:K300Co_:K30_l00005okBTb003o`000?naXLOo
/J7700Co/J770_l00005ojZVd`03o`000?nRX]CoXZ;D00CoXZ;D00?o0000oi^OeonKWmL00onKWmL0
0ol0003oUIkIoiFNf@03oiFNf@04o`000?n@WMcoT9gLoi2Mg1Wo00001oooool3o`0001kooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001?ooool2o`0003co
oooo0_l00006ooooo`03o`000?oooooo000000;o00000_ooool00ol0003oooooo`000003ooooo`04
o`000?ooooooooooo`0006;ooooo000fooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0I?ooool4o`0004Sooooo00?o0000ooooooooool02?ooool00ol0003o[K?Mojfcg@04ojfcg@04
o`000?nk]]Go0000o`0000Co^;;C00Go0000ol2bc?o0//co`;;<o`000003okf`c@03o`000?o2[/Oo
`Zk700?o`Zk700?o0000okj^bol000001onoZlH00ol0003o_ZO2o`000004okfZaP03o`000?nlY/?o
_:K300?o_:K300?o0000okZ[b_l000001_ndY<P01?l0003o/J77ok6QaonaXLL2o`000003ok6[d_l0
003oZZKC00GoZZKC00?o0000oj:Re?nRX]@00onRX]@01?l0003oVioGoi^OeonKWmL<o`0001cooooo
1?l0000Qooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b
00Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`05ooooo`;o000000?oooooo`00
0?ooool00_ooool00ol0003oooooooooo`03ooooo`;o000000?oooooo`000?ooool0HOooool003Oo
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Pooooo`Co0000COooool00ol0003o
ooooooooo`08ooooo`03o`000?n]/mgo[K?M00?o[K?M0_l00007okRbd`03o`000?o0//co000000Go
_K3=00Go0000ol:^aoo2[/Oo`Zk7o`000003okj^b`03o`000?noZlKo_j_600Co_j_60_l00006okfZ
aP03o`000?nlY/?o_:K300;o00000onjZlX00ol0003o]:C8okBTb003okBTb004o`000?naXLOo0000
o`0000Co/J_B00?o0000ojZVdonZY]<00onZY]<01?l0003oXZ;Doj:Re?nRX]@6o`0002Cooooo1?l0
000Uooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Co
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooo0000oooo
ool000002Oooool2o`0000;ooooo00?o0000ooooooooool0Goooool003Sooooo0_l0000Nooooo`03
o`000?oooooooooo05cooooo1?l0001Booooo`;o00002Oooool00ol0003o[K?Mo`000002o`000003
ojb_f_l0003o^;;C00Ko^;;C0_l00007okf`c@03o`000?o2[/Oo000000Co_Zk;00?o0000okn[a_no
ZlH00onoZlH00ol0003o_Jk;o`000006okfZaP03o`000?nlY/?o000000Go^Z_:00?o0000okBTb?nd
Y<P00ondY<P2o`0000Ko/J_B00?o0000ojZVdonZY]<00onZY]<4o`0002Kooooo1?l0000Yooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Cooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000[ooooo00Co0000
oooooooooooo0000HOooool003[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1H
ooooo`Co0000F?ooool00ol0003oooooooooo`07ooooo`03o`000?n/[m[o[:oJ00?o[:oJ00?o0000
okRbdonh/]<00_nh/]<2o`000003okF`e?l0003o_K3=00Ko_K3=0_l00006okj^b`03o`000?noZlKo
_j_600;o00000onm[//00ol0003o_J[6okfZaP03okfZaP;o00001onjZlX00ol0003o]:C8okBTb002
o`000003okF^d_l0003o/J_B00Go/J_B00?o0000ojZVdonZY]<00ol0000Vooooo`Co0000;Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000004ooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooool000002oooool00ol0003oooooooooo`1Rooooo`00>ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Cooooo1?l0001Mooooo`03o`000?oo
oooooooo00Kooooo00?o0000ojb_f_n/[mX01?n/[mX01?l0003o^;;Co`000?l00004okF`e003o`00
0?nm/<go_K3=00?o_K3=00?o0000okZ`d?l000001_nn[//00ol0003o_j_6o`000006okf^b`03o`00
0?nmZ/Ko_J[600;o000000?o^jo=o`000?njZlX01_njZlX00ol0003o]:C8o`000004okF^dP03o`00
0?naZm;o/J_B00?o/J_B0ol0000Vooooo`?o0000<Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@04ooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool0K_ooool003cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1@ooooo`Co
0000H_ooool00ol0003oooooooooo`06ooooo`03o`000?n/[m[o[:oJ00?o[:oJ0_l00007okF`e003
o`000?nm/<go_K3=00;o00000onj/=000ol0003o_Zk;okj^b`03okj^b`;o00001onm[//00ol0003o
_J[6o`000004ok^_c@03o`000?njZl[o^Z_:00Co^Z_:0_l00006okF^dP03o`000?naZm;o000000;o
00009Oooool4o`0004gooooo00?o0000ooooooooool0]_ooool003gooooo0_l0000Iooooo`03o`00
0?oooooooooo04gooooo0ol0001Wooooo`;o00001oooool00ol0003o[:oJo`000002o`0000;oZjkJ
00?o0000okF`e?ne/=@01?ne/=@00ol0003o_K3=o`000006okZ`d003o`000?nn[/_o_Zk;00;o0000
00?o^k3?o`000?nm[//01_nm[//2o`0000Ko^jo=00Co0000okZ[b_njZl[o^Z_:0_l000000oni/]?o
0000okF^dP05okF^dP;o00009?ooool4o`00057ooooo00?o0000ooooooooool0]_ooool003oooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`19ooooo`Co0000K?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?n[[][oZjkJ00CoZjkJ00?o0000okF`e?ne/=@00one/=@2o`0000Oo^[3@
00?o0000okj^bol000001?nk/<l00ol0003o_Jk;okf^b`03okf^b`03o`000?nk/]3o000000Ko^jo=
00Co0000okZ[b_l0003o00001?ni/]<01?l0003o]JkBokF^d_ne[]82o`0002;ooooo1?l0001Eoooo
o`03o`000?oooooooooo0;Kooooo0010ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0AOooool4o`00077ooooo00?o0000ooooooooool01?ooool00ol0003oZjkJoj^^fP05oj^^fP03
o`000?ne/=Co000000;o000000?o/k3Eo`000?nj/=001_nj/=02o`0000Ko^k3?00?o0000okf^bonm
[//00_l00003ok^bd003o`000?nk[lgo^jo=00?o^jo=0_l00006okVbd`04o`000?ne[];o0000o`00
023ooooo1?l0001Iooooo`03o`000?oooooooooo0;Kooooo0011ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0@Oooool4o`0007Kooooo00?o0000ooooooooool01?ooool00ol0003o
ZjkJoj^^fP04oj^^fP;o00001Onc/=D00ol0003o^[3@okZ`d002okZ`d0;o000000?o^;;Co`000?nk
/<l01Onk/<l00ol0003o_Jk;o`000006ok^bd003o`000?nk[lgo^jo=00;o000000?o^kKDo`000?ni
/]<01Oni/]<2o`0001kooooo1?l0001Mooooo`03o`000?oooooooooo0;Kooooo0012ooooo`;o0000
5?ooool00ol0003oooooooooo`0mooooo`Co0000Noooool2o`0000Gooooo00?o0000oj^^f_n[[]X0
0ol000000onZ[][o0000ok>`e@05ok>`e@04o`000?nj/=3o0000o`0000Co^;;C00?o0000ok^`conk
/<l00onk/<l2o`0000Oo^k;@00?o0000ok^_cOl000001?nk]]@01?l0003o^K;CokVbdoni/]<2o`00
01cooooo1?l0001Qooooo`03o`000?oooooooooo0;Kooooo0014ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0>Oooool4o`00087ooooo00?o0000ooooooooool00oooool2o`0000Go
ZZkJ00?o0000ok>`eOnc/=D00onc/=D2o`0000Oo^;;C00?o0000ok^`conk/<l00_l000000onj]=Co
0000ok^bd006ok^bd0;o00001_nk]]@00ol0003o^K;Co`00000Jooooo`Co0000IOooool00ol0003o
ooooooooo`2fooooo`00AOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Gooooo
1?l00026ooooo`03o`000?oooooooooo00?ooooo00?o0000ojZ^f_nZ[]X01?nZ[]X00ol0003o/k3E
ok>`e@02o`000003ok:bf?l0003o^;;C00Ko^;;C00?o0000ok^`col000001?nj]=@00ol0003o^k;@
ok^bd002ok^bd0;o000000?o^kSGo`000?nk]]@01Onk]]@2o`0001Oooooo1?l0001Yooooo`03o`00
0?oooooooooo0;Kooooo0016ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<Ooo
ool4o`0008_ooooo00?o0000ooooooooool00oooool00ol0003oZZkJojZ^fP03ojZ^fP03o`000?nc
/=Go000000Co/[;H00?o0000okRbdonh/]<01?nh/]<2o`0000Ko^[CD00Co0000ok^bd?l0003o0000
1?nk^=L01?l0003o^kKDok^fe?nk]]@2o`0001Kooooo0ol0001]ooooo`03o`000?oooooooooo0;Ko
oooo0017ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0;Oooool4o`00093ooooo
00?o0000ooooooooool00oooool01?l0003oZZkJojZ^f_nZ[]X3o`0000Ko/[;H00?o0000okRbdonh
/]<00ol000000onf]MSo0000okZde005okZde0;o00001onk^=L00ol0003o^kKDo`00000Dooooo`Co
0000L?ooool00ol0003oooooooooo`2fooooo`00B?ooool2o`0000kooooo00?o0000ooooooooool0
:Oooool4o`0009Gooooo0_l00004ooooo`?o00000_nY/=`00ol0003o/[;Hok:bf004ok:bf0?o0000
1Onf]MP01?l0003o^[CDokZde?nj]=@2o`000003okVjf_l0003o^kSG00Ko^kSG0_l0000Aooooo`Co
0000M?ooool00ol0003oooooooooo`2fooooo`00B_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo02Gooooo1?l0002Kooooo`05o`000?ooooooooooooooool000001OnY/=`01?l0003o
/[;Hok:bf?nb/]P2o`000003ok6eg?l0003o][GH00Ko][GH00?o0000okZde?l000001?ni^]X00ol0
003o^kSGok^he`02ok^he`;o00003oooool4o`0007Sooooo00?o0000ooooooooool0]_ooool004_o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`Co0000X?ooool01Ol0003o
oooooooooooooooo000000GoZK3L00?o0000ok:bf?l000001?na]M`00ol0003o][GHokJef004okJe
f0;o00001_ni^]X01?l0003o^kSGo`000?l0000=ooooo`Co0000O?ooool00ol0003oooooooooo`2f
ooooo`00C?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo1?l0002Uoooo
o`05o`000?ooooooooooooooool000000onY/=`3o`0000Ko/KGL00?o0000okJef?nf]MP00ol00002
okFjg@03o`000?ni^][o^K[J00?o^K[J0_l0000;ooooo`Co0000P?ooool00ol0003oooooooooo`2f
ooooo`00COooool2o`0000Sooooo00?o0000ooooooooool06_ooool4o`000:[ooooo0_l00002oooo
o`?o00000onY/ml00ol0003o/KGLok6eg003ok6eg0?o00001_ne^]d00ol0003o^K[Jo`000002o`00
00Wooooo1?l00024ooooo`03o`000?oooooooooo0;Kooooo001?ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05oooool3o`000;3ooooo00?o0000ooooool000001_nY/ml00ol0003o
/KGLo`000002o`000003ok2jhOl0003o]K[M00Ko]K[M0_l00008ooooo`Co0000R?ooool00ol0003o
ooooooooo`2fooooo`00D?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo
1?l0002dooooo`03o`000?oooooo000000GoZK?O0_l00005ok2jh@03o`000?ne^]go]K[M00;o]K[M
0_l00006ooooo`Co0000S?ooool00ol0003oooooooooo`2fooooo`00DOooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00oooooo1?l0002iooooo`04o`000?oooooo0000ojVcg`?o0000
0_nY^>@00ol0003o/;[Qok2jh@03ok2jh@04o`000?ne^]go0000o`0000Gooooo0ol0002@ooooo`03
o`000?oooooooooo0;Kooooo001Booooo`;o00000oooool00ol0003oooooooooo`0;ooooo`Co0000
__ooool3o`0000KoZKST00Co0000ok2jhOn`^^7o/;[Q0ol00003ooooo`Co0000Toooool00ol0003o
ooooooooo`2fooooo`00E?ooool01?l0003oooooooooool00009ooooo`Co0000a?ooool2o`0000Go
ZKST1?l00002ooooo`Co0000Uoooool00ol0003oooooooooo`2fooooo`00EOooool00ol0003ooooo
o`000005ooooo`Co0000bOooool2o`000004ojVhi?l0003o0000o`0000;ooooo1?l0002Kooooo`03
o`000?oooooooooo0;Kooooo001Fooooo`;o000000?oooooo`000?l000000_l0003>ooooo`;o0000
00?oooooo`000?l000000_l0002Oooooo`03o`000?oooooooooo0;Kooooo001Gooooo`;o0000dooo
ool2o`0009_ooooo1?l000001Ol@413ooooooooooooooooo00000;Sooooo003oooooolcooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`2fooooo`00ooooooo<ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0]_ooool00?ooooooc?ooool00ol0003oooooooooo`03oooo
o`;o0000]oooool006kooooo0_l0003ooooooecooooo00?o0000ooooooooool0_?ooool0073ooooo
00?o0000ooooooooool0d?ooool2o`0008Kooooo00?o0000ooooooooool0_?ooool005oooooo00?o
0000omgMgOooool01_ooool3o`0000Gooooo00?o0000ooooooooool0a?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0_?ooool005oooooo00?o<S8b
okZj^_ooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0<Cooooo00?o410@
omgMgOooool00_ooool3o`0000Kooooo00?o0000ooooooooool0POooool00omEEEGoIVIVo`00002n
ooooo`00Goooool01_mgMgOoQhN7odA4A?l0003o410@ohN7Q`Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`32ooooo`05olc<c?l@413o0000o`000?n7QhL00oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo08Gooooo0ol000000ol@413oooooooooo`2gooooo`00Gooo
ool01onYZJWo0000okZj^_oooooogMgMob4Q8On7QhL00_ooool2o`0000Cooooo0ol00034ooooo`06
ob4Q8On7QhOo<S8bojVYZOm4A4CoQhN70_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo08Oooooo00?o410@okZj^_ooool0^?ooool005oooooo00?ogMgMoa0@4?ooool00_ooool00ooM
gMgo410@ooooo`3>ooooo`07o`000?ooooooIVIVohN7QooMgMgo410@ooooo`02o`0000Gooooo0ol0
0029ooooo`03oiRHV?lb<S;ooooo0;Sooooo001Pooooo`03oa0@4?oMgMgooooo00;ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0<;ooooo00Ko410@omgMgOmgMgOoMgMg
ooooool0002Dooooo`03omgMgOl0003o^[Zj0;Sooooo001Pooooo`06ohN7QolQ8B7ogMgMoooooomg
MgOo<S8bcoooool01_nYZJWoA4A4oiRHV?m4A4CoV9RHoa0@40;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`27ooooo`03oeEEEOmgMgOoA4A40;Sooooo001Qooooo`05ogMgMol0003o
0000oc8b<_o<c<`0d?ooool01OnHV9So0000o`000?l@413oc<c<09?ooooo00GogMgMoa0@4?oooooo
8B4QomgMg@2gooooo`00oooooolhooooo`03okZj^_lb<S;ooooo09Cooooo00GoIVIVohN7Qooooooo
V9RHoeEEE@2gooooo`00ooooooliooooo`03o`000?oooooooooo09;ooooo00?ok^k^o`000?o^k^h0
0_ooool00ol0003ogMgMooooo`2eooooo`00ooooooo>ooooo`04oa0@4?l0003o0000ooooo`;o0000
00?o410@ooooooooool0]?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003ooooo
ooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?oo
ool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooo
oooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<oooo
o`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<ooooo`00oooooooo
ooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo
003oooooooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003ooooooooo
ooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool0
0?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooo
oon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<ooooo`00
ooooooooooooohcooooo003ooooooa7ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?l@413oc<c<00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<01?ooooo1?l000000ol@413oooooooooo`3`ooooo`00oooo
oolAooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool02Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B402Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B405Oooool00ol0003oooooooooo`3booooo`00oooooolAooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0:ooooo`05oa0@4?oooooooooooooo
ool@41002oooool5o`0000[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000002Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooo
ooooo`00000Eooooo`03o`000?oooooooooo0?;ooooo003ooooooa7ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00Go0000ooooooooooooooooo`00000;oooo
o`04odA4A?oMgMgoooooo`0000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B402Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P0Eooooo`03o`000?oooooooooo0?;ooooo003ooooooa7ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Sooooo00Go0000ooooooooooooooooo`00000;
ooooo`04omgMgOmEEEGoooooo`0000_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`02Oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`00
0?l0003o0000olc<c00Eooooo`03o`000?oooooooooo0?;ooooo003ooooooa7ooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03ogMgMoo<c<co000000_ooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEE
EOn7QhOooooo00_ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj
^_l@41005Oooool00ol0003oooooooooo`3booooo`00oooooolAooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03onk^k_m4A4Co000000_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgM
gOl@413oV9RH00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj
^_l000005Oooool00ol0003oooooooooo`3booooo`00oooooolAooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<
c?m4A4Co0000oa0@40Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT04oooool00omEEEGoIVIVo`00003dooooo`00oooooonMooooo`;o00000_ooool2o`00
0>Sooooo003ooooooigooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMgXooooo`00oooooonNoooo
o`04omgMgOl0003o410@olc<c>Wooooo003loooooi[o00001oooool01?o^k^ko8B4Qoa0@4?o^k^kY
ooooo`00o?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool01Oooool01?lQ8B7oMgMgogMgMolb<S;Yooooo`00o?ooool00ol0003oooooooooo`2Moooo
o`;o00000_ooool2o`000>Sooooo003looooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo
00?o0000ooooooooool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3oooooohcooooo003l
ooooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo0_l0003oooooohgooooo003looooo`03
o`000?oooooooooo0?ooooooS?ooool00?cooooo00?o0000ooooooooool0oooooon<ooooo`00o?oo
ool00ol0003oooooooooo`3oooooohcooooo003looooo`03o`000?oooooooooo0?ooooooS?ooool0
0?cooooo00?o0000ooooooooool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3oooooohco
oooo003looooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo0_l0003oooooohgooooo003l
ooooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo00?o0000ooooooooool0oooooon<oooo
o`00o?ooool00ol0003oooooooooo`3oooooohcooooo003looooo`03o`000?oooooooooo0?oooooo
S?ooool00?cooooo00?o0000ooooooooool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3o
ooooohcooooo003looooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo0_l0003oooooohgo
oooo003looooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0oooooom3ooooo`00o?oo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo0?oooooo?_ooool00?cooooo00?o0000
ooooooooool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3oooooohcooooo003Sooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool0oooooom1ooooo`00hoooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01?ooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0oooooolcooooo`00hoooool01Ol@
413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01Oooool2o`0003Wooooo00?o0000
ooooooooool0oooooomAooooo`00hoooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h01?ooool00ol0003oooooooooo`0_ooooo`04o`000?ooooooooooo`000?ooooooFOoo
ool00>?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00?o
0000ooooooooool0oooooon<ooooo`00hoooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`3oooooohcooooo003Sooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo8oooool00>?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3ooooood7ooooo003looooo`03o`000?oooooooooo02kooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooo`000?oooooo<?ooool00?cooooo
00?o0000ooooooooool0oooooon<ooooo`00o?ooool2o`00067ooooo00Co0000oooooooooooo0000
oooooolXooooo`00o?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0ooooooldooooo`00o?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo0?ooooooC_ooool00?cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0>oooo
o`04o`000?ooooooooooo`000?ooooooBoooool00?cooooo00?o0000ooooooooool0F?ooool00ol0
003oooooooooo`3ooooooc7ooooo003looooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo00000?oooooo:_ooool00?cooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooolSooooo`00o?ooool2o`00033ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`3ooooooc_ooooo003looooo`03o`000?oooooooooo04oooooo00?o0000
ooooooooool0ooooooljooooo`00o?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
01oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0?oooooo9_ooool0
0?cooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`3oooooockooooo003looooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool0oooooolXooooo`00o?ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0oooooolHooooo`00o?oo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo0?oooooo?Oooool00?cooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0Fooooo`;o00003?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo0?oooooo5Oooool00?cooooo0_l00015ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3ooooooa7ooooo003looooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo0?oooooo<_ooool00?cooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0oooooolPooooo`00o?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0?oooooo>Oooool00?cooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0ooooool?ooooo`00hoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`;o000000?o410@ooooooooool00_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooaKooooo003Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool^
ooooo`00hoooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00004ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo0?oooooo=oooool00>?ooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgo
ooooo`0000Gooooo0_l00015ooooo`03o`000?oooooooooo0?ooooooAOooool00>?ooooo00Go0000
ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Gooooo00?o0000ooooooooool0
Hoooool00ol0003oooooooooo`3oooooobKooooo003Sooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00omgMgOoc<c<o`000005ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0?oooooo9Oooool00>?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Gooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
oooooom<ooooo`00hoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
1?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`3oooooobOooooo003looooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0oooooolLooooo`00o?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo000000gooooo00Go
0000ooooooooooooooooo`00003oooooobGooooo003looooo`;o0000:Oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0oooooolRooooo`00o?ooool0
0ol0003oooooooooo`0[ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool01ooo
ool01Ol0003ooooooooooooooooo00000?oooooo@Oooool00?cooooo00?o0000ooooooooool0BOoo
ool2o`0001Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooo00000?oooooo4_ooool00?cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0oooooolGooooo`00o?ooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000002_ooool00ol0
003oooooooooo`3oooooob[ooooo003looooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000002cooooo00?o0000oooooooo
ool0ooooool=ooooo`00o?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`3oooooo`cooooo003looooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`3oooooodgooooo003l
ooooo`;o00007Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01_ooool2o`0000Gooooo00Co0000oooooooooooo0000ooooooliooooo`00o?ooool0
0ol0003oooooooooo`18ooooo`05o`000?ooooooooooooooool000006oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo0?oooooo5oooool00?cooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0oooooolE
ooooo`00o?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00oooooo0ol0003ooooo
oc?ooooo003looooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0oooooollooooo`00
o?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool0
7?ooool01?l0003oooooooooool0000?ooooo`04o`000?ooooooooooo`000?oooooo:oooool00?co
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo0?oo
oooo5Oooool00?cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo01Cooooo00Co0000oooooooooooo0000ooooool[ooooo`00o?ooool2o`0004Sooooo
00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo00000?oooooo=Oooool00?cooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooo`00003ooooooaGooooo003looooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
7?ooool00?cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`3oooooocGooooo003l
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3o
oooooa[ooooo003Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c004ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`3ooooooe7ooooo003Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@04ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0?oooooo
>?ooool00>?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
00001?ooool2o`0002[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooooc3o
oooo003Sooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q
00Cooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`3oooooobCooooo003Sooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Cooooo00?o0000
ooooooooool0LOooool00ol0003oooooooooo`3ooooooaSooooo003Sooooo`05oa0@4?oooooooooo
ooooool@41002oooool00omEEEGoQhN7ooooo`06ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0?oooooo4oooool0
0>?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Kooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0?oooooo<Oooool0
0>?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Cooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`3oooooofGooooo003looooo`03o`000?oooooo
oooo05[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo0?oooooo5_ooool00?cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?ooooooC_ooool00?cooooo0_l0000eooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`3ooooooacooooo003looooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo0?oooooo<Oooool00?cooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l0000?ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0oooooolFooooo`00o?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooood_ooooo003loooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0moooo
o`05o`000?ooooooooooooooool00000oooooolNooooo`00o?ooool00ol0003oooooooooo`3ooooo
ohcooooo003looooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo0?oooooo:oooool00?cooooo0_l0000^ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`;o0000
oooooolNooooo`00o?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`3ooooooa[ooooo003looooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0ooooool[ooooo`00o?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooo
ob3ooooo003looooo`03o`000?oooooooooo03kooooo00Co0000oooooooooooo00003?ooool00ol0
003oooooooooo`3ooooooc_ooooo003looooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0oooooolYooooo`00o?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo0?oooooo
@Oooool00?cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooolWooooo`00o?ooool2o`0002cooooo00?o0000
ooooool000004oooool00ol0003oooooooooo`3oooooodSooooo003looooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000ooooool_ooooo`00o?ooool00ol0003oooooooooo`3oooooohcooooo003looooo`03
o`000?oooooooooo0?ooooooS?ooool00?cooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool0oooooolZooooo`00hooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01?ooool00ol0003oooooooooo`3oooooohcooooo003Sooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@04ooooo`03o`000?oooooooooo
04Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3oooooocKooooo003Sooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`3ooooooc3ooooo003Sooooo`05o`000?oooooooooo
ooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Cooooo0_l0001<ooooo`;o0000oooo
ooloooooo`00hoooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000
olc<c004ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0oooooom7ooooo`00hooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4004ooooo`03
o`000?oooooooooo053ooooo00?o0000ooooooooool0ooooooliooooo`00hoooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000004ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`3oooooocCooooo003Sooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Cooooo00?o0000
ooooooooool0A?ooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo0?oooooo=oooool0
0?cooooo00?o0000ooooooooool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3oooooohco
oooo003looooo`;o0000oooooon=ooooo`00o?ooool00ol0003oooooooooo`3oooooohcooooo003l
ooooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo00?o0000ooooooooool0oooooon<oooo
o`00o?ooool00ol0003oooooooooo`3oooooohcooooo003looooo`03o`000?oooooooooo0?oooooo
S?ooool00?cooooo00?o0000ooooooooool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3o
ooooohcooooo003looooo`;o0000oooooon=ooooo`00o?ooool00ol0003oooooooooo`3oooooohco
oooo003looooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo00?o0000ooooooooool0oooo
oon<ooooo`00o?ooool00ol0003oooooooooo`3oooooohcooooo003looooo`03o`000?oooooooooo
0?ooooooS?ooool00?cooooo00?o0000ooooooooool0oooooon<ooooo`00o?ooool00ol0003ooooo
ooooo`3oooooohcooooo003looooo`;o0000oooooon=ooooo`00o?ooool00ol0003oooooooooo`3o
ooooohcooooo003looooo`03o`000?oooooooooo0?ooooooS?ooool00?cooooo00?o0000oooooooo
ool0oooooon<ooooo`00o?ooool00ol0003oooooooooo`3oooooohcooooo003dooooo`Co000000Go
410@ooooooooooooooooo`00003oooooohkooooo003fooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0oooooon<ooooo`00m_ooool00ol0003oooooooooo`03ooooo`;o0000oooooon=
ooooo`00m_ooool00ol0003oooooooooo`3ooooooi;ooooo003fooooo`03o`000?oooooooooo0?oo
ooooT_ooool00?Kooooo00?o0000ooooooooool0oooooonBooooo`00m_ooool00ol0003ooooooooo
o`3ooooooi;ooooo003dooooo`03oeEEEOmVIVKo00000?ooooooU?ooool00?Sooooo0ol000000ol@
413oooooooooo`3oooooohgooooo003jooooo`03oa0@4?nj^[[ooooo0?ooooooS_ooool00?[ooooo
00?oV9RHoc8b<_ooool0oooooon>ooooo`00n_ooool00ooMgMgo0000okZj^P3oooooohkooooo003j
ooooo`03oeEEEOmgMgOoA4A40?ooooooS_ooool00?Wooooo00GogMgMoa0@4?oooooo8B4QomgMg@3o
ooooohgooooo003iooooo`05ofIVI_n7QhOooooooiRHV?mEEED0oooooon=ooooo`00n?ooool00oo^
k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo0?ooooooRoooool00?Sooooo00Co410@o`000?l0
003ooooo0_l000000ol@413oooooooooo`3ooooooh[ooooo003oooooooooooooS?ooool00?oooooo
oooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<oooo
o`00ooooooooooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<ooooo`00oooooooo
ooooohcooooo003oooooooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo
003oooooooooooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003ooooooooo
ooooS?ooool00?oooooooooooon<ooooo`00ooooooooooooohcooooo003oooooooooooooS?ooool0
0001\
\>"],
  ImageRangeCache->{{{0, 649.812}, {426.062, 0}} -> {-0.0764092, -0.0492291, \
0.00606487, 0.00606487}, {{15.75, 208.938}, {415.875, 222.688}} -> \
{-0.0826818, -0.0958102, 0.00656167, 0.00656167}, {{228.25, 421.5}, {415.875, \
222.688}} -> {-1.19775, -0.0956182, 0.00655937, 0.00655937}, {{440.812, \
634.062}, {415.875, 222.688}} -> {-3.05005, -0.181531, 0.00819518, \
0.00819518}, {{228.25, 421.5}, {203.312, 10.125}} -> {-1.65646, -1.57512, \
0.00819518, 0.00819518}}],

Cell[TextData[{
  "Fig. 7.10 To determine the force on a collection of particles, shown in \
the top picture, three steps must be carried out (bottom from left to right):\
\n(1) determine the density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(i\ j\)\)]],
  " on a grid, (2) determine the potential  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(\(\ \)\(i\ j\)\)\)]],
  "(and gradients) on the grid,  (3) interpolate forces back to the particle \
positions."
}], "Caption",
  CellTags->"Fig. 7.10"],

Cell[TextData[{
  " \tIn order to move the particles, we use the leapfrog method discussed in \
Chapter ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", "c:28"},
    ButtonStyle->"Hyperlink"],
  ". To solve Poisson's equation on the grid, we use the FFT method, which is \
fast and well adapted to periodic boundary conditions. "
}], "Text"],

Cell[TextData[{
  " \tThe more particles we keep, and the finer the grid, the finer the \
resolution of the simulation results. Density variations on a scale smaller \
than the grid will not be picked up.  This is an inherent limitation of grid \
methods: they work only if ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " is smooth compared to the grid spacing."
}], "Text"],

Cell["\<\
 \tOf course, this means that close interactions between individual \
stars are neglected in the PIC method. Since the density and potential are \
smoothed on the scale of the grid, and since this scale is large compared to \
an average interstellar spacing, the method cannot model the dynamics of \
binary star systems, and also neglects collisional effects such as \
hydrodynamic shocks. \
\>", "Text"],

Cell[TextData[{
  "\tAnother obvious limitation of our PIC method is that periodic boundary \
conditions are often poor approximations to the actual conditions in a \
self-gravitating system. For instance, to model an isolated galaxy, it would \
be more appropriate to impose the condition that the potential vanishes at \
infinity, or at least at some large distance from the galaxy. It is possible \
to modify the PIC method so as to account for such boundary conditions, by \
forgoing the use of the FFT method. In such situations, where a large region \
of the computational domain is empty, a uniform grid is highly inefficient.  \
Much recent progress has been made using time-varying nonuniform grids (",
  StyleBox["adaptive grids",
    FontSlant->"Italic"],
  "), chosen so that the grid is fine where there is rapid variation in the \
potential, and coarse outside of these regions. "
}], "Text",
  CellTags->"i:89"],

Cell[TextData[{
  "\t Recently, ",
  StyleBox["tree codes",
    FontSlant->"Italic"],
  " have also been applied to such problems with great success.  In a tree \
code, the potential is not determined on a grid. Rather, the force on a mass \
point is broken into two parts: one part due to nearby particles is treated \
exactly as a sum of pairwise interactions as in molecular dynamics, and the \
second part due to far-away particles is treated approximately as a multipole \
expansion of the far-away mass distribution.  Although these codes are quite \
complex compared to PIC, their overall efficiency is similar to that of the \
PIC method (",
  ButtonBox["Greengard, 1994",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.3.3 Leapfrog Method", "Subsubtitle",
  CellTags->{"i:61", "c:30"}],

Cell[TextData[{
  "\tAs discussed in Chapter ",
  ButtonBox["1",
    ButtonData:>{"Chapter1.nb", "i:65"},
    ButtonStyle->"Hyperlink"],
  ", the leapfrog method is a second-order-accurate technique for integrating \
ODEs of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"\[DifferentialD]", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], "/", \(\[DifferentialD]t\)}], " ", 
            "=", " ", 
            RowBox[{
              StyleBox["p",
                FontWeight->"Bold",
                FontSlant->"Plain"], "/", "m"}]}], ",", " ", 
          RowBox[{
            RowBox[{
              RowBox[{"\[DifferentialD]", 
                StyleBox["p",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], "/", \(\[DifferentialD]t\)}], " ", 
            "=", " ", 
            RowBox[{
              StyleBox["f",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ")"}]}]}], TraditionalForm]]],
  ",  where particle positions are evaluated at times ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(t\_n\), " ", "=", " ", 
            RowBox[{"n", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]]}]}], ",", " ", \(n = 0\), ",", 
          "1", ",", "2", ",", "..."}], TraditionalForm]]],
  ", and particle momenta are evaluated at the intermediate times ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(t\_\(n + 1/2\)\), "=", 
          RowBox[{\((n + 1/2)\), " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ".  Positions are updated using the centered-difference form of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"\[DifferentialD]", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], "/", \(\[DifferentialD]t\)}], "=", 
          RowBox[{
            StyleBox["p",
              FontWeight->"Bold",
              FontSlant->"Plain"], "/", "m"}]}], TraditionalForm]]],
  ", "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "n"], "-", 
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(n - 1\)]}], "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], " ", 
            RowBox[{
              SubscriptBox[
                StyleBox["p",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], \(n - 1/2\)], "/", "m"}]}]}], 
        TraditionalForm]]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "Momenta are updated using the centered difference form of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"\[DifferentialD]", 
              StyleBox["p",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], "/", \(\[DifferentialD]t\)}], "=", 
          RowBox[{
            StyleBox["f",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["p",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(n + 1/2\)], "-", " ", 
            SubscriptBox[
              StyleBox["p",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(n - 1/2\)]}], "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]], " ", 
            RowBox[{
              StyleBox["f",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", 
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "n"], ")"}]}]}], TraditionalForm]]],
  ". "
}], "UNNEQ"],

Cell[TextData[{
  "We will define the initial positions for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\)\(\ \)\)\)]],
  "particles as a list ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "o"], "=", 
          " ", \({{x\_1, y\_1}, \ {x\_2, y\_2},  ... , {x\_N, y\_N}}\)}], 
        TraditionalForm]]],
  ". The initial momenta are in a second list, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["p",
              FontWeight->"Bold",
              FontSlant->"Plain"], "o"], 
          "=", \({{p\_\(x\_1\), p\_\(y\_1\)}, \ {p\_\(x\_2\), 
              p\_\(y\_2\)}, \(\(...\)\(.\)\), {p\_\(x\_N\), p\_\(y\_N\)}}\)}],
         TraditionalForm]]],
  ". \n\tAlthough initial conditions are provided for both ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["p",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " at time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ", the leapfrog method requires the momentum at time step ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "/", "2"}], TraditionalForm]]],
  " in order to begin calculating ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". The momentum ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["p",
            FontWeight->"Bold",
            FontSlant->"Plain"], \(\(1/2\)\(\ \)\)], TraditionalForm]]],
  "can be found from the initial conditions  using a second-order accurate \
predictor-corrector step:\n\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(\(1/2\)\(\ \)\)], " ", "=", " ", 
            RowBox[{
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "o"], " ", "+", " ", 
              RowBox[{
                FractionBox[
                  SubscriptBox[
                    StyleBox["p",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "o"], "m"], " ", 
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]], "/", "2"}]}]}]}], ",", "\n", 
          
          RowBox[{
            SubscriptBox[
              StyleBox["p",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(\(1/2\)\(\ \)\)], "=", " ", 
            RowBox[{
              SubscriptBox[
                StyleBox["p",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "o"], " ", "+", " ", 
              RowBox[{\(1\/\(2  m\)\), 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox["f",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "(", 
                      SubscriptBox[
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "o"], ")"}], " ", "+", " ", 
                    RowBox[{
                      StyleBox["f",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "(", 
                      SubscriptBox[
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], \(1/2\)], ")"}]}], ")"}], " ", 
                
                RowBox[{
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["t",
                        FontSlant->"Italic"]}]], "/", "2."}]}]}]}]}], 
        TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "The following module then runs the leapfrog method for ",
  Cell[BoxData[
      \(TraditionalForm\`N\_step\)]],
  " steps. Updated positions and momenta  are placed in lists ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "n"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["p",
            FontWeight->"Bold",
            FontSlant->"Plain"], "n"], TraditionalForm]]],
  ",",
  " which have the same structure as ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  ". "
}], "Text"],

Cell[BoxData[{
    RowBox[{\(Clear["\<Global`*\>"];\), "\n"}], "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{\(leapfrog[r0_, p0_, Nstep_, \[CapitalDelta]t_]\), " ", ":=", 
        " ", 
        RowBox[{"Module", "[", 
          RowBox[{\({}\), ",", "\[IndentingNewLine]", 
            StyleBox[\( (*\ initial\ conditions\ *) \),
              FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
            
            RowBox[{\(r[0]\  = \ r0\), ";", 
              "\[IndentingNewLine]", \(p[0]\  = \ p0\), ";", 
              "\[IndentingNewLine]", "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  account\ for\ periodic\ boundary\ conditions\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(md[x_]\  := \ Mod[x, L]\), ";", 
              "\[IndentingNewLine]", \(r[
                  n_]\  := \((\ r[n]\  = Map[md, \ r1[n]])\)\  /; \ n > \ 0\),
               ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
              StyleBox[\( (*\ first\ half - step\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(r1[1/2]\  = \ 
                r0\  + \ p0\ \[CapitalDelta]t/\((2\ m)\)\), ";", 
              "\[IndentingNewLine]", \(p[1/2]\  = \ 
                p0\  + \ \(\[CapitalDelta]t\/\(4\ m\)\) \((f[r[0]]\  + \ 
                        f[r[1/2]])\)\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              StyleBox[\( (*\ the\ leapfrog\ method\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(p[
                  n_]\  := \ \((p[n]\  = \ 
                      p[n - 1]\  + \ \[CapitalDelta]t\ f[r[n - 1/2]])\) /; \ 
                  n + 1/2 \[Element] Integers\  && \ n \[GreaterEqual] \ 1\), 
              ";", "\[IndentingNewLine]", \(r1[n_]\  := 
                r[n - 1]\  + \ \[CapitalDelta]t\ p[n - 1/2]/m\  /; 
                  n \[GreaterEqual] \ 1\), ";", "\[IndentingNewLine]", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  determine\ solution\ up\ to\ time\ step\ Nstep\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(Table[r[n], {n, 1, Nstep}]\), ";"}]}], 
          "]"}]}], ";"}]}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.66"],

Cell[TextData[{
  "Two details need to be mentioned. First, the function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["f",
            FontWeight->"Bold",
            FontSlant->"Plain"], "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " determines the force on all ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " particles for given positions, with a structure of the form ",
  Cell[BoxData[
      \(TraditionalForm\`{{f\_\(1\ x\), f\_\(1\ y\)}, {f\_\(2\ x\), \ 
          f\_\(2\ y\)}, \(\(...\)\(.\)\), {f\_\(N\ x\), f\_\(N\ y\)}}\)]],
  ". We will specify this function in the next section. Second, the periodic \
boundary conditions  must be taken into account.  If a particle strays \
outside the box,  it is put back into the box on the other side using the ",
  StyleBox["Mod",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function. This function is applied to the entire vector of positions \
using ",
  StyleBox["Map",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ",
  StyleBox["Map ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "takes any function ",
  Cell[BoxData[
      \(TraditionalForm\`g(x)\)]],
  " and applies it to each element  of  the  vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          StyleBox[\({{x\_1, y\_1},  ... , {x\_N, y\_N}}\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  " according to  "
}], "Text",
  CellTags->"i:60"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["Map",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{"g", ",", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}], "=", 
          " ", \({g({x\_1, y\_1}),  ... , g({x\_N, y\_N})}\), " "}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "Using ",
  StyleBox["Map",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " we can apply the ",
  StyleBox["Mod ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "function to all of the the particle positions in a single step, without \
needing a ",
  StyleBox["Table",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command. ",
  StyleBox["Map",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " works only with functions ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " of a single variable, so we write the ",
  StyleBox["Mod ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "function (a function of two variables) in terms of a user-defined function \
",
  StyleBox["md",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", a function of a single variable."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["7.3.4 Force", "Subsubtitle",
  CellTags->"c:31"],

Cell[CellGroupData[{

Cell["Mass Density on the Grid", "Section",
  CellTags->"c:32"],

Cell[TextData[{
  "\tIn order to obtain the force field from given particle positions, we \
must first determine the density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(i\ j\)\)]],
  " on the ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " grid. The grid is defined by the following points:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"x", "=", 
          RowBox[{"i", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i = 0, 1, 2,  ... , M - 1\)]],
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"y", "=", 
            RowBox[{"j", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]]}]}], ",", 
          FormBox[\(j = 0, 1, 2,  ... , M - 1\),
            "TraditionalForm"]}], TraditionalForm]]],
  ","
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]], " ", "=", " ", \(L/M\)}]}], 
        TraditionalForm]]],
  ". The points ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y = L\)]],
  " are not kept in this grid, because  the periodic boundary conditions \
imply that these points are equivalent to ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  " respectively."
}], "Text"],

Cell[TextData[{
  "Below, we choose values of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(L\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " for use in some of the following examples. We assume that the particles \
have unit mass:"
}], "Text"],

Cell[BoxData[{
    \(\(M = 20;\)\), "\n", 
    \(\(L = 1;\)\), "\n", 
    \(\(\[CapitalDelta]x\  = \ \(\[CapitalDelta]y\  = \ L/M\);\)\), "\n", 
    \(\(m = 1;\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.67"],

Cell[TextData[{
  "\tFor given particle positions we determine ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(i\ j\)\)]],
  " using the technique of area weighting, also known as linear \
interpolation. This is only one of several methods one may use to obtain the \
density, but it is one of the most popular due to its relative simplicity and \
accuracy. For a discussion of other methods, see ",
  ButtonBox["Birdsall and Langdon, (1991)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:88"],

Cell[TextData[{
  "\tA given particle at position ",
  Cell[BoxData[
      \(TraditionalForm\`{x, y}\)]],
  " falls inside one cell of the grid, as shown in Fig. ",
  ButtonBox["7.11",
    ButtonData:>"Fig. 7.11",
    ButtonStyle->"Hyperlink"],
  ". The four surrounding grid points are those closest to ",
  Cell[BoxData[
      \(TraditionalForm\`{x, y}\)]],
  ",  and are labeled ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j)\)\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\((i + 1, j)\)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j + 1)\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\((i + 1, j + 1)\)\)]],
  ". The correct values of ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " can be determine using the ",
  StyleBox["Quotient",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function:"
}], "Text",
  CellTags->"i:58"],

Cell[TextData[Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{"i", "=", 
          RowBox[{
            StyleBox["Quotient",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{"x", ",", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}]}], ";"}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{"j", "=", 
        RowBox[{
          RowBox[{
            StyleBox["Quotient",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{"y", ",", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]]}], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}], "."}]}], TraditionalForm]}]]], "NE3",
  CellTags->"(7.3.3)"],

Cell[TextData[{
  "However, the points ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(i\)\(+\)\(1\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j + 1\)]],
  " may actually be at ",
  Cell[BoxData[
      \(TraditionalForm\`i + 1 = M\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`j + 1 = M\)]],
  ". Consequently, we use the ",
  StyleBox["Mod ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "function to put these points back inside the correct range of ",
  Cell[BoxData[
      \(TraditionalForm\`i\ and\ j\)]],
  ", and call the results ",
  Cell[BoxData[
      \(TraditionalForm\`i\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\_1\)]]
}], "Text",
  CellTags->"i:59"],

Cell[TextData[Cell[BoxData[{
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{\(i\_1\), " ", "=", " ", 
            RowBox[{
              StyleBox["Mod",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontFamily->"Courier",
                FontWeight->"Bold"], \(i + 1, M\), 
              StyleBox["]",
                FontFamily->"Courier",
                FontWeight->"Bold"]}]}], ";"}], " "}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{\(j\_1\), " ", "=", " ", 
        RowBox[{
          RowBox[{
            StyleBox["Mod",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], \(j + 1; M\), 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}], "."}]}], TraditionalForm]}]]], "NE3",
  CellTags->"(7.3.4)"],

Cell[TextData[{
  "\tNow we must increment the density on these four grid points due to the \
presence of the particle. If we call this increment ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Rho]\_\(i\ j\)\)]],
  ",",
  " then we require that "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Sum]\+\(i, j\)\), 
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["A",
                    FontSlant->"Italic"]}]], 
              " ", \(\[CapitalDelta]\[Rho]\_\(i\ j\)\)}]}], " ", "=", " ", 
          "m"}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(7.3.5)"],

Cell[TextData[{
  "where the sum is over all points on the grid, and where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["A",
                FontSlant->"Italic"]}]], "=", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " is the area of a cell.  One way to satisfy Eq. ",
  ButtonBox["(7.3.5)",
    ButtonData:>{"Chapter7.nb", "(7.3.5)"},
    ButtonStyle->"Hyperlink"],
  "  would be to weight equally each of the four grid points surrounding the \
particle : ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[CapitalDelta]\[Rho]\_\(i\ j\)\), " ", "=", " ", 
          RowBox[{"m", "/", 
            RowBox[{"(", 
              RowBox[{"4", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["A",
                      FontSlant->"Italic"]}]]}], 
              StyleBox[")",
                FontSlant->"Italic"]}]}]}], TraditionalForm]]],
  " for the four surrounding grid points, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]\[Rho]\_\(i\ j\) = 0\)]],
  " for the other points.   However, this equal weighting is crude. What if \
the particle is very close to one of the grid points? This grid point should \
then get the lion's share of the particle's mass."
}], "Text"],

Cell[TextData[{
  "\tIn area weighting,  that portion of the mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " that is assigned to each of the four grid points  depends on the distance \
of the particle to the points. For instance, if the particle is right at the \
center of the cell, all four surrounding grid points get ",
  Cell[BoxData[
      \(TraditionalForm\`m/4\)]],
  ". However, if the particle is closest to the point ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j)\)\)]],
  " as shown in Fig. ",
  ButtonBox["7.11",
    ButtonData:>"Fig. 7.11",
    ButtonStyle->"Hyperlink"],
  ", this grid point is given more of the particles mass than the other \
points, according to the following prescription: break the cell into four \
rectangles as shown, each with a vertex at ",
  Cell[BoxData[
      \(TraditionalForm\`{x, y}\)]],
  ". Call the areas of these rectangles ",
  Cell[BoxData[
      \(TraditionalForm\`A\_1\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`A\_4\)]],
  ". These areas can be determined in terms of the length of the rectangle \
sides, ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[Delta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[Delta]", 
            StyleBox["y",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], "1"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["y",
                FontSlant->"Italic"]}]], "1"], TraditionalForm]]],
  "where"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", 
          RowBox[{
            StyleBox["Mod",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{"x", ",", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["y",
                FontSlant->"Italic"]}]], " ", "=", " ", 
          RowBox[{
            StyleBox["Mod",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            StyleBox["[",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{"y", ",", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]]}], 
            StyleBox["]",
              FontFamily->"Courier",
              FontWeight->"Bold"]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], "1"], " ", "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], " ", "-", " ", 
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
          SubscriptBox[
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]], "1"], " ", "=", " ", 
          RowBox[{
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["y",
                  FontSlant->"Italic"]}]], "-", 
            RowBox[{
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]], "."}]}]}]}], 
      TraditionalForm]]]], "NE3",
  CellTags->"(7.3.6)"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .75456 
%%ImageSize: 713 538 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00133574 0.0179657 0.00133574 [
[ 0 0 0 0 ]
[ 1 .75456 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .75456 L
0 .75456 L
closepath
clip
newpath
% Start of gray image
p
.02381 .01797 translate
.95238 .71862 scale
713 string
713 538 8 [713 0 0 538 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  Mimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
0000000000FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF0000000000
000000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF0000000000
000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF00FFFFFFFFFFFFFFFFFF0000000000
0000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFF000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF00FFFFFFFFFFFFFFFFFF00000000
0000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFF000000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00FFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFF00000000000000FFFFFFFFFFFFFF00
00000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFF00FFFFFFFFFFFFFF00
000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFF000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00
000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFF000000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000FFFFFFFFFF00
000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFF000000FFFFFFFF00000000000000FFFFFFFFFFFFFF0000000000FFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFF00FFFFFFFFFFFFFF00000000FFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000FFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000FFFFFFFFFFFF00000000FFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF0000FFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000FFFFFFFFFF00000000FFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000FF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000FF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000FFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF0000FFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000FF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF0000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000FF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000
FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000000000
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000FF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFF000000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000FF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000000000FFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFF000000000000FFFFFFFFFF000000FFFF00000000FFFF
FFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000FFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000000000FFFFFFFFFFFFFFFF000000000000FFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF000000
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF0000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFF000000000000FFFFFFFFFF000000FFFF00000000FFFFFFFFFFFFFF00
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000000000000000FFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF0000000000000000
0000FFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFF0000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00000000000000FFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF00000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFF00
00FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
0000FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF0000FFFFFFFF
FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF00FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFF
FFFF0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF000000
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FF00FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFF000000000000FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000000000000000FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF0000000000000000000000
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
00000000FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF0000000000000000000000
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
00000000FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF0000000000000000000000
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
00000000FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFF00000000000000000000
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
00000000FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000
00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFF00000000000000FFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFF
FFFF0000000000FFFF0000FFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFF00FFFFFFFFFF
FFFF00000000FFFFFFFF00FFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFF
FFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFF
FFFF00000000FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFF000000FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF000000
00FFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
0000000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
00FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
00000000000000FFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000
00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF0000000000000000
0000FFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
00FFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF00000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF00FF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00FFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
00FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF00000000
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FF00FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF00FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF00FF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF0000000000FF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000FFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFF0000000000FFFF
FFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF000000000000FFFFFF
000000000000000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000000000FFFFFF
FFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF000000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF00FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF0000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF0000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000000000000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFF
FFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF00FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000FFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF00FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
00000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF
FFFF0000000000000000FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFF
FFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFF00FFFFFFFFFFFF
FFFF00000000000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFF00FFFFFFFFFF
FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF00FFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF00FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF0000000000
000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000000000FFFFFFFFFF000000000000000000000000000000000000
0000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFF000000
0000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
00FFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFF
FFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFF0000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00
FFFFFFFFFF0000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
00000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF00000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00000000FFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF00FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF0000FFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF0000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{187.125, 141},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40003Y0000/2000`400?l00000o`00003ojOooool0
0>Wooooo003Yooooo`00jOooool00>Wooooo003Yooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolS0?ooo`80ZZZZ2`3oool0102Z
ZZX000000000002o_kmO0?ooo`030410@0000000EEEE02@0oooo00<0EEEE0>?Sh`3oool07`3oool6
ooooo`001ooooolG0?ooo`030;no_`2EUID0oooo00H0oooo00H0_kno0?ooo`3oool0oooo02/[:`2Z
ZZX30?ooo`030=CDe02EUID0oooo00@0oooo00@0ZZZZ000000000000_knoBP3oool0102_[jl00000
06YZJP3De=@A0?ooo`030410@0000000EEEE00D0oooo00<0T92@0>[ZjP3oool0603oool01`3De=@0
j^[Z0?ooo`3oool0eMGE01DE5@3_knl00P3oool00`3Zj^X0UIFE0>o_k`0J0?ooo`Kooooo0007oooo
oaH0oooo00<0_kno0:ZZZP3oool01`3oool01P3Shn<0LG5a0?ooo`3oool0SXj>01`L70@0oooo00<0
hn?S09FEU@3oool00`3oool0102ZZZX000000000002o_km;0?ooo`030000002ZZZX0oooo0140oooo
00<0@4100000001EEED0103oool00`1aLG40j^[Z0?ooo`0J0?ooo`06075aL@3Zj^X0oooo0?ooo`0i
>CT0UIFE103oool00`20P800oooo0?ooo`0H0?ooo`Kooooo0007oooooaH0oooo00<0@4100?ooo`3o
ool0203oool01P2>SXh0a/K60?ooo`3Shn<000000<K6aP@0oooo00<0JVYZ0:ZZZP3oool00P3oool0
102ZZZX000000000002o_km;0?ooo`030000002ZZZX0oooo0140oooo00<0@4100000001EEED00`3o
ool00`1aLG40SXj>0?ooo`0K0?ooo`060>?Sh`2EUID0oooo0?ooo`2>SXh0EEEE103oool00`2ZZZX0
EEEE0?ooo`0H0?ooo`Kooooo0007oooooaD0oooo00<0LG5a0820P03oool00P3oool00`2ZZZX00000
08j>SP020?ooo`040=GEe@0L71`000000:ZZZP80oooo00<071`L075aL@3oool00`3oool00`2o_kl0
71`L0?ooo`020?ooo`040:ZZZP00000000000;no_`@0oooo00<0j^[Z0:ZZZP2ZZZX00`3oool00`2Z
ZZX0hn?S0?ooo`020?ooo`030:ZZZP3oool0oooo03T0oooo00<000000:ZZZP3oool04@3oool00`10
@400000005EEE@020?ooo`030<K6aP000000oooo00<0oooo00<0>CTi0410@03Shn<01@3oool00`1E
EED0ZZZZ0?ooo`050?ooo`060:ZZZP1EEED0000003Ti>@2ZZZX0hn?S0P3oool00`0i>CT000000820
P0020?ooo`030<K6aP0E5AD0oooo00@0oooo00<000000<K6aP3oool05`3oool6ooooo`001ooooolD
0?ooo`030>[ZjP000000_kno00<0oooo00P0X:2P0000003Zj^X0_kno0?ooo`3_knl0@41006][J`<0
oooo00<0P82002/[:`3oool0103oool01@000000UIFE0?ooo`3oool0ZZZZ008000000180_kno0?oo
o`3oool0oooo09FEU@0`<300j^[Z0?ooo`2ZZZX0P8200?ooo`000000EEEE0=oOg`3oool0P82001DE
5@20P80X0?ooo`090=oOg`2EUID0_kno0;no_`3De=@0oooo0=GEe@20P800j^[Z0080oooo00<0_kno
09FEU@3_knl0103oool00`000000ZZZZ0?ooo`0A0?ooo`030410@0000000EEEE0080oooo00<0@410
05EEE@3oool00`3oool0100[:b/0P8200;no_`3Zj^X40?ooo`0305EEE@2ZZZX0oooo00L0oooo00<0
00000:ZZZP3oool00`3oool00`1ZJVX0EEEE0=oOg`030?ooo`03020P803EeMD0oooo00<0oooo00<0
EEEE0410@03oool05`3oool6ooooo`001ooooolD0?ooo`030:ZZZP000000j^[Z00<0oooo00@0eMGE
00000036a/H0hn?S1`3oool00`36a/H000000=GEe@040?ooo`0505EEE@0i>CT0oooo0?ooo`2ZZZX0
0P0000001P2o_kl0oooo0?ooo`3oool000000820P0<0oooo00X0JVYZ075aL@3oool0oooo09FEU@3o
ool0EEEE075aL@3oool0ZZZZ9`3oool02@0E5AD0ZZZZ0?ooo`3oool0ZZZZ0820P02ZZZX071`L05EE
E@020?ooo`0301`L701EEED0UIFE00@0oooo00<000000:ZZZP3oool04@3oool00`10@400000005EE
E@020?ooo`030000002>SXh0oooo00<0oooo00@0LG5a05EEE@3oool0hn?S103oool00`1EEED0ZZZZ
0?ooo`070?ooo`030000002ZZZX0oooo00T0oooo00<0EEEE075aL@3oool00`3oool00`2ZZZX00000
0>?Sh`0G0?ooo`Kooooo0007oooooa@0oooo00<0EEEE0000003oool0103oool00`0L71`0SXj>0?oo
o`080?ooo`0301`L702ZZZX0oooo00<0oooo00D0EEEE0000003oool0oooo0:ZZZP02000000060;no
_`3oool0oooo0:ZZZP000000UIFE0`3oool0202o_kl000000>?Sh`3oool0_kno0:ZZZP000000ZZZZ
:03oool00`2ZZZX000000?ooo`030?ooo`0:02/[:`36a/H0oooo0>?Sh`2ZZZX0oooo00000036a/H0
eMGE0>?Sh`<0oooo00<000000:ZZZP3oool04@3oool01`10@400000005EEE@3oool0_kno0000002Z
ZZX0103oool00`36a/H0:b/[0?ooo`050?ooo`0305EEE@2ZZZX0oooo00L0oooo00<000000:ZZZP3o
ool02@3oool00`2EUID0>CTi0?ooo`030?ooo`030:ZZZP000000ZZZZ01L0oooo1_ooool000Oooooo
503oool00`1EEED000000?ooo`040?ooo`80EEEE2@3oool00`1EEED0JVYZ0?ooo`030?ooo`0505EE
E@000000oooo0?ooo`2ZZZX00P0000001P2o_kl0oooo0?ooo`3Shn<000000820P0<0oooo00<0eMGE
0000002>SXh00P3oool00`1aLG4000000>?Sh`0X0?ooo`0305EEE@0E5AD0oooo00<0oooo00L0P820
03Ti>@3oool0oooo09FEU@2>SXh0000000D0oooo00<0j^[Z0000002ZZZX04P3oool01`10@4000000
05EEE@3oool0_kno0000002ZZZX01@3oool010000000oooo0?ooo`1EEED8000000030:ZZZP3oool0
oooo0080oooo00<000000:ZZZP3oool02@3oool00`2o_kl000000>?Sh`030?ooo`030:ZZZP000000
ZZZZ01L0oooo1_ooool000Oooooo503oool00`1EEED000000?ooo`040?ooo`030;no_`000000j^[Z
00P0oooo00<0_kno030`<03oool00`3oool01@1EEED000000?ooo`3oool0ZZZZ0080000000H0_kno
0?ooo`3oool0oooo02/[:`1`L7040?ooo`060000001EEED0oooo0?ooo`2EUID00000:@3oool00`2E
UID000000?ooo`030?ooo`050:2PX0000000eMGE0?ooo`3_knl00P10@4050?ooo`030;no_`1EEED0
ZZZZ0180oooo00L0@4100000001EEED0oooo0;no_`000000ZZZZ00D0oooo00<0D51@09FEU@3oool0
103oool00`1EEED0ZZZZ0?ooo`070?ooo`030000002ZZZX0oooo00X0oooo00<05ADE09FEU@3oool0
0P3oool00`2ZZZX000000:ZZZP0G0?ooo`Kooooo0007oooooa@0oooo00<0SXj>0000003oool01@3o
ool00`0L71`0ZZZZ0?ooo`080?ooo`030000003Shn<0oooo0080oooo00D0>CTi05EEE@3oool0oooo
0:ZZZP02000000060;no_`3oool0oooo0?ooo`2ZZZX0:b/[103oool01`000000EEEE0?ooo`3oool0
EEEE01`L702ZZZX0:03oool00`3Shn<000000>?Sh`030?ooo`030;no_`000000ZZZZ0080oooo00<0
>CTi05EEE@3oool06@3oool01`10@400000005EEE@3oool0j^[Z0000002ZZZX01@3oool00`2EUID0
EEEE0?ooo`040?ooo`0305EEE@2ZZZX0oooo00L0oooo00<000000:ZZZP3oool02P3oool00`1EEED0
>CTi0?ooo`020?ooo`0308j>SP000000oooo01L0oooo1_ooool000Oooooo503oool00`36a/H00000
0;no_`040?ooo`030:ZZZP0L71`0EEEE00L0oooo00@0hn?S0:ZZZP0E5AD0ZZZZ0`3oool01@000000
SXj>0?ooo`3oool0ZZZZ0080000000<0_kno0?ooo`3oool00P3oool01`10@400ZZZZ0?ooo`3oool0
ZZZZ00000036a/H00P3oool01@000000SXj>08j>SP3EeMD0ZZZZ02L0oooo00<0@41008j>SP3oool0
0P3oool00`2o_kl000000:ZZZP020?ooo`030000000i>CT0hn?S01T0oooo00<0@4100000001EEED0
0P3oool00`0L71`0EEEE0?ooo`030?ooo`030>?Sh`1ZJVX0000000D0oooo00<0EEEE0:ZZZP3oool0
1`3oool00`000000ZZZZ0?ooo`090?ooo`030;no_`1EEED0000000<0oooo00<0EEEE03Ti>@3oool0
5`3oool6ooooo`001ooooolE0?ooo`0303Ti>@2EUID0oooo00@0oooo00<0hn?S0<K6aP3oool0203o
ool01`3EeMD0a/K60?ooo`3oool0eMGE0000003Shn<00P3oool0102ZZZX000000000002o_kl50?oo
o`0>075aL@2>SXh0ZZZZ02/[:`0i>CT0oooo0<K6aP2EUID000000>?Sh`3oool0EEEE00000036a/HV
0?ooo`030;no_`0L71`0hn?S0080oooo00X0JVYZ01`L703oool0oooo0;no_`000000hn?S075aL@3E
eMD0a/K65`3oool00`10@400000005EEE@020?ooo`0308j>SP0L71`0oooo00D0oooo00<0ZZZZ0?oo
o`3oool00`3oool00`1EEED0ZZZZ0?ooo`070?ooo`030000002ZZZX0oooo00/0oooo00H0ZZZZ0>?S
h`3oool0oooo01`L702>SXhH0?ooo`Kooooo0007oooooaD0oooo00<0eMGE051@D03oool04`3oool0
0`20P800ZZZZ0?ooo`020?ooo`040:ZZZP00000000000;no_`H0oooo00@0_kno0410@010@400j^[Z
<03oool03P3Zj^X0UIFE0:ZZZP20P800410@0:ZZZP3oool0_kno092@T01ZJVX0oooo0>[ZjP1PH600
EEEE5`3oool00`10@400000005EEE@030?ooo`030410@02ZZZX0oooo01@0oooo00<000000:ZZZP3o
ool03P3oool00`2o_kl0EEEE0?ooo`0H0?ooo`Kooooo0007oooooaH0oooo00<0_kno08j>SP3oool0
0`3oool00`36a/H00000075aL@080?ooo`0505EEE@0L71`0oooo0>?Sh`20P800103oool0102ZZZX0
00000000002o_kl50?ooo`050:ZZZP000000SXj>0?ooo`3Shn<0<P3oool00`1aLG40000009FEU@0P
0?ooo`030410@0000000EEEE00@0oooo00<0EEEE0>[ZjP3oool00`3oool201`L70`0oooo00@0ZZZZ
05EEE@000000ZZZZ2`3oool01@36a/H00000075aL@3oool0JVYZ01X0oooo1_ooool000Oooooo5`3o
ool20:ZZZP<0oooo00<0a/K60000001aLG40203oool0101EEED071`L0>?Sh`1aLG450?ooo`040:ZZ
ZP00000000000;no_`D0oooo00D0EEEE08j>SP3oool0oooo05EEE@0a0?ooo`0505EEE@0L71`0a/K6
0?ooo`3Shn<07`3oool00`10@400000005EEE@050?ooo`030820P03oool0oooo0080oooo0P0L71`=
0?ooo`030>?Sh`1EEED0ZZZZ00/0oooo00D0a/K60000001aLG40LG5a0>[ZjP0J0?ooo`Kooooo0007
oooooaP0oooo00<0hn?S0?ooo`3oool03P3oool00`36a/H0oooo0?ooo`040?ooo`040:ZZZP000000
00000;no_`D0oooo00D0hn?S05EEE@2ZZZX0P8200<K6aP0a0?ooo`050000003Shn<0oooo0>[ZjP1a
LG407`3oool00`10@400000005EEE@060?ooo`030>?Sh`3oool0oooo0200oooo0P3Shn<K0?ooo`Ko
oooo0007oooooc00oooo00@0ZZZZ000000000000_kno>`3oool01@2ZZZX0LG5a0:ZZZP20P800hn?S
01l0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no
_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool@0?ooo`0308j>SP1EEED0EEEE01d0
EEEE00@0>CTi000000000000@410G`1EEED00`0E5AD0000001`L700P05EEEBH0oooo1_ooool000Oo
oooo403oool00`1EEED000000000002S000002H0oooo1_ooool000Oooooo403oool00`1EEED00000
0000002S000002H0oooo1_ooool000Oooooo403oool00`3De=@0_kno0;no_`0M0;no_`0407moO`00
0000000008n?SaT0_kno00<0P8200:ZZZP2o_kl0@`2o_kl00`0`<30000000410@00P0;no_bH0oooo
1_ooool000Oooooo<03oool0102ZZZX000000000002o_klI0?ooo`030000002ZZZX0oooo04<0oooo
00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_aT0oooo
00<000000:ZZZP3oool0@`3oool00`10@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0
ZZZZ000000000000_kno6@3oool00`000000ZZZZ0?ooo`130?ooo`030410@0000000EEEE04H0oooo
1_ooool000Oooooo<03oool0102ZZZX000000000002o_klI0?ooo`030410@02o_kl0oooo04<0oooo
00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_el0oooo
00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_el0oooo
00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_el0oooo
00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_el0oooo
00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_``0oooo
00<0ZZZZ0000001aLG400P2ZZZX00`3Shn<0oooo0?ooo`0b0?ooo`030410@0000000000000800000
00<0>CTi0?ooo`3oool04@3oool00`10@400000005EEE@160?ooo`Kooooo0007ooooobH0oooo00<0
ZZZZ0>[ZjP3oool01`3oool0102ZZZX000000000002o_kl<0?ooo`030=GEe@3Shn<0oooo0080oooo
00<0>CTi0>?Sh`3oool0<P3oool00`3Zj^X0>CTi0:ZZZP020:ZZZP0305EEE@3Shn<0oooo0140oooo
00<0@4100000001EEED0AP3oool6ooooo`001ooooolV0?ooo`0300000010@400hn?S00L0oooo00@0
ZZZZ000000000000_kno4@3oool00`1EEED0LG5a0?ooo`050?ooo`0305EEE@36a/H0oooo02/0oooo
00<0hn?S075aL@3oool00P3oool00`3Shn<0oooo0?ooo`0@0?ooo`030410@0000000EEEE04H0oooo
1_ooool000Oooooo9P3oool0102o_kl0oooo0;no_`2o_kl60?ooo`040:ZZZP00000000000;no_a00
oooo00<0kno_01DE5@1ZJVX01P3oool00`000000ZZZZ0?ooo`0/0?ooo`030>[ZjP20P800kno_01@0
oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolY0?ooo`030:ZZZP3Shn<0oooo00@0oooo
00D0ZZZZ000000000000_kno0?ooo`030:ZZZP040>[ZjP3oool0oooo0<K6aP@0ZZZZ0P3oool01@2Z
ZZX0SXj>02/[:`0L71`0hn?S00H0oooo00<000000:ZZZP3oool07P3oool30:ZZZP040>?Sh`3oool0
oooo0<K6aP@0ZZZZ103oool00`3Shn<0JVYZ0?ooo`0C0?ooo`030410@0000000EEEE04H0oooo1_oo
ool000Oooooo803oool00`3Shn<0ZZZZ0:ZZZP070?ooo`0305EEE@3oool0oooo00<0oooo00P0ZZZZ
000000000000_kno0?ooo`2>SXh000000:ZZZP@0oooo00@0P8200000000L71`0hn?S0`3oool00`2>
SXh0@4100>?Sh`070?ooo`030000002ZZZX0oooo01h0oooo00<0SXj>0000002ZZZX0103oool0102Z
ZZX0000001`L703Shn<50?ooo`0306YZJP36a/H0oooo0180oooo00<0@4100000001EEED0AP3oool6
ooooo`001ooooolO0?ooo`060820P00L71`0hn?S0?ooo`20P800ZZZZ1@3oool00`000000_kno0?oo
o`030?ooo`040:ZZZP00000000000;no_`80oooo00<0EEEE08j>SP3oool00`3oool00`2ZZZX00000
05EEE@050?ooo`0309FEU@1aLG40oooo02P0oooo00<0EEEE08j>SP3oool00`3oool00`3Shn<00000
05EEE@020?ooo`060=GEe@3oool0oooo0?ooo`20P800EEEE4`3oool00`10@400000005EEE@160?oo
o`Kooooo0007oooooal0oooo00<0410@0:ZZZP3oool00P3oool00`0[:b/0UIFE0?ooo`020?ooo`03
0:ZZZP000000_kno00@0oooo00@0ZZZZ000000000000_kno0P3oool00`3Zj^X0:b/[0>o_k`030?oo
o`060820P0000000ZZZZ0?ooo`3?cll0j^[Z0P3oool00`2_[jl000000?ooo`0X0?ooo`030>[ZjP0[
:b/0j^[Z00<0oooo00<0ZZZZ0000002ZZZX00P3oool01P20P800e=CD0?ooo`3De=@0<30`06YZJQ<0
oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolN0?ooo`030:ZZZP000000a/K600<0oooo
00<0ZZZZ0000003Shn<00P3oool0101aLG40>CTi0>[ZjP36a/H30?ooo`040:ZZZP00000000000;no
_`<0oooo00<0a/K605EEE@2ZZZX00P2ZZZX00`10@40000000<K6aP020?ooo`05075aL@2ZZZX0ZZZZ
01DE5@2>SXh0:P3oool00`36a/H0>CTi0:ZZZP020:ZZZP0305EEE@000000a/K60080oooo00H0eMGE
01`L70000000000001DE5@3Shn<C0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo7P3o
ool00`3Shn<000000:ZZZP030?ooo`030<K6aP000000SXj>0080oooo0P1EEED00`3oool0ZZZZ0?oo
o`020?ooo`040:ZZZP00000000000;no_`@0oooo00H0@41005EEE@1EEED0EEEE01DE5@0000040?oo
o`030>?Sh`2ZZZX0eMGE02`0oooo00H0EEEE0410@01EEED0EEEE01`L700000050?ooo`80ZZZZ5@3o
ool00`10@400000005EEE@160?ooo`Kooooo0007oooooal0oooo00<05ADE0:ZZZP3oool00`3oool0
2@000000EEEE0?ooo`3oool000000:ZZZP3oool0hn?S0<K6aP020?ooo`040:ZZZP00000000000;no
_`@0oooo00H0ZZZZ08j>SP3oool0oooo01DE5@0L71`c0?ooo`060>?Sh`1ZJVX0oooo0?ooo`0L71`0
5ADE703oool00`10@400000005EEE@160?ooo`Kooooo0007oooooal0oooo0P1EEED40?ooo`060000
001EEED0oooo0:ZZZP000000hn?S0P3oool0102>SXh0oooo0?ooo`2ZZZX2000000030;no_`3oool0
oooo00<0oooo00D0>CTi0>?Sh`3oool0000005EEE@0d0?ooo`0506YZJP3Shn<0oooo00000010@400
703oool00`10@400000005EEE@160?ooo`Kooooo0007oooooal0oooo00<0gmoO01DE5@2o_kl00P3o
ool01P2ZZZX000000:ZZZP3oool0EEEE0410@080oooo00D0_kno01DE5@3oool0oooo0:ZZZP020000
00030;no_`3oool0oooo00<0oooo00D0eMGE06YZJP2o_kl000000820P00?0?ooo`030820P03EeMD0
oooo0280oooo00D0gmoO06YZJP2o_kl00000061PH00L0?ooo`030410@0000000EEEE04H0oooo1_oo
ool000Oooooo8@3oool02@1aLG40SXj>09FEU@0L71`0>CTi0>?Sh`20P80000000:ZZZP020?ooo`05
075aL@0L71`0oooo0?ooo`2ZZZX00P0000000`2o_kl0oooo0?ooo`040?ooo`0408j>SP1EEED00000
0:ZZZPl0oooo00<000000:ZZZP3oool08`3oool0102>SXh0EEEE00000020P80L0?ooo`030410@000
0000EEEE04H0oooo1_ooool000Oooooo8P3oool0103Shn<0@41001`L703Shn<:0?ooo`040:ZZZP00
000000000;no_`L0oooo00<071`L0000003Shn<03`3oool00`000000ZZZZ0?ooo`0T0?ooo`0301`L
70000000ZZZZ01`0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolQ0?ooo`030>?Sh`0L
71`0EEEE00`0oooo00@0ZZZZ000000000000_kno1`3oool00`36a/H000000?ooo`0?0?ooo`030000
002ZZZX0oooo02@0oooo00<0a/K60000002o_kl0703oool00`10@400000005EEE@160?ooo`Kooooo
0007ooooob40oooo00D0EEEE06YZJP3oool0oooo06YZJP0:0?ooo`040:ZZZP00000000000;no_`P0
oooo00<0P8200?ooo`3oool03P3oool00`2o_kl0j^[Z0?ooo`0U0?ooo`0306YZJP3_knl0oooo01/0
oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolQ0?ooo`050>?Sh`1EEED0ZZZZ075aL@36
a/H02P3oool0102ZZZX000000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oo
oooo<03oool0102ZZZX000000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oo
oooo<03oool0102ZZZX000000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oo
oooo<03oool0102ZZZX000000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oo
oooo<03oool0102ZZZX000000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oo
oooo<03oool0102ZZZX000000000002o_klI0?ooo`030:ZZZP3Shn<0oooo04<0oooo00<0@4100000
001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_aT0oooo00<000000:ZZ
ZP3oool0@`3oool00`10@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ00000000
0000_kno6@3oool00`000000ZZZZ0?ooo`130?ooo`030410@0000000EEEE04H0oooo1_ooool000Oo
oooo<03oool0102ZZZX000000000002o_klH0?ooo`040820P0000000EEEE0<K6aT<0oooo00<0@410
0000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_aL0oooo00<0EEEE
0000000000000P0000000`3EeMD0oooo0?ooo`100?ooo`030410@0000000EEEE04H0oooo1_ooool0
00Oooooo<03oool0102ZZZX000000000002o_klF0?ooo`030:ZZZP000000000000<0000000<0P820
0?ooo`3oool0@03oool00`10@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00D0ZZZZ0000
00000000<30`0410@0060?ooo`050;no_`10@400@4100410@02o_kl01@3oool01P2o_kl0@4100410
@010@400_kno06YZJPD0000000@0410@0410@010@400@4101P3oool01020P800@4100410@010@406
0?ooo`050;no_`10@400@4100410@02o_kl01@3oool01@2o_kl0@4100410@010@400L71`00H0oooo
00@0P8200410@010@400@4101P3oool01020P800@4100410@010@4060?ooo`090;no_`10@400@410
0410@020P800oooo0410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool01@2ZZZX000000000
0020P800ZZZZ00H0oooo00D0hn?S0:ZZZP2ZZZX0ZZZZ0>?Sh`050?ooo`060>?Sh`2ZZZX0ZZZZ0:ZZ
ZP3Shn<0ZZZZ1@000000101EEED0ZZZZ0:ZZZP2ZZZX60?ooo`040<K6aP2ZZZX0ZZZZ0:ZZZPH0oooo
00D0hn?S0:ZZZP2ZZZX0ZZZZ0>?Sh`050?ooo`050>?Sh`2ZZZX0ZZZZ0:ZZZP2o_kl01P3oool01036
a/H0ZZZZ0:ZZZP2ZZZX60?ooo`040<K6aP2ZZZX0ZZZZ0:ZZZPH0oooo00T0hn?S0:ZZZP2ZZZX0ZZZZ
0<K6aP3oool0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no
_aL0oooo00<071`L0000000000000P0000000`2o_kl0oooo0?ooo`100?ooo`030410@0000000EEEE
04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o_klH0?ooo`0406YZJP0i>CT0EEEE
0<K6aQ80oooo00<0000003Ti>@3Shn<0;P3oool00`10@400000005EEE@160?ooo`Kooooo0007oooo
oc00oooo00@0ZZZZ000000000000_kno7`3oool00`2EUID0_kno0?ooo`080?ooo`080>[ZjP3De=@0
oooo0?ooo`20P800j^[Z0;no_`3?cll40?ooo`030>[ZjP2EUID0j^[Z02H0oooo00<0@4100000001E
EED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_aT0oooo00<000000:ZZZP3o
ool00P3oool00`1aLG40hn?S0?ooo`0:0?ooo`80ZZZZ103oool00`2ZZZX0oooo0?ooo`040?ooo`03
075aL@3Zj^X0oooo02@0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZ
ZP00000000000;no_aT0oooo00H000000:ZZZP3oool0oooo075aL@2>SXh=0?ooo`0305EEE@3oool0
oooo0080oooo00<0j^[Z08j>SP3oool0103oool00`3Shn<0@4100?ooo`0T0?ooo`030410@0000000
EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o_klI0?ooo`050000002ZZZX0
oooo0=GEe@0000000`3oool01`10@400EEEE0?ooo`3oool0eMGE0000001aLG400P3oool00`2>SXh0
0000000000050?ooo`030000003Shn<0oooo00@0oooo00<0@4100<K6aP3oool08`3oool00`10@400
000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno6@3oool01@10@400
_kno0?ooo`1`L700EEEE00<0oooo00`0X:2P0;no_`20P800oooo0820P010@400j^[Z09FEU@3oool0
ZZZZ0410@02ZZZX40?ooo`030<o?c`000000UIFE00D0oooo00<0P8200410@03oool08`3oool00`10
@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno703oool00`10
@400SXj>0?ooo`040?ooo`040<K6aP2ZZZX0EEEE0:ZZZPX0oooo00@0ZZZZ01`L703oool0ZZZZ103o
ool00`2o_kl000000>?Sh`0S0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0
102ZZZX000000000002o_klL0?ooo`030000002ZZZX0oooo00D0oooo00<0LG5a02/[:`36a/H02P3o
ool01020P800EEEE0?ooo`2ZZZX40?ooo`030;no_`000000ZZZZ02<0oooo00<0@4100000001EEED0
AP3oool6ooooo`001oooool`0?ooo`040:ZZZP00000000000;no_a`0oooo00<000000:ZZZP3oool0
1P3oool00`000000oooo0?ooo`090?ooo`0505EEE@2>SXh0oooo0?ooo`2o_kl00`3oool00`2o_kl0
00000:ZZZP0S0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX00000
0000002o_klL0?ooo`030000002ZZZX0oooo00D0oooo00<0a/K60000003oool02P3oool01@0E5AD0
a/K60?ooo`3oool0ZZZZ00<0oooo00<0_kno0000002ZZZX08`3oool00`10@400000005EEE@160?oo
o`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno703oool00`0P8200ZZZZ0?ooo`050?oo
o`030820P010@400P82000T0oooo00<0eMGE020P803oool00P3oool01`1PH600oooo0?ooo`3oool0
[jn_0000003Zj^X08`3oool00`10@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ
000000000000_kno703oool205EEE@@0oooo00P0a/K60>?Sh`0i>CT0UIFE0>?Sh`0i>CT071`L09FE
U@@0oooo00@0hn?S0:ZZZP0L71`0JVYZ0P3oool00`2ZZZX000000?ooo`020?ooo`030820P00i>CT0
oooo02<0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`0?ooo`040:ZZZP0000000000
0;no_aT0oooo00D0EEEE0<K6aP3oool0ZZZZ01`L70050?ooo`030<K6aP2ZZZX0j^[Z0080oooo00<0
ZZZZ0>[ZjP3oool01@3oool00`2ZZZX0eMGE0?ooo`020?ooo`060;no_`3oool0oooo0?ooo`1EEED0
SXj>903oool00`10@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000
_kno6@3oool01P000000ZZZZ0?ooo`3oool071`L0<K6aQX0oooo00<0@4100?ooo`3oool08`3oool0
0`10@400000005EEE@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno6@3oool0
1`000000ZZZZ0?ooo`3oool0j^[Z05EEE@3Zj^X0603oool00`1ZJVX0clo?0?ooo`0T0?ooo`030410
@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o_klI0?ooo`030000
002ZZZX0oooo00<0oooo00<0LG5a0>?Sh`3oool05@3oool00`1aLG40hn?S0?ooo`0U0?ooo`030410
@0000000EEEE04H0oooo1_ooool000Oooooo:`3oool30:ZZZP030<K6aP3oool0ZZZZ0080000000<0
_kno0?ooo`3oool07P3oool00`3Shn<0oooo0?ooo`0C0?ooo`80hn?S9`3oool00`10@400000005EE
E@160?ooo`Kooooo0007ooooob00oooo00<0a/K605EEE@36a/H0203oool00`3Zj^X0000008j>SP02
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolP
0?ooo`040;no_`1EEED0ZZZZ0<o?c`P0oooo00D000000:ZZZP3oool0oooo0:ZZZP02000000030;no
_`3oool0oooo00h0oooo00<0gmoO0820P03oool0<P3oool01@3Zj^X0X:2P0820P02ZZZX0j^[Z01D0
oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolS0?ooo`030;no_`36a/H0oooo00H0oooo
00D000000:ZZZP3oool0oooo0:ZZZP02000000030;no_`3oool0oooo00h0oooo00<0_kno0000003o
ool0<`3oool00`2o_kl000000?ooo`0F0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo
903oool00`2>SXh0oooo0?ooo`050?ooo`050000002ZZZX0oooo0?ooo`2ZZZX00P0000000`2o_kl0
oooo0?ooo`0>0?ooo`030;no_`000000oooo03<0oooo00<0_kno0000003oool05P3oool00`10@400
000005EEE@160?ooo`Kooooo0007oooooaX0oooo00D0eMGE075aL@2ZZZX0ZZZZ0<K6aP050?ooo`03
0:ZZZP1aLG40oooo00D0oooo00D000000:ZZZP3oool0oooo0:ZZZP02000000030;no_`3oool0oooo
00X0oooo00<0P820000000000000100000000`1EEED0oooo0?ooo`0`0?ooo`030;no_`000000oooo
01H0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolI0?ooo`030>[ZjP0@4100_kno0080
oooo00<0_kno061PH03oool00`3oool00`20P800:b/[0;no_`050?ooo`050000002ZZZX0oooo0?oo
o`2ZZZX00P0000000`2o_kl0oooo0?ooo`0:0?ooo`060=oOg`3De=@0oooo0?ooo`2o_kl000001`3o
ool00`20P800eMGE0?ooo`0Z0?ooo`030;no_`000000oooo01H0oooo00<0@4100000001EEED0AP3o
ool6ooooo`001ooooolI0?ooo`0308j>SP000000oooo00<0oooo00<0EEEE08j>SP3oool00P3oool2
05EEE@030:ZZZP3oool0oooo00<0oooo00D000000:ZZZP3oool0oooo0:ZZZP02000000060;no_`3o
ool0>CTi0000001aLG40j^[Z0P3oool02`36a/H0@410000000000000SXj>0?ooo`3Shn<0a/K60?oo
o`2o_kl0000000L0oooo00<000000:ZZZP3oool0703oool0102>SXh00000075aL@3Shn<20?ooo`05
0=GEe@1EEED000000000001ZJVX00`3oool00`2o_kl000000?ooo`0F0?ooo`030410@0000000EEEE
04H0oooo1_ooool000Oooooo6@3oool00`1EEED05ADE0?ooo`030?ooo`030820P00L71`0oooo0080
oooo00@000000:ZZZP3oool0_kno0`3oool00`2ZZZX000000:ZZZP020?ooo`040:ZZZP0000000000
0;no_`80oooo00<071`L0:ZZZP3oool00`3oool00`2o_kl0000005EEE@030?ooo`040<K6aP3Shn<0
_kno000000L0oooo00<000000:ZZZP3oool07@3oool00`1EEED0ZZZZ0?ooo`040?ooo`800000103o
ool00`2o_kl000000?ooo`0F0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo6@3oool0
0`2ZZZX000000?ooo`030?ooo`090:ZZZP000000a/K60?ooo`3Zj^X000000<K6aP3oool0_kno00<0
oooo00<0j^[Z075aL@2ZZZX00P3oool0102ZZZX000000000002o_kl20?ooo`030<K6aP0i>CT0oooo
00<0oooo00<0P8200000002>SXh0103oool00`2ZZZX0_kno000000070?ooo`030000002ZZZX0oooo
01d0oooo00<0eMGE03Ti>@3oool00`3oool00`2ZZZX0000003Ti>@040?ooo`030;no_`000000oooo
01H0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolI0?ooo`030>[ZjP000000eMGE00<0
oooo00H0_kno0000002ZZZX0oooo0:2PX00E5AD20?ooo`030<o?c`3EeMD0oooo00H0oooo00@0ZZZZ
000000000000_kno0`3oool00`1ZJVX0/;2`0?ooo`020?ooo`03071`L0000000ZZZZ00D0oooo00<0
Shn?0000003oool01P3oool00`20P800eMGE0?ooo`0N0?ooo`0306YZJP2EUID0oooo0080oooo00<0
UIFE0000001EEED00`3oool00`3Zj^X0P8200000000G0?ooo`030410@0000000EEEE04H0oooo1_oo
ool000Oooooo6P3oool00`1ZJVX0LG5a0?ooo`020?ooo`060:ZZZP000000a/K60?ooo`1ZJVX0LG5a
0P3oool00`3Zj^X0LG5a0?ooo`060?ooo`040:ZZZP00000000000;no_`@0oooo00<05ADE00000000
00000`0000060?ooo`030>[ZjP1EEED0oooo02P0oooo00<071`L0000000000000`0000000`2ZZZX0
oooo0?ooo`030?ooo`0308j>SP3oool0oooo01D0oooo00<0@4100000001EEED0AP3oool6ooooo`00
1ooooolJ0?ooo`030>[ZjP0i>CT0ZZZZ0080oooo00H0EEEE03Ti>@3oool0hn?S01DE5@36a/H20?oo
o`80EEEE1`3oool0102ZZZX000000000002o_kl40?ooo`0609FEU@36a/H0oooo0?ooo`0[:b/00000
<@3oool01`36a/H0LG5a0?ooo`3oool0>CTi0000002ZZZX07@3oool00`10@400000005EEE@160?oo
o`Kooooo0007oooooa`0oooo00@0ZZZZ08j>SP1EEED000000P36a/H00`2>SXh0EEEE0?ooo`020?oo
o`0309FEU@2ZZZX0oooo00H0oooo00@0ZZZZ000000000000_kno103oool01P3Zj^X0>CTi0?ooo`3o
ool0000005EEEC80oooo00<0EEEE0<K6aP3oool00P00000N0?ooo`030410@0000000EEEE04H0oooo
1_ooool000Oooooo703oool0103Zj^X0EEEE01DE5@2`/;0@0?ooo`040:ZZZP00000000000;no_`D0
oooo00D0ZZZZ0820P03EeMD0000006YZJP0b0?ooo`050>[ZjP10@400gmoO0000000E5AD07P3oool0
0`10@400000005EEE@160?ooo`Kooooo0007oooooa`0oooo00D071`L05EEE@3oool0oooo0:ZZZP0?
0?ooo`040:ZZZP00000000000;no_`H0oooo00@0LG5a08j>SP000000ZZZZ<`3oool01036a/H0JVYZ
0000001EEEDN0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo703oool01@0L71`0hn?S
0?ooo`2o_kl0SXj>00l0oooo00@0ZZZZ000000000000_kno1P3oool0103Shn<0000000000036a/Hd
0?ooo`0302/[:`000000LG5a01h0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooooolL0?oo
o`040>?Sh`2>SXh0ZZZZ0:ZZZQ00oooo00@0ZZZZ000000000000_kno1`3oool00`2>SXh000000?oo
o`0?0?ooo`030000002ZZZX0oooo0280oooo00<0ZZZZ0000002ZZZX07P3oool00`10@400000005EE
E@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno203oool00`1@D500oooo0?oo
o`0>0?ooo`030000002ZZZX0oooo02<0oooo00<0@4100=GEe@3oool07@3oool00`10@400000005EE
E@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno203oool00`3Zj^X0oooo0?oo
o`0>0?ooo`030000002ZZZX0oooo02<0oooo00<0hn?S0?ooo`3oool07@3oool00`10@400000005EE
E@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno6@3oool00`1EEED0a/K60?oo
o`130?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_klI0?ooo`030410@02o_kl0oooo04<0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_aT0oooo00<000000:ZZZP3oool0@`3oool00`10@400000005EE
E@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno6@3oool00`000000ZZZZ0?oo
o`130?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_klI0?ooo`030000002ZZZX0oooo04<0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool`
0?ooo`040:ZZZP00000000000;no_aT0oooo00<0EEEE0<K6aP3oool0@`3oool00`10@400000005EE
E@160?ooo`Kooooo0007oooooc00oooo00@0ZZZZ000000000000_kno6@3oool00`000000ZZZZ0?oo
o`130?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000002o
_klI0?ooo`030000002ZZZX0oooo04<0oooo00<0@4100000001EEED0AP3oool6ooooo`001oooool@
0?ooo`0305EEE@00000000000:<000009P3oool6ooooo`001oooool@0?ooo`0305EEE@0000000000
0:<000009P3oool6ooooo`001oooool@0?ooo`0308j>SP1EEED0EEEE01d0EEEE00@0>CTi00000000
0000@410G`1EEED00`0E5AD0000001`L700P05EEEBH0oooo1_ooool000Oooooo<03oool0102ZZZX0
00000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX0
00000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX0
00000000002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX0
00000000002o_kmO0?ooo`030410@0000000EEEE02H0oooo00<0_kno0>?Sh`3oool07@3oool6oooo
o`001oooool`0?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0203oool00`2>
SXh0oooo0?ooo`0K0?ooo`030>[ZjP0L71`0hn?S01H0oooo00<0eMGE0>?Sh`3oool0103oool6oooo
o`001oooool40?ooo`80j^[Z2@3oool00`3EeMD0Jf][0>[ZjP0F0?ooo`030>[ZjP3oool0oooo00D0
oooo00@0ZZZZ000000000000_knoG`3oool00`10@400000005EEE@060?ooo`030>[ZjP20P800j^[Z
01X0oooo00H0ZZZZ0;no_`3oool0oooo06YZJP1EEEDG0?ooo`0309FEU@2o_kl0oooo00<0oooo1_oo
ool000Oooooo0`3oool00`3Shn<0LG5a0?ooo`060?ooo`060:ZZZP3oool0oooo0?ooo`2>SXh0>CTi
5P3oool00`3Shn<0LG5a0?ooo`050?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001E
EED01@3oool00`3Zj^X0>CTi0?ooo`0L0?ooo`06075aL@3Shn<0oooo0<K6aP000000hn?S5`3oool0
0`1aLG40ZZZZ0?ooo`020?ooo`Kooooo0007ooooo`80oooo00<0j^[Z075aL@3oool01`3oool01`3S
hn<0LG5a0?ooo`3oool0hn?S0000003EeMD05P3oool00`3Shn<0LG5a0?ooo`040?ooo`040:ZZZP00
000000000;no_el0oooo00<0@4100000001EEED01@3oool00`20P800SXj>0?ooo`020?ooo`030<K6
aP1EEED0hn?S00H0oooo00<0EEEE0?ooo`3oool0103oool01P3Zj^X0ZZZZ05EEE@1EEED0JVYZ0:ZZ
ZP80oooo00@0j^[Z075aL@0i>CT0ZZZZ0P3oool00`000000SXj>0?ooo`050?ooo`0308j>SP36a/H0
oooo00D0oooo00H0ZZZZ075aL@1EEED0EEEE0:ZZZP3Shn<30?ooo`030>?Sh`000000j^[Z0080oooo
1_ooool000Oooooo0P3oool00`1EEED0hn?S0?ooo`080?ooo`0608j>SP3EeMD0oooo0?ooo`0i>CT0
UIFE5`3oool00`2>SXh0P8200?ooo`030?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000
001EEED01@3oool00`0E5AD0hn?S0?ooo`020?ooo`0405EEE@000000SXj>0>[ZjPD0oooo00<00000
0?ooo`3oool01P3oool00`2>SXh000000;no_`030?ooo`040=GEe@00000000000>?Sh`80oooo0P1E
EED60?ooo`0305EEE@2ZZZX0oooo00H0oooo00<0hn?S00000020P8001P3oool0100i>CT0UIFE0?oo
o`3oool6ooooo`001oooool00`3oool0ZZZZ051@D0030?ooo`090=oOg`000000JVYZ0=GEe@3oool0
_kno01DE5@000000clo?0080oooo00<0P820051@D03oool01@3oool00`1EEED0_kno0?ooo`050?oo
o`060;no_`20P800000005EEE@2o_kl0j^[Z103oool00`0P8200j^[Z0?ooo`020?ooo`040:ZZZP00
000000000;no_el0oooo00<0@4100000001EEED0103oool00`2o_kl0410@0?ooo`030?ooo`040:ZZ
ZP000000j^[Z0<o?c`D0oooo00<000000?ooo`3oool01P3oool00`2ZZZX000000;no_`040?ooo`03
0;no_`3Zj^X0oooo0080oooo00<0ZZZZ0000003Zj^X01@3oool00`1EEED0ZZZZ0?ooo`070?ooo`03
00000020P800oooo00D0oooo00@0P820051@D03oool0oooo1_ooool000Oooooo00<0oooo03Ti>@20
P8000`3oool0203Zj^X000000:ZZZP36a/H0j^[Z0?ooo`1EEED0SXj>0`3oool00`3Shn<05ADE0?oo
o`050?ooo`0305EEE@2o_kl0oooo00L0oooo00<000000:ZZZP3oool01@3oool00`10@400SXj>0?oo
o`020?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0103oool00`1aLG40@410
0?ooo`040?ooo`030000002ZZZX0oooo00D0oooo00<000000?ooo`3oool01P3oool00`2ZZZX00000
0;no_`0:0?ooo`030000002ZZZX0oooo00@0oooo00<0EEEE0:ZZZP3oool01`3oool00`000000P820
0?ooo`050?ooo`040:ZZZP000000oooo0?ooo`Kooooo0007ooooo`030?ooo`000000ZZZZ00@0oooo
00@071`L075aL@3oool0j^[Z1`3oool00`0E5AD0a/K60?ooo`040?ooo`0305EEE@2o_kl0oooo00L0
oooo00<000000:ZZZP3oool01@3oool00`20P800>CTi0?ooo`020?ooo`040:ZZZP00000000000;no
_el0oooo00<0@4100000001EEED0103oool00`1EEED0@4100?ooo`040?ooo`80EEEE0P3oool405EE
E@030000001EEED0EEEE0080EEEE103oool00`2ZZZX000000;no_`0:0?ooo`80EEEE00<0oooo08j>
SP1EEED00P1EEED00`0L71`0>CTi05EEE@0205EEE@030<K6aP3oool0oooo0080oooo00<000000820
P03oool01@3oool0102ZZZX000000?ooo`3oool6ooooo`001oooool00`2ZZZX000000;no_`040?oo
o`03075aL@0i>CT0oooo00P0oooo00<0EEEE08j>SP3oool0103oool00`1EEED0_kno0?ooo`070?oo
o`030000002ZZZX0oooo00D0oooo00<0P8200000003oool00P3oool0102ZZZX000000000002o_kmO
0?ooo`030410@0000000EEEE00@0oooo00<0EEEE0410@03oool0103oool0102>SXh071`L0?ooo`3o
ool40:ZZZP030000002ZZZX0ZZZZ0080ZZZZ103oool00`2ZZZX000000;no_`0:0?ooo`0408j>SP00
0000oooo0<K6aP<0ZZZZ00<0>CTi075aL@2ZZZX00P2ZZZX00`3Shn<0oooo0?ooo`020?ooo`030000
0020P800oooo00D0oooo00@0ZZZZ0000003oool0oooo1_ooool000Oooooo00<0ZZZZ0000002o_kl0
103oool00`2o_kl000000>[ZjP080?ooo`04092@T00[:b/0oooo0820P0<0@41000<05ADE030`<010
@4000P10@4000`2o_kl0oooo0?ooo`020?ooo`030000002ZZZX0oooo00D0oooo00<0P8200000003o
ool00P3oool0102ZZZX000000000002o_kmO0?ooo`030410@0000000EEEE00@0oooo00<0JVYZ0410
@03oool0103oool00`3Zj^X000000<o?c`050?ooo`030000003oool0oooo00H0oooo00<0ZZZZ0000
002o_kl02P3oool00`3Zj^X000000<o?c`040?ooo`0305EEE@2ZZZX0oooo00L0oooo00<000000820
P03oool01@3oool0102ZZZX0820P0?ooo`3oool6ooooo`001oooool00`2ZZZX000000;no_`050?oo
o`0301`L702>SXh0oooo00L0oooo00<0eMGE0000003Shn<0103oool00`1EEED0_kno0?ooo`070?oo
o`030000002ZZZX0oooo00D0oooo00<0P8200000003oool00P3oool0102ZZZX000000000002o_kmO
0?ooo`030410@0000000EEEE00@0oooo00<0ZZZZ01DE5@3oool01@3oool00`0i>CT0UIFE0?ooo`04
0?ooo`030000003oool0oooo00H0oooo00<0ZZZZ0000002o_kl02`3oool00`0L71`0P8200?ooo`03
0?ooo`0305EEE@2ZZZX0oooo00L0oooo00<000000820P03oool01@3oool205EEE@80oooo1_ooool0
00Oooooo00<0hn?S0000002o_kl01@3oool00`1aLG40EEEE0?ooo`080?ooo`030000002>SXh0oooo
00<0oooo00<0EEEE0;no_`3oool01`3oool00`000000ZZZZ0?ooo`050?ooo`0306YZJP1EEED0oooo
0080oooo00@0ZZZZ000000000000_knoG`3oool00`10@400000005EEE@050?ooo`0301DE5@3Shn<0
oooo00<0oooo00<0ZZZZ08j>SP2ZZZX01@3oool00`000000oooo0?ooo`060?ooo`030:ZZZP000000
_kno00T0oooo00@0hn?S0:ZZZP2>SXh0UIFE103oool00`1EEED0ZZZZ0?ooo`070?ooo`0300000020
P800oooo00D0oooo00@0>CTi09FEU@3oool0oooo1_ooool000Oooooo00<0oooo01`L7020P800103o
ool00`36a/H0EEEE000000080?ooo`030:ZZZP0L71`0EEEE00@0oooo00<0EEEE0;no_`3oool01`3o
ool00`000000ZZZZ0?ooo`050?ooo`030410@02>SXh0oooo0080oooo00@0ZZZZ000000000000_kno
G`3oool00`10@400000005EEE@050?ooo`0306YZJP2>SXh0oooo00/0oooo00<0ZZZZ0?ooo`3oool0
1P3oool00`2ZZZX000000;no_`0A0?ooo`030<K6aP3Shn<0oooo00L0oooo00<000000820P03oool0
103oool00`3Shn<071`L0>[ZjP020?ooo`Kooooo0007ooooo`030?ooo`2ZZZX0D51@00H0oooo00<0
_kno0?ooo`3oool01`3oool00`3Zj^X0_kno0?ooo`030?ooo`030820P03?cll0oooo00L0oooo00<0
00000:ZZZP3oool01@3oool00`0P8200j^[Z0?ooo`020?ooo`040:ZZZP00000000000;no_el0oooo
00<0@4100000001EEED01@3oool00`3_knl0EEEE0=GEe@040?ooo`030>[ZjP20P800j^[Z00/0oooo
00D0kno_0;no_`1oOgl000000;no_`0;0?ooo`030;no_`2@T900oooo00/0oooo0P2o_kl00`000000
P8200?ooo`040?ooo`0305EEE@2o_kl0oooo0080oooo1_ooool000Oooooo0P3oool00`10@400hn?S
0?ooo`0N0?ooo`030000002ZZZX0oooo00@0oooo00<0SXj>09FEU@3oool00`3oool0102ZZZX00000
0000002o_kmO0?ooo`030410@0000000EEEE00L0oooo00<0LG5a0>?Sh`3oool00P3oool00`2ZZZX0
00000:ZZZP0<0?ooo`040>?Sh`1aLG4000000;no_`/0oooo00<0EEEE0000003oool0303oool00`2>
SXh071`L0820P0040?ooo`03075aL@3Shn<0oooo00<0oooo1_ooool000Oooooo0P3oool00`3Zj^X0
EEEE0?ooo`040?ooo`0301`L701EEED0oooo00L0oooo00<0LG5a00000036a/H02`3oool0102ZZZX0
EEEE0000002ZZZX40?ooo`030>?Sh`1EEED0oooo00@0oooo00@0ZZZZ000000000000_knoG`3oool0
0`10@400000005EEE@080?ooo`030:ZZZP3oool0oooo0080oooo00<0ZZZZ0?ooo`3oool03@3oool0
0`3Shn<0j^[Z0?ooo`0:0?ooo`030>?Sh`2o_kl0oooo00h0oooo00H0eMGE0?ooo`3oool0oooo0;no
_`3Shn<50?ooo`Kooooo0007ooooo`<0oooo00<0hn?S075aL@3oool00`3oool00`0L71`0EEEE0?oo
o`070?ooo`03075aL@000000a/K600`0oooo00<0hn?S05EEE@2ZZZX00`3oool00`3Shn<0LG5a0?oo
o`050?ooo`040:ZZZP00000000000;no_el0oooo00<0@4100000001EEED0AP3oool6ooooo`001ooo
ool50?ooo`030>[ZjP3oool0oooo0200oooo00<0e=CD0?ooo`3oool01@3oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool000Oooooo<03oool0102ZZZX000000000
002o_kmO0?ooo`030410@0000000EEEE04H0oooo1_ooool00>Wooooo003Yooooo`00jOooool00>Wo
oooo0000\
\>"],
  ImageRangeCache->{{{2.3125, 232.875}, {175.25, 0}} -> {-25.3376, -15.5257, \
4.05886, 4.05886}}],

Cell["Fig. 7.11 Quantities associated with area weighting.", "Caption",
  CellTags->"Fig. 7.11"],

Cell["We then increment the density according to the formulae", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[CapitalDelta]\[Rho]\_\(i\ j\)\), " ", "=", 
          RowBox[{"m", " ", 
            RowBox[{\(A\_1\), "/", 
              RowBox[{"(", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["A",
                        FontSlant->"Italic"]}]], "2"], ")"}]}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{\(\[CapitalDelta]\[Rho]\_\(i\ j\_1\)\), " ", "=", " ", 
          RowBox[{"m", " ", 
            RowBox[{\(A\_2\), "/", 
              RowBox[{"(", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["A",
                        FontSlant->"Italic"]}]], "2"], ")"}]}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{\(\[CapitalDelta]\[Rho]\_\(\(i\_1\) j\_1\)\), " ", "=", " ", 
          RowBox[{"m", " ", 
            RowBox[{\(A\_3\), "/", 
              RowBox[{"(", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["A",
                        FontSlant->"Italic"]}]], "2"], ")"}]}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{\(\[CapitalDelta]\[Rho]\_\(\(i\_1\) j\)\), " ", "=", " ", 
          RowBox[{"m", " ", 
            RowBox[{\(A\_4\), "/", 
              RowBox[{
                RowBox[{"(", 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["A",
                          FontSlant->"Italic"]}]], "2"], ")"}], "."}]}]}]}]}],
       TraditionalForm]]]], "NE3",
  CellTags->"(7.3.7)"],

Cell[TextData[{
  "In other words, the density increment at point ",
  Cell[BoxData[
      \(TraditionalForm\`\((i, j)\)\)]],
  " is weighted by the area of the rectangle in the ",
  StyleBox["opposite corner",
    FontSlant->"Italic"],
  ".  The reasoning behind this type of weighting is as follows. First, one \
can see that Eq. ",
  ButtonBox["(7.3.5)",
    ButtonData:>{"Chapter7.nb", "(7.3.5)"},
    ButtonStyle->"Hyperlink"],
  "  is still satisfied, because ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Sum]\+\(i = 1\)\%4 A\_i\), "=", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["A",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  ". Second, one can also see that the closer the particle is to a given grid \
point, the larger the area associated with that grid point,  and the more \
mass is assigned to that grid point."
}], "Text"],

Cell[TextData[{
  "\tAlso, this type of weighting can be easily applied to one- or \
three-dimensional grids. In fact, we have used a form of one-dimensional area \
weighting already, in a different context; see the discussion surrounding \
Fig. ",
  ButtonBox["6.11",
    ButtonData:>{"Chapter6.nb", "Fig. 6.11"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "The following module takes a single particle at position ",
  Cell[BoxData[
      \(TraditionalForm\`z = {x, y}\)]],
  " and  increments the density matrix ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(i\ j\)\)]],
  " according to Eq. ",
  ButtonBox["(7.3.6)",
    ButtonData:>{"Chapter7.nb", "(7.3.6)"},
    ButtonStyle->"Hyperlink"],
  " :"
}], "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(setden[z_]\), " ", ":=", " ", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({x, y, \[Delta]x, \[Delta]y, \[Delta]x1, \[Delta]y1, i, 
              j, i1, j1}\), ",", "\[IndentingNewLine]", 
            StyleBox[\( (*\ x\ and\ y\ positions\ of\ particle\ *) \),
              FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
            
            RowBox[{\(x = z[\([1]\)]\), ";", \(y = z[\([2]\)]\), ";", 
              "\[IndentingNewLine]", 
              StyleBox[\( (*\ lengths\ of\ the\ rectangle\ sides\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(\[Delta]x = Mod[x, \[CapitalDelta]x]\),
               ";", "\[IndentingNewLine]", \(\[Delta]y = 
                Mod[y, \[CapitalDelta]y]\), ";", 
              "\[IndentingNewLine]", \(\[Delta]x1\  = \ \[CapitalDelta]x - \
\[Delta]x\), ";", 
              "\[IndentingNewLine]", \(\[Delta]y1\  = \ \[CapitalDelta]y - \
\[Delta]y\), ";", "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  determine\ surrounding\ grid\ points\ \((values\ \
incremented\ by\ 1\ in\ accord\ with\ Mathematica\ list\ notation)\)\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(i\  = 
                Quotient[x, \[CapitalDelta]x] + 1\), ";", 
              "\[IndentingNewLine]", \(j = \ 
                Quotient[y, \[CapitalDelta]y] + 1\), ";", 
              "\[IndentingNewLine]", \(i1\  = \ 1 + Mod[i, M]\), ";", 
              "\[IndentingNewLine]", \(j1\  = \ 1 + Mod[j, M]\), ";", 
              "\[IndentingNewLine]", 
              StyleBox[\( (*\ increment\ the\ density\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(\[Rho][\([i, 
                    j]\)]\  = \ \[Rho][\([i, j]\)] + \[Delta]x1*\[Delta]y1\), 
              ";", "\[IndentingNewLine]", \(\[Rho][\([i, 
                    j1]\)]\  = \[Rho][\([i, j1]\)] + \[Delta]x1*\[Delta]y\), 
              ";", "\[IndentingNewLine]", \(\[Rho][\([i1, 
                    j]\)]\  = \ \[Rho][\([i1, 
                      j]\)] + \ \[Delta]x*\[Delta]y1\), ";", 
              "\[IndentingNewLine]", \(\[Rho][\([i1, 
                    j1]\)]\  = \ \[Rho][\([i1, j1]\)] + \[Delta]x*\[Delta]y\),
               ";"}]}], "]"}]}], ";"}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.68"],

Cell[TextData[{
  "Note that matrix indices are increased by 1 over those in Eqs. ",
  ButtonBox["(7.3.3)",
    ButtonData:>{"Chapter7.nb", "(7.3.3)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.3.4)",
    ButtonData:>{"Chapter7.nb", "(7.3.4)"},
    ButtonStyle->"Hyperlink"],
  " ,  in order to comply with list notation:  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\({i, j}\)\(\ \)\(=\)\(\ \)\({0, 0}\)\(\ \)\)\)]],
  "in the notation of Eq. ",
  ButtonBox["(7.3.3)",
    ButtonData:>{"Chapter7.nb", "(7.3.3)"},
    ButtonStyle->"Hyperlink"],
  "  corresponds to element ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Rho][\([1, 1]\)]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " of the matrix ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Rho]",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ".   Also, note that this whole  procedure is applied to only one particle. \
We must now apply it to all the particles. Before we do so,  note that we did \
not divide the density increment by ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["A",
                FontSlant->"Italic"]}]], "2"], TraditionalForm]]],
  "; nor did we multiply by ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ". That's because these factors are the same for every particle. It is more \
efficient to wait until we have incremented the density due to all the \
particles, then multiply the density matrix by these constant factors \
(assuming that there are more particles than grid points, as is usually the \
case).  The following module evaluates the density for given particle \
positions:"
}], "Text"],

Cell[BoxData[
    RowBox[{\(density[r_]\), " ", ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({\[CapitalDelta]A}\), ",", "\[IndentingNewLine]", 
          StyleBox[\( (*area\ of\ a\ cell*) \),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
          
          RowBox[{\(\[CapitalDelta]A = \[CapitalDelta]x*\[CapitalDelta]y\), 
            ";", "\[IndentingNewLine]", 
            StyleBox[\( (*initialize\ the\ density\ matrix*) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Rho]\  = \ Table[0, {M}, {M}]\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*increment\ the\ density\ for\ all\ N\ particles\ at\
\ once*) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Map[setden, r]\), ";", 
            "\[IndentingNewLine]", 
            StyleBox[
              RowBox[{"(*", 
                RowBox[{
                "properly", " ", "normalize", " ", Cell[TextData[StyleBox[
                  "\[Rho]",
                    FontColor->RGBColor[1, 0, 0]]]]}], "*)"}],
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Rho] = \[Rho]*m/\[CapitalDelta]A^2\), 
            " ", ";"}]}], "]"}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.69"],

Cell[TextData[{
  "We use the ",
  StyleBox["Map",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function in order to apply our function ",
  Cell[BoxData[
      FormBox[
        StyleBox["setden",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " to the list of positions  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\({{x\_1, y\_1},  ... , {x\_N, y\_N}}\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tAs a test of the module, in Cell ",
  ButtonBox["7.70",
    ButtonData:>"Cell 7.70",
    ButtonStyle->"Hyperlink"],
  " we evaluate the density due to 20 particles with unit mass, distributed \
uniformly along the diagonal of the domain."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(r = 
        Table[{\[CapitalDelta]x\ i, \[CapitalDelta]x\ i}, {i, 0, 
            M - 1}];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(density[r];\)\), "\n", 
    \(\(ListContourPlot[\[Rho]];\)\ \), "\n", 
    \(Sum[\[CapitalDelta]x\ \[CapitalDelta]y\ \[Rho][\([i, j]\)], {i, 1, 
        M}, {j, 1, M}]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.70"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0313765 0.0506073 -0.0313765 0.0506073 [
[.09514 -0.0125 -9 -9 ]
[.09514 -0.0125 9 0 ]
[.22166 -0.0125 -3 -9 ]
[.22166 -0.0125 3 0 ]
[.34818 -0.0125 -9 -9 ]
[.34818 -0.0125 9 0 ]
[.4747 -0.0125 -6 -9 ]
[.4747 -0.0125 6 0 ]
[.60121 -0.0125 -12 -9 ]
[.60121 -0.0125 12 0 ]
[.72773 -0.0125 -6 -9 ]
[.72773 -0.0125 6 0 ]
[.85425 -0.0125 -12 -9 ]
[.85425 -0.0125 12 0 ]
[.98077 -0.0125 -6 -9 ]
[.98077 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .09514 -18 -4.5 ]
[-0.0125 .09514 0 4.5 ]
[-0.0125 .22166 -6 -4.5 ]
[-0.0125 .22166 0 4.5 ]
[-0.0125 .34818 -18 -4.5 ]
[-0.0125 .34818 0 4.5 ]
[-0.0125 .4747 -12 -4.5 ]
[-0.0125 .4747 0 4.5 ]
[-0.0125 .60121 -24 -4.5 ]
[-0.0125 .60121 0 4.5 ]
[-0.0125 .72773 -12 -4.5 ]
[-0.0125 .72773 0 4.5 ]
[-0.0125 .85425 -24 -4.5 ]
[-0.0125 .85425 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.09514 0 m
.09514 .00625 L
s
[(2.5)] .09514 -0.0125 0 1 Mshowa
.22166 0 m
.22166 .00625 L
s
[(5)] .22166 -0.0125 0 1 Mshowa
.34818 0 m
.34818 .00625 L
s
[(7.5)] .34818 -0.0125 0 1 Mshowa
.4747 0 m
.4747 .00625 L
s
[(10)] .4747 -0.0125 0 1 Mshowa
.60121 0 m
.60121 .00625 L
s
[(12.5)] .60121 -0.0125 0 1 Mshowa
.72773 0 m
.72773 .00625 L
s
[(15)] .72773 -0.0125 0 1 Mshowa
.85425 0 m
.85425 .00625 L
s
[(17.5)] .85425 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(20)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.12045 0 m
.12045 .00375 L
s
.14575 0 m
.14575 .00375 L
s
.17105 0 m
.17105 .00375 L
s
.19636 0 m
.19636 .00375 L
s
.24696 0 m
.24696 .00375 L
s
.27227 0 m
.27227 .00375 L
s
.29757 0 m
.29757 .00375 L
s
.32287 0 m
.32287 .00375 L
s
.37348 0 m
.37348 .00375 L
s
.39879 0 m
.39879 .00375 L
s
.42409 0 m
.42409 .00375 L
s
.44939 0 m
.44939 .00375 L
s
.5 0 m
.5 .00375 L
s
.5253 0 m
.5253 .00375 L
s
.55061 0 m
.55061 .00375 L
s
.57591 0 m
.57591 .00375 L
s
.62652 0 m
.62652 .00375 L
s
.65182 0 m
.65182 .00375 L
s
.67713 0 m
.67713 .00375 L
s
.70243 0 m
.70243 .00375 L
s
.75304 0 m
.75304 .00375 L
s
.77834 0 m
.77834 .00375 L
s
.80364 0 m
.80364 .00375 L
s
.82895 0 m
.82895 .00375 L
s
.87955 0 m
.87955 .00375 L
s
.90486 0 m
.90486 .00375 L
s
.93016 0 m
.93016 .00375 L
s
.95547 0 m
.95547 .00375 L
s
.06984 0 m
.06984 .00375 L
s
.04453 0 m
.04453 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .09514 m
.00625 .09514 L
s
[(2.5)] -0.0125 .09514 1 0 Mshowa
0 .22166 m
.00625 .22166 L
s
[(5)] -0.0125 .22166 1 0 Mshowa
0 .34818 m
.00625 .34818 L
s
[(7.5)] -0.0125 .34818 1 0 Mshowa
0 .4747 m
.00625 .4747 L
s
[(10)] -0.0125 .4747 1 0 Mshowa
0 .60121 m
.00625 .60121 L
s
[(12.5)] -0.0125 .60121 1 0 Mshowa
0 .72773 m
.00625 .72773 L
s
[(15)] -0.0125 .72773 1 0 Mshowa
0 .85425 m
.00625 .85425 L
s
[(17.5)] -0.0125 .85425 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(20)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .12045 m
.00375 .12045 L
s
0 .14575 m
.00375 .14575 L
s
0 .17105 m
.00375 .17105 L
s
0 .19636 m
.00375 .19636 L
s
0 .24696 m
.00375 .24696 L
s
0 .27227 m
.00375 .27227 L
s
0 .29757 m
.00375 .29757 L
s
0 .32287 m
.00375 .32287 L
s
0 .37348 m
.00375 .37348 L
s
0 .39879 m
.00375 .39879 L
s
0 .42409 m
.00375 .42409 L
s
0 .44939 m
.00375 .44939 L
s
0 .5 m
.00375 .5 L
s
0 .5253 m
.00375 .5253 L
s
0 .55061 m
.00375 .55061 L
s
0 .57591 m
.00375 .57591 L
s
0 .62652 m
.00375 .62652 L
s
0 .65182 m
.00375 .65182 L
s
0 .67713 m
.00375 .67713 L
s
0 .70243 m
.00375 .70243 L
s
0 .75304 m
.00375 .75304 L
s
0 .77834 m
.00375 .77834 L
s
0 .80364 m
.00375 .80364 L
s
0 .82895 m
.00375 .82895 L
s
0 .87955 m
.00375 .87955 L
s
0 .90486 m
.00375 .90486 L
s
0 .93016 m
.00375 .93016 L
s
0 .95547 m
.00375 .95547 L
s
0 .06984 m
.00375 .06984 L
s
0 .04453 m
.00375 .04453 L
s
0 .01923 m
.00375 .01923 L
s
.25 Mabswid
0 0 m
0 1 L
s
.09514 .99375 m
.09514 1 L
s
.22166 .99375 m
.22166 1 L
s
.34818 .99375 m
.34818 1 L
s
.4747 .99375 m
.4747 1 L
s
.60121 .99375 m
.60121 1 L
s
.72773 .99375 m
.72773 1 L
s
.85425 .99375 m
.85425 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.12045 .99625 m
.12045 1 L
s
.14575 .99625 m
.14575 1 L
s
.17105 .99625 m
.17105 1 L
s
.19636 .99625 m
.19636 1 L
s
.24696 .99625 m
.24696 1 L
s
.27227 .99625 m
.27227 1 L
s
.29757 .99625 m
.29757 1 L
s
.32287 .99625 m
.32287 1 L
s
.37348 .99625 m
.37348 1 L
s
.39879 .99625 m
.39879 1 L
s
.42409 .99625 m
.42409 1 L
s
.44939 .99625 m
.44939 1 L
s
.5 .99625 m
.5 1 L
s
.5253 .99625 m
.5253 1 L
s
.55061 .99625 m
.55061 1 L
s
.57591 .99625 m
.57591 1 L
s
.62652 .99625 m
.62652 1 L
s
.65182 .99625 m
.65182 1 L
s
.67713 .99625 m
.67713 1 L
s
.70243 .99625 m
.70243 1 L
s
.75304 .99625 m
.75304 1 L
s
.77834 .99625 m
.77834 1 L
s
.80364 .99625 m
.80364 1 L
s
.82895 .99625 m
.82895 1 L
s
.87955 .99625 m
.87955 1 L
s
.90486 .99625 m
.90486 1 L
s
.93016 .99625 m
.93016 1 L
s
.95547 .99625 m
.95547 1 L
s
.06984 .99625 m
.06984 1 L
s
.04453 .99625 m
.04453 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .09514 m
1 .09514 L
s
.99375 .22166 m
1 .22166 L
s
.99375 .34818 m
1 .34818 L
s
.99375 .4747 m
1 .4747 L
s
.99375 .60121 m
1 .60121 L
s
.99375 .72773 m
1 .72773 L
s
.99375 .85425 m
1 .85425 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .12045 m
1 .12045 L
s
.99625 .14575 m
1 .14575 L
s
.99625 .17105 m
1 .17105 L
s
.99625 .19636 m
1 .19636 L
s
.99625 .24696 m
1 .24696 L
s
.99625 .27227 m
1 .27227 L
s
.99625 .29757 m
1 .29757 L
s
.99625 .32287 m
1 .32287 L
s
.99625 .37348 m
1 .37348 L
s
.99625 .39879 m
1 .39879 L
s
.99625 .42409 m
1 .42409 L
s
.99625 .44939 m
1 .44939 L
s
.99625 .5 m
1 .5 L
s
.99625 .5253 m
1 .5253 L
s
.99625 .55061 m
1 .55061 L
s
.99625 .57591 m
1 .57591 L
s
.99625 .62652 m
1 .62652 L
s
.99625 .65182 m
1 .65182 L
s
.99625 .67713 m
1 .67713 L
s
.99625 .70243 m
1 .70243 L
s
.99625 .75304 m
1 .75304 L
s
.99625 .77834 m
1 .77834 L
s
.99625 .80364 m
1 .80364 L
s
.99625 .82895 m
1 .82895 L
s
.99625 .87955 m
1 .87955 L
s
.99625 .90486 m
1 .90486 L
s
.99625 .93016 m
1 .93016 L
s
.99625 .95547 m
1 .95547 L
s
.99625 .06984 m
1 .06984 L
s
.99625 .04453 m
1 .04453 L
s
.99625 .01923 m
1 .01923 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.9 g
.01923 .02122 m
.04408 .06984 L
.06984 .07569 L
.11459 .12045 L
.12045 .1263 L
.1652 .17105 L
.17105 .17691 L
.21581 .22166 L
.22166 .22751 L
.26641 .27227 L
.27227 .27812 L
.31702 .32287 L
.32287 .32873 L
.36763 .37348 L
.37348 .37934 L
.41823 .42409 L
.42409 .42994 L
.46884 .4747 L
.4747 .48055 L
.51945 .5253 L
.5253 .53116 L
.57006 .57591 L
.57591 .58177 L
.62066 .62652 L
.62652 .63237 L
.67127 .67713 L
.67713 .68298 L
.72188 .72773 L
.72773 .73359 L
.77249 .77834 L
.77834 .78419 L
.82309 .82895 L
.82895 .8348 L
.8737 .87955 L
.87955 .88541 L
.92431 .93016 L
.93016 .95592 L
.97878 .98077 L
.01923 .98077 L
F
0 g
.01923 .02122 m
.04408 .06984 L
.06984 .07569 L
.11459 .12045 L
.12045 .1263 L
.1652 .17105 L
.17105 .17691 L
.21581 .22166 L
.22166 .22751 L
.26641 .27227 L
.27227 .27812 L
.31702 .32287 L
.32287 .32873 L
.36763 .37348 L
.37348 .37934 L
.41823 .42409 L
.42409 .42994 L
.46884 .4747 L
.4747 .48055 L
.51945 .5253 L
.5253 .53116 L
.57006 .57591 L
.57591 .58177 L
.62066 .62652 L
.62652 .63237 L
.67127 .67713 L
.67713 .68298 L
.72188 .72773 L
.72773 .73359 L
.77249 .77834 L
.77834 .78419 L
.82309 .82895 L
.82895 .8348 L
.8737 .87955 L
.87955 .88541 L
.92431 .93016 L
.93016 .95592 L
.97878 .98077 L
s
.8 g
.01923 .02406 m
.03956 .06984 L
.06984 .08171 L
.10857 .12045 L
.12045 .13232 L
.15918 .17105 L
.17105 .18293 L
.20979 .22166 L
.22166 .23353 L
.26039 .27227 L
.27227 .28414 L
.311 .32287 L
.32287 .33475 L
.36161 .37348 L
.37348 .38536 L
.41222 .42409 L
.42409 .43596 L
.46282 .4747 L
.4747 .48657 L
.51343 .5253 L
.5253 .53718 L
.56404 .57591 L
.57591 .58778 L
.61464 .62652 L
.62652 .63839 L
.66525 .67713 L
.67713 .689 L
.71586 .72773 L
.72773 .73961 L
.76647 .77834 L
.77834 .79021 L
.81707 .82895 L
.82895 .84082 L
.86768 .87955 L
.87955 .89143 L
.91829 .93016 L
.93016 .96044 L
.97594 .98077 L
.01923 .98077 L
F
0 g
.01923 .02406 m
.03956 .06984 L
.06984 .08171 L
.10857 .12045 L
.12045 .13232 L
.15918 .17105 L
.17105 .18293 L
.20979 .22166 L
.22166 .23353 L
.26039 .27227 L
.27227 .28414 L
.311 .32287 L
.32287 .33475 L
.36161 .37348 L
.37348 .38536 L
.41222 .42409 L
.42409 .43596 L
.46282 .4747 L
.4747 .48657 L
.51343 .5253 L
.5253 .53718 L
.56404 .57591 L
.57591 .58778 L
.61464 .62652 L
.62652 .63839 L
.66525 .67713 L
.67713 .689 L
.71586 .72773 L
.72773 .73961 L
.76647 .77834 L
.77834 .79021 L
.81707 .82895 L
.82895 .84082 L
.86768 .87955 L
.87955 .89143 L
.91829 .93016 L
.93016 .96044 L
.97594 .98077 L
s
.7 g
.01923 .02709 m
.03603 .06984 L
.06984 .08681 L
.10347 .12045 L
.12045 .13742 L
.15408 .17105 L
.17105 .18803 L
.20468 .22166 L
.22166 .23864 L
.25529 .27227 L
.27227 .28924 L
.3059 .32287 L
.32287 .33985 L
.35651 .37348 L
.37348 .39046 L
.40711 .42409 L
.42409 .44106 L
.45772 .4747 L
.4747 .49167 L
.50833 .5253 L
.5253 .54228 L
.55894 .57591 L
.57591 .59289 L
.60954 .62652 L
.62652 .64349 L
.66015 .67713 L
.67713 .6941 L
.71076 .72773 L
.72773 .74471 L
.76136 .77834 L
.77834 .79532 L
.81197 .82895 L
.82895 .84592 L
.86258 .87955 L
.87955 .89653 L
.91319 .93016 L
.93016 .96397 L
.97291 .98077 L
.01923 .98077 L
F
0 g
.01923 .02709 m
.03603 .06984 L
.06984 .08681 L
.10347 .12045 L
.12045 .13742 L
.15408 .17105 L
.17105 .18803 L
.20468 .22166 L
.22166 .23864 L
.25529 .27227 L
.27227 .28924 L
.3059 .32287 L
.32287 .33985 L
.35651 .37348 L
.37348 .39046 L
.40711 .42409 L
.42409 .44106 L
.45772 .4747 L
.4747 .49167 L
.50833 .5253 L
.5253 .54228 L
.55894 .57591 L
.57591 .59289 L
.60954 .62652 L
.62652 .64349 L
.66015 .67713 L
.67713 .6941 L
.71076 .72773 L
.72773 .74471 L
.76136 .77834 L
.77834 .79532 L
.81197 .82895 L
.82895 .84592 L
.86258 .87955 L
.87955 .89653 L
.91319 .93016 L
.93016 .96397 L
.97291 .98077 L
s
.6 g
.01923 .03037 m
.03306 .06984 L
.06984 .09144 L
.09884 .12045 L
.12045 .14205 L
.14945 .17105 L
.17105 .19266 L
.20005 .22166 L
.22166 .24327 L
.25066 .27227 L
.27227 .29387 L
.30127 .32287 L
.32287 .34448 L
.35188 .37348 L
.37348 .39509 L
.40248 .42409 L
.42409 .44569 L
.45309 .4747 L
.4747 .4963 L
.5037 .5253 L
.5253 .54691 L
.55431 .57591 L
.57591 .59752 L
.60491 .62652 L
.62652 .64812 L
.65552 .67713 L
.67713 .69873 L
.70613 .72773 L
.72773 .74934 L
.75673 .77834 L
.77834 .79995 L
.80734 .82895 L
.82895 .85055 L
.85795 .87955 L
.87955 .90116 L
.90856 .93016 L
.93016 .96694 L
.96963 .98077 L
.01923 .98077 L
F
0 g
.01923 .03037 m
.03306 .06984 L
.06984 .09144 L
.09884 .12045 L
.12045 .14205 L
.14945 .17105 L
.17105 .19266 L
.20005 .22166 L
.22166 .24327 L
.25066 .27227 L
.27227 .29387 L
.30127 .32287 L
.32287 .34448 L
.35188 .37348 L
.37348 .39509 L
.40248 .42409 L
.42409 .44569 L
.45309 .4747 L
.4747 .4963 L
.5037 .5253 L
.5253 .54691 L
.55431 .57591 L
.57591 .59752 L
.60491 .62652 L
.62652 .64812 L
.65552 .67713 L
.67713 .69873 L
.70613 .72773 L
.72773 .74934 L
.75673 .77834 L
.77834 .79995 L
.80734 .82895 L
.82895 .85055 L
.85795 .87955 L
.87955 .90116 L
.90856 .93016 L
.93016 .96694 L
.96963 .98077 L
s
.5 g
.01923 .03393 m
.03045 .06984 L
.06984 .0958 L
.09448 .12045 L
.12045 .14641 L
.14509 .17105 L
.17105 .19702 L
.19569 .22166 L
.22166 .24763 L
.2463 .27227 L
.27227 .29823 L
.29691 .32287 L
.32287 .34884 L
.34752 .37348 L
.37348 .39945 L
.39812 .42409 L
.42409 .45006 L
.44873 .4747 L
.4747 .50066 L
.49934 .5253 L
.5253 .55127 L
.54994 .57591 L
.57591 .60188 L
.60055 .62652 L
.62652 .65248 L
.65116 .67713 L
.67713 .70309 L
.70177 .72773 L
.72773 .7537 L
.75237 .77834 L
.77834 .80431 L
.80298 .82895 L
.82895 .85491 L
.85359 .87955 L
.87955 .90552 L
.9042 .93016 L
.93016 .96955 L
.96607 .98077 L
.01923 .98077 L
F
0 g
.01923 .03393 m
.03045 .06984 L
.06984 .0958 L
.09448 .12045 L
.12045 .14641 L
.14509 .17105 L
.17105 .19702 L
.19569 .22166 L
.22166 .24763 L
.2463 .27227 L
.27227 .29823 L
.29691 .32287 L
.32287 .34884 L
.34752 .37348 L
.37348 .39945 L
.39812 .42409 L
.42409 .45006 L
.44873 .4747 L
.4747 .50066 L
.49934 .5253 L
.5253 .55127 L
.54994 .57591 L
.57591 .60188 L
.60055 .62652 L
.62652 .65248 L
.65116 .67713 L
.67713 .70309 L
.70177 .72773 L
.72773 .7537 L
.75237 .77834 L
.77834 .80431 L
.80298 .82895 L
.82895 .85491 L
.85359 .87955 L
.87955 .90552 L
.9042 .93016 L
.93016 .96955 L
.96607 .98077 L
s
.4 g
.01923 .03786 m
.02811 .06984 L
.06984 .10002 L
.09027 .12045 L
.12045 .15062 L
.14087 .17105 L
.17105 .20123 L
.19148 .22166 L
.22166 .25184 L
.24209 .27227 L
.27227 .30245 L
.2927 .32287 L
.32287 .35305 L
.3433 .37348 L
.37348 .40366 L
.39391 .42409 L
.42409 .45427 L
.44452 .4747 L
.4747 .50487 L
.49513 .5253 L
.5253 .55548 L
.54573 .57591 L
.57591 .60609 L
.59634 .62652 L
.62652 .6567 L
.64695 .67713 L
.67713 .7073 L
.69755 .72773 L
.72773 .75791 L
.74816 .77834 L
.77834 .80852 L
.79877 .82895 L
.82895 .85913 L
.84938 .87955 L
.87955 .90973 L
.89998 .93016 L
.93016 .97189 L
.96214 .98077 L
.01923 .98077 L
F
0 g
.01923 .03786 m
.02811 .06984 L
.06984 .10002 L
.09027 .12045 L
.12045 .15062 L
.14087 .17105 L
.17105 .20123 L
.19148 .22166 L
.22166 .25184 L
.24209 .27227 L
.27227 .30245 L
.2927 .32287 L
.32287 .35305 L
.3433 .37348 L
.37348 .40366 L
.39391 .42409 L
.42409 .45427 L
.44452 .4747 L
.4747 .50487 L
.49513 .5253 L
.5253 .55548 L
.54573 .57591 L
.57591 .60609 L
.59634 .62652 L
.62652 .6567 L
.64695 .67713 L
.67713 .7073 L
.69755 .72773 L
.72773 .75791 L
.74816 .77834 L
.77834 .80852 L
.79877 .82895 L
.82895 .85913 L
.84938 .87955 L
.87955 .90973 L
.89998 .93016 L
.93016 .97189 L
.96214 .98077 L
s
.3 g
.01923 .04227 m
.02598 .06984 L
.06984 .10416 L
.08612 .12045 L
.12045 .15477 L
.13673 .17105 L
.17105 .20538 L
.18733 .22166 L
.22166 .25599 L
.23794 .27227 L
.27227 .30659 L
.28855 .32287 L
.32287 .3572 L
.33916 .37348 L
.37348 .40781 L
.38976 .42409 L
.42409 .45842 L
.44037 .4747 L
.4747 .50902 L
.49098 .5253 L
.5253 .55963 L
.54158 .57591 L
.57591 .61024 L
.59219 .62652 L
.62652 .66084 L
.6428 .67713 L
.67713 .71145 L
.69341 .72773 L
.72773 .76206 L
.74401 .77834 L
.77834 .81267 L
.79462 .82895 L
.82895 .86327 L
.84523 .87955 L
.87955 .91388 L
.89584 .93016 L
.93016 .97402 L
.95773 .98077 L
.01923 .98077 L
F
0 g
.01923 .04227 m
.02598 .06984 L
.06984 .10416 L
.08612 .12045 L
.12045 .15477 L
.13673 .17105 L
.17105 .20538 L
.18733 .22166 L
.22166 .25599 L
.23794 .27227 L
.27227 .30659 L
.28855 .32287 L
.32287 .3572 L
.33916 .37348 L
.37348 .40781 L
.38976 .42409 L
.42409 .45842 L
.44037 .4747 L
.4747 .50902 L
.49098 .5253 L
.5253 .55963 L
.54158 .57591 L
.57591 .61024 L
.59219 .62652 L
.62652 .66084 L
.6428 .67713 L
.67713 .71145 L
.69341 .72773 L
.72773 .76206 L
.74401 .77834 L
.77834 .81267 L
.79462 .82895 L
.82895 .86327 L
.84523 .87955 L
.87955 .91388 L
.89584 .93016 L
.93016 .97402 L
.95773 .98077 L
s
.2 g
.01923 .04736 m
.02401 .06984 L
.06984 .10832 L
.08196 .12045 L
.12045 .15893 L
.13257 .17105 L
.17105 .20954 L
.18318 .22166 L
.22166 .26014 L
.23378 .27227 L
.27227 .31075 L
.28439 .32287 L
.32287 .36136 L
.335 .37348 L
.37348 .41197 L
.3856 .42409 L
.42409 .46257 L
.43621 .4747 L
.4747 .51318 L
.48682 .5253 L
.5253 .56379 L
.53743 .57591 L
.57591 .6144 L
.58803 .62652 L
.62652 .665 L
.63864 .67713 L
.67713 .71561 L
.68925 .72773 L
.72773 .76622 L
.73986 .77834 L
.77834 .81682 L
.79046 .82895 L
.82895 .86743 L
.84107 .87955 L
.87955 .91804 L
.89168 .93016 L
.93016 .97599 L
.95264 .98077 L
.01923 .98077 L
F
0 g
.01923 .04736 m
.02401 .06984 L
.06984 .10832 L
.08196 .12045 L
.12045 .15893 L
.13257 .17105 L
.17105 .20954 L
.18318 .22166 L
.22166 .26014 L
.23378 .27227 L
.27227 .31075 L
.28439 .32287 L
.32287 .36136 L
.335 .37348 L
.37348 .41197 L
.3856 .42409 L
.42409 .46257 L
.43621 .4747 L
.4747 .51318 L
.48682 .5253 L
.5253 .56379 L
.53743 .57591 L
.57591 .6144 L
.58803 .62652 L
.62652 .665 L
.63864 .67713 L
.67713 .71561 L
.68925 .72773 L
.72773 .76622 L
.73986 .77834 L
.77834 .81682 L
.79046 .82895 L
.82895 .86743 L
.84107 .87955 L
.87955 .91804 L
.89168 .93016 L
.93016 .97599 L
.95264 .98077 L
s
.1 g
.01923 .05346 m
.02217 .06984 L
.06984 .11257 L
.07772 .12045 L
.12045 .16317 L
.12832 .17105 L
.17105 .21378 L
.17893 .22166 L
.22166 .26439 L
.22954 .27227 L
.27227 .315 L
.28015 .32287 L
.32287 .3656 L
.33075 .37348 L
.37348 .41621 L
.38136 .42409 L
.42409 .46682 L
.43197 .4747 L
.4747 .51743 L
.48257 .5253 L
.5253 .56803 L
.53318 .57591 L
.57591 .61864 L
.58379 .62652 L
.62652 .66925 L
.6344 .67713 L
.67713 .71985 L
.685 .72773 L
.72773 .77046 L
.73561 .77834 L
.77834 .82107 L
.78622 .82895 L
.82895 .87168 L
.83683 .87955 L
.87955 .92228 L
.88743 .93016 L
.93016 .97783 L
.94654 .98077 L
.01923 .98077 L
F
0 g
.01923 .05346 m
.02217 .06984 L
.06984 .11257 L
.07772 .12045 L
.12045 .16317 L
.12832 .17105 L
.17105 .21378 L
.17893 .22166 L
.22166 .26439 L
.22954 .27227 L
.27227 .315 L
.28015 .32287 L
.32287 .3656 L
.33075 .37348 L
.37348 .41621 L
.38136 .42409 L
.42409 .46682 L
.43197 .4747 L
.4747 .51743 L
.48257 .5253 L
.5253 .56803 L
.53318 .57591 L
.57591 .61864 L
.58379 .62652 L
.62652 .66925 L
.6344 .67713 L
.67713 .71985 L
.685 .72773 L
.72773 .77046 L
.73561 .77834 L
.77834 .82107 L
.78622 .82895 L
.82895 .87168 L
.83683 .87955 L
.87955 .92228 L
.88743 .93016 L
.93016 .97783 L
.94654 .98077 L
s
.01923 .06138 m
.02044 .06984 L
.06984 .11699 L
.07329 .12045 L
.12045 .1676 L
.1239 .17105 L
.17105 .2182 L
.17451 .22166 L
.22166 .26881 L
.22512 .27227 L
.27227 .31942 L
.27572 .32287 L
.32287 .37003 L
.32633 .37348 L
.37348 .42063 L
.37694 .42409 L
.42409 .47124 L
.42754 .4747 L
.4747 .52185 L
.47815 .5253 L
.5253 .57246 L
.52876 .57591 L
.57591 .62306 L
.57937 .62652 L
.62652 .67367 L
.62997 .67713 L
.67713 .72428 L
.68058 .72773 L
.72773 .77488 L
.73119 .77834 L
.77834 .82549 L
.7818 .82895 L
.82895 .8761 L
.8324 .87955 L
.87955 .92671 L
.88301 .93016 L
.93016 .97956 L
.93862 .98077 L
.01923 .98077 L
F
.01923 .06138 m
.02044 .06984 L
.06984 .11699 L
.07329 .12045 L
.12045 .1676 L
.1239 .17105 L
.17105 .2182 L
.17451 .22166 L
.22166 .26881 L
.22512 .27227 L
.27227 .31942 L
.27572 .32287 L
.32287 .37003 L
.32633 .37348 L
.37348 .42063 L
.37694 .42409 L
.42409 .47124 L
.42754 .4747 L
.4747 .52185 L
.47815 .5253 L
.5253 .57246 L
.52876 .57591 L
.57591 .62306 L
.57937 .62652 L
.62652 .67367 L
.62997 .67713 L
.67713 .72428 L
.68058 .72773 L
.72773 .77488 L
.73119 .77834 L
.77834 .82549 L
.7818 .82895 L
.82895 .8761 L
.8324 .87955 L
.87955 .92671 L
.88301 .93016 L
.93016 .97956 L
.93862 .98077 L
s
.9 g
.98077 .97878 m
.95592 .93016 L
.93016 .92431 L
.88541 .87955 L
.87955 .8737 L
.8348 .82895 L
.82895 .82309 L
.78419 .77834 L
.77834 .77249 L
.73359 .72773 L
.72773 .72188 L
.68298 .67713 L
.67713 .67127 L
.63237 .62652 L
.62652 .62066 L
.58177 .57591 L
.57591 .57006 L
.53116 .5253 L
.5253 .51945 L
.48055 .4747 L
.4747 .46884 L
.42994 .42409 L
.42409 .41823 L
.37934 .37348 L
.37348 .36763 L
.32873 .32287 L
.32287 .31702 L
.27812 .27227 L
.27227 .26641 L
.22751 .22166 L
.22166 .21581 L
.17691 .17105 L
.17105 .1652 L
.1263 .12045 L
.12045 .11459 L
.07569 .06984 L
.06984 .04408 L
.02122 .01923 L
.98077 .01923 L
F
0 g
.98077 .97878 m
.95592 .93016 L
.93016 .92431 L
.88541 .87955 L
.87955 .8737 L
.8348 .82895 L
.82895 .82309 L
.78419 .77834 L
.77834 .77249 L
.73359 .72773 L
.72773 .72188 L
.68298 .67713 L
.67713 .67127 L
.63237 .62652 L
.62652 .62066 L
.58177 .57591 L
.57591 .57006 L
.53116 .5253 L
.5253 .51945 L
.48055 .4747 L
.4747 .46884 L
.42994 .42409 L
.42409 .41823 L
.37934 .37348 L
.37348 .36763 L
.32873 .32287 L
.32287 .31702 L
.27812 .27227 L
.27227 .26641 L
.22751 .22166 L
.22166 .21581 L
.17691 .17105 L
.17105 .1652 L
.1263 .12045 L
.12045 .11459 L
.07569 .06984 L
.06984 .04408 L
.02122 .01923 L
s
.8 g
.98077 .97594 m
.96044 .93016 L
.93016 .91829 L
.89143 .87955 L
.87955 .86768 L
.84082 .82895 L
.82895 .81707 L
.79021 .77834 L
.77834 .76647 L
.73961 .72773 L
.72773 .71586 L
.689 .67713 L
.67713 .66525 L
.63839 .62652 L
.62652 .61464 L
.58778 .57591 L
.57591 .56404 L
.53718 .5253 L
.5253 .51343 L
.48657 .4747 L
.4747 .46282 L
.43596 .42409 L
.42409 .41222 L
.38536 .37348 L
.37348 .36161 L
.33475 .32287 L
.32287 .311 L
.28414 .27227 L
.27227 .26039 L
.23353 .22166 L
.22166 .20979 L
.18293 .17105 L
.17105 .15918 L
.13232 .12045 L
.12045 .10857 L
.08171 .06984 L
.06984 .03956 L
.02406 .01923 L
.98077 .01923 L
F
0 g
.98077 .97594 m
.96044 .93016 L
.93016 .91829 L
.89143 .87955 L
.87955 .86768 L
.84082 .82895 L
.82895 .81707 L
.79021 .77834 L
.77834 .76647 L
.73961 .72773 L
.72773 .71586 L
.689 .67713 L
.67713 .66525 L
.63839 .62652 L
.62652 .61464 L
.58778 .57591 L
.57591 .56404 L
.53718 .5253 L
.5253 .51343 L
.48657 .4747 L
.4747 .46282 L
.43596 .42409 L
.42409 .41222 L
.38536 .37348 L
.37348 .36161 L
.33475 .32287 L
.32287 .311 L
.28414 .27227 L
.27227 .26039 L
.23353 .22166 L
.22166 .20979 L
.18293 .17105 L
.17105 .15918 L
.13232 .12045 L
.12045 .10857 L
.08171 .06984 L
.06984 .03956 L
.02406 .01923 L
s
.7 g
.98077 .97291 m
.96397 .93016 L
.93016 .91319 L
.89653 .87955 L
.87955 .86258 L
.84592 .82895 L
.82895 .81197 L
.79532 .77834 L
.77834 .76136 L
.74471 .72773 L
.72773 .71076 L
.6941 .67713 L
.67713 .66015 L
.64349 .62652 L
.62652 .60954 L
.59289 .57591 L
.57591 .55894 L
.54228 .5253 L
.5253 .50833 L
.49167 .4747 L
.4747 .45772 L
.44106 .42409 L
.42409 .40711 L
.39046 .37348 L
.37348 .35651 L
.33985 .32287 L
.32287 .3059 L
.28924 .27227 L
.27227 .25529 L
.23864 .22166 L
.22166 .20468 L
.18803 .17105 L
.17105 .15408 L
.13742 .12045 L
.12045 .10347 L
.08681 .06984 L
.06984 .03603 L
.02709 .01923 L
.98077 .01923 L
F
0 g
.98077 .97291 m
.96397 .93016 L
.93016 .91319 L
.89653 .87955 L
.87955 .86258 L
.84592 .82895 L
.82895 .81197 L
.79532 .77834 L
.77834 .76136 L
.74471 .72773 L
.72773 .71076 L
.6941 .67713 L
.67713 .66015 L
.64349 .62652 L
.62652 .60954 L
.59289 .57591 L
.57591 .55894 L
.54228 .5253 L
.5253 .50833 L
.49167 .4747 L
.4747 .45772 L
.44106 .42409 L
.42409 .40711 L
.39046 .37348 L
.37348 .35651 L
.33985 .32287 L
.32287 .3059 L
.28924 .27227 L
.27227 .25529 L
.23864 .22166 L
.22166 .20468 L
.18803 .17105 L
.17105 .15408 L
.13742 .12045 L
.12045 .10347 L
.08681 .06984 L
.06984 .03603 L
.02709 .01923 L
s
.6 g
.98077 .96963 m
.96694 .93016 L
.93016 .90856 L
.90116 .87955 L
.87955 .85795 L
.85055 .82895 L
.82895 .80734 L
.79995 .77834 L
.77834 .75673 L
.74934 .72773 L
.72773 .70613 L
.69873 .67713 L
.67713 .65552 L
.64812 .62652 L
.62652 .60491 L
.59752 .57591 L
.57591 .55431 L
.54691 .5253 L
.5253 .5037 L
.4963 .4747 L
.4747 .45309 L
.44569 .42409 L
.42409 .40248 L
.39509 .37348 L
.37348 .35188 L
.34448 .32287 L
.32287 .30127 L
.29387 .27227 L
.27227 .25066 L
.24327 .22166 L
.22166 .20005 L
.19266 .17105 L
.17105 .14945 L
.14205 .12045 L
.12045 .09884 L
.09144 .06984 L
.06984 .03306 L
.03037 .01923 L
.98077 .01923 L
F
0 g
.98077 .96963 m
.96694 .93016 L
.93016 .90856 L
.90116 .87955 L
.87955 .85795 L
.85055 .82895 L
.82895 .80734 L
.79995 .77834 L
.77834 .75673 L
.74934 .72773 L
.72773 .70613 L
.69873 .67713 L
.67713 .65552 L
.64812 .62652 L
.62652 .60491 L
.59752 .57591 L
.57591 .55431 L
.54691 .5253 L
.5253 .5037 L
.4963 .4747 L
.4747 .45309 L
.44569 .42409 L
.42409 .40248 L
.39509 .37348 L
.37348 .35188 L
.34448 .32287 L
.32287 .30127 L
.29387 .27227 L
.27227 .25066 L
.24327 .22166 L
.22166 .20005 L
.19266 .17105 L
.17105 .14945 L
.14205 .12045 L
.12045 .09884 L
.09144 .06984 L
.06984 .03306 L
.03037 .01923 L
s
.5 g
.98077 .96607 m
.96955 .93016 L
.93016 .9042 L
.90552 .87955 L
.87955 .85359 L
.85491 .82895 L
.82895 .80298 L
.80431 .77834 L
.77834 .75237 L
.7537 .72773 L
.72773 .70177 L
.70309 .67713 L
.67713 .65116 L
.65248 .62652 L
.62652 .60055 L
.60188 .57591 L
.57591 .54994 L
.55127 .5253 L
.5253 .49934 L
.50066 .4747 L
.4747 .44873 L
.45006 .42409 L
.42409 .39812 L
.39945 .37348 L
.37348 .34752 L
.34884 .32287 L
.32287 .29691 L
.29823 .27227 L
.27227 .2463 L
.24763 .22166 L
.22166 .19569 L
.19702 .17105 L
.17105 .14509 L
.14641 .12045 L
.12045 .09448 L
.0958 .06984 L
.06984 .03045 L
.03393 .01923 L
.98077 .01923 L
F
0 g
.98077 .96607 m
.96955 .93016 L
.93016 .9042 L
.90552 .87955 L
.87955 .85359 L
.85491 .82895 L
.82895 .80298 L
.80431 .77834 L
.77834 .75237 L
.7537 .72773 L
.72773 .70177 L
.70309 .67713 L
.67713 .65116 L
.65248 .62652 L
.62652 .60055 L
.60188 .57591 L
.57591 .54994 L
.55127 .5253 L
.5253 .49934 L
.50066 .4747 L
.4747 .44873 L
.45006 .42409 L
.42409 .39812 L
.39945 .37348 L
.37348 .34752 L
.34884 .32287 L
.32287 .29691 L
.29823 .27227 L
.27227 .2463 L
.24763 .22166 L
.22166 .19569 L
.19702 .17105 L
.17105 .14509 L
.14641 .12045 L
.12045 .09448 L
.0958 .06984 L
.06984 .03045 L
.03393 .01923 L
s
.4 g
.98077 .96214 m
.97189 .93016 L
.93016 .89998 L
.90973 .87955 L
.87955 .84938 L
.85913 .82895 L
.82895 .79877 L
.80852 .77834 L
.77834 .74816 L
.75791 .72773 L
.72773 .69755 L
.7073 .67713 L
.67713 .64695 L
.6567 .62652 L
.62652 .59634 L
.60609 .57591 L
.57591 .54573 L
.55548 .5253 L
.5253 .49513 L
.50487 .4747 L
.4747 .44452 L
.45427 .42409 L
.42409 .39391 L
.40366 .37348 L
.37348 .3433 L
.35305 .32287 L
.32287 .2927 L
.30245 .27227 L
.27227 .24209 L
.25184 .22166 L
.22166 .19148 L
.20123 .17105 L
.17105 .14087 L
.15062 .12045 L
.12045 .09027 L
.10002 .06984 L
.06984 .02811 L
.03786 .01923 L
.98077 .01923 L
F
0 g
.98077 .96214 m
.97189 .93016 L
.93016 .89998 L
.90973 .87955 L
.87955 .84938 L
.85913 .82895 L
.82895 .79877 L
.80852 .77834 L
.77834 .74816 L
.75791 .72773 L
.72773 .69755 L
.7073 .67713 L
.67713 .64695 L
.6567 .62652 L
.62652 .59634 L
.60609 .57591 L
.57591 .54573 L
.55548 .5253 L
.5253 .49513 L
.50487 .4747 L
.4747 .44452 L
.45427 .42409 L
.42409 .39391 L
.40366 .37348 L
.37348 .3433 L
.35305 .32287 L
.32287 .2927 L
.30245 .27227 L
.27227 .24209 L
.25184 .22166 L
.22166 .19148 L
.20123 .17105 L
.17105 .14087 L
.15062 .12045 L
.12045 .09027 L
.10002 .06984 L
.06984 .02811 L
.03786 .01923 L
s
.3 g
.98077 .95773 m
.97402 .93016 L
.93016 .89584 L
.91388 .87955 L
.87955 .84523 L
.86327 .82895 L
.82895 .79462 L
.81267 .77834 L
.77834 .74401 L
.76206 .72773 L
.72773 .69341 L
.71145 .67713 L
.67713 .6428 L
.66084 .62652 L
.62652 .59219 L
.61024 .57591 L
.57591 .54158 L
.55963 .5253 L
.5253 .49098 L
.50902 .4747 L
.4747 .44037 L
.45842 .42409 L
.42409 .38976 L
.40781 .37348 L
.37348 .33916 L
.3572 .32287 L
.32287 .28855 L
.30659 .27227 L
.27227 .23794 L
.25599 .22166 L
.22166 .18733 L
.20538 .17105 L
.17105 .13673 L
.15477 .12045 L
.12045 .08612 L
.10416 .06984 L
.06984 .02598 L
.04227 .01923 L
.98077 .01923 L
F
0 g
.98077 .95773 m
.97402 .93016 L
.93016 .89584 L
.91388 .87955 L
.87955 .84523 L
.86327 .82895 L
.82895 .79462 L
.81267 .77834 L
.77834 .74401 L
.76206 .72773 L
.72773 .69341 L
.71145 .67713 L
.67713 .6428 L
.66084 .62652 L
.62652 .59219 L
.61024 .57591 L
.57591 .54158 L
.55963 .5253 L
.5253 .49098 L
.50902 .4747 L
.4747 .44037 L
.45842 .42409 L
.42409 .38976 L
.40781 .37348 L
.37348 .33916 L
.3572 .32287 L
.32287 .28855 L
.30659 .27227 L
.27227 .23794 L
.25599 .22166 L
.22166 .18733 L
.20538 .17105 L
.17105 .13673 L
.15477 .12045 L
.12045 .08612 L
.10416 .06984 L
.06984 .02598 L
.04227 .01923 L
s
.2 g
.98077 .95264 m
.97599 .93016 L
.93016 .89168 L
.91804 .87955 L
.87955 .84107 L
.86743 .82895 L
.82895 .79046 L
.81682 .77834 L
.77834 .73986 L
.76622 .72773 L
.72773 .68925 L
.71561 .67713 L
.67713 .63864 L
.665 .62652 L
.62652 .58803 L
.6144 .57591 L
.57591 .53743 L
.56379 .5253 L
.5253 .48682 L
.51318 .4747 L
.4747 .43621 L
.46257 .42409 L
.42409 .3856 L
.41197 .37348 L
.37348 .335 L
.36136 .32287 L
.32287 .28439 L
.31075 .27227 L
.27227 .23378 L
.26014 .22166 L
.22166 .18318 L
.20954 .17105 L
.17105 .13257 L
.15893 .12045 L
.12045 .08196 L
.10832 .06984 L
.06984 .02401 L
.04736 .01923 L
.98077 .01923 L
F
0 g
.98077 .95264 m
.97599 .93016 L
.93016 .89168 L
.91804 .87955 L
.87955 .84107 L
.86743 .82895 L
.82895 .79046 L
.81682 .77834 L
.77834 .73986 L
.76622 .72773 L
.72773 .68925 L
.71561 .67713 L
.67713 .63864 L
.665 .62652 L
.62652 .58803 L
.6144 .57591 L
.57591 .53743 L
.56379 .5253 L
.5253 .48682 L
.51318 .4747 L
.4747 .43621 L
.46257 .42409 L
.42409 .3856 L
.41197 .37348 L
.37348 .335 L
.36136 .32287 L
.32287 .28439 L
.31075 .27227 L
.27227 .23378 L
.26014 .22166 L
.22166 .18318 L
.20954 .17105 L
.17105 .13257 L
.15893 .12045 L
.12045 .08196 L
.10832 .06984 L
.06984 .02401 L
.04736 .01923 L
s
.1 g
.98077 .94654 m
.97783 .93016 L
.93016 .88743 L
.92228 .87955 L
.87955 .83683 L
.87168 .82895 L
.82895 .78622 L
.82107 .77834 L
.77834 .73561 L
.77046 .72773 L
.72773 .685 L
.71985 .67713 L
.67713 .6344 L
.66925 .62652 L
.62652 .58379 L
.61864 .57591 L
.57591 .53318 L
.56803 .5253 L
.5253 .48257 L
.51743 .4747 L
.4747 .43197 L
.46682 .42409 L
.42409 .38136 L
.41621 .37348 L
.37348 .33075 L
.3656 .32287 L
.32287 .28015 L
.315 .27227 L
.27227 .22954 L
.26439 .22166 L
.22166 .17893 L
.21378 .17105 L
.17105 .12832 L
.16317 .12045 L
.12045 .07772 L
.11257 .06984 L
.06984 .02217 L
.05346 .01923 L
.98077 .01923 L
F
0 g
.98077 .94654 m
.97783 .93016 L
.93016 .88743 L
.92228 .87955 L
.87955 .83683 L
.87168 .82895 L
.82895 .78622 L
.82107 .77834 L
.77834 .73561 L
.77046 .72773 L
.72773 .685 L
.71985 .67713 L
.67713 .6344 L
.66925 .62652 L
.62652 .58379 L
.61864 .57591 L
.57591 .53318 L
.56803 .5253 L
.5253 .48257 L
.51743 .4747 L
.4747 .43197 L
.46682 .42409 L
.42409 .38136 L
.41621 .37348 L
.37348 .33075 L
.3656 .32287 L
.32287 .28015 L
.315 .27227 L
.27227 .22954 L
.26439 .22166 L
.22166 .17893 L
.21378 .17105 L
.17105 .12832 L
.16317 .12045 L
.12045 .07772 L
.11257 .06984 L
.06984 .02217 L
.05346 .01923 L
s
.98077 .93862 m
.97956 .93016 L
.93016 .88301 L
.92671 .87955 L
.87955 .8324 L
.8761 .82895 L
.82895 .7818 L
.82549 .77834 L
.77834 .73119 L
.77488 .72773 L
.72773 .68058 L
.72428 .67713 L
.67713 .62997 L
.67367 .62652 L
.62652 .57937 L
.62306 .57591 L
.57591 .52876 L
.57246 .5253 L
.5253 .47815 L
.52185 .4747 L
.4747 .42754 L
.47124 .42409 L
.42409 .37694 L
.42063 .37348 L
.37348 .32633 L
.37003 .32287 L
.32287 .27572 L
.31942 .27227 L
.27227 .22512 L
.26881 .22166 L
.22166 .17451 L
.2182 .17105 L
.17105 .1239 L
.1676 .12045 L
.12045 .07329 L
.11699 .06984 L
.06984 .02044 L
.06138 .01923 L
.98077 .01923 L
F
.98077 .93862 m
.97956 .93016 L
.93016 .88301 L
.92671 .87955 L
.87955 .8324 L
.8761 .82895 L
.82895 .7818 L
.82549 .77834 L
.77834 .73119 L
.77488 .72773 L
.72773 .68058 L
.72428 .67713 L
.67713 .62997 L
.67367 .62652 L
.62652 .57937 L
.62306 .57591 L
.57591 .52876 L
.57246 .5253 L
.5253 .47815 L
.52185 .4747 L
.4747 .42754 L
.47124 .42409 L
.42409 .37694 L
.42063 .37348 L
.37348 .32633 L
.37003 .32287 L
.32287 .27572 L
.31942 .27227 L
.27227 .22512 L
.26881 .22166 L
.22166 .17451 L
.2182 .17105 L
.17105 .1239 L
.1676 .12045 L
.12045 .07329 L
.11699 .06984 L
.06984 .02044 L
.06138 .01923 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00=Oooool5o`0000Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd07?ooool01Om4A4Co0000o`000?lb<S;ogMgM01gooooo00?o0000onk^
k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Hooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kQGooooo1?l000000ol@413oooooooooo`05o`0000Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd05?ooool4o`000005oa0@4?oooooooooo
oooooom4A4@00_l000000olb<S;ogMgMooooo`0Cooooo`Co000000?o410@ooooooooool00_ooool0
0ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01?ooooo1Ol0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool003Gooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Nooooo`03ogMgMolb<S;ooooo01cooooo
00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool06Oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05oooool00ol0003oooooooooo`02ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05Oooool00ol0
003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Gooooo00?o0000ooooooooool01?ooool00omE
EEGoZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Booooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo000fooooo`03oiRHV?lQ8B7o
k^k^017ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03ojVYZOmEEEGo
oooo013ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41005oooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool01?ooool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o
V9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo000gooooo`03oiRHV?lQ
8B7ok^k^00oooooo00?oMgMgoc8b<_ooool07_ooool00omgMgOo<S8booooo`0Mooooo`03ob4Q8Ooo
oooooooo00kooooo00?oMgMgoc8b<_ooool06Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000005oooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00oooooo
00?oMgMgoc8b<_ooool05Oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Gooooo
00?o0000ooooooooool01Oooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo01Cooooo
00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000?ooooo000hooooo`03ogMg
MomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Looooo`05o`000?lQ8B7o0000oc8b
<_o<c<`07_ooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005oooool00ol0003ooooooooo
o`05ooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`00
0?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`000?oooooooooo00Go
oooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Kooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo000iooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Pooooo`03ojVYZOmgMgOooooo
00_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41005oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool01Oooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo01Wooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo007ooooo000eooooo`05o`000?nj^[[o
oooooiRHV?l@41003?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01gooooo00Go
410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Oooooo00?o0000ooooooooool00_ooool01Ol0003o
^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
<S8b00cooooo00?o0000ooooooooool05Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`00=Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo
1?l0000Mooooo`Co00007?ooool5o`0000cooooo1?l0000Iooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0Eooooo`03oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c00<ooooo`Co00005Oooool00omEEEGoIVIVo`000005ooooo`Co00005Oooool00omE
EEGoIVIVo`000004ooooo`Go00003?ooool4o`0001Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool002;oooooool00015o`0000;ooooo000Roooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`3ooooood7ooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oo
oooooooo0?oooooo@Oooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool0oooooom1
ooooo`7o00000Oooool1ooooo`008_ooool2o`0000Cooooo4Ol0003oooooobcooooo0_l00002oooo
o`008_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo00000?oo0000=Ol00006ooooo`7o
00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooooooooooo
0000=?l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03ooooo`;o0000
1?ooooooo`0003;o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooo
ool2o`0000Kooooo1?l000000oo<c<co0000o`00003oo`0002Wo00001_ooool1o`00007ooooo0Ooo
ool002;ooooo00?o0000ooooooooool00oooool3o`0000Oooooo1?l00002olc<c?oo0000:?l00006
ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03ooooo`?o00002Oooooooo`00
02co00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooool4o`0000[o
ooooool0000Zo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?ooool4o`0000cooooo
ool0000Xo`0000Gooooo0_l00002ooooo`008_ooool00ol0003oooooooooo`03ooooo`Go00002ooo
ooooo`0002So00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooool4
o`000003onKVi_l0003ooooo00Woooooool0000Xo`0000Kooooo0Ol00001ooooo`7ooooo000Roooo
o`03o`000?oooooooooo00?ooooo1_l0000;oooooooo00009ol00006ooooo`7o00000Oooool1oooo
o`008_ooool00ol0003oooooooooo`03ooooo`Go000000?oi^KVo`000?ooool02Oooool2o`000003
olc<c?l0003oVIVI00;o000000?oC4a<o`000?l00000ool0000Mo`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`03o`000?oooooooooo00?ooooo1ol0000:ooooo`;o000000?oc<c<o`000?l00000
0ol000000om<C4co0000o`00003oo`0001co00001_ooool1o`00007ooooo0Oooool002;ooooo00?o
0000ooooooooool00oooool6o`000003onKVi_l0003ooooo00Sooooo00Ko0000onKVi_l0003oc<c<
o`000?nIVIT3o`000003oda<C?l0003o00000?oo00006ol00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03ooooo`Ko000000?oi^KVo`000?ooool02Oooool2o`000004olc<
c?l0003o0000oiVIV@?o000000?oC4a<o`000?l00000ool0000Jo`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`;o00001?ooool;o`0000Oooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo
0000o`000?l0003oC4a<0?oo00006ol00005ooooo`;o00000_ooool002;ooooo00?o0000oooooooo
ool00oooool2o`000003oaTI6Ol0003o000000[o00001?ooool01?l0003oi^KVo`000?o<c<`2o`00
0005oiVIVOl0003o0000o`000?m<C4`0ool0000Jo`0000Kooooo0Ol00001ooooo`7ooooo000Roooo
o`03o`000?oooooooooo00?ooooo0ol000000olI6AWo0000o`000007o`0000;oi^KV0_l00003oooo
o`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C03oo`0001Wo00001_oo
ool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooool4o`000003oaTI6Ol0003o
000000Go000000Koc<c<o`000?l0003o0000onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<c0;o
000000GoVIVIo`000?l0003o0000oda<C03oo`0001So00001_ooool1o`00007ooooo0Oooool002;o
oooo00?o0000ooooooooool00oooool5o`000004oaTI6Ol0003o0000ofIVIPGo00000_o<c<`00ol0
003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000OoVIVIo`000?l0003o0000oda<
C?l0003o6ATI0?oo00005Ol00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003ooooooooo
o`03ooooo`Ko000000Co6ATIo`000?l0003oIVIV0_l000002?nIVIWo0000o`000?l0003oc<c<o`00
0?oVi^Ko00000oooool01?l0003oi^KVo`000?o<c<`2o`000003oiVIVOl0003o000000?o000000?o
6ATIo`000?l00000ool0000Bo`0000Kooooo0Ol00001ooooo`7ooooo0007ooooo`Go00001Oooool2
ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00?ooooo1ol0
00000olI6AWo0000o`000003o`000008oiVIVOl0003o0000o`000?o<c<co0000onKVi_l00003oooo
o`04o`000?oVi^Ko0000olc<c0;o000000?oVIVIo`000?l000000ol000000olI6AWo0000o`00003o
o`00017o00001_ooool1o`00007ooooo0Oooool000Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A005
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?ooooo2?l00000
0olI6AWo0000o`000004o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`04o`00
0?oVi^Ko0000olc<c0;o000000?oVIVIo`000?l000000ol000000olI6AWo0000o`00003oo`00013o
00001_ooool1o`00007ooooo0Oooool000Sooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo2Ol000001OlI6AWo0000o`000?l0003oIVIV00;o
000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l0
00000onIVIWo0000ofIVIP03o`000003oaTI6Ol0003o00000?oo00003ol00006ooooo`7o00000Ooo
ool1ooooo`002Oooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00003
ooooo`[o000000Go6ATIo`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0003o
i^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0Co000000GoIVIVo`000?l0003o0000oaTI6@3o
o`00013o00001?ooool3o`0000;ooooo000:ooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00?ooooo2ol000001OlI6AWo0000o`000?l0
003oIVIV00;o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0
003oc<c<1?l000001OmVIVKo0000o`000?l0003o6ATI0?oo00003ol00006ooooo`7o00000Oooool1
ooooo`002oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool00oooool<o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<
c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`4o`000005ofIVI_l0003o0000o`00
0?lI6AT0ool0000>o`0000Kooooo0Ol00001ooooo`7ooooo0007ooooo`05o`000?nj^[[ooooooiRH
V?l@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo3Ol000001OlI
6AWo0000o`000?l0003oIVIV00;o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo
00Go0000onKVi_l0003o0000ok>c/`03o`000005ofIVI_l0003o0000o`000?lI6AT0ool0000=o`00
00Kooooo0Ol00001ooooo`7ooooo0007ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`00
00Kooooo00?o0000ooooooooool00oooool>o`000005oaTI6Ol0003o0000o`000?mVIVH00_l00000
1onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01Ol0003oi^KVo`000?l0003o/k>c00?o
000000GoIVIVo`000?l0003o0000oaTI6@3oo`0000co00001_ooool1o`00007ooooo0Oooool002;o
oooo00?o0000ooooooooool00oooool?o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onI
VIWo0000o`000?o<c<co0000onKVi_l000000oooool2o`000003olc<c?l0003o/k>c00?o000000Go
IVIVo`000?l0003o0000oaTI6@3oo`0000_o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o
0000ooooooooool00oooool@o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000
o`000?o<c<co0000onKVi_l000000oooool2o`000003olc<c?l0003o/k>c00?o000000GoIVIVo`00
0?l0003o0000oaTI6@3oo`0000[o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooo
ooooool00ooooolAo`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<
c<co0000onKVi_l000000_ooool01_l0003oi^KVo`000?o<c<co0000ok>c/`?o000000GoIVIVo`00
0?l0003o0000oaTI6@3oo`0000Wo00001_ooool1o`00007ooooo0Oooool002;ooooo0_l00004oooo
oako000000Coi^KVo`000?oooooooooo1Ol000000onc/k?o0000o`00003oo`0000ko00001Oooool2
o`0000;ooooo000Rooooo`03o`000?oooooooooo00?ooooo5Ol000001Olc<c?o0000o`000?l0003o
Ogmo00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`05o`000?oVi^Ko0000o`000?nc/k<0
0_l000001OmoOgoo0000o`000?l0003o<c<c0?oo00002?l00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03oooooaKo000000Go<c<co`000?l0003o0000ogmoO`02o`000005
ok>c/ol0003o0000onKVi_l000000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmo
o`000?l0003o0000oc<c<`3oo`0000Oo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000
ooooooooool00ooooolGo`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`00
0?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`00
0?lc<c<0ool00006o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?o
oooo6?l000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003
ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c0?oo0000
1Ol00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooaWo000000Go
<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0003o0000onKVi_l000000oooool01Ol0003o
i^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`3oo`0000Co00001_ooool1
o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooolJo`000005oc<c<ol0003o0000
o`000?moOgl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<0
0_l000001OmoOgoo0000o`000?l0003o<c<c0?oo00000ol00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03oooooa_o000000Go<c<co`000?l0003o0000ogmoO`03o`000004
olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o
0000o`000?lc<c<0ool00002o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oooolL
o`000005oc<c<ol0003o0000o`000?moOgl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`00
0?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c0?oo00000Ol00005oooo
o`;o00000_ooool002;ooooo00?o0000ooooooooool00ooooolMo`000005oc<c<ol0003o0000o`00
0?moOgl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l0
00001OmoOgoo0000o`000?l0003o<c<c0?oo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o
0000ooooooooool00ooooolNo`000005oc<c<ol0003o0000o`000?moOgl00ol000001?o<c<co0000
onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o
<c<c0?ko00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooolOo`00
0005oc<c<ol0003o0000o`000?moOgl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`000?oV
i^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c0?go00001_ooool1o`00007o
oooo0Oooool002;ooooo00?o0000ooooooooool00ooooolPo`000005oc<c<ol0003o0000o`000?mo
Ogl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l00000
1OmoOgoo0000o`000?l0003o<c<c0?co00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000
ooooooooool00ooooolRo`000004oda<C?l0003o0000ogmoO`?o000000Coc<c<o`000?oVi^Ko0000
0oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`3ko`00
00Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo8ol000001?m<C4co
0000o`000?moOgl3o`000004olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c
/`02o`000005ogmoOol0003o0000o`000?lc<c<0n_l00006ooooo`7o00000Oooool1ooooo`008_oo
ool00ol0003oooooooooo`03ooooobCo000000CoC4a<o`000?l0003oOgmo0ol000001?o<c<co0000
onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o
<c<c0?Wo00001_ooool1o`00007ooooo0Oooool002;ooooo0_l00004ooooobGo000000CoC4a<o`00
0?l0003oOgmo0ol000001?o<c<co0000onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<0
0_l000001OmoOgoo0000o`000?l0003o<c<c0?So00001Oooool2o`0000;ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo9_l000001Om<C4co0000o`000?l0003oVIVI00;o000000Coc<c<o`000?oV
i^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o0000ofIVIP?o000000?o
6ATIo`000?l00000m?l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03
ooooobOo000000GoC4a<o`000?l0003o0000oiVIV@02o`000004olc<c?l0003oi^KVo`0000;ooooo
00Co0000onKVi_l0003oc<c<0_l000001?nIVIWo0000o`000?mVIVH3o`000003oaTI6Ol0003o0000
0??o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooolXo`000005
oda<C?l0003o0000o`000?nIVIT00_l000000oo<c<co0000o`000003ooooo`04o`000?oVi^Ko0000
olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00003bo`0000Kooooo0Ol0
0001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo:Ol000001Om<C4co0000o`000?l0
003oVIVI00;o000000?oc<c<o`000?l000000oooool01?l0003oi^KVo`000?o<c<`2o`000004oiVI
VOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000lOl00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03ooooob[o000000GoC4a<o`000?l0003o0000oiVIV@03o`000003
onKVi_l0003ooooo00;ooooo00Co0000onKVi_l0003oc<c<0_l000001?nIVIWo0000o`000?mVIVH3
o`000003oaTI6Ol0003o00000?3o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooo
ooooool00oooool[o`000005oda<C?l0003o0000o`000?nIVIT00ol000000ooVi^Ko0000ooooo`02
ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI
6Ol0003o00000>oo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooo
ool/o`000005oda<C?l0003o0000o`000?nIVIT00ol000000ooVi^Ko0000ooooo`02ooooo`04o`00
0?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI6Ol0003o0000
0>ko00001_ooool1o`00007ooooo0Oooool002;ooooo0_l00004ooooobgo000000?oC4a<o`000?l0
00000_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l00000
1OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l00000kOl00005ooooo`;o00000_oo
ool002;ooooo00?o0000ooooooooool00oooool^o`000003oda<C?l0003o000000;o000000Go/k>c
o`000?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o
0000oda<C002o`000003oaTI6Ol0003o00000>co00001_ooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00oooool_o`000003oda<C?l0003o000000;o000000Go/k>co`000?l0003o
i^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002
o`000003oaTI6Ol0003o00000>_o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooo
ooooool00oooool`o`000003oda<C?l0003o000000;o000000Go/k>co`000?l0003oi^KVo`000003
ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI
6Ol0003o00000>[o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooo
oolbo`000005ofIVI_l0003o0000o`000?nc/k<00_l000000ooVi^Ko0000ooooo`02ooooo`04o`00
0?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI6Ol0003o0000
0>Wo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooolco`000005
ofIVI_l0003o0000o`000?nc/k<00_l000000ooVi^Ko0000ooooo`02ooooo`04o`000?oVi^Ko0000
olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI6Ol0003o00000>So00001_oo
ool1o`00007ooooo0Oooool001Sooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo00?ooooo=?l000001OmVIVKo0000o`000?l0003o/k>c00;o000000?oi^KVo`000?ooool0
0_ooool01?l0003oi^KVo`000?o<c<`2o`000005oiVIVOl0003o0000o`000?m<C4`00_l000000olI
6AWo0000o`00003Wo`0000Kooooo0Ol00001ooooo`7ooooo000Kooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool00ooooolbo`000004oc<c<ol0003o0000ofIVIP?o000000Go/k>co`00
0?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000
oda<C002o`000003oaTI6Ol0003o00000>Ko00001_ooool1o`00007ooooo0Oooool001cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03oooooc?o000000Co<c<co`000?l0003oIVIV
0ol000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l000001OnI
VIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l00000iOl00006ooooo`7o00000Oooool1
ooooo`006oooool00omgMgOo<S8booooo`04ooooo`?o00000ooooolgo`000005ofIVI_l0003o0000
o`000?nc/k<01Ol00002ooooooCo00001?ooool3o`0000;ooooo000Hooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`03ooooocCo000000Go6ATIo`000?l0003o0000ofIV
IP03o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000oooool01?l0003oi^KVo`000?o<c<`3o`00
0004ogmoOol0003o0000oda<C>Oo00001_ooool1o`00007ooooo0Oooool001Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`03ooooocGo000000Go6ATIo`000?l0003o0000ofIVIP03
o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000oooool01?l0003oi^KVo`000?o<c<`3o`000004
ogmoOol0003o0000oda<C>Ko00001_ooool1o`00007ooooo0Oooool001Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`03ooooocKo000000Go6ATIo`000?l0003o0000ofIVIP03o`00
0006ok>c/ol0003oc<c<o`000?oVi^Ko00000oooool01?l0003oi^KVo`000?o<c<`3o`000004ogmo
Ool0003o0000oda<C>Go00001_ooool1o`00007ooooo0Oooool001Sooooo1?l00006ooooo`03o`00
0?oooooooooo00?ooooo=ol000001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<
c<co0000onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<c0?o000000GoOgmoo`000?l0003o0000
oc<c<`3So`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo>?l0
00001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00003oooo
o`04o`000?oVi^Ko0000olc<c0?o000000GoOgmoo`000?l0003o0000oc<c<`3Ro`0000Kooooo0Ol0
0001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo>Ol000001OlI6AWo0000o`000?l0
003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<
c0?o000000GoOgmoo`000?l0003o0000oc<c<`3Qo`0000Kooooo0Ol00001ooooo`7ooooo000Roooo
o`03o`000?oooooooooo00?ooooo>_l000001OlI6AWo0000o`000?l0003oIVIV00Go000000Coc<c<
o`000?oVi^Ko00000oooool01?l0003oi^KVo`000?o<c<`4o`000004ofIVI_l0003o0000oc<c<n3o
00001_ooool1o`00007ooooo0Oooool002;ooooo0_l00004oooooc_o000000Go6ATIo`000?l0003o
0000ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko
0000olc<c0Co000000CoIVIVo`000?l0003o<c<cgol00005ooooo`;o00000_ooool002;ooooo00?o
0000ooooooooool00ooooollo`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000
o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`4o`000004ofIVI_l0003o
0000oc<c<mko00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooolm
o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000onKVi_l0
00000oooool01?l0003oi^KVo`000?o<c<`4o`000004ofIVI_l0003o0000oc<c<mgo00001_ooool1
o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooolno`000003oaTI6Ol0003o0000
00Co000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000
ok>c/`03o`000004ofIVI_l0003o0000oc<c<mco00001_ooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00oooooloo`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0
003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0
003o0000oc<c<m_o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooo
oom0o`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko0000
00?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0003o0000oc<c<m[o00001_oo
ool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooom1o`000004oaTI6Ol0003o
0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0
003o0000ok>c/`03o`000004ofIVI_l0003o0000oc<c<mWo00001_ooool1o`00007ooooo0Oooool0
02;ooooo00?o0000ooooooooool00ooooom2o`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVI
o`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004
ofIVI_l0003o0000oc<c<mSo00001_ooool1o`00007ooooo0Oooool002;ooooo0_l00004ooooodoo
000000?oi^KVo`000?ooool00_ooool01Ol0003oi^KVo`000?l0003o/k>c00?o000000CoIVIVo`00
0?l0003o<c<ceol00005ooooo`;o00000_ooool002;ooooo00?o0000ooooooooool00ooooom6o`00
0005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Go
0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0003o0000oc<c<mKo00001_ooool1o`00007o
oooo0Oooool002;ooooo00?o0000ooooooooool00ooooom7o`000005oc<c<ol0003o0000o`000?mo
Ogl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03
o`000004ofIVI_l0003o0000oc<c<mGo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000
ooooooooool00ooooom8o`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`00
0?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0003o0000oc<c
<mCo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooom9o`000005
oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Go0000
onKVi_l0003o0000ok>c/`03o`000003ofIVI_l0003o00000=Co00001_ooool1o`00007ooooo0Ooo
ool002;ooooo00?o0000ooooooooool00ooooom:o`000005oc<c<ol0003o0000o`000?moOgl00_l0
00001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000003
ofIVI_l0003oC4a<0=?o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool0
0ooooom;o`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko0000
00?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000003ofIVI_l0003oC4a<0=;o00001_ooool1
o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooom<o`000005oc<c<ol0003o0000
o`000?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000
ok>c/`05o`000003oda<C?l0003o00000<oo00001_ooool1o`00007ooooo0Oooool002;ooooo0_l0
0004ooooodgo000000Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0003o0000onKVi_l0
00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000CoOgmoo`000?l0003oC4a<d?l00005
ooooo`;o00000_ooool002;ooooo00?o0000ooooooooool00ooooom>o`000005oc<c<ol0003o0000
o`000?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000
ok>c/`02o`000004ogmoOol0003o0000oda<C<oo00001_ooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00ooooom?o`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o
0000o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000004ogmoOol0003o
0000oda<C<ko00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooom@
o`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo
00?o0000onKVi_l000001?l000001?moOgoo0000o`000?m<C4c=o`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`03o`000?oooooooooo00?oooooDOl000001Olc<c?o0000o`000?l0003oOgmo00;o
000000Go/k>co`000?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0?o000000CoOgmo
o`000?l0003oC4a<c?l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03
oooooe;o000000Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0003o0000onKVi_l00000
0oooool01?l0003oi^KVo`000?o<c<`3o`000004ogmoOol0003o0000oda<C<_o00001_ooool1o`00
007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooomCo`000005oc<c<ol0003o0000o`00
0?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0ol0
00001?moOgoo0000o`000?m<C4c:o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oo
oooooooo00?oooooE?l000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003o
i^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0?o000000CoOgmoo`000?l0003oC4a<bOl00006
ooooo`7o00000Oooool1ooooo`008_ooool2o`0000CoooooEOl000001Olc<c?o0000o`000?l0003o
Ogmo00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0?o0000
00CoOgmoo`000?l0003oC4a<b?l00005ooooo`;o00000_ooool002;ooooo00?o0000ooooooooool0
0ooooomDo`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko
000000;ooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<00;o0000
00?o6ATIo`000?l00000`ol00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003ooooooooo
o`03oooooeGo000000Co6ATIo`000?l0003oC4a<0ol000001onIVIWo0000o`000?o<c<co0000onKV
i_l000000_ooool01?l0003oi^KVo`000?o<c<`2o`000005oiVIVOl0003o0000o`000?m<C4`00_l0
00000olI6AWo0000o`000032o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooo
oooo00?oooooE_l000001?lI6AWo0000o`000?m<C4`3o`000007oiVIVOl0003o0000olc<c?l0003o
i^KVo`000002ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002
o`000003oaTI6Ol0003o00000<7o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooo
ooooool00ooooomGo`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`00
0?oVi^Ko000000;ooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<
00;o000000?o6ATIo`000?l00000`?l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003o
ooooooooo`03oooooeSo000000Co6ATIo`000?l0003oC4a<0ol000001onIVIWo0000o`000?o<c<co
0000onKVi_l000000_ooool01?l0003oi^KVo`000?o<c<`2o`000005oiVIVOl0003o0000o`000?m<
C4`00_l000000olI6AWo0000o`00002oo`0000Kooooo0Ol00001ooooo`7ooooo0009ooooo`03o`00
0?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`03oooooeWo000000Co6ATIo`000?l0003oC4a<0ol000001onIVIWo0000o`000?o<c<co
0000onKVi_l000000_ooool01?l0003oi^KVo`000?o<c<`2o`000003oiVIVOl0003o000000Co0000
00?o6ATIo`000?l00000__l00006ooooo`7o00000Oooool1ooooo`002Oooool00omEEEGoZJVYoooo
o`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?oooooF_l0
00001?lI6AWo0000o`000?m<C4`3o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000002oooo
o`04o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00
002mo`0000Kooooo0Ol00001ooooo`7ooooo0009ooooo`03ojVYZOmEEEGooooo013ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03oooooe_o000000Co6ATIo`000?l0003oC4a<1?l0
00001_nc/k?o0000olc<c?l0003oi^KVo`0000;ooooo00Co0000onKVi_l0003oc<c<0_l000001?nI
VIWo0000o`000?mVIVH3o`000003oaTI6Ol0003o00000;co00001_ooool1o`00007ooooo0Oooool0
00[ooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`04ooooo`?o00000ooooomLo`00
0004oaTI6Ol0003o0000oda<C0Co000000Ko/k>co`000?o<c<co0000onKVi_l00002ooooo`04o`00
0?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00002ko`00
00Cooooo0ol00002ooooo`002_ooool00omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b
<_o<c<`01Oooool00ol0003oooooooooo`03oooooego000000Co6ATIo`000?l0003oC4a<1?l00000
1_nc/k?o0000olc<c?l0003oi^KVo`0000;ooooo00Co0000onKVi_l0003oc<c<0_l000001?nIVIWo
0000o`000?mVIVH3o`000003oaTI6Ol0003o00000;[o00001_ooool1o`00007ooooo0Oooool000[o
oooo00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?o
ooooG_l000001?lI6AWo0000o`000?m<C4`4o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000_oo
ool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l0
0000^Ol00006ooooo`7o00000Oooool1ooooo`001oooool01Ol@413ooooooooooooooooo<S8b00co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03oooooeoo000000Go6ATIo`000?l0
003o0000ofIVIP03o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`00
0?o<c<`2o`000004oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000^?l00006ooooo`7o
00000Oooool1ooooo`001oooool5o`0000cooooo1?l00006ooooo`03o`000?oooooooooo00?ooooo
H?l000001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00002
ooooo`04o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000
o`00002go`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooHOl0
00001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00002oooo
o`04o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00
002fo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooH_l00000
1OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00002ooooo`04
o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00002e
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooHol000001OlI
6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00002ooooo`04o`00
0?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00002do`00
00Kooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oooomTo`000005oaTI6Ol0003o0000o`00
0?mVIVH00ol000001_nc/k?o0000olc<c?l0003oi^KVo`0000;ooooo`ol00005ooooo`;o00000_oo
ool002;ooooo00?o0000ooooooooool00ooooomVo`000004oc<c<ol0003o0000ofIVIP?o000000Go
/k>co`000?l0003oi^KVo`000004ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo
0000o`000?l0003o<c<c0;Go00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooooooo
ool00ooooomWo`000004oc<c<ol0003o0000ofIVIP?o000000Co/k>co`000?l0003oi^KV0_l00003
ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c0;Co0000
1_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooomXo`000004oc<c<ol0
003o0000ofIVIP?o000000?o/k>co`000?l000000_oVi^H01_l0003ooooooooooooooooo0000onKV
iP;o000000Co/k>co`000?l0003oOgmo0ol000000olc<c?o0000o`00002ao`0000Kooooo0Ol00001
ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooJOl000001?lc<c?o0000o`000?mVIVH3
o`000006ok>c/ol0003o0000o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o
000000GoOgmoo`000?l0003o0000oc<c<`2bo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03
o`000?oooooooooo00?oooooJ_l000001?lc<c?o0000o`000?mVIVH3o`000006ok>c/ol0003oc<c<
o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o
0000oc<c<`2ao`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
Jol000001?lc<c?o0000o`000?mVIVH3o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000oooool0
1Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`2`o`0000Kooooo
0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooK?l000001?lc<c?o0000o`00
0?mVIVH5o`000004olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`00
0005ogmoOol0003o0000o`000?lc<c<0[ol00006ooooo`7o00000Oooool1ooooo`008_ooool2o`00
00CoooooKOl000001?lc<c?o0000o`000?mVIVH2o`000007oiVIVOl0003o0000olc<c?l0003oi^KV
o`000003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c
0:ko00001Oooool2o`0000;ooooo000Rooooo`03o`000?oooooooooo00?oooooK_l000001?lc<c?o
0000o`000?mVIVH2o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`05o`000?oV
i^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c0:go00001_ooool1o`00007o
oooo0Oooool002;ooooo00?o0000ooooooooool00ooooom_o`000004oc<c<ol0003o0000ofIVIP;o
000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c
/`02o`000005ogmoOol0003o0000o`000?lc<c<0[?l00006ooooo`7o00000Oooool1ooooo`008_oo
ool00ol0003oooooooooo`03ooooog3o000000?o<c<co`000?l000000ol000001onIVIWo0000o`00
0?o<c<co0000onKVi_l000000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`00
0?l0003o0000oc<c<`2[o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo
00?oooooLOl000000olc<c?o0000oda<C003o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`00
0003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c0:[o
00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooombo`000003oc<c
<ol0003oC4a<00?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKV
i_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc<c<0ZOl00006ooooo`7o00000Ooo
ool1ooooo`008_ooool00ol0003oooooooooo`03ooooogGo000000GoC4a<o`000?l0003o0000oiVI
V@02o`000004olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005
ogmoOol0003o0000o`000?lc<c<0Z?l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003o
ooooooooo`03ooooogKo000000GoC4a<o`000?l0003o0000oiVIV@02o`000004olc<c?l0003oi^KV
o`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc<c<0
Yol00006ooooo`7o00000Oooool1ooooo`008_ooool2o`0000CoooooMol000000om<C4co0000o`00
0004o`000004olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005
ogmoOol0003o0000o`000?lc<c<0Y_l00005ooooo`;o00000_ooool002;ooooo00?o0000oooooooo
ool00ooooomho`000004oda<C?l0003o0000ogmoO`?o000000Coc<c<o`000?oVi^Ko00000_ooool0
1_l0003oi^KVo`000?o<c<co0000ok>c/`?o000000GoIVIVo`000?l0003o0000oaTI6@2To`0000Ko
oooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooNOl000001?m<C4co0000
o`000?moOgl3o`000004olc<c?l0003oi^KVo`0000;ooooo00Ko0000onKVi_l0003oc<c<o`000?nc
/k<3o`000005ofIVI_l0003o0000o`000?lI6AT0Xol00006ooooo`7o00000Oooool1ooooo`008_oo
ool00ol0003oooooooooo`03ooooog[o000000CoC4a<o`000?l0003oOgmo0ol000001?o<c<co0000
onKVi_l00002ooooo`06o`000?oVi^Ko0000olc<c?l0003o/k>c0ol000000omVIVKo0000o`00002T
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooNol000001?m<
C4co0000o`000?moOgl3o`000004olc<c?l0003oi^KVo`0000;ooooo00Ko0000onKVi_l0003oc<c<
o`000?nc/k<3o`000003ofIVI_l0003o00000:?o00001_ooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00ooooomlo`000004oda<C?l0003o0000ogmoO`?o000000Coc<c<o`000?oV
i^Ko00000_ooool01_l0003oi^KVo`000?o<c<co0000ok>c/`?o000000?oIVIVo`000?m<C4`0X_l0
0006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooggo000000CoC4a<
o`000?l0003oOgmo1Ol000002_oVi^Ko0000oooooooooooo0000onKVi_l0003oc<c<o`000?nc/k<3
o`000003ofIVI_l0003oC4a<0:7o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooo
ooooool00ooooomno`000004oda<C?l0003o0000ogmoO`;o000000Go/k>co`000?l0003oi^KVo`00
0002ooooo`06o`000?oVi^Ko0000olc<c?l0003o/k>c1Ol000000om<C4co0000o`00002No`0000Ko
oooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oooomoo`000004oda<C?l0003o0000ogmoO`;o
000000Go/k>co`000?l0003oi^KVo`000002ooooo`06o`000?oVi^Ko0000olc<c?l0003o/k>c1Ol0
00000om<C4co0000o`00002Mo`0000Gooooo0_l00002ooooo`008_ooool00ol0003oooooooooo`03
oooooh3o000000CoC4a<o`000?l0003oOgmo0_l000001Onc/k?o0000o`000?oVi^Ko000000;ooooo
00So0000onKVi_l0003oc<c<o`000?nc/k?o0000oiVIV@?o000000?oC4a<o`000?l00000W?l00006
ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooh7o000000CoC4a<o`00
0?l0003oOgmo0_l000001Onc/k?o0000o`000?oVi^Ko000000;ooooo00So0000onKVi_l0003oc<c<
o`000?nc/k?o0000oiVIV@?o000000?oC4a<o`000?l00000Vol00006ooooo`7o00000Oooool1oooo
o`008_ooool00ol0003oooooooooo`03oooooh;o000000CoC4a<o`000?l0003oOgmo0_l000001Onc
/k?o0000o`000?oVi^Ko000000;ooooo00Co0000onKVi_l0003oc<c<0ol000001OnIVIWo0000o`00
0?l0003oC4a<09co00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooo
oon3o`000004oda<C?l0003o0000ogmoO`;o000000Go/k>co`000?l0003oi^KVo`000002ooooo`03
o`000?oVi^Ko000000;oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<09_o00001_ooool1o`00
007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooon7o`000004ogmoOol0003o0000ok>c
/`;o000000Koi^KVo`000?ooooooooooo`000?oVi^H2o`000004olc<c?l0003o0000oiVIV@?o0000
00?oC4a<o`000?l00000V?l00006ooooo`7o00000Oooool1ooooo`004?ooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo00?oooooQ?l000001Olc
<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000002ooooo`05o`000?oV
i^Koi^KVo`000?o<c<`00_l000001OnIVIWo0000o`000?l0003oC4a<09Wo00001_ooool1o`00007o
oooo0Oooool001;ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool00ooooon5o`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc
/k?o0000o`000?oVi^Ko000000;ooooo0_l000000ooVi^Ko0000olc<c002o`000005oiVIVOl0003o
0000o`000?m<C4`0V?l00006ooooo`7o00000Oooool1ooooo`004_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`0000?oooooQ_l000001Olc<c?o0000o`00
0?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<
c0;o000000GoVIVIo`000?l0003o0000oda<C02Go`0000Cooooo0ol00002ooooo`004_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03
ooooohGo000000Go6ATIo`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0003o
i^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C02F
o`0000Kooooo0Ol00001ooooo`7ooooo000Booooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00?oooooQ_l000001OlI6AWo0000o`000?l0
003oIVIV00;o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0
003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<09Go00001_ooool1o`00007ooooo0Oooool0
01;ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000
ooooooooool00ooooon7o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`00
0?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`000005oiVIVOl0003o0000
o`000?m<C4`0U?l00006ooooo`7o00000Oooool1ooooo`004_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`03ooooohSo000000Go6ATI
o`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`04
o`000?oVi^Ko0000olc<c0;o000000OoVIVIo`000?l0003o0000oda<C?l0003o6ATI097o00001_oo
ool1o`00007ooooo0Oooool0013ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Kooooo00?o0000ooooooooool00ooooon9o`000005oaTI6Ol0003o0000o`000?mVIVH0
0_l000001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2
o`000003oiVIVOl0003o000000?o000000?o6ATIo`000?l00000S_l00006ooooo`7o00000Oooool1
ooooo`008_ooool00ol0003oooooooooo`03oooooh[o000000Go6ATIo`000?l0003o0000ofIVIP02
o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o
000000?oVIVIo`000?l000000ol000000olI6AWo0000o`00002=o`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`03o`000?oooooooooo00?oooooRol000001OlI6AWo0000o`000?l0003oIVIV00;o
000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l0
00000onIVIWo0000o`000003o`000003oaTI6Ol0003o000008co00001_ooool1o`00007ooooo0Ooo
ool002;ooooo00?o0000ooooooooool00ooooon<o`000005oaTI6Ol0003o0000o`000?mVIVH00_l0
00001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`00
0003oiVIVOl0003oIVIV00?o000000?o6ATIo`000?l00000Rol00006ooooo`7o00000Oooool1oooo
o`008_ooool2o`0000CoooooSOl000001OlI6AWo0000o`000?l0003oIVIV00;o000000OoVIVIo`00
0?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<1?l000001OmVIVKo0000
o`000?l0003o6ATI08co00001Oooool2o`0000;ooooo000Rooooo`03o`000?oooooooooo00?ooooo
S_l000001OlI6AWo0000o`000?l0003oIVIV00;o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko
000000?ooooo00Co0000onKVi_l0003oc<c<1?l000001OmVIVKo0000o`000?l0003o6ATI08_o0000
1_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooon?o`000005oaTI6Ol0
003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0
003oi^KVo`000?o<c<`4o`000005ofIVI_l0003o0000o`000?lI6AT0R_l00006ooooo`7o00000Ooo
ool1ooooo`008_ooool00ol0003oooooooooo`03oooooi3o000000Go6ATIo`000?l0003o0000ofIV
IP02o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`05o`000?oVi^Ko0000o`00
0?nc/k<00ol000001OmVIVKo0000o`000?l0003o6ATI08Wo00001_ooool1o`00007ooooo0Oooool0
02;ooooo00?o0000ooooooooool00ooooonAo`000005oaTI6Ol0003o0000o`000?mVIVH00_l00000
1onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01Ol0003oi^KVo`000?l0003o/k>c00?o
000000GoIVIVo`000?l0003o0000oaTI6@28o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03
o`000?oooooooooo00?oooooT_l000001OlI6AWo0000o`000?l0003oIVIV00;o000000OoVIVIo`00
0?l0003oc<c<o`000?oVi^Ko000000?ooooo0_l000000oo<c<co0000ok>c/`03o`000005ofIVI_l0
003o0000o`000?lI6AT0Qol00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003ooooooooo
o`03oooooi?o000000Go6ATIo`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0
003oi^KVo`000003ooooo`;o000000?oc<c<o`000?nc/k<00ol000001OmVIVKo0000o`000?l0003o
6ATI08Ko00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooonDo`00
0005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000onKVi_l00000
0_ooool01_l0003oi^KVo`000?o<c<co0000ok>c/`?o000000GoIVIVo`000?l0003o0000oaTI6@25
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oooonQo`000004onKVi_l0003ooooo
ooooo`Go000000?o/k>co`000?l00000R_l00005ooooo`;o00000_ooool002;ooooo00?o0000oooo
ooooool00ooooonHo`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc/k?o0000o`000?oV
i^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc
<c<0Q?l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooiWo0000
00Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0003o0000onKVi_l000000oooool01Ol0
003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`23o`0000Kooooo0Ol0
0001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooV_l000001Olc<c?o0000o`000?l0
003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`05o`000?oVi^Ko0000o`000?nc
/k<00_l000001OmoOgoo0000o`000?l0003o<c<c08;o00001_ooool1o`00007ooooo0Oooool002;o
oooo00?o0000ooooooooool00ooooonKo`000005oc<c<ol0003o0000o`000?moOgl00_l000001Onc
/k?o0000o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0
003o0000o`000?lc<c<0POl00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003ooooooooo
o`03oooooico000000Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0003o0000onKVi_l0
00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`20
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooWOl000001Olc
<c?o0000o`000?l0003oOgmo00?o000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`00
0?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`1oo`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`03o`000?oooooooooo00?oooooW_l000001Olc<c?o0000o`000?l0003oOgmo00?o
000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmo
o`000?l0003o0000oc<c<`1no`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oooonO
o`000005oc<c<ol0003o0000o`000?moOgl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`00
0?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c07go00001Oooool2o`00
00;ooooo000Rooooo`03o`000?oooooooooo00?oooooX?l000001Olc<c?o0000o`000?l0003oOgmo
00?o000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000Go
Ogmoo`000?l0003o0000oc<c<`1lo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oo
oooooooo00?oooooXOl000001Olc<c?o0000o`000?l0003oOgmo00?o000000Coc<c<o`000?oVi^Ko
00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`1k
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooX_l000001Olc
<c?o0000o`000?l0003oOgmo00?o000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`00
0?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`1jo`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`03o`000?oooooooooo00?oooooXol000001Olc<c?o0000o`000?l0003oOgmo00?o
000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmo
o`000?l0003o0000oc<c<`1io`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooo
oooo00?oooooY?l000001Olc<c?o0000o`000?l0003oOgmo00?o000000Coc<c<o`000?oVi^Ko0000
0oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`1ho`00
00Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooYOl000001Olc<c?o
0000o`000?l0003oOgmo00?o000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0
003o/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`1go`0000Kooooo0Ol00001ooooo`7ooooo
000Rooooo`03o`000?oooooooooo00?oooooY_l000001Olc<c?o0000o`000?l0003oOgmo00?o0000
00Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmoo`00
0?l0003o0000oc<c<`1fo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oooonWo`00
0005oc<c<ol0003o0000o`000?moOgl00ol000001?o<c<co0000onKVi_l00003ooooo`05o`000?oV
i^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c07Go00001Oooool2o`0000;o
oooo000Rooooo`03o`000?oooooooooo00?oooooZOl000001Om<C4co0000o`000?l0003oVIVI00;o
000000Coc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o
0000ofIVIP?o000000?o6ATIo`000?l00000LOl00006ooooo`7o00000Oooool1ooooo`008_ooool0
0ol0003oooooooooo`03oooooj[o000000GoC4a<o`000?l0003o0000oiVIV@02o`000004olc<c?l0
003oi^KVo`0000;ooooo00Co0000onKVi_l0003oc<c<0_l000001?nIVIWo0000o`000?mVIVH3o`00
0003oaTI6Ol0003o0000073o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooooooo
ool00ooooon[o`000005oda<C?l0003o0000o`000?nIVIT00_l000000oo<c<co0000o`000003oooo
o`04o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00
001_o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo[?l00000
1Om<C4co0000o`000?l0003oVIVI00;o000000?oc<c<o`000?l000000oooool01?l0003oi^KVo`00
0?o<c<`2o`000004oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000K_l00006ooooo`7o
00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03ooooojgo000000GoC4a<o`000?l0003o
0000oiVIV@03o`000003onKVi_l0003ooooo00;ooooo00Co0000onKVi_l0003oc<c<0_l000001?nI
VIWo0000o`000?mVIVH3o`000003oaTI6Ol0003o000006go00001_ooool1o`00007ooooo0Oooool0
00Co000000?o410@ooooooooool01Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Gooooo00?o0000ooooooooool00ooooon^o`000005oda<C?l0003o0000o`000?nIVIT00ol0
00000ooVi^Ko0000ooooo`02ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o
0000oda<C002o`000003oaTI6Ol0003o000006co00001_ooool1o`00007ooooo0Oooool000;ooooo
00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00ooooon_o`000005oda<C?l0003o0000o`00
0?nIVIT00ol000000ooVi^Ko0000ooooo`02ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVI
o`000?l0003o0000oda<C002o`000003oaTI6Ol0003o000006_o00001_ooool1o`00007ooooo0Ooo
ool000;ooooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooo
oooo00?ooooo0ol00003oooook3o000000?oC4a<o`000?l000000_l000001Onc/k?o0000o`000?oV
i^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<00;o
000000?o6ATIo`000?l00000J_l00004ooooo`?o00000_ooool000;ooooo00?o0000ooooooooool0
1?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
0ooooonao`000003oda<C?l0003o000000;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`04
o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI6Ol0003o
000006Wo00001_ooool1o`00007ooooo0Oooool000;ooooo00?o0000ooooooooool01Oooool00omg
MgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`03
oooook;o000000?oC4a<o`000?l000000_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Co
0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l0
0000J?l00006ooooo`7o00000Oooool1ooooo`000_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03oooook?o0000
00?oC4a<o`000?l000000_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0
003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l00000Iol00006
ooooo`7o00000Oooool1ooooo`000_ooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooo
oiRHV?l@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo]Ol00000
1OmVIVKo0000o`000?l0003o/k>c00;o000000?oi^KVo`000?ooool00_ooool01?l0003oi^KVo`00
0?o<c<`2o`000005oiVIVOl0003o0000o`000?m<C4`00_l000000olI6AWo0000o`00001Vo`0000Ko
oooo0Ol00001ooooo`7ooooo00000omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`03?ooool4o`0000Kooooo00?o0000ooooooooool00ooooonfo`000005ofIVI_l0003o0000o`00
0?nc/k<00_l000000ooVi^Ko0000ooooo`02ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVI
o`000?l0003o0000oda<C002o`000003oaTI6Ol0003o000006Go00001_ooool1o`00007ooooo0Ooo
ool002;ooooo00?o0000ooooooooool00ooooongo`000005ofIVI_l0003o0000o`000?nc/k<00_l0
00000ooVi^Ko0000ooooo`02ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o
0000oda<C002o`000003oaTI6Ol0003o000006Co00001_ooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00ooooonho`000005ofIVI_l0003o0000o`000?nc/k<00_l000000ooVi^Ko
0000ooooo`02ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002
o`000003oaTI6Ol0003o000006?o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooo
ooooool00oooooneo`000005oaTI6Ol0003o0000o`000?mVIVH00ol000001Onc/k?o0000o`000?oV
i^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<00;o
000000?o6ATIo`000?l00000H_l00006ooooo`7o00000Oooool1ooooo`008_ooool2o`0000Cooooo
]_l000001OlI6AWo0000o`000?l0003oIVIV00?o000000?o/k>co`000?l000000ol00002ooooog7o
00001Oooool2o`0000;ooooo000Rooooo`03o`000?oooooooooo00?ooooo]ol000001OlI6AWo0000
o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00003ooooo`04o`000?oVi^Ko
0000olc<c0?o000000GoOgmoo`000?l0003o0000oc<c<`1So`0000Kooooo0Ol00001ooooo`7ooooo
000Rooooo`03o`000?oooooooooo00?ooooo^?l000001OlI6AWo0000o`000?l0003oIVIV00?o0000
00Ko/k>co`000?o<c<co0000onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<c0?o000000GoOgmo
o`000?l0003o0000oc<c<`1Ro`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooo
oooo00?ooooo^Ol000001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000
onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<c0?o000000GoOgmoo`000?l0003o0000oc<c<`1Q
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo^_l000001OlI
6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000onKVi_l00003ooooo`04o`00
0?oVi^Ko0000olc<c0?o000000GoOgmoo`000?l0003o0000oc<c<`1Po`0000Kooooo0Ol00001oooo
o`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo^ol000001OlI6AWo0000o`000?l0003oIVIV
00?o000000Ko/k>co`000?o<c<co0000onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<c0?o0000
00GoOgmoo`000?l0003o0000oc<c<`1Oo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`00
0?oooooooooo00?ooooo_?l000001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<
c<co0000onKVi_l00003ooooo`04o`000?oVi^Ko0000olc<c0?o000000GoOgmoo`000?l0003o0000
oc<c<`1No`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo_Ol0
00001OlI6AWo0000o`000?l0003oIVIV00Go000000Coc<c<o`000?oVi^Ko00000oooool01?l0003o
i^KVo`000?o<c<`4o`000004ofIVI_l0003o0000oc<c<ego00001_ooool1o`00007ooooo0Oooool0
02;ooooo0_l00004oooookko000000Go6ATIo`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o
0000olc<c?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0Co000000CoIVIVo`000?l0
003o<c<cG?l00005ooooo`;o00000_ooool002;ooooo00?o0000ooooooooool00ooooonoo`000005
oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000onKVi_l000000ooo
ool01?l0003oi^KVo`000?o<c<`4o`000004ofIVI_l0003o0000oc<c<e_o00001_ooool1o`00007o
oooo0Oooool002;ooooo00?o0000ooooooooool00oooooo0o`000005oaTI6Ol0003o0000o`000?mV
IVH00_l000001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<
c<`4o`000004ofIVI_l0003o0000oc<c<e[o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o
0000ooooooooool00oooooo1o`000003oaTI6Ol0003o000000Co000000OoVIVIo`000?l0003oc<c<
o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0003o0000
oc<c<eWo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooo2o`00
0004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo
00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0003o0000oc<c<eSo00001_ooool1o`00
007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooo3o`000004oaTI6Ol0003o0000oda<
C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000
ok>c/`03o`000004ofIVI_l0003o0000oc<c<eOo00001_ooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00oooooo4o`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0
003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0
003o0000oc<c<eKo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooo
ooo5o`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko0000
00?ooooo00Go0000onKVi_l0003o0000ok>c/`03o`000004ofIVI_l0003o0000oc<c<eGo00001_oo
ool1o`00007ooooo0Oooool002;ooooo0_l00004ooooom;o000000?oi^KVo`000?ooool00_ooool0
1Ol0003oi^KVo`000?l0003o/k>c00?o000000CoIVIVo`000?l0003o<c<cE?l00005ooooo`;o0000
0_ooool002;ooooo00?o0000ooooooooool00oooooo9o`000005oc<c<ol0003o0000o`000?moOgl0
0_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo0_l000000oo<c<co0000ok>c/`03o`000005
ofIVI_l0003o0000o`000?lI6AT0D_l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003o
ooooooooo`03oooool[o000000Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0003o0000
onKVi_l000000oooool2o`000003olc<c?l0003o/k>c00?o000000GoIVIVo`000?l0003o0000oaTI
6@1Ao`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooobol00000
1Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`;o0000
00?oc<c<o`000?nc/k<00ol000000omVIVKo0000o`00001Bo`0000Kooooo0Ol00001ooooo`7ooooo
000Rooooo`03o`000?oooooooooo00?oooooc?l000001Olc<c?o0000o`000?l0003oOgmo00;o0000
00Go/k>co`000?l0003oi^KVo`000003ooooo`;o000000?oc<c<o`000?nc/k<00ol000000omVIVKo
0000o`00001Ao`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
cOl000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003oooo
o`;o000000?oc<c<o`000?nc/k<00ol000000omVIVKo0000oda<C01@o`0000Kooooo0Ol00001oooo
o`7ooooo000Rooooo`03o`000?oooooooooo00?oooooc_l000001Olc<c?o0000o`000?l0003oOgmo
00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`;o000000?oc<c<o`000?nc/k<00ol00000
0omVIVKo0000oda<C01?o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo
00?ooooocol000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`00
0003ooooo`;o000000?oc<c<o`000?nc/k<01Ol000000om<C4co0000o`00001<o`0000Kooooo0Ol0
0001ooooo`7ooooo000Rooooo`;o00001?ooooo@o`000005oc<c<ol0003o0000o`000?moOgl00_l0
00001Onc/k?o0000o`000?oVi^Ko000000?ooooo0_l000000oo<c<co0000ok>c/`05o`000003oda<
C?l0003o000004_o00001Oooool2o`0000;ooooo000Rooooo`03o`000?oooooooooo00?ooooodOl0
00001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003ooooo`;o
000000Goc<c<o`000?nc/k?o0000oiVIV@03o`000003oda<C?l0003o000004[o00001_ooool1o`00
007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooooBo`000005oc<c<ol0003o0000o`00
0?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo0_l000001Oo<c<co0000ok>c/ol0
003oVIVI00?o000000?oC4a<o`000?l00000BOl00006ooooo`7o00000Oooool1ooooo`008_ooool0
0ol0003oooooooooo`03ooooom?o000000Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0
003o0000onKVi_l000000oooool2o`000005olc<c?l0003o0000o`000?nIVIT00ol000000om<C4co
0000o`000018o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
e?l000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003oooo
o`;o00000_o<c<`2o`000005oiVIVOl0003o0000o`000?m<C4`0BOl00006ooooo`7o00000Oooool1
ooooo`008_ooool00ol0003oooooooooo`03ooooomGo000000Go<c<co`000?l0003o0000ogmoO`02
o`000005ok>c/ol0003o0000onKVi_l000000oooool3o`000004olc<c?l0003o0000oiVIV@?o0000
00?oC4a<o`000?l00000A_l00006ooooo`7o00000Oooool1ooooo`004?ooool4o`000005oa0@4?oo
oooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo00?ooooo
e_l000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000003oooo
o`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o0000oda<C017o`0000Kooooo0Ol0
0001ooooo`7ooooo000Booooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool0
0ol0003oooooooooo`03ooooomOo000000Go<c<co`000?l0003o0000ogmoO`02o`000005ok>c/ol0
003o0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`000005oiVIVOl0003o0000o`00
0?m<C4`0A_l00006ooooo`7o00000Oooool1ooooo`004_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00?ooooo0ol00003ooooomSo000000Go<c<co`000?l0003o0000ogmoO`02o`00
0005ok>c/ol0003o0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`000005oiVIVOl0
003o0000o`000?m<C4`0AOl00004ooooo`?o00000_ooool001;ooooo00?o0000ooooooooool01_oo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?oooooeol000001?lI6AWo0000o`00
0?m<C4`3o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000002ooooo`04o`000?oVi^Ko0000
olc<c0;o000000GoVIVIo`000?l0003o0000oda<C002o`000003oaTI6Ol0003o0000043o00001_oo
ool1o`00007ooooo0Oooool001;ooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool00ooooooHo`000004oaTI6Ol0003o0000oda<C0?o0000
00OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000;ooooo00Co0000onKVi_l0003oc<c<0_l00000
1OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l00000?ol00006ooooo`7o00000Ooo
ool1ooooo`004_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00ooooooIo`000004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<
o`000?oVi^Ko000000;ooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003o
C4a<00;o000000?o6ATIo`000?l00000?_l00006ooooo`7o00000Oooool1ooooo`004_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooooooJo`00
0004oaTI6Ol0003o0000oda<C0?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000;ooooo
00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`00
0?l00000?Ol00006ooooo`7o00000Oooool1ooooo`004?ooool00omEEEGoIVIVo`000005ooooo`Co
00001_ooool00ol0003oooooooooo`03ooooom_o000000Co6ATIo`000?l0003oC4a<0ol000001onI
VIWo0000o`000?o<c<co0000onKVi_l000000_ooool01?l0003oi^KVo`000?o<c<`2o`000005oiVI
VOl0003o0000o`000?m<C4`00_l000000olI6AWo0000o`00000lo`0000Kooooo0Ol00001ooooo`7o
oooo000Rooooo`03o`000?oooooooooo00?ooooog?l000001?lI6AWo0000o`000?m<C4`3o`000007
oiVIVOl0003o0000olc<c?l0003oi^KVo`000002ooooo`04o`000?oVi^Ko0000olc<c0;o000000?o
VIVIo`000?l000001?l000000olI6AWo0000o`00000ko`0000Kooooo0Ol00001ooooo`7ooooo000R
ooooo`03o`000?oooooooooo00?ooooogOl000001?lI6AWo0000o`000?m<C4`3o`000007oiVIVOl0
003o0000olc<c?l0003oi^KVo`000002ooooo`04o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`00
0?l0003oIVIV0ol000000olI6AWo0000o`00000jo`0000Kooooo0Ol00001ooooo`7ooooo000Roooo
o`03o`000?oooooooooo00?ooooog_l000001?lI6AWo0000o`000?m<C4`4o`000006ok>c/ol0003o
c<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o0000ofIV
IP?o000000?o6ATIo`000?l00000>Ol00006ooooo`7o00000Oooool1ooooo`008_ooool2o`0000Co
oooogol000001?lI6AWo0000o`000?m<C4`4o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000_oo
ool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l0
0000>?l00005ooooo`;o00000_ooool002;ooooo00?o0000ooooooooool00ooooooPo`000004oaTI
6Ol0003o0000oda<C0Co000000Ko/k>co`000?o<c<co0000onKVi_l00002ooooo`04o`000?oVi^Ko
0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol000000olI6AWo0000o`00000go`0000Kooooo
0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooohOl000001?lI6AWo0000o`00
0?m<C4`4o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2
o`000004oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000=_l00006ooooo`7o00000Ooo
ool1ooooo`008_ooool00ol0003oooooooooo`03ooooon;o000000Go6ATIo`000?l0003o0000ofIV
IP03o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`00
0004oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000=Ol00006ooooo`7o00000Oooool1
ooooo`008_ooool00ol0003oooooooooo`03ooooon?o000000Go6ATIo`000?l0003o0000ofIVIP03
o`000006ok>c/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004
oiVIVOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000=?l00006ooooo`7o00000Oooool1oooo
o`008_ooool00ol0003oooooooooo`03ooooonCo000000Go6ATIo`000?l0003o0000ofIVIP03o`00
0006ok>c/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVI
VOl0003o0000ofIVIP?o000000?o6ATIo`000?l00000<ol00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03ooooonGo000000Go6ATIo`000?l0003o0000ofIVIP03o`000006
ok>c/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0
003o0000ofIVIP?o000000?o6ATIo`000?l00000<_l00006ooooo`7o00000Oooool1ooooo`008_oo
ool00ol0003oooooooooo`03ooooonKo000000Go6ATIo`000?l0003o0000ofIVIP03o`000006ok>c
/ol0003oc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o
0000ofIVIP?o000000?o6ATIo`000?l00000<Ol00006ooooo`7o00000Oooool1ooooo`008_ooool2
o`0000Coooooiol000001OlI6AWo0000o`000?l0003oIVIV00?o000000Ko/k>co`000?o<c<co0000
onKVi_l00002oooood3o00001Oooool2o`0000;ooooo000Rooooo`03o`000?oooooooooo00?ooooo
jOl000001Olc<c?o0000o`000?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000004oooo
o`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c03;o00001_oo
ool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooooZo`000005oc<c<ol0003o
0000o`000?moOgl00_l000001?nc/k?o0000o`000?oVi^H2o`0000?ooooo00Go0000onKVi_l0003o
0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc<c<0<Ol00006ooooo`7o00000Oooool1oooo
o`008_ooool00ol0003oooooooooo`03ooooon_o000000Go<c<co`000?l0003o0000ogmoO`02o`00
0003ok>c/ol0003o000000;oi^KV00Ko0000ooooooooooooooooo`000?oVi^H2o`000004ok>c/ol0
003o0000ogmoO`?o000000?o<c<co`000?l00000;_l00006ooooo`7o00000Oooool1ooooo`008_oo
ool00ol0003oooooooooo`03ooooonco000000Go<c<co`000?l0003o0000ogmoO`02o`000006ok>c
/ol0003o0000o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmo
o`000?l0003o0000oc<c<`0_o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooo
oooo00?oooookOl000001Olc<c?o0000o`000?l0003oOgmo00;o000000Ko/k>co`000?o<c<co0000
onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o
<c<c02ko00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooo^o`00
0005oc<c<ol0003o0000o`000?moOgl00_l000001_nc/k?o0000olc<c?l0003oi^KVo`0000?ooooo
00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc<c<0;Ol00006oooo
o`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03ooooonoo000000Go<c<co`000?l0
003o0000ogmoO`04o`000004olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c
/`02o`000005ogmoOol0003o0000o`000?lc<c<0;?l00006ooooo`7o00000Oooool1ooooo`008_oo
ool2o`0000Coooool?l000001olc<c?o0000o`000?l0003oOgmoo`000?nIVIT00_l000001?o<c<co
0000onKVi_l00003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0
003o<c<c02_o00001Oooool2o`0000;ooooo000Rooooo`03o`000?oooooooooo00?ooooolOl00000
1olc<c?o0000o`000?l0003oOgmoo`000?nIVIT00_l000001?o<c<co0000onKVi_l00003ooooo`05
o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c02[o00001_ooool1
o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooobo`000003oc<c<ol0003o0000
00?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000onKVi_l0003o0000
ok>c/`02o`000005ogmoOol0003o0000o`000?lc<c<0:Ol00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03oooooo?o000000?o<c<co`000?l000000ol000001onIVIWo0000
o`000?o<c<co0000onKVi_l000000oooool01Ol0003oi^KVo`000?l0003o/k>c00;o000000GoOgmo
o`000?l0003o0000oc<c<`0Xo`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooo
oooo00?ooooom?l000000olc<c?o0000oda<C003o`000007oiVIVOl0003o0000olc<c?l0003oi^KV
o`000003ooooo`05o`000?oVi^Ko0000o`000?nc/k<00_l000001OmoOgoo0000o`000?l0003o<c<c
02Oo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00ooooooeo`000003
oc<c<ol0003oC4a<00?o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Go0000
onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc<c<09_l00006ooooo`7o0000
0Oooool1ooooo`008_ooool00ol0003oooooooooo`03ooooooSo000000GoC4a<o`000?l0003o0000
oiVIV@02o`000004olc<c?l0003oi^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`00
0005ogmoOol0003o0000o`000?lc<c<09Ol00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0
003oooooooooo`03ooooooWo000000GoC4a<o`000?l0003o0000oiVIV@02o`000004olc<c?l0003o
i^KVo`0000?ooooo00Go0000onKVi_l0003o0000ok>c/`02o`000005ogmoOol0003o0000o`000?lc
<c<09?l00006ooooo`7o00000Oooool1ooooo`008_ooool2o`0000Cooooon_l000001Om<C4co0000
o`000?l0003oVIVI00;o000000Coc<c<o`000?oVi^Ko00000oooool01Ol0003oi^KVo`000?l0003o
/k>c00;o000000GoOgmoo`000?l0003o0000oc<c<`0So`0000Gooooo0_l00002ooooo`008_ooool0
0ol0003oooooooooo`03oooooo_o000000GoC4a<o`000?l0003o0000oiVIV@02o`000004olc<c?l0
003oi^KVo`0000;ooooo00Co0000onKVi_l0003oc<c<0_l000001?nIVIWo0000o`000?mVIVH3o`00
0003oaTI6Ol0003o000001oo00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooooooo
ool00oooooolo`000005oda<C?l0003o0000o`000?nIVIT00_l000001?o<c<co0000onKVi_l00002
ooooo`04o`000?oVi^Ko0000olc<c0;o000000CoVIVIo`000?l0003oIVIV0ol00002oaTI6Aoo0000
1_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooomo`000005oda<C?l0
003o0000o`000?nIVIT00_l000001?o<c<co0000onKVi_l00002ooooo`04o`000?oVi^Ko0000olc<
c0;o000000CoVIVIo`000?l0003oIVIV1?l000000olI6AWo0000o`00000Lo`0000Kooooo0Ol00001
ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooo_l000001Om<C4co0000o`000?l0003o
VIVI00;o000000Coc<c<o`000?oVi^Ko00000_ooool01?l0003oi^KVo`000?o<c<`2o`000004oiVI
VOl0003o0000ofIVIPCo000000?o6ATIo`000?l000006ol00006ooooo`7o00000Oooool1ooooo`00
8_ooool00ol0003oooooooooo`03oooooooo000000GoC4a<o`000?l0003o0000oiVIV@02o`000004
olc<c?l0003oi^KVo`0000;ooooo00Co0000onKVi_l0003oc<c<0_l000001_nIVIWo0000o`000?mV
IVKo0000oda<C0;o000000?o6ATIo`000?l000006_l00006ooooo`7o00000Oooool1ooooo`001?l0
00000ol@413oooooooooo`02ooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`03oooooooo00000Ol000001Om<C4co0000
o`000?l0003oVIVI00Co000000Soi^KVo`000?ooooooooooo`000?oVi^Ko0000olc<c0;o000000Ko
VIVIo`000?l0003oIVIVo`000?m<C4`2o`000003oaTI6Ol0003o000001Wo00001_ooool1o`00007o
oooo0Oooool000;ooooo00?o0000ooooooooool01?ooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?oooooool00002o`000007oda<
C?l0003o0000o`000?nIVIWo0000ok>c/`02o`000008onKVi_l0003oooooooooool0003oi^KVo`00
0?o<c<`2o`000003oiVIVOl0003o000000;o000000CoC4a<o`000?l0003o6ATI6_l00006ooooo`7o
00000Oooool1ooooo`000_ooool00ol0003oooooooooo`04ooooo`03ojVYZOmEEEGooooo013ooooo
00?o0000ooooooooool00oooool3o`0000?oooooool00003o`000007oda<C?l0003o0000o`000?nI
VIWo0000ok>c/`02o`000008onKVi_l0003oooooooooool0003oi^KVo`000?o<c<`2o`000003oiVI
VOl0003o000000;o000000CoC4a<o`000?l0003o6ATI6Ol00004ooooo`?o00000_ooool000;ooooo
00?o0000ooooooooool01Oooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool00oooooooo`0000Co000000?oC4a<o`000?l000000ol000001Onc/k?o0000
o`000?oVi^Ko000000;ooooo00Co0000onKVi_l0003oc<c<0_l00002oiVIV@?o000000CoC4a<o`00
0?l0003o6ATI6?l00006ooooo`7o00000Oooool1ooooo`000_ooool00ol0003oooooooooo`05oooo
o`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo00?oooooool00005o`000004oda<C?l0003o0000ogmoO`;o000000Go/k>co`000?l0003oi^KV
o`000002ooooo`04o`000?oVi^Ko0000olc<c0?o000000GoVIVIo`000?l0003o0000oda<C002o`00
0003oaTI6Ol0003o000001Go00001_ooool1o`00007ooooo0Oooool000;ooooo00?o0000oooooooo
ool01Oooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00oooooooo`0000Ko000000CoC4a<o`000?l0003oOgmo0_l000001Onc/k?o0000o`000?oVi^Ko
000000;ooooo00Co0000onKVi_l0003oc<c<0ol000001OnIVIWo0000o`000?l0003oC4a<00;o0000
00?o6ATIo`000?l000005?l00006ooooo`7o00000Oooool1ooooo`000_ooool00ol0003ooooooooo
o`02ooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00?oooooool00007o`000004oda<C?l0003o0000ogmoO`;o000000Go/k>co`000?l0
003oi^KVo`000002ooooo`03o`000?oVi^Ko000000;oc<c<0_l000001OnIVIWo0000o`000?l0003o
C4a<00;o000000?o6ATIo`000?l000004ol00006ooooo`7o00000Oooool1ooooo`0000?oEEEEofIV
I_l000001?ooool5o`0000cooooo1?l00006ooooo`03o`000?oooooooooo00?oooooool0000;o`00
0004ogmoOol0003o0000ok>c/`;o000000Koi^KVo`000?ooooooooooo`000?oVi^H2o`000004olc<
c?l0003o0000oiVIV@?o000000CoC4a<o`000?l0003o6ATI5?l00006ooooo`7o00000Oooool1oooo
o`008_ooool00ol0003oooooooooo`03oooooooo00002?l000001Olc<c?o0000o`000?l0003oOgmo
00;o000000Go/k>co`000?l0003oi^KVo`000002ooooo`05o`000?oVi^Koi^KVo`000?o<c<`00_l0
00001OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l000004Ol00006ooooo`7o0000
0Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooooo00002Ol000001Olc<c?o0000o`00
0?l0003oOgmo00;o000000Go/k>co`000?l0003oi^KVo`000002ooooo`;o000000?oi^KVo`000?o<
c<`00_l000001OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l000004?l00006oooo
o`7o00000Oooool1ooooo`008_ooool2o`0000Coooooool0000:o`000005oc<c<ol0003o0000o`00
0?moOgl00_l000001Onc/k?o0000o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l0
00001OnIVIWo0000o`000?l0003oC4a<00;o000000?o6ATIo`000?l000003ol00005ooooo`;o0000
0_ooool002;ooooo00?o0000ooooooooool00oooooooo`0000Wo000000Go6ATIo`000?l0003o0000
ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000
olc<c0;o000000GoVIVIo`000?l0003o0000oda<C00Co`0000Kooooo0Ol00001ooooo`7ooooo000R
ooooo`03o`000?oooooooooo00?oooooool0000:o`000005oaTI6Ol0003o0000o`000?mVIVH00_l0
00001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`00
0005oiVIVOl0003o0000o`000?m<C4`04_l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0
003oooooooooo`03oooooooo00002ol000001OlI6AWo0000o`000?l0003oIVIV00;o000000OoVIVI
o`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co0000onKVi_l0003oc<c<0_l000001OnIVIWo
0000o`000?l0003oC4a<017o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000oooooooo
ool00oooooooo`0000co000000Go6ATIo`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o0000
olc<c?l0003oi^KVo`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000GoVIVIo`000?l0003o
0000oda<C00@o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
ool0000=o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000
onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`000004oiVIVOl0003o0000o`0000;oC4a<
3_l00006ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooooo00003_l0
00001OlI6AWo0000o`000?l0003oIVIV00;o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko0000
00?ooooo00Co0000onKVi_l0003oc<c<0_l000000onIVIWo0000o`000002o`000003oda<C?l0003o
000000_o00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooooo`00
00oo000000Go6ATIo`000?l0003o0000ofIVIP02o`000007oiVIVOl0003o0000olc<c?l0003oi^KV
o`000003ooooo`04o`000?oVi^Ko0000olc<c0;o000000?oVIVIo`000?l000000_l000000om<C4co
0000o`00000:o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
ool0000@o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000
onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`2o`000003oiVIVOl0003o000000;o000000?o
C4a<o`000?l000002Ol00006ooooo`7o00000Oooool1ooooo`008_ooool2o`0000Coooooool0000A
o`000005oaTI6Ol0003o0000o`000?mVIVH00_l000001onIVIWo0000o`000?o<c<co0000onKVi_l0
00000oooool01?l0003oi^KVo`000?o<c<`2o`0000;oVIVI0ol000000om<C4co0000o`000008o`00
00Gooooo0_l00002ooooo`008_ooool00ol0003oooooooooo`03oooooooo00004_l000001OlI6AWo
0000o`000?l0003oIVIV00;o000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00Co
0000onKVi_l0003oc<c<0ol000000onIVIWo0000o`00000;o`0000Kooooo0Ol00001ooooo`7ooooo
000Rooooo`03o`000?oooooooooo00?oooooool0000Co`000005oaTI6Ol0003o0000o`000?mVIVH0
0_l000001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?o<c<`@
o`0000Kooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000Do`00
0003oaTI6Ol0003o000000Co000000OoVIVIo`000?l0003oc<c<o`000?oVi^Ko000000?ooooo00?o
0000onKVi_l000000_o<c<`3o`000003oiVIVOl0003o000000So00001_ooool1o`00007ooooo0Ooo
ool002;ooooo00?o0000ooooooooool00oooooooo`0001Go000000Co6ATIo`000?l0003oC4a<0ol0
00001onIVIWo0000o`000?o<c<co0000onKVi_l000000oooool01?l0003oi^KVo`000?l00002olc<
c0co00001_ooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooooo`0001Ko
000000Co6ATIo`000?l0003oC4a<0ol000001onIVIWo0000o`000?o<c<co0000onKVi_l000000ooo
ool00ol0003oi^KVonKViP02o`0000;oc<c<2_l00006ooooo`7o00000Oooool1ooooo`008_ooool0
0ol0003oooooooooo`03oooooooo00005ol000001?lI6AWo0000o`000?m<C4`3o`000007oiVIVOl0
003o0000olc<c?l0003oi^KVo`000003ooooo`?o000000?oi^KVo`000?l000002_l00006ooooo`7o
00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooooo00006?l000001?lI6AWo0000
o`000?m<C4`3o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000005ooooo`go00001_ooool1
o`00007ooooo0Oooool002;ooooo0_l00004oooooooo00006Ol000001?lI6AWo0000o`000?m<C4`3
o`000007oiVIVOl0003o0000olc<c?l0003oi^KVo`000008ooooo`?o000000?oc<c<o`000?l00000
1?l00004ooooo`;o00000_ooool002;ooooo00?o0000ooooooooool00oooooooo`0001co000000Go
C4a<o`000?l0003o0000oiVIV@02o`000004olc<c?l0003oi^KVo`0000Wooooo0_l000000oo<c<co
0000o`000004o`0000Gooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
ool0000Mo`000005oda<C?l0003o0000o`000?nIVIT00_l000000oo<c<co0000o`00000:ooooo`;o
000000?oc<c<o`000?l000000ol00005ooooo`7o00000Oooool1ooooo`008_ooool00ol0003ooooo
ooooo`03oooooooo00007_l000000om<C4co0000o`000003o`000004olc<c?l0003oi^KVo`0000Wo
oooo0_l000000oo<c<co0000o`000003o`0000Gooooo0Ol00001ooooo`7ooooo000Rooooo`03o`00
0?oooooooooo00?oooooool0000Oo`000004oda<C?l0003o0000oiVIV@?o000000?oi^KVo`000?oo
ool02Oooool7o`0000Gooooo0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?ooooo
ool0000Po`000006oda<C?l0003o0000oiVIVOl0003oc<c<0_l0000:ooooo`;o000000?oc<c<o`00
0?l000000_l00005ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooooo
0000:?l0000;ooooo`Ko00001Oooool1o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool0
0oooooooo`0002Wo00002_ooool6o`0000Gooooo0Ol00001ooooo`7ooooo000Rooooo`;o00001?oo
ooooo`0002[o00002_ooool5o`0000Cooooo0_l00002ooooo`008_ooool00ol0003oooooooooo`03
oooooooo00008ol000000om<C4co0000o`000002o`0000;oi^KV0_l00008ooooo`Go00001Oooool1
o`00007ooooo0Oooool002;ooooo00?o0000ooooooooool00oooooooo`0002[o00000_oVi^H2o`00
00Oooooo1?l00005ooooo`7o00000Oooool1ooooo`008_ooool00ol0003oooooooooo`03oooooooo
0000;Ol000000ooVi^Ko0000o`000005ooooo`Co00001Oooool1o`00007ooooo0Oooool002;ooooo
00?o0000ooooooooool00oooooooo`0002oo000000?oi^KVo`000?ooool01?ooool3o`0000Gooooo
0Ol00001ooooo`7ooooo000Rooooo`03o`000?oooooooooo00?oooooool0000co`0000?ooooo0ol0
0005ooooo`7o00000Oooool1ooooo`003oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo00?oooooool0000eo`0000;ooooo0_l00005ooooo`7o00000Ooo
ool1ooooo`003oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo00?oooooool0000io`0000Gooooo0Ol00001ooooo`7ooooo
000@ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`?o0000
0oooooooo`0002_o000000?o6ATIo`000?l000002ol00003ooooo`?o00000_ooool0017ooooo00?o
V9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
oooooom1ooooo`7o00000Oooool1ooooo`004_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`3ooooood7ooooo0Ol00001ooooo`7ooooo
000Cooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo@Oooool1o`00007ooooo0Oooool000oooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool000oooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`7o00000Oooool1ooooo`008_ooooooo`0004Go00000_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-1.45856, -0.925172, 0.0763111, \
0.0763111}}],

Cell[BoxData[
    \(20\)], "Output"]
}, Open  ]],

Cell["\<\
The density is evenly distributed along the diagonal, and the total \
mass equals 20, as required. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["FFT for the Potential", "Section",
  CellTags->{"i:62", "c:33"}],

Cell[TextData[{
  "Now that we know the density on the grid, we solve Eq. ",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  "  for the potential on the grid, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(\(\ \)\(i\ j\)\)\)]],
  ". We do so using the FFT method described in Sec. ",
  ButtonBox["6.2.2",
    ButtonData:>{"Chapter6.nb", "c:26"},
    ButtonStyle->"Hyperlink"],
  ".  We then evaluate the force matrices ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(x\ i\ j\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`F\_\(y\ i\ j\)\)]],
  ", given by the discretized ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " derivatives of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(\(\ \)\(i\ j\)\)\)]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(F\_\(\(x\)\(\ \)\(i\)\(\ \)\(j\)\(\ \)\)\), "=", " ", 
          
          FractionBox[\(\[Phi]\_\(\(\ \)\(i + 1\ j\)\) - \[Phi]\_\(\(\ \)\(i \
- 1\ j\)\)\), 
            RowBox[{"2", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]]}]]}], ",", "\[IndentingNewLine]", 
        
        RowBox[{\(F\_\(\(y\)\(\ \)\(i\)\(\ \)\(j\)\(\ \)\)\), "=", " ", 
          RowBox[{
            
            FractionBox[\(\[Phi]\_\(\(\ \)\(i\ j + 1\)\) - \[Phi]\_\(\(\ \
\)\(i\ j - 1\)\)\), 
              RowBox[{"2", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]}]], "."}]}]}], 
      TraditionalForm]]]], "NE3",
  CellTags->"(7.3.8)"],

Cell[TextData[{
  "However, care must be taken to make sure that ",
  Cell[BoxData[
      \(TraditionalForm\`i \[PlusMinus] 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j \[PlusMinus] 1\)]],
  " remain in the correct ranges. This is accomplished using the ",
  StyleBox["Mod ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "function. The module ",
  StyleBox["fft\[Phi]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " performs the FFT and determines the forces."
}], "Text"],

Cell[BoxData[{
    RowBox[{\(G\  = \ 1;\), " ", 
      StyleBox[\( (*\ 
          in\ SI\ units\ G\  = \ 
            6.67\ 10^\(-11\)\ but\ here\ we\ use\ scaled\ units\ *) \),
        FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", "\n", 
      StyleBox[\( (*\ \(function\ to\ keep\ i \[PlusMinus] 
              1\ and\ j\) \[PlusMinus] 1\ in\ the\ range\ from\ 1\ to\ M; \ 
          used\ in\ force\ evaluation\ *) \),
        FontColor->RGBColor[1, 0, 0]]}], "\n", 
    RowBox[{\(imod[i_]\  := \ 1\  + \ Mod[i - 1, M];\), "\[IndentingNewLine]",
       "\n"}], "\[IndentingNewLine]", 
    RowBox[{
      StyleBox[\( (*\ 
          factor\ in\ discrete\ Fourier\ transform\ \((see\ Eq . \ \((6  .2  \
.43)\))\)\ *) \),
        FontColor->RGBColor[1, 0, 
        0]], \(factor\[Phi][m_, n_, \[CapitalDelta]x_, \[CapitalDelta]y_, 
            M_]\  := \(factor\[Phi][m, n, \[CapitalDelta]x, \[CapitalDelta]y, 
              M] = \(-4\)\ \[Pi]\ G/\((\ \(4\/\[CapitalDelta]x\^2\) 
                        Sin[\[Pi]\ m/M]^2 + \(4\/\[CapitalDelta]y\^2\) 
                        Sin[\[Pi]\ n/M]^2\ )\)\  // N\);\)}], "\n", 
    RowBox[{\(factor\[Phi][0, 0, \[CapitalDelta]x_, \[CapitalDelta]y_, 
            M_]\  = \ 1;\), "\n", 
      "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
    RowBox[{\(fft\[Phi][\[Rho]_]\), ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({\[Rho]ft, \[Phi]ft}\), ",", "\[IndentingNewLine]", 
          StyleBox[\( (*\ FFT\ of\ the\ density\ matrix\ *) \),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
          
          RowBox[{\(\[Rho]ft = Fourier[\[Rho]]\), ";", "\[IndentingNewLine]", 
            
            
            StyleBox[\( (*\ 
                total\ mass\ in\ the\ box\ equals\ \(\(zero\)\(:\)\)\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Rho]ft[\([1, 1]\)] = 0\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                determine\ potential\ \(\((\)\(see\ Eq . \ \((6  .2  .43)\)\)\
\(\ \)\)*) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(\[Phi]ft = 
              Table[\[Rho]ft[\([m + 1, n + 1]\)]*
                  factor\[Phi][m, n, \[CapitalDelta]x, \[CapitalDelta]y, 
                    M], {m, 0, M - 1}, {n, 0, M - 1}]\), ";", 
            "\[IndentingNewLine]", \(\[Phi] = \ 
              Re[InverseFourier[\[Phi]ft]]\), ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ \ data\ for\ forces, \ 
                including\ grid\ positions\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Fx\  = \ \ Table[{\((i - 
                        1)\)\ \[CapitalDelta]x, \((j - 
                        1)\) \[CapitalDelta]y, \(-m\) \((\[Phi][\([imod[
                                i + 1], imod[j]]\)] - \[Phi][\([imod[i - 1], 
                              imod[j]]\)])\)/\((2\ \[CapitalDelta]x)\)}, {i, 
                  1, M + 1}, {j, 1, M + 1}]\), ";", 
            "\[IndentingNewLine]", \(Fy\  = \ \ Table[{\((i - 
                        1)\)\ \[CapitalDelta]x, \((j - 
                        1)\) \[CapitalDelta]y, \(-m\) \((\[Phi][\([imod[i], 
                              imod[j + 1]]\)] - \[Phi][\([imod[i], 
                              imod[j - 
                                  1]]\)])\)/\((2\ \[CapitalDelta]y)\)}, {i, 
                  1, M + 1}, {j, 1, M + 1}]\), ";"}]}], " ", 
        "]"}]}]}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.71"],

Cell[TextData[{
  "Note that we require the FFT  of ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Rho]",
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Rho]\&~\),
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  ", to satisfy ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(\[Rho]\&~[\([1, 1]\)]\),
            FontFamily->"Courier",
            FontWeight->"Bold"], "=", "0"}], TraditionalForm]]],
  ". This is equivalent to ensuring that the total mass  in the domain is \
zero. Recall from Sec. ",
  ButtonBox["6.2.2",
    ButtonData:>{"Chapter6.nb", "c:26"},
    ButtonStyle->"Hyperlink"],
  " that this constraint on the mass density is required by the periodic \
boundary conditions, in order to keep the potential finite. Since the term ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[Rho]\&~[\([1, 1]\)]\),
          FontFamily->"Courier",
          FontWeight->"Bold"], TraditionalForm]]],
  " creates a uniform mass density, setting it equal to zero has no effect on \
the force between the particles. Physically, setting this term equal to zero \
is equivalent to adding a uniform ",
  StyleBox["negative",
    FontSlant->"Italic"],
  " mass density to the system so that the total mass vanishes. But this \
uniform mass density has no effect on the particle dynamics. \n\tAlso, note \
that the factor used to convert Fourier-transformed density to potential, ",
  StyleBox["factor\[Phi]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", is defined using double equal signs so that its values are remembered. \
We will be evaluating the potential many times, and it is wasteful to \
reevaluate the sin and cosine functions in ",
  StyleBox["factor\[Phi]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " at every timestep."
}], "Text"],

Cell[TextData[{
  "\tFinally,  note that we could have determined the force differently, by \
evaluating ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(-\[ImaginaryI]\), " ", 
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], " ", 
          RowBox[{
            StyleBox[
              OverscriptBox[
                StyleBox["\[Phi]",
                  FontWeight->"Plain",
                  FontSlant->"Plain"], "~"],
              FontWeight->"Plain",
              FontSlant->"Plain"], 
            StyleBox["(",
              FontWeight->"Plain",
              FontSlant->"Plain"], 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " and then performing an FFT. However, this is not a good idea, for two \
reasons. First, two FFTs (one for each dimension) need to be done, and the \
FFT is the most time-consuming part of the algorithm. Second, this method \
places too much weight on large wavenumber contributions, and leads to large \
numerical error. This will be discussed in more detail in relation to Eq. (",
  ButtonBox["7.3.12",
    ButtonData:>"(7.3.12)",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["7.72",
    ButtonData:>"Cell 7.72",
    ButtonStyle->"Hyperlink"],
  ", we evaluate the potential and force created by the previous density \
distribution."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Graphics`;\)\), "\n", 
    \(\(fft\[Phi][\[Rho]];\)\), "\n", 
    \(\(ListPlot3D[\[Phi], PlotRange \[Rule] All];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.72"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.15237 .19707 -5.94882 -9 ]
[.15237 .19707 .05118 0 ]
[.31741 .13214 -11.2392 -9 ]
[.31741 .13214 .76076 0 ]
[.49342 .06293 -10.5808 -9 ]
[.49342 .06293 1.41915 0 ]
[.68156 -0.01098 -9.92245 -9 ]
[.68156 -0.01098 2.07755 0 ]
[.77078 .10213 0 -6.15691 ]
[.77078 .10213 6 2.84309 ]
[.84915 .22213 0 -6.0419 ]
[.84915 .22213 12 2.9581 ]
[.9191 .32925 0 -5.94182 ]
[.9191 .32925 12 3.05818 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 12 3.14607 ]
[.02317 .27102 -18 -2.74731 ]
[.02317 .27102 0 6.25269 ]
[.01234 .33888 -12 -2.80473 ]
[.01234 .33888 0 6.19527 ]
[.00103 .40979 -6 -2.865 ]
[.00103 .40979 0 6.135 ]
[-0.01081 .48397 -6 -2.92835 ]
[-0.01081 .48397 0 6.07165 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(10)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(15)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(20)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.75847 .10666 m
.75231 .10893 L
s
[(5)] .77078 .10213 -1 .3682 Mshowa
.83673 .22638 m
.83053 .22851 L
s
[(10)] .84915 .22213 -1 .34264 Mshowa
.9066 .33325 m
.90035 .33526 L
s
[(15)] .9191 .32925 -1 .3204 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(20)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.77486 .13175 m
.77116 .13309 L
s
.79088 .15624 m
.78717 .15756 L
s
.80652 .18016 m
.8028 .18147 L
s
.8218 .20354 m
.81808 .20483 L
s
.85133 .24872 m
.8476 .24998 L
s
.86561 .27055 m
.86188 .2718 L
s
.87957 .29191 m
.87583 .29314 L
s
.89323 .31281 m
.88949 .31402 L
s
.91968 .35327 m
.91593 .35445 L
s
.93249 .37286 m
.92873 .37403 L
s
.94503 .39204 m
.94127 .3932 L
s
.95731 .41083 m
.95355 .41198 L
s
.74167 .08097 m
.73798 .08235 L
s
.72446 .05465 m
.72078 .05604 L
s
.70682 .02766 m
.70315 .02908 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.0354 .26625 m
.04151 .26387 L
s
[(-10)] .02317 .27102 1 -0.38949 Mshowa
.02462 .33425 m
.03076 .33194 L
s
[(-5)] .01234 .33888 1 -0.37673 Mshowa
.01336 .40531 m
.01953 .40307 L
s
[(0)] .00103 .40979 1 -0.36333 Mshowa
.00158 .47964 m
.00778 .47748 L
s
[(5)] -0.01081 .48397 1 -0.34926 Mshowa
.125 Mabswid
.03328 .27962 m
.03695 .2782 L
s
.03114 .2931 m
.03482 .29169 L
s
.02899 .3067 m
.03267 .30529 L
s
.02682 .32041 m
.0305 .31902 L
s
.02241 .34821 m
.0261 .34683 L
s
.02018 .3623 m
.02387 .36092 L
s
.01793 .37651 m
.02162 .37514 L
s
.01565 .39084 m
.01935 .38949 L
s
.01105 .41991 m
.01475 .41857 L
s
.00871 .43464 m
.01242 .43331 L
s
.00636 .4495 m
.01007 .44818 L
s
.00398 .4645 m
.0077 .46319 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.694 .303 .304 r
.38616 .65913 .40384 .64035 .43026 .66589 .41296 .68136 Metetra
.673 .255 .243 r
.41296 .68136 .43026 .66589 .45755 .68812 .44061 .70007 Metetra
.637 .181 .153 r
.44061 .70007 .45755 .68812 .48565 .70684 .46906 .71505 Metetra
.571 .064 .01 r
.46906 .71505 .48565 .70684 .5145 .72183 .49822 .72611 Metetra
.431 0 0 r
.49822 .72611 .5145 .72183 .54402 .73291 .52802 .73308 Metetra
.138 0 0 r
.52802 .73308 .54402 .73291 .57413 .73991 .55836 .7358 Metetra
.277 .753 .934 r
.55836 .7358 .57413 .73991 .60473 .74268 .58915 .73418 Metetra
.555 .83 .997 r
.58915 .73418 .60473 .74268 .63571 .74111 .62028 .7281 Metetra
.672 .8 .943 r
.62028 .7281 .63571 .74111 .66698 .73511 .65164 .71751 Metetra
.72 .757 .882 r
.65164 .71751 .66698 .73511 .69843 .72461 .68311 .70239 Metetra
.742 .721 .832 r
.68311 .70239 .69843 .72461 .72993 .70959 .71459 .68274 Metetra
.753 .693 .794 r
.71459 .68274 .72993 .70959 .76137 .69004 .74594 .6586 Metetra
.759 .671 .764 r
.74594 .6586 .76137 .69004 .79263 .66603 .77705 .63004 Metetra
.763 .653 .741 r
.77705 .63004 .79263 .66603 .82359 .6376 .80781 .59717 Metetra
.765 .639 .722 r
.80781 .59717 .82359 .6376 .85414 .60488 .83809 .56014 Metetra
.766 .627 .706 r
.83809 .56014 .85414 .60488 .88417 .568 .8678 .5191 Metetra
.767 .617 .693 r
.8678 .5191 .88417 .568 .91356 .52714 .89681 .47427 Metetra
.768 .608 .681 r
.89681 .47427 .91356 .52714 .94221 .48247 .92505 .42586 Metetra
.41 .387 .723 r
.92505 .42586 .94221 .48247 .97003 .43424 .96316 .45457 Metetra
.672 .254 .242 r
.36797 .67454 .38616 .65913 .41296 .68136 .39516 .69325 Metetra
.637 .18 .152 r
.39516 .69325 .41296 .68136 .44061 .70007 .42319 .70821 Metetra
.569 .062 .007 r
.42319 .70821 .44061 .70007 .46906 .71505 .45199 .71925 Metetra
.429 0 0 r
.45199 .71925 .46906 .71505 .49822 .72611 .48148 .72618 Metetra
.134 0 0 r
.48148 .72618 .49822 .72611 .52802 .73308 .51156 .72886 Metetra
.281 .755 .936 r
.51156 .72886 .52802 .73308 .55836 .7358 .54215 .72717 Metetra
.557 .83 .997 r
.54215 .72717 .55836 .7358 .58915 .73418 .57313 .72102 Metetra
.673 .799 .943 r
.57313 .72102 .58915 .73418 .62028 .7281 .6044 .71035 Metetra
.72 .757 .881 r
.6044 .71035 .62028 .7281 .65164 .71751 .63585 .69513 Metetra
.742 .721 .832 r
.63585 .69513 .65164 .71751 .68311 .70239 .66736 .67537 Metetra
.753 .692 .794 r
.66736 .67537 .68311 .70239 .71459 .68274 .6988 .6511 Metetra
.759 .67 .764 r
.6988 .6511 .71459 .68274 .74594 .6586 .73007 .6224 Metetra
.763 .653 .741 r
.73007 .6224 .74594 .6586 .77705 .63004 .76103 .58939 Metetra
.765 .639 .722 r
.76103 .58939 .77705 .63004 .80781 .59717 .79158 .55219 Metetra
.766 .627 .706 r
.79158 .55219 .80781 .59717 .83809 .56014 .8216 .51099 Metetra
.767 .617 .693 r
.8216 .51099 .83809 .56014 .8678 .5191 .85098 .46599 Metetra
.768 .608 .681 r
.85098 .46599 .8678 .5191 .89681 .47427 .87963 .4174 Metetra
.401 .381 .722 r
.87963 .4174 .89681 .47427 .92505 .42586 .91713 .4461 Metetra
.671 .228 .19 r
.91713 .4461 .92505 .42586 .96316 .45457 .95543 .47159 Metetra
.636 .179 .15 r
.3493 .68636 .36797 .67454 .39516 .69325 .37691 .70131 Metetra
.568 .06 .005 r
.37691 .70131 .39516 .69325 .42319 .70821 .40534 .71232 Metetra
.426 0 0 r
.40534 .71232 .42319 .70821 .45199 .71925 .4345 .71922 Metetra
.13 0 0 r
.4345 .71922 .45199 .71925 .48148 .72618 .46432 .72185 Metetra
.285 .757 .938 r
.46432 .72185 .48148 .72618 .51156 .72886 .4947 .7201 Metetra
.558 .829 .996 r
.4947 .7201 .51156 .72886 .54215 .72717 .52553 .71388 Metetra
.673 .799 .942 r
.52553 .71388 .54215 .72717 .57313 .72102 .55672 .70312 Metetra
.72 .756 .881 r
.55672 .70312 .57313 .72102 .6044 .71035 .58814 .6878 Metetra
.742 .72 .831 r
.58814 .6878 .6044 .71035 .63585 .69513 .61967 .66792 Metetra
.753 .692 .793 r
.61967 .66792 .63585 .69513 .66736 .67537 .65121 .64352 Metetra
.759 .67 .764 r
.65121 .64352 .66736 .67537 .6988 .6511 .68262 .61469 Metetra
.763 .653 .741 r
.68262 .61469 .6988 .6511 .73007 .6224 .7138 .58153 Metetra
.765 .638 .722 r
.7138 .58153 .73007 .6224 .76103 .58939 .74461 .54417 Metetra
.766 .627 .706 r
.74461 .54417 .76103 .58939 .79158 .55219 .77496 .50281 Metetra
.767 .617 .693 r
.77496 .50281 .79158 .55219 .8216 .51099 .80472 .45763 Metetra
.768 .608 .681 r
.80472 .45763 .8216 .51099 .85098 .46599 .83379 .40887 Metetra
.391 .374 .721 r
.83379 .40887 .85098 .46599 .87963 .4174 .87066 .43755 Metetra
.671 .227 .189 r
.87066 .43755 .87963 .4174 .91713 .4461 .90836 .46302 Metetra
.644 .174 .122 r
.90836 .46302 .91713 .4461 .95543 .47159 .9468 .48501 Metetra
.567 .057 .002 r
.3302 .69435 .3493 .68636 .37691 .70131 .35825 .70533 Metetra
.424 0 0 r
.35825 .70533 .37691 .70131 .40534 .71232 .38709 .71219 Metetra
.125 0 0 r
.38709 .71219 .40534 .71232 .4345 .71922 .41663 .71477 Metetra
.289 .759 .94 r
.41663 .71477 .4345 .71922 .46432 .72185 .4468 .71296 Metetra
.56 .829 .996 r
.4468 .71296 .46432 .72185 .4947 .7201 .47748 .70667 Metetra
.674 .798 .941 r
.47748 .70667 .4947 .7201 .52553 .71388 .50857 .69582 Metetra
.721 .756 .88 r
.50857 .69582 .52553 .71388 .55672 .70312 .53996 .6804 Metetra
.742 .72 .831 r
.53996 .6804 .55672 .70312 .58814 .6878 .57152 .6604 Metetra
.753 .692 .793 r
.57152 .6604 .58814 .6878 .61967 .66792 .60315 .63588 Metetra
.759 .67 .764 r
.60315 .63588 .61967 .66792 .65121 .64352 .63472 .6069 Metetra
.762 .653 .74 r
.63472 .6069 .65121 .64352 .68262 .61469 .66611 .57359 Metetra
.765 .638 .722 r
.66611 .57359 .68262 .61469 .7138 .58153 .69719 .53608 Metetra
.766 .627 .706 r
.69719 .53608 .7138 .58153 .74461 .54417 .72786 .49454 Metetra
.767 .617 .693 r
.72786 .49454 .74461 .54417 .77496 .50281 .75801 .44919 Metetra
.768 .608 .681 r
.75801 .44919 .77496 .50281 .80472 .45763 .78751 .40025 Metetra
.381 .367 .719 r
.78751 .40025 .80472 .45763 .83379 .40887 .82373 .42891 Metetra
.671 .227 .188 r
.82373 .42891 .83379 .40887 .87066 .43755 .86083 .45436 Metetra
.643 .172 .12 r
.86083 .45436 .87066 .43755 .90836 .46302 .89871 .47633 Metetra
.6 .096 .027 r
.89871 .47633 .90836 .46302 .9468 .48501 .93725 .49456 Metetra
.421 0 0 r
.31072 .69827 .3302 .69435 .35825 .70533 .33922 .70509 Metetra
.121 0 0 r
.33922 .70509 .35825 .70533 .38709 .71219 .36849 .70763 Metetra
.293 .76 .942 r
.36849 .70763 .38709 .71219 .41663 .71477 .39844 .70576 Metetra
.561 .829 .996 r
.39844 .70576 .41663 .71477 .4468 .71296 .42896 .69939 Metetra
.674 .798 .941 r
.42896 .69939 .4468 .71296 .47748 .70667 .45995 .68845 Metetra
.721 .755 .88 r
.45995 .68845 .47748 .70667 .50857 .69582 .49131 .67292 Metetra
.742 .72 .831 r
.49131 .67292 .50857 .69582 .53996 .6804 .52291 .65281 Metetra
.753 .692 .793 r
.52291 .65281 .53996 .6804 .57152 .6604 .55463 .62816 Metetra
.759 .67 .764 r
.55463 .62816 .57152 .6604 .60315 .63588 .58635 .59904 Metetra
.762 .652 .74 r
.58635 .59904 .60315 .63588 .63472 .6069 .61795 .56557 Metetra
.765 .638 .722 r
.61795 .56557 .63472 .6069 .66611 .57359 .64931 .5279 Metetra
.766 .627 .706 r
.64931 .5279 .66611 .57359 .69719 .53608 .68032 .4862 Metetra
.767 .617 .693 r
.68032 .4862 .69719 .53608 .72786 .49454 .71085 .44067 Metetra
.767 .608 .681 r
.71085 .44067 .72786 .49454 .75801 .44919 .74079 .39154 Metetra
.37 .36 .718 r
.74079 .39154 .75801 .44919 .78751 .40025 .77635 .4202 Metetra
.67 .226 .186 r
.77635 .4202 .78751 .40025 .82373 .42891 .81283 .44562 Metetra
.643 .171 .119 r
.81283 .44562 .82373 .42891 .86083 .45436 .85013 .46756 Metetra
.6 .095 .024 r
.85013 .46756 .86083 .45436 .89871 .47633 .88815 .48576 Metetra
.528 0 0 r
.88815 .48576 .89871 .47633 .93725 .49456 .92676 .49996 Metetra
.116 0 0 r
.29091 .69793 .31072 .69827 .33922 .70509 .31989 .70042 Metetra
.296 .762 .944 r
.31989 .70042 .33922 .70509 .36849 .70763 .34961 .69848 Metetra
.562 .828 .995 r
.34961 .69848 .36849 .70763 .39844 .70576 .37997 .69203 Metetra
.674 .797 .94 r
.37997 .69203 .39844 .70576 .42896 .69939 .41087 .68101 Metetra
.721 .755 .879 r
.41087 .68101 .42896 .69939 .45995 .68845 .44219 .66537 Metetra
.742 .719 .831 r
.44219 .66537 .45995 .68845 .49131 .67292 .47381 .64515 Metetra
.753 .692 .793 r
.47381 .64515 .49131 .67292 .52291 .65281 .50563 .62036 Metetra
.759 .67 .764 r
.50563 .62036 .52291 .65281 .55463 .62816 .53751 .5911 Metetra
.762 .652 .74 r
.53751 .5911 .55463 .62816 .58635 .59904 .56933 .55748 Metetra
.764 .638 .721 r
.56933 .55748 .58635 .59904 .61795 .56557 .60097 .51964 Metetra
.766 .626 .706 r
.60097 .51964 .61795 .56557 .64931 .5279 .63231 .47777 Metetra
.767 .617 .693 r
.63231 .47777 .64931 .5279 .68032 .4862 .66323 .43206 Metetra
.767 .608 .681 r
.66323 .43206 .68032 .4862 .71085 .44067 .69362 .38276 Metetra
.358 .352 .716 r
.69362 .38276 .71085 .44067 .74079 .39154 .7285 .41139 Metetra
.67 .225 .185 r
.7285 .41139 .74079 .39154 .77635 .4202 .76435 .4368 Metetra
.642 .17 .117 r
.76435 .4368 .77635 .4202 .81283 .44562 .80106 .45871 Metetra
.599 .093 .022 r
.80106 .45871 .81283 .44562 .85013 .46756 .83855 .47686 Metetra
.527 0 0 r
.83855 .47686 .85013 .46756 .88815 .48576 .87668 .49102 Metetra
.403 0 0 r
.87668 .49102 .88815 .48576 .92676 .49996 .91534 .50095 Metetra
.3 .763 .946 r
.27083 .69314 .29091 .69793 .31989 .70042 .30032 .69114 Metetra
.564 .828 .995 r
.30032 .69114 .31989 .70042 .34961 .69848 .33051 .68461 Metetra
.675 .797 .94 r
.33051 .68461 .34961 .69848 .37997 .69203 .3613 .67349 Metetra
.721 .754 .879 r
.3613 .67349 .37997 .69203 .41087 .68101 .39258 .65775 Metetra
.742 .719 .83 r
.39258 .65775 .41087 .68101 .44219 .66537 .42424 .6374 Metetra
.753 .691 .793 r
.42424 .6374 .44219 .66537 .47381 .64515 .45614 .61249 Metetra
.759 .67 .764 r
.45614 .61249 .47381 .64515 .50563 .62036 .48818 .58309 Metetra
.762 .652 .74 r
.48818 .58309 .50563 .62036 .53751 .5911 .52022 .54931 Metetra
.764 .638 .721 r
.52022 .54931 .53751 .5911 .56933 .55748 .55214 .51131 Metetra
.766 .626 .706 r
.55214 .51131 .56933 .55748 .60097 .51964 .58383 .46926 Metetra
.767 .617 .693 r
.58383 .46926 .60097 .51964 .63231 .47777 .61515 .42338 Metetra
.767 .608 .681 r
.61515 .42338 .63231 .47777 .66323 .43206 .64599 .37389 Metetra
.346 .344 .714 r
.64599 .37389 .66323 .43206 .69362 .38276 .68018 .4025 Metetra
.67 .224 .184 r
.68018 .4025 .69362 .38276 .7285 .41139 .71538 .42788 Metetra
.642 .169 .115 r
.71538 .42788 .7285 .41139 .76435 .4368 .7515 .44976 Metetra
.598 .092 .02 r
.7515 .44976 .76435 .4368 .80106 .45871 .78844 .46787 Metetra
.525 0 0 r
.78844 .46787 .80106 .45871 .83855 .47686 .82608 .48198 Metetra
.4 0 0 r
.82608 .48198 .83855 .47686 .87668 .49102 .8643 .49185 Metetra
.186 0 0 r
.8643 .49185 .87668 .49102 .91534 .50095 .90296 .49728 Metetra
.565 .828 .995 r
.25054 .68372 .27083 .69314 .30032 .69114 .28056 .67711 Metetra
.675 .796 .939 r
.28056 .67711 .30032 .69114 .33051 .68461 .31125 .6659 Metetra
.721 .754 .879 r
.31125 .6659 .33051 .68461 .3613 .67349 .34249 .65006 Metetra
.742 .719 .83 r
.34249 .65006 .3613 .67349 .39258 .65775 .37417 .62959 Metetra
.753 .691 .793 r
.37417 .62959 .39258 .65775 .42424 .6374 .40617 .60454 Metetra
.759 .669 .763 r
.40617 .60454 .42424 .6374 .45614 .61249 .43836 .57499 Metetra
.762 .652 .74 r
.43836 .57499 .45614 .61249 .48818 .58309 .47063 .54106 Metetra
.764 .638 .721 r
.47063 .54106 .48818 .58309 .52022 .54931 .50284 .50289 Metetra
.766 .626 .706 r
.50284 .50289 .52022 .54931 .55214 .51131 .53487 .46067 Metetra
.767 .617 .693 r
.53487 .46067 .55214 .51131 .58383 .46926 .5666 .4146 Metetra
.767 .608 .682 r
.5666 .4146 .58383 .46926 .61515 .42338 .5979 .36493 Metetra
.333 .335 .712 r
.5979 .36493 .61515 .42338 .64599 .37389 .63138 .39352 Metetra
.669 .223 .183 r
.63138 .39352 .64599 .37389 .68018 .4025 .66592 .41888 Metetra
.641 .168 .114 r
.66592 .41888 .68018 .4025 .71538 .42788 .70143 .44072 Metetra
.597 .09 .018 r
.70143 .44072 .71538 .42788 .7515 .44976 .73781 .45879 Metetra
.524 0 0 r
.73781 .45879 .7515 .44976 .78844 .46787 .77495 .47285 Metetra
.397 0 0 r
.77495 .47285 .78844 .46787 .82608 .48198 .81273 .48266 Metetra
.183 0 0 r
.81273 .48266 .82608 .48198 .8643 .49185 .85101 .48801 Metetra
.119 .657 .85 r
.85101 .48801 .8643 .49185 .90296 .49728 .88964 .48874 Metetra
.675 .795 .939 r
.23012 .66954 .25054 .68372 .28056 .67711 .2607 .65823 Metetra
.721 .754 .878 r
.2607 .65823 .28056 .67711 .31125 .6659 .29189 .64228 Metetra
.742 .718 .83 r
.29189 .64228 .31125 .6659 .34249 .65006 .3236 .62169 Metetra
.753 .691 .792 r
.3236 .62169 .34249 .65006 .37417 .62959 .3557 .59651 Metetra
.758 .669 .763 r
.3557 .59651 .37417 .62959 .40617 .60454 .38805 .56681 Metetra
.762 .652 .74 r
.38805 .56681 .40617 .60454 .43836 .57499 .42055 .53272 Metetra
.764 .638 .721 r
.42055 .53272 .43836 .57499 .47063 .54106 .45305 .49439 Metetra
.766 .626 .706 r
.45305 .49439 .47063 .54106 .50284 .50289 .48543 .45199 Metetra
.767 .617 .693 r
.48543 .45199 .50284 .50289 .53487 .46067 .51757 .40574 Metetra
.767 .608 .682 r
.51757 .40574 .53487 .46067 .5666 .4146 .54934 .35589 Metetra
.319 .326 .71 r
.54934 .35589 .5666 .4146 .5979 .36493 .5821 .38445 Metetra
.669 .222 .181 r
.5821 .38445 .5979 .36493 .63138 .39352 .61596 .40978 Metetra
.64 .166 .112 r
.61596 .40978 .63138 .39352 .66592 .41888 .65084 .43159 Metetra
.596 .088 .016 r
.65084 .43159 .66592 .41888 .70143 .44072 .68665 .44962 Metetra
.522 0 0 r
.68665 .44962 .70143 .44072 .73781 .45879 .72327 .46362 Metetra
.395 0 0 r
.72327 .46362 .73781 .45879 .77495 .47285 .7606 .47336 Metetra
.179 0 0 r
.7606 .47336 .77495 .47285 .81273 .48266 .79849 .47864 Metetra
.123 .66 .853 r
.79849 .47864 .81273 .48266 .85101 .48801 .83681 .47928 Metetra
.404 .798 .987 r
.83681 .47928 .85101 .48801 .88964 .48874 .8754 .47514 Metetra
.721 .753 .878 r
.20965 .65049 .23012 .66954 .2607 .65823 .2408 .63443 Metetra
.742 .718 .83 r
.2408 .63443 .2607 .65823 .29189 .64228 .27253 .61372 Metetra
.752 .691 .792 r
.27253 .61372 .29189 .64228 .3236 .62169 .30472 .5884 Metetra
.758 .669 .763 r
.30472 .5884 .3236 .62169 .3557 .59651 .33724 .55855 Metetra
.762 .652 .74 r
.33724 .55855 .3557 .59651 .38805 .56681 .36996 .5243 Metetra
.764 .638 .721 r
.36996 .5243 .38805 .56681 .42055 .53272 .40276 .4858 Metetra
.766 .626 .706 r
.40276 .4858 .42055 .53272 .45305 .49439 .4355 .44323 Metetra
.767 .616 .693 r
.4355 .44323 .45305 .49439 .48543 .45199 .46806 .3968 Metetra
.767 .608 .682 r
.46806 .3968 .48543 .45199 .51757 .40574 .50031 .34675 Metetra
.304 .315 .707 r
.50031 .34675 .51757 .40574 .54934 .35589 .53233 .3753 Metetra
.669 .221 .18 r
.53233 .3753 .54934 .35589 .5821 .38445 .56549 .40059 Metetra
.64 .165 .11 r
.56549 .40059 .5821 .38445 .61596 .40978 .59973 .42236 Metetra
.595 .087 .013 r
.59973 .42236 .61596 .40978 .65084 .43159 .63495 .44035 Metetra
.521 0 0 r
.63495 .44035 .65084 .43159 .68665 .44962 .67105 .45429 Metetra
.392 0 0 r
.67105 .45429 .68665 .44962 .72327 .46362 .70791 .46397 Metetra
.175 0 0 r
.70791 .46397 .72327 .46362 .7606 .47336 .74541 .46917 Metetra
.127 .663 .856 r
.74541 .46917 .7606 .47336 .79849 .47864 .7834 .46972 Metetra
.406 .798 .988 r
.7834 .46972 .79849 .47864 .83681 .47928 .82173 .46547 Metetra
.581 .824 .991 r
.82173 .46547 .83681 .47928 .8754 .47514 .86025 .45631 Metetra
.742 .718 .829 r
.18919 .6265 .20965 .65049 .2408 .63443 .22095 .60566 Metetra
.752 .69 .792 r
.22095 .60566 .2408 .63443 .27253 .61372 .25323 .58021 Metetra
.758 .669 .763 r
.25323 .58021 .27253 .61372 .30472 .5884 .28591 .55021 Metetra
.762 .652 .74 r
.28591 .55021 .30472 .5884 .33724 .55855 .31887 .5158 Metetra
.764 .638 .721 r
.31887 .5158 .33724 .55855 .36996 .5243 .35196 .47713 Metetra
.765 .626 .706 r
.35196 .47713 .36996 .5243 .40276 .4858 .38507 .43437 Metetra
.766 .616 .693 r
.38507 .43437 .40276 .4858 .4355 .44323 .41805 .38776 Metetra
.767 .608 .682 r
.41805 .38776 .4355 .44323 .46806 .3968 .45079 .33753 Metetra
.288 .305 .704 r
.45079 .33753 .46806 .3968 .50031 .34675 .48205 .36604 Metetra
.668 .22 .179 r
.48205 .36604 .50031 .34675 .53233 .3753 .51451 .39131 Metetra
.639 .164 .109 r
.51451 .39131 .53233 .3753 .56549 .40059 .54809 .41304 Metetra
.594 .085 .011 r
.54809 .41304 .56549 .40059 .59973 .42236 .58271 .43098 Metetra
.519 0 0 r
.58271 .43098 .59973 .42236 .63495 .44035 .61826 .44487 Metetra
.39 0 0 r
.61826 .44487 .63495 .44035 .67105 .45429 .65465 .45448 Metetra
.171 0 0 r
.65465 .45448 .67105 .45429 .70791 .46397 .69174 .4596 Metetra
.131 .665 .86 r
.69174 .4596 .70791 .46397 .74541 .46917 .72939 .46005 Metetra
.409 .799 .989 r
.72939 .46005 .74541 .46917 .7834 .46972 .76747 .45569 Metetra
.582 .823 .99 r
.76747 .45569 .7834 .46972 .82173 .46547 .8058 .44641 Metetra
.672 .8 .943 r
.8058 .44641 .82173 .46547 .86025 .45631 .84423 .43214 Metetra
.752 .69 .792 r
.16884 .59753 .18919 .6265 .22095 .60566 .20122 .57193 Metetra
.758 .669 .763 r
.20122 .57193 .22095 .60566 .25323 .58021 .23407 .54178 Metetra
.762 .652 .74 r
.23407 .54178 .25323 .58021 .28591 .55021 .26726 .50721 Metetra
.764 .638 .721 r
.26726 .50721 .28591 .55021 .31887 .5158 .30066 .46837 Metetra
.765 .626 .706 r
.30066 .46837 .31887 .5158 .35196 .47713 .33413 .42543 Metetra
.766 .616 .693 r
.33413 .42543 .35196 .47713 .38507 .43437 .36755 .37864 Metetra
.767 .608 .682 r
.36755 .37864 .38507 .43437 .41805 .38776 .40078 .32821 Metetra
.271 .293 .701 r
.40078 .32821 .41805 .38776 .45079 .33753 .43127 .3567 Metetra
.668 .219 .177 r
.43127 .3567 .45079 .33753 .48205 .36604 .463 .38193 Metetra
.639 .163 .107 r
.463 .38193 .48205 .36604 .51451 .39131 .49591 .40362 Metetra
.593 .083 .009 r
.49591 .40362 .51451 .39131 .54809 .41304 .52991 .42151 Metetra
.518 0 0 r
.52991 .42151 .54809 .41304 .58271 .43098 .56491 .43534 Metetra
.387 0 0 r
.56491 .43534 .58271 .43098 .61826 .44487 .60081 .44488 Metetra
.167 0 0 r
.60081 .44488 .61826 .44487 .65465 .45448 .63748 .44992 Metetra
.136 .668 .863 r
.63748 .44992 .65465 .45448 .69174 .4596 .67479 .45027 Metetra
.412 .8 .989 r
.67479 .45027 .69174 .4596 .72939 .46005 .71259 .4458 Metetra
.583 .823 .99 r
.71259 .4458 .72939 .46005 .76747 .45569 .75074 .43639 Metetra
.673 .799 .943 r
.75074 .43639 .76747 .45569 .8058 .44641 .78905 .42198 Metetra
.719 .766 .89 r
.78905 .42198 .8058 .44641 .84423 .43214 .82737 .40254 Metetra
.758 .669 .763 r
.14868 .56357 .16884 .59753 .20122 .57193 .1817 .53327 Metetra
.762 .651 .74 r
.1817 .53327 .20122 .57193 .23407 .54178 .21513 .49854 Metetra
.764 .638 .721 r
.21513 .49854 .23407 .54178 .26726 .50721 .24884 .45952 Metetra
.765 .626 .706 r
.24884 .45952 .26726 .50721 .30066 .46837 .28269 .4164 Metetra
.766 .616 .693 r
.28269 .4164 .30066 .46837 .33413 .42543 .31654 .36942 Metetra
.767 .608 .682 r
.31654 .36942 .33413 .42543 .36755 .37864 .35027 .31881 Metetra
.252 .28 .697 r
.35027 .31881 .36755 .37864 .40078 .32821 .37998 .34726 Metetra
.667 .218 .176 r
.37998 .34726 .40078 .32821 .43127 .3567 .41097 .37245 Metetra
.638 .162 .105 r
.41097 .37245 .43127 .3567 .463 .38193 .44318 .3941 Metetra
.592 .082 .007 r
.44318 .3941 .463 .38193 .49591 .40362 .47655 .41194 Metetra
.516 0 0 r
.47655 .41194 .49591 .40362 .52991 .42151 .51099 .42571 Metetra
.384 0 0 r
.51099 .42571 .52991 .42151 .56491 .43534 .54638 .43517 Metetra
.163 0 0 r
.54638 .43517 .56491 .43534 .60081 .44488 .58262 .44013 Metetra
.14 .67 .866 r
.58262 .44013 .60081 .44488 .63748 .44992 .61957 .44038 Metetra
.414 .8 .99 r
.61957 .44038 .63748 .44992 .67479 .45027 .6571 .4358 Metetra
.584 .822 .989 r
.6571 .4358 .67479 .45027 .71259 .4458 .69504 .42626 Metetra
.673 .799 .942 r
.69504 .42626 .71259 .4458 .75074 .43639 .73325 .41171 Metetra
.719 .766 .889 r
.73325 .41171 .75074 .43639 .78905 .42198 .77153 .39211 Metetra
.744 .734 .843 r
.77153 .39211 .78905 .42198 .82737 .40254 .80974 .36748 Metetra
.762 .651 .74 r
.12879 .52467 .14868 .56357 .1817 .53327 .16246 .48977 Metetra
.764 .638 .721 r
.16246 .48977 .1817 .53327 .21513 .49854 .19649 .45058 Metetra
.765 .626 .706 r
.19649 .45058 .21513 .49854 .24884 .45952 .23072 .40728 Metetra
.766 .616 .693 r
.23072 .40728 .24884 .45952 .28269 .4164 .26502 .36011 Metetra
.767 .608 .682 r
.26502 .36011 .28269 .4164 .31654 .36942 .29926 .3093 Metetra
.233 .267 .692 r
.29926 .3093 .31654 .36942 .35027 .31881 .32816 .33773 Metetra
.667 .218 .175 r
.32816 .33773 .35027 .31881 .37998 .34726 .35839 .36288 Metetra
.638 .16 .103 r
.35839 .36288 .37998 .34726 .41097 .37245 .3899 .38449 Metetra
.591 .08 .004 r
.3899 .38449 .41097 .37245 .44318 .3941 .42262 .40227 Metetra
.515 0 0 r
.42262 .40227 .44318 .3941 .47655 .41194 .45647 .41597 Metetra
.382 0 0 r
.45647 .41597 .47655 .41194 .51099 .42571 .49135 .42536 Metetra
.159 0 0 r
.49135 .42536 .51099 .42571 .54638 .43517 .52715 .43023 Metetra
.144 .673 .869 r
.52715 .43023 .54638 .43517 .58262 .44013 .56374 .43039 Metetra
.417 .801 .991 r
.56374 .43039 .58262 .44013 .61957 .44038 .60098 .42569 Metetra
.586 .822 .989 r
.60098 .42569 .61957 .44038 .6571 .4358 .63872 .41602 Metetra
.674 .798 .941 r
.63872 .41602 .6571 .4358 .69504 .42626 .6768 .40132 Metetra
.719 .765 .889 r
.6768 .40132 .69504 .42626 .73325 .41171 .71505 .38156 Metetra
.744 .734 .843 r
.71505 .38156 .73325 .41171 .77153 .39211 .75331 .35676 Metetra
.758 .707 .804 r
.75331 .35676 .77153 .39211 .80974 .36748 .79138 .32699 Metetra
.764 .637 .721 r
.10926 .48092 .12879 .52467 .16246 .48977 .1436 .44155 Metetra
.765 .626 .706 r
.1436 .44155 .16246 .48977 .19649 .45058 .17822 .39807 Metetra
.766 .616 .693 r
.17822 .39807 .19649 .45058 .23072 .40728 .21298 .35071 Metetra
.767 .608 .682 r
.21298 .35071 .23072 .40728 .26502 .36011 .24773 .29971 Metetra
.211 .252 .687 r
.24773 .29971 .26502 .36011 .29926 .3093 .27581 .32809 Metetra
.667 .217 .174 r
.27581 .32809 .29926 .3093 .32816 .33773 .30526 .35321 Metetra
.637 .159 .102 r
.30526 .35321 .32816 .33773 .35839 .36288 .33605 .37476 Metetra
.59 .078 .002 r
.33605 .37476 .35839 .36288 .3899 .38449 .36811 .39249 Metetra
.513 0 0 r
.36811 .39249 .3899 .38449 .42262 .40227 .40136 .40613 Metetra
.379 0 0 r
.40136 .40613 .42262 .40227 .45647 .41597 .43571 .41545 Metetra
.155 0 0 r
.43571 .41545 .45647 .41597 .49135 .42536 .47106 .42022 Metetra
.148 .675 .872 r
.47106 .42022 .49135 .42536 .52715 .43023 .50727 .42027 Metetra
.42 .801 .991 r
.50727 .42027 .52715 .43023 .56374 .43039 .54421 .41546 Metetra
.587 .822 .988 r
.54421 .41546 .56374 .43039 .60098 .42569 .58174 .40566 Metetra
.674 .798 .941 r
.58174 .40566 .60098 .42569 .63872 .41602 .61969 .39081 Metetra
.719 .765 .889 r
.61969 .39081 .63872 .41602 .6768 .40132 .65791 .37088 Metetra
.744 .734 .842 r
.65791 .37088 .6768 .40132 .71505 .38156 .69621 .34591 Metetra
.758 .707 .804 r
.69621 .34591 .71505 .38156 .75331 .35676 .73443 .31595 Metetra
.767 .685 .772 r
.73443 .31595 .75331 .35676 .79138 .32699 .77238 .28111 Metetra
.765 .626 .706 r
.09017 .43242 .10926 .48092 .1436 .44155 .12518 .38876 Metetra
.766 .616 .693 r
.12518 .38876 .1436 .44155 .17822 .39807 .1604 .34121 Metetra
.767 .608 .682 r
.1604 .34121 .17822 .39807 .21298 .35071 .19568 .29001 Metetra
.189 .236 .681 r
.19568 .29001 .21298 .35071 .24773 .29971 .22292 .31836 Metetra
.666 .216 .172 r
.22292 .31836 .24773 .29971 .27581 .32809 .25158 .34343 Metetra
.636 .158 .1 r
.25158 .34343 .27581 .32809 .30526 .35321 .28163 .36494 Metetra
.589 .076 0 r
.28163 .36494 .30526 .35321 .33605 .37476 .31301 .38261 Metetra
.511 0 0 r
.31301 .38261 .33605 .37476 .36811 .39249 .34565 .39618 Metetra
.376 0 0 r
.34565 .39618 .36811 .39249 .40136 .40613 .37946 .40542 Metetra
.151 0 0 r
.37946 .40542 .40136 .40613 .43571 .41545 .41433 .4101 Metetra
.152 .678 .874 r
.41433 .4101 .43571 .41545 .47106 .42022 .45016 .41005 Metetra
.422 .802 .992 r
.45016 .41005 .47106 .42022 .50727 .42027 .48679 .40511 Metetra
.588 .821 .988 r
.48679 .40511 .50727 .42027 .54421 .41546 .5241 .39518 Metetra
.674 .797 .94 r
.5241 .39518 .54421 .41546 .58174 .40566 .56193 .38018 Metetra
.719 .764 .888 r
.56193 .38018 .58174 .40566 .61969 .39081 .6001 .36009 Metetra
.744 .733 .842 r
.6001 .36009 .61969 .39081 .65791 .37088 .63845 .33493 Metetra
.758 .707 .804 r
.63845 .33493 .65791 .37088 .69621 .34591 .6768 .30477 Metetra
.767 .685 .772 r
.6768 .30477 .69621 .34591 .73443 .31595 .71498 .26974 Metetra
.772 .666 .746 r
.71498 .26974 .73443 .31595 .77238 .28111 .7528 .22999 Metetra
.766 .616 .693 r
.0716 .37935 .09017 .43242 .12518 .38876 .10729 .33161 Metetra
.767 .608 .682 r
.10729 .33161 .12518 .38876 .1604 .34121 .14311 .28022 Metetra
.164 .219 .674 r
.14311 .28022 .1604 .34121 .19568 .29001 .16948 .30853 Metetra
.666 .215 .171 r
.16948 .30853 .19568 .29001 .22292 .31836 .19733 .33356 Metetra
.636 .157 .098 r
.19733 .33356 .22292 .31836 .25158 .34343 .22662 .35501 Metetra
.588 .075 0 r
.22662 .35501 .25158 .34343 .28163 .36494 .25731 .37262 Metetra
.51 0 0 r
.25731 .37262 .28163 .36494 .31301 .38261 .28932 .38612 Metetra
.374 0 0 r
.28932 .38612 .31301 .38261 .34565 .39618 .32257 .39528 Metetra
.146 0 0 r
.32257 .39528 .34565 .39618 .37946 .40542 .35697 .39987 Metetra
.156 .68 .877 r
.35697 .39987 .37946 .40542 .41433 .4101 .39239 .3997 Metetra
.425 .802 .992 r
.39239 .3997 .41433 .4101 .45016 .41005 .42871 .39464 Metetra
.589 .821 .988 r
.42871 .39464 .45016 .41005 .48679 .40511 .4658 .38457 Metetra
.675 .797 .94 r
.4658 .38457 .48679 .40511 .5241 .39518 .50348 .36942 Metetra
.719 .764 .888 r
.50348 .36942 .5241 .39518 .56193 .38018 .54161 .34916 Metetra
.744 .733 .842 r
.54161 .34916 .56193 .38018 .6001 .36009 .58001 .32382 Metetra
.758 .707 .804 r
.58001 .32382 .6001 .36009 .63845 .33493 .61849 .29347 Metetra
.766 .684 .772 r
.61849 .29347 .63845 .33493 .6768 .30477 .6569 .25823 Metetra
.772 .666 .746 r
.6569 .25823 .6768 .30477 .71498 .26974 .69503 .21826 Metetra
.776 .65 .724 r
.69503 .21826 .71498 .26974 .7528 .22999 .73272 .17377 Metetra
.767 .608 .682 r
.05363 .32191 .0716 .37935 .10729 .33161 .08999 .27033 Metetra
.137 .2 .666 r
.08999 .27033 .10729 .33161 .14311 .28022 .11548 .2986 Metetra
.665 .214 .17 r
.11548 .2986 .14311 .28022 .16948 .30853 .1425 .32357 Metetra
.635 .155 .097 r
.1425 .32357 .16948 .30853 .19733 .33356 .17102 .34497 Metetra
.587 .073 0 r
.17102 .34497 .19733 .33356 .22662 .35501 .201 .36252 Metetra
.508 0 0 r
.201 .36252 .22662 .35501 .25731 .37262 .23236 .37595 Metetra
.371 0 0 r
.23236 .37595 .25731 .37262 .28932 .38612 .26504 .38502 Metetra
.142 0 0 r
.26504 .38502 .28932 .38612 .32257 .39528 .29895 .38951 Metetra
.161 .682 .88 r
.29895 .38951 .32257 .39528 .35697 .39987 .33396 .38924 Metetra
.427 .803 .993 r
.33396 .38924 .35697 .39987 .39239 .3997 .36996 .38406 Metetra
.59 .82 .987 r
.36996 .38406 .39239 .3997 .42871 .39464 .40681 .37384 Metetra
.675 .796 .939 r
.40681 .37384 .42871 .39464 .4658 .38457 .44435 .35854 Metetra
.719 .763 .887 r
.44435 .35854 .4658 .38457 .50348 .36942 .48243 .33811 Metetra
.744 .733 .842 r
.48243 .33811 .50348 .36942 .54161 .34916 .52087 .31258 Metetra
.758 .706 .803 r
.52087 .31258 .54161 .34916 .58001 .32382 .55949 .28204 Metetra
.766 .684 .772 r
.55949 .28204 .58001 .32382 .61849 .29347 .59812 .24659 Metetra
.772 .666 .746 r
.59812 .24659 .61849 .29347 .6569 .25823 .63658 .2064 Metetra
.775 .65 .724 r
.63658 .2064 .6569 .25823 .69503 .21826 .67468 .16168 Metetra
.778 .637 .705 r
.67468 .16168 .69503 .21826 .73272 .17377 .71225 .11269 Metetra
.109 .18 .657 r
.03634 .26033 .05363 .32191 .08999 .27033 .06093 .28856 Metetra
.665 .213 .168 r
.06093 .28856 .08999 .27033 .11548 .2986 .0871 .31348 Metetra
.635 .154 .095 r
.0871 .31348 .11548 .2986 .1425 .32357 .11482 .33483 Metetra
.587 .071 0 r
.11482 .33483 .1425 .32357 .17102 .34497 .14407 .35231 Metetra
.506 0 0 r
.14407 .35231 .17102 .34497 .201 .36252 .17477 .36567 Metetra
.368 0 0 r
.17477 .36567 .201 .36252 .23236 .37595 .20687 .37465 Metetra
.138 0 0 r
.20687 .37465 .23236 .37595 .26504 .38502 .24026 .37904 Metetra
.165 .685 .883 r
.24026 .37904 .26504 .38502 .29895 .38951 .27485 .37866 Metetra
.43 .803 .993 r
.27485 .37866 .29895 .38951 .33396 .38924 .31052 .37335 Metetra
.591 .82 .987 r
.31052 .37335 .33396 .38924 .36996 .38406 .34713 .36299 Metetra
.675 .795 .939 r
.34713 .36299 .36996 .38406 .40681 .37384 .38452 .34752 Metetra
.72 .763 .887 r
.38452 .34752 .40681 .37384 .44435 .35854 .42254 .32692 Metetra
.744 .732 .841 r
.42254 .32692 .44435 .35854 .48243 .33811 .46103 .30121 Metetra
.758 .706 .803 r
.46103 .30121 .48243 .33811 .52087 .31258 .49979 .27046 Metetra
.766 .684 .772 r
.49979 .27046 .52087 .31258 .55949 .28204 .53865 .2348 Metetra
.772 .666 .746 r
.53865 .2348 .55949 .28204 .59812 .24659 .57743 .19439 Metetra
.775 .65 .724 r
.57743 .19439 .59812 .24659 .63658 .2064 .61594 .14945 Metetra
.778 .637 .705 r
.61594 .14945 .63658 .2064 .67468 .16168 .65401 .10022 Metetra
.78 .625 .689 r
.65401 .10022 .67468 .16168 .71225 .11269 .69147 .04701 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.16157 .20642 m
.16617 .2111 L
s
[(5)] .15237 .19707 .98294 1 Mshowa
.32604 .14202 m
.33035 .14696 L
s
[(10)] .31741 .13214 .87321 1 Mshowa
.50139 .07336 m
.50537 .07857 L
s
[(15)] .49342 .06293 .76347 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(20)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.19364 .19386 m
.19637 .1967 L
s
.22611 .18115 m
.22881 .18402 L
s
.259 .16827 m
.26166 .17117 L
s
.29231 .15523 m
.29493 .15816 L
s
.3602 .12864 m
.36275 .13164 L
s
.39481 .11509 m
.39732 .11812 L
s
.42987 .10136 m
.43235 .10443 L
s
.4654 .08745 m
.46783 .09055 L
s
.53786 .05908 m
.5402 .06224 L
s
.57482 .04461 m
.57712 .0478 L
s
.61228 .02994 m
.61453 .03317 L
s
.65025 .01507 m
.65245 .01833 L
s
.12989 .21883 m
.13268 .2216 L
s
.0986 .23108 m
.10142 .23383 L
s
.06769 .24318 m
.07054 .2459 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00ioooool5o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP1dooooo`00ioooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`1dooooo`00j?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@4100M?ooool00>Wooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000007Cooooo003Zooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooo
ooooo`00001dooooo`00joooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool0L_ooool00>Oooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0M?ooool00>Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0M?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?Cooooo0_l0001booooo`00lOooool3o`000003ooooool0003ooooo077ooooo003_ooooo`;o
00001?ooool2o`00077ooooo003/ooooo`?o00001_ooool00ol0003oooooo`00001`ooooo`00j_oo
ool2o`0000Wooooo00?o0000ooooool00000L?ooool00>Oooooo0ol0000;ooooo`04o`000?oooooo
ooooo`0006oooooo003Uooooo`;o000000?oooooo`000?ooool02oooool01Ol0003ooooooooooooo
oooo000006kooooo003Rooooo`?o00001?ooool00ol0003oooooooooo`09ooooo`05o`000?oooooo
ooooooooool00000K_ooool00=oooooo0ol0000Cooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Joooool00=gooooo0_l0000Gooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0J_ooool00=[ooooo0ol0000Iooooo`04o`000?ooooooooooooooo`;o0000K?ooool00=So
oooo0_l00002ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1Yooooo`00eOooool3o`0000Cooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo06Sooooo002Xooooo`Co000000Go410@oooooooooooooooo
odA4A002o`000003oc8b<_oMgMgooooo01gooooo0_l0000Qooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0J?ooool00:[ooooo00?o0000ooooooooool01_ooool00omgMgOo<S8boooo
o`0Jooooo`?o00008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Oooooo002Z
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool2o`0002Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`1Wooooo`00Z_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo01Gooooo0ol000000ooooooo0000ooooo`0Uooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0I_ooool00:[ooooo00?o0000ooooooooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<01Cooooo0_l00005ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1Uooooo`00Z_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo01?ooooo0ol0000/ooooo`;o00002Oooool00ol0003oooooooooo`1Uooooo`00
Z_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo0_l0000^ooooo`04o`00
0?o7Wk3o0000o`0000Sooooo0_l0001Vooooo`00Z?ooool00omEEEGoIVIVo`000005ooooo`Co0000
3Oooool3o`00033ooooo00Co0000olNO/?l0003o00002_ooool00ol0003oooooooooo`1Sooooo`00
__ooool3o`0000;ooooo00?o0000ooooooooool0;Oooool00ol0003oain`olNO/002o`0000[ooooo
00?o0000ooooooooool0Hoooool00;cooooo0_l0000dooooo`07o`000?o7Wk3oain`olNO/?l0003o
ain`o`00000:ooooo`03o`000?oooooooooo06;ooooo002iooooo`?o0000=_ooool01ol0003oain`
olNO/?o7Wk3o0000olNO/?l000002oooool00ol0003oooooooooo`1Qooooo`00]oooool2o`0003So
oooo00?o0000olNO/?o7Wk000_o7Wk000ol0003oain`o`00000;ooooo`03o`000?oooooooooo067o
oooo002dooooo`?o0000>Oooool00ol0003oain`olNO/003olNO/004o`000?o7Wk3oain`o`0000_o
oooo00?o0000ooooooooool0H?ooool00;;ooooo0_l00003ooooo`03o`000?oooooooooo03Kooooo
00?o0000olNO/?o7Wk001?o7Wk000ol0003oain`o`00000<ooooo`03o`000?oooooooooo05oooooo
002_ooooo`?o00001_ooool00ol0003oooooooooo`0dooooo`03o`000?o7Wk3oain`00Goain`00?o
0000olNO/?l000003?ooool00ol0003oooooooooo`1Oooooo`00[Oooool2o`0003oooooo00?o0000
olNO/?o7Wk001_o7Wk001?l0003oain`olNO/?l0000;ooooo`;o0000H?ooool00:[ooooo0ol00011
ooooo`03o`000?o7Wk3oain`00Koain`00Co0000olNO/?o7Wk3o00003Oooool00ol0003ooooooooo
o`1Mooooo`00Z?ooool3o`0004;ooooo00?o0000olNO/?o7Wk001oo7Wk001?l0003oain`olNO/?l0
000=ooooo`03o`000?oooooooooo00Sooooo00GoA4A4o`000?l0003o<S8bomgMg@1@ooooo`00YOoo
ool3o`0000?ooooo00?o0000ooooooooool0?_ooool00ol0003oain`olNO/008olNO/005o`000?o7
Wk3oain`olNO/?l000003Oooool00ol0003oooooooooo`0:ooooo`03ogMgMolb<S;ooooo04oooooo
002Sooooo`;o0000Aoooool00ol0003oain`olNO/008olNO/005o`000?o7Wk3oain`olNO/?l00000
3_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04kooooo002Pooooo`?o0000B?oo
ool00ol0003oain`olNO/009olNO/005o`000?o7Wk3oain`olNO/?l000003_ooool00ol0003ooooo
ooooo`09ooooo`03ogMgMolb<S;ooooo04oooooo002Nooooo`;o0000B_ooool00ol0003oain`olNO
/00:olNO/003o`000?o7Wk3oain`00;oain`00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`05ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0D?ooool009_ooooo1?l0001;ooooo`03o`000?o7
Wk3oain`00[oain`00?o0000olNO/?o7Wk000_o7Wk000ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0D_ooool006cooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^8?ooool3o`0000Cooooo00?o0000ooooooooool0Aoooool2o`0000co
ain`00?o0000olNO/?o7Wk000_o7Wk000ol0003oooooooooo`0=ooooo`;o00001Oooool00ol0003o
ooooooooo`1Booooo`00K_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL07_ooool2o`00053ooooo00Co0000olNS]?o7XkCo00002oo7Wk000ol0003oain`olNO/003olNO
/003o`000?oooooooooo00_ooooo00?o0000ooooool000001Oooool4o`00057ooooo001^ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Kooooo`?o0000DOooool01Ol0
003oaj>dolNS]?o7XkCo000000_oain`00?o0000olNO/?o7Wk000oo7Wk000ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo05Sooooo001^ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000Iooooo`?o0000Doooool01Ol0003oaj>dolNS]?o7XkCo000000_oain`00?o
0000olNO/?o7Wk000oo7Wk000ol0003oooooooooo`0>ooooo`03o`000?oooooooooo05Oooooo001^
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Fooooo`?o00000_oo
ool00ol0003oooooooooo`1@ooooo`03o`000?o7XkCoaj>d00?oaj>d00?o0000olNO/?o7Wk002?o7
Wk000ol0003oain`olNO/002olNO/003o`000?o7XkCo0000013ooooo00?o0000ooooooooool0E_oo
ool006kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Cooooo0_l0
001Gooooo`03o`000?o7XkCoaj>d00Coaj>d00?o0000olNO/?o7Wk002?o7Wk001Ol0003oain`olNO
/?o7Wk3o000000;oaj>d00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Fooooo`00K_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04Oooool3o`0005Sooooo
00?o0000olNS]?o7Xk@01Oo7Xk@00ol0003oain`olNO/009olNO/003o`000?o7Wk3o000000?oaj>d
00?o0000ooooooooool03oooool00ol0003oooooooooo`1Eooooo`00K?ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03oooool2o`0005[ooooo00?o0000olNS]?o7Xk@0
1_o7Xk@00ol0003oain`olNO/009olNO/003o`000?o7Wk3o000000Coaj>d00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1Dooooo`00Q?ooool4o`0005_ooooo00?o0000olNS]?o7Xk@01oo7
Xk@00ol0003oain`olNO/008olNO/0;o00001Oo7Xk@00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo05Cooooo0022ooooo`;o00001?ooool00ol0003oooooooooo`1Gooooo`03o`000?o7XkCo
aj>d00Soaj>d00?o0000olNO/?o7Wk002?o7Wk000ol0003oaj>dolNS]004olNS]003o`000?oooooo
oooo00oooooo0_l0001Eooooo`00Ooooool3o`0005oooooo00?o0000olNS]?o7Xk@02Oo7Xk@00ol0
003oain`olNO/007olNO/0;o00001oo7Xk@00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
05;ooooo001mooooo`;o0000HOooool00ol0003oaj>dolNS]00;olNS]003o`000?o7Wk3oain`00Go
ain`00?o0000olNS]?l000001oo7Xk@00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05;o
oooo001jooooo`?o0000Hoooool00ol0003oaj>dolNS]00;olNS]003o`000?o7Wk3oain`00Goain`
00?o0000olNS]?l000001oo7Xk@00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo057ooooo
001hooooo`;o00000_ooool00ol0003oooooooooo`1Pooooo`03o`000?o7XkCoaj>d00coaj>d00?o
0000olNO/?o7Wk001?o7Wk001?l0003oaj>dolNS]?l00008olNS]003o`000?oooooooooo017ooooo
00?o0000ooooooooool0D?ooool007Gooooo0ol00005ooooo`03o`000?oooooooooo05kooooo00?o
0000olNS]?o7Xk@03Oo7Xk@00ol0003oain`olNO/003olNO/005o`000?o7XkCoaj>dolNS]?l00000
2?o7Xk@00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo053ooooo001booooo`?o0000J?oo
ool00ol0003oaj>dolNS]00?olNS]005o`000?o7Wk3oain`olNO/?l000001?o7Xk@00ol0003oaj>d
olNS]006olNS]003o`000?oooooooooo01;ooooo00?o0000ooooooooool0Coooool0073ooooo0_l0
001[ooooo`03o`000?o7XkCoaj>d00ooaj>d00Go0000olNO/?o7Wk3oain`o`000004olNS]003o`00
0?o7XkCoaj>d00Ooaj>d00?o0000ooooooooool04_ooool00ol0003oooooooooo`1>ooooo`00KOoo
ool4o`0006_ooooo00?o0000olJV^Ol000004?o7Xk@01?l0003oain`olNO/?l00005olNS]003o`00
0?o7XkCoaj>d00Ooaj>d00?o0000ooooooooool04Oooool2o`00053ooooo001[ooooo`;o00001?oo
ool00ol0003oooooooooo`1Wooooo`04o`000?o6Y[WoaZJio`00017oaj>d0_l00006olNS]003o`00
0?o7XkCoaj>d00Ooaj>d00?o0000ooooooooool04oooool00ol0003oooooooooo`1=ooooo`00J?oo
ool3o`0006oooooo00Go0000olJV^Oo6Y[WoaZJio`00000AolNS]003o`000?o7XkCoaj>d00Goaj>d
00?o0000olNS]?o7Xk@02?o7Xk@00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04cooooo
001Vooooo`;o0000LOooool00ol0003oaZJiolJV^@03olJV^@03o`000?o7XkCoaj>d00koaj>d00?o
0000olNS]?o7Xk@01Oo7Xk@00ol0003oaj>dolNS]008olNS]003o`000?oooooooooo01?ooooo00?o
0000ooooooooool0C?ooool006?ooooo0ol0001booooo`03o`000?o6Y[WoaZJi00CoaZJi00?o0000
olNS]?o7Xk@03Oo7Xk@00ol0003oaZJio`000006olNS]003o`000?o7XkCoaj>d00Soaj>d00?o0000
ooooooooool05?ooool00ol0003oooooooooo`1;ooooo`00>oooool01Om4A4Co0000o`000?lb<S;o
gMgM027ooooo0_l00003ooooo`03o`000?oooooooooo06kooooo00?o0000olJV^Oo6Y[T01Oo6Y[T0
0ol0003oaj>dolNS]00<olNS]004o`000?o6Y[WoaZJio`0000Koaj>d00?o0000olNS]?o7Xk@02Oo7
Xk@00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04[ooooo000nooooo`03ogMgMolb<S;o
oooo01gooooo0ol0001eooooo`03o`000?o6Y[WoaZJi00OoaZJi00?o0000olNS]?o7Xk@02_o7Xk@0
1Ol0003oaZJiolJV^Oo6Y[Wo000000Ooaj>d00?o0000olNS]?o7Xk@02?o7Xk@00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04[ooooo000oooooo`03o`000?oooooooooo01[ooooo0_l0001h
ooooo`03o`000?o6Y[WoaZJi00OoaZJi00?o0000olNS]?o7Xk@02Oo7Xk@00ol0003oaZJiolJV^@03
olJV^@03o`000?o7XkCoaj>d00Coaj>d00?o0000olNS]?o7Xk@02?o7Xk@00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo04Wooooo000nooooo`03ogMgMolb<S;ooooo01Sooooo0ol0001ioooo
o`03o`000?o6Y[WoaZJi00WoaZJi00?o0000olNS]?o7Xk@02?o7Xk@00ol0003oaZJiolJV^@03olJV
^@03o`000?o7XkCoaj>d00Coaj>d00?o0000olNS]?o7Xk@01oo7Xk@00ol0003oaZJio`00000Eoooo
o`?o0000B_ooool003_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Gooooo`;o00000_ooool00ol0
003oooooooooo`1fooooo`03o`000?o6Y[WoaZJi00[oaZJi00?o0000olNS]?o7Xk@01oo7Xk@00ol0
003oaZJiolJV^@04olJV^@03o`000?o7XkCoaj>d00Coaj>d00?o0000olNS]?o7Xk@01_o7Xk@01?l0
003oaZJiolJV^Ol0000Gooooo`03o`000?oooooooooo04Sooooo000kooooo`03o`000?oooooooooo
01Kooooo0ol0001looooo`03o`000?o6Y[WoaZJi00_oaZJi00?o0000olNS]?o7Xk@01_o7Xk@00ol0
003oaZJiolJV^@06olJV^@03o`000?o7XkCoaj>d00?oaj>d00?o0000olNS]?o7Xk@01Oo7Xk@01Ol0
003oaZJiolJV^Oo6Y[Wo000001Sooooo00?o0000ooooooooool0Aoooool003_ooooo00?o0000oooo
ooooool04oooool3o`0007kooooo00?o0000olJV^Oo6Y[T03Oo6Y[T00ol0003oaj>dolNS]004olNS
]003o`000?o6Y[WoaZJi00OoaZJi00?o0000olNS]?o7Xk@00oo7Xk@00ol0003oaj>dolNS]004olNS
]003o`000?o6Y[WoaZJi00?oaZJi00?o0000ooooooooool05Oooool00ol0003oooooooooo`17oooo
o`00>oooool4o`00013ooooo0_l00020ooooo`03o`000?o6Y[WoaZJi00koaZJi00?o0000olNS]?o7
Xk@00oo7Xk@00ol0003oaZJiolJV^@09olJV^@03o`000?o7XkCoaj>d00;oaj>d00?o0000olNS]?o7
Xk@00oo7Xk@00ol0003oaZJiolJV^@04olJV^@03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0A_ooool004cooooo1Ol0001oooooo`03o`000?o6Y[WoaZJi00ooaZJi00?o0000olNS]?o7Xk@0
0oo7Xk@00ol0003oaZJiolJV^@09olJV^@03o`000?o7XkCoaj>d00;oaj>d00?o0000olNS]?o7Xk@0
0_o7Xk@00ol0003oaZJiolJV^@05olJV^@03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
AOooool004[ooooo0_l00023ooooo`;o00004_o6Y[T01Ol0003oaj>dolNS]?o7XkCo000000coaZJi
00?o0000olNS]?o7Xk@00_o7Xk@01Ol0003oaj>dolNS]?o7XkCo000000WoaZJi00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`15ooooo`00Aoooool3o`0008Cooooo00Co0000olFZ__o5Z[ko
00004Oo6Y[T01?l0003oaj>dolNS]?l0000>olJV^@05o`000?o7XkCoaj>dolNS]?l000000oo7Xk@0
0ol0003oaZJiolJV^@07olJV^@03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A?ooool0
04Gooooo0_l00026ooooo`05o`000?o5Z[koaJZnolFZ__l000004Oo6Y[T00ol0003oaj>do`00000?
olJV^@05o`000?o7XkCoaj>dolNS]?l000000_o7Xk@00ol0003oaZJiolJV^@09olJV^@03o`000?oo
oooooooo01Kooooo0_l00015ooooo`00@_ooool4o`0008Kooooo00?o0000olFZ__o5Z[h00_o5Z[h0
0ol0003oaZJiolJV^@0@olJV^@03o`000?o6Y[WoaZJi00koaZJi00Oo0000olNS]?o7XkCoaj>do`00
0?o7XkCo000000coaZJi00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRoooooo0010ooooo`;o00001?ooool00ol0
003oooooooooo`22ooooo`03o`000?o5Z[koaJZn00CoaJZn00?o0000olJV^Oo6Y[T03_o6Y[T2o`00
017oaZJi00?o0000olNS]?o7Xk@00_l0000=olJV^@03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;oooool0
03gooooo0ol0002:ooooo`03o`000?o5Z[koaJZn00GoaJZn00?o0000olJV^Oo6Y[T03Oo6Y[T01?l0
003oaJZnolFZ__l0000@olJV^@04o`000?o7XkCoaj>do`0000ooaZJi00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400_ooooo`00>oooool2o`0008cooooo00?o0000olFZ__o5Z[h01oo5Z[h00ol0003oaZJiolJV
^@0;olJV^@05o`000?o5Z[koaJZnolFZ__l000004?o6Y[T01?l0003oaj>do`000?l0000?olJV^@03
o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool00000;oooool003Sooooo0ol0002=ooooo`03o`000?o5Z[koaJZn00So
aJZn00?o0000olJV^Oo6Y[T02_o6Y[T00ol0003oaJZnolFZ_P02olFZ_P03o`000?o6Y[WoaZJi00oo
aZJi00?o0000olJV^Ol000003oo6Y[T00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002oooooo000fooooo`;o
00000oooool00ol0003oooooooooo`29ooooo`03o`000?o5Z[koaJZn00[oaJZn00?o0000olJV^Oo6
Y[T02?o6Y[T00ol0003oaJZnolFZ_P04olFZ_P03o`000?o6Y[WoaZJi00koaZJi00?o0000olJV^Ol0
00004?o6Y[T00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@02oooooo000cooooo`?o0000T?ooool00ol0003o
aJZnolFZ_P0;olFZ_P03o`000?o6Y[WoaZJi00OoaZJi00?o0000olFZ__o5Z[h01Oo5Z[h00ol0003o
aZJiolJV^@0=olJV^@05o`000?o5Z[ko0000olJV^Ol000003oo6Y[T00ol0003oooooooooo`0Ioooo
o`;o00001oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;oooool0
037ooooo0_l0002Booooo`03o`000?o5Z[koaJZn00coaJZn00?o0000olJV^Oo6Y[T01_o6Y[T00ol0
003oaJZnolFZ_P07olFZ_P03o`000?o6Y[WoaZJi00_oaZJi00Ko0000olFZ__o5Z[ko0000olJV^Ol0
000?olJV^@03o`000?oooooooooo01Sooooo00?o0000ooooool000001Oooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;oooool002kooooo0ol0002Cooooo`03o`000?o5
Z[koaJZn00koaJZn00?o0000olJV^Oo6Y[T01?o6Y[T00ol0003oaJZnolFZ_P08olFZ_P03o`000?o6
Y[WoaZJi00[oaZJi00Oo0000olFZ__o5Z[koaJZno`000?o6Y[Wo0000013oaZJi00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0mooooo`00:oooool3o`0000;ooooo00?o0000ooooooooool0
Soooool2o`00017oaJZn00?o0000olJV^Oo6Y[T00oo6Y[T00ol0003oaJZnolFZ_P0:olFZ_P03o`00
0?o6Y[WoaZJi00SoaZJi00?o0000olFZ__o5Z[h00oo5Z[h2o`0000ooaZJi0_l0000Looooo`03o`00
0?oooooooooo03gooooo000Yooooo`;o0000U_ooool00ol0003oa:o5o`00000BolFZ_P05o`000?o6
Y[WoaZJiolJV^Ol000003Oo5Z[h00ol0003oaZJiolJV^@07olJV^@03o`000?o5Z[koaJZn00CoaJZn
0_l0000>olJV^@04o`000?o5Z[koaJZno`0001cooooo00?o0000ooooooooool0??ooool002Kooooo
0ol0002Gooooo`05o`000?o4[lGoa:o5olB_aOl000004Oo5Z[h01?l0003oaZJiolJV^Ol0000>olFZ
_P03o`000?o6Y[WoaZJi00KoaZJi00?o0000olFZ__o5Z[h01_o5Z[h00ol0003oaZJiolJV^@0;olJV
^@05o`000?o5Z[koaJZnolFZ__l000007Oooool00ol0003oooooooooo`0kooooo`009?ooool2o`00
09Wooooo00?o0000olB_aOo4[lD00_o4[lD00ol0003oaJZnolFZ_P0?olFZ_P03o`000?o6Y[Wo0000
013oaJZn00?o0000olJV^Oo6Y[T01?o6Y[T00ol0003oaJZnolFZ_P07olFZ_P03o`000?o6Y[WoaZJi
00[oaZJi00?o0000olFZ__o5Z[h00_o5Z[h00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
03_ooooo000Qooooo`?o00000_ooool00ol0003oooooooooo`2Eooooo`03o`000?o4[lGoa:o500Co
a:o500?o0000olFZ__o5Z[h03_o5Z[h2o`00017oaJZn00?o0000olJV^Oo6Y[T00oo6Y[T00ol0003o
aJZnolFZ_P07olFZ_P?o00002_o6Y[T00ol0003oaJZnolFZ_P04olFZ_P03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0>_ooool001oooooo0_l0002Looooo`03o`000?o4[lGoa:o500Goa:o5
00?o0000olFZ__o5Z[h03Oo5Z[h00ol0003oa:o5o`00000BolFZ_P05o`000?o6Y[WoaZJiolJV^Ol0
00001oo5Z[h3o`000003olFZ__l0003o000000WoaZJi00?o0000olFZ__o5Z[h01Oo5Z[h00ol0003o
ooooooooo`0Jooooo`?o0000>oooool001cooooo0ol0002Mooooo`03o`000?o4[lGoa:o500Koa:o5
00?o0000olFZ__o5Z[h03?o5Z[h01Ol0003oa:o5olB_aOo4[lGo0000017oaJZn00Co0000olJV^Oo6
Y[Wo00001Oo5Z[h3o`0000GoaJZn00?o0000olJV^Oo6Y[T01_o6Y[T00ol0003oaJZnolFZ_P06olFZ
_P03o`000?oooooooooo01cooooo00?o0000ooooooooool0>Oooool001_ooooo0_l0002Nooooo`03
o`000?o4[lGoa:o500Soa:o500?o0000olFZ__o5Z[h02_o5Z[h00ol0003oa:o5olB_a@02olB_a@03
o`000?o5Z[koaJZn00ooaJZn00?o0000olJV^Ol000000oo5Z[h3o`0000WoaJZn00?o0000olJV^Oo6
Y[T01?o6Y[T00ol0003oaJZnolFZ_P08olFZ_P03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0>?ooool001_ooooo00?o0000ooooool00000W?ooool00ol0003oa:o5olB_a@09olB_a@03o`00
0?o5Z[koaJZn00WoaJZn00?o0000olB_aOo4[lD01?o4[lD00ol0003oaJZnolFZ_P0>olFZ_P;o0000
00CoaJZno`000?l0003o00003?o5Z[h2o`0000CoaZJi00?o0000olFZ__o5Z[h02Oo5Z[h00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo03Sooooo000Jooooo`;o00000_ooool00ol0003ooooo
ooooo`2Hooooo`03o`000?o4[lGoa:o500_oa:o500?o0000olFZ__o5Z[h01oo5Z[h00ol0003oa:o5
olB_a@05olB_a@03o`000?o5Z[koaJZn00goaJZn1?l0000@olFZ_P05o`000?o6Y[WoaZJiolJV^Ol0
00003?o5Z[h00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03Oooooo000Jooooo`?o0000
0_ooool00ol0003oooooooooo`2Fooooo`03o`000?o4[lGoa:o500coa:o500?o0000olFZ__o5Z[h0
1_o5Z[h00ol0003oa:o5olB_a@06olB_a@03o`000?o5Z[koaJZn00_oaJZn0ol00002olB_a@03o`00
0?o5Z[koaJZn00koaJZn0_l000000oo6Y[Wo0000olFZ_P0=olFZ_P03o`000?oooooooooo01gooooo
00?o0000ooooooooool0=_ooool001[ooooo00?o0000oa/^Z?l000000oooool00ol0003ooooooooo
o`2Dooooo`03o`000?o4[lGoa:o500koa:o500?o0000olFZ__o5Z[h01?o5Z[h00ol0003oa:o5olB_
a@08olB_a@03o`000?o5Z[koaJZn00OoaJZn1?l00004olB_a@03o`000?o5Z[koaJZn00koaJZn00?o
0000olJV^Ol000003oo5Z[h00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03Kooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo0_l000000olK;ZSo
0000ooooo`02ooooo`03o`000?oooooooooo00Oooooo0_l00028ooooo`;o00004Oo4[lD00ol0003o
aJZnolFZ_P03olFZ_P03o`000?o4[lGoa:o500Woa:o500?o0000olFZ__o5Z[h01Oo5Z[h2o`0000;o
aJZn00?o0000olB_aOo4[lD00oo4[lD00ol0003oaJZnolFZ_P0>olFZ_P?o00003oo5Z[h00ol0003o
ooooooooo`0Nooooo`;o0000=_ooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo0_l00002oa/^Z005o`000?ooooooooooooooool000001oooool00ol0
003oZSH[o`000027ooooo`03o`000?o2]<go0000017oa:o500?o0000olFZ__o5Z[h00_o5Z[h00ol0
003oa:o5olB_a@0;olB_a@04o`000?o5Z[koaJZnolFZ_P?o00000oo5Z[h00ol0003oa:o5olB_a@05
olB_a@03o`000?o5Z[koaJZn00coaJZn00Go0000olB_aOl0003oaJZno`00000?olFZ_P03o`000?oo
oooooooo01cooooo00?o0000ooooool00000=_ooool000Go00001Oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0000?o6bjX00Go0000oooooooooooooooo
o`000004ooooo`;o00000onZ=R/00ol0003oooooooooo`23ooooo`05o`000?o2]<go`[C=ol:dcOl0
00004Oo4[lD01?l0003oaJZnolFZ__l0000>olB_a@Co00001Oo5Z[h00ol0003oa:o5olB_a@06olB_
a@03o`000?o5Z[koaJZn00_oaJZn00Oo0000olB_aOo4[lGoa:o5o`000?o5Z[ko000000koaJZn00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0dooooo`002_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001Oooool4o`0000?o6bjX00Go0000oooooooooooooooo
o`000002ooooo`03o`000?nZ=R_oZSH[00CoZSH[00?o0000ooooooooool03?ooool2o`0007;ooooo
0_l00004ol:dc@03o`000?o4[lGoa:o500ooa:o500?o0000olFZ__l000003Oo4[lD4o`0000KoaJZn
00?o0000olB_aOo4[lD01oo4[lD00ol0003oaJZnolFZ_P0:olFZ_P03o`000?o4[lGoa:o500;oa:o5
00Co0000olFZ__o5Z[ko00003Oo5Z[h00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03?o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooo000000Co6bjX00Co0000oooooooooooooooo0_l00008ojXf:`03o`000?oooooooooo
00[ooooo00?o0000ojXf:ol00000LOooool00ol0003o`[C=ol:dc@05ol:dc@03o`000?o4[lGoa:o5
00koa:o50_l0000;olB_a@?o00000oo4[lD00ol0003oaJZnolFZ_P03olFZ_P03o`000?o4[lGoa:o5
00Woa:o500?o0000olFZ__o5Z[h02?o5Z[h00ol0003oa:o5olB_a@04olB_a@03o`000?o5Z[ko0000
00goaJZn0_l0000Qooooo`03o`000?oooooooooo03;ooooo000:ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4005ooooo`04o`000?ooooooooooo`0000Go6bjX00?o0000
ooooool000002onZ=R/00ol0003oooooooooo`08ooooo`05o`000?nZ=R_oZSH[ojXf:ol00000Kooo
ool00ol0003o`[C=ol:dc@06ol:dc@03o`000?o4[lGoa:o500goa:o500?o0000ol:dcOl000002?o4
[lD3o`0000Koa:o500?o0000olFZ__o5Z[h00_o5Z[h00ol0003oa:o5olB_a@0:olB_a@03o`000?o5
Z[koaJZn00OoaJZn00?o0000olB_aOo4[lD01Oo4[lD01?l0003oaJZnolFZ__l0000;olFZ_P03o`00
0?o4[lGo0000027ooooo00?o0000ooooooooool0<_ooool000[ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00Go0000ooooooooooooooooo`000005oa/^Z003
o`000?nZ=R_oZSH[00_oZSH[00?o0000ooooooooool01Oooool2o`0000GoZSH[00?o0000oooooooo
ool0Joooool00ol0003o`[C=ol:dc@08ol:dc@03o`000?o4[lGoa:o500_oa:o500Go0000ol:dcOo2
]<go`[C=o`000004olB_a@?o00002_o4[lD01?l0003oaJZnolFZ__l0000>olB_a@03o`000?o5Z[ko
aJZn00GoaJZn00?o0000olB_aOo4[lD01oo4[lD01?l0003oaJZnolFZ__l00009olFZ_P05o`000?o4
[lGoa:o5olB_aOl000008Oooool00ol0003oooooooooo`0aooooo`002?ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0000;ooooo00?o0000oa/^Z?lK;ZP0
0olK;ZP00ol0003oZSH[ojXf:`0<ojXf:`03o`000?oooooooooo00?ooooo00?o0000ojXf:onZ=R/0
1_nZ=R/00ol0003oooooooooo`0;ooooo`;o0000Foooool2o`0000_o`[C=00?o0000olB_aOo4[lD0
2Oo4[lD2o`0000Co`[C=00?o0000olB_aOl000000_l0000=olB_a@03o`000?o5Z[ko000000ooa:o5
00?o0000olFZ__o5Z[h01?o5Z[h00ol0003oa:o5olB_a@08olB_a@05o`000?o5Z[koaJZnolFZ__l0
00001oo5Z[h00ol0003oa:o5olB_a@02olB_a@03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0<?ooool001Wooooo00Go0000ooooooooooooooooo`000006oa/^Z003o`000?nZ=R_oZSH[00co
ZSH[00Go0000ooooooooooooooooo`00000:ojXf:`03o`000?oooooooooo00Wooooo00Co0000ojXg
:onZ=b_o0000FOooool00ol0003o`[C=ol:dc@0<ol:dc@03o`000?o4[lGoa:o500Ooa:o500?o0000
ol:dcOo2]<d01?o2]<d2o`00013oa:o50_l0000@olB_a@03o`000?o5Z[koaJZn00?oaJZn00?o0000
olB_aOo4[lD02_o4[lD01?l0003oaJZnolFZ__l00006olFZ_P03o`000?o4[lGoa:o500Coa:o500?o
0000ooooooooool07_ooool2o`0003;ooooo000Iooooo`05o`000?ooooooooooooooool000001olK
;ZP00ol0003oZSH[ojXf:`0<ojXf:`03o`000?oooooo000000coZSH[00?o0000ooooooooool01_oo
ool2o`0000CoZSL[00?o0000ooooooooool0EOooool00ol0003o`[C=ol:dc@0=ol:dc@03o`000?o4
[lGoa:o500Koa:o500?o0000ol:dcOo2]<d00_o2]<d3o`000003ol:dcOl0003oa:o500koa:o500?o
0000ol:dcOl000004Oo4[lD01Ol0003oaJZnolFZ__o5Z[ko000000goa:o500Go0000olFZ__o5Z[ko
aJZno`000004olFZ_P03o`000?o4[lGoa:o500Goa:o500?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0_ooooo`006Oooool00ol0003oooooooooo`02ooooo`03o`000?lK;ZSo6bjX00Co6bjX
0_l0000=ojXf:`?o00003OnZ=R/00ol0003oooooooooo`04ooooo`03o`000?nZ=b_oZSL[00GoZSL[
00?o0000ooooooooool02_ooool2o`0004Kooooo0_l0000Aol:dc@03o`000?o4[lGoa:o500Coa:o5
00?o0000ol:dcOo2]<d00ol00005ol:dc@03o`000?o4[lGoa:o500_oa:o500Go0000ol:dcOo2]<go
`[C=o`00000@olB_a@04o`000?o5Z[koaJZno`0000koa:o500?o0000olFZ__o5Z[h00_o5Z[h01?l0
003oaJZnolFZ__l00009olB_a@03o`000?oooooooooo023ooooo00?o0000ooooooooool0;_ooool0
01Sooooo00?o0000ooooooooool00oooool00ol0003o6bjXoa/^Z004oa/^Z003o`000?o4Vjko0000
00[oZSH[0_l00003oj8W6003o`000?nZ=R_oZSH[00_oZSH[00Co0000oooooooooooooooo0_l00009
ojXg:`03o`000?oooooooooo00Sooooo00Co0000ojXg;?nZ=bco0000A?ooool00ol0003o_[_Go`00
000Aol:dc@03o`000?o4[lGoa:o500;oa:o51Ol00008ol:dc@03o`000?o4[lGoa:o500Woa:o50_l0
0004ol:dc@03o`000?o4[lGoa:o500koa:o500?o0000olFZ__l000004?o4[lD00ol0003oaJZnolFZ
_P02olFZ_P;o00002_o4[lD00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02kooooo000H
ooooo`;o00001?ooool00ol0003o6bjXoa/^Z003oa/^Z005o`000?o4Vjkoa9^^olBK[_l000001onZ
=R/2o`0000KoXRLH00?o0000ojXf:onZ=R/02onZ=R/00ol0003oooooo`00000<ojXg:`03o`000?oo
oooooooo00Kooooo00?o0000ojXg;?nZ=b`00_nZ=b`00ol0003oooooooooo`0oooooo`;o00000onn
^mL00ol0003o`[C=ol:dc@0?ol:dc@03o`000?o4[lGoa:o500?o00003?o2]<d00ol0003oa:o5olB_
a@07olB_a@03o`000?o2]<go`[C=00Go`[C=00?o0000olB_aOo4[lD03Oo4[lD2o`00017oa:o500?o
0000olFZ__o5Z[h00_o5Z[h00ol0003oa:o5olB_a@0:olB_a@03o`000?oooooooooo023ooooo00?o
0000ooooooooool0;Oooool001Sooooo00?o0000ooooooooool01?ooool01Ol0003o6bjXoa/^Z?lK
;ZSo000000Goa9^^00?o0000ojXf:onZ=R/00_nZ=R/2o`0000WoXRLH00?o0000ojXf:onZ=R/02_nZ
=R/3o`0000goZSL[00?o0000ooooooooool00oooool2o`0000KoZSL/00?o0000ooooooooool02ooo
ool2o`00033ooooo00?o0000okjkeonn^mL00onn^mL00ol0003o`[C=ol:dc@0?ol:dc@?o00003oo2
]<d00ol0003oa:o5olB_a@06olB_a@03o`000?o2]<go`[C=00Ko`[C=00?o0000olB_aOo4[lD03?o4
[lD00ol0003o`[C=o`00000BolB_a@06o`000?o5Z[koaJZno`000?o4[lGo00002oo4[lD00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo02cooooo000Hooooo`03o`000?oooooooooo00Cooooo
00Co0000oa/^Z?lK;ZSo00001oo4Vjh01?l0003oZSH[o`000?l0000<oj8W6003o`000?nZ=R_oZSH[
00OoZSH[0_l00003oj8W6003o`000?nZ=b_oZSL[00_oZSL[00Go0000ooooooooooooooooo`000009
ojXg;003o`000?oooooooooo00Wooooo00?o0000ojXg;?l00000;_ooool2o`0000Oo_[_G00?o0000
ol:dcOo2]<d02oo2]<d5o`00017o`[C=00?o0000olB_aOo4[lD01?o4[lD00ol0003o`[C=ol:dc@07
ol:dc@03o`000?o4[lGoa:o500_oa:o500Go0000ol:dcOo2]<go`[C=o`00000AolB_a@03o`000?o5
Z[ko000000?oa:o500?o0000olB_aOo4[lD02?o4[lD00ol0003oooooooooo`0Qooooo`;o0000;Ooo
ool001Sooooo00?o0000ooooooooool01?ooool01?l0003o6bjXoa/^Z?l00008olBK[P;o00003_nR
9aP00ol0003oZSH[ojXf:`04ojXf:`;o00001_nR9aP00ol0003oZSL[ojXg:`0;ojXg:`03o`000?oo
oooo000000_oZSL/00?o0000ooooooooool01oooool01Ol0003oZSL/ojXg;?nZ=bco000002cooooo
00?o0000okjkeonn^mL01onn^mL00ol0003o`[C=ol:dc@08ol:dc@?o00000_o2]<d00ol0003o_[_G
o`00000Aol:dc@03o`000?o4[lGoa:o500;oa:o50_l0000;ol:dc@03o`000?o4[lGoa:o500Soa:o5
0_l00004ol:dc@03o`000?o4[lGoa:o500ooa:o50_l00004olB_a@03o`000?o4[lGoa:o500Woa:o5
00?o0000ooooooooool08?ooool2o`0000Wooooo1?l000001Ol@413oooooooooooooooooA4A400;o
000000?o<S8bomgMgOooool05_ooool001Sooooo00?o0000ooooooooool01Oooool2o`0000_oa9^^
00?o0000oj8W6?nR9aP03?nR9aP00ol0003oZSH[ojXf:`02ojXf:`03o`000?nR9aSoXRLH00OoXRLH
00?o0000ojXg:onZ=b/02_nZ=b/3o`0000coZSL/00?o0000ooooooooool01Oooool00ol0003oZSL/
ojXg;003ojXg;003o`000?oooooooooo00_ooooo0_l0000Kooooo`03o`000?nn^mOo_[_G00Wo_[_G
00?o0000ol:dcOo2]<d01?o2]<d3o`0000?o`[C=0_l00003okjke`03o`000?o2]<go`[C=00oo`[C=
00Co0000olB_aOo4[lGo00003Oo2]<d00ol0003oa:o5olB_a@07olB_a@03o`000?o2]<go`[C=00Go
`[C=00?o0000olB_aOo4[lD03Oo4[lD00ol0003o`[C=o`000005olB_a@03o`000?o4[lGoa:o500So
a:o500?o0000ooooooooool08_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Ko
oooo00?oMgMgoc8b<_ooool05_ooool001Oooooo00?o0000ooooooooool01_ooool00ol0003oa9^^
olBK[P0;olBK[P;o00003OnR9aP01?l0003oZSH[o`000?l0000;oj8W6003o`000?nZ=b_oZSL[00Oo
ZSL[0_l00003oj8X6@03o`000?nZ=bcoZSL/00[oZSL/00?o0000ooooooooool00oooool00ol0003o
ZSL/ojXg;005ojXg;003o`000?oooooooooo00Wooooo00Co0000ojXg;?nZ=bco00006?ooool2o`00
00go_[_G00Co0000ol:dcOo2]<go`[C=0_l00005ol:dc@03o`000?nn^mOo_[_G00?o_[_G00?o0000
ol:dcOo2]<d03oo2]<d00ol0003oa:o5o`00000?ol:dc@03o`000?o4[lGoa:o500Goa:o500?o0000
ol:dcOo2]<d01_o2]<d00ol0003oa:o5olB_a@0<olB_a@05o`000?o2]<go`[C=ol:dcOl000001Oo4
[lD00ol0003oa:o5olB_a@08olB_a@03o`000?oooooooooo027ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo000Gooooo`03o`000?oooooo
oooo00Kooooo00?o0000olBK[_o4Vjh03Oo4Vjh00ol0003oXRLHoj8W600:oj8W60?o00003OnR9aP0
0ol0003oZSL[ojXg:`04ojXg:`;o00001_nR:1T00ol0003oZSL/ojXg;00:ojXg;005o`000?oooooo
ooooooooool000002OnZ=b`00ol0003oooooooooo`07ooooo`03o`000?nZ=bcoZSL/00;oZSL/00?o
0000ooooooooool05?ooool00ol0003o_[_Gokjke`0=okjke`Co00001Oo2]<d2o`0000Oo_[_G00?o
0000ol:dcOo2]<d03_o2]<d2o`00013o`[C=00?o0000olB_aOo4[lD01?o4[lD00ol0003o`[C=ol:d
c@08ol:dc@03o`000?o4[lGoa:o500Woa:o50_l00004ol:dc@03o`000?o4[lGoa:o500Coa:o500?o
0000olB_aOo4[lD01oo4[lD00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01_ooool00omgMgOo<S8booooo`0Fooooo`005oooool00ol0003oooooooooo`06
ooooo`03o`000?o4Vjkoa9^^00koa9^^00?o0000oj8W6?nR9aP01onR9aP2o`0000?oUQ8000?o0000
oj8W6?nR9aP02onR9aP00ol0003oZSL[ojXg:`02ojXg:`03o`000?nR:1WoXRPI00OoXRPI00?o0000
ojXg;?nZ=b`02_nZ=b`00ol0003oooooo`00000;ojXg;003o`000?oooooooooo00Gooooo00?o0000
ojXg;?nZ=b`01?nZ=b`00ol0003oooooooooo`0Aooooo`;o00003_nn^mL4o`0000Ko`[C=00?o0000
okjkeonn^mL01onn^mL00ol0003o`[C=ol:dc@0=ol:dc@03o`000?nn^mOo0000017o`[C=00Co0000
olB_aOo4[lGoa:o50_l0000<ol:dc@03o`000?o4[lGoa:o500Ooa:o500?o0000ol:dcOo2]<d01Oo2
]<d00ol0003oa:o5olB_a@03olB_a@03o`000?o4[lGoa:o500Ooa:o50_l0000Sooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Oooooo
000Gooooo`03o`000?oooooooooo00Oooooo00?o0000olBK[_o4Vjh03_o4Vjh2o`0000CoXRLH0ol0
0006oiHB00;o00003?nR9aP01?l0003oZSL[o`000?l0000;oj8X6@03o`000?nZ=bcoZSL/00WoZSL/
0ol0000<ojXg;003o`000?oooooooooo00?ooooo00?o0000ojXg;?nZ=b`01_nZ=b`00ol0003ooooo
ooooo`09ooooo`?o00000_ooool2o`000003okS3hol0003o_[_G00[o_[_G0ol00003okjke`03o`00
0?o2]<go`[C=00?o`[C=00?o0000okjkeonn^mL02Onn^mL00ol0003o`[C=ol:dc@0:ol:dc@;o0000
0onn^mL00ol0003o`[C=ol:dc@0>ol:dc@04o`000?o4[lGoa:o5o`0000ko`[C=00?o0000olB_aOo4
[lD01_o4[lD00ol0003o`[C=ol:dc@06ol:dc@03o`000?o4[lGoa:o500Coa:o500?o0000olB_aOo4
[lD01Oo4[lD00ol0003o`[C=o`00000Tooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Iooooo`005oooool3o`0000Oooooo00?o0000olBK[_o4Vjh0
3_o4Vjh01?l0003oa9^^o`000?nR9aP2o`0000_oUQ8000?o0000oj8W6?nR9aP02OnR9aP3o`0000go
XRPI00?o0000ojXg;?nZ=b`01onZ=b`01Ol0003oXRPIoj8X6OnR:1Wo000000coZSL/00Go0000oooo
ooooooooooooo`00000:ojXg;003o`000?oooooooooo00Oooooo00Co0000ojXg;OnZ=bgoZSL]0_l0
0004okS3h`03o`000?nn^mOo_[_G00Go_[_G0ol00007okjke`03o`000?o2]<go`[C=00;o00003Onn
^mL00ol0003o`[C=ol:dc@08ol:dc@03o`000?nn^mOo_[_G00?o_[_G00?o0000ol:dcOo2]<d03_o2
]<d00ol0003oa:o5o`00000@ol:dc@03o`000?o4[lGoa:o500Coa:o500?o0000ol:dcOo2]<d01oo2
]<d00ol0003oa:o5olB_a@05olB_a@03o`000?o4[lGoa:o500?oa:o500Go0000ol:dcOo2]<go`[C=
o`00000Sooooo`;o00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo
000Fooooo`;o00002Oooool00ol0003oa9^^olBK[P0>olBK[P03o`000?o4Vjkoa9^^00;o00003OnF
4P000ol0003oXRLHoj8W6006oj8W60;o00000onF4P000ol0003oXRPIoj8X6@0;oj8X6@03o`000?nZ
=bcoZSL/00CoZSL/0_l00005oj8X6@03o`000?nZ=bcoZSL/00[oZSL/00?o0000ooooool000003?nZ
=b`00ol0003oooooooooo`05ooooo`03o`000?nZ=bgoZSL]00;o00001onh`n<01?l0003o_[_Gokjk
eonn^mL3o`0000[o_[_G00?o0000ol:dcOl000003onn^mL00ol0003o`[C=ol:dc@06ol:dc@;o0000
1onn^mL00ol0003o`[C=ol:dc@0=ol:dc@;o00004Oo2]<d00ol0003oa:o5olB_a@02olB_a@;o0000
2oo2]<d00ol0003oa:o5olB_a@05olB_a@03o`000?o4[lGoa:o500;o00001?o2]<d00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooo000000Gooooo00?oEEEEofIVI_l000001Oooool4o`0001Sooooo
000<ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`09ooooo`03o`00
0?o4Vjkoa9^^00coa9^^0_l00004olBK[P;o00003?nF4P02o`0000CoXRLH0_l00006oiHB0003o`00
0?nR:1WoXRPI00_oXRPI00Co0000ojXg;?nZ=bcoZSL/0_l00008oj8X6@03o`000?nZ=bcoZSL/00Wo
ZSL/0ol0000=ojXg;003o`000?oooooooooo00?ooooo00Co0000ojXg;OnZ=bgo00002Onh`n<4o`00
00go_[_G0_l0000Aokjke`03o`000?o2]<go`[C=00Co`[C=00?o0000okjkeonn^mL01onn^mL00ol0
003o`[C=ol:dc@0<ol:dc@03o`000?nn^mOo000001;o`[C=00Co0000olB_aOo4[lGo00003Oo2]<d0
0ol0003oa:o5olB_a@05olB_a@03o`000?o4[lGo000000Oo`[C=00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0Vooooo`003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
00Wooooo00?o0000olBK[_o4Vjh02oo4Vjh01?l0003oa9faolBM/Ol00005olBK[P03o`000?nF4P3o
UQ8000_oUQ8000Co0000oj8W6?l0003o00002OnF4P000ol0003oXRPIoj8X6@0;oj8X6@03o`000?nZ
=bco000000_oXRPI0_l00008ojXg;005o`000?nS:1[oXbPJoj<X6_l000003OnZ=b`01_l0003ooooo
oooooooooooo0000ojXg;@;o00002?nh`n<4o`0000go_[_G0_l000000onh`n?o0000okjke`0@okjk
e`03o`000?o2]<go`[C=00?o`[C=00?o0000okjkeonn^mL02Onn^mL00ol0003o`[C=ol:dc@09ol:d
c@;o00000onn^mL00ol0003o`[C=ol:dc@0?ol:dc@03o`000?o4[lGo000000oo`[C=00?o0000olB_
aOo4[lD01Oo4[lD00ol0003o`[C=ol:dc@06ol:dc@03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool09Oooool000?ooooo1_l00007ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02Oooool00ol0003oa9^^olBK[P0:olBK[P05o`000?o4WK7oa9faolBM/Ol000001_o4Vjh2o`00
00_oUQ800ol0000;oiHB00;o00002onR:1T3o`0000goXRPI00?o0000ojXg;?nZ=b`00onZ=b`2o`00
00GoXbPJ00?o0000ojXg;?nZ=b`02onZ=b`00ol0003oooooo`000002o`0000So^<?S0_l00004okS3
h`03o`000?nn^mOo_[_G00So_[_G0_l00004okS3h`03o`000?nn^mOo_[_G00oo_[_G00?o0000ol:d
cOo2]<d00_l0000<okjke`03o`000?o2]<go`[C=00Oo`[C=0_l00005okjke`03o`000?o2]<go`[C=
00oo`[C=0_l0000@ol:dc@03o`000?o4[lGoa:o500Coa:o500?o0000ol:dcOl000001oo2]<d00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo02Gooooo000?ooooo`03ogMgMolb<S;ooooo00Co
oooo0_l0000;ooooo`03o`000?o4Vjkoa9^^00Woa9^^00Go0000olBM/Oo4WK7oa9fao`000008olBK
[P;o00001_nF4P03o`0000?oP@000_l0000;oiHB0003o`000?nR:1WoXRPI00KoXRPI0_l00003oiHC
0003o`000?nR:1WoXRPI00_oXRPI00Go0000ojXg;?nZ=bcoZSL/o`000008oj<X6P03o`000?nZ=bco
ZSL/00[oZSL/0ol00007okS3h`?o00001_nh`n<00ol0003o_[_Gokjke`06okjke`;o00001onh`n<0
0ol0003o_[_Gokjke`0>okjke`03o`000?o2]<go000000oo_[_G00?o0000ol:dcOo2]<d01Oo2]<d0
0ol0003o_[_Gokjke`06okjke`03o`000?o2]<go`[C=00go`[C=00?o0000okjkeol000004Oo2]<d0
1?l0003oa:o5olB_aOo4[lD2o`0000;o`[C=00?o0000ol:dcOo2]<d01_o2]<d00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo02Cooooo000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?o4Vjkoa9^^00Soa9^^00?o0000olBM/Oo4WK400oo4
WK400ol0003oa9^^olBK[P07olBK[P03o`000?nF4P3oUQ8000?o00002?n100000ol0003oUQ80oiHB
0009oiHB0003o`000?nR:1WoXRPI00;oXRPI0ol00006oiHC00;o00003?nR:1T00ol0003oZSL/o`00
000:oj<X6P;o00002?nZ=b`3o`000003ojc;l?l0003o^<?S00?o^<?S0ol0000:okS3h`03o`000?nn
^mOo_[_G00Co_[_G00?o0000okS3honh`n<01onh`n<00ol0003o_[_Gokjke`0>okjke`;o00004?nn
^mL00ol0003o`[C=ol:dc@03ol:dc@;o00002_nn^mL00ol0003o`[C=ol:dc@0:ol:dc@;o00000onn
^mL00ol0003o`[C=ol:dc@0>ol:dc@04o`000?o4[lGoa:o5o`0000Go`[C=00?o0000ol:dcOo2]<d0
1Oo2]<d00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02?ooooo000<ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oa9^^olBK[P07olBK[P03o`000?o4
WK7oa9fa00Coa9fa00?o0000olBK[_o4Vjh02?o4Vjh2o`0000coP@000_l0000:oiHB0004o`000?nR
:1Wo0000o`0000_oUQ<000?o0000oj8X6OnR:1T02OnR:1T3o`0000coXbPJ00?o0000ojXg;?nZ=b`0
0onZ=b`2o`0000Go[<_`1?l0000=okS3h`03o`000?nn^mOo_[_G00;o_[_G0_l0000;okS3h`03o`00
0?nn^mOo_[_G00_o_[_G0_l000000onh`n?o0000okjke`0@okjke`03o`000?o2]<go`[C=00;o0000
3?nn^mL00ol0003o`[C=ol:dc@09ol:dc@03o`000?nn^mOo_[_G00?o_[_G00?o0000ol:dcOo2]<d0
3_o2]<d00ol0003oa:o5o`000007ol:dc@03o`000?o2]<go`[C=00Go`[C=00?o0000ooooooooool0
8_ooool3o`0002Cooooo000<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02ooo
ool00ol0003oa9^^olBK[P06olBK[P03o`000?o4WK7oa9fa00Goa9fa00?o0000olBK[_o4Vjh02_o4
Vjh3o`0000_oP@000_l00007oiHB00Co00003OnF4`000ol0003oXRPIoj8X6@06oj8X6@;o00000onF
4`000ol0003oXbPJoj<X6P0:oj<X6P03o`000?nZ=bcoZSL/00;o00001On/bo04o`00013o^<?S00Co
0000okjkeol0003o00003_nh`n<00ol0003o_[_Gokjke`08okjke`;o00001?nh`n<00ol0003o_[_G
okjke`0>okjke`03o`000?o2]<go000000oo_[_G00?o0000ol:dcOo2]<d01_o2]<d2o`0000Oo_[_G
00?o0000ol:dcOo2]<d03Oo2]<d2o`0000Wo`[C=00?o0000ol:dcOo2]<d01?o2]<d00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo02;ooooo000<ooooo`Co00001Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?o4Vjkoa9^^00Goa9^^00?o0000olBM/Oo4WK401_o4WK400ol0003oa9^^olBK
[P08olBK[P04o`000?o4WK7oa9faolBM/@;o00002on100000ol0003oUQ80oiHB0004o`0000CoPP00
0_l0000<oiHC00;o00001?nR:1T2o`0000KoUQ<00_l0000:oj<X6P?o00001?n/bo03o`0000Co[<_`
00?o0000okS3honh`n<03Onh`n<2o`00017o^<?S00?o0000okjkeonn^mL01?nn^mL3o`0000Oo^<?S
00?o0000okjkeonn^mL03Onn^mL2o`00013o_[_G00?o0000ol:dcOo2]<d01Oo2]<d00ol0003o_[_G
okjke`07okjke`03o`000?o2]<go`[C=00co`[C=00?o0000okjkeol000002Oo2]<d00ol0003o`[C=
ol:dc@05ol:dc@03o`000?oooooooooo02Cooooo00?o0000ooooooooool08Oooool001Gooooo0_l0
000=ooooo`03o`000?o4Vjkoa9^^00Coa9^^00?o0000olBM/Oo4WK401oo4WK400ol0003oa9^^olBK
[P07olBK[P03o`000?o4WK7oa9fa00Coa9fa0ol00005oh4000Ko00002_n20003o`0000_oUQ<000Co
0000oj8X6Ol0003o00002_nF4`000ol0003oXbPJoj<X6P04oj<X6P?o00001?n/bo03o`0000So[<_`
00?o0000okS3honh`n<02Onh`n<3o`000003ojc;l?l0003o^<?S013o^<?S00?o0000okjkeonn^mL0
0_nn^mL2o`0000[o^<?S00?o0000okjkeonn^mL02onn^mL2o`000003okS3hol0003o_[_G013o_[_G
00?o0000ol:dcOo2]<d00oo2]<d00ol0003o_[_Gokjke`09okjke`03o`000?o2]<go`[C=00Wo`[C=
0_l00003okjke`03o`000?o2]<go`[C=00Oo`[C=00?o0000ol:dcOo2]<d01?o2]<d00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo027ooooo000Eooooo`03o`000?oooooooooo00cooooo00?o
0000olBK[_o4Vjh00oo4Vjh00ol0003oa9faolBM/@08olBM/@03o`000?o4Vjkoa9^^00Koa9^^00?o
0000olBM/Oo4WK401Oo4WK400ol0003oa9^^olBK[P05o`0000KoGP000_l0000;oh8000;o00002?nF
4`04o`0000coUQ<000?o0000oj<X6_nS:1X00ol00003oiOAo0Co00003?n/bo000ol0003o^<?SokS3
h`06okS3h`;o00001On/bo000ol0003o^<?SokS3h`0?okS3h`04o`000?nn^mOo0000o`0000go^<?S
00?o0000okjkeonn^mL02Onn^mL00ol0003o^<?SokS3h`02okS3h`03o`000?nn^mOo_[_G00oo_[_G
00?o0000ol:dcOo2]<d00_l0000<okjke`03o`000?o2]<go`[C=00Oo`[C=0_l00005okjke`03o`00
0?o2]<go`[C=00So`[C=00?o0000ol:dcOo2]<d00oo2]<d00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo023ooooo000Eooooo`03o`000?oooooooooo00gooooo00Go0000olBK[_o4Vjkoa9^^
o`00000<olBM/@03o`000?o4Vjkoa9^^00Goa9^^00?o0000olBM/Oo4WK401_o4WK400ol0003oa9^^
olBK[P02olBK[PCo00001_mN0002o`0000_oPP000_l00002oiHC00Co00001?n20002o`0000[oUQ<0
0ol00005oiOAo0?o00003on/bo000ol0003o^<?SokS3h`03okS3h`;o00002?n/bo000ol0003o^<?S
okS3h`0>okS3h`;o00004?nh`n<00ol0003o_[_Gokjke`06okjke`;o00001_nh`n<00ol0003o_[_G
okjke`0>okjke`03o`000?o2]<go000000oo_[_G00?o0000ol:dcOo2]<d01Oo2]<d00ol0003o_[_G
okjke`06okjke`03o`000?o2]<go`[C=00So`[C=00?o0000ol:dcOo2]<d00_o2]<d2o`0002Oooooo
00?o0000ooooooooool07oooool001Gooooo00?o0000ooooooooool03Oooool01Ol0003oa9^^olBK
[_o4Vjko000000coa9fa00?o0000olBK[_o4Vjh01?o4Vjh00ol0003oa9faolBM/@07olBM/@03o`00
0?o4Vjkoa9^^00Koa9^^0ol00005oeh000;o00002On20004o`0000[oPP0000?o0000oiHC0?nF4`00
1?nF4`03o`0000GoUm7l0ol00003oiOAo003o`000?n/bo3o[<_`00go[<_`00?o0000okS3hol00000
0_l0000;ojc;l003o`000?nh`n?o^<?S00[o^<?S0ol000000on/c?3o0000okS3h`0@okS3h`03o`00
0?nn^mOo_[_G00?o_[_G0_l00008okS3h`03o`000?nn^mOo_[_G00ko_[_G0_l0000@okjke`03o`00
0?o2]<go`[C=00?o`[C=0_l00009okjke`03o`000?o2]<go`[C=00So`[C=00Oo0000ol:dcOo2]<go
`[C=o`000?nn^mOo000002Oooooo00?o0000ooooooooool07oooool001Cooooo0_l0000?ooooo`04
o`000?o4Vjkoa9^^o`0000goa9fa00?o0000olBK[_o4Vjh00oo4Vjh00ol0003oa9faolBM/@08olBM
/@03o`000?o4Vjkoa9^^00Koa9^^00?o0000olBM/Oo4WK401_l000000omN003o0000o`000002oh80
00Go00001?mN0002o`0000OoPP002?l00005oiOAo0?o00001onGdO`00ol0003o[<_`ojc;l00;ojc;
l0?o00003on/bo000ol0003o^<?SokS3h`06okS3h`?o00001On/c?000ol0003o^<?SokS3h`0>okS3
h`03o`000?nn^mOo_[_G00;o_[_G00?o0000okS3honh`n<02Onh`n<00ol0003o_[_Gokjke`0;okjk
e`;o000000?o^<?So`000?nn^mL04?nn^mL00ol0003o`[C=ol:dc@02o`0000co_[_G00?o0000ol:d
cOo2]<d02?o2]<d3o`0000?o_[_G00?o0000ooooooooool09?ooool2o`00023ooooo000Dooooo`03
o`000?oooooooooo00oooooo0_l0000?olBM/@05o`000?o4Vjkoa9^^olBK[_l000003?o4WK400ol0
003oa9^^olBK[P05olBK[P03o`000?o4WK7oa9fa00Goa9fa1ol00006oeh000_o00002?m^cOh00ol0
003oUm7lo`000002o`0000_oUm7l00?o0000ojc;l?n/bo001On/bo05o`0000?oUm7l00?o0000ojc;
l?n/bo003On/bo000ol0003o^<?SokS3h`03okS3h`;o00002On/c?000ol0003o^<?SokS3h`0>okS3
h`04o`000?nn^mOo0000o`0000go^<?S00?o0000okjkeonn^mL02?nn^mL2o`0000Co^<?S00?o0000
okjkeonn^mL03_nn^mL00ol0003o`[C=o`00000>okjke`03o`000?o2]<go`[C=00Oo`[C=0ol00004
okjke`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07Oooool001Cooooo00?o0000oooo
ooooool03oooool00ol0003oa9faolBM/@0>olBM/@05o`000?o4Vjkoa9^^olBK[_l000003?o4WK40
0ol0003oa9^^olBK[P04olBK[P03o`000?o4WK7oa9fa00Ooa9fa00Co0000olBK[_o4Vjkoa9^^2?l0
0007obZ_hP;o00002Om^cOh4o`0000koUm7l00?o0000ojc;l?n/bo001?l00009oiOAo003o`000?n/
bo3o[<_`00go[<_`00?o0000okS3hol000000_l0000<ojc<l003o`000?nh`n?o^<?S00go^<?S0_l0
000?okS3h`03o`000?nn^mOo_[_G00Ko_[_G0_l00007okS3h`03o`000?nn^mOo_[_G00go_[_G0_l0
000@okjke`03o`000?o2]<go`[C=00Go`[C=00Co0000okjkeonn^mOo00001Onn^mL00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01gooooo000Dooooo`03o`000?oooooooooo00oooooo00?o
0000olBM/Oo4WK403_o4WK401?l0003oa9^^olBK[_l0000=olBM/@03o`000?o4Vjkoa9^^00?oa9^^
00?o0000olBM/Oo4WK402?o4WK400ol0003oa9^^olBK[P06olBK[PCo00002?lZ[n82o`0000CoK/gn
0ol00004ofk=oP;o00002_nGdO`5o`0000koUm7l00?o0000ojc;l?n/bo003?n/bo02o`00013o[<c`
00?o0000okS3honh`n<02Onh`n<3o`000003ojc<l?l0003o^<?S00oo^<?S00?o0000okjkeonn^mL0
1?nn^mL00ol0003o^<?SokS3h`07okS3h`03o`000?nn^mOo_[_G00_o_[_G0_l000000onh`n?o0000
okjke`0?okjke`03o`000?o2]<go`[C=00?o`[C=0_l00004okjke`03o`000?nn^mOo_[_G00;o_[_G
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`005?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?o4WK7oa9fa00koa9fa0_l0000?olBM/@05o`000?o4Vjkoa9^^olBK[_l00000
3?o4WK400ol0003oa9^^olBK[P04olBK[P03o`000?o4WK7oa9fa00;oa9fa2?l00002obZ_hPCo0000
2Om^cOh01?l0003oUm7loiOAo?nGdO`6o`0000GoKLgn00?o0000oiOAo?nGdO`03?nGdO`00ol0003o
[<_`ojc;l008ojc;l0?o00000_nFd_`00ol0003o[<c`ojc<l00=ojc<l003o`000?nh`n?o^<?S00Ko
^<?S0ol00005ojc<l003o`000?nh`n?o^<?S00go^<?S00?o0000okjkeonn^mL00_nn^mL2o`0000_o
^<?S00?o0000okjkeonn^mL02?nn^mL2o`0000Co^<?S00?o0000okjkeonn^mL03_nn^mL00ol0003o
`[C=ol:dc@02o`0000Oo_[_G00?o0000okjkeonn^mL00_nn^mL00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo01_ooooo000Dooooo`;o00004Oooool00ol0003oa9faolBM/@0>olBM/@03o`00
0?o4WK7oa9fa00koa9fa00Go0000olBK[_o4Vjkoa9^^o`00000<olBM/@03o`000?o4Vjkoa9^^00?o
a9^^00?o0000olBM/Oo4WK401oo4WK401?l0003oa9^^olBK[_o4VjhCo`0000coKLgn00?o0000oiOA
o?nGdO`03?nGdO`00ol0003o[<_`ojc;l004ojc;l0?o00001_nFd_`00ol0003o[<c`ojc<l00=ojc<
l003o`000?nh`n?o^<?S00?o^<?S0_l00009ojc<l003o`000?nh`n?o^<?S00go^<?S00Co0000okjk
eol0003o00003Onh`n<00ol0003o_[_Gokjke`06okjke`;o00001_nh`n<00ol0003o_[_Gokjke`0>
okjke`03o`000?o2]<go000000[o_[_G00?o0000okjkeonn^mL00_nn^mL00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01_ooooo000Cooooo`;o00004_ooool00ol0003oa9faolBM/@0>olBM
/@03o`000?o4WK7oa9fa00koa9fa00Co0000olBK[_o4Vjko00003Oo4WK400ol0003oa9^^olBK[P03
olBK[P03o`000?o4WK7oa9fa00Ooa9fa00Co0000olBK[_l0003o00001Oo4Vjh00ol0003oa9fao`00
0003o`0000Oo:JkQ0_l0000<ofg=oP;o00003OnGdO`00ol0003o[<_`ojc;l003o`0000[oU];l00?o
0000ojc<l?n/c?003On/c?000ol0003o^<?So`000002o`0000_o[<c`00?o0000okS3honh`n<03Onh
`n<2o`00013o^<?S00?o0000okjkeonn^mL01?nn^mL00ol0003o^<?SokS3h`07okS3h`03o`000?nn
^mOo_[_G00go_[_G0_l0000;okjke`03o`000?nn^mOo_[_G00;o_[_G00?o0000ooooooooool09Ooo
ool2o`0001cooooo000Cooooo`03o`000?oooooooooo01;ooooo00?o0000olBM/Oo4WK403?o4WK40
0ol0003o`j2do`00000@olBM/@;o00003oo4WK401Ol0003oa9^^olBK[_o4Vjko000000Woa9fa0ol0
0006olBK[P03o`000?o4WK7oa9fa00Coa9fa1Ol00004obV^h@;o00003?m]cOh00ol0003oUm7loiOA
o008oiOAo0Go00003_nFd_`00ol0003o[<c`ojc<l00;ojc<l0?o00003on/c?000ol0003o^<?SokS3
h`09okS3h`?o000000?o[<c`o`000?nh`n<04?nh`n<01?l0003o_[_Gokjkeonn^mL2o`0000[o^<?S
00?o0000okjkeonn^mL02onn^mL2o`000003okS4hol0003o_[_G00_o_[_G00?o0000okjkeonn^mL0
0_nn^mL00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01[ooooo000Cooooo`03o`000?oo
oooooooo01;ooooo00?o0000olBM/Oo4WK402oo4WK401?l0003o`j2dol>P]?l0000@olBM/@03o`00
0?o4WK7oa9fa00koa9fa00Co0000olBK[_o4Vjko00001oo4WK43o`0000;oa9fa00?o0000olBK[_o4
Vjh00oo4Vjh00ol0003oa9faolBM/@07olBM/@03o`000?o4Vjkoa9^^00So00002om]cOh01?l0003o
Um7loiOAo?nGdO`6o`0000GoK<gm00?o0000oiKBo?nFd_`03?nFd_`00ol0003o[<c`ojc<l005ojc<
l0Go00000onFd_`00ol0003o[<c`ojc<l00=ojc<l003o`000?nh`n?o^<?S00Go^<?S0ol00005ojc<
l003o`000?nh`n?o^<?S00ko^<?S00Co0000okjkeol0003o00003Onh`n<00ol0003o_[_Gokjke`08
okjke`;o00001?nha><00ol0003o_[_Gokjke`0:okjke`05o`000?nn^mOo_[_Gokjkeol00000:?oo
ool00ol0003oooooooooo`0Iooooo`004oooool00ol0003oooooooooo`0Booooo`03o`000?o4WK7o
a9fa00[oa9fa00Go0000ol>P]?o3X;Co`j2do`00000@olBM/@03o`000?o4WK7oa9fa00koa9fa00Co
0000olBK[_o4Vjko00001?o4WK43o`0000Goa9fa00?o0000olBK[_o4Vjh00oo4Vjh00ol0003oa9fa
olBM/@07olBM/@03o`000?o4Vjkoa9^^00Koa9^^4Ol0000<ofc=o@;o00003OnFd_`00ol0003o[<c`
ojc<l004o`0000WoU];l00?o0000ojc<l?n/c?003?n/c?000ol0003o^<?SokS3h`03okS3h`;o0000
2On/c?000ol0003o^<?SokS3h`0=okS3h`;o00004?nh`n<00ol0003o_[_Gokjke`05okjke`;o0000
1onha><00ol0003o_[_Gokjke`0:okjke`03o`000?nn^mOo_[_G00;o0000:?ooool00ol0003ooooo
ooooo`0Hooooo`004oooool3o`0001?ooooo00?o0000olBM/Oo4WK402?o4WK400ol0003o`j2dol>P
]003ol>P]003o`000?o4WK7oa9fa00coa9fa00?o0000ol>P]?l000004?o4WK42o`0000;oa9fa0ol0
0009olBM/@05o`000?o4Vjkoa9^^olBK[_l000002oo4WK400ol0003oa9^^olBK[P04olBK[P03o`00
0?o4WK7oa9fa00Goa9fa1_l00003obN^h0?o00003?m/cOd00ol0003oU];loiKBo008oiKBo0Go0000
3_nFd_`00ol0003o[<c`ojc<l00<ojc<l003o`000?nh`n?o000000;o00003?n/c?000ol0003o^<?S
okS3h`09okS3h`?o000000?o[<c`o`000?nh`n<03onh`n<00ol0003o_[_Gokjke`04okjke`03o`00
0?nha>?o^<CS00Oo^<CS00?o0000okjkeonn^mL02_nn^mL3o`000003okS4hol0003ooooo02Oooooo
00?o0000ooooooooool06?ooool001?ooooo00?o0000ooooooooool04oooool00ol0003oa9faolBM
/@07olBM/@03o`000?o3X;Co`j2d00Co`j2d00?o0000olBM/Oo4WK402oo4WK401?l0003o`j2dol>P
]?l0000@olBM/@Co00003?o4WK401?l0003oa9^^olBK[_l0000<olBM/@03o`000?o4Vjkoa9^^00?o
a9^^00?o0000olBM/Oo4WK401oo4WK400ol0003oa9^^olBK[P02olBK[PSo00002om/cOd01?l0003o
U];loiKBo?nFd_`6o`0000GoK<gm00?o0000oiKBo?nFd_`03?nFd_`00ol0003o[<c`ojc<l00:ojc<
l0Co00003_n/c?000ol0003o^<?SokS3h`06okS3h`?o00001On/c?000ol0003o^<?SokS3h`0>okS3
h`04o`000?nn^mOo_[_Gokjke`;o00002onha><00ol0003o_[_Gokjke`08okjke`?o00000onha><0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Oooooo0008ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Cooooo`03o`000?o4WK7oa9fa00Koa9fa00?o0000
ol>P]?o3X;@01Oo3X;@00ol0003oa9faolBM/@0:olBM/@05o`000?o3X;Co`j2dol>P]?l000003_o4
WK43o`0000ooa9fa00Co0000olBK[_o4Vjko00003?o4WK400ol0003oa9^^olBK[P03olBK[P03o`00
0?o4WK7oa9fa00Ooa9fa00?o0000olBK[_o4Vjh01_o4Vjh00ol0003oa9fao`00000@o`0000coK<gm
0_l0000=oiKBo003o`000?n/c?3o[<c`00Go[<c`1?l00004oiKBo003o`000?n/c?3o[<c`00co[<c`
00?o0000okS3honh`n<00onh`n<2o`0000Wo[<c`00?o0000okS3honh`n<03Onh`n<01?l0003o_[_G
o`000?l0000=okS4h`03o`000?nn^mOo_[_G00Ko_[_G0_l00003okS4h`03o`000?nha>?o^<CS00?o
00009oooool00ol0003oooooooooo`0Fooooo`002?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo00?o0000ooooooooool05Oooool00ol0003oa9faolBM/@05olBM/@03o`000?o3X;Co`j2d00Ko
`j2d00?o0000olBM/Oo4WK402?o4WK400ol0003o`j2dol>P]003ol>P]003o`000?o4WK7oa9fa00So
a9fa0ol000001?o4WK7o0000ol>P]?l0000?olBM/@;o00003_o4WK401Ol0003oa9^^olBK[_o4Vjko
000000_oa9fa00?o0000olBK[_o4Vjh01?o4Vjh00ol0003oa9faolBM/@05olBM/@?o00002?lV[Ml3
o`0000coK<gm00?o0000oiKBo?nFd_`02onFd_`00ol0003o[<c`ojc<l004o`0000WoU];l00?o0000
ojc<l?n/c?003?n/c?000ol0003o^<?So`000002o`0000co[<c`00?o0000okS3honh`n<02onh`n<3
o`00013o^<CS00?o0000okjkeonn^mL01?nn^mL00ol0003o^<CSokS4h`04okS4h`06o`000?nha>?o
^<CSo`000?n[>S3o00009Oooool2o`0000Wooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00_ooool000Sooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo01Go
oooo00?o0000olBM/Oo4WK401?o4WK400ol0003o`j2dol>P]007ol>P]003o`000?o4WK7oa9fa00So
a9fa00?o0000ol>P]?o3X;@00oo3X;@00ol0003oa9faolBM/@06olBM/@;o00000oo4WK401?l0003o
`j2dol>P]?l0000?olBM/@03o`000?o4WK7oa9fa00goa9fa00Co0000olBK[_o4Vjko00003?o4WK40
0ol0003oa9^^olBK[P04olBK[P03o`000?o4WK7oa9fa00Koa9fa00?o0000olBK[_l000001ol00003
obJ]g`;o00002om/cOd00ol0003oU];loiKBo005oiKBo0So00003_nFd_`00ol0003o[<c`ojc<l00:
ojc<l0?o00003on/c?000ol0003o^<?SokS3h`08okS3h`?o00000_n/c?400ol0003o^<CSokS4h`0?
okS4h`04o`000?nn^mOo_[_Gokjke`;o00001onha><01?l0003o^<CSokS4hol00002oj/j<003o`00
0?oooooooooo00Wooooo0_l0000Iooooo`03o`000?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool000Sooooo00Go0000oooooooo
ooooooooo`000005ooooo`;o00005_ooool00ol0003oa9faolBM/@03olBM/@03o`000?o3X;Co`j2d
00So`j2d00?o0000olBM/Oo4WK401oo4WK400ol0003o`j2dol>P]004ol>P]003o`000?o4WK7oa9fa
00?oa9fa0ol00004olBM/@05o`000?o3X;Co`j2dol>P]?l000003oo4WK400ol0003oa9faolBM/@0=
olBM/@04o`000?o4Vjkoa9^^o`0000coa9fa00?o0000olBK[_o4Vjh00oo4Vjh00ol0003oa9faolBM
/@07olBM/@03o`000?o4Vjkoa9^^00Koa9^^6Ol00008of_=o@03o`000?nFd_coU];l00coU];l00?o
0000ojc<l?n/c?001On/c?04o`0000?oU];m00?o0000ojc<l?n/c?003On/c?000ol0003o^<?SokS3
h`04okS3h`?o00001_n/c?400ol0003o^<CSokS4h`0>okS4h`04o`000?nn^mOo0000o`0000[o^<CS
00Co0000okS4honha>?o00000_n[>S02o`0000Wooooo00?o0000oj/j<?l000006Oooool00ol0003o
ooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4002oooo
o`002?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool05_ooool01Ol0
003oa9faolBM/Oo4WK7o000000co`j2d00?o0000olBM/Oo4WK401Oo4WK400ol0003o`j2dol>P]006
ol>P]003o`000?o4WK7o000000;o00001_o4WK400ol0003o`j2dol>P]003ol>P]003o`000?o4WK7o
a9fa00_oa9fa00?o0000ol>P]?l000003oo4WK42o`0000koa9fa00Go0000olBK[_o4Vjkoa9^^o`00
000;olBM/@03o`000?o4Vjkoa9^^00Coa9^^00?o0000olBM/Oo4WK401_o4WK44o`0000So9JcO0_l0
000<of_=o@03o`000?nFd_coU];l00coU];l00?o0000ojc<l?n/c?001?l00008oiKBo@03o`000?n/
c?3o[<c`00go[<c`00?o0000okS3honh`n<00ol0000:ojc<l@03o`000?nha>?o^<CS00go^<CS0_l0
000=okS4h`03o`000?nha>?o000000CoZcX`00?o0000ooooooooool01Oooool01Ol0003oZcX`oj/j
<?n[>S3o000001Sooooo00?o0000ooooooooool01oooool00onHV9So8B4Qonk^kP03ooooo`05o`00
0?ooooooooooooooool000000_ooool000Sooooo00Go410@oooooooooooooooooa0@4005ooooo`03
o`000?oooooooooo01Kooooo00Co0000olBM/Oo4WK7o00003Oo3X;@00ol0003oa9faolBM/@04olBM
/@03o`000?o3X;Co`j2d00Ko`j2d0ol00009olBM/@03o`000?o3X;Co`j2d00?o`j2d00?o0000olBM
/Oo4WK402_o4WK401?l0003o`j2dol>P]?l0000?olBM/@03o`000?o4WK7oa9fa00goa9fa00Go0000
olBK[_o4Vjkoa9^^o`00000;olBM/@03o`000?o4Vjkoa9^^00Coa9^^00?o0000olBM/Oo4WK401_o4
WK401?l0003oa9^^olBK[_o4Vjh5o`0000Go9JcO00?o0000of_=oOm[cOd02_m[cOd00ol0003oU];l
oiKBo009oiKBo0Go00003OnFd_d00ol0003o[<c`ojc<l00<ojc<l0?o00003_n/c?400ol0003o^<CS
okS4h`09okS4h`?o000000?o[<cao`000?nha><03?nha><01?l0003o^<CSokS4hol00004oj/j<003
o`000?oooooooooo00Cooooo00?o0000oj/j<?n[>S000_n[>S02o`0000Wooooo0_l0000<ooooo`03
o`000?oooooooooo00Oooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo0000
00;ooooo0008ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0Foooo
o`03o`000?o4WK7o000000ko`j2d00?o0000olBM/Oo4WK400oo4WK400ol0003o`j2dol>P]004ol>P
]0?o000000?o`j2do`000?o4WK402?o4WK400ol0003o`j2dol>P]004ol>P]003o`000?o4WK7oa9fa
00Woa9fa00Go0000ol>P]?o3X;Co`j2do`00000?olBM/@03o`000?o4WK7oa9fa00goa9fa00Co0000
olBK[_o4Vjko00003?o4WK400ol0003oa9^^olBK[P03olBK[P03o`000?o4WK7oa9fa00Ooa9fa00?o
0000olBK[_o4Vjh01_o4Vjh8o`0000_oJlgm00Co0000oiKBo?nFd_coU];l1ol00005of[=o@03o`00
0?nFd_goU];m00_oU];m00?o0000ojc<l?n/c?002?n/c?03o`000003oiGBoOl0003o[<ca00ko[<ca
00?o0000okS4honha><01_nha><3o`0000Go[<ca00?o0000okS4honha><02onha><00ol0003o^<CS
o`000005oj/j<0;o00000oooool00ol0003oZcX`oj/j<005oj/j<003o`000?oooooooooo00Kooooo
00?o0000oj/j<?l000002_ooool3o`0000Wooooo00Go0000oooooooooooooooooa0@4003ooooo`7o
410@0Oooool1ooooo`002?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000oooooooo
ool06?ooool00ol0003o`j2dol>P]00>ol>P]003o`000?o4WK7oa9fa00;oa9fa00Co0000ol>P]?o3
X;Co`j2d0ol00005ol>P]003o`000?o4WK7oa9fa00Goa9fa00?o0000ol>P]?o3X;@01_o3X;@00ol0
003oa9faolBM/@08olBM/@03o`000?o3X;Co`j2d00;o`j2d00?o0000olBM/Oo4WK402oo4WK400ol0
003o`j2do`00000?olBM/@;o00003_o4WK401Ol0003oa9^^olBK[_o4Vjko000000_oa9fa00?o0000
olBK[_o4Vjh01?o4Vjh00ol0003oa9faolBM/@04olBM/A7o00003OmZcOd00ol0003oU];moiKBo@0;
oiKBo@03o`000?n/c?3o[<c`00Co[<c`0ol00005oiGBo@03o`000?n/c?7o[<ca00go[<ca00?o0000
okS4honha><00onha><2o`0000Wo[<ca00?o0000okS4honha><02onha><3o`0000KoZcX`00Co0000
oooooooooooo00002?n[>S000ol0003oooooooooo`04ooooo`;o00000_n[>S000ol0003ooooooooo
o`04ooooo`Co000000?oooooo`000?ooool01?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`004Oooool2o`0001Wooooo00?o0000ol>P]?o3X;@0
3_o3X;@01_l0003oa9faolBM/Oo4WK7o0000ol>P]0?o00002?o3X;@00ol0003oa9faolBM/@04olBM
/@03o`000?o3X;Co`j2d00Oo`j2d00?o0000olBM/Oo4WK401oo4WK400ol0003o`j2dol>P]003ol>P
]003o`000?o4WK7oa9fa00[oa9fa00Co0000ol>P]?o3X;Co00003oo4WK400ol0003oa9faolBM/@0=
olBM/@05o`000?o4Vjkoa9^^olBK[_l000002oo4WK400ol0003oa9^^olBK[P04olBK[P03o`000?o4
WK7oa9fa00Koa9fa00Co0000olBK[_o4Vjkoa9^^1_l00004obB/gP?o00003?mZcOd00ol0003oU];m
oiKBo@0;oiKBo@03o`000?n/c?3o[<c`00?o00002OnEd_d00ol0003o[<caojc<l@0=ojc<l@03o`00
0?nha>?o000000;o00002on/c?400ol0003o^<CSokS4h`09okS4h`Go00001on[>S03o`0000WoZcX`
00?o0000ooooooooool00oooool00ol0003oZcX`oj/j<002oj/j<0;o000000Coooooo`000?l0003o
00001Oooool2o`0000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00_ooool0017ooooo00?o0000ooooooooool06Oooool00ol0003o`j2dol>P]00=ol>P
]003o`000?o4WK7oa9fa00?o00002oo3X;@00ol0003oa9faolBM/@03olBM/@03o`000?o3X;Co`j2d
00So`j2d00?o0000olBM/Oo4WK401_o4WK400ol0003o`j2dol>P]004ol>P]003o`000?o4WK7oa9fa
00Woa9fa00Go0000ol>P]?o3X;Co`j2do`00000?olBM/@03o`000?o4WK7oa9fa00goa9fa00Co0000
olBK[_o4Vjko00003?o4WK400ol0003oa9^^olBK[P03olBK[P03o`000?o4WK7oa9fa00Ooa9fa00?o
0000olBK[_o4Vjh01_o4Vjh:o`0000_oJ/gm00?o0000oiKBoOnFd_d01OnFd_d8o`0000goUM;m00?o
0000ojc<lOn/c?402on/c?43o`0000oo[<ca00?o0000okS4honha><01Onha><3o`0000?o[<ca00?o
0000ojc<lOl000001on[>S02o`0000[oZcX`0_l00002ooooo`;o00001_n[>S000ol0003ooooooooo
o`06ooooo`;o00004oooool0017ooooo00?o0000ooooooooool06Oooool00ol0003o`j2dol>P]00=
ol>P]0?o00003oo3X;@00ol0003oa9faolBM/@02olBM/@03o`000?o3X;Co`j2d00Wo`j2d00?o0000
olBM/Oo4WK401?o4WK400ol0003o`j2dol>P]006ol>P]003o`000?o4WK7oa9fa00Soa9fa00?o0000
ol>P]?o3X;@00_o3X;@00ol0003oa9faolBM/@0;olBM/@03o`000?o3X;Co000000ooa9fa0_l0000>
olBM/@05o`000?o4Vjkoa9^^olBK[_l000002oo4WK400ol0003oa9^^olBK[P04olBK[P03o`000?o4
WK7oa9fa00Goa9fa5_l00008ofW<o@03o`000?nEd_goUM;m00_oUM;m00?o0000ojc<lOn/c?401On/
c?45o`0000?oUM;m00?o0000ojc<lOn/c?403?n/c?400ol0003o^<CSokS4h`03okS4h`;o00001on/
c?400ol0003o[<cao`000006oj/j<003o`000?nT;1ko000000_oZcX`00Co0000ooooool0003o0000
1on[>S000ol0003oooooooooo`05ooooo`;o00004oooool0017ooooo00?o0000ooooooooool06Ooo
ool00ol0003o`j2dol>P]00;ol>P]0;o000000?o`j2do`000?o3X;@03oo3X;@01Ol0003oa9faolBM
/Oo4WK7o000000co`j2d00?o0000olBM/Oo4WK401?o4WK400ol0003o`j2dol>P]006ol>P]003o`00
0?o4WK7oa9fa00Ooa9fa00?o0000ol>P]?o3X;@00oo3X;@00ol0003oa9faolBM/@0:olBM/@04o`00
0?o3X;Co`j2do`0000ooa9fa00?o0000olBM/Oo4WK403Oo4WK401Ol0003oa9^^olBK[_o4Vjko0000
00_oa9fa00?o0000olBK[_o4Vjh00oo4Vjh00ol0003oa9faolBM/@06olBM/@03o`000?o4Vjkoa9^^
00?oa9^^0ol00008ob>[g@;o00003?mYc?d2o`0000coUM;m00?o0000ojc<lOn/c?401?l00009oiGB
o@03o`000?n/c?7o[<ca00co[<ca00?o0000okS4hol000000_l0000:ojc<l@;o00001On[>S001?l0
003oY2`Noj@/7_nT;1h2o`0000[oZcX`0_l00009oj/j<003o`000?oooooooooo00?ooooo0ol0000C
ooooo`004Oooool00ol0003oooooooooo`0Jooooo`03o`000?o3X;Co`j2d00Oo`j2d0ol00003ol>P
]003o`000?o3X;Co`j2d00ko`j2d00Co0000olBM/Oo4WK7o00003Oo3X;@00ol0003oa9faolBM/@03
olBM/@03o`000?o3X;Co`j2d00Oo`j2d00?o0000olBM/Oo4WK401_o4WK400ol0003o`j2dol>P]004
ol>P]003o`000?o4WK7oa9fa00Woa9fa00Go0000ol>P]?o3X;Co`j2do`00000?olBM/@03o`000?o4
WK7oa9fa00goa9fa00Co0000olBK[_o4Vjko00003?o4WK400ol0003oa9^^olBK[P03olBK[P03o`00
0?o4WK7oa9fa00Koa9fa00?o0000olBK[_o4Vjh01_o4Vjh7o`0000?o8j_M0_l0000<ofW<o@03o`00
0?nEd_goUM;m00CoUM;m2?l0000>oiGBo@03o`000?n/c?7o[<ca00[o[<ca0ol0000>ojc<l@;o0000
1?n[>S000ol0003oY2`Noj@/7P03oj@/7P03o`000?n[>S3oZcX`00SoZcX`0_l00009oj/j<0;o0000
0oooool00ol0003oooooo`00000Cooooo`004?ooool3o`0001_ooooo00?o0000ol>P]?o3X;@01?o3
X;@3o`0000Go`j2d00?o0000ol>S^?l000004?o3X;@2o`0000oo`j2d00Go0000olBM/Oo4WK7oa9fa
o`00000;ol>P]003o`000?o4WK7oa9fa00Coa9fa00?o0000ol>P]?o3X;@01_o3X;@00ol0003oa9fa
olBM/@07olBM/@03o`000?o3X;Co`j2d00?o`j2d00?o0000olBM/Oo4WK402oo4WK400ol0003oa:2d
o`00000?olBM/@;o00003_o4WK401Ol0003oa9^^olBK[_o4Vjko000000[oa9fa00?o0000olBK[_o4
Vjh01?o4Vjh00ol0003oa9faolBM/@05olBM/ASo00002?mYc?d00ol0003oUM;moiGBo@0<oiGBo@03
o`000?n/c?7o[<ca00Go[<ca1?l00002oiCBo@03o`000?n/c?7o[<ca00co[<ca00?o0000ojc<lOl0
00000_n[>S000ol0003oY2`Noj@/7P05oj@/7P;o00002?n[>S000ol0003oY2`Oo`00000:oj/j<006
o`000?oooooo0000o`000?oooooo00004oooool0013ooooo00?o0000ooooooooool07?ooool00ol0
003o`j2dol>P]003o`0000Oo`j2d00Co0000ol>S^?o3XkSo00004?o3X;@00ol0003o`j2dol>P]00>
ol>P]005o`000?o4WK7oa9faolBM/Ol000002oo3X;@00ol0003oa9faolBM/@04olBM/@03o`000?o3
X;Co`j2d00Ko`j2d00?o0000olBM/Oo4WK401oo4WK400ol0003o`j2dol>P]003ol>P]003o`000?o4
WK7oa9fa00[oa9fa00Co0000olBP]?o4X;Co00003oo4WK400ol0003oa9faolBM/@0=olBM/@04o`00
0?o4Vjkoa9^^o`0000_oa9fa00?o0000olBK[_o4Vjh00oo4Vjh00ol0003oa9faolBM/@07olBM/@03
o`000?o4Vjkoa9^^00;oa9^^1Ol00009ob:[g003o`000?mYc?goJLcm00[oJLcm00?o0000oiGBoOnE
d_d03?nEd_d00ol0003o[<caojc<l@04o`0000OoU=;m00?o0000ojc<lOn/c?403?n/c?43o`000003
oj/j<?l0003oY2`N00SoY2`N00?o0000oj/j<?n[>S001?n[>S001?l0003oY2`Ooj@/7onT;1l2o`00
00WoZcX`0ol000000ooooooo0000ooooo`0Booooo`004?ooool00ol0003oooooooooo`0Looooo`?o
00002Oo3X;@00ol0003o`j>hol>S^002ol>S^003o`000?o3X;Co`j2d00go`j2d00?o0000ol>P]?o3
X;@03_o3X;@01?l0003oa9faolBM/Ol0000<ol>P]003o`000?o4WK7oa9fa00?oa9fa00?o0000ol>P
]?o3X;@01oo3X;@00ol0003oa9faolBM/@06olBM/@03o`000?o3X;Co`j2d00Co`j2d00?o0000olBM
/Oo4WK402Oo4WK401Ol0003oa:2dolBP]?o4X;Co000000ooa9fa00?o0000olBM/Oo4WK403Oo4WK40
1?l0003oa9^^olBK[_l0000;olBM/@03o`000?o4Vjkoa9^^00?oa9^^00?o0000olBM/Oo4WK401oo4
WK400ol0003oa9^^olBK[P05olBK[PKo00001_lRZm`00ol0003oJLcmofW<o@0:ofW<o@03o`000?nE
d_goUM;m00WoUM;m1Ol0000<oiCBo@03o`000?n/c?7o[<ca00co[<ca1?l0000:oj@/7P03o`000?n[
>S3oZcX`00?oZcX`00?o0000oj@/7onT;1l00onT;1l00ol0003oZcX`oj/j<007oj/j<004o`000?oo
ooooooooo`0001?ooooo000@ooooo`03o`000?oooooooooo01Wooooo0ol000000ooooooo0000ol>P
]008ol>P]003o`000?o3XkSo`j>h00?o`j>h00?o0000ol>P]?o3X;@03?o3X;@00ol0003o`j>ho`00
000@ol>P]0;o00003_o3X;@01Ol0003oa9faolBM/Oo4WK7o000000_o`j2d00?o0000olBM/Oo4WK40
1?o4WK400ol0003o`j2dol>P]006ol>P]003o`000?o4WK7oa9fa00Ooa9fa00?o0000olBP]?o4X;@0
0oo4X;@00ol0003oa9faolBM/@0;olBM/@03o`000?o4X;Co000000ooa9fa0_l0000=olBM/@05o`00
0?o4Vjkoa9^^olBK[_l000002_o4WK400ol0003oa9^^olBK[P04olBK[P03o`000?o4WK7oa9fa00Co
a9fa1_l000000olRZmco0000ofW<o@0;ofW<o@04o`000?nEd_goUM;moiGBo@Oo00001?mXc?d00ol0
003oU=;moiCBo@0;oiCBo@03o`000?n/c?7o[<ca00_o[<ca0ol000000onI60Ko0000o`000009oj@/
7P;o00000_n[>S000ol0003oY2`Ooj@/7`05oj@/7`;o00001on[>S001?l0003oooooooooool0000C
ooooo`004?ooool00ol0003oooooooooo`0Fooooo`?o00001?ooool00ol0003o`j2dol>P]006ol>P
]003o`000?o3XkSo`j>h00Co`j>h00?o0000ol>P]?o3X;@02oo3X;@01?l0003o`j>hol>S^?l0000@
ol>P]003o`000?o3X;Co`j2d00go`j2d00Go0000olBM/Oo4WK7oa9fao`00000;ol>P]003o`000?o4
WK7oa9fa00?oa9fa00?o0000ol>P]?o3X;@01oo3X;@00ol0003oa9faolBM/@07olBM/@03o`000?o4
X;Coa:2d00?oa:2d00?o0000olBM/Oo4WK402_o4WK401?l0003oa:2dolBP]?l0000?olBM/@03o`00
0?o4WK7oa9fa00coa9fa00Co0000olBK[_o4Vjko00002oo4WK400ol0003oa9^^olBK[P03olBK[P03
o`000?o4WK7oa9fa00Ooa9fa00Co0000olBK[_o4Vjkoa9^^4_l0000<ofS<o@03o`000?nDd_goU=;m
00_oU=;m00?o0000ojc<lOn/c?401On/c?45o`000003oiCBoOl0003o000000?oVAP60_l00009oj@/
7P03o`000?n[>S3o000000WoY2`O00?o0000oj/j<?n[>S000on[>S000ol0003oooooooooo`02oooo
o`03o`000?oooooooooo013ooooo000@ooooo`;o00005?ooool3o`0000Oooooo00?o0000ol>P]?o3
X;@01Oo3X;@00ol0003o`j>hol>S^006ol>S^003o`000?o3X;Co`j2d00Wo`j2d00Go0000ol>S^?o3
XkSo`j>ho`00000@ol>P]003o`000?o3X;Co`j2d00go`j2d00Co0000olBM/Oo4WK7o00003?o3X;@0
0ol0003oa9faolBM/@03olBM/@03o`000?o3X;Co`j2d00Oo`j2d00?o0000olBM/Oo4WK401_o4WK40
0ol0003oa:2dolBP]004olBP]003o`000?o4WK7oa9fa00Woa9fa00Go0000olBP]?o4X;Coa:2do`00
000?olBM/@03o`000?o4WK7oa9fa00coa9fa00Co0000olBK[_o4Vjko00003?o4WK400ol0003oa9^^
olBK[P02olBK[P03o`000?o4WK7oa9fa00Ooa9fa00?o0000olBK[_o4Vjh01Oo4Vjh00ol0003oa9fa
o`000005o`0000Go8J[L0_l0000<ofS<o@03o`000?nDd_goU=;m00_oU=;m00?o0000ojc<lOn/c?40
1?l00007oiCBo@;o00001?nI60H2o`0000SoY2`N0_l0000:oj@/7`03o`000?n[>S3oZcX`00;oZcX`
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`003oooool00ol0003ooooooooo
o`0Booooo`;o00002oooool00ol0003o`j2dol>P]004ol>P]003o`000?o3XkSo`j>h00Ko`j>h00?o
0000ol>P]?o3X;@02?o3X;@00ol0003o`j>hol>S^003ol>S^003o`000?o3X;Co`j2d00co`j2d00?o
0000ol>S^?l000003oo3X;@2o`0000ko`j2d00Go0000olBM/Oo4WK7oa9fao`00000;ol>P]003o`00
0?o4WK7oa9fa00Coa9fa00?o0000olBP]?o4X;@01_o4X;@00ol0003oa9faolBM/@07olBM/@03o`00
0?o4X;Coa:2d00?oa:2d00?o0000olBM/Oo4WK402oo4WK42o`0000ooa9fa0_l0000=olBM/@05o`00
0?o4Vjkoa9^^olBK[_l000002_o4WK400ol0003oa9^^olBK[P04olBK[P03o`000?o4WK7oa9fa00Go
a9fa1ol000000olQZ]co0000ofS<o@0;ofS<o@03o`000?nDd_goU=;m00GoU=;m2?l0000<oiCBo@;o
00001OnI60H00ol0003oY2`Noj@/7P05oj@/7P04o`000?nI60Ko0000o`0000WoY2`O0_l00002oj/j
<003o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool000oooooo00?o0000oooooooo
ool03oooool3o`0000gooooo00?o0000ol>P]?o3X;@00oo3X;@00ol0003o`j>hol>S^008ol>S^003
o`000?o3X;Co`j2d00Ko`j2d00?o0000ol>S^?o3XkP01?o3XkP00ol0003o`j2dol>P]00;ol>P]004
o`000?o3XkSo`j>ho`0000oo`j2d00?o0000ol>P]?o3X;@03Oo3X;@01?l0003oa9faolBM/Ol0000<
ol>P]003o`000?o4WK7oa9fa00?oa9fa00?o0000olBP]?o4X;@01oo4X;@00ol0003oa9faolBM/@07
olBM/@03o`000?o4X;Coa:2d00?oa:2d00?o0000olBM/Oo4WK402_o4WK401?l0003oa:2dolBP]?l0
000>olBM/@03o`000?o4WK7oa9fa00coa9fa00Co0000olBK[_o4Vjko00002oo4WK400ol0003oa9^^
olBK[P03olBK[P03o`000?o4WK7oa9fa00Ooa9fa00?o0000olBK[_o4Vjh00oo4VjhFo`0000SoIlcl
00?o0000oiCBoOnDd_d02OnDd_d00ol0003oU=;mo`000005oiTH1P;o00001?nT;1h00ol0003oVAP6
oiTH1P02oiTH1P;o00002OnT;1l2o`0000Gooooo00?o0000ooooooooool04?ooool000oooooo00?o
0000ooooooooool03?ooool3o`00017ooooo00Go0000ol>P]?o3X;Co`j2do`00000;ol>S^003o`00
0?o3X;Co`j2d00Go`j2d00?o0000ol>S^?o3XkP01Oo3XkP00ol0003o`j2dol>P]00:ol>P]005o`00
0?o3XkSo`j>hol>S^?l000003oo3X;@00ol0003o`j2dol>P]00=ol>P]003o`000?o4WK7o000000go
`j2d00?o0000olBM/Oo4WK400oo4WK400ol0003oa:2dolBP]007olBP]003o`000?o4WK7oa9fa00Ko
a9fa00?o0000olBP]?o4X;@01?o4X;@00ol0003oa9faolBM/@09olBM/@05o`000?o4X;Coa:2dolBP
]?l000003_o4WK400ol0003oa9faolBM/@0<olBM/@04o`000?o4Vjkoa9^^o`0000coa9fa00?o0000
olBK[_o4Vjh00_o4Vjh00ol0003oa9faolBM/@07olBM/@03o`000?o4Vjkoa9^^00Coa9^^00?o0000
olBM/Oo4WK400_o4WK45o`0000Ko8:WK0_l0000<ofO<o003o`000?nDd_goU=;m00WoU=;m00?o0000
oiCBoOl000001_nI60H2o`000003oj@/7_l0003oVAP600KoVAP60_l00008oj@/7`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04?ooool000oooooo00?o0000ooooooooool02Oooool3o`00
01Cooooo00Co0000ol>P]?o3X;Co00003Oo3XkP00ol0003o`j2dol>P]004ol>P]003o`000?o3XkSo
`j>h00Ko`j>h00?o0000ol>P]?o3X;@02?o3X;@00ol0003o`j>hol>S^003ol>S^003o`000?o3X;Co
`j2d00_o`j2d00?o0000ol>S^?l000003oo3X;@00ol0003o`j2dol>P]00=ol>P]005o`000?o4WK7o
a9faolBM/Ol000002oo4X;@00ol0003oa9faolBM/@04olBM/@03o`000?o4X;Coa:2d00Koa:2d00?o
0000olBM/Oo4WK401oo4WK400ol0003oa:2dolBP]002olBP]003o`000?o4WK7oa9fa00_oa9fa00?o
0000olBP]?l000003_o4WK42o`0000goa9fa00Go0000olBK[_o4Vjkoa9^^o`00000:olBM/@03o`00
0?o4Vjkoa9^^00?oa9^^00?o0000olBM/Oo4WK401_o4WK400ol0003oa9^^o`000006o`000003ob2Y
fol0003oIlcl00_oIlcl00?o0000oiCBoOnDd_d01OnDd_d8o`0000GoVAP60ol00009oiTH1P03o`00
0?nT;1ooY2`O00GoY2`O00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`003ooo
ool3o`0000Kooooo0ol0000Gooooo`03o`000?o3X;Co000000ko`j>h00?o0000ol>P]?o3X;@00oo3
X;@00ol0003o`j>hol>S^007ol>S^003o`000?o3X;Co`j2d00Oo`j2d00?o0000ol>S^?o3XkP01?o3
XkP00ol0003o`j2dol>P]00:ol>P]004o`000?o3XkSo`j>ho`0000oo`j2d00?o0000ol>P]?o3X;@0
3Oo3X;@01?l0003oa9faolBM/Ol0000<olBP]003o`000?o4WK7oa9fa00?oa9fa00?o0000olBP]?o4
X;@01oo4X;@00ol0003oa9faolBM/@07olBM/@03o`000?o4X;Coa:2d00?oa:2d00?o0000olBM/Oo4
WK402Oo4WK401?l0003oa:2dolBP]?l0000>olBM/@03o`000?o4WK7oa9fa00coa9fa00Co0000olBK
[_o4Vjko00002oo4WK400ol0003oa9^^olBK[P03olBK[P03o`000?o4WK7oa9fa00Koa9fa00?o0000
olBK[_o4Vjh01_o4VjhFo`0000GoIlcl00Co0000ofO<o?mWc?co00000onI60H01?l0003oQ`00ohL0
0?n70002o`0000SoVAP60_l00004oj@/7`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4?ooool000oooooo00?o0000ooooooooool00oooool3o`0001_ooooo00?o0000ol>S^?o3XkP03Oo3
XkP00ol0003o`j2dol>P]002ol>P]003o`000?o3XkSo`j>h00Wo`j>h00?o0000ol>P]?o3X;@01Oo3
X;@00ol0003o`j>hol>S^005ol>S^003o`000?o3X;Co`j2d00Wo`j2d00Go0000ol>S^?o3XkSo`j>h
o`00000>ol>P]003o`000?o3XkSo000000ko`j2d00?o0000olBM/Ol000003Oo4X;@00ol0003oa9fa
olBM/@03olBM/@03o`000?o4X;Coa:2d00Ooa:2d00?o0000olBM/Oo4WK401_o4WK400ol0003oa:2d
olBP]004olBP]003o`000?o4WK7oa9fa00Soa9fa00Go0000olBP]?o4X;Coa:2do`00000>olBM/@03
o`000?o4WK7oa9fa00coa9fa00Co0000olBK[_o4Vjko00003?o4WK401Ol0003oa9^^olBK[_o4Vjko
000000[oa9fa00?o0000olBK[_o4Vjh01?o4Vjh00ol0003oa9faolBM/@04olBM/@Go00001_lOZ=X2
o`0000SoIlcl00Oo0000ofO<o?mWc?coIlclo`000?nI60Ko000000KoQ`000_l00008oiTH1P;o0000
00?oY2`Oo`000?ooool01oooool00ol0003oooooooooo`0?ooooo`001Oooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Cooooo00Co0000oooooooooooooooo0ol0000Nooooo`03o`000?o3XkSo`j>h00ko
`j>h00Co0000ol>P]?o3X;Co00003?o3XkP00ol0003o`j2dol>P]004ol>P]003o`000?o3XkSo`j>h
00Oo`j>h00?o0000ol>P]?o3X;@01oo3X;@00ol0003o`j>hol>S^003ol>S^003o`000?o3X;Co`j2d
00[o`j2d00Co0000ol>S^?o3XkSo00003oo3X;@00ol0003oa:2dolBP]00=olBP]005o`000?o4WK7o
a9faolBM/Ol000002oo4X;@00ol0003oa9faolBM/@04olBM/@03o`000?o4X;Coa:2d00Goa:2d00?o
0000olBM/Oo4WK401oo4WK400ol0003oa:2dolBP]003olBP]003o`000?o4WK7oa9fa00[oa9fa00?o
0000olBP]?l000003_o4WK42o`0000goa9fa00Co0000olBK[_o4Vjko00002oo4WK400ol0003oa9^^
olBK[P03olBK[P03o`000?o4WK7oa9fa00Koa9fa00Co0000olBK[_o4Vjkoa9^^1ol000000olOZ=[o
0000ofO<o007ofO<o004o`000?mWc?coIlclofO<o0;o00002?n70003o`0000OoVAP600?o0000oooo
ooooool01oooool00ol0003oooooooooo`0?ooooo`002?ooool00omgMgOo<S8booooo`03ooooo`Co
00008_ooool00ol0003o`j>hol>S^00=ol>S^003o`000?o3X;Co000000go`j>h00?o0000ol>P]?o3
X;@00oo3X;@00ol0003o`j>hol>S^008ol>S^003o`000?o3X;Co`j2d00Ko`j2d00?o0000ol>S^?o3
XkP01?o3XkP00ol0003o`j2dol>P]009ol>P]005o`000?o3XkSo`j>hol>S^?l000003oo3X;@00ol0
003oa:2dolBP]00=olBP]004o`000?o4WK7oa9fao`0000coa:2d00?o0000olBM/Oo4WK400oo4WK40
0ol0003oa:2dolBP]007olBP]003o`000?o4WK7oa9fa00Koa9fa00?o0000olBP]?o4X;@00oo4X;@0
0ol0003oa9faolBM/@09olBM/@04o`000?o4X;Coa:2do`0000koa9fa00?o0000olBM/Oo4WK403?o4
WK401?l0003oa9^^olBK[_l0000;olBM/@03o`000?o4Vjkoa9^^00?oa9^^00?o0000olBM/Oo4WK40
1_o4WK400ol0003oa9^^olBK[P06olBK[P03o`000?o4WK7o000001;o00002?n70002o`0000CoVAP6
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`002Oooool00ol0003ooooooooo
o`02ooooo`;o00009?ooool00ol0003o`j>hol>S^00=ol>S^0;o00003oo3XkP01Ol0003o`j2dol>P
]?o3X;Co000000co`j>h00?o0000ol>P]?o3X;@01?o3X;@00ol0003o`j>hol>S^006ol>S^003o`00
0?o3X;Co`j2d00Oo`j2d00?o0000ol>S^?o3XkP00oo3XkP00ol0003o`j2dol>P]00;ol>P]003o`00
0?o3XkSo000000koa:2d00?o0000olBM/Ol000003Oo4X;@00ol0003oa9faolBM/@03olBM/@03o`00
0?o4X;Coa:2d00Ooa:2d00?o0000olBM/Oo4WK401Oo4WK400ol0003oa:2dolBP]004olBP]003o`00
0?o4WK7oa9fa00Soa9fa00Go0000olBP]?o4X;Coa:2do`00000>olBM/@03o`000?o4WK7oa9fa00go
a9fa0_l0000=olBM/@05o`000?o4Vjkoa9^^olBK[_l000002_o4WK400ol0003oa9^^olBK[P04olBK
[P03o`000?o4WK7oa9fa00Coa9fa1_l000000olNZ=Wo0000oajXf@04oajXf@03o`000?mW003o0000
00;o00001on70002o`000003oiTH1_l0003ooooo00[ooooo00?o0000ooooooooool03oooool000So
oooo00?oMgMgoc8b<_ooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?o3XkSo`j>h00_o
`j>h00?o0000ol>V_Ol000003oo3XkP01?l0003o`j2dol>P]?l0000=ol>S^003o`000?o3X;Co`j2d
00Co`j2d00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`j2dol>P]006ol>P]003o`000?o3XkSo`j>h
00Co`j>h00?o0000ol>P]?o3X;@02_o3X;@01?l0003o`j>hol>S^?l0000?olBP]003o`000?o4X;Co
a:2d00goa:2d00Go0000olBM/Oo4WK7oa9fao`00000:olBP]003o`000?o4WK7oa9fa00Coa9fa00?o
0000olBP]?o4X;@01_o4X;@00ol0003oa9faolBM/@07olBM/@03o`000?o4X;Coa:2d00;oa:2d00?o
0000olBM/Oo4WK402_o4WK400ol0003oa:2do`00000>olBM/@03o`000?o4WK7oa9fa00coa9fa00Co
0000olBK[_o4Vjko00002oo4WK400ol0003oa9^^olBK[P03olBK[P03o`000?o4WK7oa9fa00Goa9fa
00?o0000olBK[_o4Vjh00oo4Vjh7o`000003oajXfOl0003oI`0000;oI`000_l00006ohL000;o0000
3?ooool00ol0003oooooooooo`0?ooooo`001Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Oooooo
00?o0000ooooooooool08Oooool00ol0003o`j>hol>S^00:ol>S^005o`000?o3Y[go`jJmol>V_Ol0
00003_o3XkP00ol0003o`j2do`00000>ol>S^003o`000?o3X;Co`j2d00?o`j2d00?o0000ol>S^?o3
XkP01oo3XkP00ol0003o`j2dol>P]005ol>P]003o`000?o3XkSo`j>h00Go`j>h00?o0000ol>P]?o3
X;@02Oo3X;@01Ol0003o`j>hol>S^?o3XkSo000000ooa:2d00?o0000olBP]?o4X;@03Oo4X;@01?l0
003oa9faolBM/Ol0000;olBP]003o`000?o4WK7oa9fa00?oa9fa00?o0000olBP]?o4X;@01oo4X;@0
0ol0003oa9faolBM/@06olBM/@03o`000?o4X;Coa:2d00?oa:2d00?o0000olBM/Oo4WK402Oo4WK40
1?l0003oa:2dolBP]?l0000>olBM/@03o`000?o4WK7oa9fa00coa9fa00Co0000olBK[_o4Vjko0000
2oo4WK400ol0003oa9^^olBK[P03olBK[P03o`000?o4WK7oa9fa00Koa9fa00?o0000olBK[_o4Vjh0
1Oo4Vjh01?l0003oa9faolBM/Oo4WK45o`0000;oI`000ol000000on7003o0000o`00000>ooooo`03
o`000?oooooooooo00oooooo0005ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
8?ooool00ol0003o`j>hol>S^009ol>S^003o`000?o3Y[go`jJm00;o`jJm00?o0000ol>S^?o3XkP0
3Oo3XkP00ol0003o`j>hol>S^00>ol>S^005o`000?o3X;Co`j2dol>P]?l000002oo3XkP00ol0003o
`j2dol>P]004ol>P]003o`000?o3XkSo`j>h00Ko`j>h00?o0000ol>P]?o3X;@01oo3X;@00ol0003o
`j>hol>S^003ol>S^003o`000?o4X;Coa:2d00_oa:2d00?o0000ol>S^?l000003_o4X;@00ol0003o
a9fao`00000=olBP]003o`000?o4WK7oa9fa00;oa9fa00?o0000olBP]?o4X;@01oo4X;@00ol0003o
a9faolBM/@05olBM/@03o`000?o4X;Coa:2d00Coa:2d00?o0000olBM/Oo4WK402?o4WK401Ol0003o
a:2dolBP]?o4X;Co000000goa9fa00?o0000olBP]?l000003_o4WK42o`0000goa9fa00Go0000olBK
[_o4Vjkoa9^^o`000009olBM/@03o`000?o4Vjkoa9^^00Coa9^^00?o0000olBM/Ol000001Oo4WK40
0ol0003oa9^^o`000005o`000003olBK[_l0003ooooo00gooooo00?o0000ooooooooool03oooool0
00Gooooo00?o0000ooooooooool02oooool2o`00027ooooo00?o0000ol>S^?o3XkP01oo3XkP00ol0
003o`jJmol>V_@04ol>V_@03o`000?o3XkSo`j>h00_o`j>h0_l0000@ol>S^004o`000?o3X;Co`j2d
o`0000co`j>h00?o0000ol>P]?o3X;@00oo3X;@00ol0003o`j>hol>S^007ol>S^003o`000?o3X;Co
`j2d00Ko`j2d00?o0000ol>S^?o3XkP01?o3XkP00ol0003oa:2dolBP]00:olBP]004o`000?o3XkSo
`j>ho`0000ooa:2d00?o0000olBP]?o4X;@03?o4X;@01Ol0003oa9faolBM/Oo4WK7o000000_oa:2d
00?o0000olBM/Oo4WK401?o4WK400ol0003oa:2dolBP]005olBP]003o`000?o4WK7oa9fa00Ooa9fa
00?o0000olBP]?o4X;@00_o4X;@00ol0003oa9faolBM/@09olBM/@04o`000?o4X;Coa:2do`0000ko
a9fa00?o0000olBM/Oo4WK403?o4WK401?l0003oa9^^olBK[_l0000:olBM/@03o`000?o4Vjkoa9^^
00?oa9^^00Co0000olBM/Oo4WK7o00001Oo4WK400ol0003oa9^^olBK[P05olBK[P03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03_ooool000Gooooo1?l0000<ooooo`03o`000?oooooooooo
01kooooo00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`jJmol>V_@05ol>V_@03o`000?o3XkSo`j>h
00[o`j>h00Co0000ol>V_Oo3Y[go00003oo3XkP00ol0003o`j2do`00000>ol>S^005o`000?o3X;Co
`j2dol>P]?l000002oo3XkP00ol0003o`j2dol>P]004ol>P]003o`000?o3XkSo`j>h00Go`j>h00?o
0000olBP]?o4X;@02Oo4X;@01Ol0003o`j>hol>S^?o3XkSo000000ooa:2d00?o0000olBP]?o4X;@0
3?o4X;@01?l0003oa9faolBM/Ol0000<olBP]003o`000?o4WK7oa9fa00?oa9fa00?o0000olBP]?o4
X;@01_o4X;@00ol0003oa9faolBM/@06olBM/@03o`000?o4X;Coa:2d00?oa:2d00?o0000olBM/Oo4
WK402?o4WK401Ol0003oa:2dolBP]?o4X;Co000000koa9fa00?o0000olBM/Oo4WK403?o4WK401?l0
003oa9^^olBK[_l0000:olBM/@03o`000?o4Vjkoa9^^00?oa9^^00Go0000olBM/Oo4WK7oa9fao`00
0004olBM/@03o`000?o4Vjkoa9^^00Coa9^^00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0>ooooo`005_ooool00ol0003oooooooooo`0Nooooo`03o`000?o3XkSo`j>h00Co`j>h00?o0000
ol>V_Oo3Y[d01_o3Y[d00ol0003o`j>hol>S^009ol>S^005o`000?o3Y[go`jJmol>V_Ol000004?o3
XkP00ol0003o`j>hol>S^00=ol>S^004o`000?o3X;Co`j2do`0000co`j>h00?o0000ol>P]?o3X;@0
1?o3X;@00ol0003o`j>hol>S^006ol>S^003o`000?o4X;Coa:2d00Ooa:2d00?o0000ol>S^?o3XkP0
0oo3XkP00ol0003oa:2dolBP]00;olBP]003o`000?o3XkSo000000koa:2d0_l0000=olBP]003o`00
0?o4WK7oa9fa00;oa9fa00?o0000olBP]?o4X;@01oo4X;@00ol0003oa9faolBM/@05olBM/@03o`00
0?o4X;Coa:2d00Coa:2d00?o0000olBM/Oo4WK402?o4WK400ol0003oa:2dolBP]002olBP]003o`00
0?o4WK7oa9fa00[oa9fa00?o0000olBP]?l000003_o4WK42o`0000coa9fa00Go0000olBK[_o4Vjko
a9^^o`000005olBM/@03o`000?o4WK7oa9fa00;oa9fa00?o0000olBK[_o4Vjh00oo4Vjh00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00kooooo000Gooooo`03o`000?oooooooooo01gooooo
00?o0000ol>S^?o3XkP00oo3XkP00ol0003o`jJmol>V_@08ol>V_@03o`000?o3XkSo`j>h00Oo`j>h
00?o0000ol>V_Oo3Y[d00oo3Y[d00ol0003o`j>hol>S^00<ol>S^0;o00003oo3XkP00ol0003o`j2d
o`00000=ol>S^003o`000?o3X;Co`j2d00?o`j2d00?o0000ol>S^?o3XkP01oo3XkP00ol0003oa:2d
olBP]006olBP]003o`000?o3XkSo`j>h00Co`j>h00?o0000olBP]?o4X;@02_o4X;@01?l0003o`j>h
ol>S^?l0000>olBP]003o`000?o4X;Coa:2d00goa:2d00Co0000olBM/Oo4WK7o00002oo4X;@00ol0
003oa9faolBM/@04olBM/@03o`000?o4X;Coa:2d00Goa:2d00?o0000olBM/Oo4WK401_o4WK400ol0
003oa:2dolBP]003olBP]003o`000?o4WK7oa9fa00Woa9fa00Co0000olBP]?o4X;Co00003_o4WK40
0ol0003oa9faolBM/@0;olBM/@04o`000?o4Vjkoa9^^o`0000Ooa9fa00Go0000olBM/Oo4WK7oa9fa
o`000004olBK[P03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool001Sooooo0_l0
000Nooooo`05o`000?o3XkSo`j>hol>S^?l000002oo3Y[d00ol0003o`j>hol>S^006ol>S^003o`00
0?o3Y[go`jJm00Co`jJm00?o0000ol>S^?o3XkP02oo3XkP01?l0003o`jJmol>V_Ol0000?ol>S^003
o`000?o3XkSo`j>h00go`j>h00Go0000ol>P]?o3X;Co`j2do`00000;ol>S^003o`000?o4X;Coa:2d
00Coa:2d00?o0000ol>S^?o3XkP01Oo3XkP00ol0003oa:2dolBP]009olBP]005o`000?o3XkSo`j>h
ol>S^?l000003_o4X;@00ol0003oa:2dolBP]00=olBP]004o`000?o4WK7oa9fao`0000_oa:2d00?o
0000olBM/Oo4WK400oo4WK400ol0003oa:2dolBP]006olBP]003o`000?o4WK7oa9fa00Goa9fa00?o
0000olBP]?o4X;@01?o4X;@00ol0003oa9faolBM/@08olBM/@05o`000?o4X;Coa:2dolBP]?l00000
3_o4WK400ol0003oa9faolBM/@0;olBM/@04o`000?o4Vjkoa9^^o`0000Ooa9fa00Go0000olBM/Oo4
WK7oa9fao`000004olBK[P03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool001[o
oooo00?o0000ooooooooool06oooool01?l0003o`j>hol>S^?l0000=ol>V_@03o`000?o3XkSo`j>h
00Co`j>h00?o0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`j>hol>S^009ol>S^005o`000?o3Y[go`jJm
ol>V_Ol000003oo3XkP00ol0003o`j>hol>S^00=ol>S^004o`000?o3X;Co`j2do`0000co`j>h00?o
0000olBP]?o4X;@01?o4X;@00ol0003o`j>hol>S^006ol>S^003o`000?o4X;Coa:2d00Ooa:2d00?o
0000ol>S^?o3XkP00oo3XkP00ol0003oa:2dolBP]00:olBP]003o`000?o3XkSo000000koa:2d00?o
0000olBM/Ol000003?o4X;@00ol0003oa9faolBM/@02olBM/@03o`000?o4X;Coa:2d00Soa:2d00?o
0000olBM/Oo4WK401?o4WK400ol0003oa:2dolBP]005olBP]003o`000?o4WK7oa9fa00Ooa9fa00?o
0000olBP]?o4X;@00_o4X;@00ol0003oa9faolBM/@0:olBM/@;o00003_o4WK42o`0000Woa9fa00Go
0000olBM/Oo4WK7oa9fao`000002olBK[P03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3_ooool001_ooooo00?o0000ooooooooool06_ooool00ol0003o`j>ho`00000>ol>V_@03o`000?o3
XkSo`j>h00?o`j>h00?o0000ol>V_Oo3Y[d01oo3Y[d00ol0003o`j>hol>S^008ol>S^003o`000?o3
Y[go`jJm00?o`jJm00?o0000ol>S^?o3XkP02oo3XkP00ol0003o`jJmo`00000>ol>S^003o`000?o3
X;Co000000go`j>h00?o0000olBP]?o4X;@00oo4X;@00ol0003o`j>hol>S^007ol>S^003o`000?o4
X;Coa:2d00Koa:2d00?o0000ol>S^?o3XkP01?o3XkP00ol0003oa:2dolBP]009olBP]004o`000?o3
XkSo`j>ho`0000ooa:2d00?o0000olBP]?o4X;@03?o4X;@01?l0003oa9faolBM/Ol0000;olBP]003
o`000?o4WK7oa9fa00?oa9fa00?o0000olBP]?o4X;@01_o4X;@00ol0003oa9faolBM/@06olBM/@03
o`000?o4X;Coa:2d00?oa:2d00?o0000olBM/Oo4WK402Oo4WK401?l0003oa:2dolBP]?l0000=olBM
/@03o`000?o4WK7oa9fa00Woa9fa00Ko0000olBM/Oo4WK7o0000olBK[_l0000Dooooo`03o`000?oo
oooooooo00kooooo000Looooo`03o`000?oooooooooo01[ooooo00?o0000ol>V_Oo3Y[d03_o3Y[d0
1Ol0003o`j>hol>S^?o3XkSo000000_o`jJm00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`jJmol>V
_@04ol>V_@03o`000?o3XkSo`j>h00[o`j>h00Co0000ol>V_Oo3Y[go00003oo3XkP00ol0003o`j>h
ol>S^00=ol>S^005o`000?o4X;Coa:2dolBP]?l000002oo3XkP00ol0003oa:2dolBP]004olBP]003
o`000?o3XkSo`j>h00Go`j>h00?o0000olBP]?o4X;@02?o4X;@01Ol0003o`j>hol>S^?o3XkSo0000
00ooa:2d00?o0000olBP]?o4X;@03?o4X;@01?l0003oa9faolBM/Ol0000;olBP]003o`000?o4WK7o
a9fa00;oa9fa00?o0000olBP]?o4X;@01oo4X;@00ol0003oa9faolBM/@05olBM/@03o`000?o4X;Co
a:2d00Coa:2d00?o0000olBM/Oo4WK402?o4WK401Ol0003oa:2dolBP]?o4X;Co000000goa9fa00?o
0000olBM/Oo4WK402_o4WK401Ol0003oa9fao`000?o4Vjko000001Gooooo00?o0000ooooooooool0
3Oooool001gooooo0_l0000Jooooo`03o`000?o3Y[go`jJm00ko`jJm00Co0000ol>S^?o3XkSo0000
3?o3Y[d00ol0003o`j>hol>S^005ol>S^003o`000?o3Y[go`jJm00Go`jJm00?o0000ol>S^?o3XkP0
2Oo3XkP01Ol0003o`jJmol>V_Oo3Y[go000000oo`j>h00?o0000ol>S^?o3XkP03Oo3XkP01?l0003o
a:2dolBP]?l0000<ol>S^003o`000?o4X;Coa:2d00Coa:2d00?o0000ol>S^?o3XkP01_o3XkP00ol0
003oa:2dolBP]007olBP]003o`000?o3XkSo`j>h00;o`j>h00?o0000olBP]?o4X;@02oo4X;@00ol0
003o`j>ho`00000=olBP]003o`000?o4WK7o000000goa:2d00Co0000olBM/Oo4WK7o00002oo4X;@0
0ol0003oa9faolBM/@04olBM/@03o`000?o4X;Coa:2d00Goa:2d00?o0000olBM/Oo4WK401oo4WK40
1Ol0003oa:2dolBP]?o4X;Co000000coa9fa00?o0000olBP]?l000002oo4WK401?l0003oa9faolBM
/Ol0000Fooooo`03o`000?oooooooooo00gooooo000Oooooo`03o`000?oooooooooo01Sooooo00?o
0000ol>V_Oo3Y[d03Oo3Y[d00ol0003o`j>ho`00000>ol>V_@03o`000?o3XkSo`j>h00?o`j>h00?o
0000ol>V_Oo3Y[d01oo3Y[d00ol0003o`j>hol>S^007ol>S^003o`000?o3Y[go`jJm00?o`jJm00?o
0000ol>S^?o3XkP02oo3XkP00ol0003o`jJmo`00000>ol>S^003o`000?o4X;Co000000go`j>h00?o
0000olBP]?o4X;@00oo4X;@00ol0003o`j>hol>S^007ol>S^003o`000?o4X;Coa:2d00Koa:2d00?o
0000ol>S^?o3XkP00oo3XkP00ol0003oa:2dolBP]00:olBP]004o`000?o3XkSo`j>ho`0000koa:2d
00?o0000olBP]?o4X;@03?o4X;@01?l0003oa9faolBM/Ol0000;olBP]003o`000?o4WK7oa9fa00?o
a9fa00?o0000olBP]?o4X;@01_o4X;@00ol0003oa9faolBM/@06olBM/@03o`000?o4X;Coa:2d00?o
a:2d00?o0000olBM/Oo4WK402?o4WK401?l0003oa:2dolBP]?l0000<olBM/@03o`000?o4WK7o0000
01Kooooo00?o0000ooooooooool03Oooool0023ooooo00?o0000ooooooooool05oooool00ol0003o
`jJmol>V_@0=ol>V_@;o00003oo3Y[d00ol0003o`j>hol>S^002ol>S^003o`000?o3Y[go`jJm00So
`jJm00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`jJmol>V_@04ol>V_@03o`000?o3XkSo`j>h00[o
`j>h00Co0000ol>V_Oo3Y[go00003oo3XkP00ol0003o`j>hol>S^00=ol>S^005o`000?o4X;Coa:2d
olBP]?l000002oo3XkP00ol0003oa:2dolBP]004olBP]003o`000?o3XkSo`j>h00Go`j>h00?o0000
olBP]?o4X;@02?o4X;@01Ol0003o`j>hol>S^?o3XkSo000000koa:2d00?o0000olBP]?o4X;@03?o4
X;@00ol0003oa9fao`00000<olBP]003o`000?o4WK7oa9fa00;oa9fa00?o0000olBP]?o4X;@01oo4
X;@00ol0003oa9faolBM/@05olBM/@03o`000?o4X;Coa:2d00Coa:2d00?o0000olBM/Oo4WK401oo4
WK401Ol0003oa:2dolBP]?o4X;Co000000goa9fa00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0=ooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?o3Y[go`jJm00_o`jJm00?o
0000ol:[`ol000004?o3Y[d01?l0003o`j>hol>S^?l0000<ol>V_@03o`000?o3XkSo`j>h00Co`j>h
00?o0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`j>hol>S^008ol>S^005o`000?o3Y[go`jJmol>V_Ol0
00003oo3XkP00ol0003o`j>hol>S^00=ol>S^004o`000?o4X;Coa:2do`0000co`j>h00?o0000olBP
]?o4X;@00oo4X;@00ol0003o`j>hol>S^006ol>S^003o`000?o4X;Coa:2d00Ooa:2d00?o0000ol>S
^?o3XkP00oo3XkP00ol0003oa:2dolBP]00:olBP]003o`000?o3XkSo000000koa:2d00?o0000olBP
]?o4X;@03?o4X;@01?l0003oa9faolBM/Ol0000;olBP]003o`000?o4WK7oa9fa00Coa9fa00?o0000
olBP]?o4X;@01?o4X;@00ol0003oa9faolBM/@07olBM/@03o`000?o4X;Coa:2d00;oa:2d00?o0000
olBM/Oo4WK402Oo4WK42o`0001Oooooo00?o0000ooooooooool03Oooool002;ooooo0_l0000Goooo
o`03o`000?o3Y[go`jJm00[o`jJm00Go0000ol:[`oo2Zl?o`Z_3o`00000?ol>V_@03o`000?o3XkSo
000000go`jJm00?o0000ol>S^?o3XkP00oo3XkP00ol0003o`jJmol>V_@07ol>V_@03o`000?o3XkSo
`j>h00Oo`j>h00?o0000ol>V_Oo3Y[d00oo3Y[d00ol0003o`j>hol>S^00;ol>S^003o`000?o3Y[go
000000ko`j>h00?o0000olBP]?l000003Oo3XkP00ol0003oa:2dolBP]002olBP]003o`000?o3XkSo
`j>h00Oo`j>h00?o0000olBP]?o4X;@01_o4X;@00ol0003o`j>hol>S^004ol>S^003o`000?o4X;Co
a:2d00Woa:2d00Co0000ol>S^?o3XkSo00003_o4X;@00ol0003oa:2dolBP]00<olBP]004o`000?o4
WK7oa9fao`0000_oa:2d00?o0000olBM/Oo4WK400oo4WK400ol0003oa:2dolBP]006olBP]003o`00
0?o4WK7oa9fa00Goa9fa00?o0000olBP]?o4X;@00oo4X;@00ol0003oa9faolBM/@08olBM/@04o`00
0?ooooooooooo`0001Kooooo00?o0000ooooooooool03Oooool002Cooooo00?o0000ooooooooool0
5Oooool00ol0003o`jJmol>V_@08ol>V_@03o`000?o2Zl?o`Z_300;o`Z_300?o0000ol>V_Oo3Y[d0
3Oo3Y[d2o`0000oo`jJm00Go0000ol>S^?o3XkSo`j>ho`00000:ol>V_@03o`000?o3XkSo`j>h00Ko
`j>h00?o0000ol>V_Oo3Y[d01?o3Y[d00ol0003o`j>hol>S^00:ol>S^004o`000?o3Y[go`jJmo`00
00oo`j>h00?o0000ol>S^?o3XkP03Oo3XkP01Ol0003oa:2dolBP]?o4X;Co000000[o`j>h00?o0000
olBP]?o4X;@01?o4X;@00ol0003o`j>hol>S^005ol>S^003o`000?o4X;Coa:2d00Soa:2d00Go0000
ol>S^?o3XkSo`j>ho`00000=olBP]003o`000?o3XkSo000000goa:2d00?o0000olBM/Ol000003?o4
X;@00ol0003oa9faolBM/@02olBM/@03o`000?o4X;Coa:2d00Ooa:2d00?o0000olBM/Oo4WK401?o4
WK400ol0003oa:2dolBP]004olBP]003o`000?o4WK7oa9fa00Soa9fa00Go0000oooooooooooooooo
o`00000Eooooo`03o`000?oooooooooo00gooooo000Uooooo`03o`000?oooooooooo01Gooooo00?o
0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`Z_3ol:[``04ol:[``03o`000?o3Y[go`jJm00_o`jJm00?o
0000ol:[`ol000003oo3Y[d01?l0003o`j>hol>S^?l0000<ol>V_@03o`000?o3XkSo`j>h00Co`j>h
00?o0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`j>hol>S^008ol>S^003o`000?o3Y[go`jJm00;o`jJm
00?o0000ol>S^?o3XkP02oo3XkP2o`0000oo`j>h00Co0000olBP]?o4X;Co00002oo3XkP00ol0003o
a:2dolBP]003olBP]003o`000?o3XkSo`j>h00Oo`j>h00?o0000olBP]?o4X;@01_o4X;@00ol0003o
`j>hol>S^003ol>S^003o`000?o4X;Coa:2d00Woa:2d00Co0000ol>S^?o3XkSo00003_o4X;@00ol0
003oa:2dolBP]00<olBP]004o`000?o4WK7oa9fao`0000[oa:2d00?o0000olBM/Oo4WK400oo4WK40
0ol0003oa:2dolBP]006olBP]003o`000?o4WK7oa9fa00Koa9fa00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo000Vooooo`03o`000?oooooooooo
01Cooooo00?o0000ol>V_Oo3Y[d01Oo3Y[d00ol0003o`Z_3ol:[``05ol:[``03o`000?o3Y[go`jJm
00[o`jJm00Go0000ol:[`oo2Zl?o`Z_3o`00000>ol>V_@03o`000?o3XkSo000000go`jJm00?o0000
ol>S^?o3XkP00oo3XkP00ol0003o`jJmol>V_@07ol>V_@03o`000?o3XkSo`j>h00Oo`j>h00?o0000
ol>V_Oo3Y[d00oo3Y[d00ol0003o`j>hol>S^00:ol>S^004o`000?o3Y[go`jJmo`0000ko`j>h00?o
0000olBP]?l000003Oo3XkP01Ol0003oa:2dolBP]?o4X;Co000000[o`j>h00?o0000olBP]?o4X;@0
1Oo4X;@00ol0003o`j>hol>S^004ol>S^003o`000?o4X;Coa:2d00Soa:2d00Go0000ol>S^?o3XkSo
`j>ho`00000>olBP]003o`000?o4X;Coa:2d00coa:2d00Co0000olBM/Oo4WK7o00002oo4X;@01Ol0
003oa9faolBM/Oo4WK7o000000Woa:2d00?o0000olBM/Oo4WK401Oo4WK400ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03?ooool002Oooooo0_l0000Eoooo
o`03o`000?o3Y[go`jJm00?o`jJm00?o0000ol:[`oo2Zl<01oo2Zl<00ol0003o`jJmol>V_@08ol>V
_@03o`000?o2Zl?o`Z_300;o`Z_300?o0000ol>V_Oo3Y[d03?o3Y[d2o`0000oo`jJm00Go0000ol>S
^?o3XkSo`j>ho`00000:ol>V_@03o`000?o3XkSo`j>h00Ko`j>h00?o0000ol>V_Oo3Y[d01?o3Y[d0
0ol0003o`j>hol>S^009ol>S^005o`000?o3Y[go`jJmol>V_Ol000003oo3XkP00ol0003o`j>hol>S
^00<ol>S^004o`000?o4X;Coa:2do`0000_o`j>h00?o0000olBP]?o4X;@01?o4X;@00ol0003o`j>h
ol>S^006ol>S^003o`000?o4X;Coa:2d00Ooa:2d00?o0000ol>S^?o3XkP00_o3XkP00ol0003oa:2d
olBP]00:olBP]003o`000?o3XkSo000000goa:2d00?o0000olBM/Ol000003?o4X;@01Ol0003oa9fa
olBM/Oo4WK7o000000[oa:2d00?o0000olBM/Oo4WK401?o4WK400ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool002Wooooo00?o0000ooooooooool0
4_ooool00ol0003o`jJmol>V_@02ol>V_@03o`000?o2Zl?o`Z_300Wo`Z_300?o0000ol>V_Oo3Y[d0
1_o3Y[d00ol0003o`Z_3ol:[``04ol:[``03o`000?o3Y[go`jJm00[o`jJm00?o0000ol:[`ol00000
3oo3Y[d01?l0003o`j>hol>S^?l0000<ol>V_@03o`000?o3XkSo`j>h00Co`j>h00?o0000ol>V_Oo3
Y[d01_o3Y[d00ol0003o`j>hol>S^007ol>S^003o`000?o3Y[go`jJm00?o`jJm00?o0000ol>S^?o3
XkP02oo3XkP2o`0000ko`j>h00?o0000olBP]?l000003Oo3XkP00ol0003oa:2dolBP]002olBP]003
o`000?o3XkSo`j>h00Oo`j>h00?o0000olBP]?o4X;@01_o4X;@00ol0003o`j>hol>S^003ol>S^003
o`000?o4X;Coa:2d00Woa:2d00Co0000ol>S^?o3XkSo00003_o4X;@00ol0003oa:2dolBP]00;olBP
]004o`000?o4WK7oa9fao`0000_oa:2d00?o0000olBM/Oo4WK400oo4WK400ol0003oooooooooo`07
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool002[ooooo00?o0000oooo
ooooool04_ooool01?l0003o`jJmol>V_Ol0000<ol:[``03o`000?o3Y[go`jJm00Go`jJm00?o0000
ol:[`oo2Zl<01Oo2Zl<00ol0003o`jJmol>V_@09ol>V_@05o`000?o2Zl?o`Z_3ol:[`ol000003_o3
Y[d00ol0003o`j>ho`00000=ol>V_@03o`000?o3XkSo`j>h00?o`j>h00?o0000ol>V_Oo3Y[d01oo3
Y[d00ol0003o`j>hol>S^006ol>S^003o`000?o3Y[go`jJm00Co`jJm00?o0000ol>S^?o3XkP02_o3
XkP01?l0003o`jJmol>V_Ol0000>ol>S^003o`000?o3XkSo`j>h00co`j>h00Go0000olBP]?o4X;Co
a:2do`00000:ol>S^003o`000?o4X;Coa:2d00Goa:2d00?o0000ol>S^?o3XkP01?o3XkP00ol0003o
a:2dolBP]008olBP]005o`000?o3XkSo`j>hol>S^?l000003_o4X;@00ol0003oa:2dolBP]00<olBP
]0;o00003?o4X;@00ol0003oa9faolBM/@02olBM/@03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0<ooooo`00:oooool00ol0003oooooooooo`0Aooooo`03
o`000?o3Y[go000000ko`Z_300?o0000ol>V_Oo3Y[d00oo3Y[d00ol0003o`Z_3ol:[``07ol:[``03
o`000?o3Y[go`jJm00Oo`jJm00?o0000ol:[`oo2Zl<00_o2Zl<00ol0003o`jJmol>V_@0<ol>V_@;o
00003oo3Y[d01Ol0003o`j>hol>S^?o3XkSo000000_o`jJm00?o0000ol>S^?o3XkP01?o3XkP00ol0
003o`jJmol>V_@05ol>V_@03o`000?o3XkSo`j>h00Wo`j>h00Go0000ol>V_Oo3Y[go`jJmo`00000>
ol>S^003o`000?o3XkSo`j>h00co`j>h00Co0000olBP]?o4X;Co00003?o3XkP00ol0003oa:2dolBP
]003olBP]003o`000?o3XkSo`j>h00Ko`j>h00?o0000olBP]?o4X;@01oo4X;@00ol0003o`j>hol>S
^002ol>S^003o`000?o4X;Coa:2d00[oa:2d00?o0000ol>S^?l000003Oo4X;@00ol0003oa:2dolBP
]00<olBP]004o`000?o4WK7oa9fao`0000cooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0<ooooo`00;?ooool2o`0001;ooooo00?o0000ol:[`oo2Zl<03Oo2Zl<00ol0003o`jJmol>V
_@02ol>V_@03o`000?o2Zl?o`Z_300So`Z_300?o0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`Z_3ol:[
``04ol:[``03o`000?o3Y[go`jJm00[o`jJm00?o0000ol:[`ol000003oo3Y[d01?l0003o`j>hol>S
^?l0000<ol>V_@03o`000?o3XkSo`j>h00?o`j>h00?o0000ol>V_Oo3Y[d01oo3Y[d00ol0003o`j>h
ol>S^007ol>S^003o`000?o3Y[go`jJm00;o`jJm00?o0000ol>S^?o3XkP02oo3XkP00ol0003o`jJm
o`00000>ol>S^0;o00003Oo3XkP00ol0003oa:2dolBP]002olBP]003o`000?o3XkSo`j>h00Oo`j>h
00?o0000olBP]?o4X;@01_o4X;@00ol0003o`j>hol>S^003ol>S^003o`000?o4X;Coa:2d00Woa:2d
00Co0000ol>S^?o3XkSo00003Oo4X;@00ol0003oa:2dolBP]00<olBP]004o`000?o4WK7oa9fao`00
00gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`00;_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?o2Zl?o`Z_300ko`Z_300Co0000ol>V_Oo3Y[go00002oo2Zl<00ol0
003o`jJmol>V_@05ol>V_@03o`000?o2Zl?o`Z_300Go`Z_300?o0000ol>V_Oo3Y[d02Oo3Y[d01Ol0
003o`Z_3ol:[`oo2Zl?o000000ko`jJm00?o0000ol>S^?l000003_o3Y[d01Ol0003o`j>hol>S^?o3
XkSo000000[o`jJm00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`jJmol>V_@04ol>V_@03o`000?o3
XkSo`j>h00Wo`j>h00Co0000ol>V_Oo3Y[go00003_o3XkP00ol0003o`j>hol>S^00=ol>S^005o`00
0?o4X;Coa:2dolBP]?l000002_o3XkP00ol0003oa:2dolBP]004olBP]003o`000?o3XkSo`j>h00Co
`j>h00?o0000olBP]?o4X;@02?o4X;@01Ol0003o`j>hol>S^?o3XkSo000000coa:2d00?o0000ol>S
^?l000003Oo4X;@00ol0003oa9fao`00000?ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool02oooool002oooooo00?o0000ooooooooool03oooool00ol0003o`Z_3ol:[``0=ol:[``03
o`000?o3Y[go000000go`Z_300?o0000ol>V_Oo3Y[d00oo3Y[d00ol0003o`Z_3ol:[``07ol:[``03
o`000?o3Y[go`jJm00Oo`jJm00?o0000ol:[`oo2Zl<00_o2Zl<00ol0003o`jJmol>V_@0=ol>V_@03
o`000?o3Y[go`jJm00go`jJm00Co0000ol>S^?o3XkSo00003?o3Y[d00ol0003o`j>hol>S^004ol>S
^003o`000?o3Y[go`jJm00Go`jJm00?o0000ol>S^?o3XkP02?o3XkP00ol0003o`jJmol>V_@02ol>V
_@03o`000?o3XkSo`j>h00_o`j>h00?o0000ol>S^?o3XkP03Oo3XkP01?l0003oa:2dolBP]?l0000;
ol>S^003o`000?o4X;Coa:2d00?oa:2d00?o0000ol>S^?o3XkP01_o3XkP00ol0003oa:2dolBP]006
olBP]003o`000?o3XkSo`j>h00?o`j>h00?o0000olBP]?o4X;@02?o4X;@01?l0003o`j>hol>S^?l0
000>olBP]003o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0;ooooo`00<?ooool00ol0003oooooooooo`0>ooooo`03o`000?o2Zl?o`Z_300go`Z_30_l0000>
ol:[``03o`000?o3Y[go`jJm00;o`jJm00?o0000ol:[`oo2Zl<02?o2Zl<00ol0003o`jJmol>V_@06
ol>V_@03o`000?o2Zl?o`Z_300Co`Z_300?o0000ol>V_Oo3Y[d02oo3Y[d2o`0000oo`jJm00?o0000
ol>S^?l000003Oo3Y[d00ol0003o`j>hol>S^003ol>S^003o`000?o3Y[go`jJm00Ko`jJm00?o0000
ol>S^?o3XkP01oo3XkP00ol0003o`jJmol>V_@03ol>V_@03o`000?o3XkSo`j>h00[o`j>h00?o0000
ol>V_Ol000003_o3XkP00ol0003oa:2do`00000<ol>S^003o`000?o4X;Coa:2d00;oa:2d00?o0000
ol>S^?o3XkP01oo3XkP00ol0003oa:2dolBP]005olBP]003o`000?o3XkSo`j>h00Co`j>h00?o0000
olBP]?o4X;@01oo4X;@01Ol0003o`j>hol>S^?o3XkSo000000koa:2d00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00_ooooo000aooooo`;o00003oooool0
0ol0003o`Z_3ol:[``0;ol:[``03o`000?o0/<[o000000oo`Z_300Co0000ol>V_Oo3Y[go00002oo2
Zl<00ol0003o`jJmol>V_@05ol>V_@03o`000?o2Zl?o`Z_300Go`Z_300?o0000ol>V_Oo3Y[d02_o3
Y[d01?l0003o`Z_3ol:[`ol0000>ol>V_@;o00003oo3Y[d01Ol0003o`j>hol>S^?o3XkSo000000[o
`jJm00?o0000ol>S^?o3XkP01Oo3XkP00ol0003o`jJmol>V_@04ol>V_@03o`000?o3XkSo`j>h00Wo
`j>h00Co0000ol>V_Oo3Y[go00003oo3XkP00ol0003o`j>hol>S^00<ol>S^005o`000?o4X;Coa:2d
olBP]?l000002Oo3XkP00ol0003oa:2dolBP]004olBP]003o`000?o3XkSo`j>h00Go`j>h00?o0000
olBP]?o4X;@01oo4X;@00ol0003o`j>hol>S^002ol>S^003o`000?o4X;Coa:2d00[oa:2d00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo000coooo
o`03o`000?oooooooooo00gooooo00?o0000ol:[`oo2Zl<02Oo2Zl<01Ol0003o`;3:ol2`b_o0/<[o
000000ko`Z_300?o0000ol>V_Ol000003Oo2Zl<00ol0003o`jJmol>V_@03ol>V_@03o`000?o2Zl?o
`Z_300Oo`Z_300?o0000ol>V_Oo3Y[d02?o3Y[d01Ol0003o`Z_3ol:[`oo2Zl?o000000go`jJm00?o
0000ol:[`ol000003oo3Y[d01?l0003o`j>hol>S^?l0000;ol>V_@03o`000?o3XkSo`j>h00Co`j>h
00?o0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`j>hol>S^007ol>S^003o`000?o3Y[go`jJm00;o`jJm
00?o0000ol>S^?o3XkP02oo3XkP2o`0000ko`j>h00Co0000olBP]?o4X;Co00002oo3XkP00ol0003o
a:2dolBP]002olBP]003o`000?o3XkSo`j>h00Oo`j>h00?o0000olBP]?o4X;@01Oo4X;@00ol0003o
`j>hol>S^003ol>S^003o`000?o4X;Coa:2d00Woa:2d00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo000dooooo`03o`000?oooooooooo00cooooo
00?o0000ol:[`oo2Zl<02?o2Zl<00ol0003o`;3:ol2`bP02ol2`bP03o`000?o2Zl?o`Z_300co`Z_3
0_l0000>ol:[``03o`000?o3Y[go`jJm00;o`jJm00?o0000ol:[`oo2Zl<02Oo2Zl<00ol0003o`jJm
ol>V_@06ol>V_@03o`000?o2Zl?o`Z_300?o`Z_300?o0000ol>V_Oo3Y[d02Oo3Y[d01Ol0003o`Z_3
ol:[`oo2Zl?o000000ko`jJm00?o0000ol>S^?l000003?o3Y[d00ol0003o`j>hol>S^003ol>S^003
o`000?o3Y[go`jJm00Oo`jJm00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`jJmol>V_@03ol>V_@03
o`000?o3XkSo`j>h00[o`j>h00Co0000ol>W_Oo3Ykgo00003Oo3XkP00ol0003oa:2do`00000<ol>S
^005o`000?o4X;Coa:2dolBP]?l000002_o3XkP00ol0003oa:2dolBP]004olBP]003o`000?o3XkSo
`j>h00Go`j>h00?o0000olBP]?o4X;@01oo4X;@00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool003Gooooo00?o0000ooooooooool03?ooool00ol0
003o`Z_3ol:[``05ol:[``;o00001_o0/<X00ol0003o`Z_3ol:[``0:ol:[``03o`000?o0/<[o0000
00oo`Z_300Co0000ol>V_Oo3Y[go00003?o2Zl<00ol0003o`jJmol>V_@05ol>V_@03o`000?o2Zl?o
`Z_300Co`Z_300?o0000ol>V_Oo3Y[d02?o3Y[d00ol0003o`Z_3ol:[``02ol:[``03o`000?o3Y[go
`jJm00co`jJm0_l0000>ol>V_@05o`000?o3XkSo`j>hol>S^?l000002oo3Y[d00ol0003o`j>hol>S
^004ol>S^003o`000?o3Y[go`jJm00Co`jJm00?o0000ol>S^?o3XkP02Oo3XkP01Ol0003o`jNmol>W
_Oo3Ykgo000000ko`j>h00?o0000ol>S^?o3XkP02oo3XkP01?l0003oa:2dolBP]?l0000;ol>S^003
o`000?o4X;Coa:2d00?oa:2d00?o0000ol>S^?o3XkP01_o3XkP00ol0003oa:2dolBP]006olBP]003
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`00
=_ooool2o`0000cooooo00?o0000ol:[`oo2Zl<01?o2Zl<00ol0003o`;3:ol2`bP06ol2`bP03o`00
0?o2Zl?o`Z_300Wo`Z_300Go0000ol2`b_o0/<[o`;3:o`00000>ol:[``03o`000?o3Y[go000000ko
`Z_300?o0000ol>V_Oo3Y[d00oo3Y[d00ol0003o`Z_3ol:[``06ol:[``03o`000?o3Y[go`jJm00Ko
`jJm00?o0000ol:[`oo2Zl<01?o2Zl<00ol0003o`jJmol>V_@0:ol>V_@03o`000?o2Zl?o000000ko
`jJm00Co0000ol>S^?o3XkSo00003?o3Y[d00ol0003o`j>hol>S^003ol>S^003o`000?o3Y[go`jJm
00Ko`jJm00?o0000ol>S^?o3XkP01oo3XkP00ol0003o`jNmol>W_@02ol>W_@03o`000?o3XkSo`j>h
00_o`j>h0_l0000>ol>S^0;o00003Oo3XkP01Ol0003oa:2dolBP]?o4X;Co000000Wo`j>h00?o0000
olBP]?o4X;@01Oo4X;@00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02_ooool003Sooooo00?o0000ooooooooool02_ooool00ol0003o`Z_3ol:[``02ol:[
``03o`000?o0/<[o`;3:00So`;3:00?o0000ol:[`oo2Zl<01oo2Zl<00ol0003o`;3:ol2`bP03ol2`
bP03o`000?o2Zl?o`Z_300_o`Z_30_l0000?ol:[``03o`000?o3Y[go`jJm00;o`jJm00?o0000ol:[
`oo2Zl<01oo2Zl<00ol0003o`jJmol>V_@05ol>V_@03o`000?o2Zl?o`Z_300Go`Z_300?o0000ol>V
_Oo3Y[d02Oo3Y[d01Ol0003o`Z_3ol:[`oo2Zl?o000000go`jJm00?o0000ol>S^?l000003_o3Y[d0
1Ol0003o`j>hol>S^?o3XkSo000000Wo`jJm00?o0000ol>S^?o3XkP01_o3XkP00ol0003o`jNmol>W
_@04ol>W_@03o`000?o3XkSo`j>h00Wo`j>h00Co0000ol>W_Oo3Ykgo00003Oo3XkP00ol0003o`j>h
ol>S^00<ol>S^005o`000?o4X;Coa:2dolBP]?l000002_o3XkP00ol0003oa:2dolBP]004olBP]003
o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`00
>Oooool00ol0003oooooooooo`0:ooooo`04o`000?o2Zl?o`Z_3o`0000_o`;3:00?o0000ol:[`oo2
Zl<01Oo2Zl<2o`0000Ko`;3:00?o0000ol:[`oo2Zl<02_o2Zl<00ol0003o`;3:o`00000@ol:[``04
o`000?o3Y[go`jJmo`0000_o`Z_300?o0000ol>V_Oo3Y[d00oo3Y[d00ol0003o`Z_3ol:[``07ol:[
``03o`000?o3Y[go`jJm00Oo`jJm00?o0000ol:[`oo2Zl<00_o2Zl<00ol0003o`jJmol>V_@0<ol>V
_@03o`000?o3Y[go`jJm00go`jJm00Co0000ol>S^?o3XkSo00002oo3Y[d00ol0003o`j>hol>S^004
ol>S^003o`000?o3Ykgo`jNm00Go`jNm00?o0000ol>S^?o3XkP02?o3XkP01Ol0003o`jNmol>W_Oo3
Ykgo000000go`j>h00?o0000ol>S^?o3XkP03?o3XkP01?l0003oa:2dolBP]?l0000;ol>S^003o`00
0?o4X;Coa:2d00?oa:2d00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo000jooooo`03o`000?oooooooooo00Wooooo00?o0000ol:[`ol000003Oo0
/<X00ol0003o`Z_3ol:[``03ol:[``03o`000?o0/<[o`;3:00Oo`;3:00?o0000ol:[`oo2Zl<02?o2
Zl<01Ol0003o`;3:ol2`b_o0/<[o000000oo`Z_300?o0000ol>V_Ol000003?o2Zl<00ol0003o`jJm
ol>V_@02ol>V_@03o`000?o2Zl?o`Z_300So`Z_300?o0000ol>V_Oo3Y[d01_o3Y[d00ol0003o`Z_3
ol:[``04ol:[``03o`000?o3Y[go`jJm00[o`jJm0_l0000?ol>V_@03o`000?o3XkSo000000co`jJm
00?o0000ol>S^?o3XkP00oo3XkP00ol0003o`jNmol>W_@06ol>W_@03o`000?o3XkSo`j>h00Oo`j>h
00?o0000ol>W_Oo3Ykd00_o3Ykd00ol0003o`j>hol>S^00:ol>S^003o`000?o3Ykgo000000ko`j>h
0_l0000=ol>S^005o`000?o4X;Coa:2dolBP]?l000007_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo000kooooo`;o00002_ooool00ol0003o`;3:ol2`bP0<ol2`bP03o`00
0?o2Zl?o`Z_300;o`Z_300?o0000ol2`b_o0/<X02Oo0/<X00ol0003o`Z_3ol:[``06ol:[``03o`00
0?o0/<[o`;3:00?o`;3:00?o0000ol:[`oo2Zl<03?o2Zl<2o`0000ko`Z_300Co0000ol>V_Oo3Y[go
00002oo2Zl<00ol0003o`jJmol>V_@05ol>V_@03o`000?o2Zl?o`Z_300Go`Z_300?o0000ol>V_Oo3
Y[d02Oo3Y[d01?l0003o`Z_3ol:[`ol0000>ol>V_@;o00003_o3Y[d01Ol0003o`j>hol>S^?o3XkSo
000000[o`jNm00?o0000ol>S^?o3XkP01Oo3XkP00ol0003o`jNmol>W_@04ol>W_@03o`000?o3XkSo
`j>h00So`j>h00Co0000ol>W_Oo3Ykgo00003_o3XkP00ol0003o`j>hol>S^00<ol>S^004o`000?o4
X;Coa:2do`00023ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00?Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?o0/<[o`;3:00go`;3:00Co0000ol:[`oo2Zl?o0000
3?o0/<X00ol0003o`Z_3ol:[``04ol:[``;o00001_o0/<X00ol0003o`Z_3ol:[``0;ol:[``03o`00
0?o0/<[o000000ko`Z_300?o0000ol>V_Ol000003Oo2Zl<00ol0003o`jJmol>V_@03ol>V_@03o`00
0?o2Zl?o`Z_300Oo`Z_300?o0000ol>V_Oo3Y[d01oo3Y[d01Ol0003o`Z_3ol:[`oo2Zl?o000000go
`jJm00?o0000ol:[`ol000003_o3Y[d01?l0003o`j>hol>S^?l0000;ol>W_@03o`000?o3XkSo`j>h
00Co`j>h00?o0000ol>W_Oo3Ykd01Oo3Ykd00ol0003o`j>hol>S^007ol>S^003o`000?o3Ykgo`jNm
00;o`jNm00?o0000ol>S^?o3XkP02oo3XkP00ol0003o`j>hol>S^00<ol>S^003o`000?o4X;Co0000
027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`00?_ooool00ol0003o
ooooooooo`07ooooo`03o`000?o0/<[o`;3:00co`;3:00?o0000ol:[`ol000003_o0/<X00ol0003o
`Z_3ol:[``02ol:[``03o`000?o0/<[o`;3:00Oo`;3:00?o0000ol:[`oo2Zl<02Oo2Zl<01Ol0003o
`;3:ol2`b_o0/<[o000000go`Z_30_l0000>ol:[``03o`000?o3Y[go`jJm00;o`jJm00?o0000ol:[
`oo2Zl<02?o2Zl<00ol0003o`jJmol>V_@06ol>V_@03o`000?o2Zl?o`Z_300?o`Z_300?o0000ol>V
_Oo3Y[d02Oo3Y[d01Ol0003o`Z_3ol:[`oo2Zl?o000000go`jJm00?o0000ol>S^?l000003?o3Ykd0
0ol0003o`j>hol>S^003ol>S^003o`000?o3Ykgo`jNm00Oo`jNm00?o0000ol>S^?o3XkP01Oo3XkP0
0ol0003o`jNmol>W_@03ol>W_@03o`000?o3XkSo`j>h00[o`j>h00?o0000ol>W_Ol000003_o3XkP0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool0
03oooooo00?o0000ooooooooool01oooool00ol0003o`;3:ol2`bP0;ol2`bP;o00003oo0/<X01Ol0
003o`Z_3ol:[`oo2Zl?o000000_o`;3:00?o0000ol:[`oo2Zl<01_o2Zl<2o`0000Co`;3:00?o0000
ol:[`oo2Zl<02_o2Zl<00ol0003o`;3;o`00000?ol:[``04o`000?o3Y[go`jJmo`0000_o`Z_300?o
0000ol>V_Oo3Y[d01Oo3Y[d00ol0003o`Z_3ol:[``04ol:[``03o`000?o3Y[go`jJm00So`jJm00?o
0000ol:[`oo2Zl<00_o2Zl<00ol0003o`jJmol>V_@0;ol>V_@;o00003_o3Ykd01Ol0003o`j>hol>S
^?o3XkSo000000[o`jNm00?o0000ol>S^?o3XkP01?o3XkP00ol0003o`jNmol>W_@04ol>W_@03o`00
0?o3XkSo`j>h00Wo`j>h00Co0000ol>W_Oo3Ykgo00003Oo3XkP00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool0043ooooo0_l00007ooooo`03o`00
0?o0/<[o`;3:00[o`;3:00?o0000okfge?l000004?o0/<X00ol0003o`Z_3o`00000<ol2`bP03o`00
0?o2Zl?o`Z_300Go`Z_300?o0000ol2`b_o0/<X01Oo0/<X00ol0003o`Z_3ol:[``08ol:[``05o`00
0?o0/<_o`;3;ol2`bol000003_o2Zl<00ol0003o`jJmo`00000=ol:[``03o`000?o3Y[go`jJm00?o
`jJm00?o0000ol:[`oo2Zl<01_o2Zl<00ol0003o`jJmol>V_@06ol>V_@03o`000?o2Zl?o`Z_300?o
`Z_300?o0000ol>V_Oo3Y[d02_o3Y[d00ol0003o`Z_3o`00000>ol>W_@04o`000?o3XkSo`j>ho`00
00_o`jNm00?o0000ol>S^?o3XkP00oo3XkP00ol0003o`jNmol>W_@06ol>W_@03o`000?o3XkSo`j>h
00Oo`j>h00Go0000ol>W_Oo3Ykgo`jNmo`00000<ol>S^003o`000?oooooooooo02Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`09ooooo`00@_ooool00ol0003oooooooooo`05oooo
o`03o`000?o0/<[o`;3:00Oo`;3:0_l00003okfge003o`000?o0/<[o`;3:00go`;3:0_l0000>ol2`
bP03o`000?o2Zl?o`Z_300;o`Z_30_l00008ol2`bP03o`000?o2Zl?o`Z_300Oo`Z_300?o0000ol2`
boo0/</00_o0/</00ol0003o`Z_3ol:[``0<ol:[``;o00003_o2Zl<00ol0003o`jJmol>V_@02ol>V
_@03o`000?o2Zl?o`Z_300Oo`Z_300?o0000ol>V_Oo3Y[d01Oo3Y[d00ol0003o`Z_3ol:[``05ol:[
``03o`000?o3Y[go`jJm00So`jJm00Go0000ol:[`oo2Zl?o`Z_3o`00000=ol>W_@03o`000?o3XkSo
000000go`jNm00Go0000ol>S^?o3XkSo`j>ho`000009ol>W_@03o`000?o3XkSo`j>h00Ko`j>h00?o
0000ol>W_Oo3Ykd00oo3Ykd00ol0003o`j>hol>S^008ol>S^003o`000?oooooooooo02Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`00@oooool00ol0003oooooooooo`05
ooooo`03o`000?o0/<[o`;3:00Go`;3:00?o0000okfge?nm]m@01?nm]m@00ol0003o`;3:ol2`bP0;
ol2`bP03o`000?nm]mCo000000ko`;3:00Go0000ol:[`oo2Zl?o`Z_3o`00000;ol2`bP03o`000?o2
Zl?o`Z_300Go`Z_300?o0000ol2`boo0/</01?o0/</00ol0003o`Z_3ol:[``0:ol:[``03o`000?o0
/<_o000000oo`Z_300Co0000ol>V_Oo3Y[go00002oo2Zl<00ol0003o`jJmol>V_@03ol>V_@03o`00
0?o2Zl?o`Z_300Ko`Z_300?o0000ol>V_Oo3Y[d01oo3Y[d00ol0003o`Z_3ol:[``02ol:[``03o`00
0?o3Ykgo`jNm00_o`jNm0_l0000>ol>W_@04o`000?o3XkSo`j>ho`0000_o`jNm00?o0000ol>S^?o3
XkP01?o3XkP00ol0003o`jNmol>W_@04ol>W_@03o`000?o3XkSo`j>h00Oo`j>h00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo0014ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ol2`b_o0/<X00oo0/<X00ol0003o_KODokfge006okfge003o`00
0?o0/<[o`;3:00So`;3:0_l00003okfge003o`000?o0/<[o`;3:00co`;3:00?o0000ol:[`ol00000
3Oo0/<X00ol0003o`Z_3ol:[``03ol:[``03o`000?o0/<_o`;3;00Go`;3;00?o0000ol:[`oo2Zl<0
2Oo2Zl<01Ol0003o`;3;ol2`boo0/<_o000000ko`Z_300?o0000ol>V_Ol000003?o2Zl<00ol0003o
`jJmol>V_@02ol>V_@03o`000?o2Zl?o`Z_300So`Z_300?o0000ol>V_Oo3Y[d01Oo3Y[d00ol0003o
`Z_3ol:[``04ol:[``03o`000?o3Ykgo`jNm00Wo`jNm00?o0000ol:[`ol000003_o3Ykd00ol0003o
`j>ho`00000<ol>W_@03o`000?o3XkSo`j>h00?o`j>h00?o0000ol>W_Oo3Ykd01_o3Ykd00ol0003o
`j>hol>S^005ol>S^003o`000?oooooooooo02[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`09ooooo`00AOooool2o`0000Gooooo00Co0000ol2`b_o0/<[o`;3:0_l0000:okfge003
o`000?o0/<[o`;3:00Go`;3:0_l00006okfge003o`000?o0/<[o`;3:00_o`;3:0_l0000>ol2`bP03
o`000?o2Zl?o`Z_300;o`Z_300?o0000ol2`boo0/</01oo0/</00ol0003o`Z_3ol:[``06ol:[``;o
00001?o0/</00ol0003o`Z_3ol:[``0<ol:[``;o00003_o2Zl<01?l0003o`jJmol>V_Ol0000;ol:[
``03o`000?o3Y[go`jJm00Co`jJm00?o0000ol:[`oo2Zl<01Oo2Zl<00ol0003o`jNmol>W_@08ol>W
_@05o`000?o2Zl?o`Z_3ol:[`ol000003_o3Ykd00ol0003o`jNmol>W_@0<ol>W_@05o`000?o3XkSo
`j>hol>S^?l000002Oo3Ykd00ol0003o`j>hol>S^004ol>S^003o`000?oooooooooo02cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`00Aoooool00ol0003oooooooooo`03
ooooo`03o`000?o0/<[o000000co_KOD00?o0000ol2`b_o0/<X01?o0/<X00ol0003o_KODokfge006
okfge003o`000?o0/<[o`;3:00[o`;3:00?o0000okfge?l000003oo0/<X01?l0003o`Z_3ol:[`ol0
000;ol2`b`03o`000?o2Zl?o`Z_300Co`Z_300?o0000ol2`boo0/</01Oo0/</00ol0003o`Z_3ol:[
``0:ol:[``03o`000?o0/L_o000000ko`Z_300?o0000ol>V_Ol000003?o2Zl<00ol0003o`jJmol>V
_@03ol>V_@03o`000?o2Zl?o`Z_300Oo`Z_300?o0000ol>W_Oo3Ykd01_o3Ykd00ol0003o`Z_3ol:[
``02ol:[``03o`000?o3Ykgo`jNm00_o`jNm0_l0000>ol>W_@04o`000?o3XkSo`j>ho`0000[o`jNm
00?o0000ol>S^?o3XkP00oo3XkP00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02Oooool004Sooooo00?o0000ooooooooool00oooool00ol0003o_KODokfg
e00<okfge004o`000?o0/<[o`;3:ol2`bP;o00002_nm]m@00ol0003o`;3:ol2`bP07ol2`bP;o0000
0onm]m@00ol0003o`;3:ol2`bP0<ol2`bP03o`000?o2Zl?o000000co`;3;00?o0000ol:[`oo2Zl<0
0_o2Zl<2o`0000So`;3;00?o0000ol:[`oo2Zl<02Oo2Zl<01Ol0003o`;7;ol2aboo0/L_o000000go
`Z_30_l0000>ol:[``05o`000?o3Y[go`jJmol>V_Ol000002_o2Zl<00ol0003o`jNmol>W_@05ol>W
_@03o`000?o2Zl?o`Z_300Co`Z_300?o0000ol>W_Oo3Ykd02Oo3Ykd01?l0003o`Z_3ol:[`ol0000=
ol>W_@03o`000?o3XkSo000000co`jNm00Go0000ol>S^?o3XkSo`j>ho`00000aooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02?ooool004Wooooo00?o0000ooooooooool00_ooool0
0ol0003o_KODokfge00=okfge003o`000?o0/<[o000000co_KOD00?o0000ol2`b_o0/<X01Oo0/<X2
o`0000Ko_KOD00?o0000ol2`b_o0/<X02oo0/<X2o`0000ko`;3;00Co0000ol:[`oo2Zl?o00002oo0
/</00ol0003o`Z_3ol:[``06ol:[``;o00001Oo0/L/00ol0003o`Z_3ol:[``09ol:[``03o`000?o0
/L_o000000ko`Z_300Co0000ol>V_Oo3Y[go00003?o2Zl<00ol0003o`jNmol>W_@03ol>W_@03o`00
0?o2Zl?o`Z_300Go`Z_300?o0000ol>W_Oo3Ykd02?o3Ykd01Ol0003o`Z_3ol:[`oo2Zl?o000000go
`jNm0_l0000=ol>W_@04o`000?o3XkSo`j>ho`0003?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`08ooooo`00B_ooool2o`0000?ooooo00?o0000okfge?nm]m@03?nm]m@2o`0000ko
_KOD00?o0000ol2`b_o0/<X00oo0/<X00ol0003o_KODokfge006okfge003o`000?o0/<[o`;3:00Wo
`;3:0_l000000onm^=Co0000ol2`b`0=ol2`b`03o`000?o2Zl?o000000go`;3;00?o0000ol:[`oo2
Zl<01?o2Zl<00ol0003o`;7;ol2ab`05ol2ab`03o`000?o2Zl?o`Z_300So`Z_300Go0000ol2aboo0
/L_o`;7;o`00000=ol:[``03o`000?o3Y[go000000go`Z_300?o0000ol>W_Oo3Ykd00_o3Ykd00ol0
003o`Z_3ol:[``07ol:[``03o`000?o3Ykgo`jNm00Ko`jNm00?o0000ol:[`oo2Zl<00_o2Zl<00ol0
003o`jNmol>W_@0:ol>W_@03o`000?o2Zl?o000000go`jNm00?o0000ol>S^?l00000=Oooool01Ol0
003ooooooooooooooooo000000[ooooo001<ooooo`05o`000?ooooooooooooooool000002onm]m@2
o`000003okS0h?l0003o_KOD00ko_KOD00?o0000ol2`b_o0/<X00_l0000:okfge003o`000?o0/<[o
`;3:00Ko`;3:0_l00004okfhe003o`000?o0/<_o`;3;00_o`;3;0_l0000>ol2`b`03o`000?o2Zl?o
`Z_300;o`Z_30_l00009ol2ab`03o`000?o2Zl?o`Z_300Ko`Z_300?o0000ol2aboo0/L/00_o0/L/0
0ol0003o`Z_3ol:[``0;ol:[``;o00003oo2Zl<01?l0003o`jNmol>W_Ol0000:ol:[``03o`000?o3
Ykgo`jNm00Go`jNm00?o0000ol:[`oo2Zl<01?o2Zl<00ol0003o`jNmol>W_@08ol>W_@05o`000?o2
Zl?o`Z_3ol:[`ol000003Oo3Ykd00ol0003oooooooooo`0dooooo`05o`000?ooooooooooooooool0
00002_ooool004gooooo00Go0000ooooooooooooooooo`000009okfge003o`000?nh`>3o^<3P00;o
^<3P00?o0000okfge?nm]m@03?nm]m@00ol0003o`;3:o`00000=okfge003o`000?o0/<[o`;3:00Co
`;3:00?o0000okfhe?nm^=@01Onm^=@00ol0003o`;3;ol2`b`09ol2`b`03o`000?nm^=Co000000oo
`;3;00Co0000ol:[`oo2Zl?o00002oo0/L/00ol0003o`Z_3ol:[``04ol:[``;o00001_o0/L/00ol0
003o`Z_3ol:[``09ol:[``03o`000?o0/L_o000000oo`Z_300?o0000ol>W_Ol000003?o2Zl<00ol0
003o`jNmol>W_@03ol>W_@03o`000?o2Zl?o`Z_300Go`Z_300?o0000ol>W_Oo3Ykd01oo3Ykd00ol0
003o`Z_3ol:[``02ol:[``03o`000?o3Ykgo`jNm00[o`jNm00?o0000ooooooooool0=_ooool01?l0
003oooooooooool0000:ooooo`00C_ooool01Ol0003ooooooooooooooooo000000Ko_KOD0_l00006
okS0h003o`000?nm]mCo_KOD00_o_KOD0_l0000>okfge003o`000?o0/<[o`;3:00;o`;3:0_l00008
okfhe003o`000?o0/<_o`;3;00Oo`;3;0_l00003okfhe003o`000?o0/<_o`;3;00co`;3;00?o0000
ol:[`ol000003Oo0/L/00ol0003o`Z_3ol:[``02ol:[``03o`000?o0/L_o`;7;00Ko`;7;00?o0000
ol:[`oo2Zl<02?o2Zl<01Ol0003o`;7;ol2aboo0/L_o000000ko`Z_30_l0000=ol:[``03o`000?o3
Ykgo`jNm00;o`jNm00?o0000ol:[`oo2Zl<01oo2Zl<00ol0003o`jNmol>W_@04ol>W_@;o00001Oo2
Zl<00ol0003o`jNmol>W_@09ol>W_@03o`000?oooooooooo03Sooooo00?o0000ooooool000002_oo
ool004oooooo0_l00002ooooo`04o`000?nm]mCo_KODokfge0;o00002Onh`>000ol0003o_KODokfg
e008okfge0;o000000?o^<7Po`000?nm]m@03_nm]m@01?l0003o`;3:o`000?l0000;okfhe003o`00
0?o0/<_o`;3;00Go`;3;00?o0000okfhe?nm^=@01?nm^=@00ol0003o`;3;ol2`b`0;ol2`b`;o0000
3oo0/L/01?l0003o`Z_3ol:[`ol0000:ol2ab`03o`000?o2Zl?o`Z_300Ko`Z_300?o0000ol2aboo0
/L/00oo0/L/00ol0003o`Z_3ol:[``0:ol:[``03o`000?o0/L_o000000ko`Z_300Co0000ol>W_Oo3
Ykgo00002_o2Zl<00ol0003o`jNmol>W_@03ol>W_@03o`000?o2Zl?o`Z_300Ko`Z_300?o0000ol>W
_Oo3Ykd01oo3Ykd00ol0003oooooooooo`0iooooo`03o`000?oooooo000000[ooooo001Aooooo`06
o`000?ooooooooooo`000?nm]mCo00003?nh`>000ol0003o_KODokfge005okfge0;o00001?nh`N00
0ol0003o_KODokfge00<okfge0;o00003_nm^=@00ol0003o`;3;ol2`b`03ol2`b`03o`000?nm^=Co
_KSD00Go_KSD00?o0000ol2`boo0/</02_o0/</00ol0003o_KSDo`00000?ol2ab`03o`000?o2Zl?o
000000co`;7;00?o0000ol:[`oo2Zl<00oo2Zl<2o`0000Ko`;7;00?o0000ol:[`oo2Zl<02Oo2Zl<0
1Ol0003o`;7;ol2aboo0/L_o000000go`Z_300?o0000ol>W_Ol000003?o2Zl<01Ol0003o`jNmol>W
_Oo3Ykgo000000Wo`Z_300?o0000ol>W_Oo3Ykd01_o3Ykd00ol0003oooooooooo`0kooooo`03o`00
0?oooooo000000Wooooo001Booooo`04o`000?ooooooooooo`0000ko^<3P00?o0000okfge?nm]m@0
0_nm]m@2o`0000Oo^<7P00?o0000okfge?nm]m@02Onm]m@2o`000003okS1hOl0003o_KSD00go_KSD
00Co0000ol2`boo0/<_o`;3;0_l00009okfhe003o`000?o0/<_o`;3;00Oo`;3;0_l00003okfhe003
o`000?o0/L_o`;7;00co`;7;0_l0000=ol2ab`03o`000?o2Zl?o`Z_300;o`Z_300?o0000ol2aboo0
/L/01oo0/L/00ol0003o`Z_3ol:[``06ol:[``;o00001?o0/L/00ol0003o`Z_3ol:[``0;ol:[``;o
00003Oo2Zl<01?l0003o`jNmol>W_Ol0000;ol:[``03o`000?o3Ykgo`jNm00Co`jNm00?o0000oooo
ooooool0?Oooool2o`0000Wooooo001Cooooo`;o000000?oooooo`000?nh`>003Onh`>001?l0003o
_KODo`000?l0000:okS1h003o`000?nm]mCo_KOD00Oo_KOD00?o0000okS1hOnh`N400_nh`N400ol0
003o_KSDokfhe00<okfhe003o`000?o0/<_o000000co_KSD00?o0000ol2`boo0/</01Oo0/</00ol0
003o_KSDokfhe004okfhe003o`000?o0/L_o`;7;00[o`;7;00?o0000okfhe?l000003_o0/L/01?l0
003o`Z_3ol:[`ol0000:ol2ab`03o`000?o2Zl?o`Z_300Go`Z_300?o0000ol2aboo0/L/01Oo0/L/0
0ol0003o`Z_3ol:[``09ol:[``03o`000?o0/L_o000000go`Z_300?o0000ol>W_Ol000003?o2Zl<0
0ol0003o`jNmol>W_@03ol>W_@03o`000?oooooooooo03gooooo0ol00009ooooo`00EOooool00ol0
003oooooo`00000=okS0h0;o00003Onh`N000ol0003o_KODokfge004okfge0;o00001_nh`N400ol0
003o_KSDokfhe00;okfhe0;o00003_nm^=@00ol0003o`;3;ol2`b`03ol2`b`03o`000?nm^=Co_KSD
00Go_KSD00?o0000ol2aboo0/L/02?o0/L/2o`0000?o_KSD00?o0000ol2aboo0/L/02oo0/L/00ol0
003o`Z_3o`00000<ol2ab`03o`000?o2Zl?o`Z_300;o`Z_30_l00008ol2ab`03o`000?o2Zl?o`Z_3
00So`Z_300Go0000ol2aboo0/L_o`;7;o`00000<ol:[``;o00003_o2Zl<01Ol0003o`jNmol>W_Oo3
Ykgo000003cooooo1?l0000<ooooo`00E_ooool00ol0003oooooo`000009okS0h0?o000000?o[<_`
o`000?nh`N003Onh`N001?l0003o_KODokfge?nm]m@2o`0000Wo^<7Q00?o0000okfhe?nm^=@02?nm
^=@2o`000003okS1hOl0003o_KSD00go_KSD00Co0000ol2`boo0/<_o`;3;0_l00009okfhe003o`00
0?o0/L_o`;7;00Go`;7;0_l00005okfhe003o`000?o0/L_o`;7;00_o`;7;0_l0000>ol2ab`04o`00
0?o2Zl?o`Z_3o`0000_o`;7;00?o0000ol:[`oo2Zl<01Oo2Zl<2o`0000Co`;7;00?o0000ol:[`oo2
Zl<02Oo2Zl<00ol0003o`;7;o`00000>ol:[``04o`000?o3Ykgo`jNmo`0003Wooooo1?l0000@oooo
o`00Eoooool00ol0003oooooo`000005okS0h0?o00001On/bo000ol0003o^<7PokS1h00<okS1h003
o`000?nm]mCo000000_o^<7Q00?o0000okfhe?nm^=@01Onm^=@3o`0000Co^<7Q00?o0000okfhe?nm
^=@03?nm^=@00ol0003o`;3;o`00000<okfhe003o`000?o0/L_o`;7;00?o`;7;00?o0000okfhe?nm
^=@01_nm^=@00ol0003o`;7;ol2ab`09ol2ab`03o`000?nm^=Co000000ko`;7;00?o0000ol:[`ol0
00003?o0/L/00ol0003o`Z_3ol:[``04ol:[``03o`000?o0/L_o`;7;00Go`;7;00?o0000ol:[`oo2
Zl<01oo2Zl<01Ol0003o`;7;ol2aboo0/L_o000000go`Z_300?o0000ol>W_Ol00000=_ooool4o`00
01Cooooo001Hooooo`?o000000Co^<3Po`000?l0003o00002On/bo000ol0003o^<7PokS1h00;okS1
h0;o00003Onh`N400ol0003o_KSDokfhe002okfhe0;o00002?nh`N400ol0003o_KSDokfhe00;okfh
e0;o00003Onm^=@01?l0003o`;7;ol2aboo0/L/2o`0000Wo_KSD00?o0000ol2aboo0/L/01oo0/L/2
o`0000?o_KSD00?o0000ol2aboo0/L/02oo0/L/2o`0000go`;7;00?o0000ol:[`oo2Zl<00_o2Zl<2
o`0000So`;7;00?o0000ol:[`oo2Zl<01_o2Zl<00ol0003o`;7;ol2ab`02ol2ab`03o`000?o2Zl?o
`Z_300_o`Z_30_l0000dooooo`?o00006?ooool005[ooooo0ol0000<ojc;l003o`000?nh`N3o^<7P
00Oo^<7P0ol00002ojc;l003o`000?nh`N7o^<7Q00_o^<7Q00Co0000okfhe?l0003o00002onh`N40
0ol0003o_KSDokfhe008okfhe0;o000000?o^<7Qo`000?nm^=@03Onm^=@00ol0003o`;7;o`00000<
okfhe003o`000?o0/L_o`;7;00Co`;7;0_l00005okfhe003o`000?o0/L_o`;7;00[o`;7;00?o0000
okfhe?l000003_o0/L/01?l0003o`Z_3ol:[`ol0000;ol2ab`03o`000?o2Zl?o`Z_300?o`Z_30_l0
0006ol2ab`03o`000?o2Zl?o`Z_300Wo`Z_300?o0000ooooooooool0<?ooool4o`0001_ooooo001K
ooooo`03o`000?oooooo000000co[<_`00?o0000okS1h?nh`N000onh`N03o`0000Ko[<_`00?o0000
okS1hOnh`N402_nh`N42o`0000go^<7Q00?o0000okfhe?nm^=@01Onm^=@3o`0000Co^<7Q00?o0000
okfhe?nm^=@02onm^=@2o`0000go_KSD00?o0000ol2aboo0/L/00oo0/L/00ol0003o_KSDokfhe006
okfhe003o`000?o0/L_o`;7;00Oo`;7;0_l00003okfhe003o`000?o0/L_o`;7;00_o`;7;00?o0000
ol:[`ol000003?o0/L/00ol0003o`Z_3ol:[``02ol:[``03o`000?o0/L_o`;7;00Ko`;7;00?o0000
ol:[`oo2Zl<02?o2Zl<00ol0003oooooooooo`0]ooooo`Co00007oooool005cooooo00Co0000oooo
ool0003o00002on/bo000ol0003o^<7Po`000002o`0000[o[<_`00?o0000okS1hOnh`N401_nh`N43
o`0000;o[<c`00?o0000okS1hOnh`N402onh`N400ol0003o_KSDokfhe002okfhe0;o00002?nh`N40
0ol0003o_KSDokfhe008okfhe0;o000000?o^<7Qo`000?nm^=@03Onm^=@00ol0003o`;7;ol2ab`02
o`0000[o_KSD00?o0000ol2aboo0/L/01?o0/L/2o`0000Go_KSD00?o0000ol2aboo0/L/02oo0/L/2
o`0000ko`;7;00Co0000ol:[`oo2Zl?o00002_o0/L/00ol0003o`Z_3ol:[``06ol:[``03o`000?oo
oooooooo02[ooooo1?l0000Sooooo`00GOooool2o`000003ooooool0003o[<_`00So[<_`1?l0000=
ojc;l003o`000?nh`N7o^<7Q00?o^<7Q0_l00006ojc<l003o`000?nh`N7o^<7Q00_o^<7Q00Co0000
okfhe?l0003o00002onh`N400ol0003o_KSDokfhe004okfhe0?o00001?nh`N400ol0003o_KSDokfh
e00;okfhe003o`000?o0/L_o000000co_KSD00?o0000ol2aboo0/L/00oo0/L/00ol0003o_KSDokfh
e006okfhe003o`000?o0/L_o`;7;00Wo`;7;00?o0000okfhe?l000003_o0/L/00ol0003o`Z_3o`00
000<ol2ab`03o`000?o2Zl?o`Z_300?o`Z_30_l0000Yooooo`Co00009oooool005oooooo00?o0000
ooooool000000on/bo05o`0000CoT=?n0_l0000<ojc;l003o`000?nh`N7o000000;o00002On/c?00
0ol0003o^<7QokS1h@0:okS1h@;o00003Onh`N400ol0003o_KSDokfhe002okfhe0;o00002?nh`N40
0ol0003o_KSDokfhe00:okfhe0;o00003_nm^=@00ol0003o`;7;ol2ab`02o`0000Wo_KSD00?o0000
ol2aboo0/L/01oo0/L/2o`0000?o_KSD00?o0000ol2aboo0/L/02oo0/L/2o`0000go`;7;00?o0000
ol:[`oo2Zl<00_o2Zl<00ol0003oooooooooo`0Uooooo`Co0000:oooool0063ooooo00?o0000oooo
ool000000_l0000;oi3CoP03o`000?n/bo3o[<_`00So[<_`1?l0000<ojc<l003o`000?nh`N7o^<7Q
00Ko^<7Q0ol00002ojc<l003o`000?nh`N7o^<7Q00_o^<7Q00Co0000okfhe?l0003o00002onh`N40
0ol0003o_KSDokfhe007okfhe0;o000000?o^<7Qo`000?nm^=@03Onm^=@00ol0003o`;7;o`00000<
okfhe003o`000?o0/L_o`;7;00Co`;7;0_l00005okfhe003o`000?o0/L_o`;7;00[o`;7;00?o0000
okfhe?l000003_o0/L/01?l0003o`Z_3ol:[`ol0000Tooooo`Co0000;oooool0067ooooo00?o0000
ooooooooool00ol0000:oi3CoP;o00000on/bo05o`0000CoT=?n00?o0000ojc<l?n/c?002_n/c?00
0ol0003o^<7QokS1h@03okS1h@;o00001_n/c?000ol0003o^<7QokS1h@0:okS1h@;o00003Onh`N40
0ol0003o_KSDokfhe005okfhe0;o00001?nh`N400ol0003o_KSDokfhe00;okfhe0;o00003Onm^=@0
0ol0003o`;7;ol2ab`03ol2ab`03o`000?nm^=Co_KSD00Ko_KSD00?o0000ol2aboo0/L/01oo0/L/2
o`0000?o_KSD00?o0000ol2aboo0/L/02oo0/L/00ol0003o`Z_3o`00000Qooooo`Co0000<oooool0
06;ooooo0_l00003ooooo`;o00001On@doh8o`0000[oT=?n00?o0000ojc<l?n/c?002_n/c?000ol0
003o^<7Qo`000002o`0000Wo[<c`00?o0000okS1hOnh`N401_nh`N43o`0000;o[<c`00?o0000okS1
hOnh`N402onh`N400ol0003o_KSDokfhe002okfhe0;o00001onh`N400ol0003o_KSDokfhe008okfh
e0;o000000?o^<7Qo`000?nm^=@03Onm^=@00ol0003o`;7;ol2ab`02o`0000[o_KSD00?o0000ol2a
boo0/L/01?o0/L/2o`0000Go_KSD00?o0000ol2aboo0/L/02oo0/L/2o`0001kooooo1?l0000goooo
o`00I?ooool00ol0003oooooooooo`02ooooo`Go00001om<`o83o`0000WoT=?n00?o0000ojc<l?n/
c?001on/c?05o`0000co[<c`00?o0000okS1hOnh`N400onh`N42o`0000Ko[<c`00?o0000okS1hOnh
`N402onh`N401?l0003o_KSDo`000?l0000:okS1h@03o`000?nm^=Co_KSD00Go_KSD0_l00004okS1
h@03o`000?nm^=Co_KSD00_o_KSD00?o0000ol2abol000003?nm^=@00ol0003o`;7;ol2ab`03ol2a
b`03o`000?nm^=Co_KSD00Ko_KSD00?o0000ol2aboo0/L/02?o0/L/2o`0001gooooo0ol0000koooo
o`00IOooool00ol0003oooooooooo`04ooooo`?o00002Om<`o82o`0000SoT=?n00Co0000ojc<l?n/
c?3o[<c`1Ol00005ohoCoP03o`000?n/c?3o[<c`00[o[<c`00?o0000okS1hOl000000_l00009ojc<
l003o`000?nh`N7o^<7Q00Wo^<7Q0ol0000=okS1h@03o`000?nm^=Co_KSD00;o_KSD0_l00007okS1
h@03o`000?nm^=Co_KSD00[o_KSD0_l0000>okfhe003o`000?o0/L_o`;7;00;o00002_nm^=@00ol0
003o`;7;ol2ab`05ol2ab`;o00006oooool4o`0003kooooo001Vooooo`03o`000?oooooooooo00Ko
oooo5ol0000;ohoCoP;o00002On/c?04o`0000co[<c`00?o0000okS1hOnh`N401?nh`N44o`0000;o
[<c`00?o0000okS1hOnh`N403?nh`N401?l0003o_KSDo`000?l0000:okS1h@03o`000?nm^=Co_KSD
00Oo_KSD0_l000000onh`N7o0000okfhe00=okfhe003o`000?o0/L_o000000co_KSD00?o0000ol2a
boo0/L/01?o0/L/00ol0003oooooooooo`0Gooooo`Co0000@_ooool006Oooooo0_l0000Aooooo`Ko
00001Om;`o43o`0000_oSm?n00Co0000ojc<l?n/c?3o[<c`1Ol00004ohoDoP03o`000?n/c?3o[<c`
00[o[<c`00?o0000okS1hOnh`N400ol00007ojc<l003o`000?nh`N7o^<7Q00_o^<7Q0_l0000<okS1
h@03o`000?nm^=Co_KSD00Go_KSD0_l00004okS1h@03o`000?nm^=Co_KSD00_o_KSD0_l0000>okfh
e004o`000?o0/L_o`;7;ol2ab`;o00005_ooool4o`0004Kooooo001Yooooo`03o`000?oooooooooo
01?ooooo1ol00002od_3l@;o00001On?doh8o`0000[oSmCn00?o0000ojc<l?n/c?002?n/c?04o`00
00_o[<c`00?o0000okS1hOnh`N401onh`N43o`000003ojc<lOl0003o^<7Q00co^<7Q00?o0000okfh
e?nm^=@00_nm^=@2o`0000Oo^<7Q00?o0000okfhe?nm^=@02?nm^=@2o`000003okS1hOl0003o_KSD
00go_KSD00Co0000ol2abol0003o00005?ooool4o`0004[ooooo001Zooooo`03o`000?oooooooooo
01Wooooo2Ol00007od_2l@;o00002_n?e?h00ol0003o[<c`ojc<l004ojc<l0?o00001?n?e?h00ol0
003o[<c`ojc<l009ojc<l003o`000?nh`N7o^<7Q00?o^<7Q0ol00005ojc<l@03o`000?nh`N7o^<7Q
00_o^<7Q00Co0000okfhe?l0003o00002_nh`N400ol0003o_KSDokfhe005okfhe0;o00001?nh`N40
0ol0003o_KSDokfhe00;okfhe0;o00004_ooool4o`0004kooooo001[ooooo`03o`000?oooooooooo
023ooooo2?l00002od_2l@;o00002On?e?h00ol0003o[<c`ojc<l003o`0000SoSmCn00?o0000ojc<
l?n/c?002On/c?000ol0003o^<7Qo`000002o`0000Wo[<ca00?o0000okS1hOnh`N402Onh`N43o`00
00go^<7Q00?o0000okfhe?nm^=@00_nm^=@2o`0000Oo^<7Q00?o0000okfhe?nm^=@02?nm^=@2o`00
013ooooo1?l0001Booooo`00K?ooool2o`0002Oooooo4Ol0000<ohoDoP03o`000?n/c?3o[<c`00Oo
[<c`1?l0000<ojc<l@03o`000?nh`N7o^<7Q00Co^<7Q1?l00002ojc<l@03o`000?nh`N7o^<7Q00co
^<7Q00Co0000okfhe?l0003o00002_nh`N400ol0003o_KSDokfhe004okfhe0?o00003_ooool4o`00
05Kooooo001^ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01?ooool4o`0000Ko
BL;`0_l0000;ohoDoP04o`000?n/c?3o[<c`ojc<l0Go00001?n>e?h00ol0003o[<caojc<l@0:ojc<
l@03o`000?nh`N7o^<7Q00?o00001on/c?400ol0003o^<7QokS1h@0;okS1h@;o00003?nh`N400ol0
003o_KSDokfhe002okfhe0;o00003Oooool4o`0005[ooooo001_ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool01oooool7o`0000;oBL;`0_l00005ohoDoPSo00002_n>e?h2o`0000Wo
[<ca1?l0000;ojc<l@03o`000?nh`N7o^<7Q00Oo^<7Q0ol000000on/c?7o0000okS1h@0<okS1h@04
o`000?nm^=Co0000o`0000cooooo0ol0001Nooooo`00L?ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00kooooo2Ol00007odS1l0;o00002on>e?h01?l0003o[<caojc<lOn/c?45o`00
00CoS]Co00?o0000ojc<lOn/c?402On/c?400ol0003o^<7QokS1h@03okS1h@?o00001On/c?400ol0
003o^<7QokS1h@0:okS1h@;o00002_ooool4o`00067ooooo001aooooo`;o00008_ooool00ol0003o
ooooooooo`0Fooooo`So00000_m8`O02o`0000GoS]Cn2?l0000:ohkDo`03o`000?n/c?7o[<ca00Wo
[<ca00?o0000okS1hOl000000_l00009ojc<l@03o`000?nh`N7o^<7Q00Ko^<7Q0ol00008ooooo`Co
0000IOooool007?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Nooooo`Wo0000
1om7`Nl2o`0000[oS]Co00?o0000ojc<lOn/c?401on/c?44o`0000co[<ca00?o0000okS1hOnh`N40
0onh`N42o`0000Oooooo1?l0001Yooooo`00M?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo02Kooooo1ol00003odO1k`03o`000?n>e?ooS]Co00SoS]Co00Co0000ojc<lOn/c?7o[<ca
1Ol00004ohkDo`03o`000?n/c?7o[<ca00[o[<ca00?o0000okS1hOl000000_l00005ooooo`Co0000
KOooool007Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0]oooooa;o00002_n>
e?l00ol0003o[<caojc<l@07ojc<l@Co00001?ooool4o`00077ooooo001fooooo`;o00007Oooool0
0ol0003oooooooooo`0cooooo`Co00001om6`>l2o`0000[oS]Co00Co0000ojc<lOn/c?7o[<ca1Ol0
0004ooooo`Co0000MOooool007Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0f
ooooo`Oo00000om6`>l00ol0003oS]CoohkDo`03ohkDo`So00001Oooool4o`0007Wooooo001ioooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0?Oooool9o`0000[ooooo0ol0001moooo
o`00N_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04cooooo1?l00020ooooo`00
Noooool2o`0001Sooooo00?o0000ooooooooool0B?ooool4o`0008Cooooo001mooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0A?ooool4o`0008Sooooo001nooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0@?ooool4o`0008cooooo001oooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0?Oooool4o`00093ooooo0020ooooo`;o00004_ooool00ol0003o
ooooooooo`0iooooo`Co0000U?ooool008;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0eooooo`Co0000V?ooool008?ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0aooooo`Co0000W?ooool008Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0^
ooooo`?o0000X?ooool008Gooooo0_l0000=ooooo`03o`000?oooooooooo02[ooooo1?l0002Soooo
o`00Qoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo1?l0002Wooooo`00
R?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo1?l0002[ooooo`00ROoo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo1?l0002_ooooo`00R_ooool2
o`0000Sooooo00?o0000ooooooooool06_ooool4o`000;?ooooo002<ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05_ooool4o`000;Oooooo002=ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04_ooool4o`000;_ooooo002>ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03_ooool4o`000;oooooo002?ooooo`;o00000oooool00ol0003ooooooooo
o`0;ooooo`?o0000`oooool0097ooooo00Co0000oooooooooooo00002Oooool4o`000<Kooooo002B
ooooo`03o`000?oooooo000000Gooooo1?l0003:ooooo`00Toooool2o`000003ooooool0003o0000
00;o0000c_ooool009Cooooo0_l0003Booooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0418495, 0.0166322, \
0.00355091, 0.00355091}}]
}, Open  ]],

Cell[TextData[{
  "The potential is minimized along the diagonal where the density is \
maximum, but also goes to zero at the box vertices due to the periodic \
boundary conditions: the mass distribution in surrounding boxes affects the \
potential. In Cell ",
  ButtonBox["7.73",
    ButtonData:>"Cell 7.73",
    ButtonStyle->"Hyperlink"],
  ", we show the resulting force field, evaluated on the grid."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(field\  = \ 
        Table[{{i\ \[CapitalDelta]x, 
              j\ \[CapitalDelta]y}, {\(Fx[\([i + 1, 
                      j + 1]\)]\)[\([3]\)], \(Fy[\([i + 1, 
                      j + 1]\)]\)[\([3]\)]} 0.001}, {i, 0, M - 1}, {j, 0, 
            M - 1}];\)\), "\n", 
    \(\(ListPlotVectorField[Flatten[field, 1], 
        Axes \[Rule] True];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.73"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0744689 0.895855 0.0744689 0.895855 [
[.25364 .06197 -9 -9 ]
[.25364 .06197 9 0 ]
[.43281 .06197 -9 -9 ]
[.43281 .06197 9 0 ]
[.61198 .06197 -9 -9 ]
[.61198 .06197 9 0 ]
[.79115 .06197 -9 -9 ]
[.79115 .06197 9 0 ]
[.97032 .06197 -3 -9 ]
[.97032 .06197 3 0 ]
[.06197 .25364 -18 -4.5 ]
[.06197 .25364 0 4.5 ]
[.06197 .43281 -18 -4.5 ]
[.06197 .43281 0 4.5 ]
[.06197 .61198 -18 -4.5 ]
[.06197 .61198 0 4.5 ]
[.06197 .79115 -18 -4.5 ]
[.06197 .79115 0 4.5 ]
[.06197 .97032 -6 -4.5 ]
[.06197 .97032 0 4.5 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.25364 .07447 m
.25364 .08072 L
s
[(0.2)] .25364 .06197 0 1 Mshowa
.43281 .07447 m
.43281 .08072 L
s
[(0.4)] .43281 .06197 0 1 Mshowa
.61198 .07447 m
.61198 .08072 L
s
[(0.6)] .61198 .06197 0 1 Mshowa
.79115 .07447 m
.79115 .08072 L
s
[(0.8)] .79115 .06197 0 1 Mshowa
.97032 .07447 m
.97032 .08072 L
s
[(1)] .97032 .06197 0 1 Mshowa
.125 Mabswid
.11926 .07447 m
.11926 .07822 L
s
.16405 .07447 m
.16405 .07822 L
s
.20885 .07447 m
.20885 .07822 L
s
.29843 .07447 m
.29843 .07822 L
s
.34323 .07447 m
.34323 .07822 L
s
.38802 .07447 m
.38802 .07822 L
s
.4776 .07447 m
.4776 .07822 L
s
.5224 .07447 m
.5224 .07822 L
s
.56719 .07447 m
.56719 .07822 L
s
.65677 .07447 m
.65677 .07822 L
s
.70157 .07447 m
.70157 .07822 L
s
.74636 .07447 m
.74636 .07822 L
s
.83595 .07447 m
.83595 .07822 L
s
.88074 .07447 m
.88074 .07822 L
s
.92553 .07447 m
.92553 .07822 L
s
.02968 .07447 m
.02968 .07822 L
s
.25 Mabswid
0 .07447 m
1 .07447 L
s
.07447 .25364 m
.08072 .25364 L
s
[(0.2)] .06197 .25364 1 0 Mshowa
.07447 .43281 m
.08072 .43281 L
s
[(0.4)] .06197 .43281 1 0 Mshowa
.07447 .61198 m
.08072 .61198 L
s
[(0.6)] .06197 .61198 1 0 Mshowa
.07447 .79115 m
.08072 .79115 L
s
[(0.8)] .06197 .79115 1 0 Mshowa
.07447 .97032 m
.08072 .97032 L
s
[(1)] .06197 .97032 1 0 Mshowa
.125 Mabswid
.07447 .11926 m
.07822 .11926 L
s
.07447 .16405 m
.07822 .16405 L
s
.07447 .20885 m
.07822 .20885 L
s
.07447 .29843 m
.07822 .29843 L
s
.07447 .34323 m
.07822 .34323 L
s
.07447 .38802 m
.07822 .38802 L
s
.07447 .4776 m
.07822 .4776 L
s
.07447 .5224 m
.07822 .5224 L
s
.07447 .56719 m
.07822 .56719 L
s
.07447 .65677 m
.07822 .65677 L
s
.07447 .70157 m
.07822 .70157 L
s
.07447 .74636 m
.07822 .74636 L
s
.07447 .83595 m
.07822 .83595 L
s
.07447 .88074 m
.07822 .88074 L
s
.07447 .92553 m
.07822 .92553 L
s
.07447 .02968 m
.07822 .02968 L
s
.25 Mabswid
.07447 0 m
.07447 1 L
s
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto fill
-0.02 0.005 moveto 0 0 lineto
-0.02 -0.005 lineto
-0.02 0.005 lineto stroke
} ifelse
grestore
} def
/MAarrowzero1 {
gsave
mathtops translate
0 0 Mdot
grestore
} def
% End of user PostScript
.0001 w
.07447 .07447 m
.07447 .07447 L
s
% Start of user PostScript
0 0 MAarrowzero1
% End of user PostScript
.07447 .11926 m
.12513 .0686 L
s
% Start of user PostScript
0 0.05 0.0565487 -0.00654867 MAarrowhead1
% End of user PostScript
.07447 .16405 m
.1195 .11902 L
s
% Start of user PostScript
0 0.1 0.0502655 0.0497345 MAarrowhead1
% End of user PostScript
.07447 .20885 m
.11387 .16945 L
s
% Start of user PostScript
0 0.15 0.0439823 0.106018 MAarrowhead1
% End of user PostScript
.07447 .25364 m
.10824 .21987 L
s
% Start of user PostScript
0 0.2 0.0376991 0.162301 MAarrowhead1
% End of user PostScript
.07447 .29843 m
.10261 .27029 L
s
% Start of user PostScript
0 0.25 0.0314159 0.218584 MAarrowhead1
% End of user PostScript
.07447 .34323 m
.09698 .32071 L
s
% Start of user PostScript
0 0.3 0.0251327 0.274867 MAarrowhead1
% End of user PostScript
.07447 .38802 m
.09136 .37113 L
s
% Start of user PostScript
0 0.35 0.0188496 0.33115 MAarrowhead1
% End of user PostScript
.07447 .43281 m
.08573 .42155 L
s
% Start of user PostScript
0 0.4 0.0125664 0.387434 MAarrowhead1
% End of user PostScript
.07447 .4776 m
.0801 .47197 L
s
% Start of user PostScript
0 0.45 0.00628319 0.443717 MAarrowhead1
% End of user PostScript
.07447 .5224 m
.07447 .5224 L
s
% Start of user PostScript
0 0.5 MAarrowzero1
% End of user PostScript
.07447 .56719 m
.06884 .57282 L
s
% Start of user PostScript
0 0.55 -0.00628319 0.556283 MAarrowhead1
% End of user PostScript
.07447 .61198 m
.06321 .62324 L
s
% Start of user PostScript
0 0.6 -0.0125664 0.612566 MAarrowhead1
% End of user PostScript
.07447 .65677 m
.05758 .67366 L
s
% Start of user PostScript
0 0.65 -0.0188496 0.66885 MAarrowhead1
% End of user PostScript
.07447 .70157 m
.05195 .72408 L
s
% Start of user PostScript
0 0.7 -0.0251327 0.725133 MAarrowhead1
% End of user PostScript
.07447 .74636 m
.04632 .7745 L
s
% Start of user PostScript
0 0.75 -0.0314159 0.781416 MAarrowhead1
% End of user PostScript
.07447 .79115 m
.0407 .82493 L
s
% Start of user PostScript
0 0.8 -0.0376991 0.837699 MAarrowhead1
% End of user PostScript
.07447 .83595 m
.03507 .87535 L
s
% Start of user PostScript
0 0.85 -0.0439823 0.893982 MAarrowhead1
% End of user PostScript
.07447 .88074 m
.02944 .92577 L
s
% Start of user PostScript
0 0.9 -0.0502655 0.950265 MAarrowhead1
% End of user PostScript
.07447 .92553 m
.02381 .97619 L
s
% Start of user PostScript
0 0.95 -0.0565487 1.00655 MAarrowhead1
% End of user PostScript
.11926 .07447 m
.0686 .12513 L
s
% Start of user PostScript
0.05 0 -0.00654867 0.0565487 MAarrowhead1
% End of user PostScript
.11926 .11926 m
.11926 .11926 L
s
% Start of user PostScript
0.05 0.05 MAarrowzero1
% End of user PostScript
.11926 .16405 m
.16992 .1134 L
s
% Start of user PostScript
0.05 0.1 0.106549 0.0434513 MAarrowhead1
% End of user PostScript
.11926 .20885 m
.16429 .16382 L
s
% Start of user PostScript
0.05 0.15 0.100265 0.0997345 MAarrowhead1
% End of user PostScript
.11926 .25364 m
.15866 .21424 L
s
% Start of user PostScript
0.05 0.2 0.0939823 0.156018 MAarrowhead1
% End of user PostScript
.11926 .29843 m
.15303 .26466 L
s
% Start of user PostScript
0.05 0.25 0.0876991 0.212301 MAarrowhead1
% End of user PostScript
.11926 .34323 m
.14741 .31508 L
s
% Start of user PostScript
0.05 0.3 0.0814159 0.268584 MAarrowhead1
% End of user PostScript
.11926 .38802 m
.14178 .3655 L
s
% Start of user PostScript
0.05 0.35 0.0751327 0.324867 MAarrowhead1
% End of user PostScript
.11926 .43281 m
.13615 .41592 L
s
% Start of user PostScript
0.05 0.4 0.0688496 0.38115 MAarrowhead1
% End of user PostScript
.11926 .4776 m
.13052 .46635 L
s
% Start of user PostScript
0.05 0.45 0.0625664 0.437434 MAarrowhead1
% End of user PostScript
.11926 .5224 m
.12489 .51677 L
s
% Start of user PostScript
0.05 0.5 0.0562832 0.493717 MAarrowhead1
% End of user PostScript
.11926 .56719 m
.11926 .56719 L
s
% Start of user PostScript
0.05 0.55 MAarrowzero1
% End of user PostScript
.11926 .61198 m
.11363 .61761 L
s
% Start of user PostScript
0.05 0.6 0.0437168 0.606283 MAarrowhead1
% End of user PostScript
.11926 .65677 m
.108 .66803 L
s
% Start of user PostScript
0.05 0.65 0.0374336 0.662566 MAarrowhead1
% End of user PostScript
.11926 .70157 m
.10238 .71845 L
s
% Start of user PostScript
0.05 0.7 0.0311504 0.71885 MAarrowhead1
% End of user PostScript
.11926 .74636 m
.09675 .76888 L
s
% Start of user PostScript
0.05 0.75 0.0248673 0.775133 MAarrowhead1
% End of user PostScript
.11926 .79115 m
.09112 .8193 L
s
% Start of user PostScript
0.05 0.8 0.0185841 0.831416 MAarrowhead1
% End of user PostScript
.11926 .83595 m
.08549 .86972 L
s
% Start of user PostScript
0.05 0.85 0.0123009 0.887699 MAarrowhead1
% End of user PostScript
.11926 .88074 m
.07986 .92014 L
s
% Start of user PostScript
0.05 0.9 0.0060177 0.943982 MAarrowhead1
% End of user PostScript
.11926 .92553 m
.07423 .97056 L
s
% Start of user PostScript
0.05 0.95 -0.000265482 1.00027 MAarrowhead1
% End of user PostScript
.16405 .07447 m
.11902 .1195 L
s
% Start of user PostScript
0.1 0 0.0497345 0.0502655 MAarrowhead1
% End of user PostScript
.16405 .11926 m
.1134 .16992 L
s
% Start of user PostScript
0.1 0.05 0.0434513 0.106549 MAarrowhead1
% End of user PostScript
.16405 .16405 m
.16405 .16405 L
s
% Start of user PostScript
0.1 0.1 MAarrowzero1
% End of user PostScript
.16405 .20885 m
.21471 .15819 L
s
% Start of user PostScript
0.1 0.15 0.156549 0.0934513 MAarrowhead1
% End of user PostScript
.16405 .25364 m
.20908 .20861 L
s
% Start of user PostScript
0.1 0.2 0.150265 0.149735 MAarrowhead1
% End of user PostScript
.16405 .29843 m
.20346 .25903 L
s
% Start of user PostScript
0.1 0.25 0.143982 0.206018 MAarrowhead1
% End of user PostScript
.16405 .34323 m
.19783 .30945 L
s
% Start of user PostScript
0.1 0.3 0.137699 0.262301 MAarrowhead1
% End of user PostScript
.16405 .38802 m
.1922 .35987 L
s
% Start of user PostScript
0.1 0.35 0.131416 0.318584 MAarrowhead1
% End of user PostScript
.16405 .43281 m
.18657 .4103 L
s
% Start of user PostScript
0.1 0.4 0.125133 0.374867 MAarrowhead1
% End of user PostScript
.16405 .4776 m
.18094 .46072 L
s
% Start of user PostScript
0.1 0.45 0.11885 0.43115 MAarrowhead1
% End of user PostScript
.16405 .5224 m
.17531 .51114 L
s
% Start of user PostScript
0.1 0.5 0.112566 0.487434 MAarrowhead1
% End of user PostScript
.16405 .56719 m
.16968 .56156 L
s
% Start of user PostScript
0.1 0.55 0.106283 0.543717 MAarrowhead1
% End of user PostScript
.16405 .61198 m
.16405 .61198 L
s
% Start of user PostScript
0.1 0.6 MAarrowzero1
% End of user PostScript
.16405 .65677 m
.15843 .6624 L
s
% Start of user PostScript
0.1 0.65 0.0937168 0.656283 MAarrowhead1
% End of user PostScript
.16405 .70157 m
.1528 .71282 L
s
% Start of user PostScript
0.1 0.7 0.0874336 0.712566 MAarrowhead1
% End of user PostScript
.16405 .74636 m
.14717 .76325 L
s
% Start of user PostScript
0.1 0.75 0.0811504 0.76885 MAarrowhead1
% End of user PostScript
.16405 .79115 m
.14154 .81367 L
s
% Start of user PostScript
0.1 0.8 0.0748673 0.825133 MAarrowhead1
% End of user PostScript
.16405 .83595 m
.13591 .86409 L
s
% Start of user PostScript
0.1 0.85 0.0685841 0.881416 MAarrowhead1
% End of user PostScript
.16405 .88074 m
.13028 .91451 L
s
% Start of user PostScript
0.1 0.9 0.0623009 0.937699 MAarrowhead1
% End of user PostScript
.16405 .92553 m
.12465 .96493 L
s
% Start of user PostScript
0.1 0.95 0.0560177 0.993982 MAarrowhead1
% End of user PostScript
.20885 .07447 m
.16945 .11387 L
s
% Start of user PostScript
0.15 0 0.106018 0.0439823 MAarrowhead1
% End of user PostScript
.20885 .11926 m
.16382 .16429 L
s
% Start of user PostScript
0.15 0.05 0.0997345 0.100265 MAarrowhead1
% End of user PostScript
.20885 .16405 m
.15819 .21471 L
s
% Start of user PostScript
0.15 0.1 0.0934513 0.156549 MAarrowhead1
% End of user PostScript
.20885 .20885 m
.20885 .20885 L
s
% Start of user PostScript
0.15 0.15 MAarrowzero1
% End of user PostScript
.20885 .25364 m
.25951 .20298 L
s
% Start of user PostScript
0.15 0.2 0.206549 0.143451 MAarrowhead1
% End of user PostScript
.20885 .29843 m
.25388 .2534 L
s
% Start of user PostScript
0.15 0.25 0.200265 0.199735 MAarrowhead1
% End of user PostScript
.20885 .34323 m
.24825 .30382 L
s
% Start of user PostScript
0.15 0.3 0.193982 0.256018 MAarrowhead1
% End of user PostScript
.20885 .38802 m
.24262 .35425 L
s
% Start of user PostScript
0.15 0.35 0.187699 0.312301 MAarrowhead1
% End of user PostScript
.20885 .43281 m
.23699 .40467 L
s
% Start of user PostScript
0.15 0.4 0.181416 0.368584 MAarrowhead1
% End of user PostScript
.20885 .4776 m
.23136 .45509 L
s
% Start of user PostScript
0.15 0.45 0.175133 0.424867 MAarrowhead1
% End of user PostScript
.20885 .5224 m
.22573 .50551 L
s
% Start of user PostScript
0.15 0.5 0.16885 0.48115 MAarrowhead1
% End of user PostScript
.20885 .56719 m
.2201 .55593 L
s
% Start of user PostScript
0.15 0.55 0.162566 0.537434 MAarrowhead1
% End of user PostScript
.20885 .61198 m
.21448 .60635 L
s
% Start of user PostScript
0.15 0.6 0.156283 0.593717 MAarrowhead1
% End of user PostScript
.20885 .65677 m
.20885 .65677 L
s
% Start of user PostScript
0.15 0.65 MAarrowzero1
% End of user PostScript
.20885 .70157 m
.20322 .7072 L
s
% Start of user PostScript
0.15 0.7 0.143717 0.706283 MAarrowhead1
% End of user PostScript
.20885 .74636 m
.19759 .75762 L
s
% Start of user PostScript
0.15 0.75 0.137434 0.762566 MAarrowhead1
% End of user PostScript
.20885 .79115 m
.19196 .80804 L
s
% Start of user PostScript
0.15 0.8 0.13115 0.81885 MAarrowhead1
% End of user PostScript
.20885 .83595 m
.18633 .85846 L
s
% Start of user PostScript
0.15 0.85 0.124867 0.875133 MAarrowhead1
% End of user PostScript
.20885 .88074 m
.1807 .90888 L
s
% Start of user PostScript
0.15 0.9 0.118584 0.931416 MAarrowhead1
% End of user PostScript
.20885 .92553 m
.17507 .9593 L
s
% Start of user PostScript
0.15 0.95 0.112301 0.987699 MAarrowhead1
% End of user PostScript
.25364 .07447 m
.21987 .10824 L
s
% Start of user PostScript
0.2 0 0.162301 0.0376991 MAarrowhead1
% End of user PostScript
.25364 .11926 m
.21424 .15866 L
s
% Start of user PostScript
0.2 0.05 0.156018 0.0939823 MAarrowhead1
% End of user PostScript
.25364 .16405 m
.20861 .20908 L
s
% Start of user PostScript
0.2 0.1 0.149735 0.150265 MAarrowhead1
% End of user PostScript
.25364 .20885 m
.20298 .25951 L
s
% Start of user PostScript
0.2 0.15 0.143451 0.206549 MAarrowhead1
% End of user PostScript
.25364 .25364 m
.25364 .25364 L
s
% Start of user PostScript
0.2 0.2 MAarrowzero1
% End of user PostScript
.25364 .29843 m
.3043 .24777 L
s
% Start of user PostScript
0.2 0.25 0.256549 0.193451 MAarrowhead1
% End of user PostScript
.25364 .34323 m
.29867 .29819 L
s
% Start of user PostScript
0.2 0.3 0.250265 0.249735 MAarrowhead1
% End of user PostScript
.25364 .38802 m
.29304 .34862 L
s
% Start of user PostScript
0.2 0.35 0.243982 0.306018 MAarrowhead1
% End of user PostScript
.25364 .43281 m
.28741 .39904 L
s
% Start of user PostScript
0.2 0.4 0.237699 0.362301 MAarrowhead1
% End of user PostScript
.25364 .4776 m
.28178 .44946 L
s
% Start of user PostScript
0.2 0.45 0.231416 0.418584 MAarrowhead1
% End of user PostScript
.25364 .5224 m
.27616 .49988 L
s
% Start of user PostScript
0.2 0.5 0.225133 0.474867 MAarrowhead1
% End of user PostScript
.25364 .56719 m
.27053 .5503 L
s
% Start of user PostScript
0.2 0.55 0.21885 0.53115 MAarrowhead1
% End of user PostScript
.25364 .61198 m
.2649 .60072 L
s
% Start of user PostScript
0.2 0.6 0.212566 0.587434 MAarrowhead1
% End of user PostScript
.25364 .65677 m
.25927 .65115 L
s
% Start of user PostScript
0.2 0.65 0.206283 0.643717 MAarrowhead1
% End of user PostScript
.25364 .70157 m
.25364 .70157 L
s
% Start of user PostScript
0.2 0.7 MAarrowzero1
% End of user PostScript
.25364 .74636 m
.24801 .75199 L
s
% Start of user PostScript
0.2 0.75 0.193717 0.756283 MAarrowhead1
% End of user PostScript
.25364 .79115 m
.24238 .80241 L
s
% Start of user PostScript
0.2 0.8 0.187434 0.812566 MAarrowhead1
% End of user PostScript
.25364 .83595 m
.23675 .85283 L
s
% Start of user PostScript
0.2 0.85 0.18115 0.86885 MAarrowhead1
% End of user PostScript
.25364 .88074 m
.23112 .90325 L
s
% Start of user PostScript
0.2 0.9 0.174867 0.925133 MAarrowhead1
% End of user PostScript
.25364 .92553 m
.2255 .95368 L
s
% Start of user PostScript
0.2 0.95 0.168584 0.981416 MAarrowhead1
% End of user PostScript
.29843 .07447 m
.27029 .10261 L
s
% Start of user PostScript
0.25 0 0.218584 0.0314159 MAarrowhead1
% End of user PostScript
.29843 .11926 m
.26466 .15303 L
s
% Start of user PostScript
0.25 0.05 0.212301 0.0876991 MAarrowhead1
% End of user PostScript
.29843 .16405 m
.25903 .20346 L
s
% Start of user PostScript
0.25 0.1 0.206018 0.143982 MAarrowhead1
% End of user PostScript
.29843 .20885 m
.2534 .25388 L
s
% Start of user PostScript
0.25 0.15 0.199735 0.200265 MAarrowhead1
% End of user PostScript
.29843 .25364 m
.24777 .3043 L
s
% Start of user PostScript
0.25 0.2 0.193451 0.256549 MAarrowhead1
% End of user PostScript
.29843 .29843 m
.29843 .29843 L
s
% Start of user PostScript
0.25 0.25 MAarrowzero1
% End of user PostScript
.29843 .34323 m
.34909 .29257 L
s
% Start of user PostScript
0.25 0.3 0.306549 0.243451 MAarrowhead1
% End of user PostScript
.29843 .38802 m
.34346 .34299 L
s
% Start of user PostScript
0.25 0.35 0.300265 0.299735 MAarrowhead1
% End of user PostScript
.29843 .43281 m
.33783 .39341 L
s
% Start of user PostScript
0.25 0.4 0.293982 0.356018 MAarrowhead1
% End of user PostScript
.29843 .4776 m
.33221 .44383 L
s
% Start of user PostScript
0.25 0.45 0.287699 0.412301 MAarrowhead1
% End of user PostScript
.29843 .5224 m
.32658 .49425 L
s
% Start of user PostScript
0.25 0.5 0.281416 0.468584 MAarrowhead1
% End of user PostScript
.29843 .56719 m
.32095 .54467 L
s
% Start of user PostScript
0.25 0.55 0.275133 0.524867 MAarrowhead1
% End of user PostScript
.29843 .61198 m
.31532 .5951 L
s
% Start of user PostScript
0.25 0.6 0.26885 0.58115 MAarrowhead1
% End of user PostScript
.29843 .65677 m
.30969 .64552 L
s
% Start of user PostScript
0.25 0.65 0.262566 0.637434 MAarrowhead1
% End of user PostScript
.29843 .70157 m
.30406 .69594 L
s
% Start of user PostScript
0.25 0.7 0.256283 0.693717 MAarrowhead1
% End of user PostScript
.29843 .74636 m
.29843 .74636 L
s
% Start of user PostScript
0.25 0.75 MAarrowzero1
% End of user PostScript
.29843 .79115 m
.2928 .79678 L
s
% Start of user PostScript
0.25 0.8 0.243717 0.806283 MAarrowhead1
% End of user PostScript
.29843 .83595 m
.28718 .8472 L
s
% Start of user PostScript
0.25 0.85 0.237434 0.862566 MAarrowhead1
% End of user PostScript
.29843 .88074 m
.28155 .89762 L
s
% Start of user PostScript
0.25 0.9 0.23115 0.91885 MAarrowhead1
% End of user PostScript
.29843 .92553 m
.27592 .94805 L
s
% Start of user PostScript
0.25 0.95 0.224867 0.975133 MAarrowhead1
% End of user PostScript
.34323 .07447 m
.32071 .09698 L
s
% Start of user PostScript
0.3 0 0.274867 0.0251327 MAarrowhead1
% End of user PostScript
.34323 .11926 m
.31508 .14741 L
s
% Start of user PostScript
0.3 0.05 0.268584 0.0814159 MAarrowhead1
% End of user PostScript
.34323 .16405 m
.30945 .19783 L
s
% Start of user PostScript
0.3 0.1 0.262301 0.137699 MAarrowhead1
% End of user PostScript
.34323 .20885 m
.30382 .24825 L
s
% Start of user PostScript
0.3 0.15 0.256018 0.193982 MAarrowhead1
% End of user PostScript
.34323 .25364 m
.29819 .29867 L
s
% Start of user PostScript
0.3 0.2 0.249735 0.250265 MAarrowhead1
% End of user PostScript
.34323 .29843 m
.29257 .34909 L
s
% Start of user PostScript
0.3 0.25 0.243451 0.306549 MAarrowhead1
% End of user PostScript
.34323 .34323 m
.34323 .34323 L
s
% Start of user PostScript
0.3 0.3 MAarrowzero1
% End of user PostScript
.34323 .38802 m
.39388 .33736 L
s
% Start of user PostScript
0.3 0.35 0.356549 0.293451 MAarrowhead1
% End of user PostScript
.34323 .43281 m
.38826 .38778 L
s
% Start of user PostScript
0.3 0.4 0.350265 0.349735 MAarrowhead1
% End of user PostScript
.34323 .4776 m
.38263 .4382 L
s
% Start of user PostScript
0.3 0.45 0.343982 0.406018 MAarrowhead1
% End of user PostScript
.34323 .5224 m
.377 .48862 L
s
% Start of user PostScript
0.3 0.5 0.337699 0.462301 MAarrowhead1
% End of user PostScript
.34323 .56719 m
.37137 .53905 L
s
% Start of user PostScript
0.3 0.55 0.331416 0.518584 MAarrowhead1
% End of user PostScript
.34323 .61198 m
.36574 .58947 L
s
% Start of user PostScript
0.3 0.6 0.325133 0.574867 MAarrowhead1
% End of user PostScript
.34323 .65677 m
.36011 .63989 L
s
% Start of user PostScript
0.3 0.65 0.31885 0.63115 MAarrowhead1
% End of user PostScript
.34323 .70157 m
.35448 .69031 L
s
% Start of user PostScript
0.3 0.7 0.312566 0.687434 MAarrowhead1
% End of user PostScript
.34323 .74636 m
.34885 .74073 L
s
% Start of user PostScript
0.3 0.75 0.306283 0.743717 MAarrowhead1
% End of user PostScript
.34323 .79115 m
.34323 .79115 L
s
% Start of user PostScript
0.3 0.8 MAarrowzero1
% End of user PostScript
.34323 .83595 m
.3376 .84157 L
s
% Start of user PostScript
0.3 0.85 0.293717 0.856283 MAarrowhead1
% End of user PostScript
.34323 .88074 m
.33197 .892 L
s
% Start of user PostScript
0.3 0.9 0.287434 0.912566 MAarrowhead1
% End of user PostScript
.34323 .92553 m
.32634 .94242 L
s
% Start of user PostScript
0.3 0.95 0.28115 0.96885 MAarrowhead1
% End of user PostScript
.38802 .07447 m
.37113 .09136 L
s
% Start of user PostScript
0.35 0 0.33115 0.0188496 MAarrowhead1
% End of user PostScript
.38802 .11926 m
.3655 .14178 L
s
% Start of user PostScript
0.35 0.05 0.324867 0.0751327 MAarrowhead1
% End of user PostScript
.38802 .16405 m
.35987 .1922 L
s
% Start of user PostScript
0.35 0.1 0.318584 0.131416 MAarrowhead1
% End of user PostScript
.38802 .20885 m
.35425 .24262 L
s
% Start of user PostScript
0.35 0.15 0.312301 0.187699 MAarrowhead1
% End of user PostScript
.38802 .25364 m
.34862 .29304 L
s
% Start of user PostScript
0.35 0.2 0.306018 0.243982 MAarrowhead1
% End of user PostScript
.38802 .29843 m
.34299 .34346 L
s
% Start of user PostScript
0.35 0.25 0.299735 0.300265 MAarrowhead1
% End of user PostScript
.38802 .34323 m
.33736 .39388 L
s
% Start of user PostScript
0.35 0.3 0.293451 0.356549 MAarrowhead1
% End of user PostScript
.38802 .38802 m
.38802 .38802 L
s
% Start of user PostScript
0.35 0.35 MAarrowzero1
% End of user PostScript
.38802 .43281 m
.43868 .38215 L
s
% Start of user PostScript
0.35 0.4 0.406549 0.343451 MAarrowhead1
% End of user PostScript
.38802 .4776 m
.43305 .43257 L
s
% Start of user PostScript
0.35 0.45 0.400265 0.399735 MAarrowhead1
% End of user PostScript
.38802 .5224 m
.42742 .48299 L
s
% Start of user PostScript
0.35 0.5 0.393982 0.456018 MAarrowhead1
% End of user PostScript
.38802 .56719 m
.42179 .53342 L
s
% Start of user PostScript
0.35 0.55 0.387699 0.512301 MAarrowhead1
% End of user PostScript
.38802 .61198 m
.41616 .58384 L
s
% Start of user PostScript
0.35 0.6 0.381416 0.568584 MAarrowhead1
% End of user PostScript
.38802 .65677 m
.41053 .63426 L
s
% Start of user PostScript
0.35 0.65 0.375133 0.624867 MAarrowhead1
% End of user PostScript
.38802 .70157 m
.4049 .68468 L
s
% Start of user PostScript
0.35 0.7 0.36885 0.68115 MAarrowhead1
% End of user PostScript
.38802 .74636 m
.39928 .7351 L
s
% Start of user PostScript
0.35 0.75 0.362566 0.737434 MAarrowhead1
% End of user PostScript
.38802 .79115 m
.39365 .78552 L
s
% Start of user PostScript
0.35 0.8 0.356283 0.793717 MAarrowhead1
% End of user PostScript
.38802 .83595 m
.38802 .83595 L
s
% Start of user PostScript
0.35 0.85 MAarrowzero1
% End of user PostScript
.38802 .88074 m
.38239 .88637 L
s
% Start of user PostScript
0.35 0.9 0.343717 0.906283 MAarrowhead1
% End of user PostScript
.38802 .92553 m
.37676 .93679 L
s
% Start of user PostScript
0.35 0.95 0.337434 0.962566 MAarrowhead1
% End of user PostScript
.43281 .07447 m
.42155 .08573 L
s
% Start of user PostScript
0.4 0 0.387434 0.0125664 MAarrowhead1
% End of user PostScript
.43281 .11926 m
.41592 .13615 L
s
% Start of user PostScript
0.4 0.05 0.38115 0.0688496 MAarrowhead1
% End of user PostScript
.43281 .16405 m
.4103 .18657 L
s
% Start of user PostScript
0.4 0.1 0.374867 0.125133 MAarrowhead1
% End of user PostScript
.43281 .20885 m
.40467 .23699 L
s
% Start of user PostScript
0.4 0.15 0.368584 0.181416 MAarrowhead1
% End of user PostScript
.43281 .25364 m
.39904 .28741 L
s
% Start of user PostScript
0.4 0.2 0.362301 0.237699 MAarrowhead1
% End of user PostScript
.43281 .29843 m
.39341 .33783 L
s
% Start of user PostScript
0.4 0.25 0.356018 0.293982 MAarrowhead1
% End of user PostScript
.43281 .34323 m
.38778 .38826 L
s
% Start of user PostScript
0.4 0.3 0.349735 0.350265 MAarrowhead1
% End of user PostScript
.43281 .38802 m
.38215 .43868 L
s
% Start of user PostScript
0.4 0.35 0.343451 0.406549 MAarrowhead1
% End of user PostScript
.43281 .43281 m
.43281 .43281 L
s
% Start of user PostScript
0.4 0.4 MAarrowzero1
% End of user PostScript
.43281 .4776 m
.48347 .42694 L
s
% Start of user PostScript
0.4 0.45 0.456549 0.393451 MAarrowhead1
% End of user PostScript
.43281 .5224 m
.47784 .47737 L
s
% Start of user PostScript
0.4 0.5 0.450265 0.449735 MAarrowhead1
% End of user PostScript
.43281 .56719 m
.47221 .52779 L
s
% Start of user PostScript
0.4 0.55 0.443982 0.506018 MAarrowhead1
% End of user PostScript
.43281 .61198 m
.46658 .57821 L
s
% Start of user PostScript
0.4 0.6 0.437699 0.562301 MAarrowhead1
% End of user PostScript
.43281 .65677 m
.46095 .62863 L
s
% Start of user PostScript
0.4 0.65 0.431416 0.618584 MAarrowhead1
% End of user PostScript
.43281 .70157 m
.45533 .67905 L
s
% Start of user PostScript
0.4 0.7 0.425133 0.674867 MAarrowhead1
% End of user PostScript
.43281 .74636 m
.4497 .72947 L
s
% Start of user PostScript
0.4 0.75 0.41885 0.73115 MAarrowhead1
% End of user PostScript
.43281 .79115 m
.44407 .7799 L
s
% Start of user PostScript
0.4 0.8 0.412566 0.787434 MAarrowhead1
% End of user PostScript
.43281 .83595 m
.43844 .83032 L
s
% Start of user PostScript
0.4 0.85 0.406283 0.843717 MAarrowhead1
% End of user PostScript
.43281 .88074 m
.43281 .88074 L
s
% Start of user PostScript
0.4 0.9 MAarrowzero1
% End of user PostScript
.43281 .92553 m
.42718 .93116 L
s
% Start of user PostScript
0.4 0.95 0.393717 0.956283 MAarrowhead1
% End of user PostScript
.4776 .07447 m
.47197 .0801 L
s
% Start of user PostScript
0.45 0 0.443717 0.00628319 MAarrowhead1
% End of user PostScript
.4776 .11926 m
.46635 .13052 L
s
% Start of user PostScript
0.45 0.05 0.437434 0.0625664 MAarrowhead1
% End of user PostScript
.4776 .16405 m
.46072 .18094 L
s
% Start of user PostScript
0.45 0.1 0.43115 0.11885 MAarrowhead1
% End of user PostScript
.4776 .20885 m
.45509 .23136 L
s
% Start of user PostScript
0.45 0.15 0.424867 0.175133 MAarrowhead1
% End of user PostScript
.4776 .25364 m
.44946 .28178 L
s
% Start of user PostScript
0.45 0.2 0.418584 0.231416 MAarrowhead1
% End of user PostScript
.4776 .29843 m
.44383 .33221 L
s
% Start of user PostScript
0.45 0.25 0.412301 0.287699 MAarrowhead1
% End of user PostScript
.4776 .34323 m
.4382 .38263 L
s
% Start of user PostScript
0.45 0.3 0.406018 0.343982 MAarrowhead1
% End of user PostScript
.4776 .38802 m
.43257 .43305 L
s
% Start of user PostScript
0.45 0.35 0.399735 0.400265 MAarrowhead1
% End of user PostScript
.4776 .43281 m
.42694 .48347 L
s
% Start of user PostScript
0.45 0.4 0.393451 0.456549 MAarrowhead1
% End of user PostScript
.4776 .4776 m
.4776 .4776 L
s
% Start of user PostScript
0.45 0.45 MAarrowzero1
% End of user PostScript
.4776 .5224 m
.52826 .47174 L
s
% Start of user PostScript
0.45 0.5 0.506549 0.443451 MAarrowhead1
% End of user PostScript
.4776 .56719 m
.52263 .52216 L
s
% Start of user PostScript
0.45 0.55 0.500265 0.499735 MAarrowhead1
% End of user PostScript
.4776 .61198 m
.51701 .57258 L
s
% Start of user PostScript
0.45 0.6 0.493982 0.556018 MAarrowhead1
% End of user PostScript
.4776 .65677 m
.51138 .623 L
s
% Start of user PostScript
0.45 0.65 0.487699 0.612301 MAarrowhead1
% End of user PostScript
.4776 .70157 m
.50575 .67342 L
s
% Start of user PostScript
0.45 0.7 0.481416 0.668584 MAarrowhead1
% End of user PostScript
.4776 .74636 m
.50012 .72384 L
s
% Start of user PostScript
0.45 0.75 0.475133 0.724867 MAarrowhead1
% End of user PostScript
.4776 .79115 m
.49449 .77427 L
s
% Start of user PostScript
0.45 0.8 0.46885 0.78115 MAarrowhead1
% End of user PostScript
.4776 .83595 m
.48886 .82469 L
s
% Start of user PostScript
0.45 0.85 0.462566 0.837434 MAarrowhead1
% End of user PostScript
.4776 .88074 m
.48323 .87511 L
s
% Start of user PostScript
0.45 0.9 0.456283 0.893717 MAarrowhead1
% End of user PostScript
.4776 .92553 m
.4776 .92553 L
s
% Start of user PostScript
0.45 0.95 MAarrowzero1
% End of user PostScript
.5224 .07447 m
.5224 .07447 L
s
% Start of user PostScript
0.5 0 MAarrowzero1
% End of user PostScript
.5224 .11926 m
.51677 .12489 L
s
% Start of user PostScript
0.5 0.05 0.493717 0.0562832 MAarrowhead1
% End of user PostScript
.5224 .16405 m
.51114 .17531 L
s
% Start of user PostScript
0.5 0.1 0.487434 0.112566 MAarrowhead1
% End of user PostScript
.5224 .20885 m
.50551 .22573 L
s
% Start of user PostScript
0.5 0.15 0.48115 0.16885 MAarrowhead1
% End of user PostScript
.5224 .25364 m
.49988 .27616 L
s
% Start of user PostScript
0.5 0.2 0.474867 0.225133 MAarrowhead1
% End of user PostScript
.5224 .29843 m
.49425 .32658 L
s
% Start of user PostScript
0.5 0.25 0.468584 0.281416 MAarrowhead1
% End of user PostScript
.5224 .34323 m
.48862 .377 L
s
% Start of user PostScript
0.5 0.3 0.462301 0.337699 MAarrowhead1
% End of user PostScript
.5224 .38802 m
.48299 .42742 L
s
% Start of user PostScript
0.5 0.35 0.456018 0.393982 MAarrowhead1
% End of user PostScript
.5224 .43281 m
.47737 .47784 L
s
% Start of user PostScript
0.5 0.4 0.449735 0.450265 MAarrowhead1
% End of user PostScript
.5224 .4776 m
.47174 .52826 L
s
% Start of user PostScript
0.5 0.45 0.443451 0.506549 MAarrowhead1
% End of user PostScript
.5224 .5224 m
.5224 .5224 L
s
% Start of user PostScript
0.5 0.5 MAarrowzero1
% End of user PostScript
.5224 .56719 m
.57306 .51653 L
s
% Start of user PostScript
0.5 0.55 0.556549 0.493451 MAarrowhead1
% End of user PostScript
.5224 .61198 m
.56743 .56695 L
s
% Start of user PostScript
0.5 0.6 0.550265 0.549735 MAarrowhead1
% End of user PostScript
.5224 .65677 m
.5618 .61737 L
s
% Start of user PostScript
0.5 0.65 0.543982 0.606018 MAarrowhead1
% End of user PostScript
.5224 .70157 m
.55617 .66779 L
s
% Start of user PostScript
0.5 0.7 0.537699 0.662301 MAarrowhead1
% End of user PostScript
.5224 .74636 m
.55054 .71822 L
s
% Start of user PostScript
0.5 0.75 0.531416 0.718584 MAarrowhead1
% End of user PostScript
.5224 .79115 m
.54491 .76864 L
s
% Start of user PostScript
0.5 0.8 0.525133 0.774867 MAarrowhead1
% End of user PostScript
.5224 .83595 m
.53928 .81906 L
s
% Start of user PostScript
0.5 0.85 0.51885 0.83115 MAarrowhead1
% End of user PostScript
.5224 .88074 m
.53365 .86948 L
s
% Start of user PostScript
0.5 0.9 0.512566 0.887434 MAarrowhead1
% End of user PostScript
.5224 .92553 m
.52803 .9199 L
s
% Start of user PostScript
0.5 0.95 0.506283 0.943717 MAarrowhead1
% End of user PostScript
.56719 .07447 m
.57282 .06884 L
s
% Start of user PostScript
0.55 0 0.556283 -0.00628319 MAarrowhead1
% End of user PostScript
.56719 .11926 m
.56719 .11926 L
s
% Start of user PostScript
0.55 0.05 MAarrowzero1
% End of user PostScript
.56719 .16405 m
.56156 .16968 L
s
% Start of user PostScript
0.55 0.1 0.543717 0.106283 MAarrowhead1
% End of user PostScript
.56719 .20885 m
.55593 .2201 L
s
% Start of user PostScript
0.55 0.15 0.537434 0.162566 MAarrowhead1
% End of user PostScript
.56719 .25364 m
.5503 .27053 L
s
% Start of user PostScript
0.55 0.2 0.53115 0.21885 MAarrowhead1
% End of user PostScript
.56719 .29843 m
.54467 .32095 L
s
% Start of user PostScript
0.55 0.25 0.524867 0.275133 MAarrowhead1
% End of user PostScript
.56719 .34323 m
.53905 .37137 L
s
% Start of user PostScript
0.55 0.3 0.518584 0.331416 MAarrowhead1
% End of user PostScript
.56719 .38802 m
.53342 .42179 L
s
% Start of user PostScript
0.55 0.35 0.512301 0.387699 MAarrowhead1
% End of user PostScript
.56719 .43281 m
.52779 .47221 L
s
% Start of user PostScript
0.55 0.4 0.506018 0.443982 MAarrowhead1
% End of user PostScript
.56719 .4776 m
.52216 .52263 L
s
% Start of user PostScript
0.55 0.45 0.499735 0.500265 MAarrowhead1
% End of user PostScript
.56719 .5224 m
.51653 .57306 L
s
% Start of user PostScript
0.55 0.5 0.493451 0.556549 MAarrowhead1
% End of user PostScript
.56719 .56719 m
.56719 .56719 L
s
% Start of user PostScript
0.55 0.55 MAarrowzero1
% End of user PostScript
.56719 .61198 m
.61785 .56132 L
s
% Start of user PostScript
0.55 0.6 0.606549 0.543451 MAarrowhead1
% End of user PostScript
.56719 .65677 m
.61222 .61174 L
s
% Start of user PostScript
0.55 0.65 0.600265 0.599735 MAarrowhead1
% End of user PostScript
.56719 .70157 m
.60659 .66217 L
s
% Start of user PostScript
0.55 0.7 0.593982 0.656018 MAarrowhead1
% End of user PostScript
.56719 .74636 m
.60096 .71259 L
s
% Start of user PostScript
0.55 0.75 0.587699 0.712301 MAarrowhead1
% End of user PostScript
.56719 .79115 m
.59533 .76301 L
s
% Start of user PostScript
0.55 0.8 0.581416 0.768584 MAarrowhead1
% End of user PostScript
.56719 .83595 m
.5897 .81343 L
s
% Start of user PostScript
0.55 0.85 0.575133 0.824867 MAarrowhead1
% End of user PostScript
.56719 .88074 m
.58408 .86385 L
s
% Start of user PostScript
0.55 0.9 0.56885 0.88115 MAarrowhead1
% End of user PostScript
.56719 .92553 m
.57845 .91427 L
s
% Start of user PostScript
0.55 0.95 0.562566 0.937434 MAarrowhead1
% End of user PostScript
.61198 .07447 m
.62324 .06321 L
s
% Start of user PostScript
0.6 0 0.612566 -0.0125664 MAarrowhead1
% End of user PostScript
.61198 .11926 m
.61761 .11363 L
s
% Start of user PostScript
0.6 0.05 0.606283 0.0437168 MAarrowhead1
% End of user PostScript
.61198 .16405 m
.61198 .16405 L
s
% Start of user PostScript
0.6 0.1 MAarrowzero1
% End of user PostScript
.61198 .20885 m
.60635 .21448 L
s
% Start of user PostScript
0.6 0.15 0.593717 0.156283 MAarrowhead1
% End of user PostScript
.61198 .25364 m
.60072 .2649 L
s
% Start of user PostScript
0.6 0.2 0.587434 0.212566 MAarrowhead1
% End of user PostScript
.61198 .29843 m
.5951 .31532 L
s
% Start of user PostScript
0.6 0.25 0.58115 0.26885 MAarrowhead1
% End of user PostScript
.61198 .34323 m
.58947 .36574 L
s
% Start of user PostScript
0.6 0.3 0.574867 0.325133 MAarrowhead1
% End of user PostScript
.61198 .38802 m
.58384 .41616 L
s
% Start of user PostScript
0.6 0.35 0.568584 0.381416 MAarrowhead1
% End of user PostScript
.61198 .43281 m
.57821 .46658 L
s
% Start of user PostScript
0.6 0.4 0.562301 0.437699 MAarrowhead1
% End of user PostScript
.61198 .4776 m
.57258 .51701 L
s
% Start of user PostScript
0.6 0.45 0.556018 0.493982 MAarrowhead1
% End of user PostScript
.61198 .5224 m
.56695 .56743 L
s
% Start of user PostScript
0.6 0.5 0.549735 0.550265 MAarrowhead1
% End of user PostScript
.61198 .56719 m
.56132 .61785 L
s
% Start of user PostScript
0.6 0.55 0.543451 0.606549 MAarrowhead1
% End of user PostScript
.61198 .61198 m
.61198 .61198 L
s
% Start of user PostScript
0.6 0.6 MAarrowzero1
% End of user PostScript
.61198 .65677 m
.66264 .60612 L
s
% Start of user PostScript
0.6 0.65 0.656549 0.593451 MAarrowhead1
% End of user PostScript
.61198 .70157 m
.65701 .65654 L
s
% Start of user PostScript
0.6 0.7 0.650265 0.649735 MAarrowhead1
% End of user PostScript
.61198 .74636 m
.65138 .70696 L
s
% Start of user PostScript
0.6 0.75 0.643982 0.706018 MAarrowhead1
% End of user PostScript
.61198 .79115 m
.64575 .75738 L
s
% Start of user PostScript
0.6 0.8 0.637699 0.762301 MAarrowhead1
% End of user PostScript
.61198 .83595 m
.64013 .8078 L
s
% Start of user PostScript
0.6 0.85 0.631416 0.818584 MAarrowhead1
% End of user PostScript
.61198 .88074 m
.6345 .85822 L
s
% Start of user PostScript
0.6 0.9 0.625133 0.874867 MAarrowhead1
% End of user PostScript
.61198 .92553 m
.62887 .90864 L
s
% Start of user PostScript
0.6 0.95 0.61885 0.93115 MAarrowhead1
% End of user PostScript
.65677 .07447 m
.67366 .05758 L
s
% Start of user PostScript
0.65 0 0.66885 -0.0188496 MAarrowhead1
% End of user PostScript
.65677 .11926 m
.66803 .108 L
s
% Start of user PostScript
0.65 0.05 0.662566 0.0374336 MAarrowhead1
% End of user PostScript
.65677 .16405 m
.6624 .15843 L
s
% Start of user PostScript
0.65 0.1 0.656283 0.0937168 MAarrowhead1
% End of user PostScript
.65677 .20885 m
.65677 .20885 L
s
% Start of user PostScript
0.65 0.15 MAarrowzero1
% End of user PostScript
.65677 .25364 m
.65115 .25927 L
s
% Start of user PostScript
0.65 0.2 0.643717 0.206283 MAarrowhead1
% End of user PostScript
.65677 .29843 m
.64552 .30969 L
s
% Start of user PostScript
0.65 0.25 0.637434 0.262566 MAarrowhead1
% End of user PostScript
.65677 .34323 m
.63989 .36011 L
s
% Start of user PostScript
0.65 0.3 0.63115 0.31885 MAarrowhead1
% End of user PostScript
.65677 .38802 m
.63426 .41053 L
s
% Start of user PostScript
0.65 0.35 0.624867 0.375133 MAarrowhead1
% End of user PostScript
.65677 .43281 m
.62863 .46095 L
s
% Start of user PostScript
0.65 0.4 0.618584 0.431416 MAarrowhead1
% End of user PostScript
.65677 .4776 m
.623 .51138 L
s
% Start of user PostScript
0.65 0.45 0.612301 0.487699 MAarrowhead1
% End of user PostScript
.65677 .5224 m
.61737 .5618 L
s
% Start of user PostScript
0.65 0.5 0.606018 0.543982 MAarrowhead1
% End of user PostScript
.65677 .56719 m
.61174 .61222 L
s
% Start of user PostScript
0.65 0.55 0.599735 0.600265 MAarrowhead1
% End of user PostScript
.65677 .61198 m
.60612 .66264 L
s
% Start of user PostScript
0.65 0.6 0.593451 0.656549 MAarrowhead1
% End of user PostScript
.65677 .65677 m
.65677 .65677 L
s
% Start of user PostScript
0.65 0.65 MAarrowzero1
% End of user PostScript
.65677 .70157 m
.70743 .65091 L
s
% Start of user PostScript
0.65 0.7 0.706549 0.643451 MAarrowhead1
% End of user PostScript
.65677 .74636 m
.70181 .70133 L
s
% Start of user PostScript
0.65 0.75 0.700265 0.699735 MAarrowhead1
% End of user PostScript
.65677 .79115 m
.69618 .75175 L
s
% Start of user PostScript
0.65 0.8 0.693982 0.756018 MAarrowhead1
% End of user PostScript
.65677 .83595 m
.69055 .80217 L
s
% Start of user PostScript
0.65 0.85 0.687699 0.812301 MAarrowhead1
% End of user PostScript
.65677 .88074 m
.68492 .85259 L
s
% Start of user PostScript
0.65 0.9 0.681416 0.868584 MAarrowhead1
% End of user PostScript
.65677 .92553 m
.67929 .90302 L
s
% Start of user PostScript
0.65 0.95 0.675133 0.924867 MAarrowhead1
% End of user PostScript
.70157 .07447 m
.72408 .05195 L
s
% Start of user PostScript
0.7 0 0.725133 -0.0251327 MAarrowhead1
% End of user PostScript
.70157 .11926 m
.71845 .10238 L
s
% Start of user PostScript
0.7 0.05 0.71885 0.0311504 MAarrowhead1
% End of user PostScript
.70157 .16405 m
.71282 .1528 L
s
% Start of user PostScript
0.7 0.1 0.712566 0.0874336 MAarrowhead1
% End of user PostScript
.70157 .20885 m
.7072 .20322 L
s
% Start of user PostScript
0.7 0.15 0.706283 0.143717 MAarrowhead1
% End of user PostScript
.70157 .25364 m
.70157 .25364 L
s
% Start of user PostScript
0.7 0.2 MAarrowzero1
% End of user PostScript
.70157 .29843 m
.69594 .30406 L
s
% Start of user PostScript
0.7 0.25 0.693717 0.256283 MAarrowhead1
% End of user PostScript
.70157 .34323 m
.69031 .35448 L
s
% Start of user PostScript
0.7 0.3 0.687434 0.312566 MAarrowhead1
% End of user PostScript
.70157 .38802 m
.68468 .4049 L
s
% Start of user PostScript
0.7 0.35 0.68115 0.36885 MAarrowhead1
% End of user PostScript
.70157 .43281 m
.67905 .45533 L
s
% Start of user PostScript
0.7 0.4 0.674867 0.425133 MAarrowhead1
% End of user PostScript
.70157 .4776 m
.67342 .50575 L
s
% Start of user PostScript
0.7 0.45 0.668584 0.481416 MAarrowhead1
% End of user PostScript
.70157 .5224 m
.66779 .55617 L
s
% Start of user PostScript
0.7 0.5 0.662301 0.537699 MAarrowhead1
% End of user PostScript
.70157 .56719 m
.66217 .60659 L
s
% Start of user PostScript
0.7 0.55 0.656018 0.593982 MAarrowhead1
% End of user PostScript
.70157 .61198 m
.65654 .65701 L
s
% Start of user PostScript
0.7 0.6 0.649735 0.650265 MAarrowhead1
% End of user PostScript
.70157 .65677 m
.65091 .70743 L
s
% Start of user PostScript
0.7 0.65 0.643451 0.706549 MAarrowhead1
% End of user PostScript
.70157 .70157 m
.70157 .70157 L
s
% Start of user PostScript
0.7 0.7 MAarrowzero1
% End of user PostScript
.70157 .74636 m
.75223 .6957 L
s
% Start of user PostScript
0.7 0.75 0.756549 0.693451 MAarrowhead1
% End of user PostScript
.70157 .79115 m
.7466 .74612 L
s
% Start of user PostScript
0.7 0.8 0.750265 0.749735 MAarrowhead1
% End of user PostScript
.70157 .83595 m
.74097 .79654 L
s
% Start of user PostScript
0.7 0.85 0.743982 0.806018 MAarrowhead1
% End of user PostScript
.70157 .88074 m
.73534 .84697 L
s
% Start of user PostScript
0.7 0.9 0.737699 0.862301 MAarrowhead1
% End of user PostScript
.70157 .92553 m
.72971 .89739 L
s
% Start of user PostScript
0.7 0.95 0.731416 0.918584 MAarrowhead1
% End of user PostScript
.74636 .07447 m
.7745 .04632 L
s
% Start of user PostScript
0.75 0 0.781416 -0.0314159 MAarrowhead1
% End of user PostScript
.74636 .11926 m
.76888 .09675 L
s
% Start of user PostScript
0.75 0.05 0.775133 0.0248673 MAarrowhead1
% End of user PostScript
.74636 .16405 m
.76325 .14717 L
s
% Start of user PostScript
0.75 0.1 0.76885 0.0811504 MAarrowhead1
% End of user PostScript
.74636 .20885 m
.75762 .19759 L
s
% Start of user PostScript
0.75 0.15 0.762566 0.137434 MAarrowhead1
% End of user PostScript
.74636 .25364 m
.75199 .24801 L
s
% Start of user PostScript
0.75 0.2 0.756283 0.193717 MAarrowhead1
% End of user PostScript
.74636 .29843 m
.74636 .29843 L
s
% Start of user PostScript
0.75 0.25 MAarrowzero1
% End of user PostScript
.74636 .34323 m
.74073 .34885 L
s
% Start of user PostScript
0.75 0.3 0.743717 0.306283 MAarrowhead1
% End of user PostScript
.74636 .38802 m
.7351 .39928 L
s
% Start of user PostScript
0.75 0.35 0.737434 0.362566 MAarrowhead1
% End of user PostScript
.74636 .43281 m
.72947 .4497 L
s
% Start of user PostScript
0.75 0.4 0.73115 0.41885 MAarrowhead1
% End of user PostScript
.74636 .4776 m
.72384 .50012 L
s
% Start of user PostScript
0.75 0.45 0.724867 0.475133 MAarrowhead1
% End of user PostScript
.74636 .5224 m
.71822 .55054 L
s
% Start of user PostScript
0.75 0.5 0.718584 0.531416 MAarrowhead1
% End of user PostScript
.74636 .56719 m
.71259 .60096 L
s
% Start of user PostScript
0.75 0.55 0.712301 0.587699 MAarrowhead1
% End of user PostScript
.74636 .61198 m
.70696 .65138 L
s
% Start of user PostScript
0.75 0.6 0.706018 0.643982 MAarrowhead1
% End of user PostScript
.74636 .65677 m
.70133 .70181 L
s
% Start of user PostScript
0.75 0.65 0.699735 0.700265 MAarrowhead1
% End of user PostScript
.74636 .70157 m
.6957 .75223 L
s
% Start of user PostScript
0.75 0.7 0.693451 0.756549 MAarrowhead1
% End of user PostScript
.74636 .74636 m
.74636 .74636 L
s
% Start of user PostScript
0.75 0.75 MAarrowzero1
% End of user PostScript
.74636 .79115 m
.79702 .74049 L
s
% Start of user PostScript
0.75 0.8 0.806549 0.743451 MAarrowhead1
% End of user PostScript
.74636 .83595 m
.79139 .79092 L
s
% Start of user PostScript
0.75 0.85 0.800265 0.799735 MAarrowhead1
% End of user PostScript
.74636 .88074 m
.78576 .84134 L
s
% Start of user PostScript
0.75 0.9 0.793982 0.856018 MAarrowhead1
% End of user PostScript
.74636 .92553 m
.78013 .89176 L
s
% Start of user PostScript
0.75 0.95 0.787699 0.912301 MAarrowhead1
% End of user PostScript
.79115 .07447 m
.82493 .0407 L
s
% Start of user PostScript
0.8 0 0.837699 -0.0376991 MAarrowhead1
% End of user PostScript
.79115 .11926 m
.8193 .09112 L
s
% Start of user PostScript
0.8 0.05 0.831416 0.0185841 MAarrowhead1
% End of user PostScript
.79115 .16405 m
.81367 .14154 L
s
% Start of user PostScript
0.8 0.1 0.825133 0.0748673 MAarrowhead1
% End of user PostScript
.79115 .20885 m
.80804 .19196 L
s
% Start of user PostScript
0.8 0.15 0.81885 0.13115 MAarrowhead1
% End of user PostScript
.79115 .25364 m
.80241 .24238 L
s
% Start of user PostScript
0.8 0.2 0.812566 0.187434 MAarrowhead1
% End of user PostScript
.79115 .29843 m
.79678 .2928 L
s
% Start of user PostScript
0.8 0.25 0.806283 0.243717 MAarrowhead1
% End of user PostScript
.79115 .34323 m
.79115 .34323 L
s
% Start of user PostScript
0.8 0.3 MAarrowzero1
% End of user PostScript
.79115 .38802 m
.78552 .39365 L
s
% Start of user PostScript
0.8 0.35 0.793717 0.356283 MAarrowhead1
% End of user PostScript
.79115 .43281 m
.7799 .44407 L
s
% Start of user PostScript
0.8 0.4 0.787434 0.412566 MAarrowhead1
% End of user PostScript
.79115 .4776 m
.77427 .49449 L
s
% Start of user PostScript
0.8 0.45 0.78115 0.46885 MAarrowhead1
% End of user PostScript
.79115 .5224 m
.76864 .54491 L
s
% Start of user PostScript
0.8 0.5 0.774867 0.525133 MAarrowhead1
% End of user PostScript
.79115 .56719 m
.76301 .59533 L
s
% Start of user PostScript
0.8 0.55 0.768584 0.581416 MAarrowhead1
% End of user PostScript
.79115 .61198 m
.75738 .64575 L
s
% Start of user PostScript
0.8 0.6 0.762301 0.637699 MAarrowhead1
% End of user PostScript
.79115 .65677 m
.75175 .69618 L
s
% Start of user PostScript
0.8 0.65 0.756018 0.693982 MAarrowhead1
% End of user PostScript
.79115 .70157 m
.74612 .7466 L
s
% Start of user PostScript
0.8 0.7 0.749735 0.750265 MAarrowhead1
% End of user PostScript
.79115 .74636 m
.74049 .79702 L
s
% Start of user PostScript
0.8 0.75 0.743451 0.806549 MAarrowhead1
% End of user PostScript
.79115 .79115 m
.79115 .79115 L
s
% Start of user PostScript
0.8 0.8 MAarrowzero1
% End of user PostScript
.79115 .83595 m
.84181 .78529 L
s
% Start of user PostScript
0.8 0.85 0.856549 0.793451 MAarrowhead1
% End of user PostScript
.79115 .88074 m
.83618 .83571 L
s
% Start of user PostScript
0.8 0.9 0.850265 0.849735 MAarrowhead1
% End of user PostScript
.79115 .92553 m
.83055 .88613 L
s
% Start of user PostScript
0.8 0.95 0.843982 0.906018 MAarrowhead1
% End of user PostScript
.83595 .07447 m
.87535 .03507 L
s
% Start of user PostScript
0.85 0 0.893982 -0.0439823 MAarrowhead1
% End of user PostScript
.83595 .11926 m
.86972 .08549 L
s
% Start of user PostScript
0.85 0.05 0.887699 0.0123009 MAarrowhead1
% End of user PostScript
.83595 .16405 m
.86409 .13591 L
s
% Start of user PostScript
0.85 0.1 0.881416 0.0685841 MAarrowhead1
% End of user PostScript
.83595 .20885 m
.85846 .18633 L
s
% Start of user PostScript
0.85 0.15 0.875133 0.124867 MAarrowhead1
% End of user PostScript
.83595 .25364 m
.85283 .23675 L
s
% Start of user PostScript
0.85 0.2 0.86885 0.18115 MAarrowhead1
% End of user PostScript
.83595 .29843 m
.8472 .28718 L
s
% Start of user PostScript
0.85 0.25 0.862566 0.237434 MAarrowhead1
% End of user PostScript
.83595 .34323 m
.84157 .3376 L
s
% Start of user PostScript
0.85 0.3 0.856283 0.293717 MAarrowhead1
% End of user PostScript
.83595 .38802 m
.83595 .38802 L
s
% Start of user PostScript
0.85 0.35 MAarrowzero1
% End of user PostScript
.83595 .43281 m
.83032 .43844 L
s
% Start of user PostScript
0.85 0.4 0.843717 0.406283 MAarrowhead1
% End of user PostScript
.83595 .4776 m
.82469 .48886 L
s
% Start of user PostScript
0.85 0.45 0.837434 0.462566 MAarrowhead1
% End of user PostScript
.83595 .5224 m
.81906 .53928 L
s
% Start of user PostScript
0.85 0.5 0.83115 0.51885 MAarrowhead1
% End of user PostScript
.83595 .56719 m
.81343 .5897 L
s
% Start of user PostScript
0.85 0.55 0.824867 0.575133 MAarrowhead1
% End of user PostScript
.83595 .61198 m
.8078 .64013 L
s
% Start of user PostScript
0.85 0.6 0.818584 0.631416 MAarrowhead1
% End of user PostScript
.83595 .65677 m
.80217 .69055 L
s
% Start of user PostScript
0.85 0.65 0.812301 0.687699 MAarrowhead1
% End of user PostScript
.83595 .70157 m
.79654 .74097 L
s
% Start of user PostScript
0.85 0.7 0.806018 0.743982 MAarrowhead1
% End of user PostScript
.83595 .74636 m
.79092 .79139 L
s
% Start of user PostScript
0.85 0.75 0.799735 0.800265 MAarrowhead1
% End of user PostScript
.83595 .79115 m
.78529 .84181 L
s
% Start of user PostScript
0.85 0.8 0.793451 0.856549 MAarrowhead1
% End of user PostScript
.83595 .83595 m
.83595 .83595 L
s
% Start of user PostScript
0.85 0.85 MAarrowzero1
% End of user PostScript
.83595 .88074 m
.8866 .83008 L
s
% Start of user PostScript
0.85 0.9 0.906549 0.843451 MAarrowhead1
% End of user PostScript
.83595 .92553 m
.88098 .8805 L
s
% Start of user PostScript
0.85 0.95 0.900265 0.899735 MAarrowhead1
% End of user PostScript
.88074 .07447 m
.92577 .02944 L
s
% Start of user PostScript
0.9 0 0.950265 -0.0502655 MAarrowhead1
% End of user PostScript
.88074 .11926 m
.92014 .07986 L
s
% Start of user PostScript
0.9 0.05 0.943982 0.0060177 MAarrowhead1
% End of user PostScript
.88074 .16405 m
.91451 .13028 L
s
% Start of user PostScript
0.9 0.1 0.937699 0.0623009 MAarrowhead1
% End of user PostScript
.88074 .20885 m
.90888 .1807 L
s
% Start of user PostScript
0.9 0.15 0.931416 0.118584 MAarrowhead1
% End of user PostScript
.88074 .25364 m
.90325 .23112 L
s
% Start of user PostScript
0.9 0.2 0.925133 0.174867 MAarrowhead1
% End of user PostScript
.88074 .29843 m
.89762 .28155 L
s
% Start of user PostScript
0.9 0.25 0.91885 0.23115 MAarrowhead1
% End of user PostScript
.88074 .34323 m
.892 .33197 L
s
% Start of user PostScript
0.9 0.3 0.912566 0.287434 MAarrowhead1
% End of user PostScript
.88074 .38802 m
.88637 .38239 L
s
% Start of user PostScript
0.9 0.35 0.906283 0.343717 MAarrowhead1
% End of user PostScript
.88074 .43281 m
.88074 .43281 L
s
% Start of user PostScript
0.9 0.4 MAarrowzero1
% End of user PostScript
.88074 .4776 m
.87511 .48323 L
s
% Start of user PostScript
0.9 0.45 0.893717 0.456283 MAarrowhead1
% End of user PostScript
.88074 .5224 m
.86948 .53365 L
s
% Start of user PostScript
0.9 0.5 0.887434 0.512566 MAarrowhead1
% End of user PostScript
.88074 .56719 m
.86385 .58408 L
s
% Start of user PostScript
0.9 0.55 0.88115 0.56885 MAarrowhead1
% End of user PostScript
.88074 .61198 m
.85822 .6345 L
s
% Start of user PostScript
0.9 0.6 0.874867 0.625133 MAarrowhead1
% End of user PostScript
.88074 .65677 m
.85259 .68492 L
s
% Start of user PostScript
0.9 0.65 0.868584 0.681416 MAarrowhead1
% End of user PostScript
.88074 .70157 m
.84697 .73534 L
s
% Start of user PostScript
0.9 0.7 0.862301 0.737699 MAarrowhead1
% End of user PostScript
.88074 .74636 m
.84134 .78576 L
s
% Start of user PostScript
0.9 0.75 0.856018 0.793982 MAarrowhead1
% End of user PostScript
.88074 .79115 m
.83571 .83618 L
s
% Start of user PostScript
0.9 0.8 0.849735 0.850265 MAarrowhead1
% End of user PostScript
.88074 .83595 m
.83008 .8866 L
s
% Start of user PostScript
0.9 0.85 0.843451 0.906549 MAarrowhead1
% End of user PostScript
.88074 .88074 m
.88074 .88074 L
s
% Start of user PostScript
0.9 0.9 MAarrowzero1
% End of user PostScript
.88074 .92553 m
.9314 .87487 L
s
% Start of user PostScript
0.9 0.95 0.956549 0.893451 MAarrowhead1
% End of user PostScript
.92553 .07447 m
.97619 .02381 L
s
% Start of user PostScript
0.95 0 1.00655 -0.0565487 MAarrowhead1
% End of user PostScript
.92553 .11926 m
.97056 .07423 L
s
% Start of user PostScript
0.95 0.05 1.00027 -0.000265482 MAarrowhead1
% End of user PostScript
.92553 .16405 m
.96493 .12465 L
s
% Start of user PostScript
0.95 0.1 0.993982 0.0560177 MAarrowhead1
% End of user PostScript
.92553 .20885 m
.9593 .17507 L
s
% Start of user PostScript
0.95 0.15 0.987699 0.112301 MAarrowhead1
% End of user PostScript
.92553 .25364 m
.95368 .2255 L
s
% Start of user PostScript
0.95 0.2 0.981416 0.168584 MAarrowhead1
% End of user PostScript
.92553 .29843 m
.94805 .27592 L
s
% Start of user PostScript
0.95 0.25 0.975133 0.224867 MAarrowhead1
% End of user PostScript
.92553 .34323 m
.94242 .32634 L
s
% Start of user PostScript
0.95 0.3 0.96885 0.28115 MAarrowhead1
% End of user PostScript
.92553 .38802 m
.93679 .37676 L
s
% Start of user PostScript
0.95 0.35 0.962566 0.337434 MAarrowhead1
% End of user PostScript
.92553 .43281 m
.93116 .42718 L
s
% Start of user PostScript
0.95 0.4 0.956283 0.393717 MAarrowhead1
% End of user PostScript
.92553 .4776 m
.92553 .4776 L
s
% Start of user PostScript
0.95 0.45 MAarrowzero1
% End of user PostScript
.92553 .5224 m
.9199 .52803 L
s
% Start of user PostScript
0.95 0.5 0.943717 0.506283 MAarrowhead1
% End of user PostScript
.92553 .56719 m
.91427 .57845 L
s
% Start of user PostScript
0.95 0.55 0.937434 0.562566 MAarrowhead1
% End of user PostScript
.92553 .61198 m
.90864 .62887 L
s
% Start of user PostScript
0.95 0.6 0.93115 0.61885 MAarrowhead1
% End of user PostScript
.92553 .65677 m
.90302 .67929 L
s
% Start of user PostScript
0.95 0.65 0.924867 0.675133 MAarrowhead1
% End of user PostScript
.92553 .70157 m
.89739 .72971 L
s
% Start of user PostScript
0.95 0.7 0.918584 0.731416 MAarrowhead1
% End of user PostScript
.92553 .74636 m
.89176 .78013 L
s
% Start of user PostScript
0.95 0.75 0.912301 0.787699 MAarrowhead1
% End of user PostScript
.92553 .79115 m
.88613 .83055 L
s
% Start of user PostScript
0.95 0.8 0.906018 0.843982 MAarrowhead1
% End of user PostScript
.92553 .83595 m
.8805 .88098 L
s
% Start of user PostScript
0.95 0.85 0.899735 0.900265 MAarrowhead1
% End of user PostScript
.92553 .88074 m
.87487 .9314 L
s
% Start of user PostScript
0.95 0.9 0.893451 0.956549 MAarrowhead1
% End of user PostScript
.92553 .92553 m
.92553 .92553 L
s
% Start of user PostScript
0.95 0.95 MAarrowzero1
% End of user PostScript
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo
000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooooom8
ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?oo
ooooB?ooool001kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003ooooooooo
o`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000oooo
ooooool0oooooolmooooo`;o00002Oooool001kooooo00?o0000ooooooooool0oooooollooooo`?o
00002Oooool001kooooo0_l0003oooooobcooooo0_l0000=ooooo`Co00002_ooool001kooooo00?o
0000ooooooooool0oooooolZooooo`?o00003?ooool4o`0000_ooooo000Nooooo`03o`000?oooooo
oooo0?oooooo6Oooool2o`0000gooooo1?l0000<ooooo`Go00002oooool001kooooo00?o0000oooo
ooooool0<_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000:_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0:Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000
ob4Q8Oo<c<`04_ooool3o`0000cooooo1?l0000>ooooo`Go000000?o410@ooooooooool01oooool0
01kooooo00?o0000ooooooooool0<_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0:_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo02[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q02[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01_lQ8B7oV9RHoooooonHV9So8B4Qooooo`;o00003Oooool4o`0000cooooo
1Ol0000=ooooo`05o`000?oooooo0000ooooool000002oooool001kooooo00?o0000ooooooooool0
<_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0:oooool01Ol@413o
oooooooooooooooo410@00_ooooo1Ol0000[ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000002[ooooo00Go410@oooooooooooooooooa0@400;ooooo`04o`00
0?ooooooooooooooo`Co00003?ooool4o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02Oooool001kooooo00?o0000ooooooooool0<_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0:_ooool01Ol0003ooooooooooooooooo0000
00_ooooo00CoA4A4omgMgOoooooo0000;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oiRHV?ooooooV9RHob4Q8@0Zooooo`04o`000?ooooooooooooooo`;o00002_ooool00olb<S;o
V9RHooooo`04o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`09ooooo`007_ooool00ol0003oooooooooo`0booooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`0Yooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool0000/ooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oEEEEo`000?l@413oc<c<02[ooooo00?o0000ooooooooool00ol0000:ooooo`03olc<
c?l0003o000000Co00003Oooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Wooooo000Nooooo`03o`000?oooooooooo03;ooooo00Go
410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo02Sooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03ogMgMoo<c<co000002cooooo00Go410@oooooooooooooooooa0@400;oooo
o`03oeEEEOn7QhOooooo01oooooo0_l0000;ooooo`03oa0@4?l0003o000000;o00002oooool00ol@
413o0000o`000003o`0000gooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool001kooooo00?o0000oooooooo
ool0<_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@400Z
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00000/ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00Mooooo`Co00002oooool5o`0000_ooooo
00?o0000okZj^_l000000ol0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo000Nooooo`03o`000?oo
oooooooo03;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0:oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@2oooool2o`0000gooooo1?l0
000;ooooo`Go000000?ok^k^ooooooooool02Oooool01OnYZJWo0000o`000?l@413o000000cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo
00?oEEEEofIVI_l000002oooool001kooooo00?o0000ooooooooool0coooool4o`0000_ooooo1Ol0
000=ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Dooooo`007_ooool00ol0003oooooooooo`2>
ooooo`03o`000?oooooooooo02kooooo0_l0000=ooooo`Co00002oooool6o`0000cooooo00Co0000
oooooooooooo00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`007_ooool00ol0003oooooooooo`2>
ooooo`;o0000;Oooool4o`0000_ooooo1Ol0000>ooooo`?o00003?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Kooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0001/oooo
o`03o`000?oooooooooo00kooooo1?l0000Looooo`;o00003Oooool4o`0000_ooooo1_l0000=oooo
o`03o`000?oooooo000000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Goooo
o`007_ooool00ol0003oooooooooo`0=ooooo`?o0000K?ooool2o`0000kooooo0ol0000Mooooo`?o
00002oooool5o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Hooooo`001?ooooooo`0006Go0000000>ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02_ooool4o`0000kooooo0_l0000>ooooo`;o00003_oo
ool2o`0000kooooo00?o0000ooooooooool03?ooool2o`0000gooooo0ol0000=ooooo`?o00003_oo
ool2o`0000oooooo00?o0000ooooooooool02_ooool4o`0000kooooo0ol0000>ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00_ooooo0ol0000;ooooo`007_ooool00ol0003oooooooooo`09ooooo`Go00003Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool000003Oooool0
0ol0003oooooooooo`0:ooooo`?o00003_ooool5o`0000cooooo0ol0000=ooooo`03o`000?oooooo
oooo01_ooooo1Ol0000?ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0:_ooool2
o`0000gooooo1Ol0000;ooooo`007_ooool00ol0003oooooooooo`0:ooooo`?o00003Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0;ooooo`?o00003Oooool4o`0000gooooo00?o0000ooooooooool0;Oooool3o`00
07_ooooo0ol0000<ooooo`Co00003Oooool001kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?ooool5o`0000cooooo0_l0000>ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0JOooool2o`0000gooooo1?l0000<ooooo`Go
00003Oooool001kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o0000
3Oooool4o`0000gooooo0_l0002/ooooo`?o00003?ooool4o`0000kooooo0ol0000>ooooo`007_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?ooool5o`0000cooooo0_l0
000>ooooo`03o`000?oooooooooo09_ooooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo00?o
0000ooooool000003oooool001kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000kooooo0ol0000=
ooooo`;o0000[?ooool3o`0000cooooo1?l0000>ooooo`?o00003Oooool00ol0003oooooooooo`0@
ooooo`007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02_ooool2o`000003ooooool0003ooooo00cooooo1Ol0000<ooooo`?o00003Oooool00ol0
003oooooooooo`2Kooooo`;o00003Oooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo0000
00gooooo00?o0000ooooooooool04Oooool001kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000>ooooo`?o00003_ooool00ol0003o
ooooooooo`2Zooooo`?o00003?ooool5o`0000gooooo0ol0000=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool04_ooool001kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooo000000gooooo1Ol0000<ooooo`?o00003_ooool00ol0003ooooo
ooooo`2Kooooo`;o00003?ooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`007_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`?o00003_ooool00ol0003ooooooooo
o`2Zooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Dooooo`007_ooool01Ol0003oooooo`000?oo
oooo000000kooooo1?l0000<ooooo`?o00003_ooool00ol0003oooooooooo`1Zooooo`03o`000?oo
oooooooo02kooooo0_l0000=ooooo`Co00002oooool5o`0000gooooo00Co0000oooooooooooo0000
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
5Oooool001kooooo00Co0000ooooool0003o00003_ooool3o`0000kooooo00?o0000ooooooooool0
Noooool2o`0002gooooo1?l0000;ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
5_ooool001kooooo1Ol0000=ooooo`;o00003Oooool2o`0006cooooo00?o0000ooooooooool03_oo
ool4o`0001cooooo0_l0000=ooooo`Co00002oooool6o`0000cooooo00Co0000oooooooooooo0000
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Gooooo`007_ooool3o`0000kooooo00?o0000ooooooooool03?oo
ool3o`0006cooooo0_l0000>ooooo`?o00007?ooool4o`0000_ooooo1Ol0000>ooooo`?o00003?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo000Nooooo`;o00003Oooool2
o`0000gooooo1?l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool0
0ol0003oooooo`00000>ooooo`Co00003Oooool2o`0000kooooo00?o0000ooooooooool02oooool4
o`0000_ooooo1_l0000=ooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Iooooo`007Oooool2o`0000gooooo0ol0000<ooooo`Co00003_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`?o00003_ooool00ol0
003oooooooooo`0Jooooo`Go00003_ooool3o`0007Wooooo000Looooo`03o`000?oooooo000000_o
oooo1?l0000<ooooo`Go00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`?o00003_ooool4o`0000go
oooo0_l0000>ooooo`03o`000?oooooooooo01[ooooo1_l0000?ooooo`03o`000?oooooooooo06Wo
oooo0_l0000=ooooo`007_ooool00ol0003oooooooooo`08ooooo`Co00003_ooool3o`0000gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03?ooool3o`0000gooooo0ol0000>ooooo`03o`000?oooooooooo02gooooo
0ol0001kooooo`?o00003Oooool001kooooo00?o0000ooooooooool01oooool5o`0000gooooo00?o
0000ooooool000003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02_ooool3o`0000kooooo1Ol0000<ooooo`;o00003_ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo06Wooooo0_l0000=ooooo`Co00003_ooool001kooooo00?o0000
ooooooooool02?ooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000gooooo1?l0000=
ooooo`03o`000?oooooooooo0:_ooooo0ol0000<ooooo`Co00003oooool001kooooo00?o0000oooo
ooooool01oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?ooool5o`00
00cooooo0_l0000>ooooo`03o`000?oooooooooo09_ooooo0_l0000=ooooo`Co00003?ooool5o`00
00oooooo000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000go
oooo1?l0000=ooooo`;o0000[?ooool3o`0000cooooo1?l0000>ooooo`?o00004?ooool001kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo00cooooo1Ol0000<ooooo`;o0000
3_ooool00ol0003oooooooooo`2Kooooo`;o00003Oooool4o`0000cooooo1Ol0000=ooooo`03o`00
0?oooooo0000017ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000>ooooo`?o00003Ooo
ool2o`000:cooooo0ol0000<ooooo`Co00003_ooool3o`0000gooooo00?o0000ooooooooool04_oo
ool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00[ooooo0_l000000ooooooo0000ooooo`0<ooooo`Go00003?ooool3o`0000gooooo00?o0000
ooooooooool0Voooool2o`0000gooooo1?l0000<ooooo`Go00003Oooool00ol0003oooooo`00000=
ooooo`03o`000?oooooooooo01?ooooo000Nooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0;ooooo`?o00003_ooool3o`0000kooooo00?o0000oooo
ooooool0Z_ooool3o`0000cooooo1Ol0000=ooooo`?o00003Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01Cooooo000Nooooo`05o`000?ooooooooooooooool000003Oooool00ol0
003oooooo`00000=ooooo`Go00003?ooool3o`0000kooooo00?o0000ooooooooool0J_ooool00ol0
003oooooooooo`0^ooooo`;o00003?ooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo0000
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`007_ooool01?l0003o
ooooooooool0000>ooooo`;o00003_ooool3o`0000kooooo00?o0000ooooooooool0Noooool2o`00
02gooooo1?l0000;ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo000Nooooo`03o`000?oooooo000000ko
oooo1?l0000<ooooo`?o00003Oooool2o`0006cooooo00?o0000ooooooooool03_ooool4o`0001co
oooo0_l0000=ooooo`Co00002oooool5o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05oooool001ko
oooo0_l0000>ooooo`?o00003_ooool00ol0003oooooooooo`0:ooooo`Go0000K?ooool2o`0000ko
oooo0ol0000Looooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01So
oooo000Nooooo`;o00003_ooool2o`0000gooooo0_l0000;ooooo`Ko00003_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003_ooool4o`0000gooooo
0_l0000>ooooo`03o`000?oooooooooo00_ooooo1?l0000;ooooo`Ko00003?ooool01?l0003ooooo
ooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01Wooooo000Nooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool4o`0000[ooooo1_l0000>ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool2o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo01[ooooo
1Ol0000>ooooo`?o0000JOooool001kooooo00?o0000ooooooooool02_ooool2o`0000cooooo1Ol0
000<ooooo`Go00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000kooooo1?l0
000=ooooo`;o00003_ooool00ol0003oooooooooo`0Jooooo`Ko00003oooool00ol0003ooooooooo
o`1Xooooo`007_ooool00ol0003oooooooooo`08ooooo`Co00002oooool5o`0000kooooo0ol0000=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`?o00003_ooool00ol0003oooooooooo`0]
ooooo`?o0000Noooool001kooooo00?o0000ooooooooool01_ooool5o`0000cooooo1Ol0000=oooo
o`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo0ol0000>ooooo`Co00003Oooool2o`0000kooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`1Yooooo`;o00003oooool001kooooo00?o0000oooooooo
ool01Oooool5o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000kooooo0ol0000=oooo
o`?o00003_ooool00ol0003oooooooooo`2Zooooo`Co00003oooool001kooooo00?o0000oooooooo
ool01Oooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool3o`0000kooooo1Ol0000<ooooo`;o
00003_ooool00ol0003oooooooooo`2Kooooo`;o00003?ooool5o`00013ooooo000Nooooo`03o`00
0?oooooooooo00Kooooo0ol0000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000003?ooool4o`0000go
oooo1?l0000=ooooo`03o`000?oooooooooo0:[ooooo1?l0000;ooooo`Go00004Oooool001kooooo
00?o0000ooooooooool01Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool0
3?ooool5o`0000cooooo0_l0000>ooooo`03o`000?oooooooooo09_ooooo0_l0000<ooooo`Go0000
3?ooool5o`00017ooooo000Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`00000<ooooo`Co00003Oooool4o`0000gooooo0_l0002[ooooo`Co00002oooool5o`0000kooooo
0ol0000Booooo`007_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?oo
ool5o`0000_ooooo0ol0000>ooooo`03o`000?oooooooooo09_ooooo0_l0000<ooooo`Go00003?oo
ool5o`0000gooooo00?o0000ooooool000004oooool001kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00
000<ooooo`Co00003Oooool4o`0000gooooo0_l0001[ooooo`03o`000?oooooooooo03gooooo1?l0
000;ooooo`Go00003_ooool3o`0000gooooo00?o0000ooooooooool05?ooool001kooooo00Go0000
ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000oooo
o`0<ooooo`Go00003?ooool3o`0000gooooo00?o0000ooooooooool0Joooool00ol0003ooooooooo
o`0]ooooo`;o00003?ooool5o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o
0000ooooooooool05Oooool001kooooo00Co0000oooooooooooo00003oooool00ol0003ooooooooo
o`0:ooooo`Co00003Oooool4o`0000kooooo00?o0000ooooooooool0JOooool00ol0003ooooooooo
o`0>ooooo`?o0000;?ooool4o`0000_ooooo1_l0000=ooooo`?o00003Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01Kooooo000Nooooo`03o`000?oooooo000000oooooo00?o0000
ooooooooool02oooool5o`0000cooooo0ol0000=ooooo`;o0000K?ooool00ol0003oooooooooo`0>
ooooo`Co00007?ooool2o`0000_ooooo1Ol0000=ooooo`Co00003Oooool00ol0003oooooo`00000=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05oooool001kooooo0_l0000?oooo
o`03o`000?oooooooooo00_ooooo1?l0000>ooooo`03o`000?oooooooooo00[ooooo1Ol0001Joooo
o`03o`000?oooooooooo00kooooo0ol0000>ooooo`?o00006oooool5o`0000[ooooo1_l0000=oooo
o`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool06?ooool001kooooo0_l0000>ooooo`03o`000?oooooooooo00cooooo0ol0000=ooooo`;o
00002oooool6o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooo000000kooooo1?l0000<ooooo`?o00003_ooool00ol0003oooooooooo`09ooooo`Ko
00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool001kooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0:ooooo`Go00002_ooool6o`0000kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool02_ooool01?l0003oooooooooool0000=ooooo`?o00003_ooool3o`0000kooooo00?o0000oooo
ooooool06Oooool6o`0000kooooo0ol0001Iooooo`007_ooool00ol0003oooooooooo`0Jooooo`;o
00002oooool6o`0000cooooo1Ol0000=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool0
00003_ooool4o`0000cooooo0ol0000>ooooo`03o`000?oooooooooo01_ooooo1Ol0000?ooooo`03
o`000?oooooooooo05Sooooo000Nooooo`03o`000?oooooooooo01Sooooo1?l0000:ooooo`Ko0000
3_ooool3o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00[ooooo00Co0000oooooooooooo00003Oooool3o`0000kooooo0ol0000>ooooo`03
o`000?oooooooooo02gooooo0ol0001[ooooo`007_ooool00ol0003oooooooooo`08ooooo`;o0000
3?ooool5o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool00000
3_ooool4o`0000cooooo0ol0000>ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
J_ooool001kooooo00?o0000ooooooooool01_ooool4o`0000_ooooo1Ol0000>ooooo`?o00003Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_oo
ool01?l0003oooooooooool0000=ooooo`?o00003_ooool3o`0000kooooo00?o0000ooooooooool0
[Oooool001kooooo00?o0000ooooooooool01?ooool5o`0000cooooo1Ol0000=ooooo`03o`000?oo
oooo000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo0ol0000>ooooo`Co00003?ooool3o`0000kooooo00?o0000ooooooooool0Vooo
ool2o`00017ooooo000Nooooo`03o`000?oooooooooo00?ooooo1Ol0000>ooooo`?o00003Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool0
1?l0003oooooooooool0000=ooooo`Co00003Oooool3o`0000kooooo00?o0000ooooooooool0Z_oo
ool4o`00017ooooo000Nooooo`03o`000?oooooooooo00?ooooo1Ol0000=ooooo`03o`000?oooooo
000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00[ooooo0ol0000>ooooo`Go00002oooool3o`0000kooooo00?o0000ooooooooool0Voooool2
o`0000cooooo1Ol0000Booooo`007_ooool00ol0003oooooooooo`04ooooo`?o00003Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000cooooo1?l0000=ooooo`Co00003Oooool00ol0003oooooooooo`2Z
ooooo`Co00002oooool5o`0001?ooooo000Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool02_ooool2o`000003ooooool0003ooooo00cooooo1Ol0000;ooooo`?o00003_ooool00ol0
003oooooooooo`2Kooooo`;o00003?ooool5o`0000cooooo1Ol0000Cooooo`007_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`09ooooo`05o`000?ooooooooooooooool000003?ooool4o`0000gooooo1?l0000=oooo
o`;o0000J_ooool00ol0003oooooooooo`0nooooo`Co00002oooool5o`0000kooooo0ol0000Doooo
o`007_ooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?ooool5o`0000_ooooo0ol0000>oooo
o`03o`000?oooooooooo06[ooooo0_l0000_ooooo`;o00003?ooool5o`0000cooooo1Ol0000=oooo
o`03o`000?oooooo000001Gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Cooooo1Ol00006ooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0:ooooo`Co00003Oooool4o`0000cooooo0ol0001[ooooo`03o`000?oooooo
oooo00gooooo1?l0000/ooooo`Co00002oooool5o`0000kooooo0ol0000=ooooo`03o`000?oooooo
oooo01Kooooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0;ooooo`Go00003?ooool3o`0000_ooooo1?l0001/ooooo`03o`000?oo
oooooooo00gooooo1Ol0000Kooooo`;o00003?ooool5o`0000cooooo1Ol0000=ooooo`03o`000?oo
oooo000000gooooo00?o0000ooooooooool05oooool000?ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0_l0000?ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02oooool4o`0000cooooo0ol0000<ooooo`Co0000Foooool00ol0003ooooooooo
o`0>ooooo`?o00003Oooool4o`0001_ooooo1?l0000;ooooo`Ko00003Oooool3o`0000gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Hooooo`000oooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0000gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`?o00002oooool4o`0000_ooooo1_l0000=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`Co00003?oo
ool3o`0000kooooo00?o0000ooooooooool02Oooool5o`0000gooooo1?l0000=ooooo`03o`000?oo
oooo000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`000oooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`0Zooooo`?o00003?ooool4o`0000_ooooo1_l0000=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00Co
0000oooooooooooo00003Oooool3o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo01Wooooo
1_l0000>ooooo`?o0000BOooool000?ooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0:?ooool4o`0000_ooooo1_l0000<ooooo`Co0000
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000kooooo1?l0000<ooooo`?o0000
3_ooool00ol0003oooooooooo`0Kooooo`Co00004?ooool00ol0003oooooooooo`18ooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03
o`000?oooooooooo01Sooooo0_l0000=ooooo`Co00002oooool6o`0000gooooo1?l0000<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`04
o`000?ooooooooooo`0000gooooo0ol0000>ooooo`?o00003_ooool00ol0003oooooooooo`0]oooo
o`?o0000Foooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Gooooo`?o00002oooool6o`0000cooooo1?l0000=
ooooo`;o000000?oooooo`000?ooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`Co00003?ooool3
o`0000kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Jooooo`007_ooool00ol0
003oooooooooo`06ooooo`;o00003Oooool4o`0000_ooooo1_l0000=ooooo`Co00003?ooool2o`00
00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`04o`000?oooooooooo
o`0000gooooo0ol0000>ooooo`?o00003_ooool00ol0003oooooooooo`2Mooooo`007_ooool00ol0
003oooooooooo`05ooooo`?o00003?ooool5o`0000cooooo1?l0000=ooooo`04o`000?oooooooooo
o`0000cooooo0_l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool0
0ol0003oooooo`00000>ooooo`Co00003?ooool3o`0000kooooo00?o0000ooooooooool0W_ooool0
01kooooo00?o0000ooooooooool00oooool4o`0000cooooo1Ol0000=ooooo`Co00003?ooool00ol0
003oooooooooo`0=ooooo`;o00003_ooool00ol0003oooooooooo`0:ooooo`04o`000?oooooooooo
o`0000gooooo0ol0000>ooooo`?o00003_ooool00ol0003oooooooooo`2Jooooo`;o00004oooool0
01kooooo00?o0000ooooooooool00_ooool5o`0000cooooo1?l0000=ooooo`04o`000?oooooooooo
o`0000cooooo00?o0000ooooooooool03Oooool2o`0000kooooo00?o0000ooooooooool02oooool3
o`0000kooooo1?l0000<ooooo`?o00003_ooool00ol0003oooooooooo`2Jooooo`?o00004oooool0
01kooooo00Co0000oooooooooooooooo1Ol0000=ooooo`Co00003?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo0_l0000;ooooo`04o`000?ooooooooooo`0000gooooo1?l0
000=ooooo`?o00003_ooool00ol0003oooooooooo`2Jooooo`;o00003Oooool4o`0001Cooooo000N
ooooo`04o`000?ooooooooooooooo`Co00003Oooool01?l0003oooooooooool0000<ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool2o`0000cooooo0ol0000>ooooo`Go0000
2oooool3o`0000kooooo00?o0000ooooooooool0V_ooool3o`0000cooooo1Ol0000Dooooo`007_oo
ool01?l0003oooooooooooooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_l0000<ooooo`Co0000
3Oooool4o`0000gooooo00?o0000ooooooooool0JOooool00ol0003oooooooooo`0^ooooo`;o0000
3Oooool4o`0000cooooo1Ol0000Eooooo`007_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00_ooooo1?l0000=ooooo`Go00002oooool3o`0000kooooo00?o0000ooooooooool0
J_ooool2o`0002kooooo0ol0000<ooooo`Go00003?ooool4o`0001Kooooo000Nooooo`03o`000?oo
oooo000000oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00_ooooo1?l0000=ooooo`Co00002oooool4o`0006[ooooo00?o0000ooooooooool03_oo
ool4o`0001cooooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo1?l0000Fooooo`007_ooool2
o`0000oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00cooooo1Ol0000;ooooo`?o00003?ooool3o`0006cooooo0_l0000?ooooo`Go00006_ooool3
o`0000cooooo1Ol0000<ooooo`Co00003Oooool01?l0003oooooooooool0000Gooooo`007_ooool2
o`0000kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00cooooo1?l0000<ooooo`?o00002oooool4o`0000kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooo000000gooooo1?l0000=ooooo`Co00003?ooool0
0ol0003oooooooooo`0;ooooo`Co00003?ooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooo
oooo01Wooooo000Nooooo`03o`000?oooooooooo03cooooo0ol0000;ooooo`Co00002oooool5o`00
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool5o`00
00cooooo0_l0000Kooooo`Go00003?ooool4o`00013ooooo00?o0000ooooooooool09oooool001ko
oooo00?o0000ooooooooool0>_ooool3o`0000cooooo1?l0000;ooooo`Go00003Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooo000000kooooo0ol0000=ooooo`Co00003Oooool00ol0003o
ooooooooo`0Jooooo`Go00003_ooool3o`0003[ooooo000Nooooo`03o`000?oooooooooo03Sooooo
1?l0000;ooooo`Ko00003?ooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`0000kooooo
1Ol0000<ooooo`;o0000;Oooool4o`0000oooooo00?o0000ooooooooool0>Oooool001kooooo00?o
0000ooooooooool0:?ooool2o`0000gooooo1?l0000;ooooo`Ko00003?ooool00ol0003oooooo`00
0002o`0000_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooool000003_ooool3o`0000kooooo0ol0000=ooooo`03o`000?oo
oooooooo02kooooo0ol0001;ooooo`007_ooool00ol0003oooooooooo`0Vooooo`Co00002oooool6
o`0000cooooo1?l0000<ooooo`05o`000?ooooooooooooooool000002oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`0000kooooo1Ol0
000<ooooo`;o0000@Oooool00ol0003oooooooooo`1:ooooo`007_ooool00ol0003oooooooooo`0F
ooooo`;o00003Oooool4o`0000_ooooo1_l0000=ooooo`Co00002oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>
ooooo`?o00003_ooool3o`0000gooooo00?o0000ooooooooool0S_ooool001kooooo00?o0000oooo
ooooool05Oooool3o`0000_ooooo1_l0000<ooooo`Co00003Oooool01?l0003oooooooooool0000;
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`;o00003_ooool5o`0000cooooo0_l0002Pooooo`007_ooool00ol0003oooooooooo`04oooo
o`;o00003Oooool4o`0000_ooooo1_l0000=ooooo`Co00003?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>oooo
o`?o00003_ooool3o`0000gooooo00?o0000ooooooooool0X?ooool001kooooo00?o0000oooooooo
ool00oooool3o`0000cooooo1Ol0000<ooooo`Co00003Oooool01?l0003oooooooooool0000<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`;o00003_ooool5o`0000cooooo0_l0002booooo`007_ooool01?l0003oooooooooooooool4o`00
00cooooo1Ol0000=ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`?o00003_ooool3o`00
00gooooo00?o0000ooooooooool0Voooool2o`0001Gooooo000Nooooo`03o`000?oooooooooo00Go
00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool2o`0000kooooo1Ol0000<oooo
o`;o0000[?ooool3o`0001Gooooo000Nooooo`03o`000?oooooo000000Co00003Oooool4o`0000co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooool000003_ooool4o`0000gooooo0ol0000=ooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool0;_ooool2o`0000gooooo1?l0000Fooooo`007_ooool00ol0003ooooo
o`000003o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool2o`0000kooooo1_l0000;ooooo`;o
0000O?ooool2o`0002kooooo0ol0000<ooooo`Go00005_ooool001kooooo00?o0000ooooool00000
0ol0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo1?l0000=ooooo`Co00002oooool2o`0006cooooo
00?o0000ooooooooool03_ooool4o`0001cooooo0_l0000=ooooo`Co00003?ooool5o`0001Oooooo
000Nooooo`;o00000_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo1_l0
000;ooooo`;o00003Oooool3o`0006cooooo0_l0000>ooooo`Ko00006_ooool3o`0000cooooo1Ol0
000<ooooo`Co00006?ooool001kooooo0_l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo1?l0000;
ooooo`;o00003Oooool4o`0000kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:
ooooo`04o`000?ooooooooooo`0000gooooo1?l0000=ooooo`Co00003?ooool00ol0003ooooooooo
o`0;ooooo`Co00003?ooool5o`0000gooooo1?l0000Hooooo`007_ooool00ol0003oooooooooo`1;
ooooo`;o00003Oooool3o`0000cooooo1Ol0000=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool02oooool3o`0000kooooo1Ol0000;ooooo`;o00007?ooool5o`0000cooooo1?l0000@
ooooo`03o`000?oooooooooo01Oooooo000Nooooo`03o`000?oooooooooo04[ooooo0_l0000<oooo
o`Co00003?ooool5o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000=oooo
o`Co00003Oooool4o`0000cooooo00?o0000ooooooooool06oooool5o`0000kooooo0ol0000Zoooo
o`007_ooool00ol0003oooooooooo`18ooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo0_l0000>ooooo`Go00003?ooool2o`0002cooooo1?l0000@ooooo`03
o`000?oooooooooo02Wooooo000Nooooo`03o`000?oooooooooo03Sooooo0_l0000=ooooo`Co0000
2oooool5o`0000gooooo00?o0000ooooool000000_l0000;ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000kooooo
0ol0000=ooooo`Co00003Oooool00ol0003oooooooooo`0]ooooo`?o0000??ooool001kooooo00?o
0000ooooooooool0=_ooool4o`0000_ooooo1_l0000<ooooo`Co00003?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo0_l0000>ooooo`Go00003?ooool2o`00043ooooo00?o0000ooooooooool0
>oooool001kooooo00?o0000ooooooooool09_ooool2o`0000gooooo1?l0000;ooooo`Ko00003?oo
ool00ol0003oooooo`000002o`0000_ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003_ooool3o`0000kooooo0ol0
000=ooooo`03o`000?oooooooooo07kooooo000Nooooo`03o`000?oooooooooo02Cooooo1?l0000;
ooooo`Ko00003?ooool4o`0000cooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_oo
ool5o`0000cooooo0_l0002@ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00003Oooool4
o`0000_ooooo1_l0000=ooooo`Co00002oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`?o00003_ooool3
o`0000gooooo00?o0000ooooooooool0T?ooool001kooooo00?o0000ooooooooool04oooool3o`00
00_ooooo1_l0000<ooooo`Co00003Oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool5
o`0000cooooo0_l0002Rooooo`007_ooool00ol0003oooooooooo`02ooooo`;o00003Oooool4o`00
00_ooooo1_l0000=ooooo`Co00003?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`?o00003_ooool3o`00
00gooooo00?o0000ooooooooool0X_ooool001kooooo00Co0000oooooooooooooooo0ol0000<oooo
o`Go00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`0000kooooo1Ol0000<
ooooo`;o0000]?ooool001kooooo00?o0000ooooool000000ol0000<ooooo`Go00003Oooool4o`00
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooool000003_ooool3o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo
06[ooooo0_l0000_ooooo`;o00005oooool001kooooo1_l0000<ooooo`Co00003Oooool01?l0003o
ooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`;o00003_ooool5o`0000cooooo0_l0001looooo`?o0000;Oooool3o`00
01Oooooo000Nooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool4o`0000go
oooo0ol0000<ooooo`;o0000K?ooool00ol0003oooooooooo`0>ooooo`Go00006oooool2o`0000go
oooo1?l0000Hooooo`007_ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`Ko00002oooool2o`0000gooooo0ol0001/ooooo`;o00003_ooool4o`0001co
oooo0ol0000<ooooo`Go00006?ooool001kooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool4o`0000_ooooo0_l0000=ooooo`Co00003_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00003Oooool4o`0000go
oooo0_l0000>ooooo`03o`000?oooooooooo00_ooooo1?l0000<ooooo`Go00006Oooool001kooooo
00?o0000ooooool00000Foooool2o`0000gooooo0ol0000<ooooo`Co00003_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000=ooooo`Ko00002oooool2o`0001cooooo
1Ol0000<ooooo`Co00006_ooool001kooooo00?o0000ooooooooool0FOooool2o`0000gooooo1?l0
000<ooooo`Go00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?oo
ool4o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo01_ooooo1Ol0000>ooooo`?o00006_oo
ool001kooooo00?o0000ooooooooool0F?ooool3o`0000cooooo1Ol0000=ooooo`?o00003Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0;ooooo`?o00003_ooool5o`0000_ooooo0_l0000]ooooo`Co00004?ooool0
0ol0003oooooooooo`0Iooooo`007_ooool00ol0003oooooooooo`18ooooo`;o00003?ooool4o`00
00cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003Oooool5o`00
00cooooo1?l0000<ooooo`03o`000?oooooooooo02kooooo0ol0000/ooooo`007_ooool00ol0003o
ooooooooo`16ooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo0_l0000>ooooo`?o00003_ooool2o`00043ooooo00?o0000ooooooooool0:oooool001kooooo
00?o0000ooooooooool0=_ooool2o`0000gooooo1?l0000;ooooo`Go00003Oooool01?l0003ooooo
ooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooo000000kooooo0ol0000=ooooo`?o00003_ooool00ol0003o
ooooooooo`1^ooooo`007_ooool00ol0003oooooooooo`0dooooo`Co00002oooool5o`0000gooooo
1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`Go00003?ooool00ol0003ooooo
ooooo`1oooooo`007_ooool00ol0003oooooooooo`0Tooooo`;o00003Oooool4o`0000_ooooo1_l0
000<ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003_ooool4o`0000gooooo
0ol0000=ooooo`03o`000?oooooooooo083ooooo000Nooooo`03o`000?oooooooooo02;ooooo1?l0
000;ooooo`Go00003_ooool3o`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`0000kooooo0ol0
000>ooooo`;o0000T_ooool001kooooo00?o0000ooooooooool04_ooool2o`0000gooooo1?l0000;
ooooo`Ko00003Oooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000kooooo1?l0000=
ooooo`;o00003_ooool00ol0003oooooooooo`2Booooo`007_ooool00ol0003oooooooooo`0Aoooo
o`?o00002oooool5o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000>oooo
o`?o00003_ooool00ol0003oooooooooo`2Sooooo`007_ooool00ol0003oooooooooo`02o`0000go
oooo1?l0000;ooooo`Ko00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000ko
oooo1?l0000=ooooo`;o00003_ooool00ol0003oooooooooo`1Zooooo`;o0000>?ooool001kooooo
00?o0000ooooool000000_l0000<ooooo`Co00003_ooool3o`0000gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3?ooool2o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo07_ooooo0ol0000gooooo`000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
1?ooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3?ooool4o`0000gooooo0_l0000=ooooo`;o0000K?ooool2o`0000oooooo1Ol0000Kooooo`;o0000
6Oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`04ooooo`Co00003_ooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`?o00003_ooool00ol0003oooooooooo`0<ooooo`?o0000K?ooool3o`0000gooooo
1?l0000Looooo`?o00006Oooool000?ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000
1?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo0_l0000=ooooo`;o00003Oooool4o`0000kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0:ooooo`?o00003_ooool5o`0000cooooo0_l0000>ooooo`03o`00
0?oooooooooo00_ooooo1?l0000Jooooo`000oooool01Ol0003ooooooooooooooooo000000_ooooo
00CoA4A4omgMgOoooooo00001_ooool3o`0006cooooo00?o0000ooooooooool03?ooool3o`0000co
oooo1?l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000go
oooo1?l0000=ooooo`;o00007?ooool4o`0001_ooooo0003ooooo`05o`000?ooooooooooooooool0
00002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo06Wooooo0_l0000=oooo
o`Co00003?ooool5o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool2o`000003ooooool0003ooooo
00cooooo1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`0Kooooo`Go00006oooool000?o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0J?ooool3o`0000cooooo1?l0000>ooooo`?o00003Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;oooo
o`?o00003Oooool4o`0000gooooo0_l0000^ooooo`?o00007?ooool000?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0Eoooool2o`00
00gooooo1?l0000<ooooo`Go00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`00
0?ooool03?ooool5o`0000cooooo0_l0000>ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool06oooool000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo
00Kooooo00?o0000ooooooooool0E_ooool3o`0000cooooo1Ol0000=ooooo`?o00003Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0;ooooo`?o00003_ooool3o`0000gooooo0_l0001Oooooo`007_ooool00ol0003o
ooooooooo`16ooooo`;o00003?ooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooool000003Oooool5o`0000cooooo0ol0000=ooooo`03o`000?oooooooooo05oo
oooo000Nooooo`03o`000?oooooooooo04Cooooo1?l0000;ooooo`Go00003Oooool4o`0000cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool2o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo06oooooo
000Nooooo`03o`000?oooooooooo03Cooooo0_l0000=ooooo`Co00002oooool5o`0000gooooo00Co
0000oooooooooooo00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`Co00003?ooool3o`0000kooooo
00?o0000ooooooooool0L?ooool001kooooo00?o0000ooooooooool0<_ooool4o`0000_ooooo1Ol0
000=ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool3o`0000kooooo00?o
0000ooooooooool0POooool001kooooo00?o0000ooooooooool08_ooool2o`0000gooooo1?l0000;
ooooo`Ko00003?ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000kooooo1?l0
000=ooooo`;o00003_ooool00ol0003oooooooooo`22ooooo`007_ooool00ol0003oooooooooo`0P
ooooo`Co00002oooool5o`0000kooooo0ol0000<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000>
ooooo`?o00003_ooool00ol0003oooooooooo`2Cooooo`007_ooool00ol0003oooooooooo`0@oooo
o`;o00003Oooool4o`0000_ooooo1_l0000=ooooo`03o`000?oooooo000000cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ool000003_ooool4o`0000gooooo0_l0000>ooooo`03o`000?oooooooooo06[ooooo00?o0000oooo
ooooool09oooool001kooooo00?o0000ooooooooool03oooool3o`0000_ooooo1Ol0000>ooooo`?o
00003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool3o`0000kooooo00?o0000oooooooo
ool0Noooool2o`0002Sooooo000Nooooo`?o00003Oooool4o`0000_ooooo1_l0000=ooooo`03o`00
0?oooooo000000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool4o`0000gooooo0_l0000=ooooo`;o0000
K?ooool2o`0000oooooo1?l0000Wooooo`007_ooool3o`0000cooooo1?l0000>ooooo`?o00003Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0ol0000>ooooo`03o`000?oo
oooooooo00cooooo0ol0001/ooooo`?o00003Oooool3o`0002Wooooo000Looooo`Co00003?ooool5
o`0000gooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo0_l0000=ooooo`;o00003Oooool4o`0000kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`?o00003_ooool5o`0000cooooo0_l0000>ooooo`03o`000?oooooo
oooo01Wooooo000Kooooo`Co00003_ooool3o`0006cooooo00?o0000ooooooooool03?ooool3o`00
00cooooo1?l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool3o`00
00gooooo1?l0000=ooooo`03o`000?oooooooooo02[ooooo000Jooooo`Go00003oooool00ol0003o
ooooooooo`1Yooooo`;o00003Oooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[o
oooo0ol0000>ooooo`Go00003?ooool2o`0000kooooo00?o0000ooooooooool0:oooool001_ooooo
1?l0001jooooo`?o00003?ooool4o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo
0ol0000=ooooo`Co00003Oooool2o`0003gooooo000Looooo`03o`000?oooooo000006Wooooo0_l0
000=ooooo`Co00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool2o`000003ooooool0
003ooooo00cooooo1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`0mooooo`007_ooool0
0ol0003oooooooooo`1Vooooo`?o00003?ooool4o`0000kooooo0ol0000=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00_ooooo0ol0000=ooooo`Co00003Oooool2o`0004oooooo000Nooooo`03o`000?oooooooooo
05Gooooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool2o`00
0003ooooool0003ooooo00cooooo1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`1?oooo
o`007_ooool00ol0003oooooooooo`1Dooooo`?o00003?ooool5o`0000gooooo0ol0000=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00_ooooo0ol0000>ooooo`?o00003Oooool2o`00067ooooo000Nooooo`03o`00
0?oooooooooo04Cooooo0_l0000<ooooo`Co00003?ooool5o`0000gooooo00?o0000ooooool00000
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
2oooool00ol0003oooooo`00000=ooooo`Go00003?ooool3o`0000gooooo00?o0000ooooooooool0
HOooool001kooooo00?o0000ooooooooool0@_ooool4o`0000_ooooo1Ol0000=ooooo`Co00003?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`;o00003_ooool3o`0000kooooo00?o0000ooooooooool0LOoo
ool001kooooo00?o0000ooooooooool0<_ooool2o`0000gooooo1?l0000;ooooo`Go00003Oooool0
1?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000kooooo1?l0000<ooooo`?o00003_oo
ool00ol0003oooooooooo`1booooo`007_ooool00ol0003oooooooooo`0`ooooo`Co00002oooool5
o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`?o00003_ooool0
0ol0003oooooooooo`23ooooo`007_ooool00ol0003oooooooooo`0Pooooo`;o00003Oooool4o`00
00_ooooo1_l0000<ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003_ooool4
o`0000gooooo0_l0000>ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool05oooool0
01kooooo00?o0000ooooooooool07_ooool4o`0000_ooooo1Ol0000>ooooo`?o00003?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0<ooooo`;o00003_ooool3o`0000kooooo00?o0000ooooooooool0Noooool2o`00
01Sooooo000Nooooo`03o`000?oooooooooo00kooooo0_l0000=ooooo`Co00002oooool6o`0000go
oooo00?o0000ooooool000003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`Co00003Oooool2o`0000go
oooo0_l0001/ooooo`03o`000?oooooooooo00kooooo1?l0000Gooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`?o00002oooool5o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool3o`0000kooooo00?o0000ooooooooool03?ooool3o`0006cooooo
0_l0000>ooooo`?o00006Oooool001kooooo0_l0000<ooooo`Co00002oooool6o`0000gooooo00?o
0000ooooool000003Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo0_l0
000=ooooo`;o00003Oooool4o`0000kooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0;ooooo`?o00003_ooool4o`0000gooooo0_l0000Jooooo`007_ooool00ol0003oooooooooo`0:
ooooo`Co00003_ooool3o`0006cooooo00?o0000ooooooooool03?ooool3o`0000cooooo1?l0000>
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool3o`0000gooooo0ol0000>
ooooo`03o`000?oooooooooo01[ooooo000Nooooo`03o`000?oooooooooo00Wooooo1Ol0000?oooo
o`03o`000?oooooooooo06Wooooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool3o`0000kooooo1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`0Koooo
o`007_ooool00ol0003oooooooooo`0:ooooo`?o0000Noooool3o`0000cooooo1?l0000>ooooo`?o
00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0<ooooo`?o00003Oooool4o`0000gooooo00?o0000oooooooo
ool0;?ooool001kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Yooooo`;o0000
3Oooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0ol0000>ooooo`Go0000
3?ooool2o`0000kooooo00?o0000ooooooooool0;Oooool001kooooo00?o0000ooooooooool0M_oo
ool3o`0000cooooo1?l0000>ooooo`?o00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o00003Ooo
ool4o`0000gooooo0_l0000oooooo`007_ooool00ol0003oooooooooo`1Uooooo`;o00003Oooool4
o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0<
ooooo`Go00003?ooool2o`0000kooooo00?o0000ooooooooool0?oooool001kooooo00?o0000oooo
ooooool0I?ooool3o`0000cooooo1?l0000>ooooo`?o00003Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;oooo
o`?o00003Oooool4o`0000gooooo0_l0001Aooooo`007_ooool00ol0003oooooooooo`1Cooooo`;o
00003Oooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo
0000ooooo`0<ooooo`Go00003?ooool2o`0000kooooo00?o0000ooooooooool0DOooool001kooooo
00?o0000ooooooooool0D_ooool3o`0000cooooo1Ol0000=ooooo`?o00003Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0;ooooo`?o00003_ooool3o`0000gooooo0_l0001Sooooo`007_ooool00ol0003ooooooooo
o`12ooooo`;o00003?ooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooool000003Oooool5o`0000cooooo0ol0000=ooooo`03o`000?oooooooooo06?ooooo000N
ooooo`03o`000?oooooooooo043ooooo1?l0000;ooooo`Go00003Oooool4o`0000cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03?ooool2o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo07?ooooo000Noooo
o`03o`000?oooooo0000033ooooo0_l0000=ooooo`Co00002oooool5o`0000gooooo00Co0000oooo
oooooooo00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool02oooool00ol0003oooooo`00000>ooooo`Co00003?ooool3o`0000kooooo00?o0000
ooooooooool0M?ooool001kooooo00Co0000ooooool0003o0000;Oooool4o`0000_ooooo1Ol0000=
ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool3o`0000kooooo00?o0000
ooooooooool0QOooool001kooooo1Ol0000Looooo`;o00003Oooool4o`0000_ooooo1_l0000<oooo
o`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool4o`0000gooooo0_l0000=
ooooo`;o0000K?ooool00ol0003oooooooooo`0Iooooo`007_ooool3o`0001cooooo1?l0000;oooo
o`Go00003_ooool3o`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`?o00003_ooool00ol0003oooooooooo`0<ooooo`?o0000K?ooool2o`0001[ooooo000Nooooo`;o
00003_ooool00ol0003oooooooooo`0;ooooo`Co00002oooool6o`0000gooooo00?o0000ooooool0
00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo0_l0000=ooooo`;o
00003Oooool4o`0000kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooo000000kooooo1?l0000Iooooo`007Oooool2o`0001_ooooo1Ol0000>ooooo`?o0000
K?ooool00ol0003oooooooooo`0<ooooo`?o00003?ooool4o`0000kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool3o`0001_ooooo000Looooo`03o`000?oo
oooo000001[ooooo1_l0000?ooooo`03o`000?oooooooooo06Wooooo0_l0000=ooooo`Co00003?oo
ool5o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02oooool3o`0000kooooo1?l0000=ooooo`;o00007?oo
ool001kooooo00?o0000ooooooooool06_ooool3o`0007_ooooo0ol0000<ooooo`Co00003_ooool3
o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03?ooool3o`0000gooooo0ol0000>ooooo`03o`000?oooooo
oooo01cooooo000Nooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0JOooool2o`00
00gooooo1?l0000<ooooo`Go00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`?o00003_ooool5o`00
00cooooo0_l0000>ooooo`03o`000?oooooooooo01gooooo000Nooooo`03o`000?oooooooooo08Ko
oooo0ol0000<ooooo`Co00003_ooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool3o`0000go
oooo1?l0000=ooooo`03o`000?oooooooooo02kooooo000Nooooo`03o`000?oooooooooo07Gooooo
0_l0000=ooooo`Co00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool3o`0000kooooo
1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`0_ooooo`007_ooool00ol0003ooooooooo
o`1dooooo`?o00003?ooool4o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0
000=ooooo`Co00003Oooool2o`00047ooooo000Nooooo`03o`000?oooooooooo06?ooooo0_l0000=
ooooo`Co00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool2o`000003ooooool0003o
oooo00cooooo1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`11ooooo`007_ooool00ol0
003oooooooooo`1Rooooo`?o00003?ooool4o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00_ooooo0ol0000=ooooo`Co00003Oooool2o`0005?ooooo000Nooooo`03o`000?oooooooooo057o
oooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool2o`000003
ooooool0003ooooo00cooooo1Ol0000<ooooo`;o00003_ooool00ol0003oooooooooo`1Cooooo`00
7_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03kooooo0ol0000<ooooo`Go0000
3Oooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000kooooo0ol0000=ooooo`;o0000
IOooool001kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0^ooooo`;o00003?oo
ool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003Ooo
ool5o`0000cooooo0ol0000=ooooo`03o`000?oooooooooo06Gooooo0003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`00
0?oooooooooo00kooooo0ol0000]ooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo0_l0000>ooooo`?o00003_ooool00ol0003oooooooooo`1eooooo`000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B401_ooool00ol0003oooooooooo`0>ooooo`Co00007?ooool2o`0000gooooo1?l0000;ooooo`Go
00003Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo1?l0000<oooo
o`?o00003Oooool2o`0007Sooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Gooooo0ol0000>ooooo`?o00007?ooool4o`0000_ooooo1Ol0000=
ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0ol0000>
ooooo`03o`000?oooooooooo00[ooooo1Ol0001Jooooo`03o`000?oooooooooo01_ooooo0003oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo1?l0
000<ooooo`?o00003_ooool00ol0003oooooooooo`0;ooooo`Co00002oooool6o`0000cooooo00Co
0000oooooooooooo00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
0_l0000=ooooo`;o00002oooool6o`0000kooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooo000001_ooooo0003ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<00Cooooo0ol0000>ooooo`03o`000?oooooooooo01[o
oooo1Ol0000>ooooo`?o0000K?ooool00ol0003oooooooooo`0;ooooo`Co00002_ooool6o`0000ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000=ooooo`?o00007?ooool000?o
oooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Gooooo1?l0000=oooo
o`03o`000?oooooooooo01[ooooo1_l0000?ooooo`03o`000?oooooooooo06Wooooo0_l0000<oooo
o`Go00003?ooool5o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>oooo
o`Co00006oooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH
00Gooooo00Co0000oooooooooooo0000;?ooool3o`0007[ooooo1?l0000;ooooo`Go00003_ooool3
o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00[ooooo00Co0000oooooooooooo00003Oooool3o`0000kooooo0ol0000Mooooo`000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@0_ooool01Ol0003ooooo
oooooooooooo000002gooooo00?o0000ooooooooool0JOooool2o`0000cooooo1Ol0000<ooooo`Go
00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0;ooooo`?o00003_ooool4o`0000cooooo0ol0000Nooooo`00
7_ooool00ol0003oooooooooo`2Eooooo`Co00002oooool5o`0000kooooo0ol0000=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`04o`00
0?ooooooooooo`0000gooooo1?l0000=ooooo`?o00003_ooool00ol0003oooooooooo`0Nooooo`00
7_ooool00ol0003oooooooooo`25ooooo`;o00003?ooool5o`0000cooooo1Ol0000=ooooo`03o`00
0?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo0ol0000>ooooo`Go00002oooool3o`0000kooooo00?o0000ooooooooool0
7oooool001kooooo00?o0000ooooooooool0Poooool4o`0000_ooooo1Ol0000>ooooo`?o00003Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Ooo
ool01?l0003oooooooooool0000=ooooo`Co00003Oooool4o`0000gooooo00?o0000ooooooooool0
<?ooool001kooooo00?o0000ooooooooool0Loooool2o`0000cooooo1Ol0000<ooooo`Go00003Ooo
ool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0:ooooo`?o00003_ooool5o`0000_ooooo0ol0000>ooooo`03o`000?oo
oooooooo037ooooo000Nooooo`03o`000?oooooooooo077ooooo1?l0000;ooooo`Go00003_ooool3
o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Wooooo00Go0000ooooooooooooooooo`00000<ooooo`Co00003Oooool4o`0000gooooo0_l0
0013ooooo`007_ooool00ol0003oooooooooo`1Qooooo`;o00003?ooool5o`0000cooooo1Ol0000=
ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0<ooooo`Go00002oooool3
o`0000kooooo00?o0000ooooooooool0@oooool001kooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0mooooo`Co00002oooool5o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`05o`000?oooooooooo
ooooool000003?ooool4o`0000gooooo1?l0000=ooooo`;o0000EOooool001kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0]ooooo`;o00003?ooool5o`0000cooooo1Ol0000=oooo
o`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0<ooooo`Go00002oooool3o`00
00kooooo00?o0000ooooooooool0EOooool001kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0>ooooo`?o0000;?ooool4o`0000_ooooo1_l0000=ooooo`?o00003Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0:ooooo`Co00003Oooool4o`0000gooooo0_l0001Wooooo`007_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo1?l0000Looooo`;o00002oooool5o`0000gooooo
1?l0000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool5o`0000cooooo
0ol0000=ooooo`;o0000J?ooool001cooooo00?o0000ooooool000003_ooool3o`0000kooooo0ol0
000Kooooo`Go00002_ooool6o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02oooool4o`0000kooooo00?o0000ooooooooool02_ooool5o`0006Sooooo000L
ooooo`04o`000?oooooo0000o`0000gooooo1?l0000<ooooo`?o00003_ooool00ol0003ooooooooo
o`09ooooo`Ko00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo0ol0000=ooooo`;o00002oooool6o`0000gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`006oooool4o`0000gooooo0ol0
000>ooooo`03o`000?oooooooooo01Wooooo1_l0000>ooooo`?o0000K?ooool00ol0003ooooooooo
o`0:ooooo`Go00002_ooool6o`0000gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool01?l0003ooooooooo
ool0000Looooo`006oooool4o`0000cooooo0ol0000>ooooo`03o`000?oooooooooo01_ooooo1Ol0
000?ooooo`03o`000?oooooooooo06Wooooo0_l0000;ooooo`Ko00003?ooool5o`0000cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02oooool00ol0003oooooo`00000Mooooo`006_ooool3o`000003ooooool0003o
oooo00_ooooo00?o0000ooooooooool0;Oooool3o`0007[ooooo1?l0000:ooooo`Ko00003_ooool3
o`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00[ooooo00Co0000oooooooooooo00003Oooool3o`0001kooooo000Iooooo`?o00000_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0JOooool2
o`0000cooooo1Ol0000<ooooo`Go00003Oooool00ol0003oooooo`00000<ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
000000kooooo1?l0000Mooooo`006Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0:Gooooo1?l0000;ooooo`Go00003_ooool3o`0000gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00003Oooool3
o`0000kooooo0ol0000Oooooo`006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
09Gooooo0_l0000<ooooo`Go00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`00
00kooooo1?l0000<ooooo`?o00008?ooool001kooooo00?o0000ooooooooool0Toooool4o`0000_o
oooo1Ol0000>ooooo`?o00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000=ooooo`Co00003Oooool3o`00
00kooooo00?o0000ooooooooool08?ooool001kooooo00?o0000ooooooooool0Poooool2o`0000co
oooo1Ol0000<ooooo`Go00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`?o00003_ooool5o`0000_o
oooo0ol0000>ooooo`03o`000?oooooooooo027ooooo000Nooooo`03o`000?oooooooooo087ooooo
1?l0000;ooooo`Go00003_ooool3o`0000gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00003Oooool4o`0000go
oooo1?l0000=ooooo`03o`000?oooooooooo03;ooooo000Nooooo`03o`000?oooooooooo077ooooo
0_l0000<ooooo`Go00003?ooool5o`0000gooooo00?o0000ooooool000003Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool3o`0000kooooo
1Ol0000;ooooo`?o00003_ooool00ol0003oooooooooo`0cooooo`007_ooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo03kooooo1?l0000;ooooo`Go00003_ooool3o`0000gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00Go
0000ooooooooooooooooo`00000<ooooo`Co00003Oooool4o`0000gooooo0_l00015ooooo`007_oo
ool00ol0003oooooooooo`0^ooooo`;o0000;oooool2o`0000cooooo1Ol0000<ooooo`Go00003Ooo
ool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0:ooooo`;o000000?oooooo`000?ooool03?ooool5o`0000_ooooo0ol0
000>ooooo`03o`000?oooooooooo04Gooooo000Nooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool03Oooool4o`0002cooooo1?l0000;ooooo`Go00003_ooool3o`0000gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool02_ooool4o`0000gooooo1?l0000<ooooo`?o0000Eoooool001kooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0=ooooo`Go00006oooool2o`0000cooooo1Ol0000<oooo
o`Go00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo1Ol0000;oooo
o`?o00003?ooool4o`0005Sooooo000Nooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03_ooool3o`0000gooooo1?l0000Kooooo`Co00002oooool6o`0000gooooo0ol0000=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool4o`0000cooooo0ol0000<ooooo`Co
0000FOooool001kooooo0_l0000<ooooo`03o`000?oooooo000000kooooo1?l0000<ooooo`?o0000
3_ooool00ol0003oooooooooo`09ooooo`Go00003Oooool4o`0000gooooo00?o0000ooooool00000
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0ol0000;ooooo`Co0000
2oooool6o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool06Oooool001[ooooo00?o0000ooooooooool00_l0
000<ooooo`?o00003_ooool3o`0000kooooo00?o0000ooooooooool06Oooool6o`0000kooooo0ol0
001Zooooo`?o00003?ooool4o`0000_ooooo1_l0000=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01[ooooo000J
ooooo`05o`000?oooooo0000ooooool000003?ooool4o`0000cooooo0ol0000>ooooo`03o`000?oo
oooooooo01_ooooo1?l0000@ooooo`03o`000?oooooooooo06Oooooo1?l0000;ooooo`Ko00003?oo
ool4o`0000gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool06oooool001Wooooo0ol00002ooooo`03o`000?oooooo
oooo00Wooooo0ol0000>ooooo`03o`000?oooooooooo02gooooo0ol0001Zooooo`;o00003Oooool4
o`0000_ooooo1_l0000=ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000Nooooo`006Oooool4
o`000003ooooool0003ooooo00Wooooo0ol0000>ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0J?ooool3o`0000_ooooo1_l0000<ooooo`Co00003Oooool01?l0003oooooooooool0
000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooo000001oooooo000Hooooo`?o00000oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo09[ooooo0_l0000=ooooo`Co00002oooool6o`0000gooooo1?l0000<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:
ooooo`04o`000?ooooooooooo`0000gooooo0ol0000Pooooo`005oooool3o`0000Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2Jooooo`?o00003?ooool5o`0000cooooo1?l0000=
ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003_ooool4o`0001oooooo000G
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Toooool2o`0000gooooo1?l0000<
ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00003Oooool3o`0000kooooo0ol0
000Qooooo`005_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09;ooooo0ol0000<
ooooo`Go00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000kooooo1?l0
000<ooooo`?o00008_ooool001kooooo00?o0000ooooooooool0POooool2o`0000gooooo1?l0000<
ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00003Oooool4o`0000gooooo0ol0
000>ooooo`03o`000?oooooooooo02;ooooo000Nooooo`03o`000?oooooooooo083ooooo0ol0000<
ooooo`Go00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool3o`0000kooooo1Ol0
000;ooooo`?o00003_ooool00ol0003oooooooooo`0Sooooo`007_ooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo02kooooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo1?l0000<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:
ooooo`04o`000?ooooooooooo`0000gooooo1?l0000=ooooo`Co00003Oooool00ol0003ooooooooo
o`0dooooo`007_ooool00ol0003oooooooooo`0nooooo`;o0000;_ooool3o`0000cooooo1Ol0000<
ooooo`Co00003Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o00003_ooool5o`0000_ooooo0ol0
000>ooooo`03o`000?oooooooooo03Gooooo000Nooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool03Oooool4o`0001cooooo0_l0000=ooooo`Co00003?ooool5o`0000gooooo1?l0000<
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00_ooooo1?l0000=ooooo`Co00002oooool4o`0004Oooooo000Noooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool03Oooool5o`0001[ooooo0ol0000<oooo
o`Go00003?ooool4o`0000gooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`Go00002oooool3o`0000cooooo0ol00019ooooo`007_ooool2o`0000kooooo00?o0000oooo
ooooool02oooool00ol0003oooooo`00000>ooooo`?o00003Oooool4o`0000cooooo00?o0000oooo
ooooool02oooool4o`0000cooooo1Ol0000=ooooo`Co00003?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00cooooo1?l0000<ooooo`?o00002oooool4o`0000kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Wooooo000Mooooo`;o
00003_ooool00ol0003oooooooooo`0<ooooo`;o00003_ooool5o`0000cooooo0_l0000Kooooo`Go
00003?ooool4o`00013ooooo00?o0000ooooooooool0FOooool3o`0000cooooo1?l0000;ooooo`Go
00003Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool06_ooool001cooooo00?o0000ooooool000002oooool00ol0003oooooo`00000>ooooo`?o0000
3_ooool3o`0000gooooo00?o0000ooooooooool06_ooool5o`0000kooooo0ol0001[ooooo`?o0000
3?ooool4o`0000_ooooo1Ol0000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Kooooo`006oooool01?l0003oooooooooool0000;ooooo`;o0000
3_ooool5o`0000cooooo0_l0000]ooooo`Co00003oooool00ol0003oooooooooo`1Xooooo`Co0000
2oooool6o`0000cooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Looooo`006?ooool00ol0003oooooo`000003ooooo`03o`000?oo
oooooooo00Sooooo0ol0000>ooooo`?o00003Oooool00ol0003oooooooooo`0^ooooo`?o0000J_oo
ool2o`0000gooooo1?l0000;ooooo`Ko00003?ooool00ol0003oooooo`000002o`0000_ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01gooooo000H
ooooo`;o00001?ooool00ol0003oooooooooo`07ooooo`Go00003?ooool2o`00047ooooo00?o0000
ooooooooool0Ioooool4o`0000_ooooo1_l0000<ooooo`Co00003?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01kooooo000Gooooo`?o00001?ooool00ol0003oooooooooo`07ooooo`?o00003Oooool0
0ol0003oooooooooo`2Kooooo`;o00003Oooool4o`0000_ooooo1_l0000=ooooo`Co00002oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool0
0ol0003oooooo`00000Qooooo`005_ooool5o`0000?ooooo00?o0000ooooooooool01_ooool2o`00
0:cooooo0ol0000;ooooo`Ko00003?ooool4o`0000gooooo00Co0000oooooooooooo00002oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2
o`0002;ooooo000Fooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
09_ooooo0_l0000=ooooo`Co00002oooool6o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo0000
00kooooo0ol0000Rooooo`005Oooool2o`0000Oooooo00?o0000ooooooooool0X_ooool3o`0000co
oooo1Ol0000<ooooo`Co00003Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o00003_ooool5o`00
027ooooo000Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0TOooool2o`0000go
oooo1?l0000<ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000003_ooool3o`0000ko
oooo0ol0000Sooooo`007_ooool00ol0003oooooooooo`2@ooooo`?o00003?ooool5o`0000cooooo
1?l0000=ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`Go00003?ooool2o`0002Go
oooo000Nooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0;_ooool2o`0000gooooo
1?l0000<ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool000003_ooool4o`0000gooooo
0ol0000=ooooo`03o`000?oooooooooo02Gooooo000Nooooo`03o`000?oooooooooo04kooooo0_l0
000^ooooo`?o00003?ooool5o`0000cooooo1?l0000=ooooo`04o`000?ooooooooooo`0000cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo
0_l0000>ooooo`Ko00002oooool2o`0003Oooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool03_ooool4o`0001cooooo0_l0000=ooooo`Co00003?ooool5o`0000go
oooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo1?l0000=ooooo`Co00002oooool2o`0003Wo
oooo0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo03cooooo0_l0000>ooooo`Ko00006_ooool3o`00
00cooooo1Ol0000<ooooo`Co00003Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00_ooooo1_l0000;ooooo`;o00003Oooool3o`0003Wooooo0003ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000=ooooo`Co0000
3Oooool4o`0000cooooo00?o0000ooooooooool02oooool4o`0000cooooo1Ol0000=ooooo`Co0000
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo1?l0000;ooooo`;o0000
3Oooool4o`0000kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`000ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P05ooooo`;o
00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000>ooooo`Go
00002oooool2o`0001cooooo1Ol0000<ooooo`Co00004?ooool00ol0003oooooooooo`1Iooooo`;o
00003Oooool3o`0000cooooo1Ol0000=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool06_ooool000?ooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`00
0?o<c<`01?ooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ool000003Oooool4o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo01_ooooo1Ol0000>oooo
o`?o0000Joooool2o`0000cooooo1?l0000<ooooo`Go00003Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01_ooooo0003ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413o^[Zjoooooonj^[[o410@00?ooooo00Co0000oooooooooooo00003?ooool00ol0003ooooooooo
o`0<ooooo`;o00003_ooool5o`0000cooooo0_l0000/ooooo`Co00004?ooool00ol0003ooooooooo
o`1Xooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool07?ooool000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooookZj^_l000000_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooool0
00003_ooool3o`0000gooooo1?l0000=ooooo`03o`000?oooooooooo02gooooo0ol0001[ooooo`;o
00003Oooool4o`0000_ooooo1Ol0000=ooooo`03o`000?oooooo000000;o00002oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01gooooo0003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01onYZJWo410@o`000?l@413oZJVYooooool000001?ooool00ol0003oooooooooo`07
ooooo`;o00003_ooool5o`0000cooooo0_l00010ooooo`03o`000?oooooooooo06Sooooo1?l0000;
ooooo`Ko00003?ooool4o`0000cooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool07_ooool001Kooooo00?o0000ooooool000001Oooool0
0ol0003oooooooooo`06ooooo`?o00003_ooool3o`0000gooooo00?o0000ooooooooool0Voooool2
o`0000gooooo1?l0000;ooooo`Ko00003?ooool00ol0003oooooo`000002o`0000_ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01oooooo000Foooo
o`;o00001_ooool00ol0003oooooooooo`05ooooo`Go00003?ooool2o`000:_ooooo1?l0000;oooo
o`Ko00003?ooool4o`0000cooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Pooooo`005Oooool3o`00
00Kooooo00?o0000ooooooooool01Oooool3o`0000gooooo00?o0000ooooooooool0Voooool2o`00
00gooooo1?l0000;ooooo`Ko00003Oooool4o`0000_ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000008oooool001Co
oooo1Ol00005ooooo`03o`000?oooooooooo00Cooooo0_l0002/ooooo`?o00002oooool6o`0000co
oooo1?l0000=ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo0_l0000Tooooo`005?ooool3o`0000Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Kooooo`;o00003Oooool4o`0000_o
oooo1_l0000=ooooo`Co00003?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`?o00009?ooool001?ooooo
0_l00009ooooo`03o`000?oooooooooo0:3ooooo0ol0000<ooooo`Go00003?ooool4o`0000gooooo
00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool2o`0000kooooo1Ol0000Sooooo`004_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo05kooooo0_l0000_ooooo`;o00003Oooool4o`0000cooooo
1Ol0000=ooooo`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooo`00000>ooooo`?o00003_ooool3o`0002Gooooo
000Nooooo`03o`000?oooooooooo05kooooo0ol0000]ooooo`?o00003?ooool5o`0000cooooo1?l0
000=ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00cooooo0_l0000>ooooo`Go00003?ooool2o`0002Oooooo
000Nooooo`03o`000?oooooooooo04cooooo0_l0000?ooooo`Go00006oooool2o`0000gooooo1?l0
000<ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool4o`0000gooooo0ol0
000<ooooo`;o0000:Oooool001kooooo00?o0000ooooooooool0C?ooool3o`0000gooooo1?l0000L
ooooo`?o00003?ooool5o`0000cooooo1?l0000=ooooo`04o`000?ooooooooooo`0000cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool6o`0000_ooooo0_l0000=ooooo`?o0000:Oooool001kooooo0_l0000>
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:
ooooo`;o000000?oooooo`000?ooool03?ooool5o`0000cooooo0_l0000>ooooo`03o`000?oooooo
oooo00_ooooo1?l0000<ooooo`Go00003Oooool4o`0000cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0=ooooo`Co00002oooool2o`0000gooooo1?l0000>ooooo`03o`000?oooooo
oooo01Wooooo000Mooooo`;o00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02oooool3o`0000gooooo1?l0000=ooooo`;o00007?ooool5o`00
00cooooo1?l0000@ooooo`03o`000?oooooooooo05Wooooo0_l0000=ooooo`?o00003?ooool4o`00
00kooooo00?o0000ooooooooool06_ooool001cooooo00?o0000ooooool000003Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0<ooooo`Go
00003?ooool2o`0000kooooo00?o0000ooooooooool06oooool5o`0000kooooo0ol0001Zooooo`;o
00003Oooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooooooo01_ooooo000Kooooo`04o`00
0?ooooooooooo`0000cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`?o
00003_ooool3o`0000gooooo0_l0000]ooooo`Co00004?ooool00ol0003oooooooooo`1Xooooo`?o
00003?ooool5o`0000gooooo0ol0000=ooooo`03o`000?oooooooooo01cooooo000Jooooo`05o`00
0?ooooooooooooooool000002oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo000000go
oooo1Ol0000<ooooo`?o00003Oooool00ol0003oooooooooo`0^ooooo`?o0000Joooool2o`0000co
oooo1?l0000<ooooo`Go00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo01go
oooo000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0<ooooo`;o00003_ooool3o`0000kooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`1Xooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool07_ooool001Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooo000000kooooo1?l0000<ooooo`?o00003_ooool00ol0003ooooooooo
o`2Kooooo`;o00003Oooool4o`0000_ooooo1Ol0000=ooooo`04o`000?ooooooooooo`0000cooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Oooooo`005oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo0_l0000>ooooo`?o00003_ooool00ol0003ooooooooo
o`2Zooooo`Co00002oooool5o`0000gooooo1?l0000<ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Pooooo`005?ooool00ol0003oooooo`000007
ooooo`03o`000?oooooooooo00Cooooo1?l0000=ooooo`;o00003_ooool00ol0003oooooooooo`2K
ooooo`;o00003Oooool4o`0000_ooooo1_l0000<ooooo`04o`000?ooooooooooo`0000cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo027ooooo000D
ooooo`;o00002?ooool00ol0003oooooooooo`03ooooo`?o00003_ooool00ol0003oooooooooo`2Z
ooooo`Co00002oooool5o`0000kooooo0ol0000<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02;ooooo000Coooo
o`Co00001oooool00ol0003oooooooooo`03ooooo`;o00003_ooool00ol0003oooooooooo`2Koooo
o`;o00003Oooool4o`0000_ooooo1_l0000=ooooo`03o`000?oooooo000000cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ool000009Oooool001;ooooo0ol00009ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0Zoooool3o`0000_ooooo1Ol0000>ooooo`?o00003Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o
00009_ooool001;ooooo0_l0000:ooooo`05o`000?ooooooooooooooool00000K?ooool2o`0002oo
oooo0_l0000=ooooo`Co00002oooool6o`0000gooooo00?o0000ooooool000003Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003o
ooooo`00000>ooooo`Co00009Oooool0017ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1^ooooo`?o0000;Oooool3o`0000cooooo1?l0000>ooooo`?o00003Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0<ooooo`;o00003_ooool3o`0002Oooooo000@ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0G?ooool2o`0000oooooo1Ol0000Kooooo`;o00003Oooool4o`0000cooooo1Ol0
000=ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool4o`0000gooooo0_l0
000=ooooo`;o00006Oooool001kooooo00?o0000ooooooooool0G?ooool3o`0000gooooo1?l0000L
ooooo`?o00003?ooool4o`0000kooooo0ol0000=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03?ooool3o`0000kooooo00?o0000ooooooooool03?ooool3o`0001Wooooo000Noooo
o`;o00003_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0:ooooo`?o00003_ooool5o`0000cooooo0_l0000>oooo
o`03o`000?oooooooooo00_ooooo1?l0000<ooooo`Go00003Oooool00ol0003oooooo`00000=oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool2o`0000gooooo0_l0000=oooo
o`Co00006_ooool001gooooo0_l0000>ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000=ooooo`Co
00003Oooool2o`0001cooooo1?l0000>ooooo`?o0000K?ooool00ol0003oooooooooo`0<ooooo`?o
00003?ooool4o`0001_ooooo000Looooo`03o`000?oooooo000000gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000
ooooo`0<ooooo`Go00003?ooool2o`0000kooooo00?o0000ooooooooool06oooool5o`0000oooooo
00?o0000ooooooooool0JOooool2o`0000gooooo1?l0000<ooooo`Go00006oooool001_ooooo00Co
0000oooooooooooo00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool02oooool3o`0000gooooo1?l0000=ooooo`;o0000;_ooool3o`0007_ooooo
0ol0000<ooooo`Co00003_ooool3o`0001cooooo000Jooooo`05o`000?ooooooooooooooool00000
2oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000
ooooo`0<ooooo`Go00003?ooool2o`0000kooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`1Yooooo`;o00003Oooool4o`0000cooooo1Ol0000=ooooo`03o`000?oooooo000001gooooo
000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000>ooooo`?o00003Oooool2o`000:cooooo0ol0
000<ooooo`Go00003Oooool3o`0000gooooo00?o0000ooooooooool07_ooool001Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooool000003Oooool5o`0000cooooo0ol0000=ooooo`;o0000WOooool2o`0000cooooo1?l0000<
ooooo`Go00003Oooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo01oooooo000Goooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<oooo
o`;o00003_ooool3o`0000kooooo00?o0000ooooooooool0Z_ooool4o`0000_ooooo1Ol0000=oooo
o`Co00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo023ooooo000Fooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`00000>ooooo`Co
00003?ooool3o`0000kooooo00?o0000ooooooooool0Voooool2o`0000gooooo1?l0000;ooooo`Go
00003Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool08Oooool001Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`;o
00003_ooool3o`0000kooooo00?o0000ooooooooool0Z_ooool4o`0000_ooooo1Ol0000=ooooo`Co
00003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool08_ooool001;ooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`02ooooo`Co0000
3Oooool2o`0000kooooo00?o0000ooooooooool0Voooool2o`0000gooooo1?l0000;ooooo`Ko0000
3?ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Sooooo`004_ooool2o`0000[ooooo00Co0000oooooooooooo
oooo0ol0000>ooooo`03o`000?oooooooooo0:[ooooo1?l0000;ooooo`Go00003_ooool3o`0000co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool09?ooool0017ooooo1?l00009ooooo`04o`000?ooooooooooooooo`;o
00003_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo02kooooo0_l0000=ooooo`Co
00002oooool6o`0000gooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02oooool00ol0003oooooo`00000Wooooo`00
4?ooool3o`0000_ooooo00Co0000oooooooooooo0000OOooool2o`0002kooooo0ol0000;ooooo`Go
00003_ooool3o`0000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`0002Sooooo000@ooooo`;o0000
3?ooool00ol0003oooooo`00001/ooooo`;o00003oooool4o`0001cooooo0_l0000=ooooo`Co0000
2oooool6o`0000gooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`Co0000
9oooool000oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1/ooooo`?o00003Ooo
ool3o`0001gooooo0ol0000<ooooo`Co00003_ooool3o`0000gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0<ooooo`?o0000:Oooool000kooooo00?o0000ooooooooool03Oooool2
o`0000kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`?o00003_ooool5
o`0000cooooo0_l0000>ooooo`03o`000?oooooooooo00_ooooo1?l0000<ooooo`Go00003Oooool0
0ol0003oooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool2
o`0000kooooo00?o0000ooooooooool06Oooool001gooooo0_l0000>ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02oooool3o`0000gooooo1?l0000=ooooo`03o`000?oooooooooo
01_ooooo1?l0000>ooooo`?o0000K?ooool00ol0003oooooooooo`0Zooooo`007?ooool00ol0003o
ooooo`00000=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0<ooooo`Go
00003?ooool2o`0000kooooo00?o0000ooooooooool06oooool5o`0000oooooo00?o0000oooooooo
ool0J_ooool00ol0003oooooooooo`0[ooooo`006oooool01?l0003oooooooooool0000<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00_ooooo0ol0000=ooooo`Co00003Oooool2o`0002kooooo0ol0002[ooooo`00
6_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000ooooo`0<ooooo`Go
00003?ooool2o`0000kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Zooooo`00
6Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo0ol0000>ooooo`?o0000
3Oooool2o`000>kooooo000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo0_l000000ooooooo0000oooo
o`0<ooooo`Go00003?ooool3o`0000gooooo00?o0000ooooooooool0k_ooool001Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool02oooool3o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo0?kooooo000Foooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooo000000gooooo1Ol0000<ooooo`?o00003_ooool00ol0003oooooooooo`3ooooo
o`005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03?ooool2o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo0?oooooo4Oooool001Cooooo
00?o0000ooooooooool01oooool01ol0003ooooooooooooooooo0000ooooool000003_ooool4o`00
00cooooo0ol0000>ooooo`03o`000?oooooooooo0?oooooo4_ooool001?ooooo00?o0000oooooooo
ool02?ooool01?l0003oooooooooooooool2o`0000kooooo0ol0000>ooooo`03o`000?oooooooooo
0?oooooo8oooool0013ooooo00?o0000ooooool000002oooool00ol0003oooooooooo`04o`0000go
oooo0_l0000>ooooo`03o`000?oooooooooo0?oooooo9?ooool0013ooooo0_l00002ooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooo`000002o`0000kooooo00?o0000ooooooooool0
ooooooleooooo`003oooool4o`0000?ooooo00?o0000ooooooooool01Oooool01?l0003oooooo`00
0?l0000>ooooo`03o`000?oooooooooo0?oooooo=_ooool000kooooo0ol00005ooooo`03o`000?oo
oooooooo00Gooooo0_l0003oooooodWooooo000>ooooo`;o00001_ooool00ol0003oooooooooo`05
ooooo`?o0000oooooom8ooooo`003Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooom8ooooo`003?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooom8ooooo`005_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?ooooooB?ooool001Cooooo00?oEEEEofIVI_l000001ooo
ool00ol0003oooooooooo`3oooooodSooooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool0
01kooooo00?o0000ooooooooool0oooooom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSo
oooo000Nooooo`03o`000?oooooooooo0?ooooooB?ooool001kooooo00?o0000ooooooooool0oooo
oom8ooooo`007_ooool00ol0003oooooooooo`3oooooodSooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {359, 0}} -> {-0.0959237, -0.0895275, \
0.00393125, 0.00393125}}]
}, Open  ]],

Cell["\<\
One can see that particles will be attracted to the mass \
distribution along the diagonal unless they are close to the edge of the box, \
so that they are attracted to the mass distribution in one of the other \
surrounding boxes. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Interpolation of the Force from the Grid to Particle \
Positions\
\>", "Section",
  CellTags->{"i:63", "c:34"}],

Cell[TextData[{
  "Now that we know the force on the grid, we must interpolate the force back \
to the particle positions. One can easily do this by first creating \
interpolating functions for ",
  Cell[BoxData[
      \(TraditionalForm\`F\_x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`F\_y\)]],
  ", and then evaluating these functions at each particle  position. This is \
set up in the module below:"
}], "Text"],

Cell[BoxData[
    \(Fpart[r_, Fx_, Fy_]\  := 
      Module[{}, \[IndentingNewLine]fxi\  = \ 
          Interpolation[Flatten[Fx, 1], 
            InterpolationOrder \[Rule] 1]; \[IndentingNewLine]fyi\  = \ 
          Interpolation[Flatten[Fy, 1], 
            InterpolationOrder \[Rule] 1]; \[IndentingNewLine]F\  = \ 
          Table[{fxi[r[\([m, 1]\)], r[\([m, 2]\)]], 
              fyi[r[\([m, 1]\)], r[\([m, 2]\)]]}, {m, 1, 
              Length[r]}]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.74"],

Cell["\<\
We reduce the order of the interpolation to 1 (linear \
interpolation) from the default of 3 (cubic interpolation) in order to speed \
up the process. Also, we will find that linear interpolation is actually more \
accurate, because the total system momentum is exactly conserved in the \
simulation when linear interpolation is used.\
\>", "Text"],

Cell["\<\
\t To test this module, we evaluate the force on the particles that \
are evenly distributed along the box diagonal:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Fpart[r, Fx, Fy];\)\), "\n", 
    \(F\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.75"],

Cell[BoxData[
    \({{2.969107051673673`*^-16, 8.229602123953836`*^-15}, {0.`, 
        0.`}, {8.881784197001252`*^-15, 
        8.881784197001252`*^-15}, {\(-8.881784197001252`*^-15\), \
\(-8.881784197001252`*^-15\)}, {3.902877655076609`*^-15, 
        4.623635174044601`*^-15}, {0.`, 0.`}, {0.`, 
        0.`}, {1.1135241121310874`*^-14, 
        1.0181040951492131`*^-14}, {\(-8.881784197001252`*^-15\), \
\(-8.881784197001252`*^-15\)}, {0.`, 
        0.`}, {\(-3.0756135938911294`*^-15\), \(-1.1876428206694692`*^-15\)}, \
{0.`, 0.`}, {1.4415150379361347`*^-15, 
        8.506083262705283`*^-15}, {\(-8.881784197001252`*^-15\), \
\(-8.881784197001252`*^-15\)}, {0.`, 0.`}, {0.`, 0.`}, {0.`, 
        0.`}, {1.4415150379361347`*^-15, 
        8.506083262705283`*^-15}, {\(-8.881784197001252`*^-15\), \
\(-8.881784197001252`*^-15\)}, {0.`, 0.`}}\)], "Output"]
}, Open  ]],

Cell["\<\
The forces on the particles vanish because of their even \
distribution.  \
\>", "Text"],

Cell["\<\
\tFor those who might wish to apply the PIC method on a mainframe \
computer, the above module is reproduced below without making use of \
interpolating functions. Rather, the linear interpolation is carried out \
directly. One can see from this module that linear interpolation back to the \
particles is just another form of area weighting:\
\>", "Text"],

Cell[BoxData[
    RowBox[{
      RowBox[{\(Fpart1[r_, Fx_, Fy_]\), " ", ":=", " ", 
        RowBox[{"Module", "[", 
          
          RowBox[{\({x, y, Npart, 
              area1, \[Delta]x, \[Delta]y, \[Delta]x1, \[Delta]y1, a1, a2, 
              a3, a4, i, i1, j, j1, fx, fy}\), ",", "\[IndentingNewLine]", 
            
            RowBox[{\(Npart\  = \ Length[r]\), ";", 
              "\[IndentingNewLine]", \(\[CapitalDelta]A = \[CapitalDelta]x*\
\[CapitalDelta]y\), ";", "\[IndentingNewLine]", 
              StyleBox[\( (*\ x\ and\ y\ positions\ of\ particle\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(x = 
                Table[r[\([n, 1]\)], {n, 1, Npart}]\), ";", 
              "\[IndentingNewLine]", \(y = 
                Table[r[\([n, 2]\)], {n, 1, Npart}]\), ";", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  list\ of\ lengths\ of\ the\ rectangle\ sides\ for\ each\ \
particle\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(\[Delta]x = Mod[x, \[CapitalDelta]x]\),
               ";", "\[IndentingNewLine]", \(\[Delta]y = 
                Mod[y, \[CapitalDelta]y]\), ";", 
              "\[IndentingNewLine]", \(\[Delta]x1\  = \ \[CapitalDelta]x - \
\[Delta]x\), ";", 
              "\[IndentingNewLine]", \(\[Delta]y1\  = \ \[CapitalDelta]y - \
\[Delta]y\), ";", "\[IndentingNewLine]", 
              StyleBox[\( (*\ list\ of\ rectangle\ areas\ \ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(a1\  = \ 
                Table[\[Delta]x1[\([n]\)]\ \[Delta]y1[\([n]\)], {n, 1, 
                    Npart}]\), ";", 
              "\[IndentingNewLine]", \(a2\  = \ 
                Table[\[Delta]x1[\([n]\)] \[Delta]y[\([n]\)], {n, 1, 
                    Npart}]\), ";", 
              "\[IndentingNewLine]", \(a3\  = \ 
                Table[\[Delta]x[\([n]\)] \[Delta]y[\([n]\)], {n, 1, Npart}]\),
               ";", "\[IndentingNewLine]", \(a4\  = \ 
                Table[\[Delta]x[\([n]\)] \[Delta]y1[\([n]\)], {n, 1, 
                    Npart}]\), ";", "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  list\ of\ surrounding\ grid\ points\ for\ all\ particles\ \ \
*) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(i\  = 
                Quotient[x, \[CapitalDelta]x] + 1\), ";", 
              "\[IndentingNewLine]", \(j\  = \ 
                Quotient[y, \[CapitalDelta]y] + 1\), ";", 
              "\[IndentingNewLine]", \(i1\  = \ 1 + Mod[i, Mx]\), ";", 
              "\[IndentingNewLine]", \(j1\  = \ 1 + Mod[j, My]\), ";", 
              "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ 
                  linear\ interpolation\ by\ area\ weighting\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(fx\  = 
                Table[Fx[\([i[\([n]\)], j[\([n]\)]]\)]*
                      a1[\([n]\)]\  + \[IndentingNewLine]\ 
                    Fx[\([i[\([n]\)], j1[\([n]\)]]\)]*a2[\([n]\)]\  + \ 
                    Fx[\([i1[\([n]\)], j1[\([n]\)]]\)]*a3[\([n]\)]\  + \ 
                    Fx[\([i1[\([n]\)], j[\([n]\)]]\)]*a4[\([n]\)], {n, 1, 
                    Npart}]\), ";", 
              "\[IndentingNewLine]", \(fy\  = 
                Table[\ Fy[\([i[\([n]\)], j[\([n]\)]]\)]*
                      a1[\([n]\)]\  + \[IndentingNewLine]Fy[\([i[\([n]\)], 
                          j1[\([n]\)]]\)]*a2[\([n]\)]\  + \ 
                    Fy[\([i1[\([n]\)], j1[\([n]\)]]\)]*a3[\([n]\)]\  + \ 
                    Fy[\([i1[\([n]\)], j[\([n]\)]]\)]*a4[\([n]\)], {n, 1, 
                    Npart}]\), ";", "\[IndentingNewLine]", 
              
              StyleBox[\( (*\ table\ of\ forces\ for\ each\ particle, \ 
                  paroperly\ normalized\ *) \),
                FontColor->RGBColor[1, 0, 0]], 
              "\[IndentingNewLine]", \(F = 
                Table[{fx[\([m]\)], fy[\([m]\)]}, {m, 1, 
                      Npart}]/\[CapitalDelta]A\), ";"}]}], "]"}]}], 
      ";"}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.76"],

Cell[TextData[{
  "We must now put these modules together to create the force function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["f",
            FontWeight->"Bold",
            FontSlant->"Plain"], "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " used in the leapfrog routine:"
}], "Text"],

Cell[BoxData[
    RowBox[{\(f[r_]\), " ", ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({}\), ",", "\[IndentingNewLine]", 
          StyleBox[\( (*determine\ the\ density\ *) \),
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
          RowBox[{\(density[r]\), ";", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                determine\ the\ force\ on\ the\ grid\ and\ the\ potential\ \
matrix\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(fft\[Phi][\[Rho]]\), ";", 
            "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ 
                determine\ the\ force\ at\ the\ particle\ positions\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Fpart[r, Fx, Fy]\)}]}], " ", 
        "]"}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.77"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["7.3.5 Examples", "Subsubtitle",
  CellTags->"c:35"],

Cell[CellGroupData[{

Cell["Code Tests ", "Section",
  CellTags->"c:36"],

Cell[TextData[{
  "It is always very important to test the validity of simulation results  \
One type of test involves running example problems where one already knows \
the answer. These sort of tests are used in the early stages of code \
development, to find errors in the program. For instance, we can take two \
particles a distance ",
  Cell[BoxData[
      \(TraditionalForm\`2  R\)]],
  " apart and orbit the particles around one another. Theoretically, they \
should follow a circular orbit of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " if they are given a velocity  ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " such that the centrifugal force balances the gravitational attraction. \
Since we are solving for the gravitational force in two dimensions only, the \
force of gravitational attraction between particles a distance ",
  Cell[BoxData[
      \(TraditionalForm\`2  R\)]],
  " apart is ",
  Cell[BoxData[
      \(TraditionalForm\`F = G\ m\^2/\ R\)]],
  ". Thus, for circular motion, ",
  Cell[BoxData[
      \(TraditionalForm\`m\ v\^2/R = G\ m\^2/R\)]],
  ", which implies"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(v\^2 = G\ m\)\)\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["7.78",
    ButtonData:>"Cell 7.78",
    ButtonStyle->"Hyperlink"],
  ", we test this result by running the code for several rotation periods. \
Also, we time the code using a function called ",
  StyleBox["Timing",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", available in the add-on package ",
  StyleBox["Utilities",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(<< Utilities`;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(m = 1; M = 40; 
    L = 1; \[CapitalDelta]x\  = \ \(\[CapitalDelta]y\  = \ 
        L/M\); \[CapitalDelta]t = 0.04;\[IndentingNewLine]\), "\n", 
    \(\(Clear[r, p];\)\), "\n", 
    \(\(R\  = \ 0.1;\)\), "\n", 
    \(\(r0\  = \ {{0.5, \ 0.5 - R}, {0.5, 0.5\  + \ R}};\)\), "\n", 
    \(\(v\  = \ Sqrt[\ G\ m];\)\), "\n", 
    \(\(\(p0\  = \ {{m\ v, 0}, {\(-m\)\ v, 0}};\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(Timing[leapfrog[r0, p0, 30, \[CapitalDelta]t]]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.78"],

Cell[BoxData[
    \({15.08`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell["\<\
The code takes quite a while to run, but most of the time is spent \
on the FFT.  Fortunately, the time for the FFT is not affected by an increase \
in the number of particles, so running the code with a thousand particles \
doesn't take much longer than running it with two particles. \
\>", "Text"],

Cell[BoxData[
    \(\(Table[
        ListPlot[r[n], PlotRange \[Rule] {{0, 1}, {0, 1}}, 
          AspectRatio \[Rule] 1], {n, 0, 30, 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.79"],

Cell[BoxData[
    \( (*simulation\ removed\ to\ save\ space*) \)], "Input"],

Cell[TextData[{
  "\tCell ",
  ButtonBox["7.79",
    ButtonData:>"Cell 7.79",
    ButtonStyle->"Hyperlink"],
  " shows that the two particles orbit in  nearly circular motion, as \
expected.  The orbit is not perfectly circular, because  of the influence of \
the periodic boundary conditions: these particles are also attracted to their \
images in the surrounding boxes, causing a slight distortion of the orbit.  "
}], "Text"],

Cell[TextData[{
  "\tIt can also be  useful to test whether constants of the motion are being \
properly evaluated. However, we will see that in the PIC method these \
constants do not always provide us with a good measure of solution accuracy. \
For example, the total momentum should not vary: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["P",
              FontWeight->"Bold",
              FontSlant->"Plain"], "tot"], "=", " ", 
          RowBox[{\(\[Sum]\+i\), 
            StyleBox[
              SubscriptBox["p", 
                StyleBox["i",
                  FontWeight->"Plain",
                  FontSlant->"Italic"]],
              FontWeight->"Bold",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". This is checked in Cell ",
  ButtonBox["7.80",
    ButtonData:>"Cell 7.80",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Ptot[n_]\  := \ 
        Sum[\(p[n]\)[\([m]\)], {m, 1, Length[p[n]]}];\)\), "\n", 
    \(\(ListPlot[Table[Ptot[n], {n, 1/2, 30, 1}], 
        PlotLabel \[Rule] \ "\<momentum\n\>", \ 
        AxesLabel \[Rule] {"\<Px\>", "\<Py\>"}, 
        PlotRange \[Rule] All];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.80"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.699927 6.54831e+13 0.603319 2.57363e+13 [
[.0451 .59082 -21.75 -12.5 ]
[.0451 .59082 21.75 0 ]
[.17606 .59082 -21.75 -12.5 ]
[.17606 .59082 21.75 0 ]
[.30703 .59082 -21.75 -12.5 ]
[.30703 .59082 21.75 0 ]
[.43799 .59082 -21.75 -12.5 ]
[.43799 .59082 21.75 0 ]
[.56896 .59082 -21.75 -12.5 ]
[.56896 .59082 21.75 0 ]
[.83089 .59082 -18.75 -12.5 ]
[.83089 .59082 18.75 0 ]
[.96186 .59082 -18.75 -12.5 ]
[.96186 .59082 18.75 0 ]
[1.025 .60332 0 -6 ]
[1.025 .60332 16 6 ]
[.68743 .08859 -43.5 -6.25 ]
[.68743 .08859 0 6.25 ]
[.68743 .21727 -55.5 -6.25 ]
[.68743 .21727 0 6.25 ]
[.68743 .34596 -43.5 -6.25 ]
[.68743 .34596 0 6.25 ]
[.68743 .47464 -43.5 -6.25 ]
[.68743 .47464 0 6.25 ]
[.69993 .64303 -8 0 ]
[.69993 .64303 8 12 ]
[.5 .63053 -26.0625 0 ]
[.5 .63053 26.0625 24.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0451 .60332 m
.0451 .60957 L
s
gsave
.0451 .59082 -21.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-14) show
grestore
.17606 .60332 m
.17606 .60957 L
s
gsave
.17606 .59082 -21.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-8) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.30703 .60332 m
.30703 .60957 L
s
gsave
.30703 .59082 -21.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-6) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.43799 .60332 m
.43799 .60957 L
s
gsave
.43799 .59082 -21.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.56896 .60332 m
.56896 .60957 L
s
gsave
.56896 .59082 -21.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.83089 .60332 m
.83089 .60957 L
s
gsave
.83089 .59082 -18.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.96186 .60332 m
.96186 .60957 L
s
gsave
.96186 .59082 -18.75 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.125 Mabswid
.07784 .60332 m
.07784 .60707 L
s
.11058 .60332 m
.11058 .60707 L
s
.14332 .60332 m
.14332 .60707 L
s
.2088 .60332 m
.2088 .60707 L
s
.24155 .60332 m
.24155 .60707 L
s
.27429 .60332 m
.27429 .60707 L
s
.33977 .60332 m
.33977 .60707 L
s
.37251 .60332 m
.37251 .60707 L
s
.40525 .60332 m
.40525 .60707 L
s
.47074 .60332 m
.47074 .60707 L
s
.50348 .60332 m
.50348 .60707 L
s
.53622 .60332 m
.53622 .60707 L
s
.6017 .60332 m
.6017 .60707 L
s
.63444 .60332 m
.63444 .60707 L
s
.66719 .60332 m
.66719 .60707 L
s
.73267 .60332 m
.73267 .60707 L
s
.76541 .60332 m
.76541 .60707 L
s
.79815 .60332 m
.79815 .60707 L
s
.86364 .60332 m
.86364 .60707 L
s
.89638 .60332 m
.89638 .60707 L
s
.92912 .60332 m
.92912 .60707 L
s
.01235 .60332 m
.01235 .60707 L
s
.9946 .60332 m
.9946 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
gsave
1.025 .60332 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Px) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.69993 .08859 m
.70618 .08859 L
s
gsave
.68743 .08859 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-14) show
grestore
.69993 .21727 m
.70618 .21727 L
s
gsave
.68743 .21727 -55.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-14) show
grestore
.69993 .34596 m
.70618 .34596 L
s
gsave
.68743 .34596 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-14) show
grestore
.69993 .47464 m
.70618 .47464 L
s
gsave
.68743 .47464 -43.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-15) show
grestore
.125 Mabswid
.69993 .11433 m
.70368 .11433 L
s
.69993 .14007 m
.70368 .14007 L
s
.69993 .1658 m
.70368 .1658 L
s
.69993 .19154 m
.70368 .19154 L
s
.69993 .24301 m
.70368 .24301 L
s
.69993 .26875 m
.70368 .26875 L
s
.69993 .29448 m
.70368 .29448 L
s
.69993 .32022 m
.70368 .32022 L
s
.69993 .37169 m
.70368 .37169 L
s
.69993 .39743 m
.70368 .39743 L
s
.69993 .42317 m
.70368 .42317 L
s
.69993 .4489 m
.70368 .4489 L
s
.69993 .50037 m
.70368 .50037 L
s
.69993 .52611 m
.70368 .52611 L
s
.69993 .55185 m
.70368 .55185 L
s
.69993 .57758 m
.70368 .57758 L
s
.69993 .06286 m
.70368 .06286 L
s
.69993 .03712 m
.70368 .03712 L
s
.69993 .01138 m
.70368 .01138 L
s
.25 Mabswid
.69993 0 m
.69993 .61803 L
s
gsave
.69993 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Py) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87.0625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 32.5 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(momentum) show
63.000 25.500 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.008 w
.75809 .60332 Mdot
.74355 .59618 Mdot
.02381 .25473 Mdot
.10015 .28044 Mdot
.22374 .31759 Mdot
.42003 .20615 Mdot
.51091 .16329 Mdot
.40185 .12615 Mdot
.50364 .20901 Mdot
.65631 .23901 Mdot
.78717 .28759 Mdot
.97619 .32616 Mdot
.7799 .10329 Mdot
.84896 .05186 Mdot
.93984 .16901 Mdot
.95438 .21187 Mdot
.40912 .11758 Mdot
.4382 .18187 Mdot
.56907 .24187 Mdot
.46728 .28759 Mdot
.05289 .33473 Mdot
.1365 .09758 Mdot
.32188 .10901 Mdot
.46728 .17472 Mdot
.63086 .10615 Mdot
.57634 .06615 Mdot
.38731 .01472 Mdot
.55453 .09901 Mdot
.72174 .14472 Mdot
.78717 .10615 Mdot
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{403.75, 249.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007h0001=b000`400?l00000o`00003ooooooom9
ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?oo
ooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo
003oooooodWooooo00?o0000ooooooooool0[Oooool00;cooooo0ol00029ooooo`?o0000[Oooool0
0;cooooo0ol00029ooooo`03o`000?oooooooooo0:gooooo002looooo`?o0000ROooool00ol0003o
ooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o
0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9oooo
o`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?oooooo
BOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003o
ooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool3o`000:gooooo003oooooodWo
oooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooo
oom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool0
0?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo03ko
oooo0ol0001/ooooo`00oooooom9ooooo`03o`000?oooooooooo03kooooo0ol0001/ooooo`00oooo
oom9ooooo`03o`000?oooooooooo03kooooo0ol0001/ooooo`00oooooom9ooooo`03o`000?oooooo
oooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003o
ooooooooo`2]ooooo`00oooooolAooooo`?o0000=Oooool3o`000:gooooo003ooooooa7ooooo0ol0
000eooooo`03o`000?oooooooooo0:gooooo003ooooooa7ooooo0ol0000eooooo`03o`000?oooooo
oooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003o
ooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003ooooooagooooo0_o^
k^h3ooooo`;ok^k^9Oooool00ol0003oooooooooo`2]ooooo`00oooooolFooooo`Go00000_ooool0
1oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^hFooooo`03o`000?oooooooooo0:gooooo003ooooooaKooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05_ooool00ol0003oooooooooo`2]ooooo`00oooo
ool>ooooo`Ko00000oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Kooooo00?o0000ooooooooool0
[Oooool00?oooooo6?ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003o
ooooooooo`2]ooooo`00oooooolIooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
5_ooool4o`000:cooooo003ooooooa[ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005_ooool00ol0003ooooo
ooooo`2]ooooo`00oooooolFooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool3o`0000Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`2]ooooo`00COooool3o`000<Gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP09oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2]oooo
o`00COooool3o`000;Kooooo0ol0000[ooooo`Co00000oooool00ol0003oooooooooo`04o`0000Ko
oooo00?o0000ooooooooool0[Oooool004gooooo0ol0002fooooo`?o0000<_ooool01ol0003ooooo
oooooooooooo0000ooooool000001_ooool00ol0003oooooooooo`2]ooooo`00ooooool7ooooo`?o
0000<_ooool00ol0003oooooooooo`02ooooo`;o00001_ooool00ol0003oooooooooo`0Pooooo`?o
0000R_ooool00?oooooo:Oooool3o`0000oooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool08?ooool6o`0008Oooooo002Oooooo`?o0000Q_ooool3o`0001gooooo00?o
0000ooooooooool08?ooool6o`0008Oooooo002Oooooo`?o0000Q_ooool3o`0001gooooo00?o0000
ooooooooool08oooool3o`0008Oooooo002Oooooo`?o0000Y_ooool00ol0003oooooooooo`2]oooo
o`00oooooom9ooooo`?o0000[Oooool00<Kooooo0ol0001oooooo`03o`000?oooooooooo0:gooooo
0036ooooo`?o0000Ooooool00ol0003oooooooooo`2]ooooo`00a_ooool3o`0007oooooo00?o0000
ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00`_ooool3o`0008?o
oooo00?o0000ooooooooool0[Oooool00<;ooooo0ol00023ooooo`03o`000?oooooooooo0:gooooo
0032ooooo`?o0000Poooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooo
oooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003o
ooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo0ol0
002]ooooo`00oooooom9ooooo`03o`000?oooooooooo00Kooooo0ol0002Tooooo`00oooooom9oooo
o`03o`000?oooooooooo00Kooooo0ol0002Tooooo`00oooooom9ooooo`03o`000?oooooooooo00Ko
oooo0ol0002Tooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o
0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9oooo
o`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00??ooooo
0ol0001Booooo`03o`000?oooooooooo0:gooooo003cooooo`?o0000D_ooool00ol0003ooooooooo
o`2]ooooo`00loooool3o`0005;ooooo0ol0002]ooooo`00oooooom9ooooo`03o`000?oooooooooo
06Oooooo0ol00013ooooo`00oooooom9ooooo`03o`000?oooooooooo06Oooooo0ol00013ooooo`00
h?ooool3o`0006Gooooo00?o0000ooooooooool0Ioooool3o`0004?ooooo003Pooooo`?o0000IOoo
ool00ol0003oooooooooo`2]ooooo`00h?ooool3o`0006Gooooo00?o0000ooooooooool0[Oooool0
0?ooooooBOooool00ol0003oooooooooo`2]ooooo`00doooool3o`0007;ooooo00?o0000oooooooo
ool0[Oooool00=?ooooo0ol0001booooo`03o`000?oooooooooo0:gooooo003Cooooo`?o0000L_oo
ool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003ooooo
odWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool3o`000:gooooo003oooooodWooooo
00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9
ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00<_o
oooo0ol0001jooooo`03o`000?oooooooooo0:gooooo003;ooooo`?o0000Coooool2onk^kP?ooooo
0_o^k^hTooooo`03o`000?oooooooooo0:gooooo003;ooooo`?o00008_ooool3o`0001Cooooo1?l0
00000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^hEooooo`03o`000?oooooooooo0:gooooo003`ooooo`?o00005_ooool00ol0003o
ooooooooo`04ooooo`;o8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Eooooo`03o`00
0?oooooooooo06gooooo0ol0000mooooo`00l?ooool3o`0000_ooooo1_l00005ooooo`03o`000?oo
oooooooo00oooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@01Gooooo00?o0000ooooooooool0KOooool3o`00
03gooooo003oooooo`[ooooo00?o0000ooooooooool03_ooool02OmgMgOo<S8booooooooooook^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Eooooo`03o`000?oooooooooo06gooooo0ol0000mooooo`00ooooool:ooooo`03o`000?oo
oooooooo00_ooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001Gooooo
1?l0002/ooooo`00ooooool:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00ooo
ool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400Eooooo`03o`000?oooooooooo0:gooooo003oooooo`[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`08ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:gooooo
003oooooo`Sooooo00?oEEEEofIVI_l000003Oooool4o`0000cooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0:gooooo003oooooocKooooo1?l00003ooooo`03o`000?oo
oooooooo00Co00001Oooool00ol0003oooooooooo`2]ooooo`00oooooolmooooo`07o`000?oooooo
ooooooooool0003oooooo`000005ooooo`03o`000?oooooooooo0:gooooo003oooooocgooooo00?o
0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool0[Oooool00?oooooo??ooool2
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2]ooooo`00oooooom9oooo
o`03o`000?oooooooooo0:gooooo003oooooocGooooo0ol0000Aooooo`03o`000?oooooooooo0:go
oooo003oooooo`kooooo0ol0000Tooooo`?o00004Oooool00ol0003oooooooooo`2]ooooo`00oooo
ool>ooooo`?o00009?ooool3o`00017ooooo00?o0000ooooooooool0[Oooool00?oooooo3_ooool3
o`0003Sooooo0ol0002]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWo
oooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`006_oo
ool3o`000?oooooo;?ooool00ol0003oooooooooo`2]ooooo`006_ooool3o`000?oooooo;?ooool0
0ol0003oooooooooo`2]ooooo`006_ooool3o`000?oooooo;?ooool00ol0003oooooooooo`2]oooo
o`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0
[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooo
oooo0:gooooo003oooooodWooooo0ol0002]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:go
oooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003ooooooooo
o`2]ooooo`00??ooool3o`000?oooooo2_ooool00ol0003oooooooooo`2]ooooo`00??ooool3o`00
0?oooooo2_ooool00ol0003oooooooooo`2]ooooo`00??ooool3o`000?oooooo2_ooool00ol0003o
ooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003Pooooo`?o0000IOoo
ool00ol0003oooooooooo`0Sooooo`?o0000Qoooool00>3ooooo0ol0001Uooooo`03o`000?oooooo
oooo02?ooooo0ol00027ooooo`00h?ooool3o`0006Gooooo00?o0000ooooooooool08oooool3o`00
08Oooooo003oooooodWooooo0ol0002]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo
003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]
ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000oooooooo
ool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oo
oooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0
003oooooooooo`2]ooooo`00Loooool3o`000=;ooooo00?o0000ooooooooool0[Oooool007?ooooo
0ol0003Booooo`03o`000?oooooooooo0:gooooo001cooooo`?o0000d_ooool3o`000:gooooo003o
ooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`1goooo
o`?o0000<oooool00?ooooooBOooool00ol0003oooooooooo`1gooooo`?o0000<oooool00?oooooo
BOooool00ol0003oooooooooo`1gooooo`?o0000<oooool00?ooooooBOooool00ol0003ooooooooo
o`2]ooooo`009oooool3o`000?;ooooo0_o^k^h3ooooo`;ok^k^9Oooool00ol0003oooooooooo`2]
ooooo`009oooool3o`000>cooooo1?l000002Ol@413oooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQKooooo00?o0000
ooooooooool0[Oooool002Oooooo0ol0003^ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEE
EOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Fooooo`03o`000?oooooooooo0:gooooo003oooooo`kooooo1_l00005ooooo`03o`000?oooooo
oooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41005_ooool00ol0003oooooooooo`2]ooooo`00oooooolIooooo`03o`000?oooooo
oooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo0:gooooo003ooooooaWooooo00_o
0000ooooooooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000Fooooo`Co0000[?ooool00?oooooo6Oooool0
1?l0003oooooooooooooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400Fooooo`03o`000?oooooooooo0:gooooo003ooooooaWooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
5_ooool00ol0003oooooooooo`2]ooooo`00oooooolGooooo`03oeEEEOmVIVKo000000gooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0ol00004ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0[Oooool00?oooooo??ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0[Oooool00?oooooo=Oooool4
o`0000?ooooo00?o0000ooooooooool01?l00006ooooo`03o`000?oooooooooo0:gooooo003ooooo
occooooo00Oo0000ooooooooooooooooo`000?oooooo000000Kooooo00?o0000ooooooooool0[Ooo
ool00?oooooo??ooool00ol0003oooooooooo`02ooooo`;o00001_ooool00ol0003oooooooooo`2]
ooooo`00oooooolkooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003ooooo
ooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo0ol0002]
ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000oooooooo
ool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oo
oooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0
003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo
00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9
ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo0ol0002]ooooo`00oooooom9ooooo`03
o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOoo
ool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003ooooo
odWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00
oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Ooo
ool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo
0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool3o`000:gooooo
003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]
ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000oooooooo
ool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oo
oooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0
003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo
00?o0000ooooooooool0[Oooool00?ooooooBOooool3o`000:gooooo003oooooodWooooo00?o0000
ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03
o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOoo
ool00ol0003oooooooooo`2]ooooo`00oooooolMooooo`;ok^k^0oooool2onk^kRGooooo00?o0000
ooooooooool0[Oooool00?oooooo5oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEE
onk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^hFooooo`03o`000?oooooooooo0:gooooo003ooooooa[ooooo00WoMgMgoc8b<_oooooooooo
onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05_ooool00ol0003oooooooooo`2]ooooo`00ooooool>ooooo`Ko00001oooool01ol0
003ooooooooooooooooogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41005_ooool00ol0003oooooooooo`2]ooooo`00oooooolJooooo`09ogMgMolb
<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000001Kooooo00?o0000ooooooooool0[Oooool00?oooooo5oooool03Ol0
003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`2]
ooooo`00oooooolGooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005_ooool4o`000:cooooo003ooooo
oaOooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05_ooool00ol0003oooooooooo`2]ooooo`00oooooolGooooo`Co00003?ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool3o`0000;ooooo0_l00007
ooooo`03o`000?oooooooooo0:gooooo003ooooooccooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:gooooo003oooooocGooooo1?l00003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2]oooo
o`00oooooollooooo`03o`000?oooooooooo00?o00001oooool00ol0003oooooooooo`2]ooooo`00
oooooollooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0[Oooool00?oooooo
>oooool2o`0000;ooooo1?l00006ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o
0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9oooo
o`03o`000?oooooooooo0:gooooo003oooooodWooooo0ol0002]ooooo`00oooooom9ooooo`03o`00
0?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool0
0ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWo
oooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooo
oom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool0
0?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:go
oooo003oooooodWooooo0ol0002]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003o
ooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]oooo
o`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000ooooooooool0
[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooo
oooo0:gooooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003o
ooooooooo`2]ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o
0000ooooooooool0[Oooool00?ooooooBOooool3o`000:gooooo003oooooodWooooo00?o0000oooo
ooooool0[Oooool00?ooooooBOooool00ol0003oooooooooo`2]ooooo`00oooooom9ooooo`03o`00
0?oooooooooo0:gooooo000Jooooo`;ok^k^0oooool2onk^kS?ooooo0_o^k^h3ooooo`;ok^k^<ooo
ool2onk^kP?ooooo0_o^k^hdooooo`;ok^k^0oooool2onk^kS?ooooo0_o^k^h3ooooo`;ok^k^?_oo
ool00ol0003oooooooooo`0Xooooo`;ok^k^0oooool2onk^kS?ooooo0_o^k^h3ooooo`;ok^k^A?oo
ool001Cooooo1?l000002Ol@413oooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQgooooo00Goc<c<ob4Q8Ol0003o8B4Q
olc<c002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kQgooooo00Gok^k^oc8b<_l0003o410@olc<c002ooooo`07
onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kR3ooooo0_l000002_l@413oooooooooooo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h3ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQgooooo1Ol00002
ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kRoooooo00?o0000ooooooooool08Oooool5o`0000;ooooo00Ook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^7oooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^
kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^=Oooool001Kooooo00?o
0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@03oooo
o`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL07Oooool01OmEEEGoMgMgoooooonHV9So8B4Q00?ooooo00Gok^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qoooo
o`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg02oooooo00?o0000ooooooooool08Oooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Pooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0eoooo
o`002oooool6o`0000Gooooo00?o0000ooooooooool00oooool00ooMgMgo0000omgMg@07ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Eooooo`Ko00000_ooool01Ol0
003ooooooooooooooooo000000Cooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41005Oooool6o`0000;ooooo00Go0000oooooooooooooooo
o`000004ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@01Kooooo1_l00002ooooo`Go00001?ooool00ooMgMgo0000omgMg@07ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Eooooo`Ko00000oooool00onH
V9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@02oooooo00?o0000ooooooooool08_ooool00onHV9So8B4Qonk^kP05
ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@01gooooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Gooooo000Fooooo`03o`000?oooooooooo00;ooooo00Go
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Mooooo`05oc8b<_nHV9SooooooiRHV?lb<S800oooool01Oo^k^koEEEEomgMgOmEEEGo
k^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001gooooo00Go
0000oiRHV?ooooooV9RHob4Q8@03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000007_ooool01?m4A4CogMgMooooool00004
ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000007oooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000;oooool00ol0
003oooooooooo`0Sooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Mooooo`04odA4A?oM
gMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000eooooo`005_ooool02ol0003oooooooooooooooook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000001gooooo00Goc<c<o`000?l0003o0000olc<c002ooooo`07onk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Mooooo`05o`000?mEEEGo0000oa0@4?o<c<`00_ooool01oo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000007_oo
ool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Pooooo`0;ogMgMomVIVKo
ooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool00000;oooool00ol0003oooooooooo`0Tooooo`0;ogMgMomVIVKo
ooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000007Oooool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000eooooo`005_ooool01?l0003oooooooooooooool2onk^kP?ooooo0_o^k^h5oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Mooooo`05oa0@4?nj^[[o
oooookZj^_l@41000_ooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400Mooooo`03oeEEEOn7QhOooooo00Cooooo0_o^k^h3ooooo`;ok^k^
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41007oooool00omgMgOo
c<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@027ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100;oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01kooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^
k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400eooooo`005_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Mooooo`05o`000?nj^[[ooooookZj^_l000003_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL07Oooool00ooMgMgo410@oiRHV00@ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Oooooo`03onk^k_m4A4Co000000oooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01gooooo00Go0000okZj^_ooooooV9RH
oa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0_ooooo`?o
00008Oooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01kooooo00?ok^k^odA4A?l000003oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=Oooool001Cooooo00?oEEEEofIVI_l000003Oooool0
0omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool3o`0000Cooooo00?o
0000ooooooooool02oooool01OnYZJWo410@o`000?l@413oZJVY00cooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0ol00002ooooo`;o00003oooool01?o<c<co
A4A4o`000?l@410<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08
ooooo`?o00000_ooool2o`00017ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool3o`0000;ooooo0_l0000>ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool3o`0000;ooooo0_l0000Pooooo`03o`000?oooooooooo027ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08
ooooo`?o00000_ooool2o`00013ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool3o`0000;ooooo0_l0000Vooooo`00>Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo037ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
<_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo037ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Oooooo00Co0000oooo
oooooooo00000_ooool00ol0003oooooooooo`0aooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool08oooool003;ooooo1?l00003ooooo`03o`000?oooooooooo00Co0000;?ooool4
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Zooooo`Co00000oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo1?l00003ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0:_ooool4o`0000?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo1?l00003ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0:_ooool4o`0000?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Sooooo`00>Oooool01ol0003ooooooooooooooooo0000ooooool00000<ooo
ool00ol0003oooooooooo`03o`0003Cooooo00?o0000ooooooooool00ol0000eooooo`03o`000?oo
oooooooo00?o0000=?ooool00ol0003oooooooooo`03o`00023ooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`03o`0003Cooooo00?o0000ooooooooool00ol0000Vooooo`00>Oooool0
0ol0003oooooooooo`02ooooo`;o0000<oooool01?l0003oooooooooool0000fooooo`04o`000?oo
ooooooooo`0003Oooooo00Co0000oooooooooooo0000=_ooool01?l0003oooooooooool0000Roooo
o`03o`000?oooooooooo04Oooooo00Co0000oooooooooooo0000=_ooool01?l0003oooooooooool0
000Xooooo`00>?ooool2o`0000Gooooo00?o0000ooooooooool0<?ooool2o`0000;ooooo1?l0000b
ooooo`;o00000_ooool4o`0003?ooooo0_l00002ooooo`Co0000<_ooool2o`0000;ooooo1?l0000O
ooooo`03o`000?oooooooooo04Kooooo0_l00002ooooo`Co0000<_ooool2o`0000;ooooo1?l0000U
ooooo`00oooooom9ooooo`03o`000?oooooooooo0:gooooo003oooooodWooooo00?o0000oooooooo
ool03oooool3o`0009_ooooo003oooooodWooooo00?o0000ooooooooool03oooool3o`0007oooooo
0ol000000ol@413oooooooooo`02ooooo`;o00000_ooool2o`0000kooooo003oooooodWooooo00?o
0000ooooooooool03oooool3o`00083ooooo00?o0000ooooooooool01?ooool01_o^k^ko8B4QohN7
Qonj^[[o0000omgMg@kooooo003oooooodWooooo00?o0000ooooooooool05_ooool3o`0007Wooooo
00?o0000ooooooooool01Oooool01?oMgMgo0000oa0@4?o<c<`?ooooo`004Oooooooo`000;oo0000
3_ooool3o`000003ob4Q8Oo<c<cooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^3oooool001Oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`?o000000?oooooo`000?ooool0
3Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooohN7Qol@41000oooool01?lQ8B7o
MgMgogMgMolb<S8?ooooo`009Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01go
oooo00Go0000ooooooooooooooooo`000002ooooo`;o00000_ooool2o`0000kooooo000Uooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooon7QhOo410@
01Kooooo003oooooodWooooo00?o0000ooooooooool0TOooool4o`000003ob4Q8Oo<c<cooooo01Go
oooo003oooooodWooooo00?o0000ooooooooool0[Oooool00?ooooooBOooool00ol0003ooooooooo
o`2]ooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooooiooooo`00oooo
oooiooooo`00oooooooiooooo`00oooooooiooooo`00oooooom:ooooo`?o000000?o410@oooooooo
ool0ZOooool00?ooooooC?ooool00ol@413o^[Zjooooo`2Zooooo`00oooooom<ooooo`03oiRHV?lb
<S;ooooo0:[ooooo003ooooood?ooooo0ol000000ol@413oooooooooo`03ooooo`03omgMgOl0003o
^[Zj0:[ooooo003oooooodCooooo00?o0000ooooooooool01Oooool00omEEEGoMgMgodA4A02Zoooo
o`00oooooom4ooooo`03o`000?oooooooooo00Cooooo00GogMgMoa0@4?oooooo8B4QomgMg@2Yoooo
o`00oooooom4ooooo`?o000000Wo8B4Qolc<c?ooooooooooofIVI_n7QhOooooooiRHV?mEEED0ZOoo
ool00?ooooooA?ooool02Ol0003ooooooooooon7QhOo410@ooooooo^k^ko0000onk^kP02ooooo`03
o`000?oMgMgooooo0:Oooooo003oooooodCooooo00Oo0000ooooooooooooooooo`000?oooooo410@
00;o000000Coooooo`000?l0003o410@Z?ooool00?ooooooA?ooool01Ol0003ooooooooooon7QhOo
410@0;3ooooo003ooooood?ooooo1?l000000olQ8B7oc<c<ooooo`2_ooooo`00oooooooiooooo`00
oooooooiooooo`00dOooool2o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o
000000?oEEEEonk^k_ooool00_l00002ooooo`07o`000?ooooooooooo`000?l@413ok^k^oeEEE@02
o`000005odA4A?nj^[[oooooooooool@41000_l000001?oooooo0000o`000?l@4102ooooo`05oiRH
V?l0003o0000odA4A?nj^[X00oooool01_nHV9So0000o`000?mgMgOo0000oa0@40;o00000_ooool0
1Ol0003oooooooooool0003o410@0>Kooooo003Booooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooomEEEGoMgMg0_ooool01OmgMgOoEEEEoooooooooooo000000;ooooo00_o0000oooooooo
oooo0000oooooomEEEGoMgMgooooooo^k^koMgMgoa0@4003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00Go0000ojVYZOooooooQhN7o`000002
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0iOooool00=;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooo`0000;ooooo
00Ko0000oooooooooooo0000ooooool00008ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo0>Gooooo003Booooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooool000001?ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooo`00
0?ooool01_l00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo0>Gooooo003Booooo`0:o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8OooooooEEEE
ogMgM`;ooooo00GoMgMgoeEEEOooooooooooo`000002olc<c00;o`000?nYZJWogMgMob4Q8Ooooooo
EEEEohN7Qoo^k^koooooohN7Qolb<S800oooool01Ol0003oQhN7oooooonYZJWo000000?ooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000;ooooo00Oo0000olc<c?o<c<co
0000ojVYZOoMgMgo8B4Q0>Oooooo003Aooooo`0;oa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nY
ZJWoooooonk^k_mEEED00_l000003_mEEEGok^k^ooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0
003oZJVYooooooo^k^koEEEE0_l000001om4A4Cok^k^oooooooooooo410@o`000?mgMgL00_l00000
0onHV9Sooooooa0@4005o`0000?ooooo00Co410@o`000?oooooooooo0_l000002Ooooooo410@o`00
0?lQ8B7o0000ogMgMol@413o0000ojVYZ@3Wooooo`00noooool00ol0003oooooooooo`3jooooo`00
noooool00ol0003oooooooooo`3jooooo`00oooooooiooooo`00oooooooiooooo`00oooooooioooo
o`00\
\>"],
  ImageRangeCache->{{{0, 503.688}, {310.938, 0}} -> {-1.12924*^-14, \
-2.34425*^-14, 4.29387*^-17, 1.09253*^-16}}]
}, Open  ]],

Cell[TextData[{
  "The error is down at the level of the machine precision. This is an \
excellent check to make sure there are no errors in the code. But the \
accuracy is ",
  StyleBox["too good ",
    FontSlant->"Italic"],
  "to be of any further use!  We can vary the grid spacing and the time step \
size, making them as large as we wish,  and we will find that total momentum \
is ",
  "always conserved",
  ". (Try it.) Thus, evaluation of ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["P",
            FontWeight->"Bold",
            FontSlant->"Plain"], "tot"], TraditionalForm]]],
  " tells us nothing about the accuracy of the solution. "
}], "Text"],

Cell[TextData[{
  "\tIt is interesting that this negligible error grows dramatically if a \
second-order interpolation scheme is used in the module ",
  StyleBox["Fpart",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". One might have expected that second-order interpolation would be more \
accurate than first-order interpolation. However, first-order interpolation \
(linear interpolation from the grid to the particles) works best, because the \
area-weighting used to create the density on the grid in the first place is \
also a linear interpolation. In the PIC method, it has been shown that one \
should use the same method to interpolate from the grid to the particle \
positions as one uses to determine the density from these positions [",
  ButtonBox["Birdsall and Langdon (1991)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "]."
}], "Text"],

Cell[TextData[{
  "\tAnother conserved quantity (in infinite space) is the total angular \
momentum, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(L\_z\),
            FontSlant->"Italic"], "=", 
          RowBox[{
            OverscriptBox[
              StyleBox["z",
                FontWeight->"Bold"], "^"], "\[CenterDot]", 
            RowBox[{\(\[Sum]\+i\), 
              RowBox[{
                StyleBox[
                  SubscriptBox["r", 
                    StyleBox["i",
                      FontWeight->"Plain",
                      FontSlant->"Italic"]],
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontWeight->"Bold"], "\[Times]", 
                StyleBox[
                  SubscriptBox["p", 
                    StyleBox["i",
                      FontWeight->"Plain",
                      FontSlant->"Italic"]],
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]}]}]}], TraditionalForm]]],
  ". To evaluate this quantity we require the momentum at the same time as \
the position. This can be obtained by averaging, as shown in Cell ",
  ButtonBox["7.81",
    ButtonData:>"Cell 7.81",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(p[n_]\  := \ \((p[n - 1/2]\  + p[n + 1/2])\)/2\  /; \ 
          n \[Element] Integers\  && \ n > \ 0;\)\(\n\)
    \)\), "\n", 
    \(\(\(angmom[n_]\  := \ 
        Sum[\(r[n]\)[\([i, 1]\)] \(p[n]\)[\([i, 2]\)] - \(r[n]\)[\([i, 
                  2]\)] \(p[n]\)[\([i, 1]\)], {i, 1, 
            Length[r[n]]}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(ListPlot[
        Table[{n\ \[CapitalDelta]t, angmom[n] - angmom[0]}, {n, 0, 30}], 
        PlotLabel \[Rule] \ "\<change in angular momentum versus time\>", \ 
        AxesLabel \[Rule] {"\<t\>", "\<\>"}, 
        PlotJoined \[Rule] True];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.81"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.793651 0.967038 188.859 [
[.18254 .01024 -9 -9 ]
[.18254 .01024 9 0 ]
[.34127 .01024 -9 -9 ]
[.34127 .01024 9 0 ]
[.5 .01024 -9 -9 ]
[.5 .01024 9 0 ]
[.65873 .01024 -9 -9 ]
[.65873 .01024 9 0 ]
[.81746 .01024 -3 -9 ]
[.81746 .01024 3 0 ]
[.97619 .01024 -9 -9 ]
[.97619 .01024 9 0 ]
[1.025 .02274 0 -6 ]
[1.025 .02274 10 6 ]
[.01131 .11717 -42 -4.5 ]
[.01131 .11717 0 4.5 ]
[.01131 .2116 -36 -4.5 ]
[.01131 .2116 0 4.5 ]
[.01131 .30603 -42 -4.5 ]
[.01131 .30603 0 4.5 ]
[.01131 .40046 -36 -4.5 ]
[.01131 .40046 0 4.5 ]
[.01131 .49489 -42 -4.5 ]
[.01131 .49489 0 4.5 ]
[.01131 .58932 -36 -4.5 ]
[.01131 .58932 0 4.5 ]
[.5 .63053 -116.062 0 ]
[.5 .63053 116.062 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .02274 m
.18254 .02899 L
s
[(0.2)] .18254 .01024 0 1 Mshowa
.34127 .02274 m
.34127 .02899 L
s
[(0.4)] .34127 .01024 0 1 Mshowa
.5 .02274 m
.5 .02899 L
s
[(0.6)] .5 .01024 0 1 Mshowa
.65873 .02274 m
.65873 .02899 L
s
[(0.8)] .65873 .01024 0 1 Mshowa
.81746 .02274 m
.81746 .02899 L
s
[(1)] .81746 .01024 0 1 Mshowa
.97619 .02274 m
.97619 .02899 L
s
[(1.2)] .97619 .01024 0 1 Mshowa
.125 Mabswid
.06349 .02274 m
.06349 .02649 L
s
.10317 .02274 m
.10317 .02649 L
s
.14286 .02274 m
.14286 .02649 L
s
.22222 .02274 m
.22222 .02649 L
s
.2619 .02274 m
.2619 .02649 L
s
.30159 .02274 m
.30159 .02649 L
s
.38095 .02274 m
.38095 .02649 L
s
.42063 .02274 m
.42063 .02649 L
s
.46032 .02274 m
.46032 .02649 L
s
.53968 .02274 m
.53968 .02649 L
s
.57937 .02274 m
.57937 .02649 L
s
.61905 .02274 m
.61905 .02649 L
s
.69841 .02274 m
.69841 .02649 L
s
.7381 .02274 m
.7381 .02649 L
s
.77778 .02274 m
.77778 .02649 L
s
.85714 .02274 m
.85714 .02649 L
s
.89683 .02274 m
.89683 .02649 L
s
.93651 .02274 m
.93651 .02649 L
s
.25 Mabswid
0 .02274 m
1 .02274 L
s
gsave
1.025 .02274 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .11717 m
.03006 .11717 L
s
[(-0.0045)] .01131 .11717 1 0 Mshowa
.02381 .2116 m
.03006 .2116 L
s
[(-0.004)] .01131 .2116 1 0 Mshowa
.02381 .30603 m
.03006 .30603 L
s
[(-0.0035)] .01131 .30603 1 0 Mshowa
.02381 .40046 m
.03006 .40046 L
s
[(-0.003)] .01131 .40046 1 0 Mshowa
.02381 .49489 m
.03006 .49489 L
s
[(-0.0025)] .01131 .49489 1 0 Mshowa
.02381 .58932 m
.03006 .58932 L
s
[(-0.002)] .01131 .58932 1 0 Mshowa
.125 Mabswid
.02381 .04163 m
.02756 .04163 L
s
.02381 .06051 m
.02756 .06051 L
s
.02381 .0794 m
.02756 .0794 L
s
.02381 .09828 m
.02756 .09828 L
s
.02381 .13606 m
.02756 .13606 L
s
.02381 .15494 m
.02756 .15494 L
s
.02381 .17383 m
.02756 .17383 L
s
.02381 .19271 m
.02756 .19271 L
s
.02381 .23049 m
.02756 .23049 L
s
.02381 .24937 m
.02756 .24937 L
s
.02381 .26826 m
.02756 .26826 L
s
.02381 .28714 m
.02756 .28714 L
s
.02381 .32492 m
.02756 .32492 L
s
.02381 .3438 m
.02756 .3438 L
s
.02381 .36269 m
.02756 .36269 L
s
.02381 .38157 m
.02756 .38157 L
s
.02381 .41935 m
.02756 .41935 L
s
.02381 .43823 m
.02756 .43823 L
s
.02381 .45712 m
.02756 .45712 L
s
.02381 .476 m
.02756 .476 L
s
.02381 .51378 m
.02756 .51378 L
s
.02381 .53266 m
.02756 .53266 L
s
.02381 .55155 m
.02756 .55155 L
s
.02381 .57043 m
.02756 .57043 L
s
.02381 .00386 m
.02756 .00386 L
s
.02381 .60821 m
.02756 .60821 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -177.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(change) show
105.000 13.000 moveto
(in) show
123.000 13.000 moveto
(angular) show
171.000 13.000 moveto
(momentum) show
225.125 13.000 moveto
(versus) show
267.125 13.000 moveto
(time) show
291.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.04035 .61803 m
.05556 .29717 L
.0873 .26748 L
.11905 .30902 L
.15079 .36754 L
.18254 .3166 L
.21429 .20998 L
.24603 .19089 L
.27778 .27573 L
.30952 .39146 L
.34127 .40656 L
.37302 .29923 L
.40476 .2102 L
.43651 .22381 L
.46825 .25059 L
.5 .20059 L
.53175 .13269 L
.56349 .13039 L
.59524 .15295 L
.62698 .10209 L
.65873 .01472 L
.69048 .04339 L
.72222 .16929 L
.75397 .25549 L
.78571 .21498 L
.81746 .11354 L
.84921 .089 L
.88095 .14909 L
.9127 .18325 L
.94444 .11282 L
.97619 .06697 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Foooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006Oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool05oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`06Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`08_oo
ool4o`000003oa0@4?oooooooooo01oooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1?oo
ool5o`0001;ooooo001Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A00Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oo
oooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B406Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B409?ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00Cooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@04_ooool005_ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go00006Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`00000Iooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000002Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0;ooooo`03
oiRHV?lQ8B7ok^k^01?ooooo001Kooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP0Iooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0000J
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q01Wooooo
00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S809?ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^k^h04_ooool005_o
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Sooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0001[ooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`06Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Goc<c<o`000?l0003o0000olc<c00Tooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool03Oooool00omgMgOoIVIVooooo`0Aooooo`00Foooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool05oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l000006_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
6oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400Toooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@oooo
o`00>?ooool00ol0003oooooooooo`0Pooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@01Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000001[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH01_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000009?ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@400B
ooooo`00>?ooool2o`00027ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`06Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
6Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@6Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Rooooo`03oeEEEOmV
IVKo000002?ooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<01;ooooo
000hooooo`03o`000?oooooooooo0?oooooo;_ooool003Sooooo00?o0000ooooooooool0ooooool^
ooooo`00>?ooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo06cooooo00GoV9RHo`00
0?l0003oA4A4okZj^P04ooooo`00>?ooool00ol0003oooooooooo`2eooooo`;o0000KOooool01Ol@
413o^[Zjonk^k_mgMgOo410@00Cooooo000hooooo`03o`000?oooooooooo0;Cooooo00Co0000oooo
oooooooo0000K?ooool00ol0003oooooooooo`06ooooo`00<Oooooooo`0002Co00002oooool00ol0
003oooooooooo`06ooooo`00>?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`;o00000oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`06ooooo`00>?ooool00ol0003oooooooooo`2cooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0IOooool00ol@413o0000o`000003o`0000Gooooo000hooooo`03o`000?oo
oooooooo0;?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Vooooo`03o`000?oo
oooooooo00Kooooo000hooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Kooooo000hooooo`;o0000/oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo06gooooo000hooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1/ooooo`00>?ooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0K?ooool003Sooooo00?o
0000ooooooooool0/Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06cooooo000h
ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1[
ooooo`00>?ooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0Joooool003Sooooo0_l0002aooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0Joooool003Sooooo00?o0000ooooooooool0/?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool06Oooool003Sooooo00?o0000ooooooooool0/?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool06Ooo
ool003Sooooo00?o0000ooooooooool0[oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool06_ooool003Sooooo00?o0000ooooooooool0[oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool06oooool003So
oooo0_l0002`ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`0Kooooo`00>?ooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Looooo`00>?ooool00ol0003ooooooooo
o`2^ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`0Mooooo`00>?ooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool09oooool2o`00023ooooo00?o0000ooooooooool07Oooool003Sooooo00?o0000oooo
ooooool0[Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ool000007oooool00ol0003oooooooooo`0Nooooo`00>?ooool00ol0003oooooooooo`2]ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool09?ooool01Ol0003ooooooooooooooooo0000
01kooooo00?o0000ooooooooool07_ooool003Sooooo0_l0002^ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool08_ooool2o`0000Cooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Oooooo`00>?ooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool08?ooool000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o000000?o410@ooooooooool00_ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0[?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo023ooooo0005oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`06ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo027ooooo0003o`0000;ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo1Ol00008oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo02;ooooo0005ooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04odA4A?oM
gMgoooooo`0000Sooooo00?oMgMgoc8b<_ooool01?ooool2o`000:[ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Rooooo`001Oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?oM
gMgoEEEEooooool00005ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`2Yooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08oooool000Gooooo00Go410@
oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00Cooooo00?oMgMgolc<c?l000001Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo0:Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Sooooo`00
1Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00oo^k^koA4A4o`000005ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo02Cooooo0005ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ogMgMol0003ooooo00Cooooo
1?l00006ooooo`03o`000?oooooooooo093ooooo2ol0000<ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool09?ooool003Sooooo0_l0002Aooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Gooooo000h
ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool02_ooool2o`0000Oooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Uooooo`00>?ooool00ol0003oooooooooo`2?oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo02Kooooo000hooooo`03o`000?oooooooooo08kooooo00?o0000oooooooo
ool03_ooool2o`0000?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Vooooo`00
>?ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo013ooooo00?o0000ooooool00000
8Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Wooooo`00>?ooool00ol0003oooooooooo`2>ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Wooooo`00>?ooool2
o`0008kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Xooooo`00>?ooool00ol0
003oooooooooo`2=ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:?ooool003So
oooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Wo
oooo000hooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Yooooo`00>?ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0:_ooool003Sooooo0_l0002<ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0:_ooool003Sooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool0000]
ooooo`00>?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo000002gooooo000hooooo`03
o`000?oooooooooo08Wooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0;?ooool003Sooooo00?o0000ooooooooool0
ROooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
COooool003Sooooo00?o0000ooooooooool0??ooool2o`0004_ooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04kooooo000hooooo`;o0000??ooool0
0ol0003oooooo`00001:ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1>ooooo`00>?ooool00ol0003oooooooooo`0iooooo`;o00000oooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`1>ooooo`00>?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0Coooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0fooooo`;o00001_ooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`1?ooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0Coooool000Gooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003oooo
o`Go00001_ooool2o`0003Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Yoooo
o`;o00006?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0D?ooool000gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00CoA4A4omgMgOoooooo0000
1oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
:Oooool01?l0003oooooo`000?l0000Fooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1@ooooo`003Oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo0ol0000Booooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1@ooooo`003Oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41001?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Go
oooo0_l0000@ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`1Aooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00oo^k^koA4A4o`000007
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00Oooooo0_l0000=ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`1Booooo`003Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Doooool003Sooooo0_l0000cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Cooooo000hooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0EOooool003Sooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03_ooool2o`00
00Kooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
05Gooooo000hooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0E_ooool003Sooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool04Oooool01?l0003oooooooooool0001?ooooo`05o`000?oooooooooooooo
ool00000FOooool003Sooooo0_l0000booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000004oooooo00Co0000oooooooo
oooo0000F_ooool003Sooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooo000005_ooooo000hooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool0
F_ooool003Sooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0a?ooool003Sooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0a?ooool0
03Sooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool0a?ooool003Sooooo0_l0000?ooooo`;o00007oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0aOooool003Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooo`00000Oooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`35ooooo`00>?ooool00ol0003ooooooooo
o`0<ooooo`05o`000?ooooooooooooooool000007_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0aOooool003Sooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0<Kooooo000hooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`36ooooo`00>?ooool2o`00
00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`36ooooo`00>?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0aoooool003Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0<Oooooo
0005ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnHV9So410@o`000?lb<S;o
c<c<00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`37ooooo`001Oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00Go410@okZj^_ooooooMgMgoc8b<P07ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
0<Sooooo0003o`0000;ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`38ooooo`001Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00onYZJWo
410@ooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0b?ooool000Gooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o410@
o`000?nj^[X01?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0<Wooooo0005ooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03okZj^_lQ8B7ooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0bOooool000Gooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00Go410@oiRHV?oooooo^[Zjo`000004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo0<Wooooo0005ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT01?ooool4o`0000Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo0<[ooooo000hooooo`;o00001oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo0<[ooooo000hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`3:ooooo`00>?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0b_ooool003Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo0<_ooooo000hooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3;ooooo`00>?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0boooool003Sooooo
0_l00006ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0c?ooool003Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0<cooooo000h
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3<
ooooo`00>?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0cOooool003Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`05
o`000?ooooooooooooooool00000:?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
0<gooooo000hooooo`;o00001_ooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`00
02Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3=ooooo`00>?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooool00000:_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo0<gooooo000hooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0c_ooool003Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0c_ooool003Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0c_ooool003Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0coooool003Sooooo0_l00006ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3?ooooo`00
>?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`3?ooooo`00>?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3?ooooo`003Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Aoooool2o`0000Wooooo00?o0000oooo
ooooool0d?ooool000gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oa0@4?nj
^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04[ooooo
0ol00006ooooo`03o`000?oooooooooo0=3ooooo0005ooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41001oooool00ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003oooooooooo`1=oooo
o`;o00001?ooool00ol0003oooooooooo`3@ooooo`003Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_oo
ool00onYZJWo410@ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Cooo
ool4o`000=?ooooo000=ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000005ooooo`03oa0@4?l0003o^[Zj00Ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo0=7o
oooo000=ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03okZj^_lQ8B7ooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooobOooooo000=ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`05oa0@4?nHV9SooooookZj^_l000001_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo9oooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oolWooooo`00>?ooool2o`0000Gooooo00?o0000ooooooooool0oooooolWooooo`00>?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo9oooool003Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooobOooooo000hooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooolWooooo`00>?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooo9oooool003Sooooo0_l00005ooooo`03o`000?oooooooooo0?oooooo9oooool0
03Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooobOooooo000hooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolWooooo`00>?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?oooooo9oooool003Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooobOooooo000hooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooolWooooo`00>?ooool2o`0000Cooooo00?o0000ooooooooool0oooooolXoooo
o`00>?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo:?ooool003Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooobSooooo000hooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooolXooooo`00>?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0?oooooo:?ooool003Sooooo0_l00004ooooo`03o`000?oooooooooo
0?oooooo:?ooool003Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooobSo
oooo000hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolXooooo`001Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo:?ooool0
00Gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0oooooolXooooo`000ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4004ooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0?oooooo:?ooool000Gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`;o00001?ooool00ol0003oooooooooo`3oooooobSooooo
0005ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000006ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolX
ooooo`001Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooobSooooo
0005ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolX
ooooo`001Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolXooooo`00
>?ooool2o`0000Cooooo00?o0000ooooooooool0oooooolXooooo`00>?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0?oooooo:?ooool003Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3oooooobSooooo000hooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0oooooolYooooo`00>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oo
oooo:Oooool003Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooobWooooo
000hooooo`;o00000oooool00ol0003oooooooooo`3oooooobWooooo000hooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0oooooolYooooo`00>?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0?oooooo:Oooool003Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`3oooooobWooooo000hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
oooooolYooooo`00>?ooool2o`0000?ooooo00?o0000ooooooooool0oooooolYooooo`00>?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo:Oooool003Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3oooooobWooooo000hooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0oooooolYooooo`00>?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0?oooooo:Oooool003Sooooo0_l00003ooooo`03o`000?oooooooooo0?oooooo:Ooo
ool003Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooobWooooo000hoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolYooooo`003Oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1Ol00006ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0oooooolYooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0oooooolYooooo`001Oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
V9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo:Ooo
ool000gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000Gooooo00?oV9RHob4Q8Oo^k^h01_ooool2o`0000;o
oooo00?o0000ooooooooool0oooooolZooooo`003Oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool0
0omgMgOoIVIVooooo`05ooooo`05o`000?ooooooooooooooool00000ooooool/ooooo`003Oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41001oooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool00000ooooool/ooooo`003Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00Go0000ooooooooooooooooo`00003oooooobcooooo000=ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool01Ol0003ooooooooo
oooooooo00000?oooooo;?ooool003Sooooo0_l00002ooooo`03o`000?oooooooooo0?oooooo:_oo
ool003Sooooo00Go0000ooooooooooooooooo`00003oooooobcooooo000hooooo`05o`000?oooooo
ooooooooool00000ooooool/ooooo`00>?ooool01Ol0003ooooooooooooooooo00000?oooooo;?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool005Gooooo00Go8B4Qo`000?l0003oA4A4omgMg@0fooooo`05ob4Q8Ol0003o0000odA4A?oMgMd0
doooool005Sooooo00?oMgMgoc8b<_ooool0>?ooool00omgMgOo<S8booooo`3Booooo`00FOooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo0=7ooooo000eooooo`05ofIVI_l0003o0000
odA4A?o<c<`00_ooool01?l@413o0000o`000?ooool2o`000003oa0@4?ooooooV9RH00;o000000?o
MgMgoa0@4?l000000_ooool01?l@413o0000o`000?ooool2o`000008oa0@4?ooooook^k^oeEEEOl0
003o410@olc<c?l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj2?ooool5o`0000;ooooo
00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`05ooooo`06oiRHV?l0003o0000ogMg
Mol@413o00000_ooool01?l@413o0000o`000?ooool2o`000008oa0@4?ooooook^k^oeEEEOl0003o
410@olc<c?l00003ooooo`07oiRHV?l0003o0000ogMgMol0003o410@ooooo`05o`0000?ooooo00So
V9RHo`000?l0003oMgMgoa0@4?l0003ooooooa0@40Go00001_ooool2o`0000;ooooo00Oo0000oooo
oooooooo0000oa0@4?o^k^koEEEE00;o000000?oEEEEonk^k_ooool00_l00002ooooo`07o`000?oo
ooooooooo`000?l@413ok^k^oeEEE@02o`000005odA4A?nj^[[oooooooooool@41000_l000001?oo
oooo0000o`000?l@4102ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool01_nHV9So0000o`00
0?mgMgOo0000oa0@40;o00000_ooool01Ol0003oooooooooool0003o410@00Kooooo00?o8B4Qoc8b
<_ooool00oooool02?o^k^koEEEEo`000?l0003oA4A4okZj^_oooooo410@1Ol00003ooooo`06oa0@
4?lb<S;o0000o`000?l@413oZJVY0oooool02OnHV9So0000o`000?mgMgOo0000oa0@4?oooooo410@
oc8b<P02o`000003oa0@4?nYZJWooooo00Kooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`Go
000000?oooooo`000?l000000_ooool01ol0003oooooooooool0003o410@onk^k_mEEED00_l00000
0om4A4Co^[Zjooooo`0Fooooo`00=?ooool01_mVIVKoMgMgooooooooooooQhN7oa0@40?ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?o<c<cok^k^ohN7Qol000001?ooool01Ol0003o
oooooooooooooooo000000;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00002ooooo`06oeEEEOmg
MgOoooooonk^k_mgMgOo410@2_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000002?ooool01Ol0003oc<c<onk^k_n7QhOo000000Cooooo00Go0000ooooooooooooooooo`00
0002ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000oooool01Ol0003oZJVYoooooon7QhOo0000
00Cooooo00?o0000ooooooooool00oooool01Ol0003oc<c<onk^k_n7QhOo000000Cooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooEEEEogMgM`;ooooo
00GoMgMgoeEEEOooooooooooo`000002ooooo`0;o`000?ooooooooooo`000?ooooooEEEEogMgMooo
ooook^k^ogMgMol@41000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@okZj^_o^
k^koMgMgoa0@4003ooooo`05o`000?nYZJWoooooohN7Qol000000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00Cooooo00CoV9RHoc8b<_l@413o^[Zj0oooool01_mEEEGoMgMg
ooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool01_l0003oZJVYoooooooooooo
^[Zjo`0000?ooooo00Go0000ojVYZOooooooQhN7o`000002ooooo`06o`000?nYZJWooooooooooonj
^[[o00001oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Gooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`08o`000?ooooooEEEEogMgMoooooook^k^ogMgMol@410Goooo
o`00=?ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000_ooool01Ol@
413oQhN7ooooooo^k^ko000000Cooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?oo
ooooooooooooooo^k^ko00000_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000008ooooo`05oa0@4?n7QhOoooooonk^k_l000001?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00003ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`05oa0@4?n7QhOooooo
onk^k_l000001?ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooool000001?ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oo
oooo00002?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`04ooooo`04oa0@4?nj^[[oV9RHoc8b<P?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`05okZj^_n7QhOoIVIVofIVI_l@41000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4007ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000001cooooo
000dooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000002ooooo`03okZj
^_l@413o000000;o00001?ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooo
ooooooooonk^k_l00002ooooo`Ko00002_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000002?ooool00onj^[[o410@o`000002o`0000Cooooo00Go0000oooooooooooooooo
o`000002ooooo`06o`000?ooooooooooooooooo^k^ko00000oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool00oooool00onj^[[o410@o`000002o`0000Cooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000Cooooo00Co
0000oooooooooooo00000_ooool01Ol0003oooooooooool0003ooooo00Ko00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`06oiRHV?lb
<S;oooooooooool@413o^[Zj0_ooool6o`0000?ooooo00?o0000ooooooooool01?ooool01_lb<S;o
8B4QogMgMomgMgOoQhN7onk^kP?ooooo00Go0000ooooooooooooooooo`000002ooooo`06oc8b<_lQ
8B7oMgMgogMgMon7QhOok^k^1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000005o`0001Oooooo000dooooo`06
ofIVI_mgMgOooooooooooon7QhOo00000oooool01Ol0003oMgMgoooooonYZJWo000000Gooooo00?o
c<c<o`000?ooool00oooool01Ol0003oQhN7oooooonYZJWo000000;ooooo00KoEEEEogMgMooooooo
k^k^oeEEEOl00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b2_ooool00ol0003ooooooooo
o`03ooooo`05o`000?n7QhOoooooojVYZOl000002oooool00oo<c<co0000ooooo`03ooooo`05o`00
0?n7QhOoooooojVYZOl000000_ooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000?ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Kooooo00?oc<c<o`000?ooool00ooo
ool00ol0003o<S8bomgMg@08ooooo`0:o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8OooooooEEEE
ogMgM`;ooooo00GoMgMgoeEEEOooooooooooo`000002olc<c00;o`000?nYZJWogMgMob4Q8Ooooooo
EEEEohN7Qoo^k^koooooohN7Qolb<S800oooool01Ol0003oQhN7oooooonYZJWo000000?ooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000;ooooo00Oo0000olc<c?o<c<co
0000ojVYZOoMgMgo8B4Q00Cooooo00?ok^k^o`000?oMgMd00_ooool02_nHV9So<S8boooooooooooo
EEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Cooooo00Ko0000okZj^_oo
ooook^k^ogMgMol00003ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003o^[Zjoooo
ooo^k^koMgMgo`0000Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`0>
o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^k^koooooohN7Qolb<S8Goooo
o`00=?ooool01_o^k^koIVIVo`000?l0003oA4A4o`0000?ooooo00Go0000ogMgMol0003o0000oiRH
V003ooooo`04oc8b<_l0003o0000oiRHV0?ooooo00?o410@o`000?mgMgL00_l000003OnHV9Sooooo
ooooooo^k^koEEEEo`000?lQ8B7oZJVYo`000?l@413oooooonk^k_mEEED00_l000000om4A4Cok^k^
ooooo`07ooooo`03oa0@4?l0003o000000Cooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooo
ooooo`07ooooo`04oc8b<_l0003o0000oiRHV0?ooooo00?o410@o`000?mgMgL00_l000003OnHV9So
ooooooooooo^k^koEEEEo`000?lQ8B7oZJVYo`000?l@413ooooooa0@4?l000000_ooool2o`0000Co
oooo00?o0000ooooooooool01?ooool01?lb<S;o0000o`000?nHV9P3ooooo`;o000000CoZJVYob4Q
8Ol0003o8B4Q1Oooool02ol@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE
00;o000000koEEEEonk^k_oooooo410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZOooooook^k^
oeEEE@;o000000OoA4A4onk^k_oooooooooooa0@4?l0003oMgMg00;o000000?oV9RHooooool@4100
1Ol00003ooooo`04oa0@4?l0003oooooooooo`;o000000Wooooooa0@4?l0003o8B4Qo`000?mgMgOo
410@o`000?nYZJT01?ooool00ol@413o0000o`000002ooooo`?o000000?oooooonk^k_mEEED00_l0
00001?m4A4Cok^k^ooooooooool2o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo00KoZJVYob4Q8Ol0
003o0000oc8b<_l00002ooooo`04oa0@4?l0003oooooooooo`;o00000_ooool01_nYZJWo8B4Qo`00
0?l0003o<S8bo`0000Gooooo00?o410@o`000?l000000ol00004ooooo`03oa0@4?l0003o000000?o
oooo00_o410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZOooooook^k^oeEEE@02o`000003odA4
A?o^k^kooooo01Kooooo000mooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo037ooooo000mooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Wooooo`00??ooool00ol@
413o0000ooooo`0]ooooo`03oa0@4?oooooooooo033ooooo00?o410@o`000?l00000W?ooool00ol@
413oooooooooo`0Wooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.243838, -0.00541057, \
0.00543053, 2.2821*^-5}}]
}, Open  ]],

Cell["\<\
It is not well conserved, because the periodic boundary conditions \
break the cylindrical symmetry required for angular momentum conservation.  \
Thus, tracking angular momentum is not particularly useful unless the \
boundaries are far from the region of interest.\
\>", "Text"],

Cell["\<\
\tA third conserved quantity is the total energy of the system, \
\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`E\_total\  = \[Sum]\+i\ p\_i\%2\/\(2  m\) + 
          1\/2\ \(\[Integral]\[Rho]\ \[Phi]\ \(\(\[DifferentialD]\^2 
                  r\)\(\ \)\)\)\)]],
  ". "
}], "NE3",
  CellTags->"(7.3.9)"],

Cell[TextData[{
  "The second term is the total gravitational potential energy ",
  Cell[BoxData[
      \(TraditionalForm\`U\)]],
  ". In order to evaluate this quantity  we write the integral as a sum over \
the grid:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"U", " ", "=", " ", 
            
            RowBox[{\(\[Integral]\[Rho]\ \[Phi]\ \[DifferentialD]\^2 r\), 
              "\[TildeEqual]", 
              RowBox[{
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]], " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]], 
                " ", \(\[Sum]\+\(i, j = 0\)\%\(M - 1\)\(\[Rho]\_\(i\ j\)\) \
\[Phi]\_\(\(\ \)\(i\ j\)\)\)}]}]}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(7.3.10)"],

Cell[TextData[{
  "Since the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " and the density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " are not saved from step to step, one can either reevaluate them, or  \
modify the previous code to evaluate and store the energy as the positions \
and momenta are updated. We proceed with the former approach below."
}], "Text"],

Cell[TextData[{
  "\tTo evaluate the kinetic energy, we require the momenta at the same time \
step as the positions. We could employ the averaging method that we used to \
determine the angular momentum. However, it is just as accurate, and somewhat \
faster, to write the kinetic energy at ",
  "time step",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(K(t\_n)\), "=", 
          RowBox[{\(\[Sum]\+i\), " ", 
            FractionBox[
              
              RowBox[{\(\(p\_i\)(t\_\(n - 1/2\))\), 
                " ", \(\(p\_i\)(t\_\(n + 1/2\))\), Cell[""]}], \(2  m\)]}]}], 
        TraditionalForm]]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["7.82",
    ButtonData:>"Cell 7.82",
    ButtonStyle->"Hyperlink"],
  ", we evaluate the energy."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(kineticenergy[n_]\  := \ 
        Sum[\(p[n - 1/2]\)[\([i]\)] . \(p[n + 1/2]\)[\([i]\)], {i, 1, 
                Length[p[n + 1/2]]}]/\((2\ m)\) /; 
          n > 0\  && \ n \[Element] Integers;\)\), "\n", 
    \(\(kineticenergy[n_]\  := \ 
        Sum[\(p[n]\)[\([i]\)] . \(p[n]\)[\([i]\)], {i, 1, 
                Length[p[n]]}]/\((2\ m)\) /; 
          n > 0\  && \ n + 1/2 \[Element] Integers;\)\), "\n", 
    \(\(\(kineticenergy[0]\  := \ 
        Sum[\(p[0]\)[\([i]\)] . \(p[0]\)[\([i]\)], {i, 1, 
              Length[p[0]]}]/\((2\ m)\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(energy[n_]\  := \(energy[n]\  = 
          Module[{}, \[IndentingNewLine]Npart\  = \ 
              Length[r[n]]; \[IndentingNewLine]density[
              r[n]]; \[IndentingNewLine]fft\[Phi][\[Rho]]; \
\[IndentingNewLine]potentialenergy[n] = 
              1/2\ \[CapitalDelta]x\ \[CapitalDelta]y\ Sum[\[Rho][\([i, 
                        j]\)]\ \[Phi][\([i, j]\)], {i, 1, M}, {j, 1, 
                    M}]; \[IndentingNewLine]kineticenergy[n] + 
              potentialenergy[n]]\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Table[{n\ \[CapitalDelta]t, energy[n]}, {n, 0, 30}], 
        PlotJoined \[Rule] True, PlotLabel -> "\<total energy\>", 
        AxesLabel \[Rule] {"\<t\>", "\<\>"}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.82"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.793651 1.85213 0.238045 [
[.18254 .17332 -9 -9 ]
[.18254 .17332 9 0 ]
[.34127 .17332 -9 -9 ]
[.34127 .17332 9 0 ]
[.5 .17332 -9 -9 ]
[.5 .17332 9 0 ]
[.65873 .17332 -9 -9 ]
[.65873 .17332 9 0 ]
[.81746 .17332 -3 -9 ]
[.81746 .17332 3 0 ]
[.97619 .17332 -9 -9 ]
[.97619 .17332 9 0 ]
[1.025 .18582 0 -6 ]
[1.025 .18582 10 6 ]
[.01131 .06679 -24 -4.5 ]
[.01131 .06679 0 4.5 ]
[.01131 .30484 -24 -4.5 ]
[.01131 .30484 0 4.5 ]
[.01131 .42386 -12 -4.5 ]
[.01131 .42386 0 4.5 ]
[.01131 .54288 -24 -4.5 ]
[.01131 .54288 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .18582 m
.18254 .19207 L
s
[(0.2)] .18254 .17332 0 1 Mshowa
.34127 .18582 m
.34127 .19207 L
s
[(0.4)] .34127 .17332 0 1 Mshowa
.5 .18582 m
.5 .19207 L
s
[(0.6)] .5 .17332 0 1 Mshowa
.65873 .18582 m
.65873 .19207 L
s
[(0.8)] .65873 .17332 0 1 Mshowa
.81746 .18582 m
.81746 .19207 L
s
[(1)] .81746 .17332 0 1 Mshowa
.97619 .18582 m
.97619 .19207 L
s
[(1.2)] .97619 .17332 0 1 Mshowa
.125 Mabswid
.06349 .18582 m
.06349 .18957 L
s
.10317 .18582 m
.10317 .18957 L
s
.14286 .18582 m
.14286 .18957 L
s
.22222 .18582 m
.22222 .18957 L
s
.2619 .18582 m
.2619 .18957 L
s
.30159 .18582 m
.30159 .18957 L
s
.38095 .18582 m
.38095 .18957 L
s
.42063 .18582 m
.42063 .18957 L
s
.46032 .18582 m
.46032 .18957 L
s
.53968 .18582 m
.53968 .18957 L
s
.57937 .18582 m
.57937 .18957 L
s
.61905 .18582 m
.61905 .18957 L
s
.69841 .18582 m
.69841 .18957 L
s
.7381 .18582 m
.7381 .18957 L
s
.77778 .18582 m
.77778 .18957 L
s
.85714 .18582 m
.85714 .18957 L
s
.89683 .18582 m
.89683 .18957 L
s
.93651 .18582 m
.93651 .18957 L
s
.25 Mabswid
0 .18582 m
1 .18582 L
s
gsave
1.025 .18582 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .06679 m
.03006 .06679 L
s
[(-7.5)] .01131 .06679 1 0 Mshowa
.02381 .30484 m
.03006 .30484 L
s
[(-6.5)] .01131 .30484 1 0 Mshowa
.02381 .42386 m
.03006 .42386 L
s
[(-6)] .01131 .42386 1 0 Mshowa
.02381 .54288 m
.03006 .54288 L
s
[(-5.5)] .01131 .54288 1 0 Mshowa
.125 Mabswid
.02381 .0906 m
.02756 .0906 L
s
.02381 .1144 m
.02756 .1144 L
s
.02381 .13821 m
.02756 .13821 L
s
.02381 .16201 m
.02756 .16201 L
s
.02381 .20962 m
.02756 .20962 L
s
.02381 .23343 m
.02756 .23343 L
s
.02381 .25723 m
.02756 .25723 L
s
.02381 .28103 m
.02756 .28103 L
s
.02381 .32864 m
.02756 .32864 L
s
.02381 .35245 m
.02756 .35245 L
s
.02381 .37625 m
.02756 .37625 L
s
.02381 .40006 m
.02756 .40006 L
s
.02381 .44767 m
.02756 .44767 L
s
.02381 .47147 m
.02756 .47147 L
s
.02381 .49527 m
.02756 .49527 L
s
.02381 .51908 m
.02756 .51908 L
s
.02381 .04299 m
.02756 .04299 L
s
.02381 .01918 m
.02756 .01918 L
s
.02381 .56669 m
.02756 .56669 L
s
.02381 .59049 m
.02756 .59049 L
s
.02381 .6143 m
.02756 .6143 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(total) show
99.000 13.000 moveto
(energy) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.05556 .55768 L
.0873 .16915 L
.11905 .34379 L
.15079 .60332 L
.18254 .37449 L
.21429 .37715 L
.24603 .54093 L
.27778 .32113 L
.30952 .54039 L
.34127 .58424 L
.37302 .25141 L
.40476 .3665 L
.43651 .50444 L
.46825 .26156 L
.5 .52564 L
.53175 .35049 L
.56349 .39046 L
.59524 .47097 L
.62698 .54707 L
.65873 .50027 L
.69048 .4178 L
.72222 .4968 L
.75397 .59849 L
.78571 .33887 L
.81746 .5763 L
.84921 .58131 L
.88095 .1323 L
.9127 .40403 L
.94444 .46076 L
.97619 .5797 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool3o`000?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0ol0003oooooodGooooo
000Qooooo`;o0000oooooom6ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo0_l0003ooooo
odKooooo000Qooooo`;o0000oooooom6ooooo`002Oooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo0_l0003oooooodKooooo0009ooooo`03oeEE
EOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0003oooooodKooooo
0005o`0000Cooooo00?oZJVYoeEEEOooool04?ooool00ol0003oooooooooo`02ooooo`;o0000oooo
oom6ooooo`002_ooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo00?ooooo0ol0003o
ooooodGooooo000:ooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004
ooooo`;o0000oooooom6ooooo`002_ooool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo
00Kooooo0_l0003oooooodKooooo0007ooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0
003oooooooooo`06ooooo`;o0000oooooom6ooooo`001oooool5o`0000cooooo1?l00005ooooo`;o
0000oooooom6ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo0_l0003oooooodKooooo000Q
ooooo`?o0000oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooool0
0000oooooom5ooooo`008Oooool00ol0003oooooo`00003oooooodGooooo000Qooooo`03o`000?oo
oooo00000?ooooooAOooool0027ooooo00?o0000ooooool00000oooooom5ooooo`008Oooool00ol0
003oooooo`00003oooooodGooooo000Qooooo`03o`000?oooooo00000?ooooooAOooool0027ooooo
0ol0003oooooodGooooo000Qooooo`03o`000?oooooo00000?ooooooAOooool0027ooooo00?o0000
ooooool00000oooooom5ooooo`008Oooool00ol0003oooooo`00003oooooodGooooo000Qooooo`03
o`000?oooooo00000?ooooooAOooool0027ooooo00?o0000ooooool00000ooooool:ooooo`03o`00
0?oooooooooo03Sooooo000Qooooo`03o`000?oooooo00000?oooooo2_ooool00ol0003ooooooooo
o`0hooooo`008Oooool3o`000?oooooo2_ooool00ol0003oooooooooo`0hooooo`008Oooool00ol0
003oooooo`00003oooooo`[ooooo00?o0000ooooooooool0>?ooool0027ooooo00?o0000ooooool0
00009?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00007Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool06_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
7Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`09Oooool4o`000003oa0@4?oooooooooo00oooooo00?o0000ooooooooool04Oooool4o`00
0003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go00004oooool0027ooooo00?o0000ooooool0
00009?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@07Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo01_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMg
oooooonHV9So8B4Q01gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q02Oooooo00?o0000ooooooooool04Oooool2o`0001Cooooo00?o0000
ooooooooool01?ooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Cooooo`008Oooool0
1?l0003oooooooooool0000Sooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Q
onk^kP0Nooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0001cooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000007Oooool01Ol@413ooooooooooooo
oooo410@00_ooooo00Go0000ooooooooooooooooo`00000Wooooo`03o`000?oooooooooo017ooooo
0_l0000Dooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h05?ooool0027ooooo00Co
0000oooooooooooo00008oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h07Oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00007Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Mooooo`05o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b02Oooooo00?o0000oooo
ooooool04Oooool2o`0001Cooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP0Coooo
o`008Oooool01?l0003oooooooooool0000Sooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`0Looooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEoooo
ool0000Mooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<
01gooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`09ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000001Cooooo00?o0000ooooooooool03Ooo
ool00omgMgOoIVIVooooo`0Booooo`008Oooool4o`0002?ooooo00Go410@oooooooooooooooooa0@
400?ooooo`03o`000?oooooooooo01_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMg
Moo<c<co000001gooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo01oo
oooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41009oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooo000001Cooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Aooooo`008Oooool01?l0003oooooooooool0000Sooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@01gooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0<ooooo`03onk^k_m4A4Co000001gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`03omgMgOl@413oV9RH01oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooookZj^_l000009oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000001Cooooo00?o
0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@01?ooooo000Qooooo`04o`000?oo
ooooooooo`0002?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`07Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool07?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@7Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Uooooo`03oeEEEOmVIVKo0000
01;ooooo00?o0000ooooool000004_ooool00omEEEGoIVIVo`00000<ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`04oooool0027ooooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`3d
ooooo`03o`000?oooooo000003Wooooo000Qooooo`04o`000?ooooooooooo`00013ooooo00?o0000
ooooooooool0m?ooool00ol0003oooooo`00000iooooo`008Oooool01?l0003oooooooooool0000@
ooooo`03o`000?oooooooooo0?Cooooo00Co0000oooooooooooo0000;oooool01OnHV9So0000o`00
0?m4A4Co^[Zj00Cooooo000Qooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooooooool0
m?ooool01?l0003oooooooooool0000_ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool0027o
oooo00Co0000oooooooooooo00004?ooool2o`000?Gooooo00Co0000oooooooooooo0000;oooool0
0ol0003oooooooooo`06ooooo`006_ooooooo`0003[o00003?ooool00ol0003oooooooooo`06oooo
o`008Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo0_l00003oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Kooooo000Qooooo`04o`000?ooooooooooo`0000oooooo00?o0000
ooooool000007?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo013ooooo00Co0000
oooooooooooo00006oooool00ol0003oooooooooo`0?ooooo`03oa0@4?l0003o000000?o00001Ooo
ool0027ooooo00Co0000oooooooooooo00003oooool00ol0003oooooo`00003eooooo`04o`000?oo
ooooooooo`0002oooooo00?o0000ooooooooool01_ooool0027ooooo00Co0000oooooooooooo0000
3oooool01?l0003oooooooooool0003dooooo`04o`000?ooooooooooo`0002oooooo00?o0000oooo
ooooool01_ooool0027ooooo00Co0000oooooooooooo00003oooool01?l0003oooooooooool0003c
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=Oooool0027ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`04o`000?ooooooooooo`000??ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0eooooo`008Oooool3o`000003ooooool0003ooooo00gooooo00Co0000
oooooooooooo0000loooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03Gooooo000Q
ooooo`05o`000?ooooooooooooooool000003_ooool01?l0003oooooooooool0003cooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0=Oooool0027ooooo00Go0000oooooooooooooooo
o`00000>ooooo`05o`000?ooooooooooooooool00000l_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo03Gooooo000Qooooo`05o`000?ooooooooooooooool000003_ooool01Ol0003o
oooooooooooooooo00000?;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0eoooo
o`008Oooool01Ol0003ooooooooooooooooo000000kooooo00Go0000ooooooooooooooooo`00003b
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=Oooool0027ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`05o`000?ooooooooooooooool00000l_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo03Gooooo000Qooooo`05o`000?ooooooooooooooool000003_oo
ool01Ol0003ooooooooooooooooo00000?;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0eooooo`008Oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3`ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
=?ooool0027ooooo0ol000000ooooooo0000ooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0koooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Cooooo000Q
ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0>oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0dooooo`008Oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`3_ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool0027ooooo00Go0000
ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0kooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Cooooo000Qooooo`05o`000?oooooo
ooooooooool000003Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0dooooo`008Oooool01Ol0003ooooooooooooo
oooo000000gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo09Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0dooooo`008Oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`1Aooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0dooooo`008Oooool3o`000003ooooool0003ooooo00cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0cooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Aooooo`;o0000V_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo03?ooooo000Qooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo057o
oooo0_l0000Looooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0cooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Aooooo`;o00007?ooool00ol0003ooooo
ooooo`1kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<oooool0027ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0D?ooool00ol0003oooooo`00000Kooooo`03o`000?oooooooooo07_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`008Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1?
ooooo`04o`000?ooooooooooo`0001_ooooo00?o0000ooooooooool0Noooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03?ooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04oooooo00Co0000
oooooooooooo00006oooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0<oooool0027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Coooool01?l0003oooooooooool0
000Jooooo`03o`000?oooooo000007cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0cooooo`008Oooool3o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo04oooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oo
oooo000007cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0cooooo`008Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1>ooooo`05o`000?ooooooooooooooool000006Oooool00ol0003oooooo`00
001looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<_ooool0027ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0C_ooool01Ol0003ooooooooooooooooo000001Wooooo00?o0000ooooool00000O?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03;ooooo000Qooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo04kooooo00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oooooo000007_ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0booooo`008Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool00ol0003oooooo`00001k
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<_ooool000Oooooo00Gok^k^oc8b
<_l0003o410@olc<c005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0C_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooool00000Noooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03;ooooo0007
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Ooo
ool01?l0003oooooooooool0001kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
<_ooool000Go00000_ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooooooool0
0_ooool3o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`05o`00
0?ooooooooooooooool00000N_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03;o
oooo0007ooooo`05o`000?nHV9SooooooiRHV?lQ8B403oooool00omgMgOo<S8booooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo04cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`05
o`000?ooooooooooooooool00000N_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03;ooooo0007ooooo`05o`000?mEEEGo0000oa0@4?o<c<`03?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Cooooo00Go0000ooooooooooooooooo`00001jooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0<Oooool000Oooooo00?oEEEEohN7Qoooool03_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0D
ooooo`05o`000?ooooooooooooooool00000N_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo037ooooo0007ooooo`03omgMgOl@413oV9RH00kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool0
1Ol0003ooooooooooooooooo000007[ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0aooooo`002?ooool01?o<c<coA4A4o`000?l@410<ooooo`Co00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Cooooo`05o`000?ooooooooooooooool00000N_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo037ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooooooooooo
o`00001jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<Oooool0027ooooo0ol0
0003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo037ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0<Oooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;oooool00ol0003oooooo`00000Ioooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo07Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0aoooo
o`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo000001Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0M_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo037ooooo000Qooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooool000006Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Mooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0`ooooo`008Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooo000001Wooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0GOoo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?oo
ool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0;_ooool00ol0003oooooo`00000Hooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo05gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo033ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02kooooo00?o0000ooooool000006?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo033ooooo000Qooooo`?o00000oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooo`00000Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?ooool0027ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0;Oooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool03_ooool2o`0004cooooo00?o0000ooooool000005oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02cooooo00Go0000oooooooooooo
ooooo`00000Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool00000Boooool00ol0003o
ooooo`00000Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<?ooool0027ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0;?ooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03?ooool01Ol0003ooooooooooooooooo000004[ooooo00?o0000ooooool000005oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02co
oooo00Go0000ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00Go0000oooo
ooooooooooooo`00001:ooooo`03o`000?oooooo000001Oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0_ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/ooooo`05o`000?oooooooooo
ooooool000005oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Aoooool00ol0003oooooo`00000Gooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0;oooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;?ooool01Ol0003ooooooooooooooooo
000001Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooool000005oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo02oooooo000Qooooo`?o00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool04?ooool6o`0001Kooooo00Go0000ooooooooooooooooo`00000G
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`15
ooooo`03o`000?oooooo000001Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0_
ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo1Ol0000@oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0A?ooool01?l0003oooooooooool0000F
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`13ooooo`05o`000?ooooooooooooooool000005Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02oooooo000Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0@_ooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0_ooooo`008Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo047ooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`10ooooo`05o`000?ooooooooooooooool000005Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo02oooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0@?ooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
03oooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0;_ooool0027ooooo0ol00004ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0;_ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02kooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0;Oooool0027ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02gooooo000Gooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0/ooooo`005oooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0:oooool000oooooo1_l00002ooooo`05o`000?oooooooooo
ooooool000001Oooool3o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08?ooool00ol0003oooooo`00000H
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo02_ooooo000Gooooo`05o`000?nHV9SooooooiRHV?lQ8B401Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo023ooooo00?o0000ooooool000006?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Zooooo`005oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo000001Sooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0:_ooool001Oooooo00?oEEEEohN7Qoooool01oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo02Wooooo000Gooooo`03omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Nooooo`05o`000?ooooooooooooooool000005_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Y
ooooo`006?ooool01?o<c<coA4A4o`000?l@4105ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0:?ooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Xoooo
o`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Oooooo000Qooooo`?o0000
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo02Kooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09Oooool0
027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Uooooo`008Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool09?ooool0027ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000001Ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Tooooo`008Oooool3o`0000Gooooo
00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`00013ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02?ooooo000Qooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`04o`000?oooooooooo
o`00013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo02?ooooo000Qooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00005_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05Oooool0
1?l0003oooooooooool0000@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`06ooooo`04o`000?oooooo
ooooo`0001Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01Gooooo00Co0000oooooooooooo00004?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool08oooool0027ooooo00?o0000ooooooooool01_oo
ool01?l0003oooooooooool0000Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`00013ooooo00Go0000oooooooo
ooooooooo`00000Looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo00Ko
oooo00Co0000oooooooooooo00005_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool05_ooool00ol0003oooooo`00000@ooooo`05o`000?oooooooooo
ooooool000007Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`06oooo
o`04o`000?ooooooooooo`0001Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooool000004Oooool01?l0003oooooooooool0
000Mooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo00Kooooo00Co0000
oooooooooooo00005oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05oooool2o`0001;ooooo00Co0000oooooooooooo00007_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Qooooo`008Oooool3o`0000Kooooo00Co0000oooooooooooo00005oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool2o`0001;ooooo
00Co0000oooooooooooo00007_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Qooooo`008Oooool00ol0003ooooo
ooooo`06ooooo`04o`000?ooooooooooo`0001Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04?ooool01?l0003o
ooooooooool0000Oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo027ooooo000Qooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooool000006?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Go
oooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo0000023ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool08Oooool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00000Hooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool01Ol0003ooooooooooooooooo0000
00oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo0000
023ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooo`00000Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool01Ol0003o
oooooooooooooooo000000oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooo0000027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooo`00000Hooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05Oooool01?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooo`00000Qooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo023ooooo000Qooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooool000006Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01Gooooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02cooooo0_l0000Rooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo023ooooo000Qooooo`?o
00001_ooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool05_ooool00ol0003oooooo`00000Aooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01oooooo000Qooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooool000006Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooool000004Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Oooooo`008Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooo000001Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07ooo
ool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00000Iooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool05oooool00ol0003oooooo`00000Aooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Nooooo`008Oooool00ol0
003oooooooooo`07ooooo`;o00006Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooool000004Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool07_ooool000Sooooo00GoA4A4o`000?l0003o<S8bomgMg@04oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool01oooool2
o`0001Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo01kooooo000;ooooo`03ogMgMolb<S;ooooo00?ooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00?ooooo00?o0000ooooooooool01oooool2o`0001Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1Dooooo`04o`000?ooooooooooo`0001kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Nooooo`001Ol00007ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool00_ooool3o`0000Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo05Cooooo00Co0000oooooooooooo00007_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo01gooooo000;ooooo`03ogMgMolb<S;ooooo00gooooo00?oMgMgoc8b
<_ooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooo`00000Pooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool07Oooool000Sooooo00Go0000ob4Q8Ol0003o<S8bolc<c00;ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00Go0000
ooooooooooooooooo`00000`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0EOoo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07Ooo
ool000Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo0000037ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool07Oooool000Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooooooo
oooo000003;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1gooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool07?ooool000Sooooo1?l0000<ooooo`Co00001Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00
000booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo01cooooo000Qooooo`03o`000?oooooooooo02?ooooo00Go0000
ooooooooooooooooo`00000cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0N?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01cooooo000Qooooo`03o`000?oooooo
oooo02?ooooo00Go0000ooooooooooooooooo`00000dooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0N?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01_ooooo000Q
ooooo`?o00009?ooool01?l0003oooooooooool0000eooooo`05o`000?ooooooooooooooool00000
O?ooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo01_ooooo000Qooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooool00000=oooool01?l0003oooooooooool0001looooo`05o`000?oooooooooooooo
ool000004_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool06oooool0027ooooo00?o0000ooooooooool09?ooool00ol0003oooooo`00000gooooo`04
o`000?ooooooooooo`0007cooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Kooooo`008Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooo000003Sooooo00?o0000ooooool00000OOooool01?l0
003oooooooooool0000Booooo`Ko00001?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo01[ooooo000Qooooo`03o`000?oooooooooo02Cooooo00?o0000ooooool00000>Oooool2o`00
07gooooo00Co0000oooooooooooo00006?ooool5o`0002Oooooo00?o0000ooooooooool06_ooool0
027ooooo00?o0000ooooooooool09?ooool00ol0003oooooo`00000jooooo`03o`000?oooooooooo
07_ooooo00Co0000oooooooooooo0000HOooool0027ooooo00?o0000ooooooooool09?ooool00ol0
003oooooo`00002iooooo`03o`000?oooooo0000067ooooo000Qooooo`?o00009?ooool00ol0003o
ooooo`00002iooooo`;o0000H_ooool0027ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`2hooooo`;o0000H_ooool0027ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`2iooooo`03o`000?oooooooooo063ooooo000Qooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0^Oooool00ol0003oooooooooo`1Pooooo`008Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo0?oooooo7Oooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0ol0003oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00=Sooooo00Ko8B4Qo`00
0?l0003oA4A4omgMgOooool3o`000003oa0@4?oooooooooo08Cooooo003Kooooo`03ogMgMolb<S;o
oooo00;ooooo00?o410@okZj^_ooool0QOooool00=cooooo00Ko0000oooooooooooooooooiRHV?lb
<S:6ooooo`00Roooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Kok^k^oeEEEOl0003o0000
oeEEEOo^k^h3ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool01_nHV9So0000o`000?mgMgOo
410@o`0000;ooooo1Ol00008ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool01?l@413o
0000o`000?ooool2o`000004oa0@4?ooooook^k^oeEEE@;o000000CoA4A4okZj^_oooooo410@1Ol0
0003ooooo`06onk^k_mEEEGo0000oa0@4?o<c<co00000oooool00ooMgMgo0000okZj^P25ooooo`00
Roooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo00KoEEEEogMgMoooooooooooogMgMomEEED3
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01Ol0003oc<c<onk^k_n7QhOo000000Gooooo
00?o0000ooooooooool02?ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool00ol0003ooooo
ooooo`04ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000oooool00omEEEGoMgMgodA4A025oooo
o`00Roooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000006ooooo`05oa0@4?n7QhOoooooonk^k_l000001Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01?ooool01_l0003oooooooooooooooook^k^o`0000;o
oooo00GogMgMoa0@4?oooooo8B4QomgMg@24ooooo`00Roooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03okZj^_l@413o0000
00;o00001Oooool00ol0003oooooooooo`08ooooo`Ko00000oooool01Ol0003ooooooooooooooooo
000000;ooooo1_l00003ooooo`03o`000?oooooooooo00Cooooo00Ko0000ooooooooooooooooonk^
k_l00002ooooo`05ofIVI_n7QhOooooooiRHV?mEEED0Q?ooool008_ooooo00?o0000ooooooooool0
1?ooool01_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00?o0000ooooooooool01oooool00oo<
c<co0000ooooo`04ooooo`03o`000?oooooooooo00Sooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb
<S83ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b
<P?ooooo00?o0000oc8b<_oMgMd01?ooool02_mEEEGoMgMgooooooo^k^koEEEEo`000?ooooook^k^
o`000?o^k^h2ooooo`03o`000?oMgMgooooo08;ooooo0029ooooo`03oa0@4?l0003o000000?o0000
0oooool02?o^k^koEEEEo`000?l0003oEEEEonk^k_oooooo410@1Ol00004ooooo`04oc8b<_l0003o
0000oiRHV0Gooooo00?o0000ooooooooool02?ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;o
oooo00?o410@o`000?mgMgL00_l000001OnHV9Soooooooooooo^k^koEEEE00;o000000CoA4A4onk^
k_oooooooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`06onk^k_mEEEGo0000ob4Q8OnYZJWo
00000_l@4102o`000004ooooool0003o0000oa0@48?ooooo002;ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2iooooo`00Roooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0^Oooool00:[ooooo00?o
410@o`000?l00000^oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.136823, -7.84456, \
0.00504448, 0.0168185}}]
}, Open  ]],

Cell["\<\
Surprisingly, the energy is not well conserved, although the \
particle dynamics is apparently correct.\
\>", "Text"],

Cell[TextData[{
  "\tAs a further check, the kinetic and potential energies are shown in Cell \
",
  ButtonBox["7.83",
    ButtonData:>"Cell 7.83",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p1 = \ 
        ListPlot[
          Table[{n\ \[CapitalDelta]t, potentialenergy[n]}, {n, 0, 30}], 
          PlotJoined \[Rule] True, PlotStyle \[Rule] RGBColor[0, 0, 1], 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(p2 = \ 
        ListPlot[Table[{n\ \[CapitalDelta]t, kineticenergy[n]}, {n, 0, 30}], 
          PlotJoined \[Rule] True, PlotStyle \[Rule] RGBColor[1, 0, 0], 
          DisplayFunction \[Rule] Identity];\)\), "\n", 
    \(\(Show[p1, p2, DisplayFunction \[Rule] $DisplayFunction, 
        AxesLabel \[Rule] {"\<t\>", "\<\>"}, 
        PlotLabel \[Rule] \ 
          TableForm[{{StyleForm["\<kinetic\>", 
                  FontColor \[Rule] RGBColor[1, 0, 0]], "\< and \>", 
                StyleForm["\<potential\>", 
                  FontColor \[Rule] RGBColor[0, 0, 1]], "\< energy\>"}}, 
            TableSpacing \[Rule] 0]];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.83"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.793651 0.542755 0.0605636 [
[.18254 .53026 -9 -9 ]
[.18254 .53026 9 0 ]
[.34127 .53026 -9 -9 ]
[.34127 .53026 9 0 ]
[.5 .53026 -9 -9 ]
[.5 .53026 9 0 ]
[.65873 .53026 -9 -9 ]
[.65873 .53026 9 0 ]
[.81746 .53026 -3 -9 ]
[.81746 .53026 3 0 ]
[.97619 .53026 -9 -9 ]
[.97619 .53026 9 0 ]
[1.025 .54276 0 -6 ]
[1.025 .54276 10 6 ]
[.01131 .05825 -12 -4.5 ]
[.01131 .05825 0 4.5 ]
[.01131 .17937 -12 -4.5 ]
[.01131 .17937 0 4.5 ]
[.01131 .3005 -12 -4.5 ]
[.01131 .3005 0 4.5 ]
[.01131 .42163 -12 -4.5 ]
[.01131 .42163 0 4.5 ]
[.5 .63053 -86 0 ]
[.5 .63053 86 12.3125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .54276 m
.18254 .54901 L
s
[(0.2)] .18254 .53026 0 1 Mshowa
.34127 .54276 m
.34127 .54901 L
s
[(0.4)] .34127 .53026 0 1 Mshowa
.5 .54276 m
.5 .54901 L
s
[(0.6)] .5 .53026 0 1 Mshowa
.65873 .54276 m
.65873 .54901 L
s
[(0.8)] .65873 .53026 0 1 Mshowa
.81746 .54276 m
.81746 .54901 L
s
[(1)] .81746 .53026 0 1 Mshowa
.97619 .54276 m
.97619 .54901 L
s
[(1.2)] .97619 .53026 0 1 Mshowa
.125 Mabswid
.06349 .54276 m
.06349 .54651 L
s
.10317 .54276 m
.10317 .54651 L
s
.14286 .54276 m
.14286 .54651 L
s
.22222 .54276 m
.22222 .54651 L
s
.2619 .54276 m
.2619 .54651 L
s
.30159 .54276 m
.30159 .54651 L
s
.38095 .54276 m
.38095 .54651 L
s
.42063 .54276 m
.42063 .54651 L
s
.46032 .54276 m
.46032 .54651 L
s
.53968 .54276 m
.53968 .54651 L
s
.57937 .54276 m
.57937 .54651 L
s
.61905 .54276 m
.61905 .54651 L
s
.69841 .54276 m
.69841 .54651 L
s
.7381 .54276 m
.7381 .54651 L
s
.77778 .54276 m
.77778 .54651 L
s
.85714 .54276 m
.85714 .54651 L
s
.89683 .54276 m
.89683 .54651 L
s
.93651 .54276 m
.93651 .54651 L
s
.25 Mabswid
0 .54276 m
1 .54276 L
s
gsave
1.025 .54276 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .05825 m
.03006 .05825 L
s
[(-8)] .01131 .05825 1 0 Mshowa
.02381 .17937 m
.03006 .17937 L
s
[(-6)] .01131 .17937 1 0 Mshowa
.02381 .3005 m
.03006 .3005 L
s
[(-4)] .01131 .3005 1 0 Mshowa
.02381 .42163 m
.03006 .42163 L
s
[(-2)] .01131 .42163 1 0 Mshowa
.125 Mabswid
.02381 .08853 m
.02756 .08853 L
s
.02381 .11881 m
.02756 .11881 L
s
.02381 .14909 m
.02756 .14909 L
s
.02381 .20966 m
.02756 .20966 L
s
.02381 .23994 m
.02756 .23994 L
s
.02381 .27022 m
.02756 .27022 L
s
.02381 .33078 m
.02756 .33078 L
s
.02381 .36106 m
.02756 .36106 L
s
.02381 .39135 m
.02756 .39135 L
s
.02381 .45191 m
.02756 .45191 L
s
.02381 .48219 m
.02756 .48219 L
s
.02381 .51247 m
.02756 .51247 L
s
.02381 .02797 m
.02756 .02797 L
s
.02381 .57304 m
.02756 .57304 L
s
.02381 .60332 m
.02756 .60332 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -147 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.3125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(kinetic) show
105.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
105.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
111.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(and) show
135.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
135.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
135.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(potential) show
189.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
189.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
195.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(energy) show
231.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
0.000 0.000 0.000 setrgbcolor
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
0 0 1 r
.5 Mabswid
.02381 .01472 m
.05556 .1579 L
.0873 .06172 L
.11905 .10936 L
.15079 .17855 L
.18254 .12321 L
.21429 .12589 L
.24603 .16818 L
.27778 .11134 L
.30952 .16499 L
.34127 .17336 L
.37302 .08572 L
.40476 .11196 L
.43651 .14448 L
.46825 .08155 L
.5 .14972 L
.53175 .1077 L
.56349 .12101 L
.59524 .14469 L
.62698 .16682 L
.65873 .15685 L
.69048 .13635 L
.72222 .15545 L
.75397 .17936 L
.78571 .11085 L
.81746 .1684 L
.84921 .16663 L
.88095 .04987 L
.9127 .11795 L
.94444 .13354 L
.97619 .16629 L
s
1 0 0 r
.02381 .60332 m
.05556 .59827 L
.0873 .5956 L
.11905 .5924 L
.15079 .58924 L
.18254 .58635 L
.21429 .58436 L
.24603 .58373 L
.27778 .58465 L
.30952 .58679 L
.34127 .58957 L
.37302 .59254 L
.40476 .59558 L
.43651 .59815 L
.46825 .59928 L
.5 .5983 L
.53175 .59576 L
.56349 .59262 L
.59524 .58942 L
.62698 .58666 L
.65873 .58472 L
.69048 .58424 L
.72222 .58523 L
.75397 .5872 L
.78571 .58965 L
.81746 .59252 L
.84921 .59556 L
.88095 .59808 L
.9127 .59914 L
.94444 .59798 L
.97619 .59548 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o4oooool0
0ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?o
oooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo
000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o003oooooooooool0oooooomC
ooooo`004oooool00ol00?ooooooooooo`3ooooooe?ooooo000Cooooo`03o`00oooooooooooo0?oo
ooooDoooool001?ooooo00?o0000o`00ooooool0oooooomCooooo`004oooool00ol0003o003ooooo
o`3ooooooe?ooooo000Cooooo`03o`000?l00?oooooo0?ooooooDoooool001?ooooo00?o0000o`00
ooooool0oooooomCooooo`004oooool00ol0003o003oooooo`3ooooooe?ooooo000Cooooo`03o`00
0?oooooo003o0?ooooooDoooool001?ooooo00?o0000ooooool00?l0oooooomCooooo`004oooool0
0ol0003oooooo`00o`3ooooooe?ooooo000Cooooo`03o`000?oooooo003o0?oooooo5_ooool00ol0
0?ooooooooooo`0jooooo`002?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ool00?l0oooooolFooooo`03o`00oooooooooooo03[ooooo0008ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool01?l0003oooooooooool00?oooooooaGooooo0_l00?lkooooo`001_l00002oooo
o`05o`000?ooooooooooooooool000001_ooool3o`000003o`00oooooooooooo0?oooooo4_ooool0
0ol00?ooooooo`00o`0kooooo`002?ooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo00Co0000
oooooooooooo003o4?ooool00ol00?ooooooooooo`3oooooo`7ooooo00Co003ooooooooooooo003o
>_ooool000Sooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`04o`000?ooooooooooo`00oa3o
oooo00?o003oooooooooool0ooooool1ooooo`04o`00ooooooooooooo`00oc[ooooo0008ooooo`05
oa0@4?nj^[[ooooookZj^_l@41001_ooool01Ol0003ooooooooooooooooo003o00oooooo0_l00?oo
ooooo`7ooooo00Go003oooooooooooooooooo`00o`0jooooo`002?ooool01Ol0003o^[Zjoooooonj
^[[o000000Kooooo00Go0000ooooooooooooooooo`00o`0>ooooo`04o`00ooooooooooooo`00oooo
oooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0gooooo`002?ooool01OnYZJWo410@
o`000?l@413oZJVY00Kooooo00Go0000ooooooooooooooooo`00o`0>ooooo`04o`00oooooooooooo
o`00oooooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`0gooooo`004oooool01Ol0
003ooooooooooooooooo003o00kooooo00Go003oooooooooooooooooo`00o`3nooooo`03o`00oooo
oooooooo00?ooooo00?o003oooooooooool0=_ooool001?ooooo00Go0000ooooooooooooooooo`00
o`0=ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0n_ooool00ol00?oooooooooo
o`04ooooo`03o`00oooooooooooo03Kooooo000Cooooo`03o`000?oooooooooo00;ooooo00?o003o
ooooooooool02_ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo07Kooooo00?o003o
ooooooooool0POooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo03Gooooo000Coooo
o`03o`000?oooooooooo00;ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo05Kooooo0_l00?lMooooo`03o`00oooooooooooo087ooooo00?o003ooooo
ooooool01Oooool00ol00?ooooooooooo`0eooooo`004oooool2o`0000?ooooo00?o003ooooooooo
ool02Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo05Gooooo00?o003oooooool0
0?l06oooool00ol00?ooooooo`00o`21ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool0=Oooool001?ooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Oooooo00?o003oooooooooool0Doooool01Ol00?oooooooooooooooooo003o01[o
oooo00?o003oooooool00?l0POooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo03Co
oooo000Cooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool02Oooool00ol00?oooooo
ooooo`07ooooo`03o`00oooooooooooo05?ooooo00?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0Fooooo`05o`00ooooooooooooooooool00?l0P?ooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo03Cooooo000Cooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool0
1oooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo05;ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0Eooooo`05o`00ooooooooooooooooool00?l0P?ooool00ol00?oo
ooooooooo`08ooooo`03o`00oooooooooooo03?ooooo000Cooooo`03o`000?oooooooooo00?ooooo
00?o003oooooooooool01oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo053ooooo
00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Cooooo`03o`00oooooooooooo00?ooooo
00?o003oooooooooool0O?ooool00ol00?ooooooooooo`09ooooo`03o`00oooooooooooo03?ooooo
000Cooooo`03o`000?oooooooooo00?ooooo00?o003oooooooooool01oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo053ooooo00?o003oooooooooool01_ooool00ol00?oooooooooo
o`0Booooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0O?ooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo03;ooooo000Cooooo`03o`000?oooooooooo00?ooooo00?o003o
ooooooooool01_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooooooo04oooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Cooooo00?o003o
ooooooooool03oooool2o`00of_ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0b
ooooo`004oooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo00Kooooo00?o003ooooo
ooooool03Oooool00ol00?ooooooooooo`0aooooo`03o`00oooooooooooo01Wooooo00?o003ooooo
ooooool02Oooool00ol00?ooooooooooo`0?ooooo`03o`00oooooooooooo00Gooooo00?o003ooooo
ooooool03_ooool01?l00?ooooooo`00ool00?m?ooooo`03o`00oooooooooooo01Kooooo00?o003o
ooooooooool02oooool00ol00?ooooooooooo`0booooo`004oooool00ol0003oooooooooo`04oooo
o`03o`00oooooooooooo00Gooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0aoooo
o`03o`00oooooooooooo01Wooooo00?o003oooooooooool02_ooool2o`00o`kooooo00?o003ooooo
ooooool01_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo0_l00?m=oooo
o`03o`00oooooooooooo01Kooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0aoooo
o`004oooool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Gooooo00?o003ooooooooo
ool03_ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooo003o01Wooooo00?o003ooooooooo
ool03Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00Oooooo00?o003ooooooooo
ool02oooool00ol00?ooooooooooo`05ooooo`;o003oB_ooool00ol00?ooooooo`00o`0Gooooo`03
o`00oooooooooooo00cooooo00?o003oooooooooool0<Oooool001?ooooo0_l00005ooooo`03o`00
oooooooooooo00Cooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`0_ooooo`03o`00
oooooooo003o01Wooooo00?o003oooooooooool03_ooool00ol00?ooooooooooo`09ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`08ooooo`;o003o
B?ooool00ol00?ooooooo`00o`0Gooooo`03o`00oooooooooooo00gooooo0_l00?laooooo`004ooo
ool00ol0003oooooooooo`04ooooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool04?oo
ool00ol00?ooooooooooo`0@ooooo`Ko003o5oooool01Ol00?oooooooooooooooooo003o01Sooooo
00?o003oooooooooool03oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo00Wooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0;ooooo`;o003oAOooool01Ol00?oooooo
oooooooooooo003o01Gooooo00?o003oooooooooool04?ooool2o`00oboooooo000Cooooo`03o`00
0?oooooooooo00Gooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`0@ooooo`03o`00
oooooooooooo013ooooo00?o003oooooooooool00oooool5o`00oa7ooooo00?o003oooooooooool0
0oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool0
1_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool0
3Oooool00ol00?ooooooooooo`12ooooo`05o`00ooooooooooooooooool00?l05Oooool00ol00?oo
ooooooooo`0Booooo`?o003o;?ooool001?ooooo00?o0000ooooooooool01Oooool00ol00?oooooo
ooooo`02ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool03_ooool00ol00?oooooo
ooooo`08ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool00oooool00ol00?oooooo
ooooo`0Dooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool01Oooool00ol00?oooooo
ooooo`0;ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03oooool2o`00od7ooooo
00?o003oooooooooool00oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01Gooooo
0_l00?lZooooo`004oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool04_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00[ooooo00?o
003oooooooooool03Oooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01;ooooo00?o
003oooooooooool05?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00cooooo00?o
003oooooooooool01Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo03kooooo00?o
003oooooooooool00oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo01Oooooo0_l0
0?lXooooo`004oooool00ol0003oooooooooo`05ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool04_ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00_ooooo00?o003o
ooooooooool03?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo01;ooooo00?o003o
ooooooooool05Oooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00gooooo00?o003o
ooooooooool00oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo03cooooo00?o003o
ooooooooool01Oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01[ooooo00?o003o
ooooooooool09Oooool001?ooooo00?o0000ooooooooool01Oooool01Ol00?oooooooooooooooooo
003o01Kooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
oooo01Kooooo00Co003ooooooooooooo003o4?ooool00ol00?ooooooooooo`03ooooo`03o`00oooo
oooooooo01Gooooo0_l00?lPooooo`?o003o6Oooool00ol00?ooooooooooo`05ooooo`03o`00oooo
oooooooo013ooooo00?o003oooooooooool06oooool00ol00?ooooooooooo`0Tooooo`004oooool0
0ol0003oooooooooo`06ooooo`04o`00ooooooooooooo`00oaKooooo00?o003oooooooooool02ooo
ool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool02?oo
ool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo01Sooooo00?o003oooooool00?l04?oo
ool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool06ooo
ool2o`00o`?ooooo0_l00?lFooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03ooo
ool00ol00?ooooooooooo`0Looooo`03o`00oooooooooooo02?ooooo000Cooooo`03o`000?oooooo
oooo00Kooooo00Co003ooooooooooooo003o5oooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`09ooooo`03o`00oooo
oooooooo00oooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0@ooooo`04o`00oooo
ooooooooo`00oacooooo0_l00?lIooooo`;o003o1oooool00ol00?ooooooooooo`0Cooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0Nooooo`03o`00
oooooooooooo02;ooooo000Cooooo`03o`000?oooooooooo00Kooooo00?o003oooooool00?l06?oo
ool00ol00?ooooooooooo`08ooooo`03o`00oooooooooooo017ooooo00?o003oooooooooool01_oo
ool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool0;?oo
ool00ol00?ooooooo`00o`0Oooooo`03o`00oooooooooooo01Gooooo00?o003oooooooooool02?oo
ool2o`00oa;ooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`0=ooooo`03o`00oooo
oooooooo01oooooo00?o003oooooooooool08Oooool001?ooooo0_l00007ooooo`03o`00oooooooo
003o01Wooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Aooooo`03o`00oooooooo
oooo00Kooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooo
oooo02kooooo00?o003oooooooooool07oooool00ol00?ooooooooooo`0Booooo`;o003o3Oooool2
o`00oa3ooooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo023ooooo00?o003oooooooooool08?ooool001?ooooo00?o0000ooooooooool01_ooool00ol0
0?ooooooo`00o`0Iooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool04oooool00ol0
0?ooooooooooo`04ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`1Aooooo`;o003o4?ooool2o`00oa7ooooo00?o003oooooooooool03Oooool00ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00cooooo00?o003oooooooooool08Oooool00ol0
0?ooooooooooo`0Oooooo`004oooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo01Wo
oooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooooooooooo00?o
oooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo05Co
oooo00?o003oooooooooool02oooool2o`00oaCooooo0_l00?l<ooooo`03o`00oooooooooooo00co
oooo00?o003oooooooooool02_ooool00ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo01ko
oooo000Cooooo`03o`000?oooooooooo00Oooooo00?o003oooooooooool06Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo01Kooooo00Go003oooooooooooooooooo`00o`0Aooooo`03
o`00oooooooooooo00[ooooo00?o003oooooooooool0EOooool2o`00o`Sooooo0ol00?lHooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool03?ooool00ol00?ooooooooooo`0:ooooo`03
o`00oooooooooooo02Cooooo00?o003oooooooooool07Oooool001?ooooo00?o0000ooooooooool0
9?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo01Oooooo00Co003ooooooooooooo
003o4_ooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo05Oooooo00?o003ooooooooo
ool00oooool2o`00oacooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0>ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool09Oooool00ol00?ooooooooooo`0Looooo`00
4oooool00ol0003oooooooooo`0Tooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
6?ooool00ol00?ooooooo`00o`0Cooooo`?o003o2?ooool00ol00?ooooooooooo`1Iooooo`03o`00
oooooooo003o00;o003o7oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo
00?o003oooooooooool02?ooool00ol00?ooooooooooo`0Wooooo`03o`00oooooooooooo01_ooooo
000Cooooo`03o`000?oooooooooo02Cooooo00Go003oooooooooooooooooo`00o`0Looooo`03o`00
oooooooooooo01Gooooo0ol00?l5ooooo`03o`00oooooooooooo05[ooooo00?o003oooooooooool0
8Oooool2o`00o`Gooooo00?o003oooooooooool04?ooool;o`00odOooooo0008ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Uooooo`04o`00ooooooooooooo`00ocOo
oooo0ol00?l2ooooo`03o`00oooooooooooo083ooooo00?o003oooooooooool00_ooool00ol00?oo
ooooooooo`1Rooooo`002?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool09Oooool00ol00?ooooooo`00o`0kooooo`;o003oQ?ooool01?l00?ooooooooooool00?mUoooo
o`001_l00002ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Voooo
o`03o`00oooooooooooo0<7ooooo00?o003oooooool00?l0IOooool000Sooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@06ooooo`?o0000joooool00ol00?ooooooooooo`1Tooooo`002?ooool01Ol0003o
EEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooomCooooo`002?ooool00omEEEGo
QhN7ooooo`08ooooo`03o`000?oooooooooo0?ooooooDoooool000Sooooo00?ogMgMoa0@4?nHV9P0
2?ooool00ol0003oooooooooo`3ooooooe?ooooo0009ooooo`04olc<c?m4A4Co0000oa0@40Kooooo
00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000C
ooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCoooo
o`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?oooooo
Doooool001?ooooo0_l0003ooooooeCooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool0
01?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?o
oooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooo
oomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo
0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003ooooo
ooooo`3ooooooe?ooooo000Cooooo`;o0000oooooomDooooo`004oooool00ol0003oooooooooo`3o
oooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000oooooooo
ool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oo
oooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0
003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo
0_l0003ooooooeCooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000
ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03
o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004ooo
ool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool0
00[ooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooDoooool000_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooe?ooooo0006o`0000;ooooo
1Ol00006ooooo`?o0000oooooomCooooo`002?ooool01?m4A4CogMgMooooool00007ooooo`03o`00
0?oooooooooo0?ooooooDoooool000Sooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooo
ooooo`3ooooooe?ooooo0009ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooo
oomCooooo`002Oooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?ooooooDoooool0
00[ooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03
o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004ooo
ool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool0
01?ooooo0_l0003ooooooeCooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo
00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000C
ooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCoooo
o`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?oooooo
Doooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3o
oooooe?ooooo000Cooooo`;o0000oooooomDooooo`004oooool00ol0003oooooooooo`3ooooooe?o
oooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooo
oomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo
0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003ooooo
ooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000
ooooooooool0oooooomCooooo`004oooool2o`000?ooooooE?ooool001?ooooo00?o0000oooooooo
ool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oo
oooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0
003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool000Sooooo
1Ol00006ooooo`03o`000?oooooooooo0?ooooooDoooool000Sooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooDoooool000Ko00000oooool00onHV9So8B4Qonk^
kP07ooooo`03o`000?oooooooooo0?ooooooDoooool000[ooooo00?oV9RHob4Q8Oo^k^h01_ooool3
o`000?ooooooDoooool000_ooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`3ooooo
oe?ooooo000<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooomCooooo`00
2?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0oooooomCooooo`00
2?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooomCooooo`00
4oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDooo
ool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooo
oe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo0_l0003ooooooeCooooo
000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomC
ooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?oo
ooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003ooooooooo
o`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000oooo
ooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`;o0000
oooooomDooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooo
oooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003o
ooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o
0000ooooooooool09_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
7_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool07Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`07oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`0:?ooool4o`000003oa0@4?oooooooooo02Gooooo1?l000000ol@413ooooo
ooooo`02ooooo`;o8B4Q1?ooool5o`0001Cooooo000Cooooo`03o`000?oooooooooo02Kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A401ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`0Noooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q
8@0Oooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@0Zooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01?ooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Dooooo`004oooool00ol0003oooooooooo`0Vooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Oooooo`05oa0@4?oooooooooo
ooooool@41002oooool5o`0001oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000007oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`00000Zooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02oooool00onH
V9So8B4Qonk^kP0Eooooo`004oooool00ol0003oooooooooo`0Vooooo`05o`000?oooooooooooooo
ool000003Oooool00onHV9So8B4Qonk^kP0Nooooo`05o`000?ooooooooooooooool000002oooool0
1?m4A4CogMgMooooool0000Pooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RH
oooooonHV9So8B4Q01oooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9Sooooo
oiRHV?lb<S80:_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00cooooo00?oV9RH
ob4Q8Oo^k^h05?ooool001?ooooo0_l0000Wooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`0Mooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEoooo
ool0000Pooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<
01oooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0:_oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool04ooo
ool001?ooooo00?o0000ooooooooool09_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool07?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l00000
8?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool08Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@400Zooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Booooo`004oooool00ol0
003oooooooooo`0Vooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@01kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000023ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH027ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000:_ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@400Dooooo`004oooool0
0ol0003oooooooooo`0Vooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`00
0?lQ8B7oc<c<01kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo01oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@41oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0:?ooool00omEEEGoIVIV
o`00000Yooooo`03oeEEEOmVIVKo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Dooooo`00
4oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?ooooooDooo
ool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooo
odWooooo00GoV9RHo`000?l0003oA4A4okZj^P05ooooo`004oooool00ol0003oooooooooo`3ooooo
odWooooo00Go410@okZj^_o^k^koMgMgoa0@4005ooooo`002oooooooo`0004Wo00002oooool00ol0
003oooooooooo`07ooooo`004oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oo
oooo000Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01oooool001?ooooo00?o
0000ooooooooool0oooooom7ooooo`03oa0@4?l0003o000000?o00001_ooool001?ooooo00?o0000
ooooooooool0oooooom9ooooo`03o`000?oooooooooo00Oooooo000Cooooo`03o`000?oooooooooo
0?ooooooBOooool00ol0003oooooooooo`07ooooo`004oooool00ol0003oooooooooo`3ooooooe?o
oooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooo
oomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`;o0000oooooomDoooo
o`004oooool00ol0003oooooooooo`3ooooooe?ooooo000Cooooo`03o`000?oooooooooo0?oooooo
Doooool001?ooooo00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`0f
ooooob3oo`00LOoooolPool006_ooooo000Cooooo`03o`000?oooooooooo02cooooo2_oo000Poooo
o`[oo`00GOooool:ool0023ooooo2ooo001Pooooo`004oooool00ol0003oooooooooo`0Qooooo`_o
o`00=?ooool;ool004Oooooo2ooo000eooooo`[oo`00E_ooool001?ooooo00?o0000ooooooooool0
5oooool:ool004[ooooo2_oo000cooooo`[oo`00B_ooool:ool004cooooo000Cooooo`03o`000?oo
oooooooo00cooooo2ooo001Nooooo`_oo`007_ooool:ool005kooooo2ooo000Doooooa3oo`007Ooo
ool001?ooooo00?o0000ooooooooool00_ooool:ool007Cooooo7_oo001coooooaCoo`00;Oooool0
01?ooooo1Ooo003ooooooe7ooooo000Cooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo
00?o0000ooooooooool0oooooomCooooo`004oooool00ol0003oooooooooo`3ooooooe?ooooo000C
ooooo`03o`000?oooooooooo0?ooooooDoooool001?ooooo00?o0000ooooooooool0oooooomCoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00X?ooool01?l@4?oo003oo`00ool00?mXooooo`06ob4Q8Ol0003o0000odA4A?oMgMgooooo0ol0
00000ol@413oooooooooo`1@ooooo`00XOooool00ol00?ooooooooooo`1[ooooo`03ogMgMolb<S;o
oooo00;ooooo00?o410@okZj^_ooool0DOooool00:7ooooo00?o003oooooooooool0K?ooool01_l0
003oooooooooooooooooV9RHoc8b<U;ooooo0016ooooo`;oo`000_ooool00ooo413oo`00ool00002
ooooo`Goo`000_ooool01?oo413oo`00ool00?ooool2ool00004ool@4?ooooooonk^oomEE@;oo`00
00?oodA4oonj^_ooool00_ooool01OooV9Soo`00ool00?ooA4CookZj00?ooooo1Ooo0003ooooo`05
oomVI_oo003oo`00oom4A?ooc<`01_ooool01_nHV9So0000o`000?mgMgOo410@o`0000;ooooo00Co
410@o`000?l0003ooooo0_l000001?l@413oooooonk^k_mEEED2o`000003oiRHV?l0003o410@00So
oooo00Wo003oogMgool00?oo003ooeEEooo^k_ooooooonk^oomEEOl00_l00?l00omEEOook^kooooo
o`02ooooo`05oiRHool00?oo003oodA4oonj^_l00_ooool01_o^k_ooEEGoo`00ool00?ooA4CookZj
o`;ooooo00Co413oo`00ool00?oooooo0_l00?l01?l@4?oooooooooooonHV?l2o`00o`03odA4oonj
^_oooooo00;ooooo1Ol00?l2ooooo`06oiRHool00?oo003oogMgool@4?oo003o0_ooool5o`00o`Ko
oooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X2ooooo`04oa0@4?l0003o0000ooooo`;o000000Co
410@ooooooo^k^koEEEE0_l000001?m4A4Co^[Zjooooool@4105o`0000?ooooo00Kok^k^oeEEEOl0
003o410@olc<c?l00003ooooo`03omgMgOl0003o^[Zj057ooooo0017ooooo`05ool00?ooooooonk^
oolb<_ooc<`01Oooool00ooo003oooooooooo`03ooooo`05ool00?oooooooooooooooooo00000_oo
ool01_ooEEGoogMgooooooook^koogMgool@40?ooooo00Gooa0@oonj^_ook^koogMgool@4005oooo
o`03ool00?oooooooooo00;ooooo00KoofIVoomgMooooooooooooon7Qooo4106ooooo`05o`000?o<
c<cok^k^ohN7Qol000001?ooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMooo
ooook^k^oeEEEOl00009ooooo`09o`00oomEEOook^kooooooomgMoooEEGooooooomEEOooMgOo00;o
oooo00?oMgOooeEEooooool00_ooool01Ol@4?oo^[[oonk^oomgMooo413o00;ooooo00KoEEGoogMg
ooooooook^koogMgool@4?l3ooooo`05o`00ooooooooooooooooool00?l00oooool01Ol@4?oo^[[o
onk^oomgMooo413o00Gooooo00?o003oooooooooool00_ooool01Ol00?ooc<coonk^oon7Qooo003o
00Gooooo00?o003oooooooooool01_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go
0000ooooooooooooooooo`000002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool00ol0
003oooooooooo`04ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00000oooool00omEEEGoMgMgodA4
A01Aooooo`00Aoooool01?oo003ooiRHoolb<_ooc<`6ooooo`03ool00?oooooooooo00?ooooo00Go
o`00ooooooooooooooooool00002ooooo`03ool00?oooooooooo00Kooooo00?oo`00ooooooooool0
1oooool00ooo003oooooooooo`02ooooo`03ool00?oooooooooo00Wooooo00Go410@ohN7Qooooooo
k^k^o`000004ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003ooooooooooooooooo
k^k^o`0000Wooooo00?o003oonk^ooooool00_ooool00ol00?ooooooo`00o`04ooooo`05o`00oooo
ooooooooooooool00?l01_ooool00ol00?ooooooooooo`06ooooo`05o`00ooooooooooooooooool0
0?l00oooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00;ooooo00Go413oohN7oooo
ooook^koo`00o`05ooooo`03o`00oooooooooooo00Kooooo00?o0000ooooooooool01_ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04
ooooo`06o`000?ooooooooooooooooo^k^ko00000_ooool01OoMgMgo410@oooooolQ8B7ogMgM053o
oooo0017ooooo`03ool00?oo413ooiRH00Oooooo00?oo`00ooooooooool00oooool01Ooo003ooooo
ooooooooooooo`0000;ooooo1_oo0003ooooo`03ool00?oooooooooo00Oooooo00?oo`00oooooooo
ool00_ooool00ooo003oooooooooo`09ooooo`03okZj^_l@413o000000;o00001?ooool01Ol0003o
oooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l00009ooooo`03o`00ooo^
k_oooooo00;ooooo00?o003oooooool00?l01?ooool01Ol00?oooooooooooooooooo003o00Kooooo
1_l00?l3ooooo`05o`00ooooooooooooooooool00?l00oooool00ol00?ooooooooooo`07ooooo`03
o`00oooooooooooo00;ooooo00?o^[[ooa0@ool00?l00_l00?l5ooooo`03o`00oooooooooooo00Ko
oooo1_l00003ooooo`05o`000?ooooooooooooooool000000_ooool6o`0000?ooooo00?o0000oooo
ooooool01?ooool01_l0003oooooooooooooooook^k^o`0000;ooooo00GoIVIVohN7QoooooooV9RH
oeEEE@1@ooooo`00Aoooool01?oo003oonk^oomEEOooQhL6ooooo`03ool00?oooooooooo00?ooooo
00Goo`00oon7QoooooooojVYool00002ooooo`06oomEEOooQhOoonk^ooooooooQhOooc8b0oooool0
0ooo003oooooooooo`07ooooo`03ool00?oooooooooo00;ooooo00KoofIVoomgMooooooooooooon7
Qooo0009ooooo`03olc<c?l0003ooooo00?ooooo00Go0000ohN7QoooooooZJVYo`000002ooooo`06
ofIVI_mgMgOoooooonk^k_mEEEGo00002Oooool02Ol00?ooEEGoonk^ooooooooMgOoofIVoooooooo
EEGoogMgo`02ooooo`03ogMgoomEEOoooooo00;ooooo00?o003oooooooooool01?ooool01_mEEOoo
QhOoonk^ooooooooQhOooc8bo`?ooooo00Go003oohN7ooooooooZJWoo`00o`03ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool01Oooool00oo<c?oo003oooooo`04ooooo`03o`00oooo
oooooooo00Kooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`05o`000?n7QhOoooooojVY
ZOl000000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01?oo
ool02_mEEEGoMgMgooooooo^k^koEEEEo`000?ooooook^k^o`000?o^k^h2ooooo`03o`000?oMgMgo
oooo04kooooo0017ooooo`05ool00?ooooooodA4ool00?oo41000oooool00ooo413oo`00ool00004
ooooo`03ool@4?oo003oogMg00;oo`0000GooiRHooooooooooooonk^oomEE@02ool00004oom4A?oo
k^koooooool@40Goo`001?ooool00ooo413oo`00ool00004ooooo`06ooo^k_ooIVKoo`00ool00?oo
A4Coo`001oooool01?lb<S;o0000o`000?nHV9P3ooooo`03oa0@4?l0003oMgMg00;o000000WoV9RH
ooooooooooook^k^oeEEEOl0003o410@olc<c?l000002?ooool00ol@4?oo003oogMgo`02o`00o`05
ofIVooo^k_ooooooonk^oomEEOl00_l00?l01?mEEOook^koooooool@4?l5o`00o`?ooooo00Kok^ko
oeEEool00?oo003oodA4ooo^k_l2ooooo`03oa0@ool00?ooMgOo00;o003o00?oV9Soooooool@4?l0
1Ol00?l4ooooo`03oa0@ool00?oo003o00Gooooo00Co<S;oo`00ool00?ooV9So1Oooool00ol00?oo
ooooooooo`06ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool00ol@413o0000ogMgM`02
o`000005oiRHV?ooooooooooonk^k_mEEED00_l000001?m4A4Cok^k^ooooooooool2o`000004ojVY
ZOlQ8B7o0000ob4Q8@;ooooo00Kok^k^oeEEEOl0003o8B4QojVYZOl00002oa0@40;o000000Cooooo
o`000?l0003o410@Coooool004Oooooo00?oo`00ooooooooool07Oooool00ooo003oooooooooo`0]
ooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0F
ooooo`03o`00oooooooooooo08?ooooo0017ooooo`03ool00?oooooooooo00Oooooo00?oo`00oooo
ooooool04oooool00ooo003oooooooooo`07ooooo`03ool00?oooooooooo02?ooooo00?o0000oooo
ooooool05oooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo00Oooooo00?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`23ooooo`00A_ooool2ool000Wooooo00?ooa0@oooooooo
ool07Oooool00ooo413oooooooooo`0Rooooo`;o0000>oooool00ol@4?ooooooooooo`0:ooooo`03
oa0@ool00?oo003o08Gooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0742721, -8.96179, \
0.00482121, 0.0631792}}]
}, Open  ]],

Cell[TextData[{
  "The kinetic energy (red curve) varies smoothly and is nearly constant, \
just as one would expect for this nearly circular motion. However, the \
potential energy (blue curve) varies considerably  from step to step. \
Clearly, this potential energy is in error.  The reason for this error can be \
understood by substituting  the discrete Fourier transform representation for \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_\(i\ j\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_\(\(\ \)\(i\ j\)\)\)]],
  " into Eq. ",
  ButtonBox["(7.3.10)",
    ButtonData:>{"Chapter7.nb", "(7.3.10)"},
    ButtonStyle->"Hyperlink"],
  " . Using orthogonality of the Fourier modes, one finds"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"U", " ", "=", " ", 
          RowBox[{
            RowBox[{\(M\^2\), 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["x",
                    FontSlant->"Italic"]}]], " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["y",
                    FontSlant->"Italic"]}]], 
              " ", \(\[Sum]\+\(m, n = 0\)\%\(M - 1\)\(\[Rho]\&~\_\(m\ n\)\) \
\(\[Phi]\&~\_\(m\ n\)\^*\)\)}], "=", 
            RowBox[{\(-4\), " ", "\[Pi]", " ", \(L\^2\), "G", 
              RowBox[{
                UnderoverscriptBox[
                  StyleBox["\[Sum]",
                    FontSize->9], \(m, 
                  n = 0\), \(M - 
                    1\)], \(\((\(|\)\(\[Rho]\&~\_\(m\ n\)\)\(|\))\)\^2\/\(\(\
\[Kappa]\^2\)(m, \ n)\)\)}]}]}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(7.3.11)"],

Cell[TextData[{
  "where, in the second step, we employed Eq. ",
  ButtonBox["(6.2.43)",
    ButtonData:>{"Chapter6.nb", "(6.2.43)"},
    ButtonStyle->"Hyperlink"],
  "  (multiplied by the factor ",
  Cell[BoxData[
      \(TraditionalForm\`4\ \[Pi]\ G\)]],
  "), and where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Kappa]\^2\)(m, n)\)]],
  " is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\[Kappa]\^2\)(m, n)\), " ", "=", " ", 
          RowBox[{
            RowBox[{
              FractionBox["4", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["x",
                        FontSlant->"Italic"]}]], 
                  "2"]], \(\(sin\^2\)(\[Pi]\ m/M)\)}], " ", "+", 
            RowBox[{
              FractionBox["4", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"\[CapitalDelta]", 
                      StyleBox["y",
                        FontSlant->"Italic"]}]], 
                  "2"]], \(\(sin\^2\)(\[Pi]\ n/M)\)}]}]}], 
        TraditionalForm]]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\^2\)]],
  " approximates the square of the wavenumber, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(k\^2\), "=", 
          RowBox[{\(\((2\ \[Pi])\)\^2\), 
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(m\^2\), "/", 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["x",
                          FontSlant->"Italic"]}]], "2"]}], "+", 
                RowBox[{\(n\^2\), "/", 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["y",
                          FontSlant->"Italic"]}]], "2"]}]}], ")"}]}]}], 
        TraditionalForm]]],
  ", provided that ",
  Cell[BoxData[
      FormBox[
        RowBox[{"k", " ", 
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]]}], TraditionalForm]]],
  " is small. In this limit Eq. ",
  ButtonBox["(7.3.11)",
    ButtonData:>{"Chapter7.nb", "(7.3.11)"},
    ButtonStyle->"Hyperlink"],
  "  returns to the correct result for the potential energy, ",
  Cell[BoxData[
      \(TraditionalForm\`U = \(-4\)\ \[Pi]\ G \
\(\[Integral]\[DifferentialD]\^2 
                k \((\(|\)\(\[Rho]\&~\)\(|\))\)\^2\/k\^2\)\)]],
  ".   However, for large wavenumbers, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\^2\)]],
  "deviates considerably from ",
  Cell[BoxData[
      \(TraditionalForm\`k\^2\)]],
  ", and in fact ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa]\^2\)]],
  " ",
  "goes to zero",
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " approach ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " . This implies that, for a given particle density,  large wavenumber \
contributions to the potential energy are afforded much more weight than they \
deserve. As a result,  large-wavenumber contributions to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " produce dramatic variations in ",
  Cell[BoxData[
      \(TraditionalForm\`U\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tOf course, we already know that large wavenumbers are not properly \
handled by the FFT solution anyway, so the nonconservation of the potential \
energy due to large-wavenumber contributions might be regarded as an \
indicator that the PIC method is breaking down. However, we can see in this \
example that the actual particle dynamics appears to be working well. The \
reason for this apparent contradiction is that the dynamics depends on the \
force, not the energy, and the force is not so heavily weighted toward large \
wavenumbers as is the energy. Recall that we used a centered difference \
method for the force field at the grid points, Eqs. ",
  ButtonBox["(7.3.8)",
    ButtonData:>{"Chapter7.nb", "(7.3.8)"},
    ButtonStyle->"Hyperlink"],
  " . If we write the force in terms of a discrete Fourier transform, we find \
that"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            OverscriptBox[
              StyleBox["F",
                FontWeight->"Bold",
                FontSlant->"Plain"], "~"], \(m\ n\)], "=", 
          RowBox[{
            RowBox[{\(-\[ImaginaryI]\), " ", 
              RowBox[{
                StyleBox["K",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["(",
                  FontWeight->"Plain"], 
                StyleBox[\(m, n\),
                  FontWeight->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}], " ", \(\[Phi]\&~\_\(m\ n\)\)}], "=",
             " ", 
            RowBox[{"4", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", "G", " ", 
              RowBox[{
                StyleBox["K",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["(",
                  FontWeight->"Plain"], 
                StyleBox[\(m, n\),
                  FontWeight->"Plain"], 
                StyleBox[")",
                  
                  FontWeight->
                    "Plain"]}], \(\[Rho]\&~\_\(m\ n\)\/\(\(\[Kappa]\^2\)(m, \ 
                    n)\)\), " "}]}]}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(7.3.12)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["K",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(m, n\),
              FontWeight->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{"(", 
            RowBox[{
              FractionBox[\(sin(2\ \[Pi]\ m/M)\), 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]], ",", 
              FractionBox[\(sin(2\ \[Pi]\ n/M)\), 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["y",
                      FontSlant->"Italic"]}]]]}], ")"}]}], 
        TraditionalForm]]],
  " is a vector that approximates ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " at small ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(k\)\(|\)\)\)]],
  ". Thus, large wavenumbers are still weighted too heavily compared to the \
exact expression ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            OverscriptBox[
              StyleBox["F",
                FontWeight->"Bold",
                FontSlant->"Plain"], "~"], "=", 
            RowBox[{"4", " ", "\[Pi]", " ", "\[ImaginaryI]", " ", "G", " ", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], \(\[Rho]\&~\/k\^2\)}]}], ","}], 
        TraditionalForm]]],
  "but ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["K",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox[\(m, n\),
            FontWeight->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " ",
  "also becomes small",
  " at large wavenumbers. This greatly reduces the effect that \
large-wavenumber contributions to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " have on the force. In other words, large-wavenumber ripples in the \
density have much less effect on the force than they do on the potential \
energy. As a result, the PIC method can still be working properly, even when \
energy is not well conserved. "
}], "Text"],

Cell[TextData[{
  "\tNote that Eq. (",
  ButtonBox["7.3.12",
    ButtonData:>"(7.3.12)",
    ButtonStyle->"Hyperlink"],
  ") relies on using a finite difference method, Eq. (",
  ButtonBox["7.3.8",
    ButtonData:>"(7.3.8)",
    ButtonStyle->"Hyperlink"],
  "), to determine the force from the potential. If instead we determined the \
force by applying an inverse FFT to the expression ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          OverscriptBox[
            StyleBox["F",
              FontWeight->"Bold",
              FontSlant->"Plain"], "~"], "=", 
          RowBox[{\(-\[ImaginaryI]\), " ", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], " ", \(\[Phi]\&~\)}]}], 
        TraditionalForm]]],
  ", large wavenumbers would be weighted too heavily.  This is the main \
reason why Eq. (",
  ButtonBox["7.3.8",
    ButtonData:>"(7.3.8)",
    ButtonStyle->"Hyperlink"],
  ") is the preferred method for force evaluation."
}], "Text"],

Cell["\<\
\tHowever, it can still  useful to keep track of the energy, \
particularly when the density has little or no large-wavenumber \
contributions. This will be true if the density is a reasonably smooth \
function of position. \
\>", "Text"],

Cell["\<\
\tSince energy is not necessarily  a good indicator of the code \
accuracy, and since linear momentum is always exactly conserved, constants of \
the motion are of limited use in accuracy tests. We must therefore fall back \
on the old standby techniques for determining the validity of our results: \
\
\>", "Text"],

Cell[TextData[{
  "\t(1) increase and/or decrease the time step size by  factors of two to \
ensure that results are independent of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["t",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\t(2) increase and/or decrease the grid spacing  by  factors of two to \
ensure that results are independent of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\t(3) increase and/or decrease the particle number by  factors of two \
(decreasing or increasing  the mass per particle by the same factor so that \
mass density remains the same) to ensure that results are independent of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Gravitational Collapse in a Cold Gas", "Section",
  CellTags->{"i:56", "c:37"}],

Cell[TextData[{
  "A cold uniform gas is unstable to gravitational collapse. Due to the \
attraction of the gas to itself, small density variations grow over time. \
Matter is attracted to maxima in these variations, increasing their size. \
This is called the",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Jeans",
    ButtonData:>{
      URL[ 
      "http://www-history.mcs.st-andrews.ac.uk/history/Mathematicians/Jeans.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" instability",
    FontSlant->"Italic"],
  ". This basic phenomenon is responsible for the formation of all the \
structure we can see in the night sky, including planets, stars,  and \
galaxies. "
}], "Text",
  CellTags->"i:80"],

Cell[TextData[{
  "\tThe instability can also be studied from a different point of view by \
considering the energy of the system. According to Eq. ",
  ButtonBox["(7.3.11)",
    ButtonData:>{"Chapter7.nb", "(7.3.11)"},
    ButtonStyle->"Hyperlink"],
  " , the potential energy is a negative quantity, becoming more negative as \
the gas collapses and the density becomes more concentrated.  In order to \
conserve energy,  kinetic energy must increase. As the gas collapses, it \
heats.   What is the end product of this process?"
}], "Text"],

Cell[TextData[{
  "\tWe can study  gravitational collapse and heating  in a PIC simulation. \
In Cells ",
  ButtonBox["7.84",
    ButtonData:>"Cell 7.84",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["7.85",
    ButtonData:>"Cell 7.85",
    ButtonStyle->"Hyperlink"],
  " we run a simulation of 1000 particles, initially distributed randomly \
throughout the box, and with zero initial momentum. We perform the simulation \
on a rather coarse 10 by 10 spatial grid, since we are not interested in \
quantitative accuracy at this point, only in the qualitative effects \
associated with the collapse."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Utilities`;\)\), "\n", 
    \(m = 1; M = 10; 
    L = 1; \[CapitalDelta]x\  = \ \(\[CapitalDelta]y\  = \ 
        L/M\); \[CapitalDelta]t\  = \ 0.003;\), "\n", 
    \(\(Clear[r, p];\)\), "\n", 
    \(\(r0\  = \ Table[{Random[], Random[]}, {1000}];\)\), "\n", 
    \(\(p0 = \ Table[{0, 0}, {1000}];\)\), "\n", 
    \(Timing[leapfrog[r0, p0, 60, \[CapitalDelta]t]]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.84"],

Cell[BoxData[
    \({31.99`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(Table[
        ListPlot[r[n], PlotRange \[Rule] {{0, 1}, {0, 1}}, 
          AspectRatio \[Rule] 1], {n, 0, 60, 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.85"],

Cell[BoxData[
    \( (*movie\ goes\ here\ *) \)], "Input"],

Cell[TextData[{
  "\tSmall fluctuations in the initial density are amplified by the Jeans \
instability, resulting in collapse of the gas cloud, followed by approach to \
something like an equilibrium state that consists of a single density peak,  \
surrounded by a hot gas of particles.   If one runs the simulation several \
times, one will find that qualitatively similar behavior occurs each time.\n\t\
  In Cell ",
  ButtonBox["7.86",
    ButtonData:>"Cell 7.86",
    ButtonStyle->"Hyperlink"],
  " we calculate the kinetic energy of the cloud."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Table[{n\ \[CapitalDelta]t, kineticenergy[n]}, {n, 0, 60}], 
        PlotJoined \[Rule] True];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.86"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 5.29101 0.0147151 1.78653e-06 [
[.15608 .00222 -15 -9 ]
[.15608 .00222 15 0 ]
[.28836 .00222 -12 -9 ]
[.28836 .00222 12 0 ]
[.42063 .00222 -15 -9 ]
[.42063 .00222 15 0 ]
[.55291 .00222 -9 -9 ]
[.55291 .00222 9 0 ]
[.68519 .00222 -15 -9 ]
[.68519 .00222 15 0 ]
[.81746 .00222 -12 -9 ]
[.81746 .00222 12 0 ]
[.94974 .00222 -15 -9 ]
[.94974 .00222 15 0 ]
[.01131 .10404 -30 -4.5 ]
[.01131 .10404 0 4.5 ]
[.01131 .19337 -36 -4.5 ]
[.01131 .19337 0 4.5 ]
[.01131 .28269 -36 -4.5 ]
[.01131 .28269 0 4.5 ]
[.01131 .37202 -36 -4.5 ]
[.01131 .37202 0 4.5 ]
[.01131 .46135 -36 -4.5 ]
[.01131 .46135 0 4.5 ]
[.01131 .55067 -36 -4.5 ]
[.01131 .55067 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15608 .01472 m
.15608 .02097 L
s
[(0.025)] .15608 .00222 0 1 Mshowa
.28836 .01472 m
.28836 .02097 L
s
[(0.05)] .28836 .00222 0 1 Mshowa
.42063 .01472 m
.42063 .02097 L
s
[(0.075)] .42063 .00222 0 1 Mshowa
.55291 .01472 m
.55291 .02097 L
s
[(0.1)] .55291 .00222 0 1 Mshowa
.68519 .01472 m
.68519 .02097 L
s
[(0.125)] .68519 .00222 0 1 Mshowa
.81746 .01472 m
.81746 .02097 L
s
[(0.15)] .81746 .00222 0 1 Mshowa
.94974 .01472 m
.94974 .02097 L
s
[(0.175)] .94974 .00222 0 1 Mshowa
.125 Mabswid
.05026 .01472 m
.05026 .01847 L
s
.07672 .01472 m
.07672 .01847 L
s
.10317 .01472 m
.10317 .01847 L
s
.12963 .01472 m
.12963 .01847 L
s
.18254 .01472 m
.18254 .01847 L
s
.20899 .01472 m
.20899 .01847 L
s
.23545 .01472 m
.23545 .01847 L
s
.2619 .01472 m
.2619 .01847 L
s
.31481 .01472 m
.31481 .01847 L
s
.34127 .01472 m
.34127 .01847 L
s
.36772 .01472 m
.36772 .01847 L
s
.39418 .01472 m
.39418 .01847 L
s
.44709 .01472 m
.44709 .01847 L
s
.47354 .01472 m
.47354 .01847 L
s
.5 .01472 m
.5 .01847 L
s
.52646 .01472 m
.52646 .01847 L
s
.57937 .01472 m
.57937 .01847 L
s
.60582 .01472 m
.60582 .01847 L
s
.63228 .01472 m
.63228 .01847 L
s
.65873 .01472 m
.65873 .01847 L
s
.71164 .01472 m
.71164 .01847 L
s
.7381 .01472 m
.7381 .01847 L
s
.76455 .01472 m
.76455 .01847 L
s
.79101 .01472 m
.79101 .01847 L
s
.84392 .01472 m
.84392 .01847 L
s
.87037 .01472 m
.87037 .01847 L
s
.89683 .01472 m
.89683 .01847 L
s
.92328 .01472 m
.92328 .01847 L
s
.97619 .01472 m
.97619 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .10404 m
.03006 .10404 L
s
[(50000)] .01131 .10404 1 0 Mshowa
.02381 .19337 m
.03006 .19337 L
s
[(100000)] .01131 .19337 1 0 Mshowa
.02381 .28269 m
.03006 .28269 L
s
[(150000)] .01131 .28269 1 0 Mshowa
.02381 .37202 m
.03006 .37202 L
s
[(200000)] .01131 .37202 1 0 Mshowa
.02381 .46135 m
.03006 .46135 L
s
[(250000)] .01131 .46135 1 0 Mshowa
.02381 .55067 m
.03006 .55067 L
s
[(300000)] .01131 .55067 1 0 Mshowa
.125 Mabswid
.02381 .03258 m
.02756 .03258 L
s
.02381 .05045 m
.02756 .05045 L
s
.02381 .06831 m
.02756 .06831 L
s
.02381 .08618 m
.02756 .08618 L
s
.02381 .12191 m
.02756 .12191 L
s
.02381 .13977 m
.02756 .13977 L
s
.02381 .15764 m
.02756 .15764 L
s
.02381 .1755 m
.02756 .1755 L
s
.02381 .21123 m
.02756 .21123 L
s
.02381 .2291 m
.02756 .2291 L
s
.02381 .24696 m
.02756 .24696 L
s
.02381 .26483 m
.02756 .26483 L
s
.02381 .30056 m
.02756 .30056 L
s
.02381 .31842 m
.02756 .31842 L
s
.02381 .33629 m
.02756 .33629 L
s
.02381 .35415 m
.02756 .35415 L
s
.02381 .38989 m
.02756 .38989 L
s
.02381 .40775 m
.02756 .40775 L
s
.02381 .42562 m
.02756 .42562 L
s
.02381 .44348 m
.02756 .44348 L
s
.02381 .47921 m
.02756 .47921 L
s
.02381 .49708 m
.02756 .49708 L
s
.02381 .51494 m
.02756 .51494 L
s
.02381 .53281 m
.02756 .53281 L
s
.02381 .56854 m
.02756 .56854 L
s
.02381 .5864 m
.02756 .5864 L
s
.02381 .60427 m
.02756 .60427 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.03968 .01488 L
.05556 .01562 L
.07143 .01716 L
.0873 .02006 L
.10317 .02542 L
.11905 .03522 L
.13492 .05296 L
.15079 .08422 L
.16667 .13461 L
.18254 .20091 L
.19841 .26528 L
.21429 .31619 L
.23016 .36094 L
.24603 .43214 L
.2619 .54195 L
.27778 .60332 L
.29365 .57446 L
.30952 .51724 L
.3254 .47161 L
.34127 .45509 L
.35714 .46579 L
.37302 .47697 L
.38889 .48823 L
.40476 .4995 L
.42063 .50382 L
.43651 .50557 L
.45238 .50308 L
.46825 .49907 L
.48413 .49101 L
.5 .47922 L
.51587 .46906 L
.53175 .45276 L
.54762 .43595 L
.56349 .43584 L
.57937 .4634 L
.59524 .51085 L
.61111 .55203 L
.62698 .56265 L
.64286 .55028 L
.65873 .52492 L
.6746 .50241 L
.69048 .48597 L
.70635 .48059 L
.72222 .48359 L
.7381 .48699 L
.75397 .48978 L
.76984 .49613 L
.78571 .50514 L
.80159 .52063 L
Mistroke
.81746 .53638 L
.83333 .53504 L
.84921 .52118 L
.86508 .50544 L
.88095 .4963 L
.89683 .4978 L
.9127 .50567 L
.92857 .50688 L
.94444 .49664 L
.96032 .48334 L
.97619 .47593 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00B_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgM
g@07ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ok^k^oooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`Co000000?o410@ooooooooool02_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool01Ol00004ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go
410@ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo00Kooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000onk^k_oo
ool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM007ooooo001:ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`06ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`07ooooo`03ogMgMolb<S;ooooo00Ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`0:ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool03?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A007ooooo`03ogMgMolb<S;ooooo00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03oeEEEOnYZJWo
oooo00Oooooo0OmgMgL1oc8b<P7ooooo001:ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol@413ooooooooooooooooo410@00Cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`05ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00So
oooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooo
oooooooooooooa0@4005ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool02Oooool0
1Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool03?ooool01Ol@413ooooooooo
oooooooo410@00kooooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP09ooooo`03o`00
0?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000oooo
ooooool01?ooool00onYZJWoEEEEooooo`08ooooo`7o00000Oooool004[ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?ooooooooooooooool000001Oooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo00Kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oo
ooooooooooooool000001oooool00omgMgOo<S8booooo`06ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`0:ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0<
ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`06ooooo`05o`000?ooooooooooooooool0
00003_ooool00ol0003oooooooooo`05ooooo`03ob4Q8Ooooooooooo00Kooooo0OmgMgL1oc8b<P7o
oooo001:ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Oooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooooooo
ooooool000001_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02ooo
ool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool03?ooool01Ol0003ooooo
oooooooooooo000000kooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Oooooo00Go0000oooooooooooooooo
o`00000>ooooo`03o`000?oooooooooo00Gooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<007ooooo001:ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o
oooooooooooooooo410@00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool02Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool03Oooool01Ol@413o
oooooooooooooooo410@00kooooo00?o0000ooooooooool03?ooool01Ol@413ooooooooooooooooo
410@00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
1Oooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00?ooooo001:ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go0000okZj^_oo
ooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`09ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go410@oooooooo
oooooooooc8b<P04ooooo`03o`000?oooooooooo00gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`03o`000?oooooooooo00cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oo
oooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool00oooool004[ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Cooooo1?l00008ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo1Ol00004ooooo`Co00003?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00008oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000005ooooo`Co00002?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001?ooool5o`0000Cooooo1?l0
0002ooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo
0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003ooooo
ooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool002goooooool0000h
o`0000Cooooo000dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool003Cooooo00?o0000oooooooo
ool04oooool3o`00013ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool04Oooool003Cooooo00?o0000ooooooooool0
5_ooool2o`000?oooooo6_ooool003Cooooo00?o0000ooooooooool06?ooool2o`000?oooooo6?oo
ool003Cooooo0_l0000Kooooo`03o`000?oooooooooo0?oooooo5Oooool003Cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`3ooooooaCooooo000dooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0oooooolDooooo`00=?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo0?oooooo4oooool003Cooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`3ooooooa;ooooo000dooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0oooooolB
ooooo`00=?ooool2o`0001oooooo00?o0000ooooooooool0oooooolAooooo`00=?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo0?oooooo4?ooool003Cooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`3ooooooa3ooooo000dooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0ooooool?ooooo`00=?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo0?oooooo3oooool003Cooooo0_l0000Rooooo`03o`000?oooooooooo0?oooooo3_ooool003Co
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`3oooooo`gooooo000dooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0ooooool=ooooo`00=?ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo0?oooooo3?ooool003Cooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`3oooooo`cooooo000dooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0ooooool;ooooo`00=?ooool2o`0002Gooooo00?o0000ooooooooool0ooooool;ooooo`00
=?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0?oooooo2oooool003Cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`3oooooo`[ooooo000:ooooo`05odA4A?l0003o
0000oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`3oooooo`[ooooo000=oooo
o`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`3oooooo`[ooooo000>oooo
o`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01?ooool3o`0002Kooooo00?o0000ooooooooool0ooooool9ooooo`003Oooool01OmgMgOo<S8b
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0?oooooo2Oooool000[ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0?oooooo2Oooool0
00[ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3oooooo`So
oooo000:ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0oooo
ool8ooooo`002_ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP06ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0ooooool8oooo
o`00=?ooool2o`0002Wooooo00?o0000ooooooooool0ooooool7ooooo`00=?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo0?oooooo1oooool003Cooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`3oooooo`Oooooo000dooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0ooooool6ooooo`00=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
0?oooooo1_ooool003Cooooo0_l0000Zooooo`03o`000?oooooooooo0?oooooo1_ooool003Cooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3oooooo`Kooooo000dooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0ooooool5ooooo`00=?ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo0?oooooo1Oooool003Cooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`3oooooo`Gooooo000dooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0ooooool5ooooo`00=?ooool2o`0002cooooo00?o0000ooooooooool0ooooool4ooooo`00=?oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0?oooooo1?ooool003Cooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`3oooooo`Cooooo000dooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0ooooool4ooooo`00=?ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo0?oooooo0oooool003Cooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`3oooooo`?ooooo000dooooo`;o0000;Oooool00ol0003oooooooooo`3oooooo`?ooooo000d
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0ooooool3ooooo`00=?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo0?oooooo0_ooool000;ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`3o
ooooo`;ooooo0004ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo0?oooooo0_ooool000Cooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4006ooooo`?o0000;Oooool00ol0003oooooooooo`3oooooo`;o
oooo0004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo0?oooooo0Oooool000Cooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0oooo
ool1ooooo`001?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000
ooooooooool0;_ooool00ol0003oooooooooo`3oooooo`7ooooo0004ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
0?oooooo0Oooool000;ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0ooooool003Cooooo0_l0000`ooooo`03o`00
0?oooooooooo0?oooooo000dooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0oooo
ool003Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`3oooooo`00=?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo0?kooooo000dooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0o_ooool003Cooooo0_l0000aooooo`03o`000?oooooooooo0?kooooo
000dooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0o_ooool003Cooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`3mooooo`00=?ooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo0?gooooo000dooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0oOooool003Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`3mooooo`00=?oo
ool2o`0003?ooooo00?o0000ooooooooool0o?ooool003Cooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`3looooo`00=?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
0?cooooo000dooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0o?ooool003Cooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`3kooooo`00=?ooool2o`0003Cooooo00?o
0000ooooooooool0noooool003Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`3k
ooooo`00=?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo0?_ooooo0002ooooo`Co
000000Go410@ooooooooooooooooodA4A002o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`3jooooo`001?ooool00ol0003oooooooooo`06ooooo`09ogMgMolb<S;ooooo
oooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`3jooooo`001?ooool00ol0003oooooooooo`07oooo
o`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oo
ooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0?[ooooo0004ooooo`03o`00
0?oooooooooo00Kooooo00GoMgMgoc8b<_ooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00Cooooo0ol0000eooooo`03o`000?oooooooooo0?Wooooo0004
ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo0?Wooooo0004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00Ko
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`3iooooo`001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0n?oo
ool000;ooooo00?oEEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0n?ooool003Cooooo0_l0000gooooo`03o`000?oooooooooo0?Sooooo000dooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0moooool003Cooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`3gooooo`00=?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo0?Oooooo000dooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0m_ooool003Co
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`3fooooo`00=?ooool2o`0003Wooooo
00?o0000ooooooooool0m_ooool003Cooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`3eooooo`00=?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo0?Gooooo000doooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0mOooool003Cooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`3dooooo`00=?ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo0?Cooooo000dooooo`;o0000>oooool00ol0003oooooooooo`3dooooo`00=?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0??ooooo000dooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0loooool003Cooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`3cooooo`00=?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo0?;ooooo
000dooooo`;o0000?Oooool00ol0003oooooooooo`3booooo`00=?ooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo0?;ooooo000dooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool0lOooool00003ooooool0003o000000?o00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0lOooool00006oooooonHV9So8B4Qonk^k_oo
ooooA4A40oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool0lOooool000;ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0l?ooool000?ooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o0000?_ooool00ol0003oooooooooo`3`ooooo`001?oo
ool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`3`ooooo`001Oooool01Ol0003ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo00Cooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`3`ooooo`0000Koooooo`00
0?nj^[[ooooooiRHV?l@4103ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`3`ooooo`0000KooooooiRHV?l@413o0000ob4Q8Oo<c<`3ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`3_ooooo`00=?oo
ool2o`00043ooooo00?o0000ooooooooool0koooool003Cooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`3_ooooo`00=?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
0>oooooo000dooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0k_ooool003Cooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`3^ooooo`00=?ooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo0>kooooo000dooooo`;o0000@Oooool00ol0003oooooooooo`3^
ooooo`00=?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo0>gooooo000dooooo`03
o`000?oooooooooo047ooooo00?o0000ooooooooool0kOooool003Cooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`3]ooooo`00=?ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo0>gooooo000dooooo`;o0000@_ooool00ol0003oooooooooo`3]ooooo`00=?ooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo0>cooooo000dooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0k?ooool003Cooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`3/ooooo`00=?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo05_ooooo1_l0
002;ooooo`00=?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`29ooooo`00=?ooool2o`0004Cooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Sooooo000dooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo08Oooooo000dooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
E_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08Oooooo00000ooooooo0000o`00
0003o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo01[ooooo0_l0000iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Q_oo
ool00006oooooonHV9So8B4Qonk^k_ooooooA4A41oooool02OmgMgOo<S8booooooooooooMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool06_ooool00ol0003oooooo`00000gooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0Q_ooool000;ooooo00?oV9RHob4Q8Oo^k^h02Oooool01?l0003ooooo
ooooool@4103ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo0ol0
0013ooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00000eooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0QOooool000?ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0Q?ooool000Cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05oooo
o`;o0000<?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Cooooo0005ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool2o`0001Cooooo
00?o0000ooooooooool0Poooool00006ooooool0003o^[ZjoooooonHV9So410@1?ooool00ol0003o
ooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Xooooo`;o00005_ooool00ol0003oooooooooo`23ooooo`0000Ko
oooooiRHV?l@413o0000ob4Q8Oo<c<`4ooooo`Co00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00_ooooo0_l0000Wooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0M_ooool2o`0000_ooooo000dooooo`;o0000AOooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08_ooool2o`0001[ooooo00?o
0000ooooooooool08Oooool5o`0004cooooo0ol0000=ooooo`00=?ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07_ooool3o`0000Gooooo1Ol00015
ooooo`;o00004?ooool003Cooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool5o`0003oooooo00?o0000oooo
ooooool04?ooool003Cooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01;ooooo0_l0000Mooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Aooooo`?o0000>oooool00ol0003oooooooooo`0Aooooo`00
=?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
5?ooool2o`0001Wooooo0_l0000Pooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
5Oooool3o`0003Oooooo00?o0000ooooooooool04_ooool003Cooooo00?o0000ooooooooool0AOoo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04ooo
ool3o`0002;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`;o00007ooo
ool5o`0000oooooo0_l0000Eooooo`00=?ooool2o`0004Kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Hooooo`;o00004?ooool3o`0002Kooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Looooo`;o00006oooool2o`0000Gooooo0ol0000;ooooo`03o`000?oooooo
oooo01Gooooo000dooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Jooooo`?o00002?ooool5o`0002Wooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02?ooool3o`00
00Oooooo00?o0000ooooooooool05_ooool003Cooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01gooooo2?l0000^ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00co
oooo1?l00002ooooo`03o`000?oooooooooo01Oooooo000dooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo013ooooo
0_l0000Jooooo`00=?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0EOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0]ooooo`00=?ooool2o`0004Oooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02kooooo000doooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Foooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo02oooooo000dooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0;ooooo`;o0000<_ooool003Cooooo00?o0000ooooooooool0
A_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
<_ooool003Cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo05Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0<oooool003Cooooo00?o0000ooooooooool0A_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool0
03Cooooo0_l00018ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0FOooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo033ooooo00Co0000oooooooooooooooo0ol0000g
ooooo`00=?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo037ooooo0ol0000joooo
o`00=?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06oooooo00001_ooooooV9RH
oa0@4?l0003o<S8bolc<c0?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo06oooooo00001_oooooo410@okZj^_ooooooMgMgoc8b<P?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo073ooooo0005oooo
o`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool3o`0004Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Kooooo0_l0001coooo
o`001?ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05gooooo0_l00006ooooo`03
o`000?oooooooooo07?ooooo0003ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
Goooool2o`0000?ooooo00?o0000ooooooooool0M?ooool000Cooooo00?o^[Zjob4Q8Oooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1Qooooo`03o`000?oooooo000007Oooooo00001_oooooo410@oiRHV?oo
oooo^[Zjo`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`1fooooo`0000Ko
ooooojVYZOl@413o0000oa0@4?nYZJT3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=cooooo000dooooo`;o0000
B_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=cooooo000dooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Mooooo`00=?ooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0gOooool0
03Cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0=gooooo000dooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`3Nooooo`00=?ooool2o`0004_ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3Nooooo`00=?ooool00ol0003oooooooooo`1;ooooo`05o`000?ooooooooooooooool00000
hOooool003Cooooo00?o0000ooooooooool0Boooool01?l0003oooooooooool0003Rooooo`00=?oo
ool00ol0003oooooooooo`1;ooooo`04o`000?ooooooooooo`000>;ooooo000dooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooool00000hoooool003Cooooo00?o0000ooooooooool0C?ooool2
o`000>?ooooo000dooooo`;o0000COooool00ol0003oooooooooo`3Rooooo`00=?ooool00ol0003o
ooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o
0000ooooooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {221.375, 0}} -> {-0.0318924, -44107.6, \
0.000760081, 2251.07}}]
}, Open  ]],

Cell["\<\
\tAfter a rapid increase, the kinetic energy begins to fluctuate \
about some equilibrium value. Evidently, the heating of the gas results in an \
arrest of the collapse.  The outward thermal pressure of the gas can balance \
the gravitational attraction, allowing a steady state to be achieved. This \
steady state can be thought of as a crude approximation to the nebulae from \
which stars, planets, or galaxies might form. Loss of kinetic energy though \
various mechanisms that are not included in our simulation allows the \
collapse to continue in real clouds, until a compact object forms such as a \
star,  planet, or black hole. These loss mechanisms include the formation of \
collisional shock waves, radiation,  and evaporation (where hot particles \
achieve escape velocity and leave the cloud, lowering the average kinetic \
energy per particle of the remainder).\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Stability of a Hot Gas to Gravitational Collapse", "Section",
  CellTags->{"i:57", "c:38"}],

Cell[TextData[{
  " If a uniform gas is sufficiently hot initially, gravitational collapse \
does not occur, because the gas pressure can balance the force of gravity. \
One can see this in the simulation (Cells ",
  ButtonBox["7.87",
    ButtonData:>"Cell 7.87",
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["7.89",
    ButtonData:>"Cell 7.89",
    ButtonStyle->"Hyperlink"],
  ") by giving the particles large random initial velocities:"
}], "Text"],

Cell[BoxData[{
    \(m = 1; M = 10; 
    L = 1; \[CapitalDelta]x\  = \ \(\[CapitalDelta]y\  = \ 
        L/M\); \[CapitalDelta]t\  = \ 0.0015;\), "\n", 
    \(\(Clear[r, p];\)\), "\n", 
    \(\(r0\  = \ Table[{Random[], Random[]}, {1000}];\)\), "\n", 
    \(\(p0 = \ 
        Table[60 {Random[] -  .5, Random[] -  .5}, {1000}];\)\), "\n", 
    \(Timing[leapfrog[r0, p0, 60, \[CapitalDelta]t]]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.87"],

Cell[CellGroupData[{

Cell[BoxData[
    \( (*\ simulation\ removed\ \ to\ save\ space\ *) \)], "Input"],

Cell[BoxData[
    \({32.27999999999999`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(Table[
        ListPlot[r[n], PlotRange \[Rule] {{0, 1}, {0, 1}}, 
          AspectRatio \[Rule] 1], {n, 0, 60, 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.88"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Table[{n\ \[CapitalDelta]t, kineticenergy[n]}, {n, 0, 60}], 
        PlotJoined \[Rule] True, 
        PlotLabel \[Rule] \ "\<kinetic energy versus time\>", \ 
        AxesLabel \[Rule] {"\<t\>", "\<\>"}, 
        PlotRange \[Rule] {0, 400000}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.89"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 10.582 0 1.54508e-06 [
[.23545 -0.0125 -12 -9 ]
[.23545 -0.0125 12 0 ]
[.44709 -0.0125 -12 -9 ]
[.44709 -0.0125 12 0 ]
[.65873 -0.0125 -12 -9 ]
[.65873 -0.0125 12 0 ]
[.87037 -0.0125 -12 -9 ]
[.87037 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.01131 .07725 -30 -4.5 ]
[.01131 .07725 0 4.5 ]
[.01131 .15451 -36 -4.5 ]
[.01131 .15451 0 4.5 ]
[.01131 .23176 -36 -4.5 ]
[.01131 .23176 0 4.5 ]
[.01131 .30902 -36 -4.5 ]
[.01131 .30902 0 4.5 ]
[.01131 .38627 -36 -4.5 ]
[.01131 .38627 0 4.5 ]
[.01131 .46353 -36 -4.5 ]
[.01131 .46353 0 4.5 ]
[.01131 .54078 -36 -4.5 ]
[.01131 .54078 0 4.5 ]
[.01131 .61803 -36 -4.5 ]
[.01131 .61803 0 4.5 ]
[.5 .63053 -80 0 ]
[.5 .63053 80 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.23545 0 m
.23545 .00625 L
s
[(0.02)] .23545 -0.0125 0 1 Mshowa
.44709 0 m
.44709 .00625 L
s
[(0.04)] .44709 -0.0125 0 1 Mshowa
.65873 0 m
.65873 .00625 L
s
[(0.06)] .65873 -0.0125 0 1 Mshowa
.87037 0 m
.87037 .00625 L
s
[(0.08)] .87037 -0.0125 0 1 Mshowa
.125 Mabswid
.07672 0 m
.07672 .00375 L
s
.12963 0 m
.12963 .00375 L
s
.18254 0 m
.18254 .00375 L
s
.28836 0 m
.28836 .00375 L
s
.34127 0 m
.34127 .00375 L
s
.39418 0 m
.39418 .00375 L
s
.5 0 m
.5 .00375 L
s
.55291 0 m
.55291 .00375 L
s
.60582 0 m
.60582 .00375 L
s
.71164 0 m
.71164 .00375 L
s
.76455 0 m
.76455 .00375 L
s
.81746 0 m
.81746 .00375 L
s
.92328 0 m
.92328 .00375 L
s
.97619 0 m
.97619 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .07725 m
.03006 .07725 L
s
[(50000)] .01131 .07725 1 0 Mshowa
.02381 .15451 m
.03006 .15451 L
s
[(100000)] .01131 .15451 1 0 Mshowa
.02381 .23176 m
.03006 .23176 L
s
[(150000)] .01131 .23176 1 0 Mshowa
.02381 .30902 m
.03006 .30902 L
s
[(200000)] .01131 .30902 1 0 Mshowa
.02381 .38627 m
.03006 .38627 L
s
[(250000)] .01131 .38627 1 0 Mshowa
.02381 .46353 m
.03006 .46353 L
s
[(300000)] .01131 .46353 1 0 Mshowa
.02381 .54078 m
.03006 .54078 L
s
[(350000)] .01131 .54078 1 0 Mshowa
.02381 .61803 m
.03006 .61803 L
s
[(400000)] .01131 .61803 1 0 Mshowa
.125 Mabswid
.02381 .01545 m
.02756 .01545 L
s
.02381 .0309 m
.02756 .0309 L
s
.02381 .04635 m
.02756 .04635 L
s
.02381 .0618 m
.02756 .0618 L
s
.02381 .09271 m
.02756 .09271 L
s
.02381 .10816 m
.02756 .10816 L
s
.02381 .12361 m
.02756 .12361 L
s
.02381 .13906 m
.02756 .13906 L
s
.02381 .16996 m
.02756 .16996 L
s
.02381 .18541 m
.02756 .18541 L
s
.02381 .20086 m
.02756 .20086 L
s
.02381 .21631 m
.02756 .21631 L
s
.02381 .24721 m
.02756 .24721 L
s
.02381 .26266 m
.02756 .26266 L
s
.02381 .27812 m
.02756 .27812 L
s
.02381 .29357 m
.02756 .29357 L
s
.02381 .32447 m
.02756 .32447 L
s
.02381 .33992 m
.02756 .33992 L
s
.02381 .35537 m
.02756 .35537 L
s
.02381 .37082 m
.02756 .37082 L
s
.02381 .40172 m
.02756 .40172 L
s
.02381 .41717 m
.02756 .41717 L
s
.02381 .43262 m
.02756 .43262 L
s
.02381 .44807 m
.02756 .44807 L
s
.02381 .47898 m
.02756 .47898 L
s
.02381 .49443 m
.02756 .49443 L
s
.02381 .50988 m
.02756 .50988 L
s
.02381 .52533 m
.02756 .52533 L
s
.02381 .55623 m
.02756 .55623 L
s
.02381 .57168 m
.02756 .57168 L
s
.02381 .58713 m
.02756 .58713 L
s
.02381 .60258 m
.02756 .60258 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -141 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(kinetic) show
111.000 13.000 moveto
(energy) show
153.000 13.000 moveto
(versus) show
195.000 13.000 moveto
(time) show
219.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .47793 m
.03968 .47783 L
.05556 .47781 L
.07143 .47788 L
.0873 .47802 L
.10317 .47816 L
.11905 .47828 L
.13492 .47847 L
.15079 .47871 L
.16667 .47899 L
.18254 .47927 L
.19841 .47956 L
.21429 .47983 L
.23016 .48007 L
.24603 .48025 L
.2619 .48029 L
.27778 .48019 L
.29365 .48002 L
.30952 .4798 L
.3254 .47954 L
.34127 .47926 L
.35714 .47893 L
.37302 .47866 L
.38889 .47862 L
.40476 .47887 L
.42063 .47939 L
.43651 .48016 L
.45238 .48105 L
.46825 .48185 L
.48413 .48249 L
.5 .48297 L
.51587 .48324 L
.53175 .48329 L
.54762 .48321 L
.56349 .48305 L
.57937 .4827 L
.59524 .48219 L
.61111 .48166 L
.62698 .48121 L
.64286 .48084 L
.65873 .48057 L
.6746 .48043 L
.69048 .48046 L
.70635 .48061 L
.72222 .48077 L
.7381 .48097 L
.75397 .48118 L
.76984 .48127 L
.78571 .48111 L
.80159 .4807 L
Mistroke
.81746 .48009 L
.83333 .47943 L
.84921 .47883 L
.86508 .47835 L
.88095 .47806 L
.89683 .47793 L
.9127 .47798 L
.92857 .47831 L
.94444 .47885 L
.96032 .4793 L
.97619 .47953 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00Hoooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool5o`00027ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_l000000ol@413oooooooooo`0Oooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`08_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02gooooo001Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Poooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B408_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OlQ8B7oV9RHoooooonHV9So
8B4Q02gooooo001Sooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooo
oooo410@00Cooooo00?oV9RHob4Q8Oo^k^h08_ooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go410@oooooooooooooooooa0@4003ooooo`Go00008Oooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05o`000?ooooooooooooooool000008_oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
o`000?ooooooooooooooool00000;Oooool006?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?ooooooooooooooool000001Oooool00onHV9So8B4Qonk^kP0Qooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00CoA4A4omgMgOoooooo
00008_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?nHV9SooooooiRHV?lQ8B408_ooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000ooooooooooooooooo`000003ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80;Oooool006?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000001_ooool0
0omgMgOoIVIVooooo`0Pooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooo
oooooooo000000?ooooo00CogMgMoeEEEOoooooo00008_ooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?mEEEGo0000oa0@4?o<c<`08_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000003ooooo`05
olc<c?l0003o0000o`000?o<c<`0;Oooool006?ooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`0Oooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?oMgMgolc<c?l00000
8_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003oooo
o`03oeEEEOn7QhOooooo02Cooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oooooo
ooooooooool@41000oooool01Ol@413o^[Zjoooooonj^[[o410@02gooooo001Sooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go0000okZj^_oo
ooooV9RHoa0@400Qooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Cooooo00?ok^k^odA4A?l000008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`03omgMgOl@413oV9RH02Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Ol0003o^[Zjoooooonj
^[[o000002gooooo001Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Qooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?oMgMgo`000?ooool08Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`04olc<
c?m4A4Co0000oa0@42;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01OnYZJWo410@o`000?l@413oZJVY02gooooo003oooooofWooooo003ooooo
ofWooooo003oooooof3ooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`00oooooomPooooo`05
oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00?ooooooH?ooool00ol0003oooooooooo`06ooooo`00
;Oooooooo`0002So00002oooool00ol0003oooooooooo`06ooooo`00=?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00Kooooo000dooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool0;Oooool00ol@413o0000o`000003o`0000Gooooo000dooooo`03o`000?oooooooooo
0?oooooo:Oooool00ol0003oooooooooo`06ooooo`00=?ooool00ol0003oooooooooo`3oooooobWo
oooo00?o0000ooooooooool01_ooool003Cooooo0_l0003ooooooc?ooooo000dooooo`03o`000?oo
oooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0
003oooooooooo`3ooooooc;ooooo000dooooo`;o0000oooooolcooooo`00=?ooool00ol0003ooooo
ooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000
ooooooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`;o
0000oooooolcooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oo
oooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool2o`00
0?oooooo<oooool003Cooooo00?o0000ooooooooool0oooooolbooooo`002_ooool01Om4A4Co0000
o`000?lb<S;ogMgM00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo0?oooooo<_ooool000gooooo00WoMgMgoc8b<_oooooooooo
ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`3ooooooc;ooooo000>ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`3ooooooc;ooooo000=oooo
o`05ogMgMolb<S;oooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`04ooooo`?o0000oooooolbooooo`002_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0?oooooo<_ooool000[ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooo
oooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolb
ooooo`002_ooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc;ooooo000:ooooo`Co0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l0
003ooooooc?ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000oooo
ooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`00
0?oooooooooo0?oooooo<_ooool003Cooooo0_l0003ooooooc?ooooo000dooooo`03o`000?oooooo
oooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003o
ooooooooo`3ooooooc;ooooo000dooooo`;o0000oooooolcooooo`00=?ooool00ol0003ooooooooo
o`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000oooo
ooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`;o0000
oooooolcooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo0002ooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo<_ooool000Cooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo<_oo
ool000Cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooo
oooo0?oooooo<_ooool000Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006oooo
o`?o0000oooooolbooooo`001?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0oooooolbooooo`001?ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooo
oooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooo
oooooooo410@00Kooooo00?o0000ooooooooool0oooooolbooooo`001?ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolbooooo`000_ooool0
0omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l0003ooooooc?ooooo000doooo
o`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00
=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_oo
ool003Cooooo0_l0003ooooooc?ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Co
oooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo
000dooooo`;o0000oooooolcooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000doooo
o`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00
=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`;o0000oooooolcooooo`00=?ooool0
0ol0003oooooooooo`3ooooooc;ooooo0002ooooo`Co000000Go410@ooooooooooooooooodA4A002
o`000009oc8b<_oMgMgoooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Kooooo00?o0000ooooooooool0oooooolbooooo`001?ooool00ol0003oooooooooo`06
ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool0oooooolbooooo`001?ooool00ol0003oooooooooo`07
ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01?ooool3o`000?oooooo<_ooool000Cooooo00?o0000ooooooooool01_ooool01OmgMgOo
<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooooc;ooooo0004ooooo`03o`000?oooooooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc;ooooo0004ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolbooooo`001?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo<_ooool000;ooooo00?o
EEEEofIVI_l000001Oooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`;o0000oooooolcooooo`00=?ooool00ol0003oooooooooo`3ooooo
oc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0
oooooolbooooo`00=?ooool2o`000?oooooo<oooool003Cooooo00?o0000ooooooooool0oooooolb
ooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oo
oooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool2o`000?oooooo<ooo
ool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooo
oc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo0_l0003ooooooc?ooooo
000dooooo`03o`000?oooooooooo0?oooooo<_ooool00003ooooool0003o000000?o00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo0?oooooo<_ooool00006oooooonHV9So8B4Q
onk^k_ooooooA4A40oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo<_oo
ool000;ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooo
oooo0?oooooo<_ooool000?ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006oooo
o`?o0000oooooolbooooo`001?ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0oooooolbooooo`001Oooool01Ol0003ooooooooooooooooo410@00?o
oooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool0
1Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0oooooolbooooo`0000Koooooo`000?nj^[[ooooo
oiRHV?l@4103ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooolbooooo`00
00KooooooiRHV?l@413o0000ob4Q8Oo<c<`3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l0003ooooo
oc?ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0
oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooo
oooo0?oooooo<_ooool003Cooooo0_l0003ooooooc?ooooo000dooooo`03o`000?oooooooooo0?oo
oooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003ooooooooo
o`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo0_l0003ooooo
oc?ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0
oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`;o0000oooooolc
ooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo00000ooooooo0000o`000003o`0000Co
oooo00GoA4A4o`000?l0003o<S8bomgMg@02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc;ooooo00001_ooooooV9RH
ob4Q8Oo^k^koooooodA4A0Oooooo00WoMgMgoc8b<_ooooooooooogMgMonHV9SooooooiRHV?mgMgL0
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooooc;ooooo0002oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00Co0000oooooooooooo410@0oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo<_ooool000?ooooo
00?oV9RHob4Q8Oo^k^h01oooool01OmgMgOo<S8boooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01?ooool3o`000?oooooo<_ooool000Cooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo<_ooool0
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05oa0@4?oooooooooo
ooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooo
oa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooooc;o
oooo00001_oooooo0000okZj^_ooooooV9RHoa0@40Cooooo00?o0000ooooooooool01?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool0oooooolbooooo`0000KooooooiRHV?l@413o0000ob4Q8Oo<c<`4ooooo`Co00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l0003ooooooc?o
oooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooo
oolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo
0?oooooo<_ooool003Cooooo0_l0003ooooooc?ooooo000dooooo`03o`000?oooooooooo0?oooooo
<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3o
oooooc;ooooo000dooooo`;o0000oooooolcooooo`00=?ooool00ol0003oooooooooo`3ooooooc;o
oooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooo
oolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`;o0000oooooolcoooo
o`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo00001_ooooooV9RHoa0@4?l0003o<S8bolc<
c0?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc;ooooo00001_oooooo
410@okZj^_ooooooMgMgoc8b<P?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3o
oooooc;ooooo0005ooooo`05o`000?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool3o`00
0?oooooo<_ooool000Cooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo0?oooooo<_ooool000?ooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?oooooo<_ooool000Cooooo00?o^[Zjob4Q8Oooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oooooo<_ooool00006ooooool@413o
V9RHoooooonj^[[o00000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo
<_ooool00006oooooonYZJWo410@o`000?l@413oZJVY0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooooh7o
0000<ooooolQo`0000gooooo=ol0000Kooooo`00=?ooool00ol0003oooooooooo`1noooooc?o0000
8Oooool=o`0005;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000
ooooooooool0oooooolbooooo`00=?ooool2o`000?oooooo<oooool003Cooooo00?o0000oooooooo
ool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oo
oooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool2o`00
0?oooooo<oooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003ooooo
ooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000
ooooooooool0oooooolbooooo`00=?ooool2o`000?oooooo<oooool003Cooooo00?o0000oooooooo
ool0oooooolbooooo`0000KooooooiRHV?l@413o0000oc8b<_o<c<`4ooooo`05odA4A?l0003o0000
oc8b<_oMgMd00_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo00?o0000ooooooooool0oooooolbooooo`0000Kooooooa0@4?nj^[[oooooogMgMolb<S87
ooooo`09ogMgMolb<S;ooooooooooomgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool0oooooolbooooo`001Oooool00ol0003oooooooooo`06
ooooo`04o`000?oooooooooooa0@40?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool01?ooool3o`000?oooooo<_ooool000Cooooo00?oZJVYoa0@4?ooool01_ooool01OmgMgOo
<S8boooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3ooooooc;ooooo0003ooooo`03oa0@4?l0003o^[Zj00Cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooooc;ooooo0004ooooo`03okZj^_lQ8B7o
oooo00?ooooo00?o0000ooooooooool01?ooool01Ol@413ooooooooooooooooo410@00?ooooo00Go
410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413o
oooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooolbooooo`0000Kooooooa0@4?nH
V9SooooookZj^_l00004ooooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo<_ooool00006
oooooonYZJWo410@o`000?l@413oZJVY1?ooool4o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`;o0000oooooolcooooo`00=?ooool00ol0003o
ooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o
0000ooooooooool0oooooolbooooo`00=?ooool2o`000?oooooo<oooool003Cooooo00?o0000oooo
ooooool0oooooolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`00
0?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool2
o`000?oooooo<oooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00=?ooool00ol0003o
ooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo0_l0
003ooooooc?ooooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool000?ooooo0_l000002Ol@
413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`3ooooooc;ooooo0004
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3o
oooooc;ooooo00000ooooooo0000o`000003o`0000?ooooo00Go410@oooooooooooooooooa0@4003
ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo
00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0
003oooooooooo`3ooooooc;ooooo00001OooooooA4A4omgMgOoooooo000000Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000001_ooool3o`000?oooooo<_ooool00005oooooooMgMgoEEEEooooool000001?ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`00003ooooooc_ooooo0002ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooo
oooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
4100oooooolkooooo`000_ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg0?oooooo
>oooool000?ooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP3ooooooc_ooooo002l
ooooo`06ob4Q8Ol0003o0000odA4A?oMgMgooooo0ol000000ol@413oooooooooo`2Pooooo`00_ooo
ool00omgMgOo<S8booooo`02ooooo`03oa0@4?nj^[[ooooo0:7ooooo0030ooooo`06o`000?oooooo
oooooooooonHV9So<S8bX_ooool005oooooo0_l00002ooooo`03oa0@4?l0003o000000;ooooo1Ol0
0002ooooo`04oa0@4?l0003o0000ooooo`;o000000Co410@ooooooo^k^koEEEE0_l000000om4A4Co
^[Zjooooo`02ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool5o`0000?ooooo00GoIVIVo`00
0?l0003oA4A4olc<c006ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0_ooool01?l@413o0000
o`000?ooool2o`000004oa0@4?ooooook^k^oeEEE@;o000000CoA4A4okZj^_oooooo410@1Ol00003
ooooo`06onk^k_mEEEGo0000oa0@4?o<c<co00000oooool00ooMgMgo0000okZj^P0;ooooo`03ob4Q
8Olb<S;ooooo00?ooooo00Sok^k^oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool0
1_l@413o<S8bo`000?l0003o410@ojVYZ@?ooooo00WoV9RHo`000?l0003oMgMgo`000?l@413ooooo
oa0@4?lb<S800_l000000ol@413oZJVYooooo`06ooooo`05oiRHV?l0003o0000odA4A?nj^[X00ooo
ool5o`000003ooooool0003o000000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o
000000?oA4A4okZj^_ooool0AOooool0063ooooo00Go0000ooooooo^k^ko<S8bolc<c005ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`06oeEEEOmgMgOooooo
onk^k_mgMgOo410@0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Gooooo00?o0000ooooooooool0
0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@40Kooooo00KoEEEEogMgMoooooook^k^ogMgMol@
4103ooooo`05o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@
40?ooooo00?o0000ooooooooool01?ooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000?ooooo00?o
EEEEogMgMom4A4@02_ooool01?nHV9So<S8boa0@4?nj^[X3ooooo`06oeEEEOmgMgOoooooonk^k_mg
MgOo410@0oooool00ol0003oooooooooo`04ooooo`06o`000?nYZJWooooooooooonj^[[o00000ooo
ool01Ol0003oZJVYoooooon7QhOo000000;ooooo00Ko0000ojVYZOoooooooooookZj^_l00007oooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41001Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00So0000oooooomEEEGoMgMgooooooo^k^koMgMgoa0@44Kooooo001Pooooo`04
o`000?nHV9So<S8bolc<c0Kooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00Ko
0000ooooooooooooooooonk^k_l00002ooooo`05omgMgOl@413oooooob4Q8OoMgMd02Oooool01?l@
413o^[ZjoiRHV?lb<S83ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
1Onj^[[oQhN7ofIVI_mVIVKo410@00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05okZj
^_n7QhOoIVIVofIVI_l@41001oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00001;ooooo`00H?ooool00ol0003o
410@oiRHV007ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002oooo
o`Ko00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02Oooool6o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`Ko00000oooool0
0ol0003oooooooooo`04ooooo`06o`000?ooooooooooooooooo^k^ko00000_ooool01OmVIVKoQhN7
oooooonHV9SoEEEE00Sooooo00KoV9RHoc8b<_oooooooooooa0@4?nj^[X2ooooo`Ko00000oooool0
0ol0003oooooooooo`04ooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h7ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooo000000Go0000A_ooool0063ooooo00Co0000onk^k_mEEEGoQhN71_ooool00ol0003ooooooooo
o`03ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b
<P?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`06ofIVI_mgMgOooooo
oooooon7QhOo00001_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00Go0000ohN7Qooo
ooooZJVYo`000002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool00ol0003o<S8bomgM
g@04ooooo`0:oeEEEOmgMgOoooooonk^k_mEEEGo0000ooooooo^k^ko0000onk^kP;ooooo00?o0000
omgMgOooool01Oooool00oo^k^ko0000omgMg@02ooooo`0:oiRHV?lb<S;ooooooooooomEEEGoQhN7
onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01?ooool01_l0003o^[Zjooooooo^k^ko
MgMgo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?nj^[[oooooonk^k_mg
MgOo00001oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00ko0000olc<
c?o<c<co0000ojVYZOoMgMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<TKooooo001Poooo
o`05o`000?ooooooA4A4o`000?l@41000oooool00ol@413o0000o`000004ooooo`03oa0@4?l0003o
MgMg00;o000000GoV9RHooooooooooook^k^oeEEE@02o`000004odA4A?o^k^kooooooa0@40Go0000
1?ooool00ol@413o0000o`000004ooooo`06onk^k_mVIVKo0000o`000?m4A4Co00001_ooool01_o^
k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00?o410@o`000?mgMgL00_l000001OnHV9Sooooooooo
ooo^k^koEEEE00;o000000CoA4A4onk^k_oooooooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42oooo
o`06onk^k_mEEEGo0000ob4Q8OnYZJWo00000_l@4102o`000004ooooool0003o0000oa0@40Kooooo
00?o410@o`000?l000000_ooool3o`000003ooooooo^k^koEEEE00;o000000CoA4A4onk^k_oooooo
oooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_oo
ool01?l@413o0000ooooooooool2o`0000;ooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00005oooo
o`03oa0@4?l0003o000000?o00001?ooool00ol@413o0000o`000003ooooo`0;oa0@4?l0003o8B4Q
o`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED00_l000000om4A4Cok^k^ooooo`15ooooo`00
H?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool0
H?ooool0063ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo05Kooooo001Oooooo`;o00002Oooool00ol@413oooooooooo`0Mooooo`03oa0@4?oooooo
oooo08;ooooo00?o410@ooooooooool0E_ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {221.375, 0}} -> {-0.0167958, -39614.6, \
0.000401908, 2752.6}}]
}, Open  ]],

Cell[TextData[{
  "The gas no longer collapses.  To understand this theoretically, consider \
the linearized version of the Navier-Stokes equations ",
  ButtonBox["(7.2.35)",
    ButtonData:>{"Chapter7.nb", "(7.2.35)"},
    ButtonStyle->"Hyperlink"],
  " -",
  ButtonBox["(7.2.37)",
    ButtonData:>{"Chapter7.nb", "(7.2.37)"},
    ButtonStyle->"Hyperlink"],
  "  for the gas, including the effect of gravity. The perturbed mass density \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\[Rho]\)]],
  ", velocity ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[Delta]", 
            StyleBox["u",
              FontWeight->"Bold",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  ", and gravitational potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\[Phi]\)]],
  " obey"
}], "Text",
  CellTags->"i:83"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[PartialD]\[Delta]\[Rho]\/\[PartialD]t\), "=", " ", 
          RowBox[{\(-\ \[Rho]\_o\), 
            RowBox[{"\[Del]", 
              RowBox[{"\[CenterDot]", 
                StyleBox[
                  RowBox[{"\[Delta]", 
                    StyleBox["u",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]]}]}]}]}], TraditionalForm]]],
  ",\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{\(\[Rho]\_o\), 
              FractionBox[
                RowBox[{"\[PartialD]", 
                  StyleBox[
                    RowBox[{"\[Delta]", 
                      StyleBox["u",
                        FontWeight->"Bold",
                        FontSlant->"Plain"]}]]}], \(\[PartialD]t\)]}], "=", 
            " ", \(\(-\ \[Del]\[Delta]p\) - \(\[Rho]\_o\) \
\[Del]\[Delta]\[Phi]\)}], ","}], TraditionalForm]]],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]p\  = \ \[Gamma] \( p\_o\/\[Rho]\_o\) \
\[Delta]\[Rho]\)]],
  ",\n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Del]\^2 \[Delta]\[Phi] = 
        4  \[Pi]\ G\ \[Delta]\[Rho]\)\(,\)\)\)]]
}], "NE3",
  CellTags->"(7.3.13)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`p\_o\)]],
  " are the equilibrium density and pressure of the uniform gas, we have \
neglected viscosity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta]\)]],
  " (our system is assumed to be dissipationless), and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " is the ratio of specific heats. If one Fourier-transforms these equations \
in space and time, one finds the following dispersion relation for sound \
waves in the gas (see the exercises):"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2 = \(c\^\(\(2\)\(\ \)\)\) k\^2 - 
          4\ \[Pi]\ G\ \[Rho]\_o\)]],
  ","
}], "NE3",
  CellTags->{"i:81", "(7.3.14)"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\@\(\[Gamma]\ p\_o/\[Rho]\_o\)\)]],
  " is the speed of sound.  A similar dispersion relation can also be derived \
directly from the collisionless Boltzmann equation, Eq. ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  "  (see the exercises). "
}], "Text"],

Cell[TextData[{
  "\tFor wavenumbers that are sufficiently small, the square of the wave \
frequency is negative; that is, the frequency is imaginary. There are two \
imaginary roots to Eq. ",
  ButtonBox["(7.3.14)",
    ButtonData:>{"Chapter7.nb", "(7.3.14)"},
    ButtonStyle->"Hyperlink"],
  " , ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\  = \ \(\[PlusMinus]\[ImaginaryI]\)\ \@\(4\ \
\[Pi]\ G\ \[Rho]\_o - \(c\^\(\(2\)\(\ \)\)\) k\^2\)\)]],
  ".  Waves of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\)\
\)]],
  " will then either grow or decay; but over time the growing wave will \
dominate. As a result, the equilibrium is unstable to waves with sufficiently \
small wavenumbers: "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`k\  < \ \@\(4  \[Pi]\ G\ \[Rho]\_o/c\^2\)\)]],
  " for instability."
}], "NE3",
  CellTags->"(7.3.15)"],

Cell[TextData[{
  "On the other hand, in our system",
  ",",
  " the minimum wavenumber that fits into our box is ",
  Cell[BoxData[
      \(TraditionalForm\`k\_min = \ 2\ \[Pi]/L\)]],
  ". Therefore, if ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(2\ \[Pi]/
            L\)\(\ \)\(>\)\(\@\(4  \[Pi]\ G\ \[Rho]\_o/c\^2\)\)\(\ \)\)\)]],
  ", the system is stable to all waves that can fit into the box.  Written as \
a condition on the sound speed, this becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`c\^2 \[GreaterEqual] \ \ \(G\ \[Rho]\_o\ \
L\^2\)\/\(\(\[Pi]\)\(\ \ \)\)\)]],
  " for stability."
}], "NE3",
  CellTags->"(7.3.16)"],

Cell[TextData[{
  "Roughly the same stability criterion holds for any cloud of size ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " and mean density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_o\)]],
  " in free space. Note that the ",
  "right-hand",
  " side is on the order of the escape velocity at the surface of such a \
system. The cloud will not collapse if the sound speed is on the order of the \
escape velocity. Since the sound speed  ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is on the order of the mean thermal speed of gas particles, this implies \
that a stable cloud will be diffuse, with particle speeds on the order of or \
even above the escape velocity.  This sort of final state is what we observed \
in our first simulation. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Rotation", "Section",
  CellTags->"c:39"],

Cell[TextData[{
  "\tNaturally occurring gas clouds have finite angular momentum, and as they \
collapse they rotate. The smaller the cloud's radius becomes, the faster the \
rotation. This can be understood by considering the angular momentum ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(L\_z\), " ", "=", " ", 
          RowBox[{
            OverscriptBox[
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], "^"], "\[CenterDot]", 
            RowBox[{\(\[Sum]\+i\), 
              RowBox[{
                SubscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "i"], " ", "\[Times]", 
                SubscriptBox[
                  StyleBox["p",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "i"]}]}]}]}], TraditionalForm]]],
  ". For a system rotating with uniform angular speed ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Omega]", Cell[""]}], TraditionalForm]]],
  " about the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-axis, we have ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["p",
              FontWeight->"Bold",
              FontSlant->"Plain"], "i"], "=", 
          RowBox[{"m", " ", "\[Omega]", " ", 
            OverscriptBox[
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], "^"], "\[Times]", 
            StyleBox[\(r\_i\),
              FontWeight->"Bold",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " and this implies ",
  Cell[BoxData[
      \(TraditionalForm\`L\_z = \ I\ \[Omega]\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`I = \[Sum]\+i 
            m\ r\_\(\(\[UpTee]\)\(\ \)\(i\)\)\%2\)]],
  " is the moment of inertia of the cloud, and  where ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{\(r\_\(\(\[UpTee]\)\(\ \)\(i\)\)\), " ", "=", " ", 
            RowBox[{"|", 
              RowBox[{
                OverscriptBox[
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"], "\[Times]", 
                StyleBox[
                  SubscriptBox["r", 
                    StyleBox["i",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], "|"}]}]}], TraditionalForm]]],
  ". As the cloud collapses, ",
  Cell[BoxData[
      \(TraditionalForm\`I\)]],
  " decreases and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " must increase to compensate so that ",
  Cell[BoxData[
      \(TraditionalForm\`L\_z\)]],
  " is conserved.  "
}], "Text"],

Cell[TextData[{
  "\tIf the cloud rotates sufficiently rapidly, it will not collapse, because \
the centrifugal force balances the gravitational attraction. For a uniform \
cylindrical cloud of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " and mass ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  " per unit length, an equilibrium will exist if"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \@\(2\ G\ \(\(M/R\^2\)\(\ \)\)\)\)]],
  "."
}], "NE3",
  CellTags->"(7.3.17)"],

Cell[TextData[{
  "In Cells ",
  ButtonBox["7.90",
    ButtonData:>"Cell 7.90",
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["7.92",
    ButtonData:>"Cell 7.92",
    ButtonStyle->"Hyperlink"],
  ", we simulate a cloud that is rotating at 70% of this rate.  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(m = 1/2; M = 40; 
    L = 1; \[CapitalDelta]x\  = \ \(\[CapitalDelta]y\  = \ 
        L/M\); \[CapitalDelta]t = 0.0012;\n\), "\[IndentingNewLine]", 
    \(\(Clear[r, p];\)\), "\n", 
    \(rad\  = \ 0.1; 
    r0 = Table[rp = Sqrt[Random[]]; 
        t = 2  Pi\ Random[]; { .5,  .5} + rad\ rp {Sin[t], Cos[t]}, {n, 1, 
          1000}];\n\), "\[IndentingNewLine]", 
    \(\(\[Omega]\  = \  .7\ Sqrt[2\ G\ \ Npart\ m/rad^2];\)\), "\n", 
    \(\(Npart = Length[r0];\)\), "\n", 
    \(\(vval[x_]\  := \ \[Omega] {\(-x[\([2]\)]\), x[\([1]\)]};\)\), "\n", 
    \(\(p0 = m\ Map[vval, r0];\)\), "\n", 
    \(px\  := \ Sum[\(p0[\([i]\)]\)[\([1]\)], {i, 1, Npart}]\ \), "\n", 
    \(py := \ Sum[\(p0[\([i]\)]\)[\([2]\)], {i, 1, Npart}]\ \), "\n", 
    \(\(mom\  = {px, py}/Npart;\)\), "\n", 
    \(\(\(p0\  = \ 
        Table[p0[\([i]\)]\  - \ mom, {i, 1, Npart}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(Timing[leapfrog[r0, p0, 50, \[CapitalDelta]t]]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.90"],

Cell[BoxData[
    \({68.76`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\(Table[
        ListPlot[r[n], PlotRange \[Rule] {{0, 1}, {0, 1}}, 
          AspectRatio \[Rule] 1], {n, 0, 50, 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.91"],

Cell[BoxData[
    \( (*\ simulation\ removed\ \ to\ save\ space\ *) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(ListPlot[Table[{n\ \[CapitalDelta]t, kineticenergy[n]}, {n, 0, 50}], 
        PlotJoined \[Rule] True, 
        PlotLabel \[Rule] \ "\<kinetic energy versus time\>", \ 
        AxesLabel \[Rule] {"\<t\>", "\<\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.92"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 15.873 -0.268776 5.2679e-06 [
[.18254 .0348 -12 -9 ]
[.18254 .0348 12 0 ]
[.34127 .0348 -12 -9 ]
[.34127 .0348 12 0 ]
[.5 .0348 -12 -9 ]
[.5 .0348 12 0 ]
[.65873 .0348 -12 -9 ]
[.65873 .0348 12 0 ]
[.81746 .0348 -12 -9 ]
[.81746 .0348 12 0 ]
[.97619 .0348 -12 -9 ]
[.97619 .0348 12 0 ]
[1.025 .0473 0 -6 ]
[1.025 .0473 10 6 ]
[.01131 .15266 -30 -4.5 ]
[.01131 .15266 0 4.5 ]
[.01131 .25801 -36 -4.5 ]
[.01131 .25801 0 4.5 ]
[.01131 .36337 -36 -4.5 ]
[.01131 .36337 0 4.5 ]
[.01131 .46873 -36 -4.5 ]
[.01131 .46873 0 4.5 ]
[.01131 .57409 -36 -4.5 ]
[.01131 .57409 0 4.5 ]
[.5 .63053 -80 0 ]
[.5 .63053 80 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .0473 m
.18254 .05355 L
s
[(0.01)] .18254 .0348 0 1 Mshowa
.34127 .0473 m
.34127 .05355 L
s
[(0.02)] .34127 .0348 0 1 Mshowa
.5 .0473 m
.5 .05355 L
s
[(0.03)] .5 .0348 0 1 Mshowa
.65873 .0473 m
.65873 .05355 L
s
[(0.04)] .65873 .0348 0 1 Mshowa
.81746 .0473 m
.81746 .05355 L
s
[(0.05)] .81746 .0348 0 1 Mshowa
.97619 .0473 m
.97619 .05355 L
s
[(0.06)] .97619 .0348 0 1 Mshowa
.125 Mabswid
.05556 .0473 m
.05556 .05105 L
s
.0873 .0473 m
.0873 .05105 L
s
.11905 .0473 m
.11905 .05105 L
s
.15079 .0473 m
.15079 .05105 L
s
.21429 .0473 m
.21429 .05105 L
s
.24603 .0473 m
.24603 .05105 L
s
.27778 .0473 m
.27778 .05105 L
s
.30952 .0473 m
.30952 .05105 L
s
.37302 .0473 m
.37302 .05105 L
s
.40476 .0473 m
.40476 .05105 L
s
.43651 .0473 m
.43651 .05105 L
s
.46825 .0473 m
.46825 .05105 L
s
.53175 .0473 m
.53175 .05105 L
s
.56349 .0473 m
.56349 .05105 L
s
.59524 .0473 m
.59524 .05105 L
s
.62698 .0473 m
.62698 .05105 L
s
.69048 .0473 m
.69048 .05105 L
s
.72222 .0473 m
.72222 .05105 L
s
.75397 .0473 m
.75397 .05105 L
s
.78571 .0473 m
.78571 .05105 L
s
.84921 .0473 m
.84921 .05105 L
s
.88095 .0473 m
.88095 .05105 L
s
.9127 .0473 m
.9127 .05105 L
s
.94444 .0473 m
.94444 .05105 L
s
.25 Mabswid
0 .0473 m
1 .0473 L
s
gsave
1.025 .0473 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .15266 m
.03006 .15266 L
s
[(80000)] .01131 .15266 1 0 Mshowa
.02381 .25801 m
.03006 .25801 L
s
[(100000)] .01131 .25801 1 0 Mshowa
.02381 .36337 m
.03006 .36337 L
s
[(120000)] .01131 .36337 1 0 Mshowa
.02381 .46873 m
.03006 .46873 L
s
[(140000)] .01131 .46873 1 0 Mshowa
.02381 .57409 m
.03006 .57409 L
s
[(160000)] .01131 .57409 1 0 Mshowa
.125 Mabswid
.02381 .07364 m
.02756 .07364 L
s
.02381 .09998 m
.02756 .09998 L
s
.02381 .12632 m
.02756 .12632 L
s
.02381 .179 m
.02756 .179 L
s
.02381 .20534 m
.02756 .20534 L
s
.02381 .23167 m
.02756 .23167 L
s
.02381 .28435 m
.02756 .28435 L
s
.02381 .31069 m
.02756 .31069 L
s
.02381 .33703 m
.02756 .33703 L
s
.02381 .38971 m
.02756 .38971 L
s
.02381 .41605 m
.02756 .41605 L
s
.02381 .44239 m
.02756 .44239 L
s
.02381 .49507 m
.02756 .49507 L
s
.02381 .52141 m
.02756 .52141 L
s
.02381 .54775 m
.02756 .54775 L
s
.02381 .02096 m
.02756 .02096 L
s
.02381 .60043 m
.02756 .60043 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -141 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(kinetic) show
111.000 13.000 moveto
(energy) show
153.000 13.000 moveto
(versus) show
195.000 13.000 moveto
(time) show
219.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .05146 m
.04286 .14674 L
.0619 .34345 L
.08095 .55589 L
.1 .60332 L
.11905 .44224 L
.1381 .23021 L
.15714 .0821 L
.17619 .01472 L
.19524 .02415 L
.21429 .10778 L
.23333 .25784 L
.25238 .42939 L
.27143 .52827 L
.29048 .48481 L
.30952 .34011 L
.32857 .19525 L
.34762 .10723 L
.36667 .08227 L
.38571 .10981 L
.40476 .1748 L
.42381 .2602 L
.44286 .34489 L
.4619 .40302 L
.48095 .40767 L
.5 .35323 L
.51905 .27161 L
.5381 .203 L
.55714 .16601 L
.57619 .15904 L
.59524 .1766 L
.61429 .21288 L
.63333 .25906 L
.65238 .30363 L
.67143 .33429 L
.69048 .34116 L
.70952 .32255 L
.72857 .28628 L
.74762 .24765 L
.76667 .22043 L
.78571 .20936 L
.80476 .21241 L
.82381 .22527 L
.84286 .24189 L
.8619 .25974 L
.88095 .27886 L
.9 .29352 L
.91905 .29713 L
.9381 .29004 L
.95714 .27729 L
Mistroke
.97619 .26268 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0.01, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo01co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Cooooo1?l000000ol@413oooooooooo`0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`Go00004_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnH
V9So410@o`000?lb<S;oc<c<017ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l000000ol@413oooooooooo`0@ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04oooo
o`05odA4A?l0003o0000oc8b<_oMgMd04Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?l@413oc<c<00ko
oooo000dooooo`03o`000?oooooooooo01cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool04Oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A401;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go410@okZj^_ooooooMgMgoc8b<P0A
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool04?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00kooooo000dooooo`03o`000?oooooooooo01cooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003o
ooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo
410@00Cooooo00?oV9RHob4Q8Oo^k^h04oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
410@oooooooooooooooooa0@4007ooooo`03o`000?oooooooooo00oooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool5o`0001;ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooooooo
o`0?ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?o
oooo00Go0000ooooooooooooooooo`00000>ooooo`00=?ooool00ol0003oooooooooo`0Looooo`05
o`000?ooooooooooooooool000002Oooool3o`0000?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Aooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooo
oooo000000Gooooo00?oV9RHob4Q8Oo^k^h04_ooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000ooooooooooooooooo`000006ooooo`03ojVYZOl@413ooooo013ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?ooooooooooooooool000000oooool01?m4A4CogMgMooooool0
000Cooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?oMgMgoc8b<_ooool04?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?nHV9SooooooiRHV?lQ8B403_ooool003Cooooo00?o0000
ooooooooool07?ooool01Ol0003ooooooooooooooooo000000Wooooo00Co0000ooooool0003o0000
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?ooooooooooooooool000001_ooool00omgMgOoIVIVooooo`0Aoooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
410@o`000?nj^[X04Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04omgMgOmEEEGoooooo`0001?ooooo00Go0000ooooooooooooooooo`00000;
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<017ooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003oEEEEo`000?l@413oc<c<00kooooo000dooooo`;o00007Oooool01Ol@413ooooooooooooooooo
410@00Wooooo00Oo0000ooooool@413oooooo`000?oooooo410@00Kooooo00?o0000ooooooooool0
4Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4007oooo
o`03o`000?oooooooooo013ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool00onj^[[o8B4Qooooo`0@ooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413ooooooooooooooooo410@00Cooooo00?oMgMgolc<c?l000004oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooo
oooo01?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@4100
0oooool00omEEEGoQhN7ooooo`0@ooooo`00=?ooool00ol0003oooooooooo`0Looooo`05ogMgMonH
V9SooooooiRHV?mgMgL02?ooool02?l0003ooooooooooomgMgOoV9RHooooool0003oMgMg1_ooool0
0ol0003oooooooooo`0Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go410@oiRHV?oooooo^[Zjo`00
000Aooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Co
oooo00?ok^k^odA4A?l000004oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`04ooooo`03o`000?oooooooooo01?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ooMgMgo410@oiRHV00@ooooo`00=?oo
ool00ol0003oooooooooo`0Looooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool01Ol0003ooooo
ooooooo^k^ko<S8b00;o000000?ok^k^ooooooooool00_ooool00omEEEGoIVIVo`00000Cooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c00Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Aooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?oMgMgo`000?ooool04_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co
00004_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04
ooooo`04olc<c?m4A4Co0000oa0@40kooooo000dooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`3oooooo`00=?ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0o_ooool003Cooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?Gooooo00GoV9RHo`000?l0
003oA4A4okZj^P04ooooo`00=?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0mOooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo000dooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3eooooo`03
o`000?oooooooooo00Kooooo000]oooooooo0000:?l0000;ooooo`03o`000?oooooooooo00Kooooo
000dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Gooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Ko
oooo000dooooo`03o`000?oooooooooo02Oooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0>ooooo`03
oa0@4?l0003o000000?o00001Oooool003Cooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo0?Cooooo00?o0000ooooooooool01_ooool003Cooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0??ooooo00?o
0000ooooooooool01_ooool003Cooooo0_l0000Wooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0o?ooool003Cooooo0_l0000Vooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0o?ooool003Cooooo0_l0000Vooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0o?ooool003Cooooo0_l0000Vooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
o?ooool003Cooooo0_l0000Uooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0nooo
ool003Cooooo00?o0000ooooool000009?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0c?ooool003Cooooo00?o0000ooooool000009?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0c?ooool003Co
oooo00?o0000ooooool000009?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooool00000cOooool003Cooooo00?o0000ooooool000009?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00003<ooooo`00
=?ooool00ol0003oooooo`00000Tooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0<[ooooo000dooooo`03o`000?oo
oooo000002?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0bOooool003Cooooo0_l000000ooooooo0000ooooo`0Q
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0<Wooooo000dooooo`04o`000?ooooooooooo`0002;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0b?ooool003Cooooo00Co0000oooooooooooo00008_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`37
ooooo`00=?ooool01?l0003oooooooooool0000Rooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0<Oooooo000doooo
o`04o`000?ooooooooooo`0002;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0aoooool003Cooooo00Co0000oooo
oooooooo00008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`36ooooo`00=?ooool01Ol0003ooooooooooooooooo
0000023ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0a_ooool003Cooooo0_l00002ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0a_ooool003Cooooo00Go0000ooooooooooooooooo`00000Poooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo0<Gooooo000dooooo`05o`000?ooooooooooooooool000008?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`35ooooo`00=?ooool01Ol0003ooooooooooooooooo0000023ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0aOooool003Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo0<Cooooo000dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`34ooooo`002Oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`34ooooo`002Oooool0
1OlQ8B7oV9RHoooooonHV9So8B4Q00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`34ooooo`002Oooool01Ol0003ooooooooooooooooo000000?ooooo00Go410@
oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o00000_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0<?ooooo0009ooooo`05oc8b<_nHV9SooooooiRH
V?lb<S800oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0<?o
oooo0009ooooo`05olc<c?l0003o0000o`000?o<c<`00oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo033ooooo0ol0002@ooooo`002Oooool01Ol@413o^[Zjoooo
oonj^[[o410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0/ooooo`?o00000oooool00ol0003oooooooooo`2=ooooo`002Oooool01Ol0003o^[Zjoooooonj
^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Z
ooooo`;o00001oooool00ol0003oooooooooo`2<ooooo`002Oooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Roooool003Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2:ooooo`00=?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo08Wooooo000dooooo`;o00001?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`29ooooo`00=?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08Sooooo000dooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0R?ooool003Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`27ooooo`00=?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08Oooooo
000dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Q_ooool003Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`26ooooo`00=?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo08Kooooo000dooooo`;o00001Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`25ooooo`00
=?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo033ooooo1Ol0001@ooooo`00=?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02gooooo0_l00005ooooo`?o0000COoo
ool003Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0[ooooo`;o00002_ooool2
o`0004_ooooo000dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0<ooooo`;o0000BOooool003Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0A_ooool003Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0AOooool003Cooooo0_l00006ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`14ooooo`00=?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`13
ooooo`00=?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`12ooooo`00=?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`11ooooo`00
=?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`10ooooo`000_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h3ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0oooooo`001?ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0?_ooool000Cooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03gooooo0004ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000001_ooool3o`0000Gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03cooooo0004ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool08Oooool2o`0001oooooo0_l0000Kooooo`001?ooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Kooooo`001?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Looooo`000_ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Mooooo`00=?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01kooooo000doooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Yoooo
o`;o00004oooool2o`00027ooooo000dooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00kooooo0_l0000Sooooo`00
=?ooool2o`0000Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00_ooooo0_l0000Uooooo`00=?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`;o00009ooo
ool003Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo033ooooo1?l00003ooooo`?o0000:Oooool003Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo03Cooooo0ol0000/ooooo`00=?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0I?ooool003Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo06Cooooo
000dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1Uooooo`00=?ooool2o`0000Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1V
ooooo`00=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0I_ooool003Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo06Oooooo000dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`1Wooooo`00=?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0J?ooool003Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo06Wooooo000dooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Zooooo`00=?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0^ooooo`?o00001Oooool00ol0003oooooooooo`1[ooooo`00=?ooool2o`0000Wooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo037ooooo
0ol000000ooooooo0000ooooo`1]ooooo`00=?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo06gooooo000dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:Cooooo000dooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0:Cooooo000dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo0:Gooooo0002ooooo`Co000000?o410@ooooooooool0
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`2Uooooo`001?ooool00ol0003oooooooooo`02ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0YOooool000Cooooo00?o0000ooooooooool00oooool00onH
V9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`2Vooooo`001?ooool00ol0003oooooooooo`04ooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`?o00002Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0Y_ooool000Cooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`02
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`2Vooooo`001?ooool00ol0003oooooooooo`06ooooo`05o`000?oooooooooooooo
ool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@
4003ooooo`05oa0@4?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo0:Oooooo0004ooooo`03o`000?oooooooooo00;ooooo00Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`2Wooooo`000_ooool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0Yoooool003Cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Z?ooool003Co
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0Z?ooool003Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0ZOooool003Cooooo0_l0
000:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`2Yooooo`00=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`2Yooooo`00=?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Zoooo
o`00=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`2Zooooo`00=?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo02cooooo1?l00003ooooo`03o`000?oooooooooo0:[ooooo000dooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0<?ooool3o`000:gooooo000dooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0h?ooool003Cooooo0_l0000;ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
0>3ooooo000dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0h?ooool003Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`3Pooooo`00=?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo0>3ooooo000dooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0hOooool003Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3Qoooo
o`00=?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0>7ooooo000dooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0hOooool003Cooooo0_l0000<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo0>7ooooo000dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0hOooool0
03Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3Qooooo`00=?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo0>;ooooo000dooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0h_ooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o000000Wo
410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0>;ooooo0004ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3R
ooooo`001?ooool00ol0003oooooooooo`02ooooo`Go00000oooool01Ol@413ooooooooooooooooo
410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100
0oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`3Rooooo`001?ooool00ol0003oooooooooo`02ooooo`04odA4A?oMgMgoooooo`0000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
2oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`3Rooooo`001?ooool00ol0003oooooooooo`02ooooo`04omgMgOmE
EEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0h_ooool000Cooooo00?o0000
ooooooooool00oooool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05
oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0>?ooooo0004ooooo`03o`000?oooooooooo00?ooooo00?ok^k^odA4A?l000001?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3Sooooo`000_ooool00omEEEGoIVIVo`000006ooooo`03ogMgMol0
003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0hoooool003Cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3Sooooo`00=?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0>?ooooo000dooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
i?ooool003Cooooo0_l0000=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>Cooooo000dooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0i?ooool003Cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`3Uooooo`00=?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0:oooool01Ol0003ooooooooooooooooo00000>Oooooo000dooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0[ooooo`04
o`000?ooooooooooo`000>Sooooo000dooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0/ooooo`04o`000?ooooooooooo`000>Sooooo000dooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooo00000>Wooooo000dooooo`;o00003_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooool00000jOooool003Cooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo0_l0003Yooooo`00=?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`3Xooooo`00=?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0oooooolIooooo`00=?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolIooooo`00=?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolJooooo`00=?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oolJooooo`00=?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooolJooooo`00=?ooool2o`0000oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3ooooooa[ooooo000dooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3ooooooa[ooooo000dooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooa[ooooo000dooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooa[ooooo000d
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
oooooa[ooooo0002ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o410@olc<c0?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooooa_ooooo0004
ooooo`03o`000?oooooooooo00;ooooo00GoEEEEogMgMoooooooV9RHob4Q8@03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolKooooo`001?ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@
41000oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo6oooool000Cooooo00?o0000oooooooo
ool00_ooool01Ol0003oV9RHoooooonHV9So8B4Q00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o00004?ooool01Ol0003ooooooooooooooooo0000
0?oooooo7Oooool000Cooooo00?o0000ooooooooool00_ooool01Ol0003oEEEEo`000?l@413oc<c<
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00003ooooooagooooo0004ooooo`03
o`000?oooooooooo00;ooooo00?oEEEEohN7Qoooool01Oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41000ooo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool04Oooool01?l0003ooooo
ooooool0003ooooooagooooo0004ooooo`03o`000?oooooooooo00;ooooo00?ogMgMoa0@4?nHV9P0
1Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool04Oooool01?l0003oooooooooool0003ooooooagooooo0002ooooo`03oeEEEOmV
IVKo000000Gooooo00Coc<c<odA4A?l0003o410@0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool04Oooool01?l0003ooooooooo
ool0003ooooooagooooo000dooooo`03o`000?oooooooooo01;ooooo0_l0003ooooooakooooo000d
ooooo`03o`000?oooooooooo01;ooooo0_l0003ooooooakooooo000dooooo`03o`000?oooooooooo
01;ooooo0_l0003ooooooakooooo000dooooo`;o00005?ooool00ol0003oooooooooo`3ooooooaco
oooo000dooooo`03o`000?oooooooooo0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooo
oolbooooo`00=?ooool00ol0003oooooooooo`3ooooooc;ooooo000dooooo`03o`000?oooooooooo
0?oooooo<_ooool003Cooooo00?o0000ooooooooool0oooooolbooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00_?ooool01_lQ8B7o0000o`000?m4A4CogMgM
ooooo`?o000000?o410@ooooooooool0X?ooool00;oooooo00?oMgMgoc8b<_ooool00_ooool00ol@
413o^[Zjooooo`2Qooooo`00`?ooool01_l0003oooooooooooooooooV9RHoc8b<Z;ooooo001Ooooo
o`;o00000_ooool00ol@413o0000o`000002ooooo`Go00000_ooool01?l@413o0000o`000?ooool2
o`000004oa0@4?ooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`00
0?m4A4Co^[Zj00?ooooo1Ol00003ooooo`05ofIVI_l0003o0000odA4A?o<c<`01_ooool01_o^k^ko
EEEEo`000?l0003oA4A4okZj^P;ooooo00Co410@o`000?l0003ooooo0_l000001?l@413oooooonk^
k_mEEED2o`000004odA4A?nj^[[ooooooa0@40Go00000oooool01_o^k^koEEEEo`000?l@413oc<c<
o`0000?ooooo00?ogMgMo`000?nj^[X02oooool00olQ8B7o<S8booooo`03ooooo`08onk^k_mEEEGo
0000o`000?m4A4Co^[Zjooooool@4105o`0000?ooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT3
ooooo`09oiRHV?l0003o0000ogMgMol0003o410@ooooool@413o<S8b00;o000000?o410@ojVYZOoo
ool01_ooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo1Ol000000ooooooo0000o`000002oooo
o`07o`000?ooooooooooo`000?l@413ok^k^oeEEE@02o`000003odA4A?nj^[[ooooo04Gooooo001P
ooooo`05o`000?ooooook^k^oc8b<_o<c<`01Oooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00Go410@okZj
^_o^k^koMgMgoa0@4005ooooo`03o`000?oooooooooo00;ooooo00KoIVIVogMgMoooooooooooohN7
Qol@4106ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool01Ol0003ooooooooooooooooo
000000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103ooooo`03o`000?oooooooooo00Cooooo
00KoEEEEogMgMoooooook^k^oeEEEOl00003ooooo`03oeEEEOmgMgOoA4A400[ooooo00CoV9RHoc8b
<_l@413o^[Zj0oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool0
1?ooool01_l0003oZJVYoooooooooooo^[Zjo`0000?ooooo00Go0000ojVYZOooooooQhN7o`000002
ooooo`06o`000?nYZJWooooooooooonj^[[o00001oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Go
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooEEEE
ogMgMoooooook^k^ogMgMol@4116ooooo`00H?ooool01?l0003oV9RHoc8b<_o<c<`6ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`04ooooo`06o`000?ooooooooooooooooo^k^ko00000_oo
ool01OoMgMgo410@oooooolQ8B7ogMgM00Wooooo00Co410@okZj^_nHV9So<S8b0oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4003oooo
o`05o`000?ooooooooooooooool000000oooool01Onj^[[oQhN7ofIVI_mVIVKo410@00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooool00000Boooool0063ooooo00?o0000oa0@4?nHV9P01oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000000_ooool6o`0000?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo1_l00003ooooo`05o`00
0?ooooooooooooooool000000_ooool6o`0000?ooooo00?o0000ooooooooool01?ooool01_l0003o
ooooooooooooooook^k^o`0000;ooooo00GoIVIVohN7QoooooooV9RHoeEEE@08ooooo`06oiRHV?lb
<S;oooooooooool@413o^[Zj0_ooool6o`0000?ooooo00?o0000ooooooooool01?ooool01_lb<S;o
8B4QogMgMomgMgOoQhN7onk^kP?ooooo00Go0000ooooooooooooooooo`000002ooooo`06oc8b<_lQ
8B7oMgMgogMgMon7QhOok^k^1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000005o`0004Kooooo001Pooooo`04
o`000?o^k^koEEEEohN7Q`Kooooo00?o0000ooooooooool00oooool01Ol0003oQhN7oooooonYZJWo
000000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool01_mVIVKoMgMgooooooooooooQhN7o`0000Kooooo00KoEEEEohN7
Qoo^k^koooooohN7Qolb<S83ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool01_mEEEGoQhN7
onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01?ooool02_mEEEGoMgMgooooooo^k^ko
EEEEo`000?ooooook^k^o`000?o^k^h2ooooo`03o`000?oMgMgooooo00Gooooo00?ok^k^o`000?oM
gMd00_ooool02_nHV9So<S8booooooooooooEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`00
0?lb<S;ogMgM00Cooooo00Ko0000okZj^_ooooook^k^ogMgMol00003ooooo`05o`000?oooooooooo
ooooool000000_ooool01_l0003o^[Zjooooooo^k^koMgMgo`0000Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`0>o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8Ooooooo
EEEEohN7Qoo^k^koooooohN7Qolb<S96ooooo`00H?ooool01Ol0003oooooodA4A?l0003o410@00?o
oooo00?o410@o`000?l000001?ooool00ol@413o0000ogMgM`02o`000005oiRHV?ooooooooooonk^
k_mEEED00_l000001?m4A4Cok^k^ooooool@4105o`0000Cooooo00?o410@o`000?l000001?ooool0
1_o^k^koIVIVo`000?l0003oA4A4o`0000Kooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2oooo
o`03oa0@4?l0003oMgMg00;o000000GoV9RHooooooooooook^k^oeEEE@02o`000004odA4A?o^k^ko
ooooooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool01_o^k^koEEEEo`000?lQ8B7oZJVYo`00
00;o410@0_l000001?oooooo0000o`000?l@4106ooooo`03oa0@4?l0003o000000;ooooo0ol00000
0oooooook^k^oeEEE@02o`000004odA4A?o^k^koooooooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q
0_ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Co410@o`000?oooooooooo0_l00002
ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00001Oooool00ol@413o0000o`000003o`0000Cooooo
00?o410@o`000?l000000oooool02ol@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^
k^koEEEE00;o000000?oA4A4onk^k_ooool0AOooool0063ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`22ooooo`03o`000?oooooooooo063ooooo001Pooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
07Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Fooooo`00Goooool2o`0000Wo
oooo00?o410@ooooooooool07Oooool00ol@413oooooooooo`22ooooo`03oa0@4?oooooooooo05Ko
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{3.5625, 359}, {221.375, 0}} -> {-0.0111972, 43891.9, \
0.000267939, 807.341}}]
}, Open  ]],

Cell["\<\
Collapse still occurs to some extent, but is moderated by the \
cloud's rotation. The final state is considerably less dense at the center \
than what one would obtain from the same initial condition without rotation \
(try it). \
\>", "Text"],

Cell[TextData[{
  "\tNote, also, the formation of spiral arms during the evolution. Spiral \
arms can be observed in many galaxies (see Fig. ",
  ButtonBox["7.9",
    ButtonData:>"Fig. 7.9",
    ButtonStyle->"Hyperlink"],
  "). These spiral structures can be understood from conservation of angular \
momentum. During the collapse, filaments of high density are thrown out from \
the core. As these filaments move to larger radius, conservation of angular \
momentum implies that they must slow their rotation. As result, the filaments \
are wound around the core, producing the spiral arms. (The formation of \
spiral arms is still a subject of some debate, and may be influenced by many \
effects beyond the scope of this simple explanation.)"
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 7.3", "Subsubtitle",
  CellTags->"c:40"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Using the linearized Navier-Stokes equations ",
  ButtonBox["(7.3.13)",
    ButtonData:>{"Chapter7.nb", "(7.3.13)"},
    ButtonStyle->"Hyperlink"],
  " , derive the dispersion relation for sound waves in a self-gravitating \
gas, Eq. ",
  ButtonBox["(7.3.14)",
    ButtonData:>{"Chapter7.nb", "(7.3.14)"},
    ButtonStyle->"Hyperlink"],
  " ."
}], "Text"],

Cell[TextData[{
  StyleBox["(2)(a)",
    FontWeight->"Bold"],
  "  Solve Poisson's equation for a uniform cylindrical cloud of density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_o\)]],
  " and radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " to find the gravitational potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r)\)]],
  "  both inside and outside the cloud. Use this result to prove Eq. ",
  ButtonBox["(7.3.17)",
    ButtonData:>{"Chapter7.nb", "(7.3.17)"},
    ButtonStyle->"Hyperlink"],
  "  for the equilibrium of a rotating cylindrical cloud. As a test of the \
FFT code, simulate this uniform cloud with 1000 particles, radius ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(R\)\(\ \)\(=\)\(\ \)\(0.25\)\(\ \)\)\)]],
  "(taking ",
  Cell[BoxData[
      \(TraditionalForm\`L = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`M = 40\)]],
  "), and plot the potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " obtained from the FFT vs. radius ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " from the cloud center, along with the analytic result, for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < r < 0.5\)]],
  ". Discuss reasons for any deviations from the analytic result that you \
observe."
}], "Text"],

Cell[TextData[{
  StyleBox["(3)(a)",
    FontWeight->"Bold"],
  "  The Jeans instability can also be understood from the linearized \
versions of the Poisson-Boltzmann equations ",
  ButtonBox["(7.3.1)",
    ButtonData:>{"Chapter7.nb", "(7.3.1)"},
    ButtonStyle->"Hyperlink"],
  " -",
  ButtonBox["(7.3.2)",
    ButtonData:>{"Chapter7.nb", "(7.3.2)"},
    ButtonStyle->"Hyperlink"],
  " . If we assume that ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f(x, p\_x, \(p\_y\) t)\), "=", 
          RowBox[{\(\(f\_o\)(p\_x, p\_y)\), " ", "+", " ", 
            RowBox[{"\[Delta]", 
              RowBox[{
                StyleBox[
                  OverscriptBox[
                    StyleBox["f",
                      FontSlant->"Italic"], "~"],
                  FontSlant->"Italic"], "(", \(p\_x, p\_y\), ")"}], 
              " ", \(\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\  - \ \
\[ImaginaryI]\ \[Omega]\ t\)\)}]}]}], TraditionalForm]]],
  ", then show that Eqs. ",
  ButtonBox["(7.1.31)",
    ButtonData:>{"Chapter7.nb", "(7.1.31)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.1.32)",
    ButtonData:>{"Chapter7.nb", "(7.1.32)"},
    ButtonStyle->"Hyperlink"],
  "  become"
}], "Text",
  CellTags->"i:82"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"(", 
                RowBox[{\(\(-\[ImaginaryI]\)\ \[Omega]\), " ", "+", " ", 
                  RowBox[{"\[ImaginaryI]", " ", "k", " ", 
                    StyleBox[
                      FractionBox[
                        StyleBox[
                          SubscriptBox[
                            StyleBox["p",
                              FontSlant->"Italic"], "x"],
                          FontSlant->"Plain"], "m"],
                      FontSlant->"Plain"]}]}], ")"}], "\[Delta]", 
              StyleBox[
                OverscriptBox[
                  StyleBox["f",
                    FontSlant->"Italic"], "~"],
                FontSlant->"Italic"]}], "-", 
            RowBox[{"m", " ", "\[ImaginaryI]", " ", "k", " ", "\[Delta]", 
              StyleBox[
                OverscriptBox[
                  StyleBox["\[Phi]",
                    FontSlant->"Plain"], "~"],
                
                FontSlant->
                  "Italic"], \(\[PartialD]f\_o\/\[PartialD]p\_x\)}]}], "=", 
          "0"}], TraditionalForm]]],
  ", \n",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Delta]  \[Phi]\&~\), "=", 
          RowBox[{\(-\(\(4  \[Pi]\ G\ m\)\/k\^2\)\), 
            RowBox[{"\[Integral]", 
              RowBox[{"\[Delta]", 
                StyleBox[
                  OverscriptBox[
                    StyleBox["f",
                      FontSlant->"Italic"], "~"],
                  FontSlant->"Italic"], \(\[DifferentialD]\^2 p\)}]}]}]}], 
        TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(7.3.18)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Delta]", 
          RowBox[{
            StyleBox[
              OverscriptBox[
                StyleBox["\[Phi]",
                  FontSlant->"Plain"], "~"],
              FontSlant->"Italic"], "(", \(k, \[Omega]\), ")"}]}], 
        TraditionalForm]]],
  " is the Fourier transform of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\[Phi]\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Show that Eqs. ",
  ButtonBox["(7.3.18)",
    ButtonData:>{"Chapter7.nb", "(7.3.18)"},
    ButtonStyle->"Hyperlink"],
  "  lead to the following dispersion relation:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`1\  + \ \(\(4  \[Pi]\ G\ m\^3\)\/k\^2\) \
\(\[Integral]\(\(\[PartialD]f\_o/\[PartialD]p\_x\)\/\(p\_x - 
                      m\ \[Omega]/k\)\) \[DifferentialD]\^2 p\) = 0\)]],
  "."
}], "UNNEQ"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " We previously simulated a case where the equilibrium velocity \
distribution is given by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(f\_o\)(p\_x, p\_y) = \ 
        N\/\((m\ V\ L)\)\^2\ \ for | 
          p\_x | \(\(<\)\(\ \)\(m\ V\ \ and\)\)\  | 
          p\_y | \(\(<\)\(m\ V\)\)\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      FormBox[Cell[TextData[{
          " ",
          Cell[BoxData[
              \(TraditionalForm\`f\_o = 0\)]],
          " "
        }]], TraditionalForm]]],
  "otherwise.  Show that for this velocity distribution the dispersion \
relation works out to be"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2\  = \ 
        V\^2\ k\^2 - \ 4\ \[Pi]\ G\ \[Rho]\_o\)]],
  ", "
}], "UNNEQ"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\_o = \ m\ N/L\^2\)]],
  " is the average mass density. What is the minimum value of ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  ",",
  " ",
  Cell[BoxData[
      \(TraditionalForm\`V\_min\)]],
  ", that allows a stable distribution in our simulation? For the simulation \
run in the above examples,  with ",
  Cell[BoxData[
      \(TraditionalForm\`V = 30\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`N = 1000\)]],
  ", should the simulation be stable or unstable? "
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Repeat the simulation taking ",
  Cell[BoxData[
      \(TraditionalForm\`V\  = \ 0.8\ V\_min\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`V\  = \ 1.2\ V\_min\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(4)(a)",
    FontWeight->"Bold"],
  " Simplify the code so that only motion in one dimension is considered,  \
where ",
  Cell[BoxData[
      \(TraditionalForm\`f = f(x, p, t)\)]],
  ". (This requires determination of the correct equivalent of  area \
weighting for a one-dimensional grid.) Test the code by running cases with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\)\(=\)\(1000\)\(\ \)\)\)]],
  "particles distributed randomly on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < L\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`M = 40\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`L = \(m = \(G = 1\)\)\)]],
  ", and\n (i) ",
  Cell[BoxData[
      \(TraditionalForm\`V\  = \ 0.8\ V\_min\)]],
  " (unstable) \n ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((ii)\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`V = 1.2\ V\_min\)]],
  " (stable). \nMake animations of the density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x, t)\)]],
  ", evaluated from your position data. Check energy and momentum \
conservation. "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " In equilibrium, we expect that the distribution function will be a \
function only of the energy: "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`f = f(p\^2/2  m\  + \ m\ \[Phi])\)]]], "NE3",
  CellTags->"(7.3.19)"],

Cell[TextData[{
  "(in a frame where the center of mass is stationary). This is the same \
equilibrium distribution as we studied for the case of particles in a given \
external field; see Eq. ",
  ButtonBox["(7.1.25)",
    ButtonData:>{"Chapter7.nb", "(7.1.25)"},
    ButtonStyle->"Hyperlink"],
  " . However, now the problem is much more difficult, because the potential \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[Phi]\)\)\)]],
  " is determined in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " itself. Nevertheless, we can test whether the final state observed from \
the evolution of an unstable initial condition satisfies this result. To do \
so, make a 2-D histogram in phase space ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, p)\)\)]],
  " of the end result of the simulation in Exercise (4)(a)(i) using the ",
  StyleBox["BinCounts ",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, available in the ",
  StyleBox["Statistics",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " add-on package.  The syntax is"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{"BinCounts", "[", 
          
          RowBox[{\({{x\_1, p\_1}, {x\_2, p\_2}, \(\(...\)\(.\)\), {x\_N, 
                p\_N}}\), ",", 
            RowBox[{"{", 
              RowBox[{"0", ",", "L", ",", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["x",
                      FontSlant->"Italic"]}]]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{\(-P\), ",", "P", ",", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["p",
                      FontSlant->"Italic"]}]]}], "}"}]}], "]"}], 
        TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["x",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " and \[CapitalDelta]",
  Cell[BoxData[
      StyleBox["p",
        FontSlant->"Italic"]]],
  " are the sizes of the bins in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " respectively, and where ",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  " is a maximum momentum, chosen from your data to capture all (or at least  \
most) of the distribution function. The result  is a list of the number of \
points in each bin. This number is ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(f\_\(i\ j\)\), "\[Congruent]", 
          RowBox[{\(f(x\_i, \ p\_j)\), " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["x",
                  FontSlant->"Italic"]}]], " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["p",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\_i, p\_j)\)\)]],
  " is the center of a bin.  Take ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["x",
                FontSlant->"Italic"]}]], " ", "=", " ", \(\(L/10\)\(\ \)\)}], 
        TraditionalForm]]],
  "and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["p",
                FontSlant->"Italic"]}]], " ", "=", " ", \(P/10\)}], 
        TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tAccording to Eq. ",
  ButtonBox["(7.3.19)",
    ButtonData:>{"Chapter7.nb", "(7.3.19)"},
    ButtonStyle->"Hyperlink"],
  " , ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " is a function only of ",
  Cell[BoxData[
      \(TraditionalForm\`E = \ p\^2/2  m\  + \ m\ \(\[Phi](x)\)\)]],
  " in equilibrium. Test this for your final state by evaluating ",
  Cell[BoxData[
      \(TraditionalForm\`E\_\(i\ j\) = 
        p\_j\^2/2  m\  + \ m\ \(\[Phi](x\_i)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " is determined from ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " using the FFT. Make a data table of ",
  Cell[BoxData[
      \(TraditionalForm\`{E\_\(i\ j\), \ f\_\(i\ j\)}\)]],
  " values, and plot them via a ",
  StyleBox["ListPlot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". If you have achieved an equilibrium, the points should all fall on a \
single curve, which defines the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(E)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " ",
  StyleBox["SIMULATION PROJECT: 2D FLUID DYNAMICS",
    FontSlant->"Italic"],
  " . The PIC method is also used in the study of 2-dimensional  \
incompressible fluids.  Two examples of  fluids that are approximately 2D are \
soap films, and planetary atmospheres and oceans (for flows whose horizontal \
scale is large compared to the atmosphere's thickness or the ocean's depth, \
such as the jet stream or large scale ocean currents).  The following project \
allows a student to  study several aspects of 2D fluid flows. "
}], "Text",
  CellTags->"i:65"],

Cell["\<\
\tThe equations of motion for such fluids are the momentum \
equation,\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{\(\[PartialD]\/\[PartialD]t\), 
              StyleBox["u",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], "+", 
            RowBox[{
              StyleBox["u",
                FontWeight->"Bold",
                FontSlant->"Plain"], "\[CenterDot]", 
              RowBox[{"\[Del]", 
                StyleBox["u",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]}]}], " ", "=", 
          " ", \(\(-\(1\/\[Rho]\)\) \[Del]p\)}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(7.3.20)"],

Cell["\<\
(assuming the flow is unforced) and the constraint equation for \
incompressible flow,\
\>", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Del]", 
            RowBox[{"\[CenterDot]", 
              RowBox[{
                StyleBox["u",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["(",
                  FontWeight->"Plain"], 
                StyleBox[\(x, y, t\),
                  FontWeight->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox["0",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". "
}], "NE3",
  CellTags->"(7.3.21)"],

Cell[TextData[{
  "  In order to solve these equations,  we note that Eq. ",
  ButtonBox["(7.3.21)",
    ButtonData:>{"Chapter7.nb", "(7.3.21)"},
    ButtonStyle->"Hyperlink"],
  "  implies that ",
  Cell[BoxData[
      FormBox[
        StyleBox["u",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " can be written in terms of a ",
  StyleBox["stream function",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Psi](x, y, t)\)\(:\)\)\)]]
}], "Text",
  CellTags->"i:64"],

Cell[TextData[{
  "  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["u",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox[
            RowBox[{
              OverscriptBox[
                StyleBox["z",
                  FontWeight->"Plain"], "^"], "\[Times]", \(\[Del]\[Psi]\)}],
            FontWeight->"Plain"]}], TraditionalForm]]]
}], "NE3",
  CellTags->"(7.3.22)"],

Cell[TextData[{
  "(The divergence of ",
  Cell[BoxData[
      FormBox[
        StyleBox["u",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " is then guaranteed to equal zero.) At any given instant of time, ",
  Cell[BoxData[
      FormBox[
        StyleBox["u",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " points along contours of constant ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  ". In order to solve for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  ", we take the curl of Eq. ",
  ButtonBox["(7.3.20)",
    ButtonData:>{"Chapter7.nb", "(7.3.20)"},
    ButtonStyle->"Hyperlink"],
  " , and then dot the result with ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"], "^"], TraditionalForm]]],
  ". After some work with vector identities, one obtains"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\(\[PartialD]\/\[PartialD]t\) \[Zeta]\), "+", 
            RowBox[{
              StyleBox["u",
                FontWeight->"Bold",
                FontSlant->"Plain"], "\[CenterDot]", \(\[Del]\[Zeta]\)}]}], 
          " ", "=", "0"}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(7.3.23)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Zeta]",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              StyleBox[
                OverscriptBox[
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"],
                FontWeight->"Plain"], "\[CenterDot]", "\[Del]"}], "\[Times]", 
            
            StyleBox["u",
              FontWeight->"Bold",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  " is the ",
  StyleBox["vorticity ",
    FontSlant->"Italic"],
  " of the flow. The vorticity  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Zeta]", "(", \(x, y, t\), 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " can be thought of as a measure of the rotation rate of a fluid element at \
",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " about its own center. According to Eq. ",
  ButtonBox["(7.3.23)",
    ButtonData:>{"Chapter7.nb", "(7.3.23)"},
    ButtonStyle->"Hyperlink"],
  " , vorticity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)]],
  " is transported without change along characteristics given by ",
  Cell[BoxData[
      FormBox[
        StyleBox["u",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ":"
}], "Text",
  CellTags->"i:66"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x\/\[DifferentialD]t = \ \(\(u\_x\)(
            x, y, t) = \(-\(\[PartialD]\[Psi]\/\[PartialD]y\)\)\)\)]],
  ",\n",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]y\/\[DifferentialD]t = \(\(u\_y\)(x, 
            y, t) = \ \ \(\(\[PartialD]\[Psi]\/\[PartialD]x\)\(\ \
\)\(.\)\)\)\)]]
}], "NE3",
  CellTags->"(7.3.24)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(7.3.23)",
    ButtonData:>{"Chapter7.nb", "(7.3.23)"},
    ButtonStyle->"Hyperlink"],
  "  is analogous to the Boltzmann equation. If we know the flow field ",
  Cell[BoxData[
      FormBox[
        StyleBox["u",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", then we can take the curl of this field to determine the vorticity, and \
populate a 2D area with a collection of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " particles (\"point vortices\") that are distributed according to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)]],
  ".  We can follow the resulting motion of these particles by solving Eqs. \
",
  ButtonBox["(7.3.24)",
    ButtonData:>{"Chapter7.nb", "(7.3.24)"},
    ButtonStyle->"Hyperlink"],
  " .  Since vorticity has dimensions of frequency, we assign a quantity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " to each particle (analogous to mass), with dimensions of ",
  Cell[BoxData[
      \(TraditionalForm\`area\ per\ unit\ time\)]],
  ". This quantity is called the ",
  StyleBox["circulation",
    FontSlant->"Italic"],
  " of the point vortex.  Then the mean circulation of the particles per unit \
area equals ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)]],
  " ; i.e.  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Zeta]\)\(\ \)\(=\)\(\ \)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\ \[Times]\((number\ or\ particles\ per\ \
unit\ area)\)\)]],
  ".  The total circulation of the flow is defined to be ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", " ", "=", " ", 
          RowBox[{
            RowBox[{"\[Integral]", 
              RowBox[{"\[Zeta]", 
                RowBox[{\(\[DifferentialD]\^2\), 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]}]}], "=", " ", \(N\ \[Gamma]\)}]}], 
        TraditionalForm]]],
  ". Clearly, \[CapitalGamma] is a conserved quantity in this dynamics, \
because ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " is fixed."
}], "Text",
  CellTags->"i:69"],

Cell[TextData[{
  "\tThe stream function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " is determined by the vorticity. This can be seen by taking the curl of \
Eq. ",
  ButtonBox["(7.3.22)",
    ButtonData:>{"Chapter7.nb", "(7.3.22)"},
    ButtonStyle->"Hyperlink"],
  " : "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Zeta]", "=", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox[
                  OverscriptBox[
                    StyleBox["z",
                      FontWeight->"Plain"], "^"],
                  FontWeight->"Plain"], "\[CenterDot]", "\[Del]"}], 
              "\[Times]", 
              StyleBox["u",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], "=", 
            RowBox[{
              RowBox[{
                RowBox[{
                  StyleBox[
                    OverscriptBox[
                      StyleBox["z",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "^"],
                    FontWeight->"Plain"], "\[CenterDot]", "\[Del]"}], 
                "\[Times]", 
                RowBox[{"(", 
                  StyleBox[
                    RowBox[{
                      OverscriptBox[
                        StyleBox["z",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "^"], 
                      "\[Times]", \(\[Del]\[Psi]\)}],
                    FontWeight->"Plain"], 
                  StyleBox[")",
                    FontWeight->"Plain"]}]}], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox["=",
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox[\(\[Del]\^2 \[Psi]\),
                FontWeight->"Plain"]}]}]}], TraditionalForm]]]
}], "NE3",
  CellTags->"(7.3.25)"],

Cell[TextData[{
  "Equations ",
  ButtonBox["(7.3.23)",
    ButtonData:>{"Chapter7.nb", "(7.3.23)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.3.25)",
    ButtonData:>{"Chapter7.nb", "(7.3.25)"},
    ButtonStyle->"Hyperlink"],
  "  are coupled equations for the vorticity and stream function, called the \
",
  StyleBox["Euler equations",
    FontSlant->"Italic"],
  " for 2D flow. Note Eq. ",
  ButtonBox["(7.3.25)",
    ButtonData:>{"Chapter7.nb", "(7.3.25)"},
    ButtonStyle->"Hyperlink"],
  "  is merely Poisson's equation. Therefore, we can follow the same \
procedure as we used for the PIC method in gravitational systems (see Table \
",
  ButtonBox["7.1",
    ButtonData:>"Table 7.1",
    ButtonStyle->"Hyperlink"],
  "). Starting with a collection of identical point vortices  that model an \
initial vorticity distribution ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta](x, y, t = 0)\)]],
  ", we solve Poissons equation using our FFT and interpolation codes in \
order to determine the stream function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, y, t)\)]],
  " and the flow field ",
  Cell[BoxData[
      FormBox[
        StyleBox["u",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". We then move the point vortices according to Eq. ",
  ButtonBox["(7.3.24)",
    ButtonData:>{"Chapter7.nb", "(7.3.24)"},
    ButtonStyle->"Hyperlink"],
  " , and repeat the procedure. "
}], "Text",
  CellTags->"i:84"],

Cell[TextData[{
  "Table 7.1 Analogous Quantities  in  2D Fluids  and Gravitational Dynamics\n\
",
  Cell[BoxData[GridBox[{
          {"gravity", \(2  D\ fluids\)},
          {"\[Phi]", "\[Psi]"},
          {"\[Rho]", "\[Zeta]"},
          {
            StyleBox["m",
              FontSlant->"Italic"], "\[Gamma]"},
          {
            StyleBox["f",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["u",
              FontWeight->"Bold",
              FontSlant->"Plain"]}
          },
        GridFrame->True,
        RowLines->True,
        ColumnLines->True]]],
  "\n"
}], "Text",
  CellFrame->True,
  TextAlignment->Center,
  Background->GrayLevel[0.900008],
  CellTags->"Table 7.1"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Modify the previous PIC code to solve these 2D fluid equations.  Part of \
the job is done for you below, since the leapfrog technique for moving the \
particles will no longer work. Instead, we use the Adams-Bashforth scheme \
discussed in Chapter 1: see Eq. ",
  ButtonBox["(1.4.29)",
    ButtonData:>{"Chapter1.nb", "(1.4.29)"},
    ButtonStyle->"Hyperlink"],
  "  . The following module implements this method, including a few extra \
tricks in order to save memory. First,  the code keeps  memory  of only one  \
previous velocity field evaluation in the variable ",
  StyleBox["u0",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  ", by updating ",
  StyleBox["u0",
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  " after each step.  Second,  an ",
  StyleBox["Unset",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command is used to clear previous position evaluations (again, in order \
to save memory space), and for this reason the plots of the flow are created \
inside the routine. [This ",
  StyleBox["Unset",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " command can be disabled if you wish by surrounding the command with \
comment marks ",
  StyleBox["(* *)",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". ]"
}], "Text",
  CellTags->"i:68"],

Cell[TextData[{
  "\tAlso, for long runs, it is not a bad idea to save data to a file \
periodically. This is implemented using the ",
  StyleBox["Export",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " statement to open a datafile named ",
  StyleBox["r_n",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " in the default directory, and to  write positions to the file every 100 \
steps. The module is"
}], "Text",
  CellTags->"i:67"],

Cell[BoxData[
    RowBox[{\(adbash[r0_, \ Nstep_, \[CapitalDelta]t_, \ \[CapitalDelta]N_]\),
       " ", ":=", " ", 
      RowBox[{"Module", "[", 
        RowBox[{\({}\), ",", "\[IndentingNewLine]", 
          StyleBox[
            RowBox[{"(*", " ", 
              RowBox[{
                RowBox[{"second", "-", 
                  RowBox[{
                  "order", " ", "Adams", " ", "Bashforth", " ", "method", " ",
                     "for", " ", "the", " ", "ODE", 
                    RowBox[{
                    Cell["dr/dt =  u"], ".", " ", 
                      "\[IndentingNewLine]", \((Requires\ a\ function\ u[
                            r])\), ".", " ", "r0"}], " ", "is", " ", "the", 
                    " ", "initial", " ", "condition"}]}], ",", 
                " ", \(Nstep\ is\ the\ number\ of\ timsteps\), ",", 
                " ", \(\[CapitalDelta]t\ is\ the\ step\ size\), ",", 
                " ", \(\[CapitalDelta]N\ is\ a\ parameter\ in\ the\ plots\)}],
               " ", "*)"}],
            FontColor->RGBColor[1, 0, 0]], "\[IndentingNewLine]", 
          "\[IndentingNewLine]", "\[IndentingNewLine]", 
          
          RowBox[{\(md[x_]\  := \ Mod[x, L]\), ";", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", 
            StyleBox[\( (*\ initial\ conditions\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(r[0]\  = \ Map[r0, L]\), ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            "\[IndentingNewLine]", 
            RowBox[{\(r[n_]\), " ", ":=", 
              RowBox[{
                RowBox[{"(", " ", 
                  RowBox[{\(r[n]\), " ", "=", 
                    RowBox[{
                      StyleBox["(",
                        FontSize->16,
                        FontColor->RGBColor[0, 0, 1]], "\[IndentingNewLine]", 
                      
                      RowBox[{
                        StyleBox["(*",
                          FontColor->RGBColor[1, 0, 0]], 
                        StyleBox[" ",
                          FontColor->RGBColor[1, 0, 0]], 
                        
                        StyleBox[\(write\ n - 
                            1\ position\ data\ to\ file\ if\ n - 
                            1\ a\ multiple\ of\ 100\),
                          FontColor->RGBColor[1, 0, 0]], " ", 
                        StyleBox["*)",
                          FontColor->RGBColor[1, 0, 0]]}], 
                      "\[IndentingNewLine]", 
                      
                      RowBox[{\(If[Mod[n - 1, 100]\  == 0, 
                          Export["\<r_\>" <> ToString[n - 1], 
                            r[n - 1], "\<Table\>"]]\), ";", 
                        "\[IndentingNewLine]", 
                        
                        StyleBox[\( (*\ 
                            account\ for\ periodic\ boundary\ conditions\ *) \
\),
                          FontColor->RGBColor[1, 0, 0]], 
                        "\[IndentingNewLine]", " ", \(Map[md, \ r1[n]]\)}], 
                      StyleBox[")",
                        FontSize->16,
                        FontColor->RGBColor[0, 0, 1]]}]}], ")"}], " ", "/;", 
                " ", \(n \[GreaterEqual] \ 1\)}]}], ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            StyleBox[\( (*\ predictor\ step\ for\ n = 1\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(u0\  = \ \ u[r[0]]\), ";", " ", 
            "\[IndentingNewLine]", \(rp\  = \ 
              Map[md, r[0]\  + \ u0\ \ \[CapitalDelta]t]\), ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            StyleBox[\( (*\ corrector\ step\ for\ n = 1*) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(u1\  = \ u[rp]\), ";", 
            "\[IndentingNewLine]", \(r1[1]\  := 
              r[0]\  + \ \[CapitalDelta]t \((u0\  + \ u1)\)/2\), " ", ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            RowBox[{
              StyleBox["(*",
                FontColor->RGBColor[1, 0, 0]], 
              StyleBox[" ",
                FontColor->RGBColor[1, 0, 0]], 
              
              StyleBox[\(second - order\ Adams - 
                    Bashforth\ step\ for\ n\  \[GreaterEqual] \ 2\),
                FontColor->RGBColor[1, 0, 0]], " ", 
              StyleBox["*)",
                FontColor->RGBColor[1, 0, 0]]}], "\[IndentingNewLine]", 
            RowBox[{\(r1[n_]\), " ", ":=", 
              RowBox[{
                RowBox[{"(", 
                  
                  RowBox[{\(u1\  = \ u[r[n - 1]]\), ";", 
                    "\[IndentingNewLine]", 
                    "                ", \(rnew = \ 
                      r[n - 1]\  + \ \[CapitalDelta]t\ \((1.5\ u1 - 
                              0.5  u0)\)\), ";", "\[IndentingNewLine]", 
                    "                ", 
                    RowBox[{
                      StyleBox["(*",
                        FontColor->RGBColor[1, 0, 0]], 
                      StyleBox[" ",
                        FontColor->RGBColor[1, 0, 0]], 
                      StyleBox[\(update\ the\ old\ velocity\ field\),
                        FontColor->RGBColor[1, 0, 0]], " ", 
                      StyleBox["*)",
                        FontColor->RGBColor[1, 0, 0]]}], 
                    "\[IndentingNewLine]", "                ", \(u0 = u1\), 
                    ";", "\[IndentingNewLine]", "                ", 
                    RowBox[{
                      StyleBox["(*",
                        FontColor->RGBColor[1, 0, 0]], 
                      StyleBox[" ",
                        FontColor->RGBColor[1, 0, 0]], 
                      
                      StyleBox[\(un - 
                          memorize\ \((Unset)\)\ r[n - 2]\ to\ save\ memory\),
                        
                        FontColor->RGBColor[1, 0, 0]], " ", 
                      StyleBox["*)",
                        FontColor->RGBColor[1, 0, 0]]}], 
                    "\[IndentingNewLine]", 
                    "                ", \(Unset[r[n - 2]]\), ";", 
                    "\[IndentingNewLine]", "                ", 
                    RowBox[{
                      StyleBox["(*",
                        FontColor->RGBColor[1, 0, 0]], 
                      StyleBox[" ",
                        FontColor->RGBColor[1, 0, 0]], 
                      StyleBox[\(return\ new\ position\),
                        FontColor->RGBColor[1, 0, 0]], " ", 
                      StyleBox["*)",
                        FontColor->RGBColor[1, 0, 0]]}], 
                    "\[IndentingNewLine]", "                ", "rnew"}], 
                  ")"}], "  ", "/;", \(n \[GreaterEqual] \ 2\)}]}], ";", 
            "\[IndentingNewLine]", "\[IndentingNewLine]", 
            
            StyleBox[\( (*\ plot\ solution\ up\ to\ time\ step\ Nstep, \ 
                showing\ every\ \[CapitalDelta]N\ th\ step\ *) \),
              FontColor->RGBColor[1, 0, 0]], 
            "\[IndentingNewLine]", \(Table[
              ListPlot[r[n], PlotRange \[Rule] {{0, L}, {0, L}}, 
                AspectRatio \[Rule] 1, 
                PlotLabel -> "\<n= \>" <> ToString[n\ ]], {n, 0, 
                Nstep, \ \[CapitalDelta]N}]\), ";"}]}], "]"}]}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.93"],

Cell[TextData[{
  "\t",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  StyleBox["Code tests.\n\t(",
    FontSlant->"Italic"],
  "i) Show that a circular patch of vorticity with radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  " and vorticity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)]],
  " causes fluid rotation of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["u",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[
            RowBox[{\(\[Omega](r)\), " ", "r", " ", 
              OverscriptBox[
                StyleBox["\[Theta]",
                  FontWeight->"Bold"], "^"]}],
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", where the rotation frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](r)\)]],
  " is  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](r)\  = \ \[Zeta]\ /2\)]],
  " inside the patch, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](r)\  = \ \[Zeta]\ R\^2/2\ r\^2\)]],
  " outside the patch.  (This sort of flow can be set up by stirring the \
fluid with a rotating disk of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ", then removing the disk.)"
}], "Text"],

Cell[TextData[{
  "\t(ii) Create such a uniform circular patch with radius ",
  Cell[BoxData[
      \(TraditionalForm\`R = 0.3\)]],
  ", using ",
  Cell[BoxData[
      \(TraditionalForm\`N = 1000\)]],
  " point vortices  each with circulation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 1/N\)]],
  ". Evaluate the rotation frequency of the patch numerically as a function \
of ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  ", and compare with part (i)"
}], "Text"],

Cell[TextData[{
  "\t(iii) Show analytically that two isolated point vortices, each with \
circulation ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Gamma]\)\(,\)\)\)]],
  " and separated by a distance ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  ", will rotate around one another with rotation rate ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\  = \ \[Gamma]/R\^2\)]],
  ". Test this result in your code, taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`R = 0.25\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t(iv) Show analytically that the total kinetic energy ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  " of the flow is conserved, where  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"K", " ", "=", " ", 
          RowBox[{"\[Rho]", 
            RowBox[{"\[Integral]", 
              RowBox[{\(u\^2\/2\), 
                RowBox[{\(\[DifferentialD]\^2\), 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]}]}]}]}], TraditionalForm]]],
  ". Test this result for the simulations done in parts ii) and iii). Comment \
on whether the PIC method does an adequate job of evaluating ",
  Cell[BoxData[
      \(TraditionalForm\`K\)]],
  ". [Hint: First show that ",
  Cell[BoxData[
      FormBox[
        RowBox[{"K", " ", "=", 
          RowBox[{\(-\(\[Rho]\/2\)\), 
            RowBox[{"\[Integral]", 
              RowBox[{"\[Zeta]", "  ", "\[Psi]", 
                RowBox[{\(\[DifferentialD]\^2\), 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], " "}]}]}]}]}], TraditionalForm]]],
  ". Take a time derivative of this quantity and apply Eqs. ",
  ButtonBox["(7.3.23)",
    ButtonData:>{"Chapter7.nb", "(7.3.23)"},
    ButtonStyle->"Hyperlink"],
  "  and ",
  ButtonBox["(7.3.25)",
    ButtonData:>{"Chapter7.nb", "(7.3.25)"},
    ButtonStyle->"Hyperlink"],
  " . ]"
}], "Text"],

Cell[TextData[{
  "\t(v) Show analytically that, for an unbounded flow where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["u",
            FontWeight->"Bold",
            FontSlant->"Plain"], "\[Rule]", "0"}], TraditionalForm]]],
  " at infinity,  the total angular momentum ",
  Cell[BoxData[
      \(TraditionalForm\`L\_z\)]],
  " of the flow is conserved, where  ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\(L\)\(\ \)\)\_z\), "=", " ", 
          RowBox[{"\[Rho]", 
            RowBox[{"\[Integral]", 
              RowBox[{\((x\ u\_y - y\ u\_x)\), 
                RowBox[{\(\[DifferentialD]\^2\), 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]}]}]}]}], TraditionalForm]]],
  ". Test this result for the simulations done in parts (ii) and (iii). \
Comment. "
}], "Text"],

Cell[TextData[{
  "\t ",
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  StyleBox["Fluid turbulence",
    FontSlant->"Italic"],
  ". \t(i) Run your code for a random collection of ",
  Cell[BoxData[
      \(TraditionalForm\`N = 500\)]],
  " point vortices, taking ",
  Cell[BoxData[
      \(TraditionalForm\`M = 15\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["t",
                    FontSlant->"Italic"]}]], " ", "=", " ", "0.3"}],
            "TraditionalForm"], ","}], TraditionalForm]]],
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 1/N\)]],
  ". These vortices create a complicated flow field, which has been used by \
researchers as a model of fluid turbulence.   Run the code for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["Nstep",
            FontFamily->"Courier",
            FontWeight->"Bold"], " ", "=", " ", "300"}], TraditionalForm]]],
  " steps.  Does anything like gravitational collapse happen here?  Describe \
the motion of the fluid in a few words."
}], "Text",
  CellTags->"i:72"],

Cell[TextData[{
  "\t \t\t         \t(ii) Higher-kinetic-energy initial conditions do go \
through a process somewhat akin to gravitational collapse: there is an \
instability that results in a final (rotating) equilibrium state. Repeat the \
simulation, now confining the initial random positions of the point vortices \
to the region ",
  Cell[BoxData[
      \(TraditionalForm\`0.4 < y < 0.5\)]],
  ".  Sheets of vorticity such as this create shear flows that are unstable \
and that can be analyzed in much the same way as for the Jeans instability. \
(This instability is called the Kelvin-Helmholtz instability.) Take ",
  Cell[BoxData[
      \(TraditionalForm\`M = 20\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N = 500\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], "=", "0.03"}], TraditionalForm]]],
  ". Now describe the state that develops after 300 steps. "
}], "Text"],

Cell[TextData[{
  "\t ",
  StyleBox["(d)",
    FontWeight->"Bold"],
  " ",
  StyleBox["Vortex merger.\t (",
    FontSlant->"Italic"],
  "i)",
  StyleBox[" ",
    FontSlant->"Italic"],
  " In part (c)(ii), it should have become apparent that merger between \
vortex patches is an important process in the equilibration of initially \
unstable flows.  To study this process, create an initial condition \
consisting of two identical uniform circular vortex patches of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R = 0.1\)]],
  ", with centers separated by distance ",
  Cell[BoxData[
      \(TraditionalForm\`D = 0.25\)]],
  ".  Take ",
  Cell[BoxData[
      \(TraditionalForm\`N = 1000\)]],
  " (500 in each patch),  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 2/N\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["Nstep",
            FontFamily->"Courier",
            FontWeight->"Bold"], " ", "=", " ", "300"}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.01"}], 
        TraditionalForm]]],
  ".  (This run requires fine resolution; take ",
  Cell[BoxData[
      \(TraditionalForm\`M > 30\)]],
  "). How long would you estimate that it takes the two vortices to merge, \
becoming one vortex?"
}], "Text",
  CellTags->"i:70"],

Cell[TextData[{
  "\t \t\t         (ii) Repeat the simulation for ",
  Cell[BoxData[
      \(TraditionalForm\`D = 0.5\)]],
  ". Now what happens? Do the vortices merge? The time required to merge is \
in fact  a sensitive function of the ratio ",
  Cell[BoxData[
      \(TraditionalForm\`D/R\)]],
  ".  [See ",
  ButtonBox["Driscoll and Fine (1990)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".] "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(e)",
    FontWeight->"Bold"],
  " ",
  StyleBox["Vortex crystals",
    FontSlant->"Italic"],
  ". The following code will create an initial condition consisting of a thin \
vortex ring of thickness ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " surrounding a low vorticity center. Such vortex rings can occur \
naturally, for example, in the eye-walls of hurricanes.  These rings are \
unstable because the flow field is highly sheared.  Follow the dynamics of \
the ring for 1000-1500 time steps.  Often, through chaotic vortex merger \
processes, an equilibrium state will develop  called a v",
  StyleBox["ortex crystal",
    FontSlant->"Italic"],
  ", that consists of several strong vortices in a stable regular pattern \
[\"a phalanx of tornadoes\", in the words of  ",
  ButtonBox["James Glanz (1998)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "].  (This simulation will take up to several hours. It might be best to \
run the code overnight.) See ",
  ButtonBox["Fine et. al (1995)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text",
  CellTags->"i:71"],

Cell[BoxData[{
    \(M = 50; 
    L = 1; \[CapitalDelta]x\  = \ \(\[CapitalDelta]y\  = \ 
        L/M\); \[Gamma] = \ 1. /6000; \[CapitalDelta]t\  = \ 0.018;\), "\n", 
    \(\(\(Clear[r];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(d\  = \ 0.025; R\  = \ 0.2;\), "\n", 
    \(\(r0\  = \ 
        Table[\((rr = d\ Random[] + R; \[Theta]\  = \ 
              2\ Pi\ Random[]; {rr\ Cos[\[Theta]]\  + \  .5, 
              rr\ Sin[\[Theta]] + \  .5})\), {5000}];\)\), "\n", 
    \(\(rc = 
        Table[\((rr = \((Random[Real, {0, R^3}])\)^\((1/3)\); \[Theta]\  = \ 
              2\ Pi\ Random[]; {rr\ Cos[\[Theta]]\  + \  .5, 
              rr\ Sin[\[Theta]] + \  .5})\), {1000}];\)\), "\n", 
    \(\(r0\  = \ Join[r0, rc];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.94"],

Cell[TextData[{
  "The results of one such simulation are shown in Cell ",
  ButtonBox["7.95",
    ButtonData:>"Cell 7.95",
    ButtonStyle->"Hyperlink"],
  ". Your results may differ substantially because even small differences in \
the initial conditions can lead to large differences in the final state.  \
However,  from this initial condition roughly the same number of vortices in \
the final crystal should appear almost every time. "
}], "Text"],

Cell[TextData[{
  "\t(i) Show, using Eq. ",
  ButtonBox["(7.3.23)",
    ButtonData:>{"Chapter7.nb", "(7.3.23)"},
    ButtonStyle->"Hyperlink"],
  " , that equilibrium vorticity distributions satisfy ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta](x, y)\  = \ \[Zeta](\[Psi])\)]],
  ": contours of vorticity lie along contours of the stream function."
}], "Text"],

Cell[TextData[{
  "\t(ii)   Test whether your final state is an equilibrium by plotting ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, y)\)]],
  " vs. ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta](x, y)\)]],
  " for all points ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y)\)\)]],
  " on the grid. (Make a table of data pairs ",
  Cell[BoxData[
      \(TraditionalForm\`\(\({\[Psi]\_\(i\ j\), \ \[Rho]\_\(i\ \
j\)}\)\(,\)\)\)]],
  " and plot them with a list plot.)  Smooth your data by evaluating ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)]],
  " from the  position data taking ",
  Cell[BoxData[
      \(TraditionalForm\`M = 15\)]],
  ". Does the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  "-vs.- ",
  Cell[BoxData[
      \(TraditionalForm\`\[Zeta]\)]],
  " data fall on one (or more) lines? Comment on the scatter. Repeat this for \
an intermediate value of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " where the system has not yet achieved equilibrium.  "
}], "Text"],

Cell[TextData[{
  "\t(iii) ",
  StyleBox["Other possible runs:",
    FontSlant->"Italic"],
  " "
}], "Text"],

Cell["\<\
\tRemove the low-vorticity region in the center. How does this \
affect the number of vortices in the final state? \
\>", "Text"],

Cell[TextData[{
  "\tIncrease the thickness ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " of the ring by a factor of two. How does this affect the number of \
vortices observed in the final state?"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Utilities`;\)\), "\n", 
    \(Timing[adbash[r0, 1500, \[CapitalDelta]t, 6]]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.95"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -17 0 ]
[.5 1.0125 17 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.65997 .37116 Mdot
.59727 .31797 Mdot
.37533 .3389 Mdot
.46646 .71221 Mdot
.43511 .70589 Mdot
.3822 .33037 Mdot
.55783 .29986 Mdot
.49982 .28502 Mdot
.28413 .43997 Mdot
.45241 .71015 Mdot
.40862 .30653 Mdot
.70211 .57872 Mdot
.54892 .29725 Mdot
.52506 .70901 Mdot
.62809 .65988 Mdot
.71231 .43985 Mdot
.61906 .32219 Mdot
.43042 .70253 Mdot
.69594 .5625 Mdot
.28805 .42699 Mdot
.29354 .49224 Mdot
.47729 .70746 Mdot
.60027 .30683 Mdot
.55623 .70938 Mdot
.70299 .55011 Mdot
.70418 .4706 Mdot
.66216 .37587 Mdot
.70876 .52794 Mdot
.70379 .56922 Mdot
.45647 .28285 Mdot
.70953 .50391 Mdot
.61231 .69185 Mdot
.29708 .50384 Mdot
.6715 .37267 Mdot
.39959 .3152 Mdot
.4185 .29371 Mdot
.36435 .35136 Mdot
.45018 .29032 Mdot
.48084 .27881 Mdot
.42661 .3087 Mdot
.41684 .31067 Mdot
.70547 .46505 Mdot
.40685 .29824 Mdot
.5746 .3025 Mdot
.58813 .70078 Mdot
.68722 .37973 Mdot
.29179 .48245 Mdot
.53884 .69692 Mdot
.65242 .35888 Mdot
.28996 .4919 Mdot
.62927 .66639 Mdot
.58086 .31129 Mdot
.30225 .54979 Mdot
.62035 .3136 Mdot
.5382 .29686 Mdot
.70603 .54438 Mdot
.32461 .38015 Mdot
.65112 .65044 Mdot
.67705 .60028 Mdot
.67625 .38125 Mdot
.56703 .71033 Mdot
.33669 .61943 Mdot
.69717 .57242 Mdot
.30895 .3869 Mdot
.32972 .38384 Mdot
.49224 .30001 Mdot
.59003 .29442 Mdot
.44677 .29233 Mdot
.53935 .70832 Mdot
.32714 .39715 Mdot
.63466 .65921 Mdot
.40878 .30683 Mdot
.69651 .41841 Mdot
.46004 .70749 Mdot
.64894 .36248 Mdot
.42768 .29828 Mdot
.45022 .71593 Mdot
.70424 .4356 Mdot
.28168 .54112 Mdot
.51225 .72444 Mdot
.49989 .71015 Mdot
.37535 .31434 Mdot
.65388 .63028 Mdot
.70764 .4686 Mdot
.59775 .69021 Mdot
.42532 .28913 Mdot
.44351 .70344 Mdot
.70941 .50082 Mdot
.71434 .50949 Mdot
.7098 .56706 Mdot
.28836 .45035 Mdot
.57848 .29395 Mdot
.45277 .70178 Mdot
.62812 .68113 Mdot
.5936 .68307 Mdot
.59511 .68931 Mdot
.71676 .50045 Mdot
.28851 .52662 Mdot
.4454 .30176 Mdot
.29794 .52623 Mdot
.43346 .29442 Mdot
.31123 .58851 Mdot
.61566 .69146 Mdot
.34686 .35196 Mdot
.65488 .3488 Mdot
.28762 .54012 Mdot
.43754 .29863 Mdot
.44378 .69638 Mdot
.43467 .29089 Mdot
.58496 .30129 Mdot
.71334 .49273 Mdot
.39208 .68289 Mdot
.43877 .71379 Mdot
.66835 .38501 Mdot
.65222 .66392 Mdot
.45646 .71144 Mdot
.49483 .70719 Mdot
.5854 .29212 Mdot
.29023 .42915 Mdot
.28089 .47558 Mdot
.61897 .33633 Mdot
.44097 .30436 Mdot
.63157 .33138 Mdot
.35294 .65956 Mdot
.29925 .41896 Mdot
.29234 .54794 Mdot
.30284 .59252 Mdot
.59265 .70202 Mdot
.59417 .68831 Mdot
.34816 .66266 Mdot
.34798 .3492 Mdot
.62067 .33794 Mdot
.53224 .29068 Mdot
.63258 .67893 Mdot
.69457 .39122 Mdot
.53853 .29795 Mdot
.37063 .66085 Mdot
.41221 .69907 Mdot
.69193 .40617 Mdot
.64618 .66483 Mdot
.50183 .29691 Mdot
.52097 .27819 Mdot
.64931 .65326 Mdot
.68868 .38541 Mdot
.37835 .66149 Mdot
.52048 .27788 Mdot
.31311 .58243 Mdot
.71635 .47905 Mdot
.69786 .60251 Mdot
.3899 .30402 Mdot
.62461 .66805 Mdot
.30017 .45665 Mdot
.33555 .62425 Mdot
.52461 .29479 Mdot
.47286 .71544 Mdot
.63018 .33404 Mdot
.68651 .39313 Mdot
.67884 .61544 Mdot
.29046 .52206 Mdot
.67287 .63688 Mdot
.3223 .61717 Mdot
.2958 .58375 Mdot
.48878 .70334 Mdot
.67811 .3774 Mdot
.64373 .33011 Mdot
.63853 .65724 Mdot
.32784 .38797 Mdot
.45921 .71988 Mdot
.40174 .30828 Mdot
.58009 .69495 Mdot
.57379 .69098 Mdot
.68773 .60533 Mdot
.54611 .28807 Mdot
.36361 .32795 Mdot
.28946 .46621 Mdot
.4863 .29714 Mdot
.38854 .31533 Mdot
.32647 .36677 Mdot
.68929 .59164 Mdot
.40004 .69614 Mdot
.32447 .63242 Mdot
.63643 .65883 Mdot
.55896 .70689 Mdot
.70584 .5751 Mdot
.30322 .60544 Mdot
.30863 .6175 Mdot
.66706 .37273 Mdot
.39721 .30409 Mdot
.52364 .71803 Mdot
.6838 .58492 Mdot
.61082 .67721 Mdot
.49202 .29283 Mdot
.5187 .28668 Mdot
.32541 .36135 Mdot
.29076 .42003 Mdot
.3066 .43563 Mdot
.63145 .65174 Mdot
.63141 .65639 Mdot
.51355 .71532 Mdot
.29679 .54452 Mdot
.72121 .51 Mdot
.33617 .62416 Mdot
.62065 .32516 Mdot
.37212 .31702 Mdot
.69415 .61029 Mdot
.69195 .55721 Mdot
.27828 .46614 Mdot
.27865 .50701 Mdot
.32981 .64492 Mdot
.3656 .67062 Mdot
.62451 .66635 Mdot
.66159 .3672 Mdot
.63416 .66331 Mdot
.29656 .50803 Mdot
.43833 .71527 Mdot
.61091 .32717 Mdot
.54722 .695 Mdot
.55685 .30298 Mdot
.42361 .3137 Mdot
.43586 .69849 Mdot
.43692 .69276 Mdot
.70294 .42485 Mdot
.62641 .6801 Mdot
.69584 .5678 Mdot
.70808 .51579 Mdot
.31033 .42584 Mdot
.45765 .29456 Mdot
.45611 .28106 Mdot
.29101 .49283 Mdot
.69371 .39947 Mdot
.58537 .31058 Mdot
.35089 .35264 Mdot
.29623 .47807 Mdot
.40771 .30224 Mdot
.36172 .65792 Mdot
.35314 .34852 Mdot
.37927 .66099 Mdot
.68861 .58608 Mdot
.3566 .33784 Mdot
.37753 .66939 Mdot
.6426 .65053 Mdot
.30723 .59698 Mdot
.41482 .70781 Mdot
.56586 .30465 Mdot
.56108 .28902 Mdot
.65407 .64696 Mdot
.31001 .58884 Mdot
.29822 .50789 Mdot
.68398 .59812 Mdot
.30393 .59892 Mdot
.29663 .57581 Mdot
.68702 .59679 Mdot
.41804 .69301 Mdot
.37102 .32203 Mdot
.71008 .50264 Mdot
.62387 .32594 Mdot
.55731 .7077 Mdot
.47133 .30134 Mdot
.53443 .29717 Mdot
.52328 .72257 Mdot
.42972 .28919 Mdot
.5725 .30913 Mdot
.49282 .70505 Mdot
.47501 .28284 Mdot
.70585 .42098 Mdot
.69505 .60975 Mdot
.69545 .42213 Mdot
.52223 .70898 Mdot
.47588 .28139 Mdot
.29071 .49218 Mdot
.70598 .4412 Mdot
.47028 .70855 Mdot
.49051 .71678 Mdot
.29856 .54535 Mdot
.7118 .50185 Mdot
.47729 .28833 Mdot
.70126 .57928 Mdot
.37572 .32569 Mdot
.65005 .64102 Mdot
.32237 .60016 Mdot
.33952 .63697 Mdot
.68703 .38514 Mdot
.29827 .59215 Mdot
.3667 .33925 Mdot
.59315 .68238 Mdot
.5918 .68033 Mdot
.60084 .69326 Mdot
.29959 .57635 Mdot
.65234 .63216 Mdot
.55062 .30611 Mdot
.72059 .49122 Mdot
.34602 .65918 Mdot
.33516 .37027 Mdot
.30435 .55022 Mdot
.59751 .68936 Mdot
.59313 .30271 Mdot
.70819 .49931 Mdot
.36787 .32936 Mdot
.59892 .30888 Mdot
.55852 .69266 Mdot
.44987 .29244 Mdot
.3287 .60509 Mdot
.45733 .28646 Mdot
.69805 .55093 Mdot
.65817 .63507 Mdot
.32257 .40239 Mdot
.70361 .41667 Mdot
.51295 .29106 Mdot
.69629 .42042 Mdot
.66417 .64422 Mdot
.66834 .64412 Mdot
.68456 .38554 Mdot
.33135 .62187 Mdot
.2838 .50105 Mdot
.41054 .30416 Mdot
.29522 .55373 Mdot
.31204 .41254 Mdot
.6517 .35594 Mdot
.35577 .34419 Mdot
.66463 .65317 Mdot
.42905 .31247 Mdot
.70626 .50589 Mdot
.32116 .40205 Mdot
.67872 .61803 Mdot
.59485 .69942 Mdot
.31455 .37621 Mdot
.2945 .50318 Mdot
.64019 .65804 Mdot
.7009 .40272 Mdot
.49315 .70194 Mdot
.43851 .70173 Mdot
.63262 .65261 Mdot
.33348 .37141 Mdot
.64956 .66249 Mdot
.70396 .53218 Mdot
.70058 .54975 Mdot
.61902 .32619 Mdot
.30364 .57067 Mdot
.3815 .66744 Mdot
.41745 .70655 Mdot
.31881 .59992 Mdot
.7073 .5748 Mdot
.65853 .65401 Mdot
.69053 .39366 Mdot
.29072 .47616 Mdot
.55175 .28375 Mdot
.29604 .50879 Mdot
.49823 .28431 Mdot
.36891 .3252 Mdot
.43151 .69535 Mdot
.43462 .7031 Mdot
.70938 .491 Mdot
.65029 .35847 Mdot
.69817 .41871 Mdot
.50935 .28979 Mdot
.71941 .52642 Mdot
.51549 .72426 Mdot
.52568 .72216 Mdot
.49429 .27943 Mdot
.29324 .52218 Mdot
.66481 .61706 Mdot
.58633 .68145 Mdot
.56444 .29615 Mdot
.58448 .69919 Mdot
.68104 .39892 Mdot
.50239 .70216 Mdot
.6167 .68877 Mdot
.52707 .70439 Mdot
.69654 .39649 Mdot
.70751 .49655 Mdot
.58925 .68065 Mdot
.27632 .47976 Mdot
.69749 .60644 Mdot
.38611 .69248 Mdot
.46062 .70684 Mdot
.62303 .66683 Mdot
.3695 .65576 Mdot
.66652 .38023 Mdot
.56483 .69583 Mdot
.39424 .3026 Mdot
.46564 .7063 Mdot
.40098 .30757 Mdot
.66852 .62131 Mdot
.61618 .68307 Mdot
.70656 .52692 Mdot
.599 .30559 Mdot
.48696 .27763 Mdot
.40555 .31146 Mdot
.34025 .65061 Mdot
.53261 .29684 Mdot
.59012 .6933 Mdot
.66451 .62533 Mdot
.66832 .38452 Mdot
.30553 .59263 Mdot
.57502 .29161 Mdot
.47302 .72195 Mdot
.54568 .29177 Mdot
.30704 .57044 Mdot
.70736 .55839 Mdot
.52505 .2819 Mdot
.38637 .31059 Mdot
.71356 .49043 Mdot
.29352 .52157 Mdot
.65885 .36733 Mdot
.32117 .40294 Mdot
.29023 .55385 Mdot
.53128 .29539 Mdot
.57929 .70306 Mdot
.71836 .48595 Mdot
.49528 .28748 Mdot
.69183 .43241 Mdot
.71601 .47031 Mdot
.45845 .70331 Mdot
.7034 .48127 Mdot
.56769 .28551 Mdot
.68296 .62625 Mdot
.54216 .71739 Mdot
.36504 .34473 Mdot
.29806 .57217 Mdot
.29967 .5716 Mdot
.2879 .56076 Mdot
.43684 .31006 Mdot
.28315 .48703 Mdot
.46202 .29639 Mdot
.52965 .70762 Mdot
.48124 .29801 Mdot
.31085 .5908 Mdot
.3681 .34233 Mdot
.55403 .70642 Mdot
.7248 .50425 Mdot
.51951 .27692 Mdot
.30166 .42486 Mdot
.4272 .68981 Mdot
.63378 .33562 Mdot
.56368 .29878 Mdot
.63245 .65623 Mdot
.31857 .41273 Mdot
.33454 .6158 Mdot
.63528 .66905 Mdot
.51902 .27942 Mdot
.68558 .41737 Mdot
.51486 .27894 Mdot
.59901 .67862 Mdot
.5609 .70041 Mdot
.6292 .34612 Mdot
.37571 .68457 Mdot
.69858 .58207 Mdot
.5591 .70952 Mdot
.2868 .51204 Mdot
.57107 .2963 Mdot
.37128 .68089 Mdot
.71254 .5542 Mdot
.31154 .6113 Mdot
.45955 .71909 Mdot
.50586 .71457 Mdot
.68947 .59805 Mdot
.34013 .64185 Mdot
.47521 .28561 Mdot
.402 .70126 Mdot
.27972 .46449 Mdot
.60259 .3164 Mdot
.46372 .29581 Mdot
.28796 .52318 Mdot
.41205 .30596 Mdot
.69995 .59038 Mdot
.32334 .62297 Mdot
.58942 .31577 Mdot
.40584 .67861 Mdot
.30043 .58278 Mdot
.32581 .38077 Mdot
.66265 .64395 Mdot
.69265 .59079 Mdot
.45587 .70212 Mdot
.38117 .66777 Mdot
.56956 .29278 Mdot
.39022 .31219 Mdot
.47747 .27698 Mdot
.48401 .70167 Mdot
.68673 .38486 Mdot
.68409 .42086 Mdot
.29926 .53227 Mdot
.38535 .68104 Mdot
.36612 .66324 Mdot
.47507 .69977 Mdot
.68191 .59285 Mdot
.69454 .3957 Mdot
.46892 .70834 Mdot
.49252 .70305 Mdot
.29502 .44793 Mdot
.70071 .4915 Mdot
.34894 .34406 Mdot
.68739 .57133 Mdot
.6225 .67522 Mdot
.45786 .29303 Mdot
.55479 .30487 Mdot
.30109 .56702 Mdot
.45601 .28093 Mdot
.28883 .46437 Mdot
.29984 .57222 Mdot
.47258 .70918 Mdot
.66671 .38717 Mdot
.46391 .70696 Mdot
.46368 .70601 Mdot
.53979 .70577 Mdot
.65597 .65572 Mdot
.27664 .49781 Mdot
.39355 .68993 Mdot
.70162 .57014 Mdot
.33357 .35722 Mdot
.27883 .46257 Mdot
.60179 .67966 Mdot
.49205 .7132 Mdot
.4837 .70454 Mdot
.7014 .47256 Mdot
.72001 .47905 Mdot
.51216 .28166 Mdot
.62788 .34544 Mdot
.48991 .72008 Mdot
.29549 .46271 Mdot
.55894 .69826 Mdot
.68443 .39226 Mdot
.4085 .31374 Mdot
.49726 .29291 Mdot
.30701 .6039 Mdot
.29895 .5187 Mdot
.29781 .57576 Mdot
.29409 .49955 Mdot
.41057 .29655 Mdot
.36947 .34153 Mdot
.31906 .58964 Mdot
.66992 .64353 Mdot
.53745 .71688 Mdot
.56978 .69682 Mdot
.29605 .44011 Mdot
.309 .56489 Mdot
.65533 .65351 Mdot
.71864 .44771 Mdot
.41507 .3162 Mdot
.28722 .55138 Mdot
.7052 .49616 Mdot
.59331 .30787 Mdot
.31616 .41317 Mdot
.44667 .29052 Mdot
.38033 .6704 Mdot
.29353 .48107 Mdot
.5708 .29101 Mdot
.68783 .58364 Mdot
.4115 .31812 Mdot
.66338 .62515 Mdot
.72476 .4955 Mdot
.36672 .33526 Mdot
.71957 .49971 Mdot
.59481 .29781 Mdot
.30458 .59261 Mdot
.66006 .6315 Mdot
.68094 .60264 Mdot
.31398 .37375 Mdot
.46003 .70857 Mdot
.28424 .46132 Mdot
.33176 .37416 Mdot
.31035 .59784 Mdot
.33416 .37069 Mdot
.5408 .30268 Mdot
.33005 .36713 Mdot
.69762 .45278 Mdot
.60059 .70067 Mdot
.6335 .32384 Mdot
.67984 .62045 Mdot
.48846 .72092 Mdot
.57962 .31209 Mdot
.47478 .29957 Mdot
.55236 .71263 Mdot
.42653 .70058 Mdot
.33605 .37088 Mdot
.29018 .46889 Mdot
.71796 .50078 Mdot
.30611 .42216 Mdot
.5986 .30503 Mdot
.44389 .29463 Mdot
.47543 .29946 Mdot
.29424 .56793 Mdot
.69319 .3887 Mdot
.45868 .28934 Mdot
.44339 .30404 Mdot
.32805 .6042 Mdot
.67898 .62843 Mdot
.66473 .36349 Mdot
.6648 .61737 Mdot
.40225 .68021 Mdot
.46866 .70648 Mdot
.34319 .34984 Mdot
.30082 .44433 Mdot
.594 .67702 Mdot
.35378 .35088 Mdot
.29831 .56116 Mdot
.68035 .4028 Mdot
.70316 .55195 Mdot
.59192 .31164 Mdot
.62978 .67858 Mdot
.46599 .29555 Mdot
.59293 .3053 Mdot
.28761 .56932 Mdot
.57001 .71239 Mdot
.68022 .37985 Mdot
.72 .53771 Mdot
.46126 .7041 Mdot
.31003 .40489 Mdot
.37213 .6575 Mdot
.30187 .45697 Mdot
.28736 .45068 Mdot
.34555 .63781 Mdot
.58076 .30504 Mdot
.30056 .4164 Mdot
.3617 .66148 Mdot
.35727 .66427 Mdot
.28726 .55992 Mdot
.38614 .68755 Mdot
.59509 .69089 Mdot
.51683 .29373 Mdot
.58709 .30848 Mdot
.52696 .70242 Mdot
.45711 .71283 Mdot
.62476 .31611 Mdot
.29778 .53971 Mdot
.45925 .70189 Mdot
.67142 .63544 Mdot
.68555 .3947 Mdot
.36938 .31993 Mdot
.30882 .39331 Mdot
.29367 .53445 Mdot
.58791 .3071 Mdot
.37508 .31431 Mdot
.32396 .38963 Mdot
.35468 .64697 Mdot
.49241 .28957 Mdot
.66589 .3872 Mdot
.30103 .54769 Mdot
.56219 .30242 Mdot
.29222 .44004 Mdot
.62493 .6684 Mdot
.71656 .44973 Mdot
.40869 .32151 Mdot
.62824 .66671 Mdot
.70027 .52401 Mdot
.31008 .42958 Mdot
.36503 .32625 Mdot
.58273 .2994 Mdot
.48612 .28103 Mdot
.37549 .67207 Mdot
.69804 .42358 Mdot
.57488 .29193 Mdot
.55404 .30475 Mdot
.62145 .31199 Mdot
.64884 .6367 Mdot
.42849 .29884 Mdot
.66268 .61702 Mdot
.63534 .66179 Mdot
.30301 .5581 Mdot
.3983 .69389 Mdot
.45324 .29427 Mdot
.70443 .4705 Mdot
.53228 .27864 Mdot
.5988 .68578 Mdot
.71938 .47238 Mdot
.39699 .68482 Mdot
.64155 .33286 Mdot
.35276 .33239 Mdot
.51728 .28205 Mdot
.2879 .50512 Mdot
.4237 .69914 Mdot
.606 .69074 Mdot
.33184 .38756 Mdot
.57534 .69781 Mdot
.58756 .31621 Mdot
.69969 .52507 Mdot
.61192 .32532 Mdot
.41966 .30094 Mdot
.71156 .47173 Mdot
.70437 .57164 Mdot
.54624 .71489 Mdot
.30879 .42774 Mdot
.67301 .38717 Mdot
.33879 .63642 Mdot
.41979 .68786 Mdot
.57453 .71179 Mdot
.29948 .50823 Mdot
.59977 .69974 Mdot
.37483 .32124 Mdot
.29206 .5166 Mdot
.4058 .31817 Mdot
.30154 .58786 Mdot
.29741 .55521 Mdot
.65145 .35074 Mdot
.30638 .43759 Mdot
.29913 .51526 Mdot
.52054 .72322 Mdot
.44759 .69501 Mdot
.48867 .27681 Mdot
.65234 .63518 Mdot
.67388 .60906 Mdot
.34754 .3413 Mdot
.3273 .6018 Mdot
.56934 .69081 Mdot
.70788 .44324 Mdot
.4103 .69582 Mdot
.32242 .61593 Mdot
.60357 .31281 Mdot
.59956 .68819 Mdot
.29422 .44903 Mdot
.30563 .59054 Mdot
.3155 .59676 Mdot
.3863 .67557 Mdot
.55942 .29518 Mdot
.68668 .40669 Mdot
.33023 .37598 Mdot
.71399 .4573 Mdot
.45603 .71541 Mdot
.30867 .42327 Mdot
.30352 .56164 Mdot
.33347 .64105 Mdot
.68701 .38617 Mdot
.6966 .44626 Mdot
.28983 .51342 Mdot
.33623 .35365 Mdot
.42458 .29086 Mdot
.42215 .30396 Mdot
.67578 .61866 Mdot
.46079 .28583 Mdot
.58307 .29928 Mdot
.61284 .67899 Mdot
.36445 .66211 Mdot
.53052 .28379 Mdot
.29418 .56995 Mdot
.58494 .30299 Mdot
.69963 .44607 Mdot
.56963 .70859 Mdot
.48279 .70875 Mdot
.29136 .48834 Mdot
.60885 .69391 Mdot
.55075 .2898 Mdot
.37312 .6612 Mdot
.35733 .35327 Mdot
.71874 .49353 Mdot
.62942 .33297 Mdot
.30743 .44084 Mdot
.71475 .55532 Mdot
.31411 .38296 Mdot
.60966 .33053 Mdot
.403 .68648 Mdot
.39202 .68925 Mdot
.61657 .67807 Mdot
.30629 .44397 Mdot
.56618 .30314 Mdot
.69289 .39011 Mdot
.57411 .2994 Mdot
.69457 .58084 Mdot
.48815 .71207 Mdot
.71178 .5302 Mdot
.39445 .30956 Mdot
.58892 .69252 Mdot
.38539 .67302 Mdot
.62728 .32157 Mdot
.58679 .70183 Mdot
.42786 .70522 Mdot
.34207 .64146 Mdot
.33347 .64457 Mdot
.30272 .39567 Mdot
.40645 .68783 Mdot
.41201 .69152 Mdot
.43041 .70967 Mdot
.37084 .32434 Mdot
.65237 .64284 Mdot
.42748 .69761 Mdot
.47142 .71277 Mdot
.65674 .64833 Mdot
.71752 .45488 Mdot
.4832 .29691 Mdot
.32408 .4015 Mdot
.61078 .67322 Mdot
.48953 .71653 Mdot
.61885 .31505 Mdot
.71274 .44064 Mdot
.57215 .68847 Mdot
.61001 .31876 Mdot
.66301 .3578 Mdot
.29627 .41096 Mdot
.51915 .3004 Mdot
.33667 .38425 Mdot
.71822 .5393 Mdot
.72231 .52368 Mdot
.64686 .34145 Mdot
.51194 .29356 Mdot
.71786 .53874 Mdot
.56832 .30046 Mdot
.61314 .31195 Mdot
.71871 .45208 Mdot
.69335 .43767 Mdot
.33686 .61838 Mdot
.58031 .68604 Mdot
.5646 .30926 Mdot
.61382 .67159 Mdot
.54435 .30209 Mdot
.44937 .70873 Mdot
.71812 .5358 Mdot
.48647 .71809 Mdot
.53497 .70719 Mdot
.30124 .60339 Mdot
.48977 .71097 Mdot
.28221 .53689 Mdot
.6312 .33648 Mdot
.44817 .71201 Mdot
.69567 .57134 Mdot
.64402 .65604 Mdot
.47354 .70374 Mdot
.62335 .31475 Mdot
.50701 .7093 Mdot
.32347 .39764 Mdot
.7223 .52991 Mdot
.60989 .67307 Mdot
.51815 .28769 Mdot
.41897 .30722 Mdot
.66894 .38667 Mdot
.32655 .62851 Mdot
.62976 .32214 Mdot
.47812 .70234 Mdot
.31169 .39685 Mdot
.31729 .59506 Mdot
.3954 .67664 Mdot
.6082 .32954 Mdot
.41961 .68965 Mdot
.40559 .2992 Mdot
.29287 .43236 Mdot
.71258 .49115 Mdot
.36779 .33114 Mdot
.31637 .37543 Mdot
.55981 .28902 Mdot
.39754 .69285 Mdot
.54563 .69943 Mdot
.675 .37958 Mdot
.66265 .34555 Mdot
.6937 .58247 Mdot
.29981 .41291 Mdot
.34063 .64228 Mdot
.69952 .51895 Mdot
.34472 .62743 Mdot
.35483 .65306 Mdot
.55785 .3044 Mdot
.3081 .39943 Mdot
.29364 .54201 Mdot
.36214 .66116 Mdot
.29462 .41271 Mdot
.28836 .522 Mdot
.28736 .50013 Mdot
.69111 .39211 Mdot
.66719 .64907 Mdot
.67972 .37477 Mdot
.46545 .27957 Mdot
.2962 .458 Mdot
.698 .40606 Mdot
.70803 .4403 Mdot
.29753 .55001 Mdot
.32948 .38739 Mdot
.66825 .37367 Mdot
.66741 .6374 Mdot
.32178 .63364 Mdot
.58024 .70711 Mdot
.45572 .71934 Mdot
.45193 .69729 Mdot
.31185 .43032 Mdot
.50786 .28017 Mdot
.35579 .35221 Mdot
.5631 .30648 Mdot
.61288 .69224 Mdot
.55947 .71617 Mdot
.47601 .71118 Mdot
.66958 .61981 Mdot
.64742 .34381 Mdot
.67539 .38356 Mdot
.31667 .38575 Mdot
.3476 .35924 Mdot
.71097 .54334 Mdot
.63851 .33886 Mdot
.32702 .61709 Mdot
.69287 .58036 Mdot
.51351 .71051 Mdot
.62914 .33473 Mdot
.71991 .46062 Mdot
.50973 .29812 Mdot
.6677 .62411 Mdot
.62835 .32553 Mdot
.28308 .48266 Mdot
.52326 .70783 Mdot
.29929 .52478 Mdot
.34903 .66228 Mdot
.69446 .59932 Mdot
.42616 .69948 Mdot
.60597 .32171 Mdot
.30663 .56167 Mdot
.63678 .34197 Mdot
.42983 .31181 Mdot
.51529 .30021 Mdot
.61461 .32492 Mdot
.50071 .70776 Mdot
.34579 .37245 Mdot
.52448 .29594 Mdot
.51185 .70314 Mdot
.4267 .3009 Mdot
.69765 .41344 Mdot
.62903 .34101 Mdot
.28833 .5221 Mdot
.72064 .493 Mdot
.55303 .29477 Mdot
.52377 .71909 Mdot
.69199 .43493 Mdot
.71146 .47779 Mdot
.3936 .6724 Mdot
.54602 .70192 Mdot
.68353 .62861 Mdot
.28188 .47177 Mdot
.60832 .67795 Mdot
.38697 .31689 Mdot
.40553 .30075 Mdot
.39072 .30972 Mdot
.66009 .36636 Mdot
.29481 .58998 Mdot
.69199 .42579 Mdot
.29856 .56422 Mdot
.33808 .37716 Mdot
.51726 .7036 Mdot
.29601 .49229 Mdot
.45568 .29535 Mdot
.37815 .68414 Mdot
.70668 .57305 Mdot
.39642 .32857 Mdot
.32949 .64647 Mdot
.53284 .28575 Mdot
.69198 .44136 Mdot
.60497 .31705 Mdot
.28571 .49739 Mdot
.52653 .70598 Mdot
.47972 .70899 Mdot
.4664 .29925 Mdot
.30898 .43881 Mdot
.34806 .64167 Mdot
.29373 .50613 Mdot
.45738 .29698 Mdot
.66063 .62989 Mdot
.70194 .42422 Mdot
.61527 .67054 Mdot
.65782 .63048 Mdot
.37656 .32209 Mdot
.66222 .34831 Mdot
.34245 .6336 Mdot
.62086 .68208 Mdot
.60897 .3252 Mdot
.5345 .29204 Mdot
.37555 .687 Mdot
.6895 .57379 Mdot
.52021 .71711 Mdot
.65843 .64187 Mdot
.68606 .60202 Mdot
.70773 .5082 Mdot
.30255 .59849 Mdot
.64818 .64994 Mdot
.70792 .55102 Mdot
.71321 .45823 Mdot
.56483 .69774 Mdot
.57232 .69338 Mdot
.62893 .33618 Mdot
.63532 .65145 Mdot
.34379 .35165 Mdot
.7141 .52393 Mdot
.3035 .44814 Mdot
.707 .5149 Mdot
.65596 .63698 Mdot
.66678 .35388 Mdot
.69379 .60091 Mdot
.67683 .39733 Mdot
.65047 .35295 Mdot
.46268 .28012 Mdot
.70021 .5262 Mdot
.31379 .38299 Mdot
.32904 .62451 Mdot
.31584 .4111 Mdot
.63149 .33849 Mdot
.29371 .41811 Mdot
.49249 .29945 Mdot
.40872 .3218 Mdot
.39749 .31993 Mdot
.51161 .27957 Mdot
.55625 .28544 Mdot
.71731 .54877 Mdot
.52769 .28186 Mdot
.30883 .56768 Mdot
.35708 .65166 Mdot
.65717 .34137 Mdot
.3004 .48552 Mdot
.42106 .68523 Mdot
.5246 .27692 Mdot
.37127 .34546 Mdot
.67587 .62751 Mdot
.65069 .36043 Mdot
.42009 .70543 Mdot
.61777 .32894 Mdot
.30544 .45141 Mdot
.33416 .62031 Mdot
.6062 .68941 Mdot
.29614 .46659 Mdot
.38045 .31888 Mdot
.54887 .69933 Mdot
.66736 .36095 Mdot
.31659 .41048 Mdot
.5496 .30589 Mdot
.41919 .29141 Mdot
.29657 .52469 Mdot
.62167 .3215 Mdot
.69089 .42695 Mdot
.3013 .57139 Mdot
.53078 .29 Mdot
.67879 .40061 Mdot
.66426 .64669 Mdot
.44083 .28362 Mdot
.53 .70041 Mdot
.64538 .66542 Mdot
.31358 .57855 Mdot
.29201 .57625 Mdot
.71383 .43898 Mdot
.33288 .38041 Mdot
.71714 .51905 Mdot
.62472 .68046 Mdot
.51193 .70538 Mdot
.52089 .71379 Mdot
.64908 .64861 Mdot
.2876 .46364 Mdot
.66692 .37614 Mdot
.32876 .63855 Mdot
.30031 .54879 Mdot
.71175 .42774 Mdot
.29195 .49201 Mdot
.37305 .67752 Mdot
.28503 .51057 Mdot
.57576 .71067 Mdot
.49814 .70949 Mdot
.70268 .44872 Mdot
.65672 .66003 Mdot
.30019 .58859 Mdot
.52942 .71412 Mdot
.71563 .55804 Mdot
.52166 .29055 Mdot
.68638 .62527 Mdot
.48692 .70194 Mdot
.494 .29376 Mdot
.52409 .28923 Mdot
.30283 .43551 Mdot
.29847 .47878 Mdot
.31121 .3806 Mdot
.34306 .62978 Mdot
.61387 .67024 Mdot
.61187 .68068 Mdot
.65547 .63591 Mdot
.34015 .6234 Mdot
.70528 .52613 Mdot
.64844 .66853 Mdot
.4689 .69819 Mdot
.35756 .65761 Mdot
.46514 .28463 Mdot
.6236 .33048 Mdot
.64565 .6646 Mdot
.30025 .55098 Mdot
.71303 .47109 Mdot
.43445 .70858 Mdot
.63708 .34293 Mdot
.67775 .37607 Mdot
.61229 .33264 Mdot
.52453 .28428 Mdot
.31781 .41527 Mdot
.33362 .6192 Mdot
.61658 .32804 Mdot
.29123 .43101 Mdot
.44718 .29369 Mdot
.68005 .61516 Mdot
.47425 .27851 Mdot
.55754 .28756 Mdot
.64424 .34123 Mdot
.65591 .36937 Mdot
.71069 .53109 Mdot
.65313 .64558 Mdot
.29674 .56039 Mdot
.46118 .29706 Mdot
.34195 .37056 Mdot
.60302 .68499 Mdot
.67429 .37186 Mdot
.69639 .60567 Mdot
.60815 .68968 Mdot
.45391 .69762 Mdot
.43683 .69379 Mdot
.32048 .63485 Mdot
.46378 .7128 Mdot
.46468 .71029 Mdot
.59001 .31714 Mdot
.30629 .4281 Mdot
.55093 .71867 Mdot
.33286 .64287 Mdot
.41794 .69134 Mdot
.41979 .70687 Mdot
.62959 .67137 Mdot
.71678 .53071 Mdot
.62058 .32682 Mdot
.34478 .34491 Mdot
.30077 .4063 Mdot
.38044 .66799 Mdot
.49615 .28369 Mdot
.55842 .28316 Mdot
.28798 .45459 Mdot
.33111 .61564 Mdot
.54025 .70471 Mdot
.67145 .61744 Mdot
.69668 .59581 Mdot
.69166 .59491 Mdot
.53205 .70526 Mdot
.29206 .5701 Mdot
.38093 .32389 Mdot
.67268 .62513 Mdot
.68546 .37937 Mdot
.42394 .69969 Mdot
.35579 .64487 Mdot
.67171 .38087 Mdot
.62348 .68302 Mdot
.57157 .31199 Mdot
.67491 .60106 Mdot
.47963 .28868 Mdot
.63767 .32935 Mdot
.45053 .71217 Mdot
.56057 .6976 Mdot
.57931 .68862 Mdot
.442 .70228 Mdot
.65623 .35094 Mdot
.68042 .40052 Mdot
.70445 .46797 Mdot
.51882 .2906 Mdot
.60209 .67866 Mdot
.41238 .31109 Mdot
.30079 .58968 Mdot
.59455 .30804 Mdot
.62173 .65944 Mdot
.34904 .35792 Mdot
.71389 .44446 Mdot
.39835 .69722 Mdot
.67918 .59972 Mdot
.32076 .62028 Mdot
.67581 .63737 Mdot
.37061 .34021 Mdot
.70116 .41769 Mdot
.71566 .44577 Mdot
.27625 .49225 Mdot
.63489 .65884 Mdot
.35844 .67268 Mdot
.30017 .47759 Mdot
.33654 .61919 Mdot
.57274 .69081 Mdot
.40677 .70174 Mdot
.54798 .29211 Mdot
.55117 .7182 Mdot
.62791 .66369 Mdot
.46745 .7042 Mdot
.58519 .69235 Mdot
.5256 .2937 Mdot
.69372 .55719 Mdot
.32278 .61191 Mdot
.30218 .46494 Mdot
.70684 .51383 Mdot
.38609 .6902 Mdot
.42479 .30387 Mdot
.30176 .43589 Mdot
.29101 .52856 Mdot
.33384 .6124 Mdot
.55914 .69541 Mdot
.53807 .71184 Mdot
.29771 .58968 Mdot
.59561 .69062 Mdot
.70943 .53078 Mdot
.37314 .32971 Mdot
.70373 .51617 Mdot
.41783 .69938 Mdot
.40553 .69793 Mdot
.51619 .29334 Mdot
.6144 .32583 Mdot
.37118 .66163 Mdot
.3691 .34325 Mdot
.64274 .66271 Mdot
.55716 .69993 Mdot
.69661 .4487 Mdot
.59112 .70164 Mdot
.41892 .70004 Mdot
.60467 .68997 Mdot
.7002 .49883 Mdot
.62966 .31909 Mdot
.51828 .71713 Mdot
.71402 .50872 Mdot
.65355 .35496 Mdot
.35896 .65556 Mdot
.49191 .28038 Mdot
.6066 .67162 Mdot
.54693 .28858 Mdot
.70399 .47304 Mdot
.30206 .5333 Mdot
.57778 .30078 Mdot
.30206 .53211 Mdot
.70959 .44656 Mdot
.51593 .70701 Mdot
.69363 .44214 Mdot
.36076 .67214 Mdot
.31422 .38765 Mdot
.348 .36751 Mdot
.30835 .59761 Mdot
.60044 .3155 Mdot
.30264 .56974 Mdot
.37079 .66472 Mdot
.35599 .33309 Mdot
.65353 .35845 Mdot
.40895 .31727 Mdot
.37537 .34205 Mdot
.46544 .30091 Mdot
.45478 .69974 Mdot
.63778 .65842 Mdot
.40362 .32116 Mdot
.44673 .28668 Mdot
.61915 .31734 Mdot
.48004 .70961 Mdot
.29205 .51817 Mdot
.35119 .34467 Mdot
.32199 .36251 Mdot
.70142 .43732 Mdot
.71703 .44572 Mdot
.52704 .70713 Mdot
.4013 .30459 Mdot
.68657 .62384 Mdot
.71569 .50573 Mdot
.34932 .63761 Mdot
.61667 .68967 Mdot
.66198 .64665 Mdot
.4042 .30871 Mdot
.29711 .51444 Mdot
.69282 .59286 Mdot
.28831 .45029 Mdot
.66551 .6377 Mdot
.42644 .69516 Mdot
.29689 .58807 Mdot
.54688 .70432 Mdot
.31359 .58677 Mdot
.60117 .32105 Mdot
.47598 .70655 Mdot
.45347 .29311 Mdot
.31682 .37996 Mdot
.53122 .70631 Mdot
.29677 .47317 Mdot
.41964 .29928 Mdot
.3184 .61453 Mdot
.34683 .64021 Mdot
.71575 .46661 Mdot
.60999 .69401 Mdot
.29571 .44078 Mdot
.3881 .68646 Mdot
.46609 .70193 Mdot
.35137 .35824 Mdot
.41527 .30703 Mdot
.32468 .63575 Mdot
.60667 .67595 Mdot
.44358 .30237 Mdot
.50382 .28397 Mdot
.40042 .69939 Mdot
.53795 .2805 Mdot
.62545 .6866 Mdot
.52326 .70876 Mdot
.58804 .31222 Mdot
.69745 .44379 Mdot
.56418 .69153 Mdot
.47015 .7175 Mdot
.56759 .30618 Mdot
.66604 .63465 Mdot
.68374 .62941 Mdot
.3628 .67543 Mdot
.53025 .30041 Mdot
.30178 .39363 Mdot
.35113 .36344 Mdot
.37804 .67695 Mdot
.56572 .29044 Mdot
.33833 .63343 Mdot
.3238 .37227 Mdot
.65819 .64572 Mdot
.56107 .29661 Mdot
.7009 .51268 Mdot
.43273 .29831 Mdot
.38493 .33206 Mdot
.68767 .40412 Mdot
.68084 .59359 Mdot
.42722 .69562 Mdot
.47316 .28798 Mdot
.2862 .48881 Mdot
.39088 .67247 Mdot
.68586 .37956 Mdot
.53838 .71055 Mdot
.65938 .63538 Mdot
.55125 .70645 Mdot
.31056 .61478 Mdot
.30407 .42684 Mdot
.2898 .51525 Mdot
.29596 .52464 Mdot
.58396 .68376 Mdot
.50124 .28319 Mdot
.40151 .31121 Mdot
.31959 .6127 Mdot
.52034 .28449 Mdot
.58257 .70791 Mdot
.38121 .33005 Mdot
.70907 .47166 Mdot
.51376 .7104 Mdot
.3221 .59536 Mdot
.50142 .29991 Mdot
.70619 .41958 Mdot
.29778 .40586 Mdot
.5754 .6901 Mdot
.66674 .37213 Mdot
.53897 .28675 Mdot
.64878 .66024 Mdot
.31509 .38438 Mdot
.29071 .52913 Mdot
.34074 .36761 Mdot
.51462 .69992 Mdot
.57712 .69021 Mdot
.30029 .51603 Mdot
.50278 .70891 Mdot
.67598 .40023 Mdot
.69101 .57283 Mdot
.71509 .52998 Mdot
.46119 .70906 Mdot
.67323 .35877 Mdot
.41953 .29573 Mdot
.31862 .61014 Mdot
.68624 .60223 Mdot
.59641 .68853 Mdot
.66064 .36913 Mdot
.41911 .30469 Mdot
.36129 .32504 Mdot
.52568 .29248 Mdot
.31186 .3882 Mdot
.49667 .28309 Mdot
.42878 .69353 Mdot
.63541 .32861 Mdot
.34198 .35918 Mdot
.30674 .57196 Mdot
.28149 .44978 Mdot
.47454 .71799 Mdot
.36674 .32874 Mdot
.31829 .39862 Mdot
.71872 .50199 Mdot
.58428 .29248 Mdot
.30564 .61312 Mdot
.69061 .58084 Mdot
.6685 .63937 Mdot
.55647 .70602 Mdot
.29314 .50763 Mdot
.51842 .29342 Mdot
.70066 .44602 Mdot
.28715 .50583 Mdot
.41627 .69889 Mdot
.67609 .39533 Mdot
.4157 .70544 Mdot
.66406 .62438 Mdot
.67629 .36478 Mdot
.71701 .55485 Mdot
.54549 .30163 Mdot
.60355 .31707 Mdot
.44256 .71394 Mdot
.68467 .58383 Mdot
.39287 .68493 Mdot
.30685 .40585 Mdot
.72115 .52815 Mdot
.38474 .32444 Mdot
.44782 .30603 Mdot
.30762 .4317 Mdot
.57773 .31172 Mdot
.29559 .48081 Mdot
.69742 .5331 Mdot
.40995 .29916 Mdot
.48044 .29728 Mdot
.33708 .3562 Mdot
.32522 .6251 Mdot
.69512 .55392 Mdot
.3409 .64757 Mdot
.33658 .64339 Mdot
.39923 .3088 Mdot
.60401 .31381 Mdot
.63592 .33673 Mdot
.416 .69024 Mdot
.60696 .31665 Mdot
.3575 .34188 Mdot
.66926 .62194 Mdot
.71912 .52512 Mdot
.43012 .29279 Mdot
.71549 .46623 Mdot
.41729 .68394 Mdot
.33045 .39257 Mdot
.37039 .33408 Mdot
.51175 .28788 Mdot
.54725 .28196 Mdot
.30865 .57213 Mdot
.70048 .43474 Mdot
.57895 .29826 Mdot
.61943 .33682 Mdot
.55659 .28628 Mdot
.6201 .67048 Mdot
.5817 .31421 Mdot
.60537 .32199 Mdot
.53032 .69996 Mdot
.58068 .70609 Mdot
.28974 .5439 Mdot
.31409 .62355 Mdot
.7078 .53239 Mdot
.29541 .55703 Mdot
.54737 .71348 Mdot
.33489 .36996 Mdot
.30228 .60223 Mdot
.30678 .55764 Mdot
.32912 .36202 Mdot
.33866 .35077 Mdot
.33961 .64675 Mdot
.29891 .59745 Mdot
.67427 .39668 Mdot
.69841 .52701 Mdot
.66761 .36172 Mdot
.30455 .41571 Mdot
.39844 .30078 Mdot
.69587 .4479 Mdot
.49885 .70102 Mdot
.29905 .49398 Mdot
.37126 .33868 Mdot
.65556 .36454 Mdot
.48558 .71352 Mdot
.29945 .55447 Mdot
.38017 .67417 Mdot
.30885 .58094 Mdot
.28931 .56021 Mdot
.65187 .3412 Mdot
.54232 .2836 Mdot
.6853 .38697 Mdot
.28437 .45912 Mdot
.31904 .61795 Mdot
.66161 .36113 Mdot
.29228 .47098 Mdot
.34284 .34028 Mdot
.68566 .57938 Mdot
.45966 .70881 Mdot
.3479 .34196 Mdot
.59882 .30507 Mdot
.50931 .27558 Mdot
.7146 .5608 Mdot
.61534 .32743 Mdot
.29723 .48196 Mdot
.30087 .58512 Mdot
.34965 .34563 Mdot
.67711 .39318 Mdot
.71641 .50111 Mdot
.61973 .33371 Mdot
.46237 .29976 Mdot
.53781 .70714 Mdot
.6667 .37197 Mdot
.29423 .54644 Mdot
.62665 .32982 Mdot
.35253 .35994 Mdot
.3908 .67769 Mdot
.58389 .6945 Mdot
.44657 .28858 Mdot
.47231 .70311 Mdot
.4496 .30474 Mdot
.32332 .5939 Mdot
.72241 .4851 Mdot
.56503 .70442 Mdot
.67699 .618 Mdot
.48251 .29718 Mdot
.51037 .70032 Mdot
.64982 .63278 Mdot
.67877 .37696 Mdot
.69319 .40943 Mdot
.57791 .70996 Mdot
.38687 .32501 Mdot
.27888 .52278 Mdot
.51777 .70753 Mdot
.27576 .50803 Mdot
.71338 .5483 Mdot
.32821 .62364 Mdot
.43464 .70504 Mdot
.61427 .67747 Mdot
.587 .69663 Mdot
.49327 .71895 Mdot
.4956 .70161 Mdot
.7039 .58287 Mdot
.31932 .37752 Mdot
.30328 .3954 Mdot
.36778 .66313 Mdot
.69339 .61189 Mdot
.4043 .69388 Mdot
.41317 .30685 Mdot
.69876 .53002 Mdot
.30155 .47009 Mdot
.61324 .32197 Mdot
.47549 .70518 Mdot
.32096 .39153 Mdot
.55584 .70403 Mdot
.71577 .48898 Mdot
.3534 .34447 Mdot
.36225 .34674 Mdot
.29371 .43834 Mdot
.42028 .69951 Mdot
.63312 .34603 Mdot
.45121 .7082 Mdot
.39168 .67151 Mdot
.30851 .56694 Mdot
.69972 .59511 Mdot
.63906 .33144 Mdot
.63692 .34121 Mdot
.63664 .3506 Mdot
.52279 .71976 Mdot
.52163 .72034 Mdot
.4211 .31011 Mdot
.6834 .40499 Mdot
.59046 .31928 Mdot
.35839 .33464 Mdot
.27686 .52221 Mdot
.57807 .70017 Mdot
.32624 .60502 Mdot
.39211 .69327 Mdot
.29242 .43223 Mdot
.28696 .55026 Mdot
.40953 .70319 Mdot
.52969 .7205 Mdot
.35095 .34258 Mdot
.42714 .70328 Mdot
.57334 .29821 Mdot
.38938 .3061 Mdot
.4067 .69421 Mdot
.29385 .53044 Mdot
.67777 .38371 Mdot
.62928 .66806 Mdot
.36295 .67089 Mdot
.41024 .30117 Mdot
.71436 .55634 Mdot
.28857 .56314 Mdot
.32598 .60806 Mdot
.62133 .66489 Mdot
.3309 .36699 Mdot
.29491 .52388 Mdot
.45126 .71933 Mdot
.72299 .50685 Mdot
.34804 .64819 Mdot
.63376 .33674 Mdot
.71657 .52656 Mdot
.59681 .69523 Mdot
.71954 .47018 Mdot
.46237 .28096 Mdot
.30218 .4115 Mdot
.30548 .4026 Mdot
.69551 .45095 Mdot
.67653 .61569 Mdot
.40956 .3195 Mdot
.68162 .61121 Mdot
.43486 .70451 Mdot
.52757 .70002 Mdot
.45897 .71761 Mdot
.69816 .56641 Mdot
.42897 .71337 Mdot
.39969 .68648 Mdot
.47936 .29286 Mdot
.50642 .28089 Mdot
.53016 .29562 Mdot
.39106 .32264 Mdot
.66767 .61743 Mdot
.30375 .40018 Mdot
.56409 .29471 Mdot
.3754 .67921 Mdot
.28285 .47464 Mdot
.44132 .70088 Mdot
.54455 .71416 Mdot
.71767 .45376 Mdot
.2906 .52223 Mdot
.54806 .69756 Mdot
.44908 .30248 Mdot
.29046 .43237 Mdot
.32956 .35423 Mdot
.6975 .46846 Mdot
.58242 .30771 Mdot
.3567 .351 Mdot
.43863 .70666 Mdot
.38933 .69298 Mdot
.69534 .60514 Mdot
.35 .66761 Mdot
.32558 .38079 Mdot
.62552 .68263 Mdot
.65598 .36347 Mdot
.34043 .37707 Mdot
.47009 .70586 Mdot
.36182 .35345 Mdot
.28375 .55768 Mdot
.71968 .50217 Mdot
.60871 .6776 Mdot
.39135 .30614 Mdot
.68263 .60645 Mdot
.42798 .71031 Mdot
.30039 .51435 Mdot
.61964 .66113 Mdot
.32622 .36865 Mdot
.2842 .43896 Mdot
.39887 .68383 Mdot
.69123 .3856 Mdot
.64591 .34758 Mdot
.67329 .394 Mdot
.44828 .30393 Mdot
.50785 .70576 Mdot
.34696 .34703 Mdot
.69463 .42493 Mdot
.6416 .66346 Mdot
.55558 .29965 Mdot
.28146 .45349 Mdot
.50106 .70865 Mdot
.56175 .7045 Mdot
.39269 .68146 Mdot
.40039 .67644 Mdot
.31655 .59733 Mdot
.33887 .34318 Mdot
.58769 .68171 Mdot
.70844 .49723 Mdot
.51777 .71743 Mdot
.64002 .33395 Mdot
.30266 .57251 Mdot
.39687 .69294 Mdot
.56857 .68957 Mdot
.64525 .64488 Mdot
.6373 .33355 Mdot
.55406 .30481 Mdot
.30779 .57975 Mdot
.59747 .67772 Mdot
.48838 .70601 Mdot
.60286 .6936 Mdot
.71116 .5293 Mdot
.42471 .68748 Mdot
.32094 .40449 Mdot
.70702 .47734 Mdot
.35046 .63483 Mdot
.62733 .34178 Mdot
.2917 .46908 Mdot
.68414 .57948 Mdot
.6736 .60422 Mdot
.67583 .36307 Mdot
.60296 .30429 Mdot
.46488 .29942 Mdot
.57061 .30439 Mdot
.32868 .60626 Mdot
.52934 .70291 Mdot
.30303 .59422 Mdot
.61333 .33078 Mdot
.3059 .40696 Mdot
.40657 .69706 Mdot
.28548 .49152 Mdot
.52108 .71458 Mdot
.33433 .36012 Mdot
.31669 .62068 Mdot
.66357 .36326 Mdot
.33063 .37332 Mdot
.29051 .52976 Mdot
.35394 .64595 Mdot
.70817 .56555 Mdot
.30106 .46057 Mdot
.29904 .52872 Mdot
.55129 .70335 Mdot
.70981 .4615 Mdot
.71668 .46744 Mdot
.35934 .67108 Mdot
.29609 .40573 Mdot
.29533 .5386 Mdot
.7085 .45575 Mdot
.72146 .48996 Mdot
.32667 .38745 Mdot
.69108 .43018 Mdot
.68929 .57565 Mdot
.3039 .54147 Mdot
.62862 .32259 Mdot
.28795 .50571 Mdot
.64016 .35731 Mdot
.64139 .66283 Mdot
.43253 .68867 Mdot
.39542 .32094 Mdot
.38861 .68064 Mdot
.40209 .31345 Mdot
.49521 .2945 Mdot
.47252 .29458 Mdot
.42079 .3145 Mdot
.48442 .70622 Mdot
.60671 .32195 Mdot
.52244 .28147 Mdot
.70178 .45136 Mdot
.36041 .3512 Mdot
.38646 .32668 Mdot
.71608 .45058 Mdot
.40665 .69918 Mdot
.44607 .70397 Mdot
.30802 .4045 Mdot
.31168 .42227 Mdot
.66192 .36205 Mdot
.43102 .71093 Mdot
.69438 .56554 Mdot
.30236 .4571 Mdot
.68837 .61855 Mdot
.68377 .37331 Mdot
.30415 .58961 Mdot
.68727 .42548 Mdot
.66809 .64256 Mdot
.37175 .32673 Mdot
.30001 .45068 Mdot
.68145 .6093 Mdot
.37258 .32278 Mdot
.54818 .29056 Mdot
.32681 .37577 Mdot
.49737 .71265 Mdot
.28483 .48697 Mdot
.37611 .67504 Mdot
.67667 .59415 Mdot
.32147 .61599 Mdot
.70013 .45655 Mdot
.51356 .27808 Mdot
.29902 .59847 Mdot
.40258 .31339 Mdot
.53433 .29736 Mdot
.66769 .35667 Mdot
.59542 .69533 Mdot
.36295 .34362 Mdot
.40061 .32434 Mdot
.44908 .71247 Mdot
.32984 .39182 Mdot
.6491 .35846 Mdot
.34229 .34397 Mdot
.65232 .642 Mdot
.57337 .71063 Mdot
.28996 .57414 Mdot
.30943 .60485 Mdot
.31138 .4273 Mdot
.50972 .69988 Mdot
.6941 .39813 Mdot
.30055 .39961 Mdot
.36787 .3489 Mdot
.72055 .47787 Mdot
.509 .28004 Mdot
.35677 .67327 Mdot
.36197 .33923 Mdot
.60457 .67255 Mdot
.57746 .69965 Mdot
.49124 .29093 Mdot
.35736 .34315 Mdot
.29087 .49859 Mdot
.44512 .28923 Mdot
.68897 .40648 Mdot
.69414 .59711 Mdot
.7005 .42463 Mdot
.40891 .70237 Mdot
.314 .39339 Mdot
.41084 .30983 Mdot
.31396 .60295 Mdot
.27964 .51508 Mdot
.40906 .31809 Mdot
.62965 .33624 Mdot
.59936 .69543 Mdot
.63015 .67248 Mdot
.50225 .70838 Mdot
.70066 .59955 Mdot
.42509 .706 Mdot
.5076 .29807 Mdot
.46501 .29821 Mdot
.69291 .59946 Mdot
.42885 .7052 Mdot
.3108 .38547 Mdot
.35063 .34702 Mdot
.47346 .28937 Mdot
.29044 .56554 Mdot
.30813 .38987 Mdot
.56086 .70223 Mdot
.27818 .48656 Mdot
.67391 .37023 Mdot
.50505 .2799 Mdot
.59598 .68924 Mdot
.41108 .31738 Mdot
.65278 .3417 Mdot
.67386 .61226 Mdot
.50612 .7061 Mdot
.35872 .66819 Mdot
.55715 .29624 Mdot
.53947 .28009 Mdot
.3308 .39256 Mdot
.47651 .69982 Mdot
.4258 .30521 Mdot
.29487 .48064 Mdot
.27997 .47672 Mdot
.60558 .32671 Mdot
.37624 .34129 Mdot
.49423 .27911 Mdot
.32252 .63011 Mdot
.34929 .63346 Mdot
.33594 .37141 Mdot
.34078 .37426 Mdot
.707 .52056 Mdot
.39434 .67179 Mdot
.3997 .70093 Mdot
.59742 .30203 Mdot
.57116 .30954 Mdot
.71685 .48045 Mdot
.60578 .67216 Mdot
.51414 .72131 Mdot
.51688 .2937 Mdot
.63533 .32598 Mdot
.62309 .6866 Mdot
.50163 .71755 Mdot
.63588 .6673 Mdot
.68303 .38553 Mdot
.58918 .30332 Mdot
.68722 .61597 Mdot
.71214 .51448 Mdot
.66188 .62166 Mdot
.6222 .32851 Mdot
.63385 .34374 Mdot
.67488 .60423 Mdot
.71006 .50995 Mdot
.68461 .41077 Mdot
.51193 .28259 Mdot
.54931 .29122 Mdot
.61625 .33497 Mdot
.71939 .45695 Mdot
.51221 .29372 Mdot
.70375 .44538 Mdot
.38721 .32985 Mdot
.65456 .62751 Mdot
.56111 .28513 Mdot
.71921 .53365 Mdot
.54854 .29251 Mdot
.67856 .62283 Mdot
.71699 .53836 Mdot
.42676 .68848 Mdot
.59281 .6978 Mdot
.39107 .67205 Mdot
.31386 .60116 Mdot
.3399 .6475 Mdot
.51816 .29308 Mdot
.47042 .7153 Mdot
.70557 .46056 Mdot
.50348 .72052 Mdot
.59007 .70206 Mdot
.61815 .66608 Mdot
.61248 .66643 Mdot
.6108 .33156 Mdot
.70488 .46786 Mdot
.27705 .49611 Mdot
.29226 .42599 Mdot
.64853 .64171 Mdot
.55362 .29405 Mdot
.62467 .32734 Mdot
.58745 .31626 Mdot
.32576 .36996 Mdot
.36533 .34245 Mdot
.29667 .56543 Mdot
.29492 .52326 Mdot
.33485 .3671 Mdot
.27619 .49045 Mdot
.66904 .63124 Mdot
.69442 .43995 Mdot
.70763 .4788 Mdot
.61351 .68338 Mdot
.64673 .66492 Mdot
.3851 .67836 Mdot
.30083 .4591 Mdot
.44116 .30372 Mdot
.68699 .60555 Mdot
.53965 .71997 Mdot
.29997 .53304 Mdot
.4508 .28096 Mdot
.35479 .65684 Mdot
.51736 .27966 Mdot
.34615 .63552 Mdot
.33442 .37853 Mdot
.49896 .70928 Mdot
.48679 .71779 Mdot
.45957 .29805 Mdot
.29979 .42649 Mdot
.35881 .33623 Mdot
.39139 .68529 Mdot
.61118 .68225 Mdot
.34266 .35309 Mdot
.56127 .28376 Mdot
.63658 .32849 Mdot
.31532 .61904 Mdot
.49153 .71372 Mdot
.61489 .67632 Mdot
.72065 .49537 Mdot
.31009 .57583 Mdot
.30683 .57556 Mdot
.56943 .29836 Mdot
.6709 .63478 Mdot
.35667 .32685 Mdot
.29832 .51685 Mdot
.61348 .33528 Mdot
.35723 .34855 Mdot
.31051 .57901 Mdot
.34654 .65659 Mdot
.4601 .71621 Mdot
.34022 .65634 Mdot
.61483 .3178 Mdot
.69892 .41551 Mdot
.69675 .54623 Mdot
.60741 .30403 Mdot
.33875 .62222 Mdot
.37796 .68436 Mdot
.3079 .43656 Mdot
.45141 .29266 Mdot
.66778 .64538 Mdot
.38284 .68468 Mdot
.60246 .32574 Mdot
.71431 .4496 Mdot
.71167 .49347 Mdot
.70107 .53466 Mdot
.70253 .44577 Mdot
.56674 .69443 Mdot
.308 .42176 Mdot
.62767 .33393 Mdot
.70454 .51393 Mdot
.64018 .67152 Mdot
.6661 .37478 Mdot
.56385 .3075 Mdot
.69015 .57889 Mdot
.60875 .32311 Mdot
.69968 .59016 Mdot
.57563 .31095 Mdot
.66209 .63262 Mdot
.33102 .3544 Mdot
.30685 .44051 Mdot
.51191 .28675 Mdot
.2838 .44919 Mdot
.33985 .35348 Mdot
.36308 .33544 Mdot
.58751 .30443 Mdot
.31566 .4032 Mdot
.70485 .47311 Mdot
.28626 .48728 Mdot
.59929 .67706 Mdot
.33417 .61998 Mdot
.30738 .43001 Mdot
.6219 .33821 Mdot
.56244 .29284 Mdot
.41717 .68805 Mdot
.59721 .70214 Mdot
.40354 .30627 Mdot
.3644 .6604 Mdot
.66881 .62186 Mdot
.34956 .63694 Mdot
.31506 .38254 Mdot
.54519 .69528 Mdot
.57926 .69922 Mdot
.37991 .31508 Mdot
.38992 .68098 Mdot
.63184 .34415 Mdot
.70456 .52707 Mdot
.4164 .313 Mdot
.37979 .67817 Mdot
.40468 .69805 Mdot
.50656 .70663 Mdot
.70063 .41899 Mdot
.38036 .3242 Mdot
.46638 .28671 Mdot
.28209 .54848 Mdot
.70131 .5898 Mdot
.64646 .65245 Mdot
.5603 .70772 Mdot
.66024 .62796 Mdot
.29054 .47094 Mdot
.51726 .28557 Mdot
.56624 .70629 Mdot
.29292 .4767 Mdot
.48538 .69977 Mdot
.64382 .33254 Mdot
.29611 .45239 Mdot
.32183 .63329 Mdot
.28991 .54044 Mdot
.47408 .7095 Mdot
.47946 .7217 Mdot
.60783 .67557 Mdot
.4904 .28904 Mdot
.32567 .6274 Mdot
.28816 .44247 Mdot
.65281 .35958 Mdot
.45814 .71517 Mdot
.71031 .52494 Mdot
.49218 .29031 Mdot
.34472 .35233 Mdot
.46636 .71831 Mdot
.37911 .66331 Mdot
.72283 .5135 Mdot
.58297 .70607 Mdot
.47756 .71087 Mdot
.55069 .3001 Mdot
.46551 .2852 Mdot
.6872 .37754 Mdot
.2903 .57686 Mdot
.66244 .36392 Mdot
.43404 .29693 Mdot
.47486 .7212 Mdot
.30567 .59796 Mdot
.68999 .39019 Mdot
.31043 .61042 Mdot
.4687 .27992 Mdot
.62272 .6671 Mdot
.69988 .41793 Mdot
.30893 .59808 Mdot
.71348 .54099 Mdot
.7148 .47346 Mdot
.6298 .65928 Mdot
.46145 .69923 Mdot
.64527 .35134 Mdot
.62861 .33362 Mdot
.70552 .44249 Mdot
.29991 .58115 Mdot
.52835 .71425 Mdot
.44876 .70221 Mdot
.44895 .69342 Mdot
.64469 .33584 Mdot
.48581 .70718 Mdot
.65144 .36572 Mdot
.64764 .63813 Mdot
.32188 .36339 Mdot
.50477 .71928 Mdot
.49918 .28583 Mdot
.44883 .69946 Mdot
.41688 .70721 Mdot
.69927 .58021 Mdot
.71276 .52853 Mdot
.5267 .2869 Mdot
.6227 .68361 Mdot
.29323 .48835 Mdot
.47032 .71642 Mdot
.34273 .63136 Mdot
.39159 .30975 Mdot
.63145 .66451 Mdot
.67832 .39928 Mdot
.62312 .33652 Mdot
.33878 .37091 Mdot
.55582 .29253 Mdot
.31419 .38815 Mdot
.69818 .52757 Mdot
.3 .59411 Mdot
.28274 .48216 Mdot
.61037 .6699 Mdot
.65181 .64953 Mdot
.29172 .51212 Mdot
.70108 .476 Mdot
.31699 .41024 Mdot
.65423 .66086 Mdot
.71698 .45167 Mdot
.39241 .67802 Mdot
.35125 .64167 Mdot
.418 .69106 Mdot
.69867 .43389 Mdot
.56831 .29623 Mdot
.55214 .29989 Mdot
.41141 .31864 Mdot
.43128 .71231 Mdot
.42613 .28818 Mdot
.46875 .28291 Mdot
.31676 .41623 Mdot
.5169 .27862 Mdot
.52503 .71704 Mdot
.33911 .64502 Mdot
.68271 .39533 Mdot
.31015 .58305 Mdot
.66485 .64667 Mdot
.37596 .34256 Mdot
.29756 .58305 Mdot
.38738 .66802 Mdot
.4882 .28083 Mdot
.34552 .36079 Mdot
.60116 .69311 Mdot
.62887 .33302 Mdot
.70951 .41929 Mdot
.28422 .53925 Mdot
.71147 .5325 Mdot
.7064 .54886 Mdot
.68325 .38135 Mdot
.33423 .63162 Mdot
.27935 .54135 Mdot
.69946 .56372 Mdot
.47312 .29676 Mdot
.31641 .58292 Mdot
.30093 .42709 Mdot
.30976 .39871 Mdot
.34009 .36009 Mdot
.6735 .63722 Mdot
.31137 .38008 Mdot
.68947 .58844 Mdot
.41446 .31345 Mdot
.40065 .30099 Mdot
.54984 .6996 Mdot
.35136 .3474 Mdot
.30056 .52267 Mdot
.57215 .6989 Mdot
.6911 .40431 Mdot
.33579 .35199 Mdot
.42391 .6863 Mdot
.2756 .48553 Mdot
.464 .30051 Mdot
.29902 .57849 Mdot
.7155 .55535 Mdot
.51978 .28256 Mdot
.60318 .30937 Mdot
.63349 .65598 Mdot
.37637 .67716 Mdot
.70471 .42298 Mdot
.32219 .59651 Mdot
.3977 .69776 Mdot
.65562 .62734 Mdot
.58942 .29594 Mdot
.3301 .645 Mdot
.35362 .6464 Mdot
.38446 .66431 Mdot
.33582 .36322 Mdot
.29232 .47564 Mdot
.29456 .53492 Mdot
.60312 .69215 Mdot
.28926 .45914 Mdot
.50102 .28425 Mdot
.5612 .7082 Mdot
.36483 .33321 Mdot
.33218 .64103 Mdot
.49449 .71625 Mdot
.71139 .51836 Mdot
.67934 .38059 Mdot
.31655 .62766 Mdot
.34273 .63359 Mdot
.69466 .40845 Mdot
.5448 .70852 Mdot
.33816 .61827 Mdot
.28267 .54777 Mdot
.57054 .69615 Mdot
.59314 .3142 Mdot
.57419 .29902 Mdot
.30404 .40793 Mdot
.55331 .30511 Mdot
.39591 .32798 Mdot
.34377 .63048 Mdot
.46499 .71691 Mdot
.29353 .55409 Mdot
.69234 .57497 Mdot
.6982 .57798 Mdot
.32617 .38411 Mdot
.63489 .34624 Mdot
.52473 .30045 Mdot
.70101 .57715 Mdot
.56511 .6992 Mdot
.47883 .71221 Mdot
.2969 .45282 Mdot
.64974 .35318 Mdot
.48542 .7133 Mdot
.3079 .60981 Mdot
.56195 .69788 Mdot
.36958 .6624 Mdot
.32617 .35961 Mdot
.29645 .50885 Mdot
.61737 .31114 Mdot
.30425 .58506 Mdot
.36311 .33709 Mdot
.5976 .67477 Mdot
.6634 .62261 Mdot
.44332 .70787 Mdot
.61728 .31922 Mdot
.655 .34502 Mdot
.36721 .33973 Mdot
.29034 .47709 Mdot
.70554 .54156 Mdot
.70477 .53143 Mdot
.57411 .69899 Mdot
.31494 .38341 Mdot
.28848 .42463 Mdot
.30812 .60464 Mdot
.28967 .56539 Mdot
.64072 .64644 Mdot
.34258 .36904 Mdot
.49585 .70886 Mdot
.71785 .45923 Mdot
.48018 .27789 Mdot
.69646 .4205 Mdot
.44843 .29042 Mdot
.49371 .2755 Mdot
.65986 .65419 Mdot
.5724 .68648 Mdot
.43903 .3058 Mdot
.4859 .29571 Mdot
.3205 .41078 Mdot
.63819 .64459 Mdot
.40748 .6958 Mdot
.61107 .67036 Mdot
.31147 .38943 Mdot
.54156 .71241 Mdot
.64137 .3547 Mdot
.2861 .53566 Mdot
.5009 .29438 Mdot
.45584 .71227 Mdot
.69253 .56137 Mdot
.29587 .44263 Mdot
.30072 .53066 Mdot
.31749 .60793 Mdot
.61759 .67408 Mdot
.49088 .70846 Mdot
.30469 .40655 Mdot
.71115 .55099 Mdot
.43165 .29743 Mdot
.31562 .42157 Mdot
.69694 .43258 Mdot
.45917 .70452 Mdot
.66549 .37719 Mdot
.48298 .27913 Mdot
.31919 .59545 Mdot
.40754 .68798 Mdot
.47627 .7181 Mdot
.68392 .58068 Mdot
.43275 .3086 Mdot
.70538 .53662 Mdot
.71407 .49733 Mdot
.29703 .54661 Mdot
.69564 .56425 Mdot
.59219 .70491 Mdot
.62974 .68364 Mdot
.30886 .56888 Mdot
.47157 .28145 Mdot
.65732 .65188 Mdot
.30465 .54734 Mdot
.7043 .5756 Mdot
.52231 .27799 Mdot
.70592 .53704 Mdot
.5235 .29228 Mdot
.31518 .42106 Mdot
.45872 .30112 Mdot
.35195 .63636 Mdot
.3136 .4189 Mdot
.70563 .41343 Mdot
.60684 .32167 Mdot
.58047 .31206 Mdot
.35487 .64744 Mdot
.5106 .28866 Mdot
.33733 .36917 Mdot
.4742 .29927 Mdot
.62025 .31017 Mdot
.60208 .67362 Mdot
.65918 .65415 Mdot
.54227 .30439 Mdot
.2956 .42331 Mdot
.61594 .33456 Mdot
.46216 .29301 Mdot
.71784 .54569 Mdot
.38299 .66654 Mdot
.4671 .7084 Mdot
.48576 .28068 Mdot
.29978 .44147 Mdot
.6779 .37043 Mdot
.34909 .64196 Mdot
.53825 .2798 Mdot
.32947 .38256 Mdot
.53814 .70161 Mdot
.49832 .29497 Mdot
.28024 .50135 Mdot
.45576 .29731 Mdot
.62539 .67615 Mdot
.29362 .5804 Mdot
.31166 .61645 Mdot
.66871 .37017 Mdot
.29922 .48477 Mdot
.29531 .47967 Mdot
.48051 .29808 Mdot
.69582 .39197 Mdot
.27824 .47983 Mdot
.60403 .69227 Mdot
.70197 .51962 Mdot
.29714 .55856 Mdot
.63886 .34021 Mdot
.71378 .51939 Mdot
.29446 .56394 Mdot
.64814 .637 Mdot
.69885 .42119 Mdot
.32366 .36667 Mdot
.55854 .70276 Mdot
.40945 .29684 Mdot
.42249 .30122 Mdot
.29677 .48439 Mdot
.40495 .31225 Mdot
.7039 .57622 Mdot
.58439 .29278 Mdot
.69581 .55361 Mdot
.36756 .66102 Mdot
.67859 .40723 Mdot
.30784 .60627 Mdot
.41181 .68526 Mdot
.54634 .70334 Mdot
.36503 .34207 Mdot
.2822 .4676 Mdot
.64397 .64442 Mdot
.62124 .32884 Mdot
.69208 .58792 Mdot
.70547 .54802 Mdot
.70549 .53358 Mdot
.41032 .31842 Mdot
.66588 .62378 Mdot
.49036 .70771 Mdot
.53945 .3021 Mdot
.71622 .55995 Mdot
.63548 .67212 Mdot
.29735 .47499 Mdot
.71365 .52511 Mdot
.39604 .30675 Mdot
.69402 .43737 Mdot
.36208 .34373 Mdot
.69631 .39923 Mdot
.69875 .4462 Mdot
.594 .3081 Mdot
.43182 .2877 Mdot
.70484 .5542 Mdot
.37723 .31312 Mdot
.67404 .36898 Mdot
.64202 .66725 Mdot
.64662 .36 Mdot
.27998 .547 Mdot
.70156 .40262 Mdot
.60622 .31128 Mdot
.70313 .50491 Mdot
.64769 .3498 Mdot
.58967 .69486 Mdot
.59878 .68834 Mdot
.62896 .65626 Mdot
.28696 .47902 Mdot
.50937 .70955 Mdot
.34209 .65269 Mdot
.36386 .65597 Mdot
.68634 .38365 Mdot
.3085 .58167 Mdot
.67826 .59738 Mdot
.31343 .58495 Mdot
.55947 .70919 Mdot
.49914 .7155 Mdot
.70048 .5419 Mdot
.66366 .63616 Mdot
.28552 .47677 Mdot
.63677 .3498 Mdot
.64146 .6699 Mdot
.27895 .49536 Mdot
.52734 .69954 Mdot
.69405 .58762 Mdot
.63265 .6796 Mdot
.363 .34361 Mdot
.69267 .42766 Mdot
.33704 .64391 Mdot
.66973 .39235 Mdot
.46874 .70211 Mdot
.3356 .63107 Mdot
.33213 .61123 Mdot
.49545 .71413 Mdot
.6687 .38305 Mdot
.71014 .53335 Mdot
.61185 .31362 Mdot
.65291 .34957 Mdot
.56407 .69941 Mdot
.69072 .41527 Mdot
.58701 .30116 Mdot
.70546 .53045 Mdot
.29456 .44557 Mdot
.34827 .33732 Mdot
.64028 .65782 Mdot
.35073 .64526 Mdot
.52474 .70438 Mdot
.36803 .67666 Mdot
.33145 .63107 Mdot
.29636 .53119 Mdot
.56999 .69169 Mdot
.28551 .44154 Mdot
.34669 .64646 Mdot
.28691 .47454 Mdot
.6172 .30852 Mdot
.66591 .35989 Mdot
.43799 .29586 Mdot
.29165 .48528 Mdot
.29568 .53601 Mdot
.61533 .67951 Mdot
.69355 .60238 Mdot
.41562 .3106 Mdot
.65953 .35603 Mdot
.63291 .66263 Mdot
.29722 .49425 Mdot
.34124 .34708 Mdot
.39879 .32361 Mdot
.47913 .2978 Mdot
.70955 .45182 Mdot
.53784 .71611 Mdot
.29273 .51069 Mdot
.68996 .5798 Mdot
.31659 .60946 Mdot
.33693 .65312 Mdot
.28059 .45641 Mdot
.51468 .71315 Mdot
.71774 .53688 Mdot
.33816 .3536 Mdot
.36179 .66791 Mdot
.6598 .35623 Mdot
.33958 .62351 Mdot
.38298 .31305 Mdot
.68092 .375 Mdot
.32464 .37645 Mdot
.29414 .51372 Mdot
.54352 .71139 Mdot
.7005 .4461 Mdot
.70035 .47294 Mdot
.69246 .41164 Mdot
.36521 .65965 Mdot
.30269 .40427 Mdot
.28306 .52991 Mdot
.59684 .69403 Mdot
.59157 .29619 Mdot
.46867 .71972 Mdot
.53976 .7051 Mdot
.54457 .28903 Mdot
.71808 .50252 Mdot
.59436 .31462 Mdot
.71363 .53137 Mdot
.67347 .36269 Mdot
.39087 .32413 Mdot
.41225 .68187 Mdot
.58654 .69462 Mdot
.62852 .66617 Mdot
.3569 .65987 Mdot
.64849 .34711 Mdot
.62431 .66381 Mdot
.68821 .61869 Mdot
.63043 .66782 Mdot
.48034 .71359 Mdot
.65999 .65337 Mdot
.34942 .658 Mdot
.29209 .55334 Mdot
.7059 .56637 Mdot
.46643 .69884 Mdot
.67015 .38343 Mdot
.67937 .38682 Mdot
.7138 .54319 Mdot
.51779 .29431 Mdot
.70622 .4216 Mdot
.33938 .35127 Mdot
.4094 .31485 Mdot
.27775 .50384 Mdot
.42614 .69965 Mdot
.70199 .54812 Mdot
.49058 .72134 Mdot
.51371 .29447 Mdot
.37088 .67228 Mdot
.62887 .32306 Mdot
.4046 .70065 Mdot
.68186 .6098 Mdot
.35442 .63939 Mdot
.28599 .54423 Mdot
.43305 .28999 Mdot
.71741 .45897 Mdot
.33641 .62774 Mdot
.69501 .41282 Mdot
.63682 .66064 Mdot
.59716 .68349 Mdot
.54863 .28471 Mdot
.4062 .69205 Mdot
.28192 .54915 Mdot
.51786 .7005 Mdot
.69017 .61452 Mdot
.52383 .29361 Mdot
.34848 .63294 Mdot
.56281 .29803 Mdot
.71866 .48748 Mdot
.64729 .3327 Mdot
.6256 .33419 Mdot
.42378 .29867 Mdot
.69331 .58775 Mdot
.36195 .64684 Mdot
.32955 .37101 Mdot
.63315 .64957 Mdot
.28446 .47711 Mdot
.35522 .66229 Mdot
.64587 .6582 Mdot
.31251 .41471 Mdot
.64038 .6709 Mdot
.43951 .3009 Mdot
.4504 .70731 Mdot
.71732 .51457 Mdot
.53819 .6972 Mdot
.36273 .33287 Mdot
.34218 .35828 Mdot
.28414 .49141 Mdot
.67859 .62909 Mdot
.64206 .67259 Mdot
.70108 .45923 Mdot
.3046 .40435 Mdot
.59792 .31536 Mdot
.64281 .34676 Mdot
.28617 .44476 Mdot
.63678 .33197 Mdot
.40549 .69864 Mdot
.5398 .6964 Mdot
.44104 .30067 Mdot
.4503 .29662 Mdot
.33177 .37016 Mdot
.31007 .4085 Mdot
.36431 .34323 Mdot
.71826 .49864 Mdot
.58071 .29176 Mdot
.6433 .65185 Mdot
.47637 .70111 Mdot
.47161 .71527 Mdot
.6965 .43332 Mdot
.70498 .57045 Mdot
.50889 .72446 Mdot
.38796 .67451 Mdot
.36385 .33734 Mdot
.52692 .28008 Mdot
.70476 .50339 Mdot
.52596 .29837 Mdot
.57141 .6937 Mdot
.3609 .3302 Mdot
.68183 .4076 Mdot
.36157 .64761 Mdot
.71919 .46844 Mdot
.41368 .69212 Mdot
.4771 .27937 Mdot
.701 .46993 Mdot
.67384 .61727 Mdot
.55518 .69917 Mdot
.67174 .61177 Mdot
.31254 .57888 Mdot
.67915 .36643 Mdot
.55934 .29973 Mdot
.71632 .46276 Mdot
.31544 .59266 Mdot
.72296 .49387 Mdot
.67131 .63945 Mdot
.48473 .70065 Mdot
.64661 .66087 Mdot
.60713 .68818 Mdot
.68822 .40467 Mdot
.68807 .59704 Mdot
.29291 .51463 Mdot
.59345 .69159 Mdot
.42149 .2905 Mdot
.56113 .70995 Mdot
.47687 .71598 Mdot
.55583 .71344 Mdot
.62065 .68554 Mdot
.70743 .42854 Mdot
.70098 .53295 Mdot
.53747 .30064 Mdot
.67572 .62848 Mdot
.43806 .29284 Mdot
.33958 .36437 Mdot
.29965 .46699 Mdot
.68441 .39676 Mdot
.40957 .68885 Mdot
.3732 .32128 Mdot
.66316 .6381 Mdot
.27737 .50903 Mdot
.61215 .68853 Mdot
.28535 .5442 Mdot
.33757 .64316 Mdot
.36468 .64927 Mdot
.41616 .3181 Mdot
.50747 .28372 Mdot
.62459 .68403 Mdot
.6063 .32464 Mdot
.60743 .31625 Mdot
.58384 .69355 Mdot
.46135 .27927 Mdot
.42329 .30117 Mdot
.30865 .42725 Mdot
.536 .71598 Mdot
.59941 .68861 Mdot
.63493 .32943 Mdot
.28739 .51132 Mdot
.66192 .61923 Mdot
.38876 .68477 Mdot
.48018 .72012 Mdot
.2972 .49739 Mdot
.68451 .60045 Mdot
.53772 .29979 Mdot
.33081 .64368 Mdot
.53947 .72051 Mdot
.60418 .67424 Mdot
.7009 .5639 Mdot
.42531 .69683 Mdot
.29147 .42123 Mdot
.55628 .70175 Mdot
.53726 .70386 Mdot
.69962 .42445 Mdot
.46066 .2994 Mdot
.63262 .34584 Mdot
.68638 .42558 Mdot
.29613 .53214 Mdot
.45939 .30246 Mdot
.42409 .68868 Mdot
.39449 .3117 Mdot
.71781 .50432 Mdot
.66684 .64022 Mdot
.55997 .30041 Mdot
.66236 .3657 Mdot
.63377 .32538 Mdot
.59843 .68129 Mdot
.71627 .48771 Mdot
.52411 .70418 Mdot
.2908 .4791 Mdot
.29681 .48264 Mdot
.55775 .69864 Mdot
.61961 .32366 Mdot
.56381 .70428 Mdot
.47738 .28103 Mdot
.32969 .61518 Mdot
.6162 .32576 Mdot
.30022 .43325 Mdot
.40525 .3203 Mdot
.29655 .41893 Mdot
.29232 .58 Mdot
.70066 .55762 Mdot
.69658 .40433 Mdot
.60769 .32921 Mdot
.67819 .60247 Mdot
.36196 .33792 Mdot
.37692 .67066 Mdot
.52292 .70602 Mdot
.29916 .49264 Mdot
.40694 .29882 Mdot
.61107 .30684 Mdot
.64712 .63936 Mdot
.34444 .62612 Mdot
.69428 .60082 Mdot
.29873 .54677 Mdot
.51817 .71621 Mdot
.35289 .6371 Mdot
.3341 .38116 Mdot
.71156 .54196 Mdot
.3517 .6649 Mdot
.28801 .46598 Mdot
.42113 .31608 Mdot
.42305 .29723 Mdot
.29574 .41186 Mdot
.43216 .70572 Mdot
.29693 .51451 Mdot
.6092 .32064 Mdot
.49735 .7116 Mdot
.29888 .55646 Mdot
.38126 .32978 Mdot
.3054 .59873 Mdot
.4521 .70524 Mdot
.66461 .38033 Mdot
.33034 .37516 Mdot
.55561 .70419 Mdot
.70771 .54797 Mdot
.68349 .37861 Mdot
.29966 .4384 Mdot
.69007 .58936 Mdot
.43714 .71394 Mdot
.34788 .36841 Mdot
.36522 .33193 Mdot
.57869 .69245 Mdot
.3736 .66099 Mdot
.45132 .69853 Mdot
.50684 .28107 Mdot
.69045 .60563 Mdot
.45996 .29807 Mdot
.60286 .6976 Mdot
.60493 .69481 Mdot
.66918 .62898 Mdot
.65876 .34299 Mdot
.2888 .51306 Mdot
.52156 .70673 Mdot
.43469 .69293 Mdot
.64592 .35864 Mdot
.72345 .51924 Mdot
.65012 .64559 Mdot
.68851 .41571 Mdot
.33281 .6156 Mdot
.5124 .29164 Mdot
.52291 .70572 Mdot
.37669 .31661 Mdot
.37057 .66373 Mdot
.60588 .68064 Mdot
.6438 .64024 Mdot
.63474 .34457 Mdot
.50633 .72261 Mdot
.62133 .333 Mdot
.65298 .64903 Mdot
.69497 .38785 Mdot
.45956 .29362 Mdot
.61874 .68067 Mdot
.29738 .51677 Mdot
.2798 .49769 Mdot
.64994 .66046 Mdot
.39149 .68075 Mdot
.71851 .51015 Mdot
.29796 .53542 Mdot
.51653 .27957 Mdot
.33923 .34444 Mdot
.36674 .34097 Mdot
.43818 .28493 Mdot
.69455 .39271 Mdot
.30178 .43834 Mdot
.30028 .58952 Mdot
.70344 .56095 Mdot
.4273 .71214 Mdot
.45022 .30469 Mdot
.44247 .69729 Mdot
.51681 .72079 Mdot
.2951 .45656 Mdot
.33342 .35216 Mdot
.65901 .37547 Mdot
.68913 .38009 Mdot
.70216 .46728 Mdot
.35993 .6649 Mdot
.29621 .44558 Mdot
.41812 .68682 Mdot
.51464 .71117 Mdot
.34041 .37547 Mdot
.69347 .42873 Mdot
.3613 .65231 Mdot
.31237 .61813 Mdot
.50266 .29174 Mdot
.2814 .47751 Mdot
.61434 .32465 Mdot
.29243 .44412 Mdot
.28376 .52747 Mdot
.70403 .50041 Mdot
.60992 .68362 Mdot
.51547 .2832 Mdot
.30265 .42374 Mdot
.58692 .30755 Mdot
.57432 .69167 Mdot
.32118 .61836 Mdot
.29378 .583 Mdot
.66982 .36063 Mdot
.32548 .37795 Mdot
.38094 .66655 Mdot
.66295 .64779 Mdot
.38361 .66351 Mdot
.6971 .44016 Mdot
.32209 .39156 Mdot
.32714 .63513 Mdot
.5273 .2795 Mdot
.56188 .70468 Mdot
.36493 .65783 Mdot
.51926 .28433 Mdot
.29023 .53724 Mdot
.60137 .67654 Mdot
.64891 .64568 Mdot
.69846 .56421 Mdot
.53222 .2949 Mdot
.66634 .61567 Mdot
.58559 .70729 Mdot
.43854 .30108 Mdot
.3241 .59949 Mdot
.28064 .50133 Mdot
.70619 .57484 Mdot
.48074 .29808 Mdot
.32137 .39679 Mdot
.29579 .4073 Mdot
.28398 .55528 Mdot
.28571 .47563 Mdot
.41488 .30217 Mdot
.31244 .60111 Mdot
.28393 .50319 Mdot
.46035 .299 Mdot
.68782 .6026 Mdot
.53949 .70677 Mdot
.71714 .53321 Mdot
.29323 .51941 Mdot
.30124 .57758 Mdot
.6809 .3965 Mdot
.71379 .47387 Mdot
.32444 .6288 Mdot
.44382 .69196 Mdot
.70271 .47174 Mdot
.56163 .30038 Mdot
.48736 .72444 Mdot
.45621 .2845 Mdot
.70789 .55196 Mdot
.43091 .31206 Mdot
.30512 .43139 Mdot
.49579 .71184 Mdot
.35408 .33111 Mdot
.46876 .71929 Mdot
.51634 .7048 Mdot
.71922 .46839 Mdot
.48818 .70043 Mdot
.59106 .69208 Mdot
.70099 .50053 Mdot
.28869 .55221 Mdot
.70552 .4492 Mdot
.52388 .28389 Mdot
.32853 .61254 Mdot
.29529 .48149 Mdot
.52718 .29489 Mdot
.51072 .70878 Mdot
.30303 .45773 Mdot
.48049 .71167 Mdot
.46952 .69835 Mdot
.6936 .61464 Mdot
.46646 .72217 Mdot
.35214 .35466 Mdot
.4186 .69681 Mdot
.6329 .33112 Mdot
.67183 .38299 Mdot
.38587 .67551 Mdot
.63396 .64982 Mdot
.66211 .61766 Mdot
.31856 .36775 Mdot
.60863 .31709 Mdot
.39716 .69882 Mdot
.50028 .28726 Mdot
.71224 .57211 Mdot
.6438 .64668 Mdot
.48636 .28927 Mdot
.47237 .71373 Mdot
.60333 .32493 Mdot
.68581 .4107 Mdot
.43866 .30721 Mdot
.59778 .31886 Mdot
.66352 .61995 Mdot
.71793 .49107 Mdot
.5316 .29851 Mdot
.50868 .70518 Mdot
.46496 .29822 Mdot
.66715 .65055 Mdot
.71737 .47659 Mdot
.61906 .32769 Mdot
.62868 .67266 Mdot
.6766 .39931 Mdot
.29865 .56951 Mdot
.68874 .61772 Mdot
.38036 .67285 Mdot
.6688 .61515 Mdot
.31427 .4103 Mdot
.63392 .32048 Mdot
.61736 .33625 Mdot
.47936 .27694 Mdot
.63846 .34501 Mdot
.66454 .36228 Mdot
.45653 .28689 Mdot
.70792 .46244 Mdot
.47324 .70273 Mdot
.65844 .35638 Mdot
.69507 .39987 Mdot
.54894 .29628 Mdot
.37166 .67 Mdot
.6935 .417 Mdot
.28851 .49475 Mdot
.56512 .70126 Mdot
.36809 .34476 Mdot
.41686 .7058 Mdot
.68504 .39816 Mdot
.38762 .6782 Mdot
.37748 .33349 Mdot
.28631 .55954 Mdot
.46613 .29026 Mdot
.39682 .31444 Mdot
.34472 .66207 Mdot
.47939 .29929 Mdot
.64343 .34267 Mdot
.28952 .455 Mdot
.52655 .70749 Mdot
.53764 .71501 Mdot
.41816 .7074 Mdot
.65387 .36064 Mdot
.38503 .31686 Mdot
.31153 .59436 Mdot
.68765 .42056 Mdot
.50968 .27675 Mdot
.31231 .41925 Mdot
.71934 .53217 Mdot
.42928 .29545 Mdot
.29398 .51342 Mdot
.29712 .54231 Mdot
.47697 .71193 Mdot
.61495 .67489 Mdot
.34634 .63657 Mdot
.282 .50455 Mdot
.71228 .44298 Mdot
.30098 .4206 Mdot
.56662 .71109 Mdot
.70987 .4944 Mdot
.59799 .70217 Mdot
.43413 .70835 Mdot
.41779 .29787 Mdot
.60347 .3158 Mdot
.31954 .59732 Mdot
.40717 .32061 Mdot
.71844 .55162 Mdot
.59214 .68752 Mdot
.68014 .59711 Mdot
.33697 .35278 Mdot
.64945 .3549 Mdot
.34815 .35534 Mdot
.43451 .30191 Mdot
.40499 .69421 Mdot
.71495 .51442 Mdot
.29539 .51164 Mdot
.32191 .38796 Mdot
.58289 .31475 Mdot
.3004 .43174 Mdot
.36002 .33156 Mdot
.2965 .53387 Mdot
.72206 .53196 Mdot
.31668 .37304 Mdot
.3251 .62439 Mdot
.67119 .371 Mdot
.69632 .60665 Mdot
.66941 .35357 Mdot
.31425 .38498 Mdot
.43762 .70421 Mdot
.52873 .2864 Mdot
.49331 .29753 Mdot
.64997 .66302 Mdot
.4709 .71936 Mdot
.67217 .6404 Mdot
.39811 .30131 Mdot
.44495 .29989 Mdot
.53574 .29415 Mdot
.35501 .3493 Mdot
.66249 .36695 Mdot
.70892 .5534 Mdot
.31573 .37711 Mdot
.47673 .69876 Mdot
.62741 .32199 Mdot
.6328 .65433 Mdot
.3035 .39536 Mdot
.70324 .53618 Mdot
.68419 .37192 Mdot
.4037 .70212 Mdot
.65143 .65321 Mdot
.42433 .299 Mdot
.51916 .70451 Mdot
.37155 .31633 Mdot
.36837 .33777 Mdot
.3326 .64886 Mdot
.55693 .29267 Mdot
.50359 .72039 Mdot
.54773 .71207 Mdot
.54093 .71003 Mdot
.41786 .70197 Mdot
.67289 .37205 Mdot
.57983 .68623 Mdot
.55479 .69268 Mdot
.71151 .43188 Mdot
.30988 .43419 Mdot
.42286 .69886 Mdot
.59882 .67637 Mdot
.27787 .47725 Mdot
.68199 .40189 Mdot
.43455 .69524 Mdot
.43523 .29208 Mdot
.71247 .48664 Mdot
.56666 .30859 Mdot
.57056 .30191 Mdot
.33439 .38371 Mdot
.62958 .33087 Mdot
.6934 .55539 Mdot
.28422 .43708 Mdot
.65907 .34228 Mdot
.69816 .53639 Mdot
.70838 .43856 Mdot
.46882 .28166 Mdot
.49657 .72445 Mdot
.48361 .29299 Mdot
.28945 .56974 Mdot
.70295 .40908 Mdot
.63083 .32383 Mdot
.68411 .59959 Mdot
.57685 .29572 Mdot
.29514 .45588 Mdot
.69931 .40863 Mdot
.29202 .49365 Mdot
.69994 .47119 Mdot
.53645 .29062 Mdot
.46806 .30001 Mdot
.69843 .55096 Mdot
.46692 .70306 Mdot
.6623 .62926 Mdot
.31231 .59706 Mdot
.71969 .53924 Mdot
.33806 .354 Mdot
.28652 .50756 Mdot
.41136 .29452 Mdot
.70508 .48646 Mdot
.44209 .28591 Mdot
.55145 .71184 Mdot
.71803 .47685 Mdot
.60024 .68809 Mdot
.44361 .29406 Mdot
.68872 .58171 Mdot
.45784 .69778 Mdot
.70193 .54768 Mdot
.39539 .31885 Mdot
.28889 .4422 Mdot
.70897 .47556 Mdot
.29838 .43023 Mdot
.46855 .71129 Mdot
.38083 .68534 Mdot
.44498 .71235 Mdot
.60111 .68087 Mdot
.32145 .39758 Mdot
.66016 .62237 Mdot
.43773 .69386 Mdot
.69998 .58945 Mdot
.35264 .33741 Mdot
.30215 .46943 Mdot
.37856 .32985 Mdot
.70843 .4621 Mdot
.34139 .65307 Mdot
.35222 .34178 Mdot
.67145 .60503 Mdot
.29678 .55006 Mdot
.27986 .49365 Mdot
.36989 .66194 Mdot
.56027 .70806 Mdot
.44585 .70668 Mdot
.30036 .40249 Mdot
.52193 .28767 Mdot
.6874 .39846 Mdot
.55625 .30639 Mdot
.29024 .4417 Mdot
.60744 .68057 Mdot
.29171 .55957 Mdot
.44157 .30787 Mdot
.71104 .43301 Mdot
.37708 .68015 Mdot
.4948 .29526 Mdot
.69255 .56866 Mdot
.59583 .68419 Mdot
.44874 .70979 Mdot
.49631 .71945 Mdot
.28585 .50925 Mdot
.44925 .30471 Mdot
.40323 .67986 Mdot
.49489 .71007 Mdot
.35665 .35567 Mdot
.43041 .70207 Mdot
.46027 .70654 Mdot
.30426 .42698 Mdot
.53128 .70351 Mdot
.35054 .63483 Mdot
.69862 .41786 Mdot
.64109 .6512 Mdot
.31151 .56859 Mdot
.31973 .59768 Mdot
.66521 .64731 Mdot
.60943 .69074 Mdot
.28247 .5132 Mdot
.63568 .34475 Mdot
.55149 .70112 Mdot
.42146 .70793 Mdot
.70073 .48024 Mdot
.69645 .39881 Mdot
.70268 .56137 Mdot
.55819 .29389 Mdot
.33099 .37337 Mdot
.35415 .64989 Mdot
.28594 .51828 Mdot
.55884 .706 Mdot
.72184 .49454 Mdot
.38697 .67467 Mdot
.54803 .29114 Mdot
.70602 .54459 Mdot
.56771 .29847 Mdot
.66584 .63653 Mdot
.50604 .29925 Mdot
.41936 .68372 Mdot
.62348 .67558 Mdot
.70277 .42411 Mdot
.38679 .30577 Mdot
.48386 .29838 Mdot
.40217 .32223 Mdot
.32605 .6334 Mdot
.6593 .35769 Mdot
.36518 .65895 Mdot
.67468 .59944 Mdot
.4968 .71859 Mdot
.40625 .67685 Mdot
.70086 .41532 Mdot
.59542 .68764 Mdot
.7013 .49177 Mdot
.28965 .48794 Mdot
.49125 .72403 Mdot
.61044 .324 Mdot
.631 .34233 Mdot
.71057 .43916 Mdot
.27846 .50225 Mdot
.65219 .34367 Mdot
.50503 .70288 Mdot
.29075 .4388 Mdot
.42326 .69544 Mdot
.3578 .65112 Mdot
.41593 .6908 Mdot
.64251 .33002 Mdot
.69468 .57685 Mdot
.71202 .5293 Mdot
.56374 .69411 Mdot
.70087 .58937 Mdot
.43719 .30197 Mdot
.56979 .68921 Mdot
.30329 .55706 Mdot
.37574 .33238 Mdot
.63418 .67415 Mdot
.46441 .69798 Mdot
.6012 .31444 Mdot
.32266 .60151 Mdot
.52485 .29947 Mdot
.32955 .63153 Mdot
.29852 .40501 Mdot
.39529 .69399 Mdot
.64619 .34235 Mdot
.64466 .66412 Mdot
.31981 .6082 Mdot
.29063 .51774 Mdot
.47514 .71389 Mdot
.5542 .70182 Mdot
.31085 .57633 Mdot
.55211 .30211 Mdot
.40198 .32348 Mdot
.33016 .63074 Mdot
.66576 .61918 Mdot
.69988 .58921 Mdot
.52656 .71251 Mdot
.68201 .41684 Mdot
.58252 .31345 Mdot
.29761 .57251 Mdot
.29593 .43671 Mdot
.5168 .70532 Mdot
.66247 .63255 Mdot
.3101 .567 Mdot
.30702 .57699 Mdot
.70148 .56608 Mdot
.39049 .67166 Mdot
.71701 .4776 Mdot
.6651 .63686 Mdot
.70659 .56977 Mdot
.4427 .70252 Mdot
.3408 .37394 Mdot
.49445 .27826 Mdot
.34841 .66227 Mdot
.36183 .33905 Mdot
.69572 .39804 Mdot
.56617 .69334 Mdot
.64579 .35074 Mdot
.62516 .34306 Mdot
.6656 .36212 Mdot
.496 .28876 Mdot
.61641 .31046 Mdot
.30784 .55832 Mdot
.52603 .71781 Mdot
.44566 .30337 Mdot
.64329 .33004 Mdot
.69625 .59233 Mdot
.68647 .42333 Mdot
.64788 .34734 Mdot
.70016 .5863 Mdot
.71082 .52036 Mdot
.5916 .68059 Mdot
.47695 .6992 Mdot
.39271 .67475 Mdot
.58955 .2939 Mdot
.6652 .63077 Mdot
.67169 .63869 Mdot
.50659 .71329 Mdot
.698 .5484 Mdot
.42556 .69826 Mdot
.60929 .68665 Mdot
.51048 .71856 Mdot
.61981 .66571 Mdot
.69739 .5885 Mdot
.65045 .36229 Mdot
.4728 .29049 Mdot
.68652 .58323 Mdot
.35631 .36007 Mdot
.70154 .44643 Mdot
.34735 .64736 Mdot
.6797 .40194 Mdot
.68098 .58605 Mdot
.50644 .28667 Mdot
.59754 .31789 Mdot
.33446 .37253 Mdot
.5151 .28526 Mdot
.46464 .2981 Mdot
.69997 .54039 Mdot
.38781 .33355 Mdot
.32903 .61026 Mdot
.42895 .29476 Mdot
.71217 .5419 Mdot
.53517 .29046 Mdot
.70922 .44683 Mdot
.72198 .5304 Mdot
.6412 .65446 Mdot
.31333 .60691 Mdot
.34912 .65874 Mdot
.42859 .30237 Mdot
.38567 .68208 Mdot
.70309 .55106 Mdot
.69165 .41041 Mdot
.38103 .68175 Mdot
.67771 .36981 Mdot
.31249 .41776 Mdot
.68958 .42352 Mdot
.30215 .4437 Mdot
.57697 .29374 Mdot
.65061 .65425 Mdot
.31495 .57886 Mdot
.31297 .58503 Mdot
.67341 .62049 Mdot
.32716 .63779 Mdot
.61281 .69421 Mdot
.69358 .56376 Mdot
.47837 .70316 Mdot
.27696 .52128 Mdot
.39427 .69847 Mdot
.70339 .42056 Mdot
.29706 .47299 Mdot
.57916 .31333 Mdot
.67511 .60382 Mdot
.33628 .65039 Mdot
.71685 .48434 Mdot
.70078 .48593 Mdot
.59555 .30426 Mdot
.70592 .41581 Mdot
.2993 .42717 Mdot
.28611 .56453 Mdot
.5301 .7115 Mdot
.29559 .48374 Mdot
.44354 .29887 Mdot
.43603 .30808 Mdot
.35144 .35825 Mdot
.41618 .68707 Mdot
.35695 .3423 Mdot
.40391 .67962 Mdot
.58162 .29559 Mdot
.34112 .63151 Mdot
.49343 .70649 Mdot
.69156 .41936 Mdot
.7147 .53756 Mdot
.31993 .59325 Mdot
.40966 .68853 Mdot
.46883 .30196 Mdot
.43687 .3063 Mdot
.31525 .62035 Mdot
.69691 .58833 Mdot
.69001 .60435 Mdot
.49078 .72052 Mdot
.42246 .30427 Mdot
.71411 .50213 Mdot
.50431 .29735 Mdot
.71822 .46406 Mdot
.39235 .69748 Mdot
.37848 .32616 Mdot
.32204 .36325 Mdot
.69937 .43941 Mdot
.56767 .69238 Mdot
.66403 .35709 Mdot
.65805 .64154 Mdot
.34741 .33897 Mdot
.31963 .59011 Mdot
.35563 .35065 Mdot
.39569 .30185 Mdot
.37964 .32602 Mdot
.3759 .6865 Mdot
.72445 .5011 Mdot
.48473 .27593 Mdot
.70643 .56383 Mdot
.28736 .4411 Mdot
.61763 .69006 Mdot
.31319 .59258 Mdot
.30251 .45909 Mdot
.70686 .50065 Mdot
.68095 .37671 Mdot
.40256 .68369 Mdot
.49852 .7074 Mdot
.70788 .47927 Mdot
.49953 .70795 Mdot
.50657 .70922 Mdot
.5636 .70734 Mdot
.43653 .29597 Mdot
.71121 .55541 Mdot
.46761 .70261 Mdot
.28362 .48868 Mdot
.46544 .72063 Mdot
.32275 .36515 Mdot
.7036 .42972 Mdot
.37086 .67228 Mdot
.7009 .45234 Mdot
.6662 .624 Mdot
.45552 .28234 Mdot
.67384 .37268 Mdot
.70744 .52082 Mdot
.64003 .32758 Mdot
.48811 .29705 Mdot
.37899 .66603 Mdot
.2997 .54351 Mdot
.49573 .29231 Mdot
.28692 .47464 Mdot
.32874 .63395 Mdot
.30462 .42837 Mdot
.44477 .70268 Mdot
.61079 .32049 Mdot
.32824 .63681 Mdot
.5886 .31795 Mdot
.28271 .4523 Mdot
.69548 .60972 Mdot
.58725 .69871 Mdot
.33599 .35458 Mdot
.30669 .58019 Mdot
.66807 .6167 Mdot
.70897 .55796 Mdot
.28568 .44402 Mdot
.50094 .29321 Mdot
.43828 .29868 Mdot
.36704 .66538 Mdot
.6522 .35808 Mdot
.59554 .30769 Mdot
.56351 .30095 Mdot
.35721 .32908 Mdot
.58688 .69638 Mdot
.56364 .70372 Mdot
.67942 .60936 Mdot
.62019 .68614 Mdot
.29542 .43853 Mdot
.32009 .61733 Mdot
.61286 .33121 Mdot
.69257 .5629 Mdot
.7141 .44965 Mdot
.53083 .71061 Mdot
.60846 .681 Mdot
.31666 .38744 Mdot
.71959 .47277 Mdot
.34802 .63261 Mdot
.6654 .36876 Mdot
.52945 .703 Mdot
.37285 .68263 Mdot
.59052 .3046 Mdot
.28055 .49587 Mdot
.52506 .28872 Mdot
.28242 .44449 Mdot
.28285 .44143 Mdot
.34836 .65035 Mdot
.70118 .44059 Mdot
.32806 .63283 Mdot
.31089 .41321 Mdot
.29389 .49732 Mdot
.38974 .67038 Mdot
.61695 .67273 Mdot
.2895 .47022 Mdot
.37664 .32499 Mdot
.50505 .27522 Mdot
.66314 .63937 Mdot
.55368 .71843 Mdot
.4834 .29966 Mdot
.49006 .71492 Mdot
.38645 .67517 Mdot
.42241 .308 Mdot
.60799 .32855 Mdot
.38266 .66705 Mdot
.41199 .29943 Mdot
.59842 .30711 Mdot
.70081 .54081 Mdot
.6952 .59413 Mdot
.68831 .39553 Mdot
.63804 .33285 Mdot
.58814 .69536 Mdot
.33876 .37892 Mdot
.61125 .32714 Mdot
.68802 .38662 Mdot
.70293 .50197 Mdot
.30294 .41299 Mdot
.4142 .69048 Mdot
.48746 .27648 Mdot
.45494 .69896 Mdot
.39971 .31874 Mdot
.35764 .65932 Mdot
.57891 .29961 Mdot
.591 .70504 Mdot
.5568 .70605 Mdot
.37988 .68284 Mdot
.44077 .71102 Mdot
.38326 .68153 Mdot
.47113 .29829 Mdot
.70464 .53057 Mdot
.70414 .48238 Mdot
.48491 .29765 Mdot
.40933 .70345 Mdot
.3513 .65425 Mdot
.29283 .49085 Mdot
.58091 .69911 Mdot
.43265 .70801 Mdot
.62553 .31792 Mdot
.72429 .50886 Mdot
.29477 .49342 Mdot
.46014 .71707 Mdot
.27808 .52591 Mdot
.44291 .70811 Mdot
.49079 .27968 Mdot
.71556 .46709 Mdot
.35762 .64923 Mdot
.29333 .54096 Mdot
.58878 .69728 Mdot
.60572 .68956 Mdot
.38598 .68836 Mdot
.6134 .6857 Mdot
.60531 .31273 Mdot
.66537 .35206 Mdot
.37276 .67507 Mdot
.32685 .38823 Mdot
.32688 .36277 Mdot
.34051 .35877 Mdot
.51965 .71375 Mdot
.62252 .66103 Mdot
.71118 .57262 Mdot
.70819 .47032 Mdot
.45703 .30146 Mdot
.5861 .30004 Mdot
.65959 .35849 Mdot
.70031 .40707 Mdot
.28333 .45225 Mdot
.38536 .68157 Mdot
.68066 .41198 Mdot
.46755 .30093 Mdot
.42523 .30236 Mdot
.30192 .39464 Mdot
.36395 .33612 Mdot
.32709 .37381 Mdot
.68616 .40314 Mdot
.54914 .28416 Mdot
.71491 .55388 Mdot
.62267 .34136 Mdot
.2754 .49355 Mdot
.29014 .48 Mdot
.30177 .39628 Mdot
.55307 .29774 Mdot
.65871 .35881 Mdot
.54828 .70412 Mdot
.50767 .7243 Mdot
.33237 .35647 Mdot
.40752 .69362 Mdot
.60443 .30147 Mdot
.45669 .71367 Mdot
.72041 .46126 Mdot
.53721 .28487 Mdot
.29468 .5566 Mdot
.56715 .70907 Mdot
.39772 .32365 Mdot
.41623 .68948 Mdot
.29024 .56335 Mdot
.68702 .59044 Mdot
.62046 .31182 Mdot
.50105 .28183 Mdot
.7233 .51906 Mdot
.30364 .53882 Mdot
.69364 .55133 Mdot
.42589 .30689 Mdot
.31658 .39299 Mdot
.28808 .5118 Mdot
.68123 .39693 Mdot
.59323 .68266 Mdot
.29098 .54758 Mdot
.6772 .63428 Mdot
.34612 .34851 Mdot
.37748 .66332 Mdot
.33311 .36157 Mdot
.65175 .36365 Mdot
.30351 .4091 Mdot
.57942 .70749 Mdot
.70323 .48068 Mdot
.43598 .30008 Mdot
.70127 .59044 Mdot
.29784 .46696 Mdot
.3353 .3758 Mdot
.31656 .59701 Mdot
.71349 .47177 Mdot
.68391 .58674 Mdot
.34815 .66403 Mdot
.58697 .70679 Mdot
.56385 .30307 Mdot
.70206 .49342 Mdot
.58056 .31379 Mdot
.44052 .70894 Mdot
.4971 .29279 Mdot
.52444 .28901 Mdot
.62322 .65873 Mdot
.38401 .6689 Mdot
.60622 .68185 Mdot
.46767 .69894 Mdot
.56172 .2971 Mdot
.67141 .60728 Mdot
.70502 .49626 Mdot
.66603 .6116 Mdot
.58365 .68405 Mdot
.56428 .30239 Mdot
.29852 .58819 Mdot
.71605 .5436 Mdot
.44635 .71231 Mdot
.41555 .30172 Mdot
.6487 .64598 Mdot
.31914 .61434 Mdot
.39763 .69621 Mdot
.40831 .69088 Mdot
.39649 .68987 Mdot
.53038 .70952 Mdot
.62873 .67107 Mdot
.31715 .59024 Mdot
.4495 .28674 Mdot
.33498 .62743 Mdot
.32245 .59244 Mdot
.44503 .28906 Mdot
.43292 .70615 Mdot
.43799 .69436 Mdot
.71744 .46351 Mdot
.71516 .46991 Mdot
.37392 .33934 Mdot
.50103 .29445 Mdot
.28491 .50437 Mdot
.40985 .68038 Mdot
.54654 .28398 Mdot
.69646 .40516 Mdot
.35906 .66998 Mdot
.53876 .69638 Mdot
.68965 .57524 Mdot
.69369 .39325 Mdot
.67844 .60793 Mdot
.69049 .42727 Mdot
.30888 .57225 Mdot
.58071 .70826 Mdot
.70184 .42835 Mdot
.6491 .33592 Mdot
.61467 .68564 Mdot
.68877 .42385 Mdot
.57105 .28927 Mdot
.46187 .30023 Mdot
.48854 .28194 Mdot
.56422 .30298 Mdot
.38214 .32641 Mdot
.62782 .34189 Mdot
.54785 .69985 Mdot
.39794 .32225 Mdot
.47709 .7151 Mdot
.56393 .30179 Mdot
.67634 .6367 Mdot
.63117 .34283 Mdot
.43415 .68962 Mdot
.62765 .65569 Mdot
.30795 .42179 Mdot
.38196 .6846 Mdot
.68522 .37663 Mdot
.28553 .52389 Mdot
.42505 .2963 Mdot
.58409 .30666 Mdot
.32002 .58888 Mdot
.70159 .51987 Mdot
.41138 .6822 Mdot
.62532 .68428 Mdot
.70047 .52386 Mdot
.72063 .51981 Mdot
.28833 .55819 Mdot
.40665 .32041 Mdot
.28925 .43032 Mdot
.5762 .6974 Mdot
.62756 .33962 Mdot
.35708 .64101 Mdot
.31527 .58702 Mdot
.35726 .67159 Mdot
.65701 .62642 Mdot
.55531 .69256 Mdot
.69044 .61925 Mdot
.57357 .69009 Mdot
.36119 .3489 Mdot
.29979 .47788 Mdot
.68187 .60136 Mdot
.40109 .6907 Mdot
.53308 .70057 Mdot
.70361 .43395 Mdot
.56123 .28444 Mdot
.31749 .38474 Mdot
.41312 .29516 Mdot
.33909 .64337 Mdot
.3174 .37233 Mdot
.57428 .69822 Mdot
.71249 .45303 Mdot
.40505 .31241 Mdot
.65661 .36098 Mdot
.37125 .67892 Mdot
.39007 .32563 Mdot
.33366 .62214 Mdot
.63831 .34593 Mdot
.57877 .2994 Mdot
.58889 .68975 Mdot
.29928 .60166 Mdot
.31652 .39434 Mdot
.52348 .71202 Mdot
.3382 .35225 Mdot
.30983 .42879 Mdot
.47807 .29146 Mdot
.55448 .70037 Mdot
.68261 .58995 Mdot
.57239 .31219 Mdot
.55991 .71327 Mdot
.71076 .49868 Mdot
.70913 .53466 Mdot
.31138 .40595 Mdot
.31246 .57022 Mdot
.37943 .68694 Mdot
.59382 .31644 Mdot
.54671 .28565 Mdot
.68557 .62086 Mdot
.31219 .40222 Mdot
.71634 .526 Mdot
.52355 .29085 Mdot
.58487 .29554 Mdot
.52655 .27687 Mdot
.54758 .29609 Mdot
.57218 .70139 Mdot
.38409 .67407 Mdot
.63168 .32816 Mdot
.29836 .47671 Mdot
.70102 .59446 Mdot
.31516 .59211 Mdot
.28981 .50857 Mdot
.32153 .61741 Mdot
.46575 .27772 Mdot
.32014 .37815 Mdot
.69288 .44635 Mdot
.57444 .30593 Mdot
.51537 .2893 Mdot
.28173 .54909 Mdot
.68371 .37938 Mdot
.70838 .42717 Mdot
.61648 .31023 Mdot
.28748 .47306 Mdot
.38167 .67626 Mdot
.65239 .63045 Mdot
.34374 .35614 Mdot
.29297 .47661 Mdot
.38811 .3197 Mdot
.44968 .30593 Mdot
.66257 .38191 Mdot
.50655 .70166 Mdot
.70593 .49026 Mdot
.43838 .69659 Mdot
.61734 .67235 Mdot
.53831 .28661 Mdot
.58242 .29472 Mdot
.39064 .31349 Mdot
.57401 .69526 Mdot
.6246 .66636 Mdot
.2825 .45747 Mdot
.30814 .57867 Mdot
.34967 .33844 Mdot
.57178 .69265 Mdot
.36144 .33623 Mdot
.67735 .36225 Mdot
.2951 .52148 Mdot
.65444 .63898 Mdot
.40195 .31451 Mdot
.29361 .5656 Mdot
.30055 .52485 Mdot
.43136 .6971 Mdot
.69419 .43628 Mdot
.63341 .34918 Mdot
.41256 .68949 Mdot
.39612 .3052 Mdot
.40739 .30136 Mdot
.53752 .28201 Mdot
.56944 .70153 Mdot
.38621 .31943 Mdot
.29908 .46872 Mdot
.55587 .71472 Mdot
.69456 .55561 Mdot
.67715 .38146 Mdot
.68459 .62506 Mdot
.70485 .55381 Mdot
.5348 .28857 Mdot
.35325 .65854 Mdot
.68173 .62417 Mdot
.31568 .3802 Mdot
.66605 .37648 Mdot
.68743 .41355 Mdot
.35727 .6452 Mdot
.46299 .29376 Mdot
.40379 .67677 Mdot
.58867 .29715 Mdot
.5197 .70233 Mdot
.5324 .29294 Mdot
.29319 .55505 Mdot
.31858 .62188 Mdot
.3571 .66584 Mdot
.58772 .29419 Mdot
.29315 .54626 Mdot
.66111 .35415 Mdot
.67497 .61313 Mdot
.61005 .67625 Mdot
.51563 .29349 Mdot
.38054 .67442 Mdot
.29921 .465 Mdot
.31786 .41307 Mdot
.695 .59008 Mdot
.60599 .67928 Mdot
.43928 .28762 Mdot
.37588 .66883 Mdot
.51221 .70858 Mdot
.28715 .54339 Mdot
.61857 .66178 Mdot
.4268 .69623 Mdot
.33404 .64208 Mdot
.71645 .44623 Mdot
.63667 .33447 Mdot
.32922 .6406 Mdot
.55725 .28255 Mdot
.53284 .7104 Mdot
.67537 .60415 Mdot
.64334 .35569 Mdot
.62322 .3177 Mdot
.32425 .61708 Mdot
.426 .29339 Mdot
.66348 .61821 Mdot
.42843 .68781 Mdot
.63143 .65564 Mdot
.29981 .5677 Mdot
.49741 .29252 Mdot
.38349 .32353 Mdot
.28267 .46885 Mdot
.31328 .40949 Mdot
.37097 .32658 Mdot
.46972 .28971 Mdot
.51066 .7047 Mdot
.71362 .54351 Mdot
.6275 .65828 Mdot
.46475 .28586 Mdot
.72448 .5052 Mdot
.46663 .70297 Mdot
.49227 .7169 Mdot
.33906 .35113 Mdot
.4763 .27878 Mdot
.70258 .56158 Mdot
.67771 .60483 Mdot
.40485 .70309 Mdot
.61118 .33213 Mdot
.45153 .7005 Mdot
.43242 .28738 Mdot
.30269 .41649 Mdot
.42737 .28856 Mdot
.45095 .70271 Mdot
.30719 .57401 Mdot
.39555 .31285 Mdot
.4463 .29797 Mdot
.35409 .35946 Mdot
.35561 .35771 Mdot
.4344 .69244 Mdot
.53864 .30237 Mdot
.72111 .52025 Mdot
.67831 .5976 Mdot
.30206 .5632 Mdot
.34871 .6379 Mdot
.61653 .69157 Mdot
.70787 .41876 Mdot
.29025 .50786 Mdot
.5241 .71277 Mdot
.64382 .35069 Mdot
.33561 .36707 Mdot
.31527 .41345 Mdot
.59827 .31437 Mdot
.30537 .42965 Mdot
.49712 .29325 Mdot
.67766 .63672 Mdot
.36598 .65122 Mdot
.70986 .41899 Mdot
.3185 .59288 Mdot
.29661 .56988 Mdot
.5757 .70097 Mdot
.31508 .40533 Mdot
.32462 .3971 Mdot
.70362 .50713 Mdot
.50954 .28191 Mdot
.28891 .56805 Mdot
.71118 .51218 Mdot
.37374 .68335 Mdot
.37032 .3355 Mdot
.31615 .62561 Mdot
.53975 .70171 Mdot
.70017 .44494 Mdot
.71288 .53559 Mdot
.33419 .65189 Mdot
.3015 .57584 Mdot
.34229 .65497 Mdot
.4129 .29885 Mdot
.70052 .39945 Mdot
.40664 .3145 Mdot
.32327 .40278 Mdot
.71869 .54462 Mdot
.59213 .68206 Mdot
.58391 .29922 Mdot
.544 .71702 Mdot
.54603 .30355 Mdot
.61422 .31013 Mdot
.37988 .67744 Mdot
.3059 .5501 Mdot
.38179 .31437 Mdot
.30337 .45763 Mdot
.71133 .47863 Mdot
.71502 .43567 Mdot
.70451 .43628 Mdot
.53898 .28308 Mdot
.6424 .66979 Mdot
.29184 .41738 Mdot
.36824 .67596 Mdot
.46701 .30032 Mdot
.70531 .50979 Mdot
.48208 .70112 Mdot
.37863 .67195 Mdot
.47529 .30075 Mdot
.35369 .66837 Mdot
.53354 .30147 Mdot
.32231 .60975 Mdot
.70593 .49785 Mdot
.46942 .71004 Mdot
.30842 .57836 Mdot
.691 .39611 Mdot
.45444 .30053 Mdot
.6811 .39001 Mdot
.30719 .56249 Mdot
.31531 .41965 Mdot
.46186 .30173 Mdot
.56108 .69396 Mdot
.6879 .42984 Mdot
.55393 .28722 Mdot
.70654 .42532 Mdot
.29386 .47856 Mdot
.28754 .49121 Mdot
.32292 .37838 Mdot
.55466 .29928 Mdot
.41666 .31497 Mdot
.38759 .67185 Mdot
.64919 .63548 Mdot
.35385 .35848 Mdot
.69273 .38748 Mdot
.41284 .3168 Mdot
.64275 .64526 Mdot
.4798 .29273 Mdot
.3293 .35898 Mdot
.53045 .7185 Mdot
.70578 .51829 Mdot
.30456 .58363 Mdot
.40025 .67756 Mdot
.67252 .61481 Mdot
.54518 .69702 Mdot
.29958 .53692 Mdot
.43914 .69467 Mdot
.55203 .30594 Mdot
.59446 .67663 Mdot
.70378 .57649 Mdot
.31136 .42263 Mdot
.60598 .30487 Mdot
.28767 .43419 Mdot
.33567 .6299 Mdot
.54586 .71378 Mdot
.4374 .69231 Mdot
.71649 .50306 Mdot
.60652 .30356 Mdot
.43945 .29627 Mdot
.71643 .55181 Mdot
.29209 .45738 Mdot
.7033 .47464 Mdot
.70472 .46127 Mdot
.62103 .66895 Mdot
.31354 .59887 Mdot
.51055 .2769 Mdot
.5593 .70917 Mdot
.28675 .55843 Mdot
.55752 .69249 Mdot
.34591 .33928 Mdot
.28664 .50031 Mdot
.33169 .39176 Mdot
.69697 .45932 Mdot
.33094 .35886 Mdot
.71775 .49637 Mdot
.29439 .55327 Mdot
.31577 .40622 Mdot
.43659 .29556 Mdot
.35437 .65723 Mdot
.50726 .71782 Mdot
.6085 .68377 Mdot
.33599 .35293 Mdot
.39855 .32758 Mdot
.71739 .53497 Mdot
.42782 .28802 Mdot
.3066 .61491 Mdot
.43681 .30377 Mdot
.70413 .44073 Mdot
.65822 .65917 Mdot
.49594 .72348 Mdot
.50867 .29007 Mdot
.7053 .51058 Mdot
.3139 .3795 Mdot
.33643 .63214 Mdot
.69818 .40074 Mdot
.35628 .66003 Mdot
.53023 .72066 Mdot
.70533 .43582 Mdot
.28675 .46221 Mdot
.70253 .49588 Mdot
.3224 .62493 Mdot
.49214 .2961 Mdot
.374 .33573 Mdot
.47991 .27742 Mdot
.69816 .57051 Mdot
.38147 .67721 Mdot
.64792 .6542 Mdot
.72086 .46837 Mdot
.6747 .37304 Mdot
.7053 .53328 Mdot
.34429 .66156 Mdot
.70206 .53698 Mdot
.70349 .4607 Mdot
.45615 .69653 Mdot
.41048 .67909 Mdot
.30676 .4382 Mdot
.47392 .7133 Mdot
.55932 .70632 Mdot
.62722 .65588 Mdot
.52973 .71452 Mdot
.51178 .70992 Mdot
.56133 .69937 Mdot
.64339 .3454 Mdot
.59372 .68027 Mdot
.66426 .37968 Mdot
.65449 .37014 Mdot
.31912 .40697 Mdot
.38062 .68946 Mdot
.42611 .70032 Mdot
.63932 .65614 Mdot
.60786 .68286 Mdot
.68079 .37873 Mdot
.67951 .40726 Mdot
.43972 .29977 Mdot
.70337 .57336 Mdot
.29766 .46171 Mdot
.61869 .67636 Mdot
.3709 .3419 Mdot
.31677 .39909 Mdot
.43473 .69451 Mdot
.46702 .71819 Mdot
.60948 .69187 Mdot
.66164 .63149 Mdot
.48532 .70269 Mdot
.58244 .68913 Mdot
.2953 .42185 Mdot
.64777 .65634 Mdot
.70982 .53768 Mdot
.6998 .46676 Mdot
.34122 .63601 Mdot
.3286 .6353 Mdot
.67502 .60461 Mdot
.66255 .65221 Mdot
.68115 .39782 Mdot
.7138 .51491 Mdot
.38678 .32938 Mdot
.59618 .31556 Mdot
.67142 .62244 Mdot
.4288 .29408 Mdot
.70105 .59527 Mdot
.46399 .28769 Mdot
.41299 .30513 Mdot
.39353 .69478 Mdot
.32853 .37961 Mdot
.55599 .71718 Mdot
.41323 .31811 Mdot
.56643 .69917 Mdot
.71957 .53111 Mdot
.35968 .64524 Mdot
.6873 .40262 Mdot
.40536 .31358 Mdot
.62908 .32978 Mdot
.70885 .435 Mdot
.59635 .67551 Mdot
.34062 .34581 Mdot
.3064 .40489 Mdot
.3103 .61622 Mdot
.668 .36716 Mdot
.54798 .70703 Mdot
.64993 .34256 Mdot
.61449 .32329 Mdot
.69515 .43307 Mdot
.60119 .67424 Mdot
.68068 .62139 Mdot
.54623 .70255 Mdot
.69317 .40013 Mdot
.32323 .38479 Mdot
.38 .66219 Mdot
.59163 .69287 Mdot
.29482 .55563 Mdot
.69635 .45695 Mdot
.31173 .38584 Mdot
.65316 .65153 Mdot
.36298 .33578 Mdot
.70651 .44404 Mdot
.28765 .43805 Mdot
.49171 .29397 Mdot
.35247 .35948 Mdot
.62755 .67949 Mdot
.47501 .70043 Mdot
.70354 .46417 Mdot
.58127 .3016 Mdot
.70548 .50854 Mdot
.53412 .71655 Mdot
.65914 .35513 Mdot
.32377 .39459 Mdot
.67907 .40816 Mdot
.70238 .5528 Mdot
.59246 .69967 Mdot
.32032 .59953 Mdot
.72104 .54117 Mdot
.61983 .66438 Mdot
.70431 .57653 Mdot
.38775 .68222 Mdot
.70194 .56622 Mdot
.66692 .643 Mdot
.60958 .69343 Mdot
.28862 .46386 Mdot
.50918 .72087 Mdot
.29546 .5176 Mdot
.68576 .57682 Mdot
.70534 .5917 Mdot
.69684 .54154 Mdot
.69209 .38978 Mdot
.70565 .46883 Mdot
.31773 .40095 Mdot
.69685 .40068 Mdot
.29205 .54446 Mdot
.51075 .27708 Mdot
.70728 .41722 Mdot
.2987 .48189 Mdot
.29146 .56316 Mdot
.30803 .55989 Mdot
.33525 .64278 Mdot
.30375 .60988 Mdot
.28257 .54253 Mdot
.29699 .57642 Mdot
.66499 .36356 Mdot
.27984 .4763 Mdot
.32134 .59309 Mdot
.51318 .27714 Mdot
.29776 .52037 Mdot
.50678 .72103 Mdot
.70643 .54049 Mdot
.55907 .28804 Mdot
.36623 .3287 Mdot
.34485 .65614 Mdot
.59996 .69688 Mdot
.68483 .41556 Mdot
.45466 .70166 Mdot
.3222 .60557 Mdot
.63246 .34322 Mdot
.38314 .32729 Mdot
.35484 .64045 Mdot
.32052 .61358 Mdot
.37623 .67778 Mdot
.33873 .35427 Mdot
.43381 .28572 Mdot
.51052 .72199 Mdot
.29947 .46553 Mdot
.41852 .70331 Mdot
.51129 .72148 Mdot
.66848 .3709 Mdot
.34193 .64798 Mdot
.51201 .70337 Mdot
.71452 .50353 Mdot
.6047 .3107 Mdot
.37565 .31497 Mdot
.55097 .71809 Mdot
.71418 .43559 Mdot
.69839 .46344 Mdot
.30293 .59821 Mdot
.38907 .3244 Mdot
.58934 .70477 Mdot
.5199 .28045 Mdot
.5692 .30503 Mdot
.28569 .46775 Mdot
.56931 .29402 Mdot
.43018 .31216 Mdot
.63356 .67407 Mdot
.30018 .52536 Mdot
.57824 .70641 Mdot
.27566 .48743 Mdot
.52003 .30045 Mdot
.62597 .32331 Mdot
.32372 .40107 Mdot
.69127 .61181 Mdot
.53735 .28293 Mdot
.30975 .4241 Mdot
.70052 .46883 Mdot
.63716 .34841 Mdot
.60002 .31703 Mdot
.34592 .63218 Mdot
.36159 .33838 Mdot
.64666 .3592 Mdot
.6466 .34655 Mdot
.70765 .53916 Mdot
.44779 .70349 Mdot
.70228 .42785 Mdot
.28588 .48267 Mdot
.34247 .63878 Mdot
.29393 .45068 Mdot
.29581 .4768 Mdot
.44667 .30375 Mdot
.63783 .64836 Mdot
.69478 .59238 Mdot
.49632 .72416 Mdot
.56391 .69305 Mdot
.53601 .70981 Mdot
.68366 .38206 Mdot
.46168 .7198 Mdot
.33824 .62338 Mdot
.6663 .36662 Mdot
.63689 .3322 Mdot
.3537 .64739 Mdot
.62408 .67336 Mdot
.5083 .705 Mdot
.69463 .60804 Mdot
.70565 .48829 Mdot
.66127 .35146 Mdot
.52462 .28329 Mdot
.69797 .4653 Mdot
.28039 .51307 Mdot
.30241 .39761 Mdot
.33126 .38042 Mdot
.45783 .29838 Mdot
.53685 .7211 Mdot
.30069 .41218 Mdot
.71727 .47277 Mdot
.28074 .52017 Mdot
.7125 .48557 Mdot
.34036 .37798 Mdot
.53957 .71629 Mdot
.34755 .3346 Mdot
.47275 .27677 Mdot
.69027 .56903 Mdot
.64672 .66133 Mdot
.38348 .68827 Mdot
.68397 .38134 Mdot
.52825 .29835 Mdot
.70273 .40253 Mdot
.4523 .7029 Mdot
.69681 .42131 Mdot
.41506 .31068 Mdot
.457 .28723 Mdot
.69683 .56588 Mdot
.71653 .48309 Mdot
.7051 .49486 Mdot
.63742 .32296 Mdot
.38573 .32531 Mdot
.69359 .43198 Mdot
.65443 .36498 Mdot
.704 .52259 Mdot
.31975 .37093 Mdot
.69253 .60285 Mdot
.68506 .39215 Mdot
.37192 .65517 Mdot
.63627 .34468 Mdot
.3548 .65035 Mdot
.63662 .35194 Mdot
.29132 .47739 Mdot
.55308 .71115 Mdot
.3153 .41174 Mdot
.40331 .68933 Mdot
.28805 .4261 Mdot
.4679 .28651 Mdot
.2963 .53186 Mdot
.57452 .31257 Mdot
.65334 .63601 Mdot
.70734 .42625 Mdot
.49063 .27925 Mdot
.69351 .60169 Mdot
.5316 .70867 Mdot
.63398 .35033 Mdot
.38416 .32924 Mdot
.29376 .44559 Mdot
.66603 .62342 Mdot
.58808 .29578 Mdot
.35937 .35681 Mdot
.72061 .50635 Mdot
.2798 .48482 Mdot
.68702 .57264 Mdot
.52495 .27662 Mdot
.70571 .47658 Mdot
.29355 .44474 Mdot
.65399 .63706 Mdot
.65684 .36432 Mdot
.3057 .40146 Mdot
.54344 .30426 Mdot
.5137 .27997 Mdot
.62245 .68854 Mdot
.50751 .27537 Mdot
.37733 .33689 Mdot
.42588 .28849 Mdot
.64865 .35983 Mdot
.45184 .28833 Mdot
.38673 .68344 Mdot
.3283 .37748 Mdot
.30137 .56242 Mdot
.71561 .53268 Mdot
.39628 .32005 Mdot
.48038 .72175 Mdot
.2924 .48896 Mdot
.27748 .48778 Mdot
.63098 .34386 Mdot
.58546 .29322 Mdot
.72296 .47385 Mdot
.66872 .61934 Mdot
.37029 .33625 Mdot
.27927 .50091 Mdot
.57172 .68744 Mdot
.29975 .53119 Mdot
.2847 .46583 Mdot
.54929 .69903 Mdot
.70896 .52186 Mdot
.43924 .30192 Mdot
.61542 .67099 Mdot
.66083 .36739 Mdot
.59495 .68372 Mdot
.55297 .30529 Mdot
.28123 .45726 Mdot
.44509 .69861 Mdot
.38227 .68846 Mdot
.58373 .31463 Mdot
.57971 .31198 Mdot
.32452 .36182 Mdot
.56407 .29046 Mdot
.67765 .37685 Mdot
.36613 .33456 Mdot
.70699 .5173 Mdot
.29823 .5416 Mdot
.53732 .70252 Mdot
.69198 .41968 Mdot
.70229 .40179 Mdot
.32789 .37813 Mdot
.67016 .64175 Mdot
.54412 .29809 Mdot
.27696 .49386 Mdot
.71185 .48267 Mdot
.33322 .37746 Mdot
.37334 .68565 Mdot
.30886 .38273 Mdot
.65721 .34793 Mdot
.354 .66231 Mdot
.69618 .42334 Mdot
.29765 .5823 Mdot
.37644 .68772 Mdot
.39555 .69586 Mdot
.29646 .42176 Mdot
.59986 .29965 Mdot
.31483 .41088 Mdot
.53697 .71372 Mdot
.53077 .70345 Mdot
.35622 .33659 Mdot
.37703 .67274 Mdot
.47388 .72281 Mdot
.33148 .61031 Mdot
.59925 .31961 Mdot
.68504 .58022 Mdot
.2911 .49727 Mdot
.29157 .49123 Mdot
.40875 .31079 Mdot
.68656 .41969 Mdot
.29022 .55989 Mdot
.44361 .28492 Mdot
.58604 .31889 Mdot
.3652 .66143 Mdot
.30948 .43542 Mdot
.69985 .43918 Mdot
.46139 .28313 Mdot
.65789 .36579 Mdot
.53975 .70759 Mdot
.33587 .65185 Mdot
.30548 .44822 Mdot
.29214 .57354 Mdot
.6787 .60669 Mdot
.48136 .27764 Mdot
.48036 .70669 Mdot
.34861 .64958 Mdot
.45251 .29909 Mdot
.3195 .59488 Mdot
.71084 .4882 Mdot
.28367 .45151 Mdot
.52988 .27718 Mdot
.62665 .68366 Mdot
.52828 .72172 Mdot
.44719 .3044 Mdot
.63292 .66948 Mdot
.70116 .46339 Mdot
.65063 .35689 Mdot
.32112 .37779 Mdot
.60138 .67394 Mdot
.59963 .68794 Mdot
.59778 .69165 Mdot
.35952 .3359 Mdot
.32289 .62249 Mdot
.28326 .52268 Mdot
.59978 .6925 Mdot
.53418 .28741 Mdot
.69793 .53742 Mdot
.57021 .30118 Mdot
.62779 .67744 Mdot
.55633 .71185 Mdot
.71633 .47907 Mdot
.70117 .54659 Mdot
.57412 .31189 Mdot
.32656 .62786 Mdot
.32402 .61793 Mdot
.69191 .3873 Mdot
.52463 .71864 Mdot
.63198 .65977 Mdot
.5644 .70888 Mdot
.38601 .68978 Mdot
.71314 .57184 Mdot
.64074 .64514 Mdot
.68942 .58494 Mdot
.68541 .61968 Mdot
.49051 .70519 Mdot
.42726 .30812 Mdot
.62993 .32425 Mdot
.53485 .2953 Mdot
.33625 .34782 Mdot
.36911 .34824 Mdot
.32244 .60237 Mdot
.43617 .69379 Mdot
.36439 .65378 Mdot
.59367 .67881 Mdot
.43401 .71244 Mdot
.67943 .60156 Mdot
.71003 .55474 Mdot
.34543 .62846 Mdot
.58323 .7074 Mdot
.33425 .35789 Mdot
.29653 .40411 Mdot
.71546 .46736 Mdot
.62555 .68062 Mdot
.4034 .30916 Mdot
.55123 .29126 Mdot
.28799 .49703 Mdot
.28291 .51315 Mdot
.31945 .59888 Mdot
.30945 .56219 Mdot
.7011 .53917 Mdot
.48664 .70153 Mdot
.31604 .60444 Mdot
.42615 .31195 Mdot
.29586 .57824 Mdot
.29854 .45215 Mdot
.52096 .29634 Mdot
.49837 .28287 Mdot
.48074 .71684 Mdot
.4881 .72433 Mdot
.61779 .32393 Mdot
.58075 .29085 Mdot
.58006 .30915 Mdot
.28784 .43384 Mdot
.3255 .63466 Mdot
.63786 .32829 Mdot
.6933 .44206 Mdot
.40858 .69253 Mdot
.5852 .70507 Mdot
.30108 .40372 Mdot
.68105 .4052 Mdot
.41425 .70407 Mdot
.69102 .60407 Mdot
.27794 .49348 Mdot
.47864 .70948 Mdot
.71659 .43937 Mdot
.64804 .34388 Mdot
.66645 .61918 Mdot
.68507 .39385 Mdot
.53837 .28684 Mdot
.47262 .28545 Mdot
.55941 .71244 Mdot
.57375 .30133 Mdot
.6757 .36067 Mdot
.46865 .28286 Mdot
.34541 .63016 Mdot
.29741 .55066 Mdot
.31598 .58371 Mdot
.31553 .38256 Mdot
.38899 .69276 Mdot
.40461 .31817 Mdot
.30623 .4305 Mdot
.70061 .42536 Mdot
.37833 .67148 Mdot
.632 .65307 Mdot
.29738 .55898 Mdot
.32491 .61178 Mdot
.69108 .58455 Mdot
.71231 .42889 Mdot
.36252 .34554 Mdot
.37085 .65949 Mdot
.43396 .69865 Mdot
.41097 .29348 Mdot
.49523 .29657 Mdot
.48929 .28942 Mdot
.32504 .63041 Mdot
.33521 .37189 Mdot
.69411 .42754 Mdot
.56737 .68938 Mdot
.65966 .34397 Mdot
.50375 .70207 Mdot
.51007 .71623 Mdot
.66981 .35719 Mdot
.69329 .42558 Mdot
.56395 .71257 Mdot
.56869 .6917 Mdot
.29499 .55048 Mdot
.56147 .29876 Mdot
.62546 .34117 Mdot
.6236 .33868 Mdot
.39294 .32942 Mdot
.70289 .47076 Mdot
.30784 .61568 Mdot
.47941 .28747 Mdot
.30009 .46828 Mdot
.55524 .30113 Mdot
.41072 .68501 Mdot
.33439 .38302 Mdot
.63976 .33101 Mdot
.56807 .29359 Mdot
.71684 .50487 Mdot
.70219 .42956 Mdot
.38137 .67991 Mdot
.70528 .46007 Mdot
.69506 .40674 Mdot
.52104 .7196 Mdot
.32394 .6213 Mdot
.30001 .57675 Mdot
.68105 .60316 Mdot
.61753 .32422 Mdot
.53687 .71088 Mdot
.71112 .55862 Mdot
.54318 .71795 Mdot
.66848 .61677 Mdot
.64715 .35486 Mdot
.65417 .65815 Mdot
.70367 .42966 Mdot
.65607 .37453 Mdot
.30567 .44606 Mdot
.29906 .56452 Mdot
.28833 .5534 Mdot
.32406 .36039 Mdot
.51511 .70366 Mdot
.31072 .41999 Mdot
.70551 .5251 Mdot
.30374 .54103 Mdot
.62453 .65694 Mdot
.39017 .67267 Mdot
.56963 .69798 Mdot
.30646 .56567 Mdot
.38091 .32924 Mdot
.7183 .49641 Mdot
.57607 .70097 Mdot
.33091 .63876 Mdot
.702 .44021 Mdot
.59916 .31122 Mdot
.6868 .41896 Mdot
.36462 .66411 Mdot
.55254 .30363 Mdot
.70652 .52558 Mdot
.31969 .37674 Mdot
.31659 .41132 Mdot
.69658 .42551 Mdot
.31212 .40532 Mdot
.49992 .27966 Mdot
.5877 .69811 Mdot
.55944 .29893 Mdot
.37362 .65939 Mdot
.63223 .34198 Mdot
.71564 .49582 Mdot
.68385 .58551 Mdot
.70547 .4705 Mdot
.29346 .53424 Mdot
.33095 .61392 Mdot
.28024 .45593 Mdot
.60684 .30944 Mdot
.54014 .30019 Mdot
.37899 .3385 Mdot
.71826 .48049 Mdot
.44313 .71603 Mdot
.65075 .65059 Mdot
.44324 .69981 Mdot
.6976 .57202 Mdot
.4185 .68279 Mdot
.32499 .40124 Mdot
.68767 .38275 Mdot
.69183 .56269 Mdot
.67786 .59748 Mdot
.47383 .72147 Mdot
.31698 .58314 Mdot
.45814 .69954 Mdot
.62801 .65708 Mdot
.61792 .68074 Mdot
.62603 .31978 Mdot
.66443 .62325 Mdot
.28421 .45831 Mdot
.29717 .4736 Mdot
.33636 .34778 Mdot
.30079 .53757 Mdot
.28608 .44586 Mdot
.56128 .69532 Mdot
.67158 .63713 Mdot
.67519 .40182 Mdot
.71213 .45418 Mdot
.51412 .29045 Mdot
.66284 .65104 Mdot
.38861 .32846 Mdot
.32826 .39305 Mdot
.64586 .6713 Mdot
.70007 .46105 Mdot
.38976 .307 Mdot
.31168 .5887 Mdot
.28745 .5464 Mdot
.40591 .69167 Mdot
.29269 .43681 Mdot
.36262 .67374 Mdot
.54684 .29867 Mdot
.51766 .7237 Mdot
.6402 .64566 Mdot
.36814 .32132 Mdot
.70181 .48769 Mdot
.40636 .30287 Mdot
.40939 .68379 Mdot
.50069 .71008 Mdot
.63236 .33394 Mdot
.69857 .40171 Mdot
.41876 .70513 Mdot
.31917 .41441 Mdot
.28842 .46835 Mdot
.40014 .67406 Mdot
.3322 .62917 Mdot
.41806 .31362 Mdot
.32645 .61749 Mdot
.71027 .50616 Mdot
.67785 .60127 Mdot
.50653 .29983 Mdot
.53362 .71469 Mdot
.59628 .32047 Mdot
.69099 .38748 Mdot
.48979 .7034 Mdot
.33858 .63076 Mdot
.68091 .40794 Mdot
.72091 .49452 Mdot
.51268 .72403 Mdot
.32206 .38586 Mdot
.51835 .71324 Mdot
.29355 .48911 Mdot
.28774 .52525 Mdot
.45572 .70981 Mdot
.37956 .32792 Mdot
.3531 .66075 Mdot
.33706 .62667 Mdot
.70768 .46871 Mdot
.30027 .53843 Mdot
.71238 .47337 Mdot
.52717 .70219 Mdot
.34437 .62977 Mdot
.71473 .48974 Mdot
.66197 .34979 Mdot
.29928 .48579 Mdot
.33137 .38086 Mdot
.63616 .33208 Mdot
.52671 .71203 Mdot
.29566 .54756 Mdot
.49506 .70363 Mdot
.70625 .49204 Mdot
.46814 .71227 Mdot
.5192 .29852 Mdot
.65844 .35913 Mdot
.53022 .28974 Mdot
.71606 .50453 Mdot
.48479 .71064 Mdot
.32629 .61735 Mdot
.31958 .62589 Mdot
.59982 .69709 Mdot
.69516 .42193 Mdot
.69137 .39718 Mdot
.69199 .43166 Mdot
.37868 .33774 Mdot
.58523 .68247 Mdot
.51825 .28518 Mdot
.32099 .61722 Mdot
.51431 .27597 Mdot
.62302 .6612 Mdot
.36862 .67 Mdot
.49114 .29241 Mdot
.59405 .69769 Mdot
.57379 .29001 Mdot
.49013 .70143 Mdot
.63756 .32986 Mdot
.32732 .3572 Mdot
.40468 .30462 Mdot
.61879 .32867 Mdot
.47447 .70181 Mdot
.67899 .60789 Mdot
.64296 .64078 Mdot
.47475 .28232 Mdot
.34066 .64857 Mdot
.31049 .43539 Mdot
.30486 .39781 Mdot
.4383 .71486 Mdot
.46047 .30243 Mdot
.41024 .29426 Mdot
.70226 .55303 Mdot
.61348 .31623 Mdot
.52678 .29607 Mdot
.50222 .29302 Mdot
.37638 .33642 Mdot
.71116 .52679 Mdot
.47812 .71105 Mdot
.29171 .54274 Mdot
.41973 .2985 Mdot
.59924 .6897 Mdot
.71187 .46109 Mdot
.28592 .51514 Mdot
.68684 .41249 Mdot
.36937 .31849 Mdot
.60804 .66907 Mdot
.67447 .37158 Mdot
.28008 .4827 Mdot
.64761 .3595 Mdot
.50517 .70835 Mdot
.31668 .61452 Mdot
.29693 .42488 Mdot
.51542 .70148 Mdot
.32709 .39731 Mdot
.49878 .28756 Mdot
.37647 .31821 Mdot
.67426 .62389 Mdot
.28094 .50618 Mdot
.56952 .71102 Mdot
.72228 .47618 Mdot
.40648 .69736 Mdot
.48239 .28559 Mdot
.67028 .39088 Mdot
.59449 .70268 Mdot
.40517 .32371 Mdot
.31618 .3746 Mdot
.68792 .4003 Mdot
.68862 .42568 Mdot
.6004 .29986 Mdot
.30385 .57095 Mdot
.35704 .35767 Mdot
.29601 .55 Mdot
.43039 .69637 Mdot
.46531 .28286 Mdot
.33721 .6264 Mdot
.28721 .43932 Mdot
.46584 .29693 Mdot
.71234 .42943 Mdot
.56888 .29296 Mdot
.72069 .51203 Mdot
.71702 .46857 Mdot
.30446 .41697 Mdot
.36942 .674 Mdot
.66211 .62119 Mdot
.69967 .56245 Mdot
.35109 .64452 Mdot
.38406 .33323 Mdot
.60543 .31696 Mdot
.70094 .40519 Mdot
.6587 .35872 Mdot
.64083 .64757 Mdot
.6536 .34749 Mdot
.62154 .67089 Mdot
.42293 .6889 Mdot
.566 .29312 Mdot
.55077 .69512 Mdot
.50118 .29206 Mdot
.60809 .30941 Mdot
.66752 .61788 Mdot
.70787 .49861 Mdot
.6026 .68054 Mdot
.6656 .64545 Mdot
.69758 .54945 Mdot
.51391 .70347 Mdot
.66644 .35771 Mdot
.70198 .40103 Mdot
.67156 .60628 Mdot
.4554 .28119 Mdot
.3858 .68672 Mdot
.65392 .36582 Mdot
.51374 .71359 Mdot
.66779 .35568 Mdot
.68561 .59023 Mdot
.52799 .30104 Mdot
.69837 .54171 Mdot
.28281 .45416 Mdot
.62735 .66539 Mdot
.32508 .36322 Mdot
.69366 .57289 Mdot
.67025 .35483 Mdot
.45998 .29075 Mdot
.71953 .5024 Mdot
.27773 .52786 Mdot
.66764 .64741 Mdot
.31762 .61876 Mdot
.37789 .68578 Mdot
.34788 .65183 Mdot
.5731 .31347 Mdot
.52637 .7045 Mdot
.55816 .6948 Mdot
.6052 .69807 Mdot
.41736 .68712 Mdot
.29816 .56228 Mdot
.41726 .69303 Mdot
.70899 .46314 Mdot
.56587 .70128 Mdot
.29798 .41396 Mdot
.63369 .3323 Mdot
.57662 .68977 Mdot
.70459 .56318 Mdot
.71621 .44353 Mdot
.61724 .32478 Mdot
.55172 .28186 Mdot
.29684 .46433 Mdot
.39196 .68353 Mdot
.55069 .71537 Mdot
.36965 .65268 Mdot
.70871 .51781 Mdot
.56172 .30328 Mdot
.62202 .68307 Mdot
.34429 .37208 Mdot
.65965 .63 Mdot
.38076 .33564 Mdot
.47941 .7191 Mdot
.63295 .34545 Mdot
.48289 .28689 Mdot
.28752 .4617 Mdot
.28493 .46726 Mdot
.60845 .68582 Mdot
.29238 .48629 Mdot
.35932 .65453 Mdot
.3704 .66913 Mdot
.51052 .29281 Mdot
.50612 .7071 Mdot
.65914 .62826 Mdot
.71052 .47393 Mdot
.50643 .70042 Mdot
.50963 .72312 Mdot
.45621 .295 Mdot
.46029 .29808 Mdot
.29151 .43141 Mdot
.55729 .71522 Mdot
.58596 .69216 Mdot
.62801 .33397 Mdot
.31909 .59221 Mdot
.34339 .3717 Mdot
.40858 .70412 Mdot
.35147 .34411 Mdot
.70061 .59768 Mdot
.33659 .64277 Mdot
.36849 .6682 Mdot
.39434 .31712 Mdot
.57422 .29394 Mdot
.29389 .55566 Mdot
.34978 .35539 Mdot
.33775 .37659 Mdot
.56717 .69417 Mdot
.70126 .49273 Mdot
.65074 .35842 Mdot
.36001 .65797 Mdot
.57421 .30497 Mdot
.7173 .47213 Mdot
.28967 .56506 Mdot
.41976 .69176 Mdot
.37896 .33936 Mdot
.63452 .3267 Mdot
.71489 .53439 Mdot
.49789 .71552 Mdot
.60017 .31297 Mdot
.49017 .71391 Mdot
.69461 .43442 Mdot
.65799 .37244 Mdot
.64087 .67117 Mdot
.67798 .39047 Mdot
.42364 .3135 Mdot
.33665 .38269 Mdot
.69379 .55096 Mdot
.4923 .29341 Mdot
.70675 .52042 Mdot
.28403 .51017 Mdot
.58453 .70376 Mdot
.51876 .7012 Mdot
.51468 .71474 Mdot
.37607 .6866 Mdot
.67783 .62705 Mdot
.30481 .5902 Mdot
.31634 .61562 Mdot
.60538 .31385 Mdot
.35204 .65825 Mdot
.67636 .60871 Mdot
.37303 .66586 Mdot
.32169 .37815 Mdot
.60675 .68465 Mdot
.36345 .66464 Mdot
.70026 .40179 Mdot
.71368 .52277 Mdot
.59706 .32 Mdot
.30702 .38457 Mdot
.31503 .60454 Mdot
.50505 .2891 Mdot
.71066 .56622 Mdot
.39725 .32402 Mdot
.42756 .30082 Mdot
.69228 .5912 Mdot
.27978 .46098 Mdot
.4447 .28302 Mdot
.33806 .38161 Mdot
.42721 .30406 Mdot
.53015 .28096 Mdot
.66315 .63087 Mdot
.37354 .66594 Mdot
.36454 .6774 Mdot
.4277 .70015 Mdot
.41654 .29708 Mdot
.34578 .37129 Mdot
.34711 .36104 Mdot
.67548 .6005 Mdot
.67332 .38556 Mdot
.29963 .52236 Mdot
.55053 .71789 Mdot
.44957 .30077 Mdot
.66855 .63268 Mdot
.36193 .67368 Mdot
.50319 .28371 Mdot
.69812 .56676 Mdot
.70394 .58742 Mdot
.30593 .57538 Mdot
.29652 .57032 Mdot
.37046 .66013 Mdot
.2989 .44847 Mdot
.64536 .35636 Mdot
.40376 .68544 Mdot
.61346 .69296 Mdot
.54105 .71554 Mdot
.57259 .31152 Mdot
.30106 .54093 Mdot
.50928 .28229 Mdot
.33073 .61778 Mdot
.41581 .69208 Mdot
.7078 .44133 Mdot
.69652 .44623 Mdot
.31983 .6046 Mdot
.69558 .61 Mdot
.6894 .62036 Mdot
.67334 .39915 Mdot
.64037 .35061 Mdot
.67437 .63993 Mdot
.33494 .61624 Mdot
.37823 .66574 Mdot
.72067 .49875 Mdot
.71559 .54834 Mdot
.69735 .55451 Mdot
.69188 .60177 Mdot
.34503 .34187 Mdot
.71774 .49462 Mdot
.28381 .44952 Mdot
.69043 .60458 Mdot
.39125 .3122 Mdot
.71538 .46213 Mdot
.48094 .71429 Mdot
.34605 .35277 Mdot
.47932 .71849 Mdot
.31409 .38792 Mdot
.53741 .71144 Mdot
.27546 .48767 Mdot
.31984 .37669 Mdot
.29358 .48354 Mdot
.70627 .5802 Mdot
.30408 .58811 Mdot
.34052 .62768 Mdot
.28566 .5544 Mdot
.64813 .65467 Mdot
.6104 .32358 Mdot
.64365 .33377 Mdot
.49641 .71601 Mdot
.37063 .34101 Mdot
.49174 .284 Mdot
.70298 .56003 Mdot
.52458 .70763 Mdot
.71461 .48208 Mdot
.5658 .29084 Mdot
.32483 .38226 Mdot
.38274 .68983 Mdot
.28322 .54739 Mdot
.28499 .50125 Mdot
.33817 .37877 Mdot
.50502 .72392 Mdot
.7156 .44614 Mdot
.29221 .49671 Mdot
.68142 .39313 Mdot
.47019 .72174 Mdot
.69837 .40441 Mdot
.29852 .53483 Mdot
.39428 .68045 Mdot
.63676 .65451 Mdot
.64392 .34401 Mdot
.35757 .33718 Mdot
.47856 .70895 Mdot
.33324 .6394 Mdot
.42762 .70013 Mdot
.65862 .36309 Mdot
.34419 .62897 Mdot
.34223 .3602 Mdot
.29899 .5497 Mdot
.62886 .66113 Mdot
.65555 .65968 Mdot
.7247 .51123 Mdot
.48878 .71038 Mdot
.35495 .64999 Mdot
.7004 .49019 Mdot
.71509 .47714 Mdot
.41791 .30365 Mdot
.66993 .61781 Mdot
.4387 .70143 Mdot
.28058 .52621 Mdot
.60424 .32523 Mdot
.38677 .68237 Mdot
.44702 .30137 Mdot
.396 .68781 Mdot
.29086 .56791 Mdot
.69895 .44645 Mdot
.2884 .55743 Mdot
.71208 .46642 Mdot
.52695 .29533 Mdot
.65026 .35625 Mdot
.2821 .53617 Mdot
.33054 .62732 Mdot
.35957 .33405 Mdot
.70719 .58055 Mdot
.6915 .40946 Mdot
.47207 .29427 Mdot
.28484 .52762 Mdot
.52574 .30006 Mdot
.72057 .53049 Mdot
.55958 .29668 Mdot
.49861 .71623 Mdot
.67672 .39823 Mdot
.53748 .28287 Mdot
.28465 .47363 Mdot
.63037 .65555 Mdot
.28711 .55412 Mdot
.55471 .7091 Mdot
.47587 .28934 Mdot
.47132 .27763 Mdot
.70431 .44956 Mdot
.44709 .30553 Mdot
.61247 .69323 Mdot
.29743 .55652 Mdot
.50102 .71965 Mdot
.40785 .30579 Mdot
.47443 .29893 Mdot
.29482 .44662 Mdot
.47458 .70647 Mdot
.39209 .69272 Mdot
.28516 .44822 Mdot
.32204 .36785 Mdot
.31311 .40304 Mdot
.67302 .36392 Mdot
.32099 .61351 Mdot
.30629 .58061 Mdot
.61552 .68407 Mdot
.51069 .28041 Mdot
.30527 .59025 Mdot
.54249 .70345 Mdot
.60913 .67543 Mdot
.65987 .36082 Mdot
.34995 .35221 Mdot
.45391 .71031 Mdot
.69118 .55898 Mdot
.32999 .63992 Mdot
.36166 .3379 Mdot
.70133 .43899 Mdot
.28156 .53212 Mdot
.57246 .70298 Mdot
.69767 .55856 Mdot
.70574 .47164 Mdot
.66789 .35086 Mdot
.6847 .62084 Mdot
.48574 .71348 Mdot
.57306 .30801 Mdot
.53788 .65996 Mdot
.37101 .57361 Mdot
.44407 .47131 Mdot
.30536 .54441 Mdot
.59511 .5679 Mdot
.48296 .64306 Mdot
.68607 .56414 Mdot
.47952 .57838 Mdot
.5971 .67257 Mdot
.53942 .61745 Mdot
.6246 .41851 Mdot
.45732 .53504 Mdot
.43545 .32131 Mdot
.66736 .47148 Mdot
.6373 .62795 Mdot
.33 .49055 Mdot
.66971 .52222 Mdot
.50786 .62458 Mdot
.67178 .46487 Mdot
.60658 .46484 Mdot
.55439 .33067 Mdot
.50101 .30415 Mdot
.60295 .41661 Mdot
.37589 .6496 Mdot
.54964 .64298 Mdot
.39771 .58783 Mdot
.6497 .57918 Mdot
.62746 .37765 Mdot
.68621 .5693 Mdot
.40132 .3833 Mdot
.61441 .57141 Mdot
.45168 .38018 Mdot
.45864 .66387 Mdot
.62798 .44762 Mdot
.39133 .58137 Mdot
.36862 .42996 Mdot
.5582 .68256 Mdot
.53439 .58825 Mdot
.59254 .59076 Mdot
.44273 .63798 Mdot
.62116 .55403 Mdot
.40936 .32395 Mdot
.6971 .47251 Mdot
.67691 .48365 Mdot
.4454 .36558 Mdot
.63739 .54194 Mdot
.47915 .57934 Mdot
.30652 .53791 Mdot
.59702 .56158 Mdot
.46641 .68659 Mdot
.69006 .45946 Mdot
.64804 .46763 Mdot
.63825 .39928 Mdot
.46016 .64967 Mdot
.65202 .41872 Mdot
.43692 .67156 Mdot
.51338 .62672 Mdot
.4918 .64625 Mdot
.60744 .4593 Mdot
.53741 .35316 Mdot
.61994 .33996 Mdot
.33333 .48808 Mdot
.5656 .44275 Mdot
.39848 .47007 Mdot
.65345 .48648 Mdot
.49533 .67614 Mdot
.67195 .57333 Mdot
.68431 .43772 Mdot
.58014 .35617 Mdot
.43978 .35004 Mdot
.60962 .4076 Mdot
.57303 .4466 Mdot
.63969 .53231 Mdot
.37812 .60324 Mdot
.5772 .60677 Mdot
.57822 .38096 Mdot
.59629 .66133 Mdot
.3507 .40746 Mdot
.53745 .52728 Mdot
.38396 .35942 Mdot
.48141 .65264 Mdot
.6167 .46285 Mdot
.43532 .56016 Mdot
.59778 .53275 Mdot
.39974 .64837 Mdot
.41125 .35356 Mdot
.55191 .64198 Mdot
.55534 .38382 Mdot
.66599 .53151 Mdot
.51845 .66662 Mdot
.65166 .42824 Mdot
.34265 .39695 Mdot
.4451 .41305 Mdot
.39343 .36897 Mdot
.48639 .5723 Mdot
.36911 .41705 Mdot
.62711 .44503 Mdot
.66883 .41612 Mdot
.48887 .30721 Mdot
.63057 .60241 Mdot
.46759 .3705 Mdot
.63917 .35803 Mdot
.53482 .32527 Mdot
.47933 .60433 Mdot
.62029 .61429 Mdot
.39551 .37401 Mdot
.58737 .36481 Mdot
.583 .52692 Mdot
.59549 .43622 Mdot
.5895 .58761 Mdot
.56698 .61402 Mdot
.67434 .51918 Mdot
.30865 .55625 Mdot
.60928 .63913 Mdot
.43894 .38346 Mdot
.6062 .37628 Mdot
.33082 .44237 Mdot
.53358 .69673 Mdot
.47195 .38802 Mdot
.58997 .6717 Mdot
.50974 .47277 Mdot
.66607 .55382 Mdot
.38536 .36284 Mdot
.69524 .54035 Mdot
.57158 .66456 Mdot
.60212 .41378 Mdot
.34855 .48903 Mdot
.67991 .52908 Mdot
.67374 .45452 Mdot
.5591 .32707 Mdot
.50172 .66202 Mdot
.36952 .36239 Mdot
.34831 .55607 Mdot
.39947 .44527 Mdot
.56268 .32403 Mdot
.38867 .4662 Mdot
.43399 .4382 Mdot
.39507 .33803 Mdot
.63503 .60922 Mdot
.43004 .42263 Mdot
.61577 .65725 Mdot
.57019 .37344 Mdot
.61949 .41397 Mdot
.54859 .654 Mdot
.31597 .55093 Mdot
.39955 .40327 Mdot
.45615 .43755 Mdot
.59297 .54744 Mdot
.69333 .54043 Mdot
.39185 .56252 Mdot
.62022 .43833 Mdot
.51956 .40869 Mdot
.52312 .35731 Mdot
.67173 .44775 Mdot
.6403 .3595 Mdot
.5012 .38373 Mdot
.41709 .54705 Mdot
.63039 .63822 Mdot
.50719 .42534 Mdot
.66847 .56011 Mdot
.49016 .41104 Mdot
.39923 .38131 Mdot
.56555 .32785 Mdot
.58756 .38621 Mdot
.64478 .52983 Mdot
.64083 .39955 Mdot
.58261 .62567 Mdot
.59032 .6239 Mdot
.49109 .36393 Mdot
.66669 .52117 Mdot
.62666 .47938 Mdot
.68701 .45889 Mdot
.50573 .61162 Mdot
.43064 .63082 Mdot
.36592 .55909 Mdot
.435 .51105 Mdot
.3376 .61552 Mdot
.36864 .43634 Mdot
.50608 .66516 Mdot
.32721 .59208 Mdot
.3745 .49641 Mdot
.38547 .58106 Mdot
.30471 .46244 Mdot
.35698 .56039 Mdot
.45548 .68093 Mdot
.56135 .54999 Mdot
.59107 .38178 Mdot
.46092 .45533 Mdot
.35607 .54392 Mdot
.65848 .56715 Mdot
.54881 .68395 Mdot
.38834 .36202 Mdot
.45172 .33698 Mdot
.50911 .64116 Mdot
.57891 .65233 Mdot
.56318 .31859 Mdot
.64098 .37655 Mdot
.43595 .32377 Mdot
.64541 .52875 Mdot
.67294 .56711 Mdot
.32478 .40624 Mdot
.60866 .49667 Mdot
.43282 .57201 Mdot
.4065 .62307 Mdot
.41919 .36276 Mdot
.57192 .56233 Mdot
.30907 .51036 Mdot
.45521 .61246 Mdot
.4415 .45413 Mdot
.39017 .40219 Mdot
.34598 .4218 Mdot
.342 .44099 Mdot
.67437 .49624 Mdot
.35929 .44247 Mdot
.3861 .38306 Mdot
.55134 .69174 Mdot
.56575 .48391 Mdot
.6581 .60701 Mdot
.39221 .52026 Mdot
.5371 .33094 Mdot
.56386 .42718 Mdot
.56172 .60993 Mdot
.46152 .65058 Mdot
.36764 .38811 Mdot
.45004 .67931 Mdot
.61338 .53678 Mdot
.43563 .38934 Mdot
.56706 .39657 Mdot
.46566 .38358 Mdot
.49718 .35719 Mdot
.50783 .57729 Mdot
.67399 .4582 Mdot
.36624 .64363 Mdot
.54222 .35083 Mdot
.63704 .57481 Mdot
.57719 .67012 Mdot
.53954 .32955 Mdot
.6139 .62484 Mdot
.60799 .60158 Mdot
.46368 .6388 Mdot
.40183 .55741 Mdot
.4675 .49081 Mdot
.54155 .59103 Mdot
.38474 .43531 Mdot
.54324 .39563 Mdot
.54376 .31776 Mdot
.48102 .32306 Mdot
.46853 .47549 Mdot
.56166 .47855 Mdot
.35419 .52496 Mdot
.57924 .34822 Mdot
.52714 .5599 Mdot
.37081 .58108 Mdot
.45959 .45213 Mdot
.51801 .63536 Mdot
.66958 .56348 Mdot
.41055 .55182 Mdot
.47624 .69301 Mdot
.43853 .36166 Mdot
.40045 .3336 Mdot
.48775 .35329 Mdot
.5576 .64867 Mdot
.65497 .40187 Mdot
.65538 .50868 Mdot
.36209 .50056 Mdot
.39551 .61061 Mdot
.49456 .54215 Mdot
.43111 .66351 Mdot
.61611 .3483 Mdot
.67705 .5502 Mdot
.57272 .63332 Mdot
.36112 .63077 Mdot
.43798 .5274 Mdot
.55358 .63195 Mdot
.37255 .48094 Mdot
.5822 .67393 Mdot
.69362 .52975 Mdot
.55574 .35728 Mdot
.50473 .30484 Mdot
.31824 .5048 Mdot
.56278 .45432 Mdot
.31087 .55906 Mdot
.47794 .33083 Mdot
.58477 .54123 Mdot
.45284 .66016 Mdot
.63473 .37884 Mdot
.51869 .36532 Mdot
.44558 .31825 Mdot
.4979 .35584 Mdot
.61651 .40896 Mdot
.65253 .49408 Mdot
.36052 .60317 Mdot
.62099 .58105 Mdot
.66617 .44231 Mdot
.37938 .63755 Mdot
.61747 .38219 Mdot
.60318 .54777 Mdot
.68783 .48977 Mdot
.44438 .68261 Mdot
.45347 .69301 Mdot
.34935 .45171 Mdot
.3698 .60336 Mdot
.43063 .47475 Mdot
.69451 .49336 Mdot
.33055 .54169 Mdot
.61893 .53679 Mdot
.65824 .61051 Mdot
.58124 .65457 Mdot
.67608 .53133 Mdot
.57839 .67113 Mdot
.47744 .31223 Mdot
.64927 .38269 Mdot
.55876 .6282 Mdot
.36899 .49936 Mdot
.40592 .40467 Mdot
.35789 .49445 Mdot
.58808 .64775 Mdot
.40511 .52534 Mdot
.66472 .57426 Mdot
.46604 .64979 Mdot
.55462 .5138 Mdot
.63546 .60351 Mdot
.45972 .60478 Mdot
.54563 .67705 Mdot
.63118 .63421 Mdot
.4601 .34825 Mdot
.33857 .49922 Mdot
.52905 .59521 Mdot
.4007 .66475 Mdot
.49881 .46609 Mdot
.48733 .60607 Mdot
.34137 .54187 Mdot
.51299 .60048 Mdot
.38016 .65435 Mdot
.67314 .40639 Mdot
.56761 .58741 Mdot
.52762 .40334 Mdot
.33764 .56888 Mdot
.45441 .66252 Mdot
.51731 .66418 Mdot
.67212 .45257 Mdot
.33579 .5115 Mdot
.4377 .34748 Mdot
.53488 .50664 Mdot
.3542 .53865 Mdot
.46201 .42559 Mdot
.34821 .46342 Mdot
.30995 .46418 Mdot
.49411 .35933 Mdot
.60025 .56676 Mdot
.32742 .5563 Mdot
.61096 .36627 Mdot
.43381 .50308 Mdot
.43624 .56675 Mdot
.55232 .35271 Mdot
.45082 .576 Mdot
.45883 .56012 Mdot
.47289 .45313 Mdot
.55912 .34481 Mdot
.56357 .57385 Mdot
.61155 .54793 Mdot
.68578 .55192 Mdot
.38272 .39689 Mdot
.55078 .61369 Mdot
.60943 .60561 Mdot
.53959 .4032 Mdot
.41835 .67978 Mdot
.42746 .51366 Mdot
.69115 .46637 Mdot
.52072 .4411 Mdot
.57164 .62002 Mdot
.40323 .33169 Mdot
.57937 .55749 Mdot
.46294 .4636 Mdot
.32826 .51625 Mdot
.32892 .5672 Mdot
.42361 .58909 Mdot
.38138 .3758 Mdot
.61933 .53464 Mdot
.59104 .64009 Mdot
.62353 .56069 Mdot
.39986 .63002 Mdot
.66686 .39163 Mdot
.43412 .34095 Mdot
.56859 .32207 Mdot
.65699 .56668 Mdot
.44573 .6089 Mdot
.36509 .36763 Mdot
.55523 .4861 Mdot
.61897 .49614 Mdot
.65916 .40696 Mdot
.58861 .35344 Mdot
.58511 .37154 Mdot
.41605 .50948 Mdot
.64293 .43794 Mdot
.542 .35408 Mdot
.61874 .62061 Mdot
.47736 .31437 Mdot
.54711 .36289 Mdot
.65493 .62363 Mdot
.57751 .38103 Mdot
.63905 .61855 Mdot
.64866 .42554 Mdot
.48345 .60118 Mdot
.58486 .54873 Mdot
.52115 .42493 Mdot
.60314 .63856 Mdot
.67069 .49904 Mdot
.5667 .50924 Mdot
.47852 .68475 Mdot
.5334 .67065 Mdot
.59952 .65952 Mdot
.40401 .59321 Mdot
.5779 .5247 Mdot
.3287 .55418 Mdot
.52821 .30658 Mdot
.38537 .62474 Mdot
.68963 .47525 Mdot
.53686 .69407 Mdot
.62545 .48434 Mdot
.56231 .68467 Mdot
.46363 .35131 Mdot
.62784 .48301 Mdot
.33822 .44677 Mdot
.3411 .38205 Mdot
.33622 .49822 Mdot
.5732 .60125 Mdot
.47727 .33138 Mdot
.53445 .33149 Mdot
.49924 .31898 Mdot
.3379 .43348 Mdot
.51886 .34357 Mdot
.38105 .63705 Mdot
.56437 .52422 Mdot
.38276 .60363 Mdot
.34998 .4937 Mdot
.53307 .34364 Mdot
.69112 .50595 Mdot
.41356 .40465 Mdot
.47907 .62561 Mdot
.60141 .3617 Mdot
.34182 .47296 Mdot
.45251 .69136 Mdot
.50298 .43963 Mdot
.60607 .44592 Mdot
.43916 .3104 Mdot
.32546 .455 Mdot
.55704 .65506 Mdot
.50532 .37905 Mdot
.56615 .66388 Mdot
.63998 .63858 Mdot
.62897 .42114 Mdot
.47977 .63599 Mdot
.35377 .62776 Mdot
.64251 .48634 Mdot
.36654 .36168 Mdot
.60011 .53951 Mdot
.67333 .41477 Mdot
.35092 .48148 Mdot
.48548 .36159 Mdot
.50934 .38302 Mdot
.33372 .45234 Mdot
.41912 .40412 Mdot
.41893 .41173 Mdot
.37131 .64604 Mdot
.50332 .63384 Mdot
.38006 .61238 Mdot
.39035 .39933 Mdot
.43701 .63311 Mdot
.442 .35093 Mdot
.56209 .31162 Mdot
.60786 .47055 Mdot
.67838 .54342 Mdot
.36185 .58389 Mdot
.36961 .59533 Mdot
.52659 .3669 Mdot
.66518 .53644 Mdot
.45458 .48975 Mdot
.45838 .43926 Mdot
.64635 .41606 Mdot
.41268 .6497 Mdot
.5133 .5882 Mdot
.32838 .46348 Mdot
.47736 .69277 Mdot
.30686 .50562 Mdot
.5896 .38516 Mdot
.61885 .5817 Mdot
.57494 .53764 Mdot
.66989 .56886 Mdot
.42355 .48101 Mdot
.35054 .59899 Mdot
.38848 .3931 Mdot
.57376 .53634 Mdot
.38608 .58784 Mdot
.35784 .46398 Mdot
.60774 .61028 Mdot
.65191 .54323 Mdot
.48886 .58237 Mdot
.59282 .46873 Mdot
.56495 .68902 Mdot
.60662 .40835 Mdot
.39366 .33571 Mdot
.33013 .52136 Mdot
.65199 .53592 Mdot
.36255 .59062 Mdot
.44071 .42696 Mdot
.57372 .41922 Mdot
.32784 .48413 Mdot
.57813 .3433 Mdot
.50707 .66609 Mdot
.61636 .38412 Mdot
.65955 .54735 Mdot
.61783 .49135 Mdot
.3691 .61202 Mdot
.33354 .49136 Mdot
.43555 .58824 Mdot
.54452 .53278 Mdot
.48012 .42471 Mdot
.51992 .68897 Mdot
.55108 .63991 Mdot
.40364 .56143 Mdot
.67977 .4429 Mdot
.33226 .46323 Mdot
.60599 .42811 Mdot
.35566 .45708 Mdot
.33022 .48093 Mdot
.684 .54448 Mdot
.57659 .63408 Mdot
.67308 .42733 Mdot
.35748 .53804 Mdot
.44292 .31048 Mdot
.48226 .69842 Mdot
.44995 .67739 Mdot
.45899 .59788 Mdot
.50628 .394 Mdot
.33907 .60499 Mdot
.54089 .67477 Mdot
.59889 .41839 Mdot
.58613 .6708 Mdot
.46838 .31679 Mdot
.50505 .57255 Mdot
.48674 .64702 Mdot
.41635 .48103 Mdot
.64905 .50011 Mdot
.50693 .63314 Mdot
.45048 .38155 Mdot
.39521 .5117 Mdot
.47382 .64218 Mdot
.48222 .64916 Mdot
.42571 .56243 Mdot
.63645 .59051 Mdot
.43175 .38295 Mdot
.59677 .37407 Mdot
.34208 .61222 Mdot
.43718 .6362 Mdot
.37111 .59174 Mdot
.58865 .54662 Mdot
.47293 .38041 Mdot
.33557 .38863 Mdot
.32566 .57467 Mdot
.42457 .64607 Mdot
.67302 .55241 Mdot
.50407 .53721 Mdot
.38963 .60257 Mdot
.38495 .61026 Mdot
.65932 .47902 Mdot
.58152 .53204 Mdot
.44924 .47308 Mdot
.696 .47841 Mdot
.62071 .35962 Mdot
.34874 .62871 Mdot
.32406 .58628 Mdot
.63902 .55699 Mdot
.41415 .58 Mdot
.5714 .36869 Mdot
.68366 .49976 Mdot
.31524 .5589 Mdot
.62588 .51641 Mdot
.35435 .61851 Mdot
.3849 .54306 Mdot
.33965 .60353 Mdot
.36682 .4268 Mdot
.6907 .52526 Mdot
.59113 .62975 Mdot
.64994 .46054 Mdot
.51832 .36794 Mdot
.55001 .5531 Mdot
.52233 .34054 Mdot
.45546 .40703 Mdot
.50122 .37136 Mdot
.46834 .63151 Mdot
.4767 .56052 Mdot
.61015 .39505 Mdot
.47735 .33328 Mdot
.60279 .37234 Mdot
.41835 .45778 Mdot
.57061 .44791 Mdot
.56184 .32487 Mdot
.50789 .43448 Mdot
.62807 .526 Mdot
.66286 .60361 Mdot
.49112 .54601 Mdot
.5544 .34137 Mdot
.69548 .46508 Mdot
.59416 .45108 Mdot
.50606 .64517 Mdot
.65437 .56778 Mdot
.43462 .38553 Mdot
.57984 .63897 Mdot
.60276 .38104 Mdot
.37463 .59359 Mdot
.55794 .39694 Mdot
.4408 .6559 Mdot
.3902 .46344 Mdot
.30077 .49351 Mdot
.39475 .44276 Mdot
.33542 .40756 Mdot
.40333 .66133 Mdot
.37601 .48781 Mdot
.41995 .35757 Mdot
.39558 .64644 Mdot
.52651 .42652 Mdot
.61975 .46163 Mdot
.68707 .46869 Mdot
.39097 .36324 Mdot
.34619 .5815 Mdot
.61398 .6338 Mdot
.58433 .3728 Mdot
.3231 .43473 Mdot
.3303 .49226 Mdot
.66287 .54254 Mdot
.54312 .43086 Mdot
.43206 .32164 Mdot
.53919 .50841 Mdot
.49082 .32966 Mdot
.59989 .53957 Mdot
.6602 .61417 Mdot
.39725 .37958 Mdot
.62583 .46841 Mdot
.52049 .42847 Mdot
.37489 .5855 Mdot
.46485 .64785 Mdot
.37622 .64232 Mdot
.36377 .54579 Mdot
.40666 .32543 Mdot
.37731 .57281 Mdot
.6276 .44037 Mdot
.42753 .59375 Mdot
.57236 .37197 Mdot
.4634 .32519 Mdot
.56886 .42761 Mdot
.65407 .41873 Mdot
.32721 .53699 Mdot
.42026 .40886 Mdot
.65155 .6138 Mdot
.57285 .67496 Mdot
.32617 .58093 Mdot
.52213 .34412 Mdot
.33794 .49976 Mdot
.38627 .56466 Mdot
.44972 .41074 Mdot
.44939 .34232 Mdot
.51252 .45915 Mdot
.53367 .30935 Mdot
.43342 .61951 Mdot
.61048 .6374 Mdot
.52104 .65397 Mdot
.6808 .44749 Mdot
.54949 .33993 Mdot
.55774 .62803 Mdot
.47752 .57309 Mdot
.50754 .41936 Mdot
.36601 .35885 Mdot
.64584 .56233 Mdot
.59535 .33113 Mdot
.46188 .66352 Mdot
.3321 .49904 Mdot
.61938 .65237 Mdot
.48598 .59835 Mdot
.53107 .57736 Mdot
.3397 .5256 Mdot
.67961 .5075 Mdot
.56901 .64042 Mdot
.50897 .67387 Mdot
.34289 .45095 Mdot
.54785 .59771 Mdot
.46373 .33099 Mdot
.62843 .3952 Mdot
.51628 .57379 Mdot
.49654 .32566 Mdot
.68289 .43144 Mdot
.3431 .44057 Mdot
.35599 .52924 Mdot
.31919 .44002 Mdot
.4507 .68801 Mdot
.45719 .60978 Mdot
.49343 .35781 Mdot
.54762 .55178 Mdot
.6764 .52941 Mdot
.50921 .65569 Mdot
.56499 .33836 Mdot
.3136 .50732 Mdot
.62153 .36715 Mdot
.61133 .45276 Mdot
.38795 .58161 Mdot
.3935 .59372 Mdot
.61555 .59437 Mdot
.59489 .54908 Mdot
.44936 .55647 Mdot
.58971 .46726 Mdot
.42519 .61779 Mdot
.45071 .33534 Mdot
.3272 .46792 Mdot
.54666 .68154 Mdot
.39603 .33321 Mdot
.47481 .66699 Mdot
.48774 .66974 Mdot
.59579 .41941 Mdot
.56737 .59583 Mdot
.53477 .41639 Mdot
.52372 .3973 Mdot
.63472 .35364 Mdot
.3244 .56188 Mdot
.57192 .6211 Mdot
.58738 .44969 Mdot
.65496 .45471 Mdot
.49605 .61267 Mdot
.41807 .32327 Mdot
.66504 .49389 Mdot
.54609 .33039 Mdot
.57762 .38043 Mdot
.66597 .47851 Mdot
.61273 .54099 Mdot
.62938 .60853 Mdot
.38528 .40578 Mdot
.61934 .4582 Mdot
.45375 .37746 Mdot
.67956 .49056 Mdot
.41386 .53601 Mdot
.43079 .67251 Mdot
.34764 .55716 Mdot
.40091 .48843 Mdot
.40975 .43335 Mdot
.34217 .46054 Mdot
.31074 .44407 Mdot
.32408 .58563 Mdot
.65108 .43609 Mdot
.32501 .52041 Mdot
.50509 .62933 Mdot
.30332 .51252 Mdot
.53862 .39632 Mdot
.54617 .59677 Mdot
.38748 .62944 Mdot
.46693 .44741 Mdot
.5122 .34676 Mdot
.61394 .60926 Mdot
.53262 .65463 Mdot
.44311 .34575 Mdot
.46253 .69241 Mdot
.5449 .68572 Mdot
.67038 .54019 Mdot
.46645 .30875 Mdot
.5198 .65763 Mdot
.32409 .45103 Mdot
.62739 .35773 Mdot
.6333 .37879 Mdot
.61882 .59048 Mdot
.50849 .37612 Mdot
.64742 .37276 Mdot
.66076 .57214 Mdot
.34376 .37713 Mdot
.61425 .35249 Mdot
.37709 .44293 Mdot
.62978 .64267 Mdot
.40102 .65798 Mdot
.41297 .4453 Mdot
.30698 .53325 Mdot
.4603 .35749 Mdot
.39024 .61796 Mdot
.60349 .46337 Mdot
.33234 .5184 Mdot
.61342 .39178 Mdot
.62163 .3807 Mdot
.67302 .52612 Mdot
.45242 .62627 Mdot
.64239 .38418 Mdot
.65531 .46862 Mdot
.44475 .66299 Mdot
.33541 .50474 Mdot
.3984 .43071 Mdot
.54598 .54665 Mdot
.45198 .43443 Mdot
.40601 .38108 Mdot
.52165 .33409 Mdot
.51995 .31408 Mdot
.49611 .30582 Mdot
.34531 .54007 Mdot
.56433 .41758 Mdot
.45331 .50253 Mdot
.34957 .44746 Mdot
.65376 .49611 Mdot
.62533 .46632 Mdot
.60238 .39073 Mdot
.45732 .61015 Mdot
.52955 .69674 Mdot
.33429 .45947 Mdot
.39342 .52789 Mdot
.54574 .328 Mdot
.67387 .49956 Mdot
.65183 .4353 Mdot
.32749 .49109 Mdot
.44336 .5516 Mdot
.38546 .49118 Mdot
.33618 .58453 Mdot
.38531 .35701 Mdot
.62465 .61039 Mdot
.34049 .5928 Mdot
.32567 .40815 Mdot
.66418 .45439 Mdot
.52817 .37691 Mdot
.69032 .44765 Mdot
.6038 .35699 Mdot
.37055 .5429 Mdot
.3318 .53481 Mdot
.59285 .46108 Mdot
.68251 .55096 Mdot
.46089 .63648 Mdot
.61675 .44324 Mdot
.6198 .38504 Mdot
.41928 .60992 Mdot
.67335 .40668 Mdot
.42604 .468 Mdot
.69445 .45541 Mdot
.46859 .35915 Mdot
.32531 .48342 Mdot
.50278 .68106 Mdot
.35572 .42276 Mdot
.55461 .6846 Mdot
.47576 .61241 Mdot
.47203 .66807 Mdot
.35879 .59528 Mdot
.61962 .43946 Mdot
.32638 .51737 Mdot
.42097 .59499 Mdot
.32623 .47805 Mdot
.38377 .34944 Mdot
.69965 .5062 Mdot
.42145 .55874 Mdot
.36286 .56802 Mdot
.5423 .61429 Mdot
.57939 .59961 Mdot
.64709 .41591 Mdot
.48634 .32815 Mdot
.6347 .49314 Mdot
.49595 .69837 Mdot
.44389 .43914 Mdot
.48586 .36616 Mdot
.61857 .48961 Mdot
.48164 .36612 Mdot
.42303 .45231 Mdot
.43942 .68029 Mdot
.34956 .61715 Mdot
.59165 .64181 Mdot
.37386 .51807 Mdot
.32626 .59368 Mdot
.30408 .51795 Mdot
.59799 .67319 Mdot
.61656 .34777 Mdot
.33866 .57006 Mdot
.61813 .37084 Mdot
.46118 .36153 Mdot
.46918 .66367 Mdot
.36774 .58999 Mdot
.63384 .3819 Mdot
.50459 .69375 Mdot
.37166 .58423 Mdot
.58914 .32486 Mdot
.64013 .42536 Mdot
.3909 .33531 Mdot
.6551 .57075 Mdot
.52293 .62937 Mdot
.5605 .687 Mdot
.307 .48104 Mdot
.62625 .43119 Mdot
.61315 .59441 Mdot
.66984 .5387 Mdot
.60386 .38135 Mdot
.41778 .41453 Mdot
.65801 .54005 Mdot
.45132 .32851 Mdot
.37671 .61201 Mdot
.44219 .43199 Mdot
.57089 .61256 Mdot
.40405 .53962 Mdot
.41099 .38531 Mdot
.31788 .48036 Mdot
.30577 .4575 Mdot
.40555 .51107 Mdot
.42378 .36168 Mdot
.61672 .34626 Mdot
.36567 .35634 Mdot
.56921 .59202 Mdot
.50207 .64398 Mdot
.40673 .49443 Mdot
.57326 .54469 Mdot
.67767 .58611 Mdot
.33428 .56297 Mdot
.39102 .46097 Mdot
.64967 .40226 Mdot
.5792 .53929 Mdot
.50906 .62069 Mdot
.52149 .61241 Mdot
.39916 .41896 Mdot
.67936 .58796 Mdot
.37701 .64862 Mdot
.32223 .42561 Mdot
.47323 .68515 Mdot
.3049 .51074 Mdot
.54813 .41329 Mdot
.66659 .42978 Mdot
.63118 .43077 Mdot
.61323 .36862 Mdot
.4544 .39527 Mdot
.40372 .37862 Mdot
.67198 .59023 Mdot
.35976 .43325 Mdot
.48912 .44847 Mdot
.666 .50797 Mdot
.39023 .54028 Mdot
.32844 .48227 Mdot
.43535 .44416 Mdot
.33055 .40701 Mdot
.43625 .33702 Mdot
.47378 .37667 Mdot
.65688 .50594 Mdot
.66528 .58211 Mdot
.64948 .42865 Mdot
.36359 .4977 Mdot
.5385 .65925 Mdot
.31889 .50564 Mdot
.51611 .35999 Mdot
.59272 .48749 Mdot
.57294 .60711 Mdot
.40596 .56943 Mdot
.33538 .53768 Mdot
.41868 .32106 Mdot
.40519 .52551 Mdot
.41519 .43098 Mdot
.33883 .47026 Mdot
.6487 .61692 Mdot
.49345 .51468 Mdot
.42829 .43991 Mdot
.3347 .44795 Mdot
.36525 .35221 Mdot
.3864 .58961 Mdot
.51914 .6847 Mdot
.6661 .42122 Mdot
.32028 .43979 Mdot
.32883 .53115 Mdot
.66523 .43783 Mdot
.58905 .46623 Mdot
.59783 .33848 Mdot
.43299 .43254 Mdot
.52753 .67874 Mdot
.63637 .57163 Mdot
.34937 .39992 Mdot
.46517 .42185 Mdot
.37538 .65108 Mdot
.50317 .3659 Mdot
.53186 .41699 Mdot
.46508 .66909 Mdot
.59787 .38982 Mdot
.4129 .63707 Mdot
.66198 .52976 Mdot
.46672 .353 Mdot
.56143 .32325 Mdot
.37146 .34933 Mdot
.52145 .58333 Mdot
.6847 .44547 Mdot
.56119 .41592 Mdot
.55132 .65981 Mdot
.57242 .51948 Mdot
.67103 .40335 Mdot
.57758 .65517 Mdot
.36869 .4299 Mdot
.55475 .57272 Mdot
.63014 .34952 Mdot
.42751 .60804 Mdot
.50714 .54676 Mdot
.57725 .58669 Mdot
.48665 .59786 Mdot
.48386 .57437 Mdot
.64594 .56983 Mdot
.5013 .52659 Mdot
.59566 .63682 Mdot
.62896 .55677 Mdot
.40137 .44987 Mdot
.6107 .43796 Mdot
.4726 .38938 Mdot
.32279 .4102 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0?ooooooB_ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A006ooooo`03o`000?oooooooooo0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0?ooooooB_oo
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06
ooooo`?o0000oooooom:ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom:ooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooo
oiRHV?l@41001_ooool00ol0003oooooooooo`3ooooood[ooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`;o0000oooooom;ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo09Kooooo2Ol000000ooooooo0000o`000007o`000:3ooooo
000Looooo`03o`000?oooooooooo09;ooooo6ol0002Looooo`007?ooool00ol0003oooooooooo`2=
ooooob3o000000?oooooo`000?l000001?l0002Eooooo`007?ooool00ol0003oooooooooo`29oooo
obko0000T_ooool001cooooo00?o0000ooooooooool0Q_oooolbo`00097ooooo000Looooo`03o`00
0?oooooooooo08Cooooo>?l0002=ooooo`007?ooool00ol0003oooooooooo`22ooooob[o000000?o
ooooo`000?l000003ol0002;ooooo`007?ooool00ol0003oooooooooo`20ooooocoo0000R_ooool0
01cooooo0_l0001oooooodGo0000Q_ooool001cooooo00?o0000ooooooooool0NooooolPo`000004
ooooool0003o0000ooooo`Co000000?oooooo`000?l000007_l00025ooooo`007?ooool00ol0003o
ooooooooo`1joooooaKo000000Goooooo`000?l0003o0000ooooo`02o`0000Cooooo1ol00006oooo
o`;o000000?oooooo`000?l000006?l00024ooooo`007?ooool00ol0003oooooooooo`1joooooaKo
00001?ooool2o`0000Gooooo1?l000000ooooooo0000o`000006ooooo`Co00000ooooolIo`00087o
oooo000Looooo`03o`000?oooooooooo07Oooooo5ol00006ooooo`;o000000?oooooo`000?l00000
4Oooool2o`0000Oooooo5Ol00021ooooo`007?ooool00ol0003oooooooooo`1eoooooaGo00002_oo
ool2o`000003ooooool0003o000000cooooo0_l0000<ooooo`;o000000?oooooo`000?l000004Ol0
0020ooooo`007?ooool00ol0003oooooooooo`1doooooa?o00001_ooool2o`0000Gooooo0_l00000
0ooooooo0000o`000005ooooo`;o00001Oooool2o`0000Kooooo0_l00004ooooo`;o00001?oooolB
o`0007kooooo000Looooo`03o`000?oooooooooo07Cooooo4_l00003ooooo`?o000000?oooooo`00
0?l000002Oooool2o`0000Cooooo0_l0000=ooooo`;o00001?ooool4o`0000Cooooo4_l0001loooo
o`007?ooool00ol0003oooooooooo`1boooooa7o000000?oooooo`000?l000000oooool3o`0000Oo
oooo0_l00003ooooo`;o00001?ooool2o`0000[ooooo0_l00007ooooo`Co00001OoooolAo`0007co
oooo000Looooo`03o`000?oooooooooo073ooooo4ol000000ooooooo0000o`000004ooooo`;o0000
0oooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000[ooooo0_l00002ooooo`;o0000
0_ooool4o`0000Kooooo0_l00002ooooo`ko0000Noooool001cooooo00?o0000ooooooooool0Kooo
oolBo`0000kooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o000000;o00003?oo
ool3o`000003ooooool0003o000000Ko00002?ooool2o`000003ooooool0003o000000co0000N_oo
ool001cooooo00?o0000ooooooooool0KOoooolDo`0000kooooo0_l00002ooooo`;o00000_ooool2
o`0000?ooooo0_l00008ooooo`;o00000_ooool3o`000003ooooool0003o000000;o00003?ooool2
o`0000;ooooo3_l0001iooooo`007?ooool00ol0003oooooooooo`1]oooooa?o00002_ooool2o`00
00?ooooo0_l00006ooooo`;o00003Oooool2o`0000cooooo0_l00008ooooo`;o00000oooool>o`00
07Sooooo000Looooo`03o`000?oooooooooo06cooooo3_l00002ooooo`?o00002_ooool3o`0000?o
oooo0_l0000Eooooo`;o00001oooool3o`0000;ooooo0_l00008ooooo`;o00001Oooool?o`0007Go
oooo000Looooo`03o`000?oooooooooo06[ooooo3ol0000@ooooo`;o00000oooool2o`0001Gooooo
0ol000000ooooooo0000o`000004ooooo`Go00001?ooool2o`0000cooooo3_l0001eooooo`007?oo
ool00ol0003oooooooooo`1Yooooo`oo00004_ooool6o`0001?ooooo1Ol000000ooooooo0000o`00
0007ooooo`;o00001?ooool2o`0000[ooooo4Ol0001dooooo`007?ooool2o`0006[ooooo3_l00002
ooooo`;o00003oooool4o`0000Cooooo0_l0000?ooooo`;o00001oooool2o`0000[ooooo0_l0000:
ooooo`?o000000?oooooo`000?l000003Ol0001booooo`007?ooool00ol0003oooooooooo`1Yoooo
o`ko00000_ooool2o`0000Oooooo0_l00007ooooo`?o00001?ooool4o`0000Gooooo0_l0000>oooo
o`?o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000007ooooo`;o00000oooool?o`00
077ooooo000Looooo`03o`000?oooooooooo06Oooooo3_l00004ooooo`;o00001oooool2o`0000oo
oooo0ol00005ooooo`;o000000?oooooo`000?l000002oooool3o`0000;ooooo0_l00007ooooo`Co
00000oooool2o`0000;ooooo0_l00004ooooo`ko0000LOooool001cooooo00?o0000ooooooooool0
I_ooool?o`0000Cooooo0_l0000:ooooo`;o00002oooool4o`0000Oooooo0ol00004ooooo`Co0000
1?ooool2o`0000?ooooo0_l00006ooooo`;o00001Oooool2o`0000Cooooo1?l00002ooooo`go0000
L?ooool001cooooo00?o0000ooooooooool0IOooool=o`000004ooooool0003o0000o`0000?ooooo
1?l00007ooooo`Co00000oooool2o`0000Gooooo1?l00004ooooo`;o000000Coooooo`000?l0003o
00001?ooool4o`0000Kooooo0_l000000ooooooo0000o`00000=ooooo`;o00001?ooool4o`0000;o
oooo3_l0001_ooooo`007?ooool00ol0003oooooooooo`1Uooooo`_o00000oooool3o`0000?ooooo
1?l00007ooooo`Co00000oooool4o`0000?ooooo0_l00005ooooo`Go00000_ooool2o`0000?ooooo
0_l00007ooooo`;o00002oooool2o`0000?ooooo0_l000000ooooooo0000o`00000:ooooo`_o0000
Koooool001cooooo00?o0000ooooooooool0I?ooool<o`0000?ooooo0_l00007ooooo`;o00003ooo
ool2o`0000[ooooo1Ol00002ooooo`;o00000oooool4o`0000gooooo0_l00003ooooo`;o00001_oo
ool2o`000003ooooool0003o000000Sooooo2ol0001^ooooo`007?ooool00ol0003oooooooooo`1S
ooooo`co00001?ooool2o`0000Oooooo0_l0000Fooooo`;o00002Oooool2o`0000Cooooo1?l0000=
ooooo`;o00000_ooool2o`0000Cooooo0_l000000ooooooo0000o`000003o`0000Wooooo2ol0001]
ooooo`007?ooool00ol0003oooooooooo`1Rooooo`go00003_ooool2o`0001Gooooo0_l00009oooo
o`;o00005?ooool3o`0000;ooooo0_l00002ooooo`Co00000oooool2o`0000Sooooo3Ol0001]oooo
o`007?ooool00ol0003oooooooooo`1Rooooo`co00002_ooool2o`0000?ooooo1?l0000?ooooo`;o
00001?ooool2o`0000Wooooo0_l00005ooooo`;o00002oooool2o`0000?ooooo0_l00002ooooo`;o
000000?oooooo`000?l000001Oooool2o`0000;ooooo0_l000000ooooooo0000o`00000<o`0006co
oooo000Looooo`03o`000?oooooooooo067ooooo3Ol0000:ooooo`;o00000oooool5o`0000gooooo
0ol00004ooooo`;o00002?ooool3o`0000Gooooo0_l0000>ooooo`;o00000_ooool2o`0000;ooooo
0ol00003ooooo`So00001Oooool;o`0006_ooooo000Looooo`03o`000?oooooooooo063ooooo3Ol0
000=ooooo`;o000000?oooooo`000?l000000ol00006ooooo`;o000000?oooooo`000?l000000_oo
ool2o`0000?ooooo1?l00007ooooo`Go00003Oooool2o`0000Gooooo0_l00002ooooo`;o00000_oo
ool2o`0000;ooooo1?l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`_o0000Jooo
ool001cooooo00?o0000ooooooooool0H?ooool=o`0000gooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001?ooool5o`0000Oooooo0_l00009ooooo`;o000000?oooooo`000?l000003Oooool2
o`0000Sooooo0ol00006ooooo`Co00000_ooool2o`000003ooooool0003o000000;o00000_ooool=
o`0006Wooooo000Looooo`03o`000?oooooooooo063ooooo2ol00009ooooo`;o00003?ooool2o`00
00Gooooo0ol0000:ooooo`;o00008oooool7o`0000Cooooo0_l0000=ooooo`_o0000JOooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04
ooooo`03o`000?oooooooooo05kooooo3Ol00009ooooo`;o00001?ooool2o`0000kooooo0_l0000:
ooooo`;o00002Oooool2o`0001_ooooo1?l000000ooooooo0000o`00000@ooooo`_o0000JOooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1Nooooo`co00000_ooool2o`0000_ooooo0ol0000Dooooo`;o00003ooo
ool2o`0000Sooooo1?l00002ooooo`;o000000?oooooo`000?l000003?ooool3o`0000?ooooo0_l0
000;ooooo`_o0000JOooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5
o`0000Kooooo00?o0000ooooooooool0G_ooool;o`0000?ooooo1?l00009ooooo`Co00004oooool2
o`0001Cooooo0_l00003ooooo`Co00000_ooool2o`000003ooooool0003o000000cooooo0_l00004
ooooo`;o00000_ooool2o`0000Wooooo2ol0001Wooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Oooooo0ol0001Nooooo`_o00001Oooool2
o`0000_ooooo0_l000000ooooooo0000o`00000Vooooo`Co00000_ooool2o`0001kooooo0_l00000
0ooooooo0000o`000002o`0000?ooooo3?l0001Wooooo`0000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`09ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0G?ooool<
o`00017ooooo1?l000000ooooooo0000o`000002o`000004ooooool0003o0000o`0002;ooooo0_l0
0002ooooo`;o00008Oooool4o`0000?ooooo3?l0001Wooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0G?ooool?
o`0000?ooooo0_l00009ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00002Oooool2
o`0001?ooooo0_l0000Jooooo`Go00003?ooool2o`0000?ooooo3?l0001Vooooo`0000KoooooogMg
MonHV9SooooooiRHV?mgMgL<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0G?oo
ool?o`0000?ooooo0_l0000Dooooo`?o00001oooool4o`0000Wooooo0_l00008ooooo`;o00006_oo
ool5o`0000cooooo0_l00003ooooo`co0000I_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^
3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo05cooooo2ol0000Mooooo`;o0000
1oooool3o`0000_ooooo0_l0000Aooooo`;o00004?ooool2o`0000?ooooo0_l0000@ooooo`co0000
I_ooool001cooooo00?o0000ooooooooool0Foooool;o`0000kooooo0_l0000>ooooo`;o00001ooo
ool2o`0001[ooooo0ol00002ooooo`;o00000oooool3o`0000Wooooo0ol00003ooooo`Co00001Ooo
ool5o`0000;ooooo1?l000000ooooooo0000o`000008o`0006Gooooo000Looooo`03o`000?oooooo
oooo05_ooooo2_l00008ooooo`;o00001Oooool2o`0000Sooooo0_l0000Qooooo`;o00001_ooool3
o`0000Oooooo0ol000000ooooooo0000o`000005ooooo`Co00001Oooool4o`0000?ooooo1Ol00002
ooooo`;o00000oooool;o`0006Cooooo000Looooo`03o`000?oooooooooo05[ooooo2ol00008oooo
o`;o000000?oooooo`000?l000003?ooool2o`0000Sooooo0_l00009ooooo`;o00000oooool2o`00
00Oooooo0_l0000Dooooo`;o00001Oooool2o`0000Wooooo0_l0000:ooooo`;o00000oooool;o`00
06Cooooo000Looooo`03o`000?oooooooooo05[ooooo2_l000000ooooooo0000o`000009ooooo`;o
000000?oooooo`000?l000004oooool2o`000003ooooool0003o000000Gooooo0ol00003ooooo`;o
00001oooool2o`0000?ooooo0ol0000:ooooo`Co00005Oooool2o`000003ooooool0003o000000Ko
oooo0_l00002ooooo`[o0000I?ooool001cooooo00?o0000ooooooooool0F_ooool:o`000003oooo
ool0003o000000cooooo0ol00008ooooo`;o00000oooool2o`0000Kooooo0_l00005ooooo`;o0000
3Oooool2o`0000;ooooo1?l00004ooooo`;o00001?ooool4o`0000[ooooo0_l00006ooooo`;o0000
00Coooooo`000?l0003ooooo0ol00003ooooo`Co00000_ooool;o`0006?ooooo000Looooo`03o`00
0?oooooooooo05[ooooo2_l00006ooooo`;o00001Oooool2o`000003ooooool0003o000000Sooooo
0_l000000ooooooo0000o`000002o`0000Cooooo0_l000000ooooooo0000o`00000Gooooo`;o0000
1_ooool2o`0001;ooooo0_l00005ooooo`?o00001?ooool3o`0000?ooooo0_l00003ooooo`co0000
Hoooool001cooooo00?o0000ooooooooool0FOooool:o`0000;ooooo0_l00003ooooo`;o00001Ooo
ool2o`000003ooooool0003o000000?ooooo0_l00006ooooo`;o00001_ooool2o`000004ooooool0
003o0000ooooo`;o00004?ooool2o`0001_ooooo0_l00008ooooo`;o00001_ooool2o`0000Sooooo
0_l000000ooooooo0000o`000007o`0006?ooooo000Looooo`03o`000?oooooooooo05Wooooo2_l0
00001?oooooo0000o`000?l0000=ooooo`;o00000oooool2o`0000cooooo1?l000001?oooooo0000
o`000?ooool4o`0000gooooo0ol0000Kooooo`;o00000oooool5o`0000Gooooo0_l000000ooooooo
0000o`000002ooooo`;o00001?ooool2o`000003ooooool0003o000000So0000H_ooool001cooooo
00?o0000ooooooooool0F?ooool;o`000003ooooool0003o000000;ooooo0_l000001?oooooo0000
o`000?l00003ooooo`;o00001?ooool2o`0000?ooooo0_l00009ooooo`Co000000?oooooo`000?l0
00000_ooool3o`0000gooooo0_l00003ooooo`;o00003Oooool2o`0000gooooo1ol00003ooooo`;o
00001Oooool3o`0000;ooooo0ol000000ooooooo0000o`000008o`0006;ooooo000Looooo`03o`00
0?oooooooooo05Sooooo2ol00005ooooo`;o000000Coooooo`000?l0003o00000oooool2o`0000Co
oooo0_l00003ooooo`Co00000_ooool2o`0000Kooooo0_l0000Iooooo`;o00003Oooool2o`0000_o
oooo0_l00002ooooo`;o000000?oooooo`000?l000002oooool2o`0000;ooooo3_l0001Rooooo`00
7?ooool00ol0003oooooooooo`1Hooooo`_o00001_ooool3o`0000;ooooo0_l0000>ooooo`;o0000
0_ooool2o`0000Kooooo0_l00008ooooo`;o00001Oooool2o`0001Wooooo0_l00009ooooo`;o0000
1Oooool2o`0000cooooo0_l000000ooooooo0000o`00000=o`00067ooooo000Looooo`;o0000FOoo
ool:o`0000Cooooo0_l000000ooooooo0000o`000005o`0000oooooo0_l00005ooooo`;o00002_oo
ool4o`0000Gooooo0_l0000Iooooo`;o00000oooool4o`0000Wooooo0_l0000<ooooo`Go000000?o
ooooo`000?l000002_l0001Qooooo`007?ooool00ol0003oooooooooo`1Hooooo`Wo00001Oooool2
o`000004ooooool0003o0000ooooo`Co00003oooool2o`0000Gooooo0_l00004ooooo`;o00001?oo
ool2o`0000;ooooo0_l0000Kooooo`;o00001_ooool4o`0000Cooooo0_l0000<ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00005ooooo`Co000000?oooooo`000?l000000ol0001Qooooo`007?oo
ool00ol0003oooooooooo`1Gooooo`_o00001?ooool2o`0000Sooooo0_l0000Booooo`;o00001_oo
ool2o`0000Cooooo0_l00002ooooo`;o00006oooool2o`0000kooooo1?l0000:ooooo`;o000000Co
ooooo`000?l0003ooooo0_l00005ooooo`[o0000HOooool001cooooo00?o0000ooooooooool0Eooo
ool;o`0000Oooooo1?l00003ooooo`;o00002Oooool2o`0000Oooooo0_l0000Mooooo`;o00006?oo
ool2o`0000?ooooo0_l000001?oooooo0000o`000?l00007ooooo`;o00001_ooool2o`0000;ooooo
3Ol0001Qooooo`007?ooool00ol0003oooooooooo`1Gooooo`co00001?ooool8o`0000;ooooo0_l0
0008ooooo`;o00005_ooool2o`0000kooooo0_l0000Hooooo`;o000000?oooooo`000?l000000_l0
00001?oooooo0000o`000?l00007ooooo`;o00001Oooool2o`0000?ooooo0ol000000ooooooo0000
o`000007o`00067ooooo000Looooo`03o`000?oooooooooo05Oooooo3?l00004ooooo`?o00000ooo
ool2o`0000;ooooo0_l00008ooooo`;o00002_ooool2o`0000[ooooo0_l00009ooooo`;o00007?oo
ool2o`0000;ooooo0ol00002ooooo`Co00001_ooool2o`0000Gooooo0_l00005ooooo`[o0000H_oo
ool001cooooo00?o0000ooooooooool0Eoooool9o`0000Oooooo0_l000000ooooooo0000o`00000?
ooooo`;o000000?oooooo`000?l000001oooool2o`0001Gooooo0_l0000Looooo`?o00000oooool2
o`0000?ooooo0ol00005ooooo`Co00002?ooool=o`00067ooooo000Looooo`03o`000?oooooooooo
05Sooooo2?l0000:ooooo`?o00004Oooool2o`0000cooooo1?l0000Booooo`;o00006Oooool2o`00
00?ooooo0_l00004ooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool:o`00
063ooooo000Looooo`03o`000?oooooooooo05Oooooo2?l0000<ooooo`;o00006oooool2o`0000;o
oooo1?l00004ooooo`;o00003?ooool2o`00037ooooo0_l00005ooooo`;o000000?oooooo`000?l0
00002?l0001Pooooo`007?ooool00ol0003oooooooooo`1Fooooo`[o00001?ooool4o`00023ooooo
0_l0000:ooooo`;o00007Oooool2o`0001?ooooo0_l00008ooooo`;o000000?oooooo`000?l00000
1Oooool=o`00063ooooo000Looooo`03o`000?oooooooooo05Kooooo3?l00002ooooo`Ko00001?oo
ool2o`0000Gooooo0_l0000=ooooo`Co0000:oooool2o`0001?ooooo0_l00008ooooo`;o000000?o
ooooo`000?l000001oooool:o`00067ooooo000Looooo`03o`000?oooooooooo05Kooooo3?l00004
ooooo`Co00001?ooool2o`0000Gooooo0_l0000=ooooo`Co0000:Oooool2o`000003ooooool0003o
0000017ooooo0ol00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Kooooo2Ol0001P
ooooo`007?ooool00ol0003oooooooooo`1Fooooo`[o00001oooool4o`0000;ooooo0_l00007oooo
o`;o00001_ooool2o`00037ooooo0_l000000ooooooo0000o`000007ooooo`;o00002?ooool2o`00
00Cooooo0_l000000ooooooo0000o`000006ooooo`;o00001_ooool9o`00063ooooo000Looooo`03
o`000?oooooooooo05Kooooo2Ol00008ooooo`Co00000_ooool2o`0000Oooooo0_l000000ooooooo
0000o`000003ooooo`;o00004?ooool2o`0000;ooooo0_l0000Wooooo`;o00001_ooool2o`0001;o
oooo0_l000000ooooooo0000o`000002ooooo`Wo0000H?ooool001cooooo00?o0000ooooooooool0
E_ooool:o`0000Oooooo1?l00003ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Gooooo
0_l0000>ooooo`;o00000_ooool2o`0002oooooo0_l00003ooooo`;o00001?ooool2o`0000;ooooo
0_l00003ooooo`;o000000?oooooo`000?l000003?l0001Oooooo`007?ooool00ol0003ooooooooo
o`1Fooooo`[o00002Oooool2o`0000?ooooo0_l000001?oooooo0000o`000?l00002ooooo`;o0000
2?ooool2o`00043ooooo0_l000000ooooooo0000o`000003ooooo`;o00001?ooool3o`000004oooo
ool0003o0000ooooo`;o00001Oooool<o`0005oooooo000Looooo`;o0000Eoooool9o`0000Wooooo
1?l00006ooooo`Ko0000B_ooool2o`000003ooooool0003o000000Sooooo1?l00003ooooo`?o0000
00?oooooo`000?l000001?ooool:o`0005oooooo000Looooo`03o`000?oooooooooo05Oooooo2?l0
0005ooooo`;o00000_ooool4o`0000Kooooo1?l0000Cooooo`;o00001?ooool2o`0003kooooo0_l0
0005ooooo`?o000000?oooooo`000?l000001?ooool:o`0005oooooo000Looooo`03o`000?oooooo
oooo05Kooooo2Ol000000ooooooo0000o`000004o`0000?ooooo0_l0000Nooooo`;o00001?ooool2
o`0001Wooooo0_l0000Vooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo3Ol0001O
ooooo`007?ooool00ol0003oooooooooo`1Foooooa3o00006_ooool2o`000003ooooool0003o0000
00Gooooo0_l0000Nooooo`?o00001oooool2o`0001_ooooo0ol000000ooooooo0000o`000002oooo
o`;o00000_ooool=o`0005oooooo000Looooo`03o`000?oooooooooo05Kooooo3Ol00006ooooo`;o
00004_ooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`000003ooooool0003o0000
01oooooo0_l00003ooooo`;o00000_ooool2o`0001_ooooo0_l0000=ooooo`[o0000Goooool001co
oooo00?o0000ooooooooool0Eoooool:o`0000Kooooo1?l0000Booooo`;o00002?ooool2o`0001Co
oooo0_l0000Aooooo`;o00005_ooool2o`0001Kooooo2_l0001Oooooo`007?ooool00ol0003ooooo
ooooo`1Gooooo`[o00001Oooool4o`0000cooooo0_l00004ooooo`;o00007oooool2o`0001Oooooo
0_l0000@ooooo`;o00003Oooool2o`0000Kooooo2_l0001Pooooo`007?ooool00ol0003ooooooooo
o`1Fooooo`_o00001Oooool4o`0000cooooo0_l00004ooooo`;o0000>?ooool2o`0001gooooo1?l0
0006ooooo`[o0000H?ooool001cooooo00?o0000ooooooooool0E_ooool:o`0000Sooooo0_l00000
0ooooooo0000o`000002ooooo`;o00003oooool2o`0003;ooooo0_l00002ooooo`;o00003_ooool2
o`0000_ooooo1?l00004ooooo`co0000H?ooool001cooooo00?o0000ooooooooool0Eoooool9o`00
00_ooooo0_l00002ooooo`?o00002_ooool2o`0000;ooooo0_l00009ooooo`;o00004_ooool2o`00
00[ooooo0_l00007ooooo`;o00000_ooool4o`0000cooooo0_l00004ooooo`;o00001oooool4o`00
00;ooooo3?l0001Pooooo`007?ooool00ol0003oooooooooo`1Gooooo`Wo00001oooool2o`0000Oo
oooo0_l0000:ooooo`;o00003Oooool2o`0001;ooooo0_l0000:ooooo`;o00003?ooool3o`00013o
oooo1?l00003ooooo`Co000000Coooooo`000?l0003o00000oooool;o`00063ooooo000Looooo`03
o`000?oooooooooo05Sooooo2_l00005ooooo`?o00009oooool2o`0001[ooooo0_l0000:ooooo`;o
00000oooool2o`0000Gooooo0_l00005ooooo`Co00000oooool4o`000003ooooool0003o000000Co
oooo2ol0001Pooooo`007?ooool00ol0003oooooooooo`1Hooooo`[o00001Oooool4o`0000Cooooo
0ol0000Aooooo`;o00003?ooool2o`0000gooooo0_l0000;ooooo`;o00002?ooool2o`0000Gooooo
0_l00003ooooo`Co00002Oooool2o`0000;ooooo1?l00007ooooo`Wo0000HOooool001cooooo00?o
0000ooooooooool0Eoooool;o`0000Gooooo1ol000001?oooooo0000o`000?l00009ooooo`;o0000
0oooool2o`000003ooooool0003o000001_ooooo0_l0000Eooooo`Go00000oooool2o`0000;ooooo
1?l00004ooooo`;o00000oooool8o`0000Gooooo2ol0001Qooooo`007?ooool00ol0003ooooooooo
o`1Gooooo`[o00001oooool2o`000004ooooool0003o0000o`0000;ooooo0_l00003ooooo`;o0000
0_ooool4o`0000?ooooo0_l0000Kooooo`;o00005oooool6o`0000?ooooo0_l00002ooooo`;o0000
1_ooool2o`0000?ooooo2?l000001Ooooooo0000o`000?l0003ooooo00_o0000HOooool001cooooo
00?o0000ooooooooool0Eoooool:o`0000oooooo1?l000000ooooooo0000o`000002ooooo`;o0000
2Oooool2o`0001Kooooo0ol00002ooooo`;o00002oooool2o`0000Kooooo0_l00003ooooo`Co0000
00Coooooo`000?l0003ooooo0_l0000;ooooo`Ko00000oooool3o`0000?ooooo2Ol0001Qooooo`00
7?ooool2o`0005Sooooo2ol000000ooooooo0000o`00000=ooooo`;o00004?ooool2o`0001Kooooo
0_l00003ooooo`;o00002oooool2o`0000?ooooo0_l00005ooooo`Go000000Coooooo`000?l0003o
oooo0_l0000=ooooo`;o00001?ooool4o`0000;ooooo2Ol0001Rooooo`007?ooool00ol0003ooooo
ooooo`1Hooooo`[o000000?oooooo`000?l000000_ooool2o`0001Wooooo0_l00008ooooo`;o0000
8?ooool3o`0000;ooooo0_l00005ooooo`;o000000?oooooo`000?l000001oooool2o`0000gooooo
2?l000000ooooooo0000o`000008o`00067ooooo000Looooo`03o`000?oooooooooo05Wooooo2_l0
0004ooooo`;o00001?ooool2o`0001?ooooo0_l00008ooooo`Co00007_ooool3o`0001Gooooo0_l0
00001?oooooo0000o`000?ooool2o`0000Oooooo1?l00002ooooo`go0000HOooool001cooooo00?o
0000ooooooooool0F?ooool=o`0000;ooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo
0_l0000:ooooo`;o00001?ooool2o`0000?ooooo0_l00002ooooo`;o000000?oooooo`000?l00000
5?ooool2o`0000oooooo0_l0000?ooooo`;o000000?oooooo`000?l000001oooool2o`0000Kooooo
2_l0001Rooooo`007?ooool00ol0003oooooooooo`1Hooooo`go000000Coooooo`000?l0003ooooo
0_l00005ooooo`;o000000?oooooo`000?l000001oooool2o`000003ooooool0003o000000Cooooo
1?l000000ooooooo0000o`000005ooooo`;o00001?ooool2o`0000kooooo0_l0000=ooooo`Co0000
1?ooool2o`0000Oooooo0_l00005ooooo`;o00001Oooool3o`0000Gooooo2_l0001Rooooo`007?oo
ool00ol0003oooooooooo`1Iooooo`[o00000oooool2o`000003ooooool0003o000000oooooo1?l0
00000ooooooo0000o`000006ooooo`;o00003_ooool2o`0001gooooo0_l00006ooooo`;o00001ooo
ool2o`0000Gooooo0_l00006ooooo`;o00000oooool;o`0006?ooooo000Looooo`03o`000?oooooo
oooo05Wooooo2_l00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000Kooooo0_l00004
ooooo`;o00002?ooool2o`0003;ooooo0ol0000@ooooo`?o00000_ooool3o`0000;ooooo2_l0001T
ooooo`007?ooool00ol0003oooooooooo`1Jooooo`[o00000oooool2o`000003ooooool0003o0000
00Kooooo0_l0000<ooooo`;o00001oooool3o`0000kooooo0_l00004ooooo`;o00003_ooool2o`00
00cooooo0ol00003ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`Co000000Cooooo
o`000?l0003o00000_ooool;o`0006?ooooo000Looooo`03o`000?oooooooooo05[ooooo2_l00002
ooooo`;o00000_ooool2o`0000Wooooo1?l0000@ooooo`;o00003?ooool5o`0000Cooooo0_l00002
ooooo`;o00002_ooool2o`000003ooooool0003o000000oooooo0_l00005ooooo`;o000000Cooooo
o`000?l0003ooooo1ol00003ooooo`_o0000Hoooool001cooooo00?o0000ooooooooool0F_ooool;
o`000003ooooool0003o000000gooooo1?l0000Fooooo`;o00001_ooool4o`0000Kooooo0_l00000
0ooooooo0000o`000003ooooo`;o00002?ooool2o`0001Kooooo0_l00007ooooo`Co00000oooool9
o`0006Gooooo000Looooo`03o`000?oooooooooo05_ooooo2_l000000ooooooo0000o`000005oooo
o`;o00001_ooool2o`0000;ooooo1?l00006ooooo`;o00002_ooool2o`0000Oooooo0_l00007oooo
o`;o00001_ooool2o`0001[ooooo0ol00007ooooo`;o00002Oooool:o`0006Gooooo000Looooo`03
o`000?oooooooooo05_ooooo2_l000001?oooooo0000o`000?ooool2o`0000;ooooo0_l00003oooo
o`;o000000?oooooo`000?l000000_ooool4o`0000Kooooo0_l0000Cooooo`;o000000?oooooo`00
0?l000002Oooool2o`0001gooooo0ol00007ooooo`;o00000oooool2o`0000Cooooo2_l0001Uoooo
o`007?ooool00ol0003oooooooooo`1Looooo`Wo000000Coooooo`000?l0003ooooo0_l00007oooo
o`;o000000Coooooo`000?l0003o00000_ooool2o`000003ooooool0003o000001cooooo0_l00009
ooooo`;o00003Oooool2o`000003ooooool0003o000000;ooooo0_l0000Fooooo`;o00000_ooool;
o`0006Kooooo000Looooo`03o`000?oooooooooo05cooooo3?l0000:ooooo`Ko00000_ooool2o`00
0003ooooool0003o000000Oooooo0_l00002ooooo`;o00005oooool2o`0000Gooooo1?l00007oooo
o`;o000000?oooooo`000?l000000_ooool3o`0000Kooooo0_l00004ooooo`;o00002Oooool=o`00
06Kooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`1Looooo`go00000_ooool2o`0000Gooooo1_l0
0002ooooo`Co000000?oooooo`000?l000001Oooool3o`000003ooooool0003o000001Oooooo0_l0
0005ooooo`Co00001oooool2o`0000Kooooo0_l00006ooooo`;o00001?ooool2o`0000Wooooo3Ol0
001Vooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMg
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0GOooool<o`0000;ooooo0_l00004ooooo`;o
000000?oooooo`000?l000000_l00004ooooo`;o000000?oooooo`000?l000001?ooool4o`0001oo
oooo0_l00004ooooo`;o00001Oooool2o`0000cooooo0ol0000Booooo`_o0000I_ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0GOooool;o`0000Kooooo0_l000001?oooooo0000o`000?ooool2o`00
00oooooo0_l0000:ooooo`;o00001oooool2o`0000Oooooo0_l00003ooooo`;o00001?ooool2o`00
00Gooooo0_l000000ooooooo0000o`000009ooooo`?o00004Oooool;o`0006Oooooo00000ooooooo
0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06oooo
o`?o0000GOooool<o`0000;ooooo0_l000001?oooooo0000o`000?ooool2o`000004ooooool0003o
0000ooooo`;o00000_ooool2o`0001Cooooo0_l00006ooooo`?o00001oooool2o`0000Wooooo0_l0
0006ooooo`Co00002?ooool2o`0000Gooooo1?l0000:ooooo`_o0000Ioooool00003ooooool0003o
oooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool0GOooool<o`000004ooooool0003o0000o`0000Cooooo0_l000001?oooooo0000
o`000?ooool6o`0001Gooooo0_l00004ooooo`Go00006Oooool2o`0000[ooooo0_l00005ooooo`Co
00001oooool=o`0006Sooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo
00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`1Oooooo`[o000000?oooooo`000?l00000
3Oooool2o`0000cooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo0_l000000ooooooo0000
o`00000Iooooo`Co00002?ooool4o`0000?ooooo0ol00006ooooo`oo0000J?ooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo05oo
oooo3_l00007ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o00001Oooool2o`000003
ooooool0003o000000Cooooo0_l000001?oooooo0000o`000?l00004ooooo`;o00001?ooool2o`00
00;ooooo0_l00003ooooo`;o00002oooool2o`000003ooooool0003o000000;o00002?ooool4o`00
0003ooooool0003o000000?o00001_ooool2o`000003ooooool0003o000000Go000000Coooooo`00
0?l0003o0000JOooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo05oooooo3_l00007ooooo`;o000000?oooooo`000?l00000
0_l00002ooooo`;o00001Oooool2o`0000[ooooo0ol00004ooooo`;o00001?ooool2o`0000;ooooo
0_l00003ooooo`;o00001?ooool2o`000003ooooool0003o000000;ooooo1Ol0000:ooooo`;o0000
0_ooool3o`0000Oooooo4?l0001Yooooo`007?ooool00ol0003oooooooooo`1Pooooo`co00000_oo
ool3o`0000[ooooo0_l00009ooooo`;o00008oooool3o`000003ooooool0003o000000?ooooo0_l0
000@ooooo`;o00001?ooool2o`000005ooooool0003o0000o`000?ooool03Ol0001Yooooo`007?oo
ool00ol0003oooooooooo`1Qooooo`_o00000_ooool3o`0000[ooooo0_l00009ooooo`;o000000?o
ooooo`000?l000005oooool2o`0000Oooooo0_l00009ooooo`;o00003Oooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002ooooo`_o0000Joooool001cooooo00?o0000ooooooooool0H_ooool;
o`0000cooooo0_l00005ooooo`;o00001oooool2o`0001Kooooo0ol0000Booooo`;o00001?ooool2
o`0000Kooooo0ol0000:ooooo`go0000Joooool001cooooo00?o0000ooooooooool0H_ooool<o`00
0003ooooool0003o000000Sooooo0_l00005ooooo`;o00003Oooool2o`0000Oooooo0_l00007oooo
o`Co00003?ooool3o`0000Gooooo0_l000000ooooooo0000o`000006ooooo`;o00001Oooool2o`00
00Cooooo3?l0001/ooooo`007?ooool00ol0003oooooooooo`1Sooooo`ko000000?oooooo`000?l0
00001_ooool2o`0000;ooooo0_l00008ooooo`;o00001Oooool2o`0000Oooooo0_l00006ooooo`;o
000000Coooooo`000?l0003ooooo0_l00009ooooo`?o00001Oooool2o`000003ooooool0003o0000
00gooooo0_l00003ooooo`go0000K?ooool001cooooo00?o0000ooooooooool0IOooool;o`0000;o
oooo0_l00006ooooo`;o00000_ooool2o`0000Sooooo1?l00008ooooo`;o00002_ooool3o`0000?o
oooo0_l00008ooooo`;o00001?ooool4o`0000;ooooo0_l00006ooooo`;o00000oooool2o`0000Co
oooo3Ol0001]ooooo`007?ooool00ol0003oooooooooo`1Tooooo`go00001oooool2o`0000Sooooo
0_l00006ooooo`;o00001_ooool4o`0000;ooooo0_l00006ooooo`?o00000_ooool2o`0000Wooooo
0_l00004ooooo`Co00001?ooool2o`0000?ooooo0ol00003ooooo`;o00001?ooool;o`0006oooooo
000Looooo`03o`000?oooooooooo06Cooooo3_l00005ooooo`?o00002?ooool2o`0000Kooooo1?l0
0004ooooo`?o00000oooool2o`0000_ooooo0_l00008ooooo`;o00001?ooool2o`0000;ooooo0_l0
00000ooooooo0000o`000007o`0000Cooooo0_l000000ooooooo0000o`00000<o`0006oooooo000L
ooooo`03o`000?oooooooooo06Oooooo2ol000001?oooooo0000o`000?ooool3o`0001?ooooo0_l0
0005ooooo`;o000000Coooooo`000?l0003ooooo0_l00007ooooo`;o00002oooool3o`0000?ooooo
0_l00002ooooo`;o000000?oooooo`000?l000000_ooool4o`0000Gooooo0_l000000ooooooo0000
o`00000;o`00073ooooo000Looooo`03o`000?oooooooooo06Oooooo4Ol00005ooooo`;o00001ooo
ool2o`0000kooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000?o0000
2oooool3o`0000[ooooo0_l0000;ooooo`;o000000?oooooo`000?l000002_l0001aooooo`007?oo
ool00ol0003oooooooooo`1Woooooa;o00001?ooool3o`0000;ooooo0_l00002ooooo`;o00002_oo
ool4o`0000?ooooo1Ol000000ooooooo0000o`000002o`0000kooooo0_l00008ooooo`;o00003Ooo
ool=o`0007;ooooo000Looooo`;o0000JOoooolAo`0000Gooooo0_l00002ooooo`;o00003_ooool4
o`0000?ooooo0ol0000Eooooo`;o00001Oooool2o`000003ooooool0003o000000Sooooo0_l00002
ooooo`ko0000L_ooool001cooooo00?o0000ooooooooool0JOoooolAo`00017ooooo0_l00005oooo
o`;o00001Oooool2o`0000Oooooo0_l000000ooooooo0000o`000002ooooo`;o00000oooool2o`00
0003ooooool0003o000000Gooooo0ol0000:ooooo`;o000000?oooooo`000?l000003Ol0001boooo
o`007?ooool00ol0003oooooooooo`1Zooooo`go000000?oooooo`000?l000001Oooool2o`0000[o
oooo0_l0000Eooooo`;o000000?oooooo`000?l000000_ooool2o`0000?ooooo0_l000000ooooooo
0000o`000005ooooo`?o00002Oooool2o`000003ooooool0003o000000go0000Loooool001cooooo
00?o0000ooooooooool0Joooool>o`0000Kooooo0_l0000>ooooo`;o00003_ooool2o`0000Cooooo
0_l00004ooooo`;o00000_ooool2o`0000gooooo0ol00003oooooa3o0000MOooool001cooooo00?o
0000ooooooooool0K?ooool?o`0000?ooooo0ol00007ooooo`;o00000oooool7o`000003ooooool0
003o000000Sooooo1?l000000ooooooo0000o`000005ooooo`;o00000_ooool2o`0000?ooooo1?l0
0006ooooo`?o00001?ooool?o`0007Gooooo000Looooo`03o`000?oooooooooo06gooooo3ol00002
ooooo`;o00002?ooool2o`0000?ooooo0_l000000ooooooo0000o`000002o`000004ooooool0003o
0000o`0000Wooooo0_l000001?oooooo0000o`000?l0000=ooooo`Co00002oooool?o`0007Oooooo
000Looooo`03o`000?oooooooooo06kooooo3ol0000Fooooo`;o000000?oooooo`000?l000000ooo
ool2o`0000Cooooo0_l00002ooooo`;o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`00
0005ooooo`oo0000N?ooool001cooooo00?o0000ooooooooool0KooooolAo`0000Sooooo1?l00007
ooooo`;o00001_ooool2o`0000Gooooo0_l00005ooooo`;o00003OoooolIo`0007Sooooo000Loooo
o`03o`000?oooooooooo073ooooo4_l00006ooooo`Co00000_ooool2o`0000gooooo0_l00003oooo
o`;o00002?ooool3o`0000Oooooo0_l000001?oooooo0000o`000?oooolCo`0007[ooooo000Loooo
o`03o`000?oooooooooo07;ooooo5?l00005ooooo`;o000000?oooooo`000?l000003Oooool2o`00
00Wooooo0_l00002ooooo`?o00001oooool2o`0000Cooooo4?l0001mooooo`007?ooool00ol0003o
ooooooooo`1eoooooa7o00001Oooool7o`0000kooooo0_l00006ooooo`;o00001?ooool2o`0000;o
oooo0_l00006oooooa;o0000OOooool001cooooo00?o0000ooooooooool0MOoooolCo`0000Gooooo
0_l000000ooooooo0000o`000002ooooo`Ko00001_ooool2o`0000?ooooo0_l00006ooooo`So0000
00Coooooo`000?l0003ooooo4_l0001nooooo`007?ooool00ol0003oooooooooo`1foooooaGo0000
1?ooool2o`0000?ooooo1_l0000;ooooo`;o00001_oooolLo`00083ooooo000Looooo`03o`000?oo
oooooooo07Kooooo6?l000001?oooooo0000o`000?ooool2o`0000?ooooo0_l0000<ooooo`;o0000
2?oooolIo`00087ooooo000Looooo`03o`000?oooooooooo07[ooooo6_l00003ooooo`;o00001ooo
ool2o`0000Wooooo7?l00022ooooo`007?ooool00ol0003oooooooooo`1kooooob3o00000_ooool2
o`000003ooooool0003o000000Kooooo7Ol00024ooooo`007?ooool2o`0007gooooo:ol000000ooo
oooo0000o`00000Io`0008Kooooo000Looooo`03o`000?oooooooooo07kooooo@ol00028ooooo`00
7?ooool00ol0003oooooooooo`20oooood3o0000ROooool001cooooo00?o0000ooooooooool0Pooo
ooljo`0008cooooo000Looooo`03o`000?oooooooooo08Oooooo<ol0002?ooooo`007?ooool00ol0
003oooooooooo`27oooooc;o0000T?ooool001cooooo00?o0000ooooooooool0RooooolYo`0009Go
oooo000Looooo`03o`000?oooooooooo08oooooo8ol0002Gooooo`007?ooool00ol0003ooooooooo
o`2Dooooo`Ko000000?oooooo`000?l000003Ol000000ooooooo0000o`00002Looooo`007?ooool0
0ol0003oooooooooo`2Kooooo`_o0000Xoooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg1Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
0?ooooooB_ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?oooooo`000?oo
ool00_ooool00ol0003oooooooooo`09ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`00
0?ooooooB_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co
0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooom:ooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`09ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0
003oooooooooo`3ooooood[ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000
okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo0_l0003ooooood_ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo
00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool2o`00
0?ooooooBoooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`004_ooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom:
ooooo`005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooB_ooool001Co
oooo00?o0000ooooooooool01Oooool3o`000?ooooooB_ooool001Cooooo00?o0000ooooooooool0
oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo000Dooooo`03o`000?oooooo
oooo0?ooooooD_ooool001Cooooo00?o0000ooooooooool0oooooomBooooo`004_ooool00omEEEGo
IVIVo`00003ooooooeCooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002]oooo
o`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool05Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^09Sooooo002^ooooo`05o`000?ooooooooooooooool000002Oooool6o`0000Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`2Hooooo`00[_ooool01Ol0003ooooooooooooooooo000001Sooooo
00Go410@oooooooooooooooooa0@402Hooooo`00[_ooool01Ol0003ooooooooooooooooo000000Wo
oooo1_l00009ooooo`05o`000?ooooooooooooooool00000V?ooool00:kooooo00Go0000ohN7Qooo
ooooZJVYo`00000Hooooo`05o`000?ooooooooooooooool00000V?ooool00:gooooo00?o410@o`00
0?mgMgL00_l000000onHV9Soooooooooo`0Fooooo`05oa0@4?ooooooooooooooool@4100V?ooool0
0<_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2Hooooo`00boooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^09Sooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[.5 1.0125 -26 0 ]
[.5 1.0125 26 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
.5 1.0125 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1500) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.008 w
.60092 .62114 Mdot
.60031 .61375 Mdot
.54318 .3359 Mdot
.42875 .56334 Mdot
.18347 .51831 Mdot
.56169 .37671 Mdot
.70401 .50406 Mdot
.69689 .5015 Mdot
.53544 .32854 Mdot
.67239 .69832 Mdot
.68448 .45786 Mdot
.47483 .57291 Mdot
.67503 .48523 Mdot
.40412 .59811 Mdot
.46932 .87644 Mdot
.43704 .51579 Mdot
.6031 .62455 Mdot
.30494 .31767 Mdot
.45489 .54405 Mdot
.57492 .34777 Mdot
.5697 .68353 Mdot
.40516 .59391 Mdot
.5919 .63735 Mdot
.4037 .59844 Mdot
.40363 .55969 Mdot
.58256 .63292 Mdot
.56611 .58784 Mdot
.36886 .54719 Mdot
.36485 .58668 Mdot
.68746 .4595 Mdot
.30385 .34296 Mdot
.27497 .7313 Mdot
.32605 .55067 Mdot
.27388 .55313 Mdot
.64959 .47519 Mdot
.46751 .76582 Mdot
.53942 .36916 Mdot
.694 .49497 Mdot
.69395 .4856 Mdot
.68162 .50713 Mdot
.68741 .5025 Mdot
.58882 .65415 Mdot
.76158 .53671 Mdot
.74601 .45414 Mdot
.39083 .62215 Mdot
.23346 .34479 Mdot
.36838 .73429 Mdot
.44123 .58377 Mdot
.57601 .67039 Mdot
.47921 .23912 Mdot
.70878 .35963 Mdot
.64283 .48193 Mdot
.55892 .33084 Mdot
.58211 .11821 Mdot
.67449 .46977 Mdot
.35517 .61558 Mdot
.54072 .35415 Mdot
.39278 .58481 Mdot
.39969 .60008 Mdot
.5052 .6837 Mdot
.35282 .53726 Mdot
.39218 .33496 Mdot
.55121 .60187 Mdot
.49019 .4554 Mdot
.551 .35155 Mdot
.69008 .4698 Mdot
.61697 .62629 Mdot
.66862 .46941 Mdot
.31819 .59678 Mdot
.55861 .39766 Mdot
.44706 .56257 Mdot
.6896 .46544 Mdot
.55019 .65727 Mdot
.36722 .56494 Mdot
.45298 .23154 Mdot
.24402 .32134 Mdot
.40438 .32569 Mdot
.47871 .74911 Mdot
.50972 .68099 Mdot
.45084 .28223 Mdot
.34987 .5897 Mdot
.26541 .41313 Mdot
.26536 .3084 Mdot
.5999 .68166 Mdot
.41624 .50871 Mdot
.34359 .31388 Mdot
.36864 .56026 Mdot
.16546 .49716 Mdot
.38191 .52145 Mdot
.52545 .51554 Mdot
.51827 .34671 Mdot
.55809 .63818 Mdot
.4226 .5612 Mdot
.37044 .58891 Mdot
.56224 .71794 Mdot
.44997 .55875 Mdot
.41411 .58175 Mdot
.60048 .67749 Mdot
.64297 .47148 Mdot
.33421 .56135 Mdot
.55844 .29967 Mdot
.58285 .37548 Mdot
.38538 .53124 Mdot
.53968 .39191 Mdot
.55063 .65562 Mdot
.37033 .5877 Mdot
.68967 .48459 Mdot
.40712 .53919 Mdot
.73828 .32026 Mdot
.60684 .63388 Mdot
.35545 .5672 Mdot
.40239 .37411 Mdot
.4123 .69512 Mdot
.55726 .65331 Mdot
.66747 .52324 Mdot
.46125 .55775 Mdot
.40389 .57491 Mdot
.6193 .63214 Mdot
.58889 .3698 Mdot
.18315 .44047 Mdot
.61907 .66522 Mdot
.62461 .45242 Mdot
.60184 .69327 Mdot
.47819 .58181 Mdot
.55713 .35217 Mdot
.72126 .51339 Mdot
.7339 .51837 Mdot
.30437 .3806 Mdot
.37258 .5616 Mdot
.7803 .54353 Mdot
.5828 .35517 Mdot
.57007 .65145 Mdot
.66868 .47404 Mdot
.36943 .51697 Mdot
.61138 .65157 Mdot
.64689 .44313 Mdot
.35921 .34256 Mdot
.69458 .30509 Mdot
.57997 .61296 Mdot
.58703 .44642 Mdot
.64125 .46314 Mdot
.66444 .5095 Mdot
.52891 .83924 Mdot
.60429 .67021 Mdot
.38228 .36196 Mdot
.66203 .4749 Mdot
.4081 .44327 Mdot
.37371 .61711 Mdot
.25551 .39971 Mdot
.79241 .38143 Mdot
.31888 .49238 Mdot
.65757 .32688 Mdot
.37604 .36447 Mdot
.64723 .50148 Mdot
.42145 .57266 Mdot
.57509 .623 Mdot
.58782 .63692 Mdot
.35448 .53608 Mdot
.39569 .54827 Mdot
.43305 .53066 Mdot
.44041 .59428 Mdot
.55126 .55621 Mdot
.39328 .51708 Mdot
.38405 .73783 Mdot
.55874 .63309 Mdot
.42996 .5684 Mdot
.55678 .33065 Mdot
.45163 .60896 Mdot
.69982 .48607 Mdot
.39951 .58801 Mdot
.4258 .56332 Mdot
.34141 .57231 Mdot
.64916 .49533 Mdot
.24894 .6756 Mdot
.36668 .66226 Mdot
.24652 .58993 Mdot
.60486 .56189 Mdot
.50581 .35397 Mdot
.37512 .55549 Mdot
.39504 .35301 Mdot
.53039 .7762 Mdot
.43279 .55247 Mdot
.30088 .19362 Mdot
.41357 .58757 Mdot
.20159 .58012 Mdot
.34125 .50856 Mdot
.25852 .57448 Mdot
.28203 .40508 Mdot
.40195 .56278 Mdot
.74586 .62303 Mdot
.6666 .43585 Mdot
.60784 .33169 Mdot
.67224 .50071 Mdot
.564 .34009 Mdot
.54473 .34189 Mdot
.4348 .41524 Mdot
.46008 .52195 Mdot
.46288 .58556 Mdot
.41688 .52424 Mdot
.5863 .38346 Mdot
.53449 .59738 Mdot
.39814 .37602 Mdot
.54131 .60805 Mdot
.22621 .67728 Mdot
.5364 .24679 Mdot
.69771 .46549 Mdot
.36013 .35722 Mdot
.52478 .37707 Mdot
.5198 .33888 Mdot
.37736 .36885 Mdot
.38414 .60131 Mdot
.60665 .66835 Mdot
.38552 .79969 Mdot
.66293 .25625 Mdot
.7911 .70802 Mdot
.59166 .67834 Mdot
.76388 .57263 Mdot
.7025 .48842 Mdot
.52929 .35995 Mdot
.40721 .57677 Mdot
.3763 .58248 Mdot
.54728 .65493 Mdot
.44754 .56433 Mdot
.63798 .67781 Mdot
.40437 .56881 Mdot
.70351 .46077 Mdot
.38708 .31962 Mdot
.43388 .41548 Mdot
.33693 .41651 Mdot
.55837 .66466 Mdot
.61039 .76475 Mdot
.51542 .34134 Mdot
.54175 .77026 Mdot
.68165 .45826 Mdot
.36062 .33387 Mdot
.51939 .3265 Mdot
.41412 .36684 Mdot
.40822 .51005 Mdot
.57323 .35904 Mdot
.41235 .3619 Mdot
.45676 .46504 Mdot
.40442 .62121 Mdot
.63698 .21546 Mdot
.66696 .50407 Mdot
.57641 .6013 Mdot
.41117 .53756 Mdot
.51185 .36509 Mdot
.33723 .61751 Mdot
.61793 .30439 Mdot
.76256 .41787 Mdot
.58171 .34961 Mdot
.39261 .41797 Mdot
.36103 .33053 Mdot
.68667 .36545 Mdot
.77478 .54822 Mdot
.59178 .60662 Mdot
.42349 .51798 Mdot
.28422 .73573 Mdot
.66252 .47443 Mdot
.41823 .54396 Mdot
.21962 .42131 Mdot
.65322 .46504 Mdot
.39196 .58279 Mdot
.63739 .44818 Mdot
.58831 .6377 Mdot
.52403 .67874 Mdot
.62139 .64262 Mdot
.44854 .56719 Mdot
.6846 .48002 Mdot
.59377 .35823 Mdot
.57834 .63597 Mdot
.41037 .60993 Mdot
.37188 .54803 Mdot
.46311 .44973 Mdot
.43089 .57573 Mdot
.2376 .60991 Mdot
.40295 .56546 Mdot
.53278 .34351 Mdot
.34631 .56833 Mdot
.77405 .62501 Mdot
.43284 .4112 Mdot
.62052 .64889 Mdot
.57754 .34116 Mdot
.55004 .33822 Mdot
.37934 .25918 Mdot
.6819 .52298 Mdot
.43502 .6119 Mdot
.50983 .35602 Mdot
.46118 .49909 Mdot
.66218 .45088 Mdot
.37751 .52601 Mdot
.6011 .42467 Mdot
.55808 .26391 Mdot
.56608 .33745 Mdot
.48823 .60879 Mdot
.56149 .61603 Mdot
.41386 .55717 Mdot
.51513 .36756 Mdot
.41591 .4866 Mdot
.35661 .58173 Mdot
.79091 .49994 Mdot
.43911 .43699 Mdot
.64492 .46033 Mdot
.46718 .58474 Mdot
.42746 .53601 Mdot
.5704 .36446 Mdot
.55093 .64695 Mdot
.65679 .45204 Mdot
.58374 .64708 Mdot
.26527 .5571 Mdot
.6551 .23203 Mdot
.51308 .50956 Mdot
.4131 .33598 Mdot
.55243 .27647 Mdot
.2551 .60445 Mdot
.70751 .72842 Mdot
.51879 .81248 Mdot
.2812 .68877 Mdot
.54993 .39262 Mdot
.51918 .25658 Mdot
.54747 .34663 Mdot
.37934 .54114 Mdot
.55467 .35608 Mdot
.30116 .76664 Mdot
.40817 .57204 Mdot
.55158 .36672 Mdot
.58766 .74337 Mdot
.41752 .56166 Mdot
.59108 .60506 Mdot
.21826 .63248 Mdot
.81451 .59053 Mdot
.65764 .53349 Mdot
.53249 .37539 Mdot
.41377 .81252 Mdot
.41657 .58162 Mdot
.34692 .56543 Mdot
.55975 .62667 Mdot
.32053 .57424 Mdot
.40363 .35321 Mdot
.35779 .35661 Mdot
.60583 .49066 Mdot
.33822 .36718 Mdot
.46769 .5852 Mdot
.57631 .63297 Mdot
.56917 .56723 Mdot
.40342 .26117 Mdot
.49406 .24059 Mdot
.67345 .4417 Mdot
.218 .6301 Mdot
.65793 .63724 Mdot
.63258 .56309 Mdot
.62428 .411 Mdot
.56825 .65954 Mdot
.26814 .7214 Mdot
.6786 .50092 Mdot
.58639 .19491 Mdot
.70212 .68382 Mdot
.3806 .59648 Mdot
.67574 .45971 Mdot
.39179 .63805 Mdot
.78758 .62683 Mdot
.54047 .1939 Mdot
.30941 .69078 Mdot
.38263 .52251 Mdot
.53235 .24691 Mdot
.40343 .58352 Mdot
.61389 .30835 Mdot
.39232 .55865 Mdot
.58095 .64777 Mdot
.68651 .68979 Mdot
.63974 .5133 Mdot
.49102 .6207 Mdot
.67941 .37404 Mdot
.38424 .37019 Mdot
.40163 .56892 Mdot
.38439 .59991 Mdot
.4073 .35104 Mdot
.59168 .62913 Mdot
.44375 .54681 Mdot
.61986 .7598 Mdot
.38306 .60377 Mdot
.69825 .49476 Mdot
.69089 .69679 Mdot
.31981 .66498 Mdot
.45065 .58879 Mdot
.60209 .68478 Mdot
.70799 .48622 Mdot
.68495 .48371 Mdot
.38801 .49214 Mdot
.68133 .45064 Mdot
.42407 .58741 Mdot
.51093 .18669 Mdot
.59009 .61903 Mdot
.78971 .43062 Mdot
.61458 .65548 Mdot
.46755 .73607 Mdot
.64523 .47067 Mdot
.72117 .33004 Mdot
.39607 .63697 Mdot
.67599 .49854 Mdot
.42741 .65382 Mdot
.40699 .61726 Mdot
.41895 .61822 Mdot
.38645 .79718 Mdot
.52324 .34897 Mdot
.45492 .44259 Mdot
.68542 .45689 Mdot
.4204 .60102 Mdot
.45759 .56067 Mdot
.70763 .48986 Mdot
.59851 .23764 Mdot
.7174 .70068 Mdot
.40504 .56799 Mdot
.57391 .64609 Mdot
.57486 .65525 Mdot
.40576 .6269 Mdot
.3925 .535 Mdot
.55772 .3363 Mdot
.58963 .34121 Mdot
.50561 .36659 Mdot
.44258 .43474 Mdot
.74769 .36473 Mdot
.19265 .46249 Mdot
.6798 .50723 Mdot
.73745 .58195 Mdot
.50357 .49657 Mdot
.3851 .52027 Mdot
.54142 .38196 Mdot
.4301 .53728 Mdot
.44008 .56685 Mdot
.74071 .43047 Mdot
.19676 .51358 Mdot
.666 .68443 Mdot
.55377 .6591 Mdot
.64648 .49811 Mdot
.46844 .55023 Mdot
.72065 .45033 Mdot
.37497 .33053 Mdot
.33904 .48014 Mdot
.68225 .45743 Mdot
.5978 .60762 Mdot
.65383 .49014 Mdot
.37311 .58208 Mdot
.33858 .60784 Mdot
.57046 .65976 Mdot
.3925 .33287 Mdot
.35416 .52129 Mdot
.39413 .57999 Mdot
.75757 .30082 Mdot
.39569 .44871 Mdot
.62135 .54122 Mdot
.40545 .56567 Mdot
.41296 .61463 Mdot
.35643 .36977 Mdot
.37854 .5997 Mdot
.41601 .52929 Mdot
.40536 .69761 Mdot
.67534 .57477 Mdot
.38239 .37708 Mdot
.53623 .20013 Mdot
.59148 .67781 Mdot
.27007 .70742 Mdot
.55158 .38141 Mdot
.6238 .51626 Mdot
.70804 .69938 Mdot
.53288 .31998 Mdot
.65298 .33161 Mdot
.26052 .68629 Mdot
.53822 .29827 Mdot
.51236 .38798 Mdot
.55928 .59503 Mdot
.43996 .58949 Mdot
.40066 .57576 Mdot
.39661 .35508 Mdot
.60305 .66828 Mdot
.55717 .50847 Mdot
.31727 .25399 Mdot
.40627 .59198 Mdot
.78719 .49412 Mdot
.52639 .21893 Mdot
.51587 .24279 Mdot
.3866 .34517 Mdot
.35807 .36085 Mdot
.39966 .56896 Mdot
.39218 .68295 Mdot
.58164 .63211 Mdot
.41072 .60956 Mdot
.3894 .51752 Mdot
.52318 .36057 Mdot
.60632 .64018 Mdot
.58957 .36805 Mdot
.69672 .34123 Mdot
.24281 .57707 Mdot
.5554 .16537 Mdot
.66453 .46097 Mdot
.4591 .21965 Mdot
.64864 .44654 Mdot
.26932 .41607 Mdot
.51771 .32159 Mdot
.40866 .54981 Mdot
.55278 .63044 Mdot
.42672 .595 Mdot
.39663 .53807 Mdot
.38667 .60259 Mdot
.45473 .57968 Mdot
.57754 .16294 Mdot
.39079 .3727 Mdot
.39576 .50481 Mdot
.53697 .33903 Mdot
.26987 .31037 Mdot
.33178 .27223 Mdot
.38628 .59961 Mdot
.3825 .55447 Mdot
.60071 .64435 Mdot
.38391 .52801 Mdot
.65259 .44789 Mdot
.57814 .59865 Mdot
.36502 .57118 Mdot
.18437 .59647 Mdot
.36245 .58462 Mdot
.25053 .60285 Mdot
.65451 .48955 Mdot
.6808 .26815 Mdot
.33163 .59723 Mdot
.75482 .46467 Mdot
.4551 .44282 Mdot
.5221 .32445 Mdot
.63376 .45644 Mdot
.54188 .36975 Mdot
.33842 .23096 Mdot
.44762 .62675 Mdot
.41864 .57001 Mdot
.40284 .52199 Mdot
.5059 .35482 Mdot
.15253 .55956 Mdot
.69755 .38701 Mdot
.46172 .62114 Mdot
.56159 .33965 Mdot
.62159 .62276 Mdot
.27596 .65016 Mdot
.59836 .66087 Mdot
.34743 .32922 Mdot
.70109 .49488 Mdot
.39598 .33591 Mdot
.25497 .48808 Mdot
.60703 .62813 Mdot
.5413 .63212 Mdot
.54587 .37969 Mdot
.53679 .66453 Mdot
.86663 .42881 Mdot
.70954 .67893 Mdot
.30054 .40796 Mdot
.57072 .62573 Mdot
.36753 .58874 Mdot
.25959 .44893 Mdot
.69399 .68751 Mdot
.54303 .36781 Mdot
.43867 .55108 Mdot
.5457 .69468 Mdot
.55658 .3345 Mdot
.33267 .55336 Mdot
.53242 .33773 Mdot
.66589 .49814 Mdot
.52988 .3764 Mdot
.59874 .69761 Mdot
.3632 .55677 Mdot
.87806 .42889 Mdot
.35082 .38941 Mdot
.4185 .57842 Mdot
.66616 .51528 Mdot
.63579 .2819 Mdot
.42135 .55201 Mdot
.41631 .34928 Mdot
.55878 .36644 Mdot
.51876 .61926 Mdot
.40014 .56416 Mdot
.56222 .34019 Mdot
.5877 .61008 Mdot
.71476 .51268 Mdot
.55576 .71329 Mdot
.64939 .57486 Mdot
.55445 .63221 Mdot
.6223 .5661 Mdot
.63299 .48225 Mdot
.42084 .61431 Mdot
.44895 .5546 Mdot
.57589 .65072 Mdot
.25997 .35724 Mdot
.35432 .54234 Mdot
.34718 .57626 Mdot
.52568 .3557 Mdot
.54759 .37334 Mdot
.50857 .81203 Mdot
.5788 .38257 Mdot
.32786 .5842 Mdot
.57869 .65293 Mdot
.42515 .56126 Mdot
.60188 .64062 Mdot
.38651 .52849 Mdot
.29652 .56464 Mdot
.591 .62845 Mdot
.73971 .4363 Mdot
.43957 .55643 Mdot
.34325 .52202 Mdot
.41112 .54165 Mdot
.43623 .59551 Mdot
.55768 .33881 Mdot
.39296 .34755 Mdot
.38306 .5188 Mdot
.42381 .33005 Mdot
.38304 .37406 Mdot
.64789 .52587 Mdot
.52238 .35817 Mdot
.39208 .36765 Mdot
.45338 .19546 Mdot
.57026 .35307 Mdot
.39816 .35808 Mdot
.32871 .27405 Mdot
.64828 .47587 Mdot
.55889 .61783 Mdot
.41282 .55932 Mdot
.28282 .49967 Mdot
.36326 .72466 Mdot
.48619 .35114 Mdot
.4086 .56952 Mdot
.4222 .54602 Mdot
.62342 .65737 Mdot
.24914 .29602 Mdot
.5501 .39661 Mdot
.37108 .59803 Mdot
.60564 .61756 Mdot
.17602 .36653 Mdot
.5381 .34397 Mdot
.39978 .35375 Mdot
.65024 .49109 Mdot
.48076 .63248 Mdot
.75878 .47879 Mdot
.67893 .51677 Mdot
.53618 .30699 Mdot
.70677 .3523 Mdot
.44941 .54198 Mdot
.56837 .38225 Mdot
.65483 .7883 Mdot
.54395 .55668 Mdot
.4784 .44825 Mdot
.37851 .78412 Mdot
.56141 .65381 Mdot
.65016 .44686 Mdot
.37704 .36608 Mdot
.58307 .67675 Mdot
.60273 .6256 Mdot
.70196 .50019 Mdot
.35383 .66199 Mdot
.61053 .42288 Mdot
.69636 .4875 Mdot
.34046 .46326 Mdot
.2402 .36739 Mdot
.5538 .38411 Mdot
.40373 .35431 Mdot
.23943 .49805 Mdot
.5876 .65108 Mdot
.24336 .70219 Mdot
.4139 .82018 Mdot
.41422 .58195 Mdot
.37907 .36325 Mdot
.15908 .54031 Mdot
.24318 .30784 Mdot
.65205 .46377 Mdot
.63445 .52049 Mdot
.37171 .32716 Mdot
.41435 .53901 Mdot
.39883 .46275 Mdot
.36122 .54269 Mdot
.69315 .5026 Mdot
.54864 .72159 Mdot
.60526 .62603 Mdot
.66956 .50813 Mdot
.29327 .52616 Mdot
.42129 .58951 Mdot
.43782 .55365 Mdot
.33706 .4391 Mdot
.58334 .67826 Mdot
.51924 .3256 Mdot
.44531 .54274 Mdot
.39658 .58318 Mdot
.33203 .59225 Mdot
.43153 .62689 Mdot
.4513 .69199 Mdot
.38247 .54532 Mdot
.4417 .22853 Mdot
.39222 .52468 Mdot
.43715 .58096 Mdot
.58794 .68448 Mdot
.52089 .15716 Mdot
.70065 .35962 Mdot
.39904 .58607 Mdot
.39462 .61162 Mdot
.66239 .50477 Mdot
.65621 .41894 Mdot
.65027 .70418 Mdot
.52313 .61303 Mdot
.46971 .82207 Mdot
.40777 .62103 Mdot
.61623 .62614 Mdot
.41414 .35566 Mdot
.43135 .61316 Mdot
.60569 .61158 Mdot
.34357 .57981 Mdot
.54834 .327 Mdot
.56909 .35005 Mdot
.56311 .57702 Mdot
.3976 .36804 Mdot
.77753 .60237 Mdot
.73509 .58176 Mdot
.57078 .35997 Mdot
.41487 .56697 Mdot
.66979 .43653 Mdot
.51479 .35629 Mdot
.53172 .29647 Mdot
.2286 .40535 Mdot
.5743 .62119 Mdot
.55644 .63675 Mdot
.2511 .40196 Mdot
.66932 .3169 Mdot
.80264 .47284 Mdot
.66773 .50038 Mdot
.38946 .50723 Mdot
.76055 .59217 Mdot
.55476 .64242 Mdot
.2655 .43281 Mdot
.38504 .36769 Mdot
.65315 .46604 Mdot
.69187 .41106 Mdot
.60522 .65246 Mdot
.56484 .60639 Mdot
.34137 .55102 Mdot
.38513 .58153 Mdot
.53215 .80247 Mdot
.42831 .33621 Mdot
.69928 .50842 Mdot
.40256 .35259 Mdot
.53362 .31819 Mdot
.36041 .54855 Mdot
.59094 .6319 Mdot
.22262 .38554 Mdot
.45322 .59034 Mdot
.53502 .32587 Mdot
.55869 .64873 Mdot
.35615 .33403 Mdot
.41393 .34198 Mdot
.43913 .59719 Mdot
.57115 .78019 Mdot
.6889 .4969 Mdot
.58442 .67151 Mdot
.60728 .44812 Mdot
.36316 .5389 Mdot
.38631 .57403 Mdot
.30841 .54937 Mdot
.6957 .51085 Mdot
.68332 .64729 Mdot
.41938 .34828 Mdot
.58892 .66842 Mdot
.38266 .54837 Mdot
.40197 .36053 Mdot
.74554 .5813 Mdot
.55239 .31988 Mdot
.52656 .37503 Mdot
.41229 .34156 Mdot
.37737 .34316 Mdot
.41849 .35495 Mdot
.24603 .70902 Mdot
.60528 .60475 Mdot
.64597 .59707 Mdot
.36855 .60245 Mdot
.28869 .4048 Mdot
.3806 .50602 Mdot
.64372 .458 Mdot
.52448 .34374 Mdot
.41047 .54597 Mdot
.44261 .59864 Mdot
.31524 .53018 Mdot
.78886 .45693 Mdot
.31068 .61056 Mdot
.60494 .63455 Mdot
.34189 .61297 Mdot
.53192 .37391 Mdot
.25357 .74106 Mdot
.46239 .84426 Mdot
.33576 .60473 Mdot
.63454 .4215 Mdot
.58502 .62274 Mdot
.68254 .50747 Mdot
.30335 .45825 Mdot
.64797 .48042 Mdot
.57949 .66324 Mdot
.37648 .54296 Mdot
.7157 .61109 Mdot
.37236 .38197 Mdot
.42625 .5991 Mdot
.67075 .50364 Mdot
.447 .56534 Mdot
.68448 .51407 Mdot
.27192 .51281 Mdot
.63132 .78476 Mdot
.41318 .58681 Mdot
.44298 .52531 Mdot
.56504 .7946 Mdot
.39609 .6044 Mdot
.40833 .30733 Mdot
.58412 .6218 Mdot
.56172 .72732 Mdot
.46098 .54072 Mdot
.3844 .47362 Mdot
.35581 .5465 Mdot
.59759 .73075 Mdot
.38307 .57505 Mdot
.50689 .23887 Mdot
.35705 .56205 Mdot
.4163 .52767 Mdot
.6765 .46926 Mdot
.66608 .50724 Mdot
.57679 .68513 Mdot
.52 .37993 Mdot
.24787 .6037 Mdot
.39204 .57709 Mdot
.73463 .34954 Mdot
.67863 .60003 Mdot
.38065 .34261 Mdot
.58474 .66542 Mdot
.17267 .38691 Mdot
.65506 .44204 Mdot
.51555 .83584 Mdot
.45503 .81443 Mdot
.69673 .55072 Mdot
.21246 .49565 Mdot
.5981 .25681 Mdot
.36324 .33073 Mdot
.34121 .56796 Mdot
.48217 .31082 Mdot
.50056 .23618 Mdot
.25471 .36101 Mdot
.6303 .4639 Mdot
.52594 .78435 Mdot
.20891 .45749 Mdot
.385 .32292 Mdot
.35351 .35591 Mdot
.6495 .49776 Mdot
.60329 .39171 Mdot
.47136 .54566 Mdot
.37224 .35499 Mdot
.50605 .36199 Mdot
.57287 .34935 Mdot
.51425 .38216 Mdot
.58453 .63293 Mdot
.46561 .84064 Mdot
.62649 .47299 Mdot
.64818 .45716 Mdot
.61037 .3223 Mdot
.28643 .55737 Mdot
.53829 .62043 Mdot
.53364 .36821 Mdot
.55019 .3878 Mdot
.58092 .61772 Mdot
.34879 .60816 Mdot
.45372 .62241 Mdot
.40252 .58958 Mdot
.39348 .35217 Mdot
.38041 .5799 Mdot
.56417 .34893 Mdot
.66115 .4624 Mdot
.53448 .38384 Mdot
.68098 .5196 Mdot
.20835 .39961 Mdot
.42255 .60959 Mdot
.36186 .55559 Mdot
.70648 .24485 Mdot
.55117 .6208 Mdot
.25318 .32745 Mdot
.73126 .46544 Mdot
.54631 .34514 Mdot
.41674 .53018 Mdot
.53435 .61573 Mdot
.41993 .37506 Mdot
.56464 .17317 Mdot
.37936 .53143 Mdot
.59363 .6483 Mdot
.36513 .54602 Mdot
.50674 .52614 Mdot
.82732 .51143 Mdot
.58624 .65631 Mdot
.79875 .44328 Mdot
.37037 .59523 Mdot
.46508 .20261 Mdot
.38918 .52584 Mdot
.4618 .47231 Mdot
.35456 .54214 Mdot
.59398 .67814 Mdot
.39778 .59016 Mdot
.54301 .60631 Mdot
.57498 .36793 Mdot
.6607 .50171 Mdot
.55571 .63179 Mdot
.45216 .57672 Mdot
.76972 .2201 Mdot
.65843 .48573 Mdot
.40512 .57315 Mdot
.64604 .48694 Mdot
.61238 .66239 Mdot
.57099 .66681 Mdot
.30545 .27552 Mdot
.69332 .33883 Mdot
.66463 .49581 Mdot
.36162 .5478 Mdot
.50695 .21982 Mdot
.39885 .54711 Mdot
.44475 .48474 Mdot
.35338 .61477 Mdot
.35531 .60131 Mdot
.28742 .29173 Mdot
.64347 .46252 Mdot
.8041 .46673 Mdot
.25708 .30424 Mdot
.27211 .30822 Mdot
.57626 .68791 Mdot
.39295 .32643 Mdot
.26045 .70494 Mdot
.75275 .37494 Mdot
.53727 .32205 Mdot
.41494 .54708 Mdot
.54452 .59029 Mdot
.69071 .49288 Mdot
.38244 .33315 Mdot
.41257 .58605 Mdot
.54659 .38595 Mdot
.71369 .71692 Mdot
.64648 .49958 Mdot
.59115 .65897 Mdot
.62578 .65022 Mdot
.39811 .18106 Mdot
.39599 .55909 Mdot
.36197 .56148 Mdot
.70119 .49514 Mdot
.61391 .26014 Mdot
.36376 .35649 Mdot
.58838 .74146 Mdot
.66372 .4931 Mdot
.55211 .4813 Mdot
.60169 .60739 Mdot
.42384 .54391 Mdot
.1917 .57905 Mdot
.67973 .40255 Mdot
.75612 .3133 Mdot
.39386 .35412 Mdot
.45451 .49134 Mdot
.5935 .67773 Mdot
.66653 .47489 Mdot
.66747 .2956 Mdot
.41346 .61917 Mdot
.43664 .54121 Mdot
.46779 .49105 Mdot
.64834 .52237 Mdot
.5974 .70595 Mdot
.37632 .53269 Mdot
.45456 .44072 Mdot
.38637 .53084 Mdot
.3912 .49716 Mdot
.37173 .62611 Mdot
.37922 .56555 Mdot
.59255 .63856 Mdot
.49643 .57199 Mdot
.50751 .34243 Mdot
.65373 .69288 Mdot
.54256 .48112 Mdot
.41386 .57545 Mdot
.34861 .57899 Mdot
.32464 .70491 Mdot
.63757 .31696 Mdot
.55868 .62975 Mdot
.55666 .67457 Mdot
.6681 .44317 Mdot
.39261 .62732 Mdot
.52203 .38119 Mdot
.37225 .51199 Mdot
.55457 .33548 Mdot
.5913 .63515 Mdot
.5432 .3449 Mdot
.65386 .49985 Mdot
.57722 .37724 Mdot
.74091 .3526 Mdot
.65735 .47527 Mdot
.56544 .62157 Mdot
.36808 .56938 Mdot
.66861 .51655 Mdot
.31996 .39607 Mdot
.39201 .35402 Mdot
.15667 .47028 Mdot
.36444 .57148 Mdot
.67425 .55195 Mdot
.35965 .49147 Mdot
.54097 .3864 Mdot
.82584 .49499 Mdot
.54929 .64016 Mdot
.37016 .37002 Mdot
.57506 .67563 Mdot
.34149 .48018 Mdot
.37972 .35042 Mdot
.17644 .41094 Mdot
.44481 .44702 Mdot
.4052 .45324 Mdot
.37205 .61983 Mdot
.3522 .43127 Mdot
.55827 .32729 Mdot
.68913 .49183 Mdot
.66231 .30515 Mdot
.42012 .52937 Mdot
.72593 .72847 Mdot
.58988 .68313 Mdot
.51203 .36154 Mdot
.67007 .47288 Mdot
.65047 .45356 Mdot
.38676 .61052 Mdot
.45825 .25829 Mdot
.43425 .53668 Mdot
.6848 .31761 Mdot
.4119 .81019 Mdot
.64924 .61168 Mdot
.40467 .5693 Mdot
.57087 .36518 Mdot
.36546 .54582 Mdot
.41889 .3437 Mdot
.55346 .82539 Mdot
.35275 .51896 Mdot
.71577 .47048 Mdot
.43112 .33916 Mdot
.60733 .67012 Mdot
.31164 .52814 Mdot
.64691 .58838 Mdot
.39305 .55617 Mdot
.50395 .12502 Mdot
.39896 .35987 Mdot
.49277 .30025 Mdot
.4584 .57732 Mdot
.44336 .60537 Mdot
.46688 .42375 Mdot
.77018 .44731 Mdot
.61828 .39331 Mdot
.4031 .60337 Mdot
.32263 .38412 Mdot
.64181 .48349 Mdot
.4079 .53728 Mdot
.4013 .57411 Mdot
.37041 .70335 Mdot
.63858 .47056 Mdot
.54362 .3327 Mdot
.52409 .32087 Mdot
.49635 .33254 Mdot
.42155 .35685 Mdot
.68311 .68327 Mdot
.28354 .42525 Mdot
.76554 .66725 Mdot
.36592 .37231 Mdot
.43637 .60493 Mdot
.54236 .28969 Mdot
.36917 .54164 Mdot
.38158 .33485 Mdot
.63816 .47497 Mdot
.55371 .64503 Mdot
.75578 .59213 Mdot
.55365 .32692 Mdot
.44239 .61294 Mdot
.37301 .36904 Mdot
.57595 .62315 Mdot
.27456 .46803 Mdot
.60567 .67041 Mdot
.67131 .495 Mdot
.68739 .68145 Mdot
.37736 .33232 Mdot
.61861 .64665 Mdot
.6946 .44742 Mdot
.27849 .28519 Mdot
.39945 .63123 Mdot
.7234 .63964 Mdot
.61394 .66725 Mdot
.5434 .65374 Mdot
.61744 .62299 Mdot
.44359 .58121 Mdot
.62779 .42194 Mdot
.37376 .6163 Mdot
.6416 .46881 Mdot
.53522 .33528 Mdot
.63792 .76895 Mdot
.74858 .41705 Mdot
.59024 .49001 Mdot
.35362 .52496 Mdot
.42051 .59062 Mdot
.4001 .5694 Mdot
.42077 .50533 Mdot
.74548 .3568 Mdot
.44229 .5785 Mdot
.67724 .46962 Mdot
.5602 .36153 Mdot
.34153 .57104 Mdot
.55619 .31576 Mdot
.31895 .28481 Mdot
.37386 .32629 Mdot
.60414 .47485 Mdot
.53535 .85157 Mdot
.57277 .62296 Mdot
.58085 .34547 Mdot
.56597 .35771 Mdot
.35742 .34143 Mdot
.69425 .49634 Mdot
.61153 .66685 Mdot
.47264 .51468 Mdot
.38506 .37466 Mdot
.39684 .58762 Mdot
.67342 .42916 Mdot
.70017 .74802 Mdot
.34171 .55839 Mdot
.4238 .55626 Mdot
.52264 .38911 Mdot
.49276 .30357 Mdot
.86854 .56048 Mdot
.30109 .43603 Mdot
.39111 .34014 Mdot
.39794 .33187 Mdot
.58098 .61487 Mdot
.45368 .5996 Mdot
.66086 .51087 Mdot
.57378 .70219 Mdot
.66959 .64801 Mdot
.79435 .55283 Mdot
.73596 .28738 Mdot
.39792 .53585 Mdot
.58011 .23064 Mdot
.42932 .58422 Mdot
.6132 .61316 Mdot
.58978 .64027 Mdot
.57246 .63608 Mdot
.68841 .49274 Mdot
.48571 .76836 Mdot
.68489 .47871 Mdot
.6263 .81349 Mdot
.58203 .67339 Mdot
.43394 .44009 Mdot
.53024 .36863 Mdot
.47273 .61424 Mdot
.36888 .32751 Mdot
.71329 .66153 Mdot
.31768 .59515 Mdot
.39154 .67343 Mdot
.51076 .35429 Mdot
.55834 .62626 Mdot
.61061 .26153 Mdot
.32205 .76522 Mdot
.53593 .66052 Mdot
.30004 .57761 Mdot
.30126 .46033 Mdot
.38392 .34091 Mdot
.75391 .30954 Mdot
.39804 .3395 Mdot
.66746 .50228 Mdot
.36775 .55101 Mdot
.36937 .56007 Mdot
.38423 .53018 Mdot
.4031 .6093 Mdot
.64084 .49702 Mdot
.40645 .51294 Mdot
.77289 .62664 Mdot
.54594 .32339 Mdot
.32705 .32768 Mdot
.40097 .34689 Mdot
.63534 .4607 Mdot
.56107 .36005 Mdot
.64336 .3226 Mdot
.33114 .41314 Mdot
.40221 .56597 Mdot
.4114 .54596 Mdot
.54316 .81689 Mdot
.37643 .53311 Mdot
.47903 .56941 Mdot
.55575 .33091 Mdot
.30783 .65574 Mdot
.37539 .32658 Mdot
.38763 .32746 Mdot
.65567 .47366 Mdot
.59184 .64 Mdot
.39238 .3632 Mdot
.52698 .36303 Mdot
.3439 .53114 Mdot
.42428 .51824 Mdot
.60802 .67151 Mdot
.55348 .81709 Mdot
.41051 .33383 Mdot
.50337 .21641 Mdot
.56443 .61983 Mdot
.60919 .68614 Mdot
.43501 .53973 Mdot
.77969 .36069 Mdot
.61328 .69514 Mdot
.40756 .37779 Mdot
.63371 .46127 Mdot
.31919 .45551 Mdot
.65779 .44351 Mdot
.59429 .66053 Mdot
.36036 .58708 Mdot
.58601 .6292 Mdot
.40203 .56368 Mdot
.37558 .8139 Mdot
.37412 .5648 Mdot
.7736 .65155 Mdot
.25586 .38918 Mdot
.56422 .37743 Mdot
.62871 .29937 Mdot
.55065 .38118 Mdot
.55305 .65434 Mdot
.46195 .56957 Mdot
.35521 .34984 Mdot
.37191 .24705 Mdot
.48666 .64644 Mdot
.5181 .34588 Mdot
.5822 .39073 Mdot
.63867 .44478 Mdot
.35072 .54559 Mdot
.44245 .55094 Mdot
.55076 .36891 Mdot
.64475 .68004 Mdot
.61083 .65382 Mdot
.37871 .55088 Mdot
.42302 .59104 Mdot
.56 .37944 Mdot
.28691 .27628 Mdot
.52132 .57604 Mdot
.37362 .55461 Mdot
.62725 .40465 Mdot
.64726 .45601 Mdot
.46782 .61712 Mdot
.44146 .52583 Mdot
.37417 .34373 Mdot
.48617 .68327 Mdot
.32117 .74551 Mdot
.63788 .47859 Mdot
.56658 .34775 Mdot
.38889 .55395 Mdot
.57029 .36336 Mdot
.40598 .51134 Mdot
.75989 .48066 Mdot
.58059 .3493 Mdot
.34993 .59038 Mdot
.34599 .60252 Mdot
.58933 .68009 Mdot
.40466 .54058 Mdot
.38092 .76312 Mdot
.52024 .33021 Mdot
.38123 .60752 Mdot
.5792 .75815 Mdot
.69495 .47798 Mdot
.42977 .62789 Mdot
.38754 .37404 Mdot
.41107 .47012 Mdot
.71673 .59121 Mdot
.21205 .5179 Mdot
.37111 .3248 Mdot
.44635 .57109 Mdot
.56304 .39636 Mdot
.69992 .50748 Mdot
.80633 .59925 Mdot
.41739 .53968 Mdot
.68235 .50485 Mdot
.66052 .46284 Mdot
.38045 .33139 Mdot
.4928 .15021 Mdot
.45508 .5828 Mdot
.3829 .59616 Mdot
.43509 .75606 Mdot
.55384 .60951 Mdot
.37699 .57352 Mdot
.37377 .59586 Mdot
.67313 .46462 Mdot
.47242 .57576 Mdot
.4604 .8069 Mdot
.5948 .73519 Mdot
.70791 .4835 Mdot
.76005 .61319 Mdot
.57722 .34688 Mdot
.40788 .35548 Mdot
.56628 .65324 Mdot
.36489 .35964 Mdot
.52435 .36822 Mdot
.36933 .58752 Mdot
.69952 .5003 Mdot
.37444 .75117 Mdot
.65127 .50083 Mdot
.21671 .43832 Mdot
.57251 .59927 Mdot
.61954 .48032 Mdot
.49259 .13089 Mdot
.65222 .38574 Mdot
.695 .53007 Mdot
.38012 .34279 Mdot
.59786 .32061 Mdot
.42458 .5896 Mdot
.73829 .28311 Mdot
.43141 .60852 Mdot
.56685 .74245 Mdot
.52737 .32128 Mdot
.50821 .37377 Mdot
.37115 .55176 Mdot
.3853 .78886 Mdot
.70564 .50188 Mdot
.6656 .45194 Mdot
.35512 .59441 Mdot
.67538 .49868 Mdot
.38418 .58609 Mdot
.56232 .34765 Mdot
.76894 .31283 Mdot
.40667 .58693 Mdot
.37956 .50134 Mdot
.70404 .53989 Mdot
.26408 .3038 Mdot
.36858 .31261 Mdot
.32775 .21657 Mdot
.37638 .80639 Mdot
.67646 .49801 Mdot
.37099 .61136 Mdot
.7668 .60128 Mdot
.53478 .39311 Mdot
.60047 .49354 Mdot
.37029 .58077 Mdot
.39711 .61033 Mdot
.40929 .52597 Mdot
.43561 .55534 Mdot
.61783 .2 Mdot
.51509 .64434 Mdot
.48152 .72279 Mdot
.39846 .53817 Mdot
.35645 .42239 Mdot
.65357 .48509 Mdot
.51707 .60484 Mdot
.37871 .37819 Mdot
.40028 .53719 Mdot
.56001 .6868 Mdot
.70278 .47759 Mdot
.65662 .80099 Mdot
.68968 .50447 Mdot
.55074 .33984 Mdot
.66995 .51097 Mdot
.42928 .57642 Mdot
.57454 .65465 Mdot
.47134 .40065 Mdot
.69062 .36674 Mdot
.51096 .33064 Mdot
.41805 .57808 Mdot
.38594 .41944 Mdot
.5089 .34469 Mdot
.24692 .32938 Mdot
.56519 .64648 Mdot
.31616 .36938 Mdot
.58848 .63331 Mdot
.35737 .59116 Mdot
.35652 .5892 Mdot
.65142 .43903 Mdot
.65814 .50469 Mdot
.58941 .63506 Mdot
.40452 .15556 Mdot
.41788 .3466 Mdot
.57513 .6397 Mdot
.45569 .52793 Mdot
.54398 .43216 Mdot
.57177 .64898 Mdot
.42839 .37314 Mdot
.66555 .46223 Mdot
.56039 .61295 Mdot
.37624 .52269 Mdot
.34658 .46274 Mdot
.41261 .34615 Mdot
.50015 .3396 Mdot
.26331 .45455 Mdot
.51908 .33692 Mdot
.63274 .45822 Mdot
.55639 .38126 Mdot
.6512 .45752 Mdot
.6968 .61063 Mdot
.65967 .68563 Mdot
.46899 .34291 Mdot
.62771 .46347 Mdot
.54494 .37926 Mdot
.36665 .54872 Mdot
.33768 .37345 Mdot
.46341 .57811 Mdot
.44866 .55984 Mdot
.6691 .45672 Mdot
.57746 .67395 Mdot
.56868 .68357 Mdot
.42821 .46717 Mdot
.59585 .64305 Mdot
.53128 .32671 Mdot
.44376 .67708 Mdot
.74031 .36787 Mdot
.6728 .44864 Mdot
.65898 .50186 Mdot
.372 .53847 Mdot
.5421 .36919 Mdot
.50119 .34657 Mdot
.65175 .44259 Mdot
.78224 .45723 Mdot
.43245 .51474 Mdot
.56059 .67998 Mdot
.55896 .60782 Mdot
.58324 .65535 Mdot
.59181 .59564 Mdot
.39649 .47453 Mdot
.64917 .46982 Mdot
.56915 .66966 Mdot
.37151 .53776 Mdot
.375 .59511 Mdot
.67746 .70029 Mdot
.41087 .35949 Mdot
.34575 .59024 Mdot
.3707 .62524 Mdot
.42496 .54356 Mdot
.53702 .38106 Mdot
.48469 .5689 Mdot
.58387 .37296 Mdot
.53297 .39051 Mdot
.53175 .39052 Mdot
.75919 .39173 Mdot
.50134 .83147 Mdot
.26627 .65676 Mdot
.38224 .60682 Mdot
.54406 .21944 Mdot
.53519 .35557 Mdot
.52023 .65946 Mdot
.67935 .64201 Mdot
.41808 .53178 Mdot
.42475 .23782 Mdot
.55186 .37245 Mdot
.57208 .6165 Mdot
.37096 .57275 Mdot
.5692 .33017 Mdot
.40194 .37317 Mdot
.41766 .61709 Mdot
.54491 .31657 Mdot
.61918 .6435 Mdot
.4253 .35464 Mdot
.55089 .62386 Mdot
.53459 .39213 Mdot
.47004 .56007 Mdot
.83015 .40346 Mdot
.54922 .31581 Mdot
.41151 .20735 Mdot
.38881 .6474 Mdot
.37425 .54834 Mdot
.58968 .35277 Mdot
.61851 .68354 Mdot
.63416 .45707 Mdot
.5832 .53147 Mdot
.59069 .61773 Mdot
.5084 .37421 Mdot
.52061 .37751 Mdot
.51123 .33031 Mdot
.60131 .62787 Mdot
.42694 .62471 Mdot
.60449 .64335 Mdot
.67441 .51226 Mdot
.40942 .55565 Mdot
.25911 .57816 Mdot
.6253 .26437 Mdot
.57212 .61833 Mdot
.53177 .3323 Mdot
.36082 .37475 Mdot
.42085 .58725 Mdot
.59695 .24552 Mdot
.36728 .54703 Mdot
.65374 .455 Mdot
.42519 .70073 Mdot
.31734 .67169 Mdot
.36312 .60802 Mdot
.3803 .5387 Mdot
.66917 .45322 Mdot
.41487 .58083 Mdot
.3536 .54287 Mdot
.74015 .35073 Mdot
.60928 .64284 Mdot
.40124 .59264 Mdot
.53101 .34109 Mdot
.71808 .36048 Mdot
.41544 .50639 Mdot
.55756 .30316 Mdot
.32861 .38609 Mdot
.39264 .69616 Mdot
.42884 .61025 Mdot
.64134 .42819 Mdot
.4376 .54842 Mdot
.42302 .604 Mdot
.38102 .5412 Mdot
.57016 .19811 Mdot
.55909 .32443 Mdot
.56623 .36554 Mdot
.40472 .3366 Mdot
.32502 .38202 Mdot
.37314 .3548 Mdot
.65808 .46067 Mdot
.46446 .26972 Mdot
.58698 .3676 Mdot
.60515 .66241 Mdot
.42957 .59471 Mdot
.55862 .3202 Mdot
.42422 .53955 Mdot
.42793 .57558 Mdot
.53863 .39157 Mdot
.56663 .33214 Mdot
.23711 .3767 Mdot
.41149 .36247 Mdot
.57007 .63037 Mdot
.34393 .56797 Mdot
.3782 .37212 Mdot
.43925 .60323 Mdot
.28717 .40572 Mdot
.5699 .63486 Mdot
.60844 .64487 Mdot
.59026 .69482 Mdot
.36676 .58054 Mdot
.42607 .58145 Mdot
.6847 .47736 Mdot
.55002 .6447 Mdot
.69686 .48092 Mdot
.55334 .51352 Mdot
.3632 .2856 Mdot
.37032 .58142 Mdot
.70051 .67915 Mdot
.383 .36891 Mdot
.51762 .34971 Mdot
.68543 .75634 Mdot
.40504 .3368 Mdot
.39655 .56073 Mdot
.51391 .37306 Mdot
.36969 .33601 Mdot
.48953 .50726 Mdot
.59506 .81824 Mdot
.35666 .36925 Mdot
.37259 .53755 Mdot
.47271 .56576 Mdot
.34571 .20666 Mdot
.35134 .33375 Mdot
.64986 .48821 Mdot
.36615 .57822 Mdot
.53952 .63911 Mdot
.37241 .36888 Mdot
.58363 .27513 Mdot
.55756 .36874 Mdot
.35633 .46303 Mdot
.33829 .52704 Mdot
.44204 .64513 Mdot
.40616 .34032 Mdot
.58989 .67033 Mdot
.46052 .5188 Mdot
.4349 .54096 Mdot
.3523 .33214 Mdot
.71215 .51606 Mdot
.55636 .35597 Mdot
.69622 .35114 Mdot
.59908 .62429 Mdot
.74177 .4425 Mdot
.52159 .34448 Mdot
.49029 .21295 Mdot
.65701 .72903 Mdot
.46223 .61802 Mdot
.45696 .18609 Mdot
.65772 .56596 Mdot
.3791 .52683 Mdot
.39643 .38407 Mdot
.67416 .51908 Mdot
.69705 .4677 Mdot
.66717 .492 Mdot
.6867 .61126 Mdot
.52225 .61481 Mdot
.52492 .3146 Mdot
.71891 .45434 Mdot
.40738 .35796 Mdot
.33138 .44979 Mdot
.44644 .55033 Mdot
.4153 .59189 Mdot
.34845 .55444 Mdot
.40042 .536 Mdot
.44279 .57311 Mdot
.6899 .5006 Mdot
.6915 .59523 Mdot
.52058 .62975 Mdot
.56994 .64225 Mdot
.51992 .28688 Mdot
.52776 .35785 Mdot
.50462 .37387 Mdot
.36474 .3464 Mdot
.63214 .38021 Mdot
.55149 .31376 Mdot
.54483 .34364 Mdot
.33916 .57916 Mdot
.60637 .65206 Mdot
.48285 .60219 Mdot
.37684 .53785 Mdot
.54177 .32732 Mdot
.49388 .45542 Mdot
.4057 .78978 Mdot
.28866 .32204 Mdot
.41812 .3316 Mdot
.69631 .44268 Mdot
.38062 .32406 Mdot
.45002 .5459 Mdot
.82248 .52397 Mdot
.52534 .37004 Mdot
.54645 .3561 Mdot
.40592 .36573 Mdot
.77956 .35688 Mdot
.56341 .65399 Mdot
.74424 .43843 Mdot
.64274 .47599 Mdot
.35733 .5854 Mdot
.70392 .72731 Mdot
.52068 .60002 Mdot
.44816 .25919 Mdot
.66163 .48922 Mdot
.57684 .36911 Mdot
.43209 .52111 Mdot
.39025 .53972 Mdot
.37368 .36124 Mdot
.18963 .52542 Mdot
.39215 .63195 Mdot
.14801 .56094 Mdot
.63291 .78462 Mdot
.29604 .70368 Mdot
.43845 .54351 Mdot
.60697 .63985 Mdot
.54002 .32018 Mdot
.40464 .35399 Mdot
.42626 .61859 Mdot
.38157 .79887 Mdot
.59867 .67421 Mdot
.66066 .47716 Mdot
.5268 .46495 Mdot
.31404 .44961 Mdot
.44056 .58903 Mdot
.38171 .60302 Mdot
.42917 .60121 Mdot
.84598 .64289 Mdot
.56702 .38342 Mdot
.57698 .61814 Mdot
.37653 .33101 Mdot
.59627 .65064 Mdot
.57074 .37371 Mdot
.43403 .40506 Mdot
.35794 .55709 Mdot
.62086 .65303 Mdot
.58464 .66854 Mdot
.69878 .47316 Mdot
.6368 .48006 Mdot
.54145 .48587 Mdot
.37599 .56598 Mdot
.58478 .37986 Mdot
.57638 .67443 Mdot
.67069 .43167 Mdot
.37799 .34998 Mdot
.66624 .46155 Mdot
.40326 .54061 Mdot
.58403 .37148 Mdot
.33428 .5864 Mdot
.55663 .63448 Mdot
.54421 .34465 Mdot
.23789 .36592 Mdot
.3756 .32597 Mdot
.37651 .59459 Mdot
.32014 .31248 Mdot
.56481 .34379 Mdot
.43163 .58477 Mdot
.42825 .21585 Mdot
.40903 .38594 Mdot
.69604 .38956 Mdot
.50937 .36307 Mdot
.73248 .51232 Mdot
.58282 .61493 Mdot
.76377 .4541 Mdot
.55031 .34937 Mdot
.5217 .22291 Mdot
.21227 .40754 Mdot
.37633 .51718 Mdot
.58612 .64983 Mdot
.71956 .52572 Mdot
.30246 .77526 Mdot
.37314 .21881 Mdot
.40428 .5733 Mdot
.57574 .38423 Mdot
.36765 .3421 Mdot
.67564 .45157 Mdot
.72271 .40254 Mdot
.35775 .38768 Mdot
.59768 .34943 Mdot
.38168 .54171 Mdot
.60946 .66667 Mdot
.67938 .47882 Mdot
.71371 .59791 Mdot
.52624 .35407 Mdot
.53212 .33528 Mdot
.45979 .58034 Mdot
.38761 .36849 Mdot
.65355 .25119 Mdot
.55942 .33727 Mdot
.57065 .80038 Mdot
.51927 .39277 Mdot
.39976 .37553 Mdot
.43203 .55155 Mdot
.4035 .46213 Mdot
.41488 .61801 Mdot
.36736 .23951 Mdot
.52991 .36533 Mdot
.56396 .63032 Mdot
.43645 .53493 Mdot
.59609 .76498 Mdot
.53129 .3273 Mdot
.66789 .42447 Mdot
.61943 .34174 Mdot
.64817 .46628 Mdot
.68657 .75477 Mdot
.3778 .58091 Mdot
.69885 .50829 Mdot
.37061 .35506 Mdot
.37577 .55951 Mdot
.43043 .57854 Mdot
.62096 .66395 Mdot
.69525 .4692 Mdot
.24257 .3693 Mdot
.67174 .50799 Mdot
.65493 .49144 Mdot
.53291 .63213 Mdot
.39214 .59659 Mdot
.54906 .3369 Mdot
.55002 .37166 Mdot
.37224 .52372 Mdot
.70164 .22081 Mdot
.56951 .66078 Mdot
.49712 .34881 Mdot
.86602 .6117 Mdot
.36139 .52966 Mdot
.66953 .75356 Mdot
.18795 .50845 Mdot
.64975 .50147 Mdot
.37107 .53743 Mdot
.61705 .65569 Mdot
.61955 .38889 Mdot
.53461 .33325 Mdot
.37855 .52117 Mdot
.67939 .48107 Mdot
.41418 .3603 Mdot
.51209 .3344 Mdot
.45591 .25967 Mdot
.4177 .61038 Mdot
.40352 .25612 Mdot
.54899 .39066 Mdot
.24531 .66656 Mdot
.64908 .31443 Mdot
.58365 .64605 Mdot
.42934 .57256 Mdot
.55308 .62859 Mdot
.36663 .33283 Mdot
.5297 .46769 Mdot
.6714 .46807 Mdot
.30207 .52839 Mdot
.82015 .54816 Mdot
.5116 .32988 Mdot
.56661 .61774 Mdot
.36189 .60251 Mdot
.77148 .44936 Mdot
.38016 .58578 Mdot
.34093 .50693 Mdot
.25313 .35896 Mdot
.68082 .46258 Mdot
.64359 .487 Mdot
.43978 .56341 Mdot
.35759 .34561 Mdot
.52678 .35983 Mdot
.55693 .34492 Mdot
.22019 .65562 Mdot
.74454 .44441 Mdot
.52496 .80611 Mdot
.3984 .61053 Mdot
.59427 .37296 Mdot
.7511 .44703 Mdot
.6985 .4991 Mdot
.44241 .62208 Mdot
.51548 .37345 Mdot
.32432 .33438 Mdot
.46784 .48797 Mdot
.4374 .54534 Mdot
.46712 .57073 Mdot
.64693 .48961 Mdot
.53035 .63803 Mdot
.57322 .35939 Mdot
.34106 .60698 Mdot
.44624 .38724 Mdot
.48582 .50205 Mdot
.63243 .79248 Mdot
.57037 .63041 Mdot
.47976 .24541 Mdot
.69184 .49971 Mdot
.36458 .50522 Mdot
.37439 .32834 Mdot
.60147 .3702 Mdot
.58393 .35928 Mdot
.39077 .55217 Mdot
.42713 .51883 Mdot
.61265 .7818 Mdot
.60421 .65821 Mdot
.6528 .47889 Mdot
.36391 .56199 Mdot
.74111 .62024 Mdot
.38053 .53008 Mdot
.68861 .47879 Mdot
.82484 .38444 Mdot
.44979 .60363 Mdot
.38128 .59181 Mdot
.6506 .25081 Mdot
.58432 .61048 Mdot
.57271 .67645 Mdot
.73568 .71561 Mdot
.39568 .60966 Mdot
.64642 .7775 Mdot
.56806 .62574 Mdot
.55927 .65232 Mdot
.70281 .32525 Mdot
.41604 .58946 Mdot
.53828 .57526 Mdot
.64416 .46196 Mdot
.65472 .49255 Mdot
.60275 .63501 Mdot
.43256 .63121 Mdot
.63762 .46304 Mdot
.61248 .21254 Mdot
.5407 .36927 Mdot
.8097 .47036 Mdot
.57407 .66566 Mdot
.63553 .54195 Mdot
.6706 .50252 Mdot
.58123 .82813 Mdot
.67608 .41062 Mdot
.3631 .55166 Mdot
.40165 .61081 Mdot
.40564 .36434 Mdot
.34557 .58041 Mdot
.50751 .37215 Mdot
.67478 .49887 Mdot
.36619 .76681 Mdot
.57294 .63611 Mdot
.38335 .57329 Mdot
.42122 .2294 Mdot
.20568 .3875 Mdot
.52912 .25392 Mdot
.59671 .67267 Mdot
.58528 .63657 Mdot
.57527 .3775 Mdot
.56598 .38847 Mdot
.411 .60027 Mdot
.66003 .44843 Mdot
.54996 .63616 Mdot
.68463 .47133 Mdot
.5236 .36791 Mdot
.54883 .33975 Mdot
.54982 .31992 Mdot
.44069 .53808 Mdot
.54097 .33842 Mdot
.29556 .30742 Mdot
.70705 .43027 Mdot
.53558 .62786 Mdot
.76985 .71059 Mdot
.71377 .60347 Mdot
.46047 .63873 Mdot
.39441 .37776 Mdot
.544 .32383 Mdot
.68843 .51172 Mdot
.42181 .5596 Mdot
.41459 .54466 Mdot
.75675 .39392 Mdot
.69716 .50729 Mdot
.37554 .33157 Mdot
.67764 .51574 Mdot
.37822 .33084 Mdot
.41803 .25553 Mdot
.34843 .5468 Mdot
.40422 .51347 Mdot
.67749 .50208 Mdot
.54296 .34105 Mdot
.56238 .36755 Mdot
.34984 .35443 Mdot
.48531 .45458 Mdot
.50955 .3465 Mdot
.56156 .65725 Mdot
.30553 .69861 Mdot
.53816 .38771 Mdot
.37274 .57258 Mdot
.27789 .42337 Mdot
.71602 .25554 Mdot
.42291 .50632 Mdot
.70859 .32208 Mdot
.39429 .7552 Mdot
.42943 .52961 Mdot
.72325 .26208 Mdot
.71374 .49712 Mdot
.59304 .62434 Mdot
.55674 .3301 Mdot
.49983 .3822 Mdot
.48801 .61494 Mdot
.42632 .35073 Mdot
.45396 .60658 Mdot
.62106 .65062 Mdot
.62616 .6495 Mdot
.38976 .45379 Mdot
.37473 .22667 Mdot
.37087 .33703 Mdot
.36636 .3494 Mdot
.55249 .34742 Mdot
.15324 .47657 Mdot
.31044 .53685 Mdot
.38315 .33367 Mdot
.63681 .68177 Mdot
.38579 .54496 Mdot
.31801 .3491 Mdot
.62962 .60151 Mdot
.60222 .632 Mdot
.37472 .43145 Mdot
.53798 .32848 Mdot
.59638 .64116 Mdot
.76336 .57856 Mdot
.40698 .62608 Mdot
.57081 .63644 Mdot
.68413 .47321 Mdot
.64654 .34185 Mdot
.56724 .66415 Mdot
.28491 .41774 Mdot
.64831 .44457 Mdot
.6709 .43226 Mdot
.45077 .47891 Mdot
.1342 .38413 Mdot
.68331 .50083 Mdot
.51886 .37526 Mdot
.55047 .37083 Mdot
.55648 .34442 Mdot
.59799 .65244 Mdot
.51147 .32968 Mdot
.60206 .65936 Mdot
.40683 .18813 Mdot
.74597 .30223 Mdot
.38908 .33793 Mdot
.6937 .34976 Mdot
.59969 .66716 Mdot
.71513 .68754 Mdot
.57325 .12973 Mdot
.36523 .53931 Mdot
.68976 .4588 Mdot
.38808 .33848 Mdot
.15706 .51091 Mdot
.37636 .34068 Mdot
.41935 .82174 Mdot
.37717 .67373 Mdot
.38781 .57974 Mdot
.52354 .77519 Mdot
.3555 .36182 Mdot
.60125 .60948 Mdot
.43079 .58491 Mdot
.52087 .5021 Mdot
.37052 .34467 Mdot
.40985 .37021 Mdot
.4046 .59797 Mdot
.558 .62653 Mdot
.52906 .33225 Mdot
.6612 .50142 Mdot
.36419 .36185 Mdot
.44799 .50954 Mdot
.37838 .61122 Mdot
.36009 .5509 Mdot
.69404 .68794 Mdot
.41852 .37878 Mdot
.67749 .4978 Mdot
.51441 .16379 Mdot
.56265 .39591 Mdot
.47074 .46575 Mdot
.60189 .79882 Mdot
.65848 .6038 Mdot
.53079 .36561 Mdot
.57004 .36587 Mdot
.44246 .57494 Mdot
.29598 .62618 Mdot
.37544 .66177 Mdot
.44211 .42652 Mdot
.50852 .32679 Mdot
.55743 .3505 Mdot
.56559 .675 Mdot
.27066 .61649 Mdot
.40955 .49899 Mdot
.6397 .48444 Mdot
.57929 .34828 Mdot
.73928 .30716 Mdot
.39964 .36665 Mdot
.40779 .68576 Mdot
.34494 .55259 Mdot
.3624 .55427 Mdot
.67464 .48025 Mdot
.68418 .47886 Mdot
.62463 .35998 Mdot
.31629 .73368 Mdot
.38275 .74998 Mdot
.6952 .58309 Mdot
.37931 .69397 Mdot
.58791 .68243 Mdot
.57147 .61834 Mdot
.68582 .37538 Mdot
.6863 .50746 Mdot
.4295 .52828 Mdot
.5912 .63774 Mdot
.32358 .35356 Mdot
.32381 .50741 Mdot
.33677 .48823 Mdot
.65075 .76274 Mdot
.40772 .56785 Mdot
.61402 .6436 Mdot
.58103 .60774 Mdot
.56762 .60465 Mdot
.65427 .53256 Mdot
.4026 .60353 Mdot
.40752 .57109 Mdot
.44312 .54972 Mdot
.78195 .39973 Mdot
.41442 .60578 Mdot
.67546 .54164 Mdot
.54556 .47146 Mdot
.51278 .6807 Mdot
.34601 .61283 Mdot
.68663 .51525 Mdot
.44182 .59424 Mdot
.35685 .34443 Mdot
.35327 .55299 Mdot
.32819 .49572 Mdot
.65695 .48644 Mdot
.49535 .56963 Mdot
.70015 .61421 Mdot
.40159 .52623 Mdot
.40282 .37933 Mdot
.66964 .63511 Mdot
.28388 .73198 Mdot
.39042 .31281 Mdot
.56288 .6575 Mdot
.53557 .36667 Mdot
.69396 .51005 Mdot
.54729 .3481 Mdot
.38877 .51856 Mdot
.67455 .37236 Mdot
.16327 .51157 Mdot
.51598 .48946 Mdot
.40423 .53887 Mdot
.32386 .5241 Mdot
.55636 .65077 Mdot
.53779 .39185 Mdot
.63263 .66356 Mdot
.44343 .58203 Mdot
.39469 .35132 Mdot
.37252 .35789 Mdot
.57335 .52425 Mdot
.22263 .59361 Mdot
.67993 .25875 Mdot
.67692 .4859 Mdot
.55604 .33319 Mdot
.3685 .32736 Mdot
.54672 .23554 Mdot
.71845 .50858 Mdot
.66312 .45352 Mdot
.65513 .48141 Mdot
.3663 .58786 Mdot
.56842 .3328 Mdot
.51659 .68359 Mdot
.57479 .39546 Mdot
.41771 .58079 Mdot
.54029 .383 Mdot
.5119 .35646 Mdot
.40112 .35476 Mdot
.65368 .48247 Mdot
.52574 .36843 Mdot
.36229 .59398 Mdot
.5709 .62359 Mdot
.65091 .52144 Mdot
.25086 .38143 Mdot
.37673 .22947 Mdot
.57848 .56602 Mdot
.58864 .61157 Mdot
.27008 .70534 Mdot
.64287 .45996 Mdot
.78472 .44191 Mdot
.23326 .3818 Mdot
.45585 .58613 Mdot
.72403 .24067 Mdot
.58623 .39908 Mdot
.51338 .35177 Mdot
.43331 .55064 Mdot
.61056 .38251 Mdot
.38362 .57745 Mdot
.51884 .36103 Mdot
.70577 .4185 Mdot
.53652 .60882 Mdot
.53847 .3434 Mdot
.3309 .58604 Mdot
.43569 .57539 Mdot
.60617 .64077 Mdot
.58699 .37261 Mdot
.45439 .60126 Mdot
.24767 .72123 Mdot
.68866 .484 Mdot
.66284 .60114 Mdot
.26445 .42428 Mdot
.69517 .49764 Mdot
.57671 .64317 Mdot
.44954 .56359 Mdot
.36952 .35304 Mdot
.60421 .66627 Mdot
.30425 .51924 Mdot
.39594 .334 Mdot
.81315 .42257 Mdot
.58172 .60741 Mdot
.51829 .34285 Mdot
.35778 .33604 Mdot
.37466 .61589 Mdot
.55427 .3977 Mdot
.62829 .30292 Mdot
.52976 .36115 Mdot
.44526 .56576 Mdot
.72743 .38752 Mdot
.65188 .47928 Mdot
.39998 .57044 Mdot
.51527 .34045 Mdot
.70974 .32517 Mdot
.37542 .60079 Mdot
.4407 .55773 Mdot
.58454 .80571 Mdot
.59582 .71641 Mdot
.37805 .34493 Mdot
.54704 .63026 Mdot
.36961 .53811 Mdot
.38903 .37478 Mdot
.4513 .31738 Mdot
.36068 .57317 Mdot
.60008 .67416 Mdot
.44664 .62055 Mdot
.57804 .38207 Mdot
.69621 .48512 Mdot
.44208 .43377 Mdot
.40049 .37357 Mdot
.21875 .30221 Mdot
.57989 .35556 Mdot
.44994 .55514 Mdot
.38205 .53105 Mdot
.24815 .48145 Mdot
.59579 .63015 Mdot
.64445 .63968 Mdot
.37731 .5959 Mdot
.78532 .40049 Mdot
.38108 .56297 Mdot
.60597 .38539 Mdot
.56271 .65386 Mdot
.38858 .60101 Mdot
.62819 .49203 Mdot
.38476 .5009 Mdot
.41202 .34962 Mdot
.63184 .2587 Mdot
.42439 .62361 Mdot
.81955 .39721 Mdot
.55879 .53439 Mdot
.53741 .34192 Mdot
.32688 .28513 Mdot
.24267 .71938 Mdot
.68861 .61873 Mdot
.59517 .65228 Mdot
.17982 .51051 Mdot
.54861 .33657 Mdot
.38036 .2535 Mdot
.29096 .75502 Mdot
.43561 .56767 Mdot
.44208 .58641 Mdot
.29335 .46229 Mdot
.5481 .39578 Mdot
.57793 .38845 Mdot
.36159 .52161 Mdot
.39002 .49927 Mdot
.544 .33594 Mdot
.4279 .61484 Mdot
.35672 .62417 Mdot
.69207 .46174 Mdot
.58999 .674 Mdot
.67881 .45941 Mdot
.64643 .45337 Mdot
.59533 .22914 Mdot
.53575 .52579 Mdot
.69068 .48162 Mdot
.65547 .50891 Mdot
.33536 .39065 Mdot
.35727 .76467 Mdot
.36443 .35929 Mdot
.22979 .63916 Mdot
.55509 .35518 Mdot
.39281 .60011 Mdot
.56342 .6067 Mdot
.36298 .73379 Mdot
.44895 .33057 Mdot
.79739 .58597 Mdot
.44325 .54694 Mdot
.53004 .32837 Mdot
.65013 .57878 Mdot
.48318 .59059 Mdot
.51863 .31438 Mdot
.36534 .56695 Mdot
.5107 .37857 Mdot
.41883 .80304 Mdot
.52633 .22609 Mdot
.49674 .37674 Mdot
.54066 .64328 Mdot
.36544 .5562 Mdot
.61828 .62792 Mdot
.69746 .49928 Mdot
.35932 .35188 Mdot
.37527 .34872 Mdot
.42009 .593 Mdot
.30209 .56643 Mdot
.40124 .26759 Mdot
.42379 .58583 Mdot
.38956 .54591 Mdot
.70443 .46267 Mdot
.38322 .54104 Mdot
.39022 .53007 Mdot
.42322 .53574 Mdot
.41386 .5251 Mdot
.65423 .49103 Mdot
.63216 .37479 Mdot
.44384 .63634 Mdot
.32114 .57658 Mdot
.63667 .45335 Mdot
.19579 .48937 Mdot
.63947 .46075 Mdot
.30265 .76859 Mdot
.64781 .49666 Mdot
.38242 .3515 Mdot
.20616 .49722 Mdot
.32165 .55751 Mdot
.60414 .67706 Mdot
.60143 .4846 Mdot
.36055 .33675 Mdot
.66973 .49541 Mdot
.5177 .36534 Mdot
.59808 .80652 Mdot
.57434 .58898 Mdot
.54714 .68432 Mdot
.66121 .63082 Mdot
.63842 .3676 Mdot
.5789 .37552 Mdot
.59291 .60563 Mdot
.45649 .80232 Mdot
.39568 .53296 Mdot
.38709 .37461 Mdot
.41273 .59887 Mdot
.70057 .49836 Mdot
.54526 .33052 Mdot
.38977 .20326 Mdot
.37453 .36224 Mdot
.74467 .73357 Mdot
.5601 .37122 Mdot
.40629 .53587 Mdot
.63775 .46313 Mdot
.81274 .64519 Mdot
.67871 .46129 Mdot
.32037 .63342 Mdot
.58115 .61699 Mdot
.32221 .22595 Mdot
.59297 .66261 Mdot
.60565 .28174 Mdot
.8831 .50477 Mdot
.50387 .2282 Mdot
.56649 .6219 Mdot
.42867 .40402 Mdot
.39362 .55765 Mdot
.35926 .55209 Mdot
.46491 .20038 Mdot
.55044 .62032 Mdot
.39067 .536 Mdot
.75624 .41419 Mdot
.74132 .44978 Mdot
.65623 .74655 Mdot
.57262 .37748 Mdot
.37952 .57701 Mdot
.69635 .46092 Mdot
.7096 .49315 Mdot
.57191 .35068 Mdot
.65661 .45345 Mdot
.40948 .57378 Mdot
.59864 .66675 Mdot
.53778 .30388 Mdot
.38436 .36145 Mdot
.16686 .46284 Mdot
.39908 .32694 Mdot
.53144 .367 Mdot
.46493 .57352 Mdot
.54864 .34063 Mdot
.42857 .89164 Mdot
.39509 .56258 Mdot
.56657 .6263 Mdot
.39067 .54197 Mdot
.36909 .55379 Mdot
.4217 .52441 Mdot
.52954 .33419 Mdot
.26724 .34204 Mdot
.37197 .601 Mdot
.66863 .46535 Mdot
.43734 .70895 Mdot
.35494 .60599 Mdot
.49701 .30649 Mdot
.35762 .47499 Mdot
.69033 .67181 Mdot
.56383 .6125 Mdot
.53382 .34777 Mdot
.57508 .63361 Mdot
.79658 .41581 Mdot
.57662 .6434 Mdot
.41192 .72542 Mdot
.47078 .80672 Mdot
.54981 .78745 Mdot
.56822 .78176 Mdot
.47202 .41282 Mdot
.5478 .62585 Mdot
.41693 .32152 Mdot
.55037 .63798 Mdot
.59821 .62782 Mdot
.63399 .13803 Mdot
.62264 .64518 Mdot
.37202 .57909 Mdot
.34108 .57994 Mdot
.55202 .24892 Mdot
.29181 .37858 Mdot
.40718 .55309 Mdot
.40466 .5466 Mdot
.36362 .32896 Mdot
.79385 .42232 Mdot
.68417 .3869 Mdot
.6048 .71808 Mdot
.2168 .38041 Mdot
.40934 .59848 Mdot
.35613 .54721 Mdot
.34489 .62029 Mdot
.8349 .57353 Mdot
.56115 .21068 Mdot
.54292 .65621 Mdot
.3248 .56132 Mdot
.43954 .2238 Mdot
.44164 .54255 Mdot
.37574 .5983 Mdot
.40262 .56407 Mdot
.54824 .33568 Mdot
.55546 .61808 Mdot
.38464 .5204 Mdot
.23554 .48886 Mdot
.36894 .58481 Mdot
.65125 .56453 Mdot
.20452 .33725 Mdot
.37741 .58179 Mdot
.58857 .68661 Mdot
.36097 .54915 Mdot
.60094 .64039 Mdot
.60958 .6285 Mdot
.34578 .52916 Mdot
.37193 .6883 Mdot
.56526 .67576 Mdot
.41854 .58096 Mdot
.5172 .36942 Mdot
.24105 .64577 Mdot
.44228 .57795 Mdot
.36591 .36063 Mdot
.39499 .60894 Mdot
.42066 .36567 Mdot
.39715 .55112 Mdot
.57773 .35154 Mdot
.35736 .71963 Mdot
.54809 .35503 Mdot
.47857 .18549 Mdot
.5583 .32458 Mdot
.71191 .75875 Mdot
.59187 .61367 Mdot
.71094 .37053 Mdot
.80856 .5046 Mdot
.76523 .42888 Mdot
.60276 .4359 Mdot
.50151 .43116 Mdot
.66131 .44905 Mdot
.59117 .62701 Mdot
.77551 .51112 Mdot
.50409 .29127 Mdot
.52052 .26908 Mdot
.50778 .34112 Mdot
.47196 .14486 Mdot
.80894 .41755 Mdot
.44851 .54149 Mdot
.47888 .78155 Mdot
.49764 .7466 Mdot
.43546 .53276 Mdot
.41924 .52067 Mdot
.5414 .40413 Mdot
.39908 .61456 Mdot
.73818 .62791 Mdot
.54071 .37667 Mdot
.35902 .34011 Mdot
.55373 .63882 Mdot
.41464 .35939 Mdot
.44925 .36013 Mdot
.50514 .43011 Mdot
.5203 .36602 Mdot
.44891 .60675 Mdot
.4143 .5545 Mdot
.60481 .64705 Mdot
.4115 .65798 Mdot
.57084 .67208 Mdot
.3827 .33666 Mdot
.55201 .3793 Mdot
.68206 .23349 Mdot
.41328 .55156 Mdot
.57891 .6645 Mdot
.58941 .45341 Mdot
.37524 .53729 Mdot
.68692 .50292 Mdot
.38728 .55448 Mdot
.55454 .63136 Mdot
.38372 .54123 Mdot
.59333 .66162 Mdot
.53717 .36665 Mdot
.41498 .53446 Mdot
.43234 .5459 Mdot
.75684 .71491 Mdot
.39397 .34497 Mdot
.58908 .60213 Mdot
.43262 .44208 Mdot
.36083 .53872 Mdot
.68568 .32758 Mdot
.36754 .56995 Mdot
.55388 .68234 Mdot
.45493 .55052 Mdot
.66273 .60321 Mdot
.34016 .53183 Mdot
.42215 .59735 Mdot
.60753 .55249 Mdot
.48412 .7437 Mdot
.54994 .57958 Mdot
.67868 .51873 Mdot
.59151 .60217 Mdot
.6336 .7476 Mdot
.58809 .31805 Mdot
.58986 .37074 Mdot
.34163 .42881 Mdot
.3703 .52228 Mdot
.38688 .5822 Mdot
.68252 .68129 Mdot
.39104 .37256 Mdot
.61258 .66662 Mdot
.37922 .33105 Mdot
.68734 .75977 Mdot
.39934 .3332 Mdot
.60882 .3813 Mdot
.40029 .25714 Mdot
.64981 .22004 Mdot
.37139 .32751 Mdot
.55295 .63289 Mdot
.45305 .23026 Mdot
.39002 .52772 Mdot
.57287 .53885 Mdot
.39207 .35633 Mdot
.38047 .17151 Mdot
.39351 .53089 Mdot
.60193 .43876 Mdot
.69122 .47593 Mdot
.37164 .328 Mdot
.64685 .44347 Mdot
.42849 .56212 Mdot
.68706 .38894 Mdot
.59393 .65191 Mdot
.63059 .44966 Mdot
.38107 .62296 Mdot
.38434 .33518 Mdot
.5811 .35105 Mdot
.61806 .46789 Mdot
.64597 .49756 Mdot
.20439 .55035 Mdot
.368 .20703 Mdot
.55572 .37879 Mdot
.67197 .72703 Mdot
.68281 .51543 Mdot
.3749 .52679 Mdot
.78806 .4624 Mdot
.36168 .5531 Mdot
.71183 .29129 Mdot
.52851 .35375 Mdot
.63636 .37279 Mdot
.3691 .5387 Mdot
.43792 .58697 Mdot
.62661 .64432 Mdot
.54875 .3636 Mdot
.57563 .6543 Mdot
.53713 .61194 Mdot
.53899 .36882 Mdot
.58526 .65105 Mdot
.34897 .34421 Mdot
.78327 .55477 Mdot
.64262 .47996 Mdot
.65746 .46403 Mdot
.55723 .34484 Mdot
.53395 .34138 Mdot
.54533 .34453 Mdot
.38638 .55381 Mdot
.57955 .66794 Mdot
.42496 .56937 Mdot
.43145 .60908 Mdot
.45646 .70217 Mdot
.55973 .61157 Mdot
.41598 .57074 Mdot
.49667 .48294 Mdot
.31607 .6101 Mdot
.52578 .3794 Mdot
.69183 .48075 Mdot
.74393 .38601 Mdot
.63608 .30296 Mdot
.37862 .57374 Mdot
.29653 .32498 Mdot
.5512 .63628 Mdot
.36905 .34344 Mdot
.39053 .32563 Mdot
.37818 .34171 Mdot
.72466 .47357 Mdot
.56871 .60482 Mdot
.51725 .6611 Mdot
.38186 .57931 Mdot
.54405 .67541 Mdot
.55089 .67078 Mdot
.44337 .23734 Mdot
.69167 .48399 Mdot
.39048 .54014 Mdot
.45254 .44039 Mdot
.35938 .74931 Mdot
.36771 .5494 Mdot
.34981 .60096 Mdot
.26875 .32618 Mdot
.4575 .52727 Mdot
.61102 .67798 Mdot
.798 .66775 Mdot
.35933 .60586 Mdot
.73218 .295 Mdot
.14336 .52711 Mdot
.37313 .56668 Mdot
.43119 .5963 Mdot
.42038 .5507 Mdot
.35157 .55728 Mdot
.577 .68442 Mdot
.31112 .37823 Mdot
.68341 .51709 Mdot
.52761 .64465 Mdot
.68671 .5062 Mdot
.51485 .32429 Mdot
.63514 .37627 Mdot
.58548 .62077 Mdot
.40478 .36538 Mdot
.20629 .37536 Mdot
.76039 .67728 Mdot
.57281 .35884 Mdot
.6296 .22038 Mdot
.3899 .35463 Mdot
.33946 .55601 Mdot
.36296 .36527 Mdot
.56947 .38333 Mdot
.65025 .46472 Mdot
.43951 .62059 Mdot
.56777 .61919 Mdot
.5703 .66599 Mdot
.38515 .53701 Mdot
.38495 .24434 Mdot
.69977 .49018 Mdot
.68701 .52088 Mdot
.36279 .58268 Mdot
.36667 .61222 Mdot
.57744 .65388 Mdot
.56169 .3546 Mdot
.56951 .78842 Mdot
.36816 .35617 Mdot
.44084 .5387 Mdot
.37799 .54059 Mdot
.58656 .80361 Mdot
.66588 .462 Mdot
.58137 .34053 Mdot
.46072 .57395 Mdot
.68638 .56727 Mdot
.452 .59214 Mdot
.33655 .60866 Mdot
.51861 .37325 Mdot
.46759 .62291 Mdot
.40162 .51105 Mdot
.54883 .60152 Mdot
.66805 .44928 Mdot
.56815 .63193 Mdot
.5521 .59952 Mdot
.77739 .5855 Mdot
.67386 .50243 Mdot
.40173 .56118 Mdot
.69123 .4914 Mdot
.36022 .57171 Mdot
.35538 .59655 Mdot
.68891 .47886 Mdot
.57704 .65541 Mdot
.18468 .4949 Mdot
.5967 .28608 Mdot
.34857 .57458 Mdot
.37793 .51705 Mdot
.30288 .35371 Mdot
.40702 .39953 Mdot
.44374 .5821 Mdot
.55374 .65048 Mdot
.42668 .5575 Mdot
.69397 .46888 Mdot
.35332 .35652 Mdot
.56815 .62273 Mdot
.5651 .36606 Mdot
.57725 .36189 Mdot
.69682 .61858 Mdot
.51005 .3586 Mdot
.44251 .58785 Mdot
.47863 .62942 Mdot
.62361 .67235 Mdot
.23419 .33189 Mdot
.54333 .37155 Mdot
.373 .3697 Mdot
.4422 .56397 Mdot
.3455 .46343 Mdot
.68988 .45533 Mdot
.64099 .16177 Mdot
.75146 .65754 Mdot
.37683 .37952 Mdot
.52696 .6668 Mdot
.56906 .33673 Mdot
.38969 .51796 Mdot
.36715 .36144 Mdot
.57598 .37697 Mdot
.35346 .57705 Mdot
.32237 .57352 Mdot
.38206 .65105 Mdot
.50011 .4118 Mdot
.68925 .48959 Mdot
.50556 .35926 Mdot
.39555 .38207 Mdot
.50149 .33469 Mdot
.60438 .62377 Mdot
.40762 .60494 Mdot
.46221 .57924 Mdot
.56341 .35527 Mdot
.59305 .36296 Mdot
.41779 .57605 Mdot
.5571 .62357 Mdot
.5754 .28158 Mdot
.40425 .59593 Mdot
.74195 .46543 Mdot
.54438 .64824 Mdot
.5646 .37993 Mdot
.42776 .59577 Mdot
.40143 .32086 Mdot
.56003 .36679 Mdot
.52895 .38097 Mdot
.35695 .54579 Mdot
.36903 .32666 Mdot
.39496 .50528 Mdot
.64224 .46914 Mdot
.46463 .15075 Mdot
.69457 .46906 Mdot
.56966 .30577 Mdot
.4345 .50528 Mdot
.7276 .533 Mdot
.57627 .61101 Mdot
.40625 .45356 Mdot
.75564 .41227 Mdot
.36392 .62755 Mdot
.24568 .58945 Mdot
.63366 .5393 Mdot
.27034 .30519 Mdot
.26626 .56226 Mdot
.39707 .35742 Mdot
.66712 .49281 Mdot
.43153 .59623 Mdot
.68458 .45318 Mdot
.37307 .36806 Mdot
.48559 .18738 Mdot
.44413 .57539 Mdot
.55912 .65143 Mdot
.41186 .57285 Mdot
.56867 .66159 Mdot
.34738 .56678 Mdot
.41294 .50827 Mdot
.76258 .42282 Mdot
.46211 .47861 Mdot
.45358 .58891 Mdot
.84918 .6323 Mdot
.33939 .63665 Mdot
.36299 .34611 Mdot
.43228 .57122 Mdot
.48503 .36249 Mdot
.69898 .50474 Mdot
.69316 .53589 Mdot
.54604 .33362 Mdot
.63969 .48279 Mdot
.58153 .65212 Mdot
.53116 .35532 Mdot
.57172 .35466 Mdot
.47215 .61942 Mdot
.36424 .37183 Mdot
.66018 .47334 Mdot
.39203 .60362 Mdot
.44051 .5818 Mdot
.69061 .72215 Mdot
.48811 .29252 Mdot
.44106 .66712 Mdot
.84925 .50369 Mdot
.55861 .60203 Mdot
.36596 .33412 Mdot
.53089 .3315 Mdot
.43867 .60048 Mdot
.40393 .57471 Mdot
.69605 .34282 Mdot
.56375 .67143 Mdot
.52796 .47183 Mdot
.43298 .67102 Mdot
.3242 .35191 Mdot
.37939 .42567 Mdot
.55319 .64157 Mdot
.36375 .4168 Mdot
.41234 .38307 Mdot
.1933 .61307 Mdot
.46302 .47563 Mdot
.69305 .47891 Mdot
.33954 .3982 Mdot
.61173 .66651 Mdot
.36458 .59394 Mdot
.51536 .36685 Mdot
.51172 .35865 Mdot
.56696 .64005 Mdot
.51305 .31885 Mdot
.40142 .3589 Mdot
.42337 .60651 Mdot
.71432 .69311 Mdot
.73619 .58268 Mdot
.55563 .33598 Mdot
.47204 .61564 Mdot
.65517 .48314 Mdot
.38315 .53642 Mdot
.39874 .34081 Mdot
.68791 .49865 Mdot
.36605 .77785 Mdot
.73849 .42684 Mdot
.43865 .57727 Mdot
.59211 .80467 Mdot
.67253 .50054 Mdot
.29114 .63616 Mdot
.39677 .59828 Mdot
.64728 .4588 Mdot
.4488 .50178 Mdot
.64264 .33518 Mdot
.53648 .5088 Mdot
.29305 .75933 Mdot
.56041 .50058 Mdot
.52439 .32876 Mdot
.64122 .35334 Mdot
.76067 .38469 Mdot
.67441 .51174 Mdot
.58852 .34092 Mdot
.53415 .52823 Mdot
.65059 .4439 Mdot
.34623 .54372 Mdot
.36822 .56564 Mdot
.55303 .20864 Mdot
.60521 .4997 Mdot
.59031 .267 Mdot
.69844 .64317 Mdot
.35967 .53873 Mdot
.43577 .52458 Mdot
.40177 .57778 Mdot
.59486 .684 Mdot
.68252 .48273 Mdot
.82139 .65349 Mdot
.69698 .49902 Mdot
.42615 .69371 Mdot
.55583 .35084 Mdot
.57168 .37849 Mdot
.3774 .5775 Mdot
.60288 .44146 Mdot
.28343 .67176 Mdot
.4124 .5773 Mdot
.3693 .38696 Mdot
.56192 .22437 Mdot
.34834 .59173 Mdot
.57027 .61405 Mdot
.40835 .63648 Mdot
.41295 .49025 Mdot
.64342 .48271 Mdot
.39746 .36624 Mdot
.38756 .46199 Mdot
.65065 .4679 Mdot
.38845 .58177 Mdot
.7041 .55274 Mdot
.37659 .55488 Mdot
.34952 .57311 Mdot
.40326 .67465 Mdot
.38349 .32417 Mdot
.54012 .355 Mdot
.38161 .34242 Mdot
.59564 .62715 Mdot
.54204 .09275 Mdot
.4022 .33497 Mdot
.32206 .73617 Mdot
.50911 .18225 Mdot
.34323 .39965 Mdot
.61526 .6647 Mdot
.37469 .37572 Mdot
.69729 .48289 Mdot
.24013 .64801 Mdot
.31835 .62253 Mdot
.62015 .51727 Mdot
.39925 .59308 Mdot
.5706 .59153 Mdot
.58067 .67498 Mdot
.63147 .45108 Mdot
.60736 .62171 Mdot
.53419 .57966 Mdot
.35308 .58305 Mdot
.66523 .50486 Mdot
.70448 .58204 Mdot
.68873 .51776 Mdot
.44461 .40798 Mdot
.43024 .57735 Mdot
.5632 .62547 Mdot
.41245 .51431 Mdot
.61248 .69115 Mdot
.57704 .33753 Mdot
.45448 .59898 Mdot
.40294 .35888 Mdot
.71782 .53601 Mdot
.56053 .37809 Mdot
.35034 .40147 Mdot
.60378 .64475 Mdot
.72443 .46185 Mdot
.60773 .64248 Mdot
.62629 .6742 Mdot
.6385 .46195 Mdot
.6181 .63771 Mdot
.42767 .59984 Mdot
.53368 .51416 Mdot
.60075 .65106 Mdot
.67003 .48158 Mdot
.38773 .36697 Mdot
.58793 .65969 Mdot
.60567 .38915 Mdot
.44344 .56559 Mdot
.53153 .33527 Mdot
.43162 .38238 Mdot
.59258 .59513 Mdot
.35072 .33313 Mdot
.58551 .37805 Mdot
.41014 .37016 Mdot
.3019 .27876 Mdot
.6329 .48062 Mdot
.37711 .67669 Mdot
.39328 .39489 Mdot
.60348 .67812 Mdot
.2273 .39258 Mdot
.42236 .61242 Mdot
.44272 .56176 Mdot
.4178 .36842 Mdot
.58055 .67498 Mdot
.16212 .58991 Mdot
.29619 .59033 Mdot
.45484 .39622 Mdot
.71373 .49182 Mdot
.7371 .74414 Mdot
.44777 .4013 Mdot
.14905 .48895 Mdot
.44536 .62717 Mdot
.58179 .38746 Mdot
.38553 .57181 Mdot
.73161 .35841 Mdot
.38977 .34072 Mdot
.50775 .30109 Mdot
.44733 .52714 Mdot
.53582 .35784 Mdot
.42716 .54277 Mdot
.59943 .54695 Mdot
.2918 .5579 Mdot
.39237 .378 Mdot
.40913 .242 Mdot
.59972 .60124 Mdot
.38497 .35957 Mdot
.5576 .38379 Mdot
.4666 .49498 Mdot
.35272 .5783 Mdot
.34706 .54137 Mdot
.32468 .34783 Mdot
.58621 .6718 Mdot
.51771 .34091 Mdot
.64402 .466 Mdot
.39554 .36933 Mdot
.41502 .5561 Mdot
.43419 .60836 Mdot
.69166 .32515 Mdot
.65662 .48989 Mdot
.54318 .39392 Mdot
.68328 .46179 Mdot
.56744 .33855 Mdot
.37074 .60191 Mdot
.57543 .36869 Mdot
.34308 .53596 Mdot
.65001 .54582 Mdot
.3947 .67946 Mdot
.48129 .75381 Mdot
.52767 .35986 Mdot
.38074 .78476 Mdot
.65931 .49254 Mdot
.67389 .45824 Mdot
.5673 .19701 Mdot
.33069 .63668 Mdot
.72147 .7011 Mdot
.23909 .54013 Mdot
.6555 .49573 Mdot
.65966 .47851 Mdot
.53171 .33638 Mdot
.61697 .63568 Mdot
.57371 .60087 Mdot
.56959 .34389 Mdot
.2721 .42372 Mdot
.61126 .66769 Mdot
.22962 .60286 Mdot
.67405 .73895 Mdot
.33042 .57726 Mdot
.61204 .34522 Mdot
.37013 .35025 Mdot
.28654 .42214 Mdot
.59165 .54394 Mdot
.44584 .57395 Mdot
.36358 .44396 Mdot
.55951 .35008 Mdot
.62916 .43155 Mdot
.28948 .74578 Mdot
.42127 .53851 Mdot
.39502 .60057 Mdot
.3943 .57691 Mdot
.35979 .37054 Mdot
.33354 .67821 Mdot
.41934 .6038 Mdot
.26965 .42339 Mdot
.37103 .53469 Mdot
.28505 .58617 Mdot
.37633 .34602 Mdot
.52031 .52792 Mdot
.48144 .31425 Mdot
.78114 .68668 Mdot
.3057 .53477 Mdot
.64137 .47689 Mdot
.54592 .28398 Mdot
.67195 .45431 Mdot
.43442 .73251 Mdot
.43751 .45276 Mdot
.55009 .60616 Mdot
.44422 .57888 Mdot
.53219 .36872 Mdot
.57978 .67429 Mdot
.65691 .34868 Mdot
.59393 .11629 Mdot
.65104 .50105 Mdot
.2072 .70539 Mdot
.65381 .45558 Mdot
.57069 .35371 Mdot
.57702 .65268 Mdot
.44639 .80403 Mdot
.72418 .66783 Mdot
.58828 .65789 Mdot
.16011 .53508 Mdot
.59715 .69959 Mdot
.42779 .47401 Mdot
.62488 .64691 Mdot
.66611 .48282 Mdot
.66855 .43454 Mdot
.5383 .5663 Mdot
.37745 .59832 Mdot
.51075 .43767 Mdot
.27963 .65854 Mdot
.42437 .61175 Mdot
.54364 .37776 Mdot
.36851 .66169 Mdot
.35671 .4334 Mdot
.61954 .64927 Mdot
.73946 .46906 Mdot
.40506 .60249 Mdot
.3695 .54319 Mdot
.35667 .58381 Mdot
.7718 .63001 Mdot
.19061 .61103 Mdot
.3694 .59918 Mdot
.34961 .55494 Mdot
.53294 .35685 Mdot
.3593 .39003 Mdot
.50573 .23235 Mdot
.5743 .71466 Mdot
.41929 .53104 Mdot
.38006 .35622 Mdot
.42101 .37231 Mdot
.42588 .61476 Mdot
.52777 .51535 Mdot
.71568 .54532 Mdot
.39531 .60499 Mdot
.36558 .65843 Mdot
.56918 .41498 Mdot
.55566 .39698 Mdot
.56285 .36354 Mdot
.59744 .60536 Mdot
.56603 .3489 Mdot
.57789 .34818 Mdot
.37625 .7711 Mdot
.54783 .48769 Mdot
.64829 .5312 Mdot
.37882 .33572 Mdot
.39867 .5689 Mdot
.49439 .61496 Mdot
.69029 .55896 Mdot
.65336 .44703 Mdot
.5781 .62372 Mdot
.70768 .4935 Mdot
.42892 .33465 Mdot
.75677 .6307 Mdot
.51725 .32676 Mdot
.64821 .48543 Mdot
.64385 .50304 Mdot
.37815 .35561 Mdot
.66933 .44486 Mdot
.6777 .42055 Mdot
.38749 .61696 Mdot
.45761 .78422 Mdot
.41603 .58219 Mdot
.19025 .39678 Mdot
.6542 .47656 Mdot
.70897 .4659 Mdot
.38296 .58904 Mdot
.55867 .36894 Mdot
.46564 .51641 Mdot
.37356 .5943 Mdot
.56484 .34908 Mdot
.44992 .54109 Mdot
.40857 .33383 Mdot
.54596 .64214 Mdot
.71858 .67202 Mdot
.47354 .14227 Mdot
.36625 .37252 Mdot
.66207 .34294 Mdot
.44668 .55736 Mdot
.35165 .2271 Mdot
.58958 .66266 Mdot
.45703 .57014 Mdot
.37624 .43125 Mdot
.60529 .65703 Mdot
.57873 .63532 Mdot
.38762 .55031 Mdot
.69048 .47252 Mdot
.56331 .37865 Mdot
.37482 .35214 Mdot
.16319 .43034 Mdot
.41219 .59232 Mdot
.43192 .55125 Mdot
.38651 .35687 Mdot
.67418 .50459 Mdot
.44809 .59745 Mdot
.26273 .48317 Mdot
.1766 .62014 Mdot
.64924 .45557 Mdot
.40165 .53207 Mdot
.42796 .74631 Mdot
.29797 .55682 Mdot
.2836 .255 Mdot
.56256 .53513 Mdot
.53839 .34901 Mdot
.37577 .49557 Mdot
.7849 .30768 Mdot
.39367 .36772 Mdot
.75197 .68296 Mdot
.37029 .54208 Mdot
.40906 .54729 Mdot
.56596 .67071 Mdot
.42394 .57215 Mdot
.58285 .62064 Mdot
.57261 .16819 Mdot
.61752 .79321 Mdot
.59586 .60984 Mdot
.61205 .673 Mdot
.36624 .46976 Mdot
.7171 .51779 Mdot
.56944 .64205 Mdot
.35663 .6003 Mdot
.49839 .49722 Mdot
.66303 .68932 Mdot
.37349 .37264 Mdot
.28822 .32128 Mdot
.31667 .55671 Mdot
.3203 .31589 Mdot
.19303 .49226 Mdot
.368 .64282 Mdot
.4413 .42055 Mdot
.66809 .45937 Mdot
.42051 .53714 Mdot
.51184 .36239 Mdot
.51161 .36744 Mdot
.33918 .53931 Mdot
.38797 .56024 Mdot
.59885 .6338 Mdot
.38124 .3687 Mdot
.68707 .51278 Mdot
.40805 .54893 Mdot
.4182 .45899 Mdot
.40593 .36825 Mdot
.61052 .62336 Mdot
.42274 .70372 Mdot
.37989 .31934 Mdot
.37324 .50589 Mdot
.38086 .59819 Mdot
.40777 .56785 Mdot
.53889 .56379 Mdot
.68203 .47784 Mdot
.20446 .48445 Mdot
.34191 .57077 Mdot
.70215 .75351 Mdot
.67287 .53194 Mdot
.41636 .50262 Mdot
.60691 .63045 Mdot
.7381 .46864 Mdot
.5338 .31568 Mdot
.79784 .54056 Mdot
.43421 .58176 Mdot
.39886 .24264 Mdot
.54773 .20866 Mdot
.58891 .34966 Mdot
.59525 .69333 Mdot
.37553 .33891 Mdot
.40996 .57509 Mdot
.36672 .685 Mdot
.37012 .56829 Mdot
.4311 .36983 Mdot
.53725 .38517 Mdot
.67117 .46054 Mdot
.24698 .32514 Mdot
.50778 .36019 Mdot
.57581 .63416 Mdot
.51347 .85372 Mdot
.58128 .61891 Mdot
.5761 .60083 Mdot
.43998 .70737 Mdot
.68229 .47641 Mdot
.7137 .2157 Mdot
.60184 .18763 Mdot
.37885 .60927 Mdot
.66692 .50123 Mdot
.56114 .63564 Mdot
.38754 .5331 Mdot
.61595 .69908 Mdot
.5559 .60789 Mdot
.36047 .59751 Mdot
.41416 .54585 Mdot
.50878 .21933 Mdot
.25879 .66172 Mdot
.37693 .33813 Mdot
.58663 .61395 Mdot
.73868 .63811 Mdot
.38386 .53153 Mdot
.38162 .58036 Mdot
.70986 .30285 Mdot
.35893 .36578 Mdot
.75263 .58398 Mdot
.36986 .54269 Mdot
.53618 .82666 Mdot
.42167 .63849 Mdot
.55596 .66509 Mdot
.66539 .45188 Mdot
.76 .70539 Mdot
.65613 .41608 Mdot
.58415 .62258 Mdot
.40965 .35908 Mdot
.62752 .64855 Mdot
.34964 .76058 Mdot
.68745 .50547 Mdot
.55432 .63166 Mdot
.44397 .4339 Mdot
.68199 .49093 Mdot
.65093 .47399 Mdot
.46739 .70114 Mdot
.55328 .31864 Mdot
.37389 .37992 Mdot
.65926 .47528 Mdot
.7854 .43162 Mdot
.67217 .48798 Mdot
.58195 .18112 Mdot
.41575 .53722 Mdot
.31721 .43992 Mdot
.56711 .30245 Mdot
.31117 .5523 Mdot
.65168 .48206 Mdot
.35593 .33395 Mdot
.35323 .5745 Mdot
.61593 .62318 Mdot
.38077 .37145 Mdot
.60848 .47007 Mdot
.54487 .3355 Mdot
.61024 .6457 Mdot
.60967 .45191 Mdot
.56704 .66185 Mdot
.7741 .51227 Mdot
.47434 .16516 Mdot
.30757 .50877 Mdot
.73061 .66183 Mdot
.35184 .57845 Mdot
.20805 .5603 Mdot
.39774 .52816 Mdot
.38115 .55405 Mdot
.55522 .3808 Mdot
.33558 .43808 Mdot
.576 .65433 Mdot
.16957 .48411 Mdot
.64444 .48277 Mdot
.77774 .69249 Mdot
.32263 .51799 Mdot
.44765 .54884 Mdot
.59916 .64819 Mdot
.55131 .65316 Mdot
.47565 .7309 Mdot
.49849 .3625 Mdot
.4451 .5485 Mdot
.41634 .62799 Mdot
.32833 .5579 Mdot
.64602 .46927 Mdot
.48502 .4801 Mdot
.52731 .32614 Mdot
.42339 .18393 Mdot
.54257 .38715 Mdot
.36109 .29658 Mdot
.61647 .62968 Mdot
.40319 .33589 Mdot
.38029 .58262 Mdot
.41626 .65376 Mdot
.56803 .67512 Mdot
.41624 .36908 Mdot
.36512 .33036 Mdot
.65684 .30552 Mdot
.6892 .47998 Mdot
.37596 .59978 Mdot
.4258 .59774 Mdot
.42083 .56633 Mdot
.38795 .55594 Mdot
.65079 .49957 Mdot
.35771 .5798 Mdot
.66108 .43723 Mdot
.8044 .53975 Mdot
.2945 .46594 Mdot
.56542 .5025 Mdot
.66441 .25262 Mdot
.61878 .65568 Mdot
.77599 .45841 Mdot
.45757 .52316 Mdot
.81783 .48506 Mdot
.47657 .19512 Mdot
.37914 .61936 Mdot
.57866 .36433 Mdot
.38138 .47926 Mdot
.50944 .3408 Mdot
.13703 .51806 Mdot
.73159 .3369 Mdot
.25228 .64585 Mdot
.44173 .57975 Mdot
.53083 .51013 Mdot
.776 .3754 Mdot
.38498 .52649 Mdot
.68476 .30882 Mdot
.70942 .2883 Mdot
.44018 .22802 Mdot
.37413 .32723 Mdot
.42437 .59223 Mdot
.53057 .5906 Mdot
.42485 .60306 Mdot
.38297 .57457 Mdot
.35693 .58168 Mdot
.70584 .50343 Mdot
.45138 .58338 Mdot
.35589 .561 Mdot
.40254 .27421 Mdot
.41454 .44253 Mdot
.57034 .39309 Mdot
.55085 .19307 Mdot
.39861 .33216 Mdot
.60173 .64604 Mdot
.19171 .58661 Mdot
.69315 .47994 Mdot
.48494 .73558 Mdot
.3961 .5609 Mdot
.54107 .24326 Mdot
.74086 .42511 Mdot
.4079 .35894 Mdot
.57945 .37786 Mdot
.25431 .6767 Mdot
.53669 .37169 Mdot
.73487 .45856 Mdot
.55736 .37179 Mdot
.40395 .4932 Mdot
.59754 .63033 Mdot
.39426 .61144 Mdot
.66181 .47159 Mdot
.568 .36302 Mdot
.296 .36868 Mdot
.39979 .57605 Mdot
.53918 .36821 Mdot
.38719 .60856 Mdot
.59576 .71194 Mdot
.62009 .73316 Mdot
.5807 .35569 Mdot
.62862 .47585 Mdot
.67174 .47071 Mdot
.39391 .33389 Mdot
.60764 .6509 Mdot
.58155 .62419 Mdot
.68525 .49888 Mdot
.62622 .61504 Mdot
.41697 .52928 Mdot
.39975 .53689 Mdot
.72753 .73117 Mdot
.43301 .59865 Mdot
.47371 .50507 Mdot
.45587 .44454 Mdot
.60481 .61253 Mdot
.42949 .52143 Mdot
.38534 .54589 Mdot
.44089 .57362 Mdot
.64876 .71514 Mdot
.56251 .34879 Mdot
.41899 .53784 Mdot
.35648 .33812 Mdot
.62503 .37723 Mdot
.38211 .53626 Mdot
.48791 .61374 Mdot
.57925 .62269 Mdot
.83934 .5286 Mdot
.65911 .45524 Mdot
.55444 .38357 Mdot
.52699 .35876 Mdot
.208 .46459 Mdot
.77481 .41979 Mdot
.45966 .44707 Mdot
.33928 .2082 Mdot
.76242 .426 Mdot
.37672 .33131 Mdot
.59982 .38012 Mdot
.6041 .457 Mdot
.52353 .35223 Mdot
.66506 .51224 Mdot
.40579 .53466 Mdot
.41695 .53083 Mdot
.77656 .31311 Mdot
.44471 .60267 Mdot
.37317 .34202 Mdot
.68957 .51499 Mdot
.60472 .67023 Mdot
.40659 .36236 Mdot
.68109 .45933 Mdot
.59883 .60752 Mdot
.37686 .61889 Mdot
.34445 .58659 Mdot
.5811 .62693 Mdot
.56274 .66607 Mdot
.3796 .59445 Mdot
.71266 .40364 Mdot
.60625 .67558 Mdot
.55274 .64185 Mdot
.52841 .32299 Mdot
.51076 .35789 Mdot
.3373 .6176 Mdot
.65951 .48996 Mdot
.35452 .56576 Mdot
.53034 .35931 Mdot
.40252 .33584 Mdot
.5785 .65852 Mdot
.34911 .56736 Mdot
.39324 .54229 Mdot
.37832 .35749 Mdot
.40541 .34435 Mdot
.39619 .3383 Mdot
.62492 .43914 Mdot
.42929 .56666 Mdot
.57693 .64882 Mdot
.68547 .47592 Mdot
.41137 .37943 Mdot
.36305 .36355 Mdot
.58869 .39371 Mdot
.43948 .5964 Mdot
.53618 .30388 Mdot
.79738 .32428 Mdot
.64281 .77563 Mdot
.58224 .34843 Mdot
.53066 .3168 Mdot
.27418 .36561 Mdot
.64474 .58975 Mdot
.69187 .50069 Mdot
.39129 .3998 Mdot
.30876 .5102 Mdot
.41664 .6229 Mdot
.34656 .58368 Mdot
.43518 .52145 Mdot
.39019 .33381 Mdot
.33308 .45257 Mdot
.58742 .62227 Mdot
.51399 .53401 Mdot
.40692 .36854 Mdot
.57939 .3837 Mdot
.60654 .36776 Mdot
.54867 .38753 Mdot
.33885 .5625 Mdot
.49168 .76308 Mdot
.76771 .46607 Mdot
.23825 .51992 Mdot
.65429 .4868 Mdot
.46011 .63357 Mdot
.36981 .22168 Mdot
.58171 .63274 Mdot
.5052 .33351 Mdot
.36878 .33147 Mdot
.56367 .66531 Mdot
.70759 .48834 Mdot
.66103 .47713 Mdot
.55426 .33466 Mdot
.55323 .33603 Mdot
.51799 .35848 Mdot
.54917 .61483 Mdot
.61712 .63284 Mdot
.43501 .57977 Mdot
.58442 .66536 Mdot
.81413 .55644 Mdot
.42368 .3444 Mdot
.48455 .37716 Mdot
.66417 .49157 Mdot
.62106 .63997 Mdot
.40329 .5777 Mdot
.53866 .66249 Mdot
.66923 .5883 Mdot
.36307 .34964 Mdot
.65574 .73166 Mdot
.14741 .46331 Mdot
.39242 .60989 Mdot
.67589 .47044 Mdot
.7457 .67309 Mdot
.39635 .57925 Mdot
.52507 .33568 Mdot
.31392 .29581 Mdot
.49274 .40213 Mdot
.37071 .58967 Mdot
.39514 .61787 Mdot
.64039 .47478 Mdot
.41865 .18555 Mdot
.42446 .58769 Mdot
.76864 .56759 Mdot
.70206 .52113 Mdot
.523 .33231 Mdot
.27284 .77016 Mdot
.34618 .32015 Mdot
.28124 .42449 Mdot
.5391 .32484 Mdot
.36774 .55451 Mdot
.50615 .34068 Mdot
.35649 .34284 Mdot
.57581 .37906 Mdot
.57558 .61598 Mdot
.56917 .38663 Mdot
.43121 .55149 Mdot
.5675 .63811 Mdot
.67251 .50099 Mdot
.7723 .68907 Mdot
.39153 .29194 Mdot
.55824 .3673 Mdot
.57748 .35496 Mdot
.44272 .5377 Mdot
.73873 .61981 Mdot
.36843 .52135 Mdot
.39875 .53266 Mdot
.66583 .50347 Mdot
.60547 .65496 Mdot
.64435 .45745 Mdot
.34647 .52178 Mdot
.28697 .4863 Mdot
.68349 .46363 Mdot
.5131 .23273 Mdot
.39154 .35334 Mdot
.57425 .44031 Mdot
.40426 .57348 Mdot
.64969 .44257 Mdot
.43168 .5677 Mdot
.58977 .62293 Mdot
.57623 .49504 Mdot
.66447 .39324 Mdot
.65549 .46603 Mdot
.33685 .27425 Mdot
.27699 .46244 Mdot
.48243 .62047 Mdot
.67131 .45604 Mdot
.3567 .42517 Mdot
.56982 .35253 Mdot
.37113 .36181 Mdot
.41651 .34256 Mdot
.41091 .36643 Mdot
.35145 .61851 Mdot
.32096 .51887 Mdot
.34599 .34215 Mdot
.69547 .50646 Mdot
.39031 .37783 Mdot
.7065 .26429 Mdot
.16781 .4893 Mdot
.39097 .34571 Mdot
.39771 .59645 Mdot
.45848 .5186 Mdot
.33993 .39545 Mdot
.63801 .323 Mdot
.24725 .62018 Mdot
.63774 .26028 Mdot
.37121 .58646 Mdot
.54404 .65099 Mdot
.56702 .60674 Mdot
.79701 .60991 Mdot
.31298 .72061 Mdot
.60947 .79039 Mdot
.59031 .60026 Mdot
.72291 .38025 Mdot
.61303 .63396 Mdot
.37595 .60309 Mdot
.3955 .5351 Mdot
.56489 .59831 Mdot
.30503 .47688 Mdot
.69695 .36564 Mdot
.20438 .3705 Mdot
.5642 .66186 Mdot
.66749 .44938 Mdot
.63941 .45339 Mdot
.6502 .47735 Mdot
.71145 .72326 Mdot
.59567 .64937 Mdot
.40866 .55628 Mdot
.52861 .36425 Mdot
.42382 .53338 Mdot
.68499 .49071 Mdot
.15166 .52591 Mdot
.59389 .65973 Mdot
.41145 .60382 Mdot
.50781 .58175 Mdot
.5497 .33552 Mdot
.38268 .35299 Mdot
.5831 .70601 Mdot
.59388 .7971 Mdot
.64588 .48372 Mdot
.58613 .59295 Mdot
.60123 .49087 Mdot
.21572 .36431 Mdot
.47197 .61325 Mdot
.45769 .60638 Mdot
.15976 .43694 Mdot
.49279 .83728 Mdot
.44848 .56752 Mdot
.58228 .37089 Mdot
.7001 .34151 Mdot
.37864 .53824 Mdot
.57625 .60765 Mdot
.39144 .32218 Mdot
.40189 .3743 Mdot
.36261 .63442 Mdot
.61049 .70959 Mdot
.58433 .53216 Mdot
.39777 .55897 Mdot
.38716 .50292 Mdot
.52698 .32761 Mdot
.73385 .35138 Mdot
.68695 .76021 Mdot
.40863 .34489 Mdot
.41291 .61515 Mdot
.18265 .48239 Mdot
.57545 .67497 Mdot
.58817 .35125 Mdot
.69002 .46187 Mdot
.5477 .66612 Mdot
.5818 .3756 Mdot
.34855 .58497 Mdot
.44016 .60722 Mdot
.65181 .44897 Mdot
.55149 .6578 Mdot
.39633 .34021 Mdot
.55768 .38186 Mdot
.40529 .35125 Mdot
.60265 .65737 Mdot
.60325 .66781 Mdot
.51083 .59142 Mdot
.47287 .60816 Mdot
.56432 .36709 Mdot
.32929 .56557 Mdot
.67434 .41464 Mdot
.22855 .30066 Mdot
.60143 .48501 Mdot
.4478 .59114 Mdot
.62488 .63496 Mdot
.64942 .46707 Mdot
.41208 .54768 Mdot
.14809 .50434 Mdot
.3739 .53192 Mdot
.70396 .50883 Mdot
.34259 .76301 Mdot
.40204 .3534 Mdot
.55585 .5606 Mdot
.46771 .20252 Mdot
.43176 .60273 Mdot
.5298 .34465 Mdot
.43587 .63142 Mdot
.69321 .47375 Mdot
.61955 .6414 Mdot
.20526 .3172 Mdot
.67317 .48404 Mdot
.41626 .6092 Mdot
.40019 .36791 Mdot
.61712 .67234 Mdot
.56579 .54172 Mdot
.51543 .50013 Mdot
.47971 .56014 Mdot
.43271 .52716 Mdot
.37905 .54712 Mdot
.25675 .49716 Mdot
.53869 .37976 Mdot
.55451 .63826 Mdot
.67137 .46536 Mdot
.6881 .49976 Mdot
.55879 .34214 Mdot
.51269 .30744 Mdot
.57282 .44043 Mdot
.84151 .40888 Mdot
.50396 .34026 Mdot
.40803 .33888 Mdot
.74891 .59677 Mdot
.53585 .37615 Mdot
.543 .36877 Mdot
.52105 .32517 Mdot
.44963 .43072 Mdot
.61242 .66706 Mdot
.34792 .58327 Mdot
.56428 .61259 Mdot
.36555 .55392 Mdot
.71172 .50924 Mdot
.65784 .4687 Mdot
.60085 .66246 Mdot
.22957 .32645 Mdot
.43164 .77508 Mdot
.39201 .58687 Mdot
.35437 .22657 Mdot
.4613 .54765 Mdot
.31682 .33521 Mdot
.45687 .54472 Mdot
.55519 .36086 Mdot
.34067 .54982 Mdot
.33789 .60635 Mdot
.77905 .64412 Mdot
.66257 .49244 Mdot
.58114 .39345 Mdot
.41171 .50386 Mdot
.37922 .50497 Mdot
.5463 .61913 Mdot
.56025 .66272 Mdot
.41795 .34802 Mdot
.49367 .53245 Mdot
.67739 .50292 Mdot
.67103 .22095 Mdot
.37834 .59877 Mdot
.34666 .30807 Mdot
.58085 .76514 Mdot
.41519 .54917 Mdot
.4315 .20783 Mdot
.49175 .75708 Mdot
.40824 .57454 Mdot
.48176 .42347 Mdot
.65792 .49074 Mdot
.27927 .53204 Mdot
.36772 .53683 Mdot
.5404 .33003 Mdot
.61384 .62656 Mdot
.57328 .67723 Mdot
.41261 .33924 Mdot
.80944 .42114 Mdot
.64142 .45958 Mdot
.61592 .65608 Mdot
.39391 .57035 Mdot
.67694 .46951 Mdot
.51746 .32499 Mdot
.4532 .56222 Mdot
.41979 .81554 Mdot
.58136 .66518 Mdot
.44886 .53844 Mdot
.76186 .54533 Mdot
.26582 .39768 Mdot
.35328 .78012 Mdot
.66475 .46102 Mdot
.39099 .33235 Mdot
.3759 .63404 Mdot
.63468 .62532 Mdot
.39366 .51241 Mdot
.29532 .43782 Mdot
.69405 .25915 Mdot
.35041 .35102 Mdot
.38583 .59255 Mdot
.4122 .5552 Mdot
.6192 .55281 Mdot
.41048 .35142 Mdot
.43796 .58535 Mdot
.65519 .63061 Mdot
.56755 .65886 Mdot
.54974 .32397 Mdot
.5938 .67194 Mdot
.39824 .59306 Mdot
.47788 .60179 Mdot
.56353 .6687 Mdot
.27469 .27618 Mdot
.37889 .31773 Mdot
.67355 .45945 Mdot
.41771 .6177 Mdot
.34515 .55171 Mdot
.86146 .59472 Mdot
.59033 .34677 Mdot
.69375 .39937 Mdot
.51757 .243 Mdot
.20092 .46298 Mdot
.33313 .36331 Mdot
.31713 .76924 Mdot
.4844 .83753 Mdot
.45296 .58079 Mdot
.59572 .58025 Mdot
.75774 .51563 Mdot
.6615 .49823 Mdot
.78829 .37473 Mdot
.3782 .59923 Mdot
.38353 .5726 Mdot
.57272 .33612 Mdot
.64845 .39145 Mdot
.6177 .78737 Mdot
.52483 .61591 Mdot
.39912 .34703 Mdot
.59535 .62328 Mdot
.35223 .595 Mdot
.51257 .46128 Mdot
.59026 .37094 Mdot
.40432 .31224 Mdot
.40727 .60474 Mdot
.65286 .71583 Mdot
.67805 .59707 Mdot
.68693 .48208 Mdot
.52663 .35601 Mdot
.56115 .80119 Mdot
.4403 .59847 Mdot
.6492 .44178 Mdot
.41085 .5897 Mdot
.34064 .38067 Mdot
.33867 .52187 Mdot
.37829 .33286 Mdot
.35987 .54765 Mdot
.55243 .28123 Mdot
.77962 .72207 Mdot
.38741 .38759 Mdot
.53944 .63362 Mdot
.57592 .33022 Mdot
.56325 .35127 Mdot
.55575 .65703 Mdot
.5621 .3589 Mdot
.48814 .72341 Mdot
.40218 .79392 Mdot
.39415 .3537 Mdot
.32731 .60332 Mdot
.38631 .3465 Mdot
.58106 .34218 Mdot
.37162 .58961 Mdot
.16689 .38584 Mdot
.56971 .37092 Mdot
.52825 .83955 Mdot
.67334 .49145 Mdot
.59396 .35152 Mdot
.37201 .5348 Mdot
.66185 .60519 Mdot
.5079 .35893 Mdot
.69275 .38336 Mdot
.44029 .57454 Mdot
.60276 .6697 Mdot
.38721 .54115 Mdot
.37463 .60719 Mdot
.57866 .3893 Mdot
.35823 .56616 Mdot
.68124 .459 Mdot
.58651 .60014 Mdot
.23596 .62086 Mdot
.74175 .32411 Mdot
.438 .58697 Mdot
.39518 .57285 Mdot
.62196 .67711 Mdot
.35223 .53824 Mdot
.64949 .49724 Mdot
.33975 .15586 Mdot
.39086 .35352 Mdot
.59691 .36281 Mdot
.53552 .26404 Mdot
.40627 .62537 Mdot
.355 .5764 Mdot
.13771 .58625 Mdot
.28572 .47955 Mdot
.67449 .45635 Mdot
.3267 .56403 Mdot
.50361 .35137 Mdot
.38138 .36735 Mdot
.68547 .51116 Mdot
.41081 .57009 Mdot
.38159 .58535 Mdot
.39961 .33713 Mdot
.3273 .31788 Mdot
.66568 .74517 Mdot
.63832 .44667 Mdot
.43173 .50415 Mdot
.58518 .40116 Mdot
.41465 .52692 Mdot
.70392 .71908 Mdot
.56167 .62489 Mdot
.64779 .48796 Mdot
.19879 .48347 Mdot
.44461 .59382 Mdot
.66101 .44962 Mdot
.67405 .50246 Mdot
.39862 .51102 Mdot
.53692 .59611 Mdot
.57548 .59916 Mdot
.5701 .66358 Mdot
.64042 .16853 Mdot
.29827 .41772 Mdot
.51797 .35842 Mdot
.65992 .49443 Mdot
.57522 .34629 Mdot
.43272 .3677 Mdot
.52322 .49565 Mdot
.57794 .35139 Mdot
.58799 .67366 Mdot
.59597 .35689 Mdot
.43176 .56152 Mdot
.67806 .50233 Mdot
.52357 .34813 Mdot
.37333 .60965 Mdot
.67084 .69874 Mdot
.61375 .27388 Mdot
.35573 .3539 Mdot
.37194 .31959 Mdot
.3907 .53547 Mdot
.5009 .33777 Mdot
.37751 .58924 Mdot
.68392 .45315 Mdot
.72038 .66461 Mdot
.37348 .60543 Mdot
.55866 .36437 Mdot
.61983 .6775 Mdot
.57021 .79916 Mdot
.34138 .60237 Mdot
.39586 .59618 Mdot
.36175 .55879 Mdot
.41175 .58958 Mdot
.23445 .34341 Mdot
.63584 .46401 Mdot
.67767 .26525 Mdot
.21406 .45042 Mdot
.58849 .65379 Mdot
.55283 .62347 Mdot
.66894 .76291 Mdot
.73844 .53265 Mdot
.65886 .48958 Mdot
.38375 .55481 Mdot
.68314 .57286 Mdot
.17644 .61563 Mdot
.18516 .38681 Mdot
.31089 .67332 Mdot
.58882 .34451 Mdot
.58817 .59358 Mdot
.56959 .35822 Mdot
.3679 .55901 Mdot
.3958 .50422 Mdot
.3945 .82722 Mdot
.70161 .50002 Mdot
.39626 .34659 Mdot
.36358 .55352 Mdot
.29269 .41834 Mdot
.53232 .35501 Mdot
.59402 .35035 Mdot
.416 .54175 Mdot
.59281 .68539 Mdot
.76408 .72867 Mdot
.68145 .47762 Mdot
.66437 .2656 Mdot
.77057 .36008 Mdot
.67955 .6384 Mdot
.68496 .48734 Mdot
.63281 .60976 Mdot
.58671 .35342 Mdot
.57402 .74529 Mdot
.58745 .64735 Mdot
.3743 .36673 Mdot
.4316 .50995 Mdot
.55389 .62971 Mdot
.53405 .38621 Mdot
.61586 .6603 Mdot
.35488 .57913 Mdot
.67092 .52142 Mdot
.53921 .34606 Mdot
.66849 .53284 Mdot
.62548 .63823 Mdot
.41006 .35636 Mdot
.69951 .43747 Mdot
.32755 .7077 Mdot
.49235 .75466 Mdot
.41764 .53989 Mdot
.50246 .45718 Mdot
.41162 .55906 Mdot
.60155 .69295 Mdot
.40516 .58211 Mdot
.44867 .64542 Mdot
.53112 .34395 Mdot
.35127 .5517 Mdot
.39217 .55617 Mdot
.58291 .18912 Mdot
.43213 .58906 Mdot
.39895 .52149 Mdot
.40558 .57053 Mdot
.45206 .64225 Mdot
.37379 .63708 Mdot
.60558 .63106 Mdot
.46535 .23075 Mdot
.54491 .36726 Mdot
.41366 .3687 Mdot
.37376 .32631 Mdot
.32631 .43513 Mdot
.5197 .28251 Mdot
.63661 .36542 Mdot
.57043 .65789 Mdot
.68178 .45585 Mdot
.40845 .58519 Mdot
.28263 .72924 Mdot
.53471 .4033 Mdot
.5735 .38649 Mdot
.74457 .33017 Mdot
.30871 .54354 Mdot
.2615 .61303 Mdot
.33671 .54087 Mdot
.7517 .27292 Mdot
.40951 .62889 Mdot
.34983 .50552 Mdot
.50528 .33563 Mdot
.35339 .30045 Mdot
.36331 .53134 Mdot
.58207 .60523 Mdot
.36489 .34094 Mdot
.32416 .51724 Mdot
.60008 .3249 Mdot
.61296 .40253 Mdot
.46452 .65473 Mdot
.43617 .57167 Mdot
.54012 .34644 Mdot
.60891 .6462 Mdot
.66716 .7703 Mdot
.68409 .47416 Mdot
.53531 .3017 Mdot
.78581 .5558 Mdot
.29549 .26651 Mdot
.40867 .36559 Mdot
.54461 .70983 Mdot
.43131 .5541 Mdot
.37559 .27755 Mdot
.3978 .61524 Mdot
.14698 .56622 Mdot
.37302 .32445 Mdot
.60033 .67401 Mdot
.66899 .44885 Mdot
.57797 .60839 Mdot
.47809 .74484 Mdot
.60781 .33322 Mdot
.5553 .47302 Mdot
.53765 .3713 Mdot
.57716 .53393 Mdot
.56324 .63146 Mdot
.37568 .60108 Mdot
.83937 .39953 Mdot
.55321 .63456 Mdot
.62258 .66343 Mdot
.49932 .18105 Mdot
.19855 .33583 Mdot
.45935 .60971 Mdot
.61086 .67323 Mdot
.54556 .3752 Mdot
.37259 .33808 Mdot
.36635 .54061 Mdot
.43823 .56368 Mdot
.56208 .62192 Mdot
.58807 .38568 Mdot
.37852 .71472 Mdot
.55668 .34499 Mdot
.60424 .6717 Mdot
.54787 .35484 Mdot
.71811 .49105 Mdot
.55881 .38289 Mdot
.3444 .5529 Mdot
.40609 .58294 Mdot
.47855 .25266 Mdot
.60219 .66836 Mdot
.40034 .56001 Mdot
.44639 .54373 Mdot
.57455 .64787 Mdot
.62812 .58821 Mdot
.39386 .72365 Mdot
.44313 .54675 Mdot
.44026 .5781 Mdot
.36032 .32924 Mdot
.5254 .48786 Mdot
.59998 .72836 Mdot
.35249 .57221 Mdot
.3533 .36031 Mdot
.59265 .61203 Mdot
.39306 .60453 Mdot
.18274 .56723 Mdot
.6981 .34251 Mdot
.39113 .60893 Mdot
.57022 .35389 Mdot
.32771 .58198 Mdot
.37207 .79227 Mdot
.39418 .53095 Mdot
.56635 .64292 Mdot
.61493 .65293 Mdot
.65629 .21672 Mdot
.57415 .63245 Mdot
.51165 .35856 Mdot
.68342 .49127 Mdot
.21483 .36267 Mdot
.56101 .33742 Mdot
.38575 .62615 Mdot
.51105 .1577 Mdot
.45826 .55676 Mdot
.35826 .60701 Mdot
.5769 .81767 Mdot
.56967 .36385 Mdot
.59795 .6396 Mdot
.67933 .42956 Mdot
.47143 .60516 Mdot
.64669 .48167 Mdot
.38056 .50039 Mdot
.4025 .53259 Mdot
.41871 .82452 Mdot
.23768 .34322 Mdot
.63536 .44398 Mdot
.40142 .5222 Mdot
.35319 .57417 Mdot
.48527 .35857 Mdot
.39972 .57299 Mdot
.37621 .33602 Mdot
.59757 .65095 Mdot
.57682 .37614 Mdot
.38184 .3618 Mdot
.43197 .60653 Mdot
.39631 .33894 Mdot
.53078 .33556 Mdot
.69955 .47255 Mdot
.36775 .56935 Mdot
.37704 .37506 Mdot
.39932 .34461 Mdot
.41173 .56092 Mdot
.61638 .62796 Mdot
.30057 .56995 Mdot
.42823 .59311 Mdot
.34932 .56815 Mdot
.58363 .62585 Mdot
.26671 .77183 Mdot
.39667 .53479 Mdot
.29821 .44494 Mdot
.55047 .6491 Mdot
.59721 .55227 Mdot
.55512 .32859 Mdot
.3801 .52728 Mdot
.69912 .4714 Mdot
.69701 .47088 Mdot
.55467 .38835 Mdot
.59339 .59544 Mdot
.5447 .25668 Mdot
.54582 .60395 Mdot
.39481 .63358 Mdot
.38541 .52095 Mdot
.33929 .63847 Mdot
.26219 .68865 Mdot
.57764 .61236 Mdot
.57591 .30142 Mdot
.52985 .64699 Mdot
.67304 .447 Mdot
.57165 .39258 Mdot
.57576 .59836 Mdot
.58908 .62684 Mdot
.60357 .60956 Mdot
.37434 .36736 Mdot
.47791 .25559 Mdot
.55774 .66647 Mdot
.58859 .68669 Mdot
.441 .56161 Mdot
.35244 .56708 Mdot
.51844 .82731 Mdot
.50374 .82037 Mdot
.35674 .33438 Mdot
.51595 .3557 Mdot
.58327 .12802 Mdot
.70427 .48568 Mdot
.61588 .21256 Mdot
.35143 .59791 Mdot
.62129 .13697 Mdot
.37088 .53687 Mdot
.39384 .56839 Mdot
.57418 .59871 Mdot
.36708 .36618 Mdot
.38757 .34996 Mdot
.55427 .6362 Mdot
.5865 .68957 Mdot
.37889 .33601 Mdot
.44102 .1987 Mdot
.18477 .60631 Mdot
.67588 .41166 Mdot
.58202 .65633 Mdot
.35436 .74501 Mdot
.64511 .44641 Mdot
.41619 .49012 Mdot
.62637 .46661 Mdot
.53577 .36258 Mdot
.58834 .36232 Mdot
.64655 .47469 Mdot
.43564 .58099 Mdot
.51955 .36302 Mdot
.45525 .58089 Mdot
.60978 .25523 Mdot
.46618 .76797 Mdot
.61086 .31802 Mdot
.3838 .48087 Mdot
.63041 .58994 Mdot
.69425 .53165 Mdot
.41329 .61147 Mdot
.17271 .53016 Mdot
.39767 .34978 Mdot
.43425 .63236 Mdot
.65107 .49397 Mdot
.56413 .83095 Mdot
.36777 .57803 Mdot
.5692 .64802 Mdot
.66995 .50197 Mdot
.7927 .55857 Mdot
.76224 .58043 Mdot
.36317 .55607 Mdot
.81665 .36434 Mdot
.63245 .67819 Mdot
.52828 .36875 Mdot
.71725 .68485 Mdot
.5518 .62748 Mdot
.34532 .38177 Mdot
.20192 .5087 Mdot
.25258 .30287 Mdot
.6017 .64452 Mdot
.56828 .32916 Mdot
.60495 .62264 Mdot
.40742 .36334 Mdot
.54029 .62959 Mdot
.53277 .34808 Mdot
.40156 .60359 Mdot
.55924 .3532 Mdot
.36889 .36176 Mdot
.63838 .74612 Mdot
.63575 .44382 Mdot
.52744 .38831 Mdot
.66369 .468 Mdot
.24488 .40399 Mdot
.25291 .48742 Mdot
.67011 .45927 Mdot
.37061 .68046 Mdot
.38295 .52151 Mdot
.54918 .6504 Mdot
.55263 .3305 Mdot
.40353 .30059 Mdot
.69935 .44444 Mdot
.58448 .64264 Mdot
.5205 .37543 Mdot
.74971 .61998 Mdot
.46725 .63421 Mdot
.38186 .51986 Mdot
.37393 .41918 Mdot
.57998 .65196 Mdot
.57182 .33362 Mdot
.74974 .71585 Mdot
.6037 .62329 Mdot
.50269 .34636 Mdot
.66012 .44748 Mdot
.69123 .49707 Mdot
.42849 .53421 Mdot
.70967 .51701 Mdot
.53575 .38213 Mdot
.61966 .50803 Mdot
.61689 .66767 Mdot
.78408 .59007 Mdot
.41025 .37569 Mdot
.54968 .36347 Mdot
.46226 .56488 Mdot
.61447 .69084 Mdot
.71463 .32722 Mdot
.39685 .73502 Mdot
.85197 .49338 Mdot
.55897 .34292 Mdot
.59389 .6453 Mdot
.57249 .65303 Mdot
.34739 .61068 Mdot
.72176 .67125 Mdot
.49476 .23782 Mdot
.40612 .64892 Mdot
.59318 .47221 Mdot
.53247 .31978 Mdot
.5638 .31361 Mdot
.40641 .50247 Mdot
.4299 .58032 Mdot
.66641 .44539 Mdot
.40217 .60206 Mdot
.61741 .62312 Mdot
.41876 .54126 Mdot
.67275 .46754 Mdot
.54021 .37557 Mdot
.36908 .57371 Mdot
.40132 .34608 Mdot
.63721 .46558 Mdot
.70671 .4826 Mdot
.55394 .36693 Mdot
.56204 .62161 Mdot
.58816 .55204 Mdot
.55025 .33276 Mdot
.43639 .57246 Mdot
.48953 .45998 Mdot
.35589 .58291 Mdot
.56842 .57823 Mdot
.60066 .62254 Mdot
.57707 .37539 Mdot
.53361 .62553 Mdot
.66826 .4772 Mdot
.21106 .46038 Mdot
.3987 .58887 Mdot
.50531 .33773 Mdot
.75637 .40716 Mdot
.57275 .56168 Mdot
.62701 .64422 Mdot
.55641 .24614 Mdot
.54705 .64413 Mdot
.51697 .34781 Mdot
.55741 .19025 Mdot
.3903 .37347 Mdot
.58179 .38154 Mdot
.24194 .63166 Mdot
.56509 .37161 Mdot
.42768 .53955 Mdot
.39615 .53771 Mdot
.56248 .38224 Mdot
.38708 .32996 Mdot
.63353 .78792 Mdot
.51899 .31088 Mdot
.59902 .64342 Mdot
.53859 .21127 Mdot
.83397 .58044 Mdot
.64036 .54522 Mdot
.67526 .44915 Mdot
.46522 .60135 Mdot
.3792 .52418 Mdot
.65695 .50153 Mdot
.623 .45225 Mdot
.41783 .35669 Mdot
.50963 .33574 Mdot
.62638 .68041 Mdot
.69934 .46115 Mdot
.52178 .64727 Mdot
.5115 .2718 Mdot
.33716 .59378 Mdot
.76292 .34631 Mdot
.35005 .59438 Mdot
.24334 .47194 Mdot
.66957 .46432 Mdot
.40468 .61537 Mdot
.33905 .53964 Mdot
.676 .50645 Mdot
.37049 .3383 Mdot
.54417 .30259 Mdot
.54561 .3521 Mdot
.25972 .75108 Mdot
.4536 .57369 Mdot
.42411 .54524 Mdot
.65272 .48177 Mdot
.41546 .27908 Mdot
.59282 .65607 Mdot
.55572 .61446 Mdot
.53891 .37975 Mdot
.57101 .42336 Mdot
.41252 .53015 Mdot
.40843 .60921 Mdot
.54523 .34367 Mdot
.52526 .38471 Mdot
.64184 .35899 Mdot
.41395 .55378 Mdot
.66278 .48833 Mdot
.3079 .3153 Mdot
.66211 .46088 Mdot
.36349 .59123 Mdot
.42406 .54823 Mdot
.34333 .55516 Mdot
.4482 .598 Mdot
.64378 .50247 Mdot
.36028 .59383 Mdot
.36306 .51987 Mdot
.59102 .64476 Mdot
.35906 .55507 Mdot
.60274 .44618 Mdot
.40646 .59859 Mdot
.37536 .33706 Mdot
.59358 .72215 Mdot
.36773 .57693 Mdot
.41273 .53797 Mdot
.59686 .347 Mdot
.38677 .58582 Mdot
.69082 .46049 Mdot
.59492 .66636 Mdot
.65658 .4878 Mdot
.69472 .46787 Mdot
.54306 .31624 Mdot
.39348 .32774 Mdot
.41403 .62504 Mdot
.35778 .341 Mdot
.4194 .63103 Mdot
.44514 .59293 Mdot
.4742 .3279 Mdot
.71935 .23696 Mdot
.69884 .73071 Mdot
.40028 .59015 Mdot
.56969 .36741 Mdot
.57041 .35786 Mdot
.59476 .58364 Mdot
.4137 .52056 Mdot
.67797 .51416 Mdot
.67465 .44753 Mdot
.32794 .73765 Mdot
.33624 .47634 Mdot
.37419 .33709 Mdot
.53554 .48789 Mdot
.44885 .56291 Mdot
.4076 .61554 Mdot
.4552 .56463 Mdot
.5787 .35082 Mdot
.28488 .61867 Mdot
.56431 .39256 Mdot
.66455 .55255 Mdot
.65118 .46925 Mdot
.36415 .56592 Mdot
.74496 .318 Mdot
.56878 .66615 Mdot
.59496 .66677 Mdot
.70932 .48803 Mdot
.5321 .39986 Mdot
.57616 .79658 Mdot
.16784 .41083 Mdot
.6239 .70009 Mdot
.37144 .36837 Mdot
.42486 .60715 Mdot
.55616 .37881 Mdot
.61501 .66494 Mdot
.3687 .36518 Mdot
.36773 .59013 Mdot
.47908 .25634 Mdot
.40865 .59249 Mdot
.75866 .50155 Mdot
.61215 .62713 Mdot
.16445 .59281 Mdot
.59812 .59879 Mdot
.64383 .49506 Mdot
.65009 .49594 Mdot
.41365 .54931 Mdot
.64884 .66136 Mdot
.54934 .63033 Mdot
.41714 .40878 Mdot
.40951 .34107 Mdot
.65164 .56801 Mdot
.38386 .36999 Mdot
.52529 .35734 Mdot
.3682 .3554 Mdot
.53305 .34538 Mdot
.58961 .78932 Mdot
.42673 .6669 Mdot
.38449 .3582 Mdot
.7588 .42516 Mdot
.37684 .52491 Mdot
.35155 .34164 Mdot
.39937 .50516 Mdot
.3965 .64614 Mdot
.54782 .34285 Mdot
.41164 .34938 Mdot
.40515 .61433 Mdot
.30314 .74276 Mdot
.67407 .45835 Mdot
.67304 .51411 Mdot
.40316 .5062 Mdot
.55307 .32459 Mdot
.57873 .60164 Mdot
.18063 .46769 Mdot
.69083 .45048 Mdot
.40371 .54001 Mdot
.35828 .53399 Mdot
.54839 .65124 Mdot
.67484 .2456 Mdot
.42282 .55277 Mdot
.53834 .58293 Mdot
.41099 .55068 Mdot
.64607 .45914 Mdot
.58409 .61114 Mdot
.58027 .66016 Mdot
.51945 .37299 Mdot
.58234 .677 Mdot
.48407 .48819 Mdot
.77004 .44347 Mdot
.32709 .53136 Mdot
.67277 .48006 Mdot
.67429 .58339 Mdot
.69217 .53738 Mdot
.24808 .60257 Mdot
.62153 .62231 Mdot
.36885 .60275 Mdot
.58671 .68 Mdot
.37409 .36062 Mdot
.59331 .67025 Mdot
.58788 .59353 Mdot
.37767 .5936 Mdot
.36814 .55434 Mdot
.53417 .37277 Mdot
.72685 .66431 Mdot
.55313 .62965 Mdot
.37234 .53713 Mdot
.33772 .56046 Mdot
.45917 .57375 Mdot
.42241 .41982 Mdot
.58209 .61214 Mdot
.40398 .18556 Mdot
.41934 .45265 Mdot
.55565 .62655 Mdot
.71495 .76293 Mdot
.74199 .37031 Mdot
.61052 .35701 Mdot
.46024 .35702 Mdot
.4067 .54891 Mdot
.5092 .36625 Mdot
.36785 .55978 Mdot
.76568 .35339 Mdot
.3831 .57993 Mdot
.3744 .33545 Mdot
.4532 .58035 Mdot
.5861 .37166 Mdot
.55715 .34298 Mdot
.40713 .54014 Mdot
.37052 .57107 Mdot
.64291 .75331 Mdot
.54073 .62344 Mdot
.60975 .66297 Mdot
.61968 .34059 Mdot
.39194 .36297 Mdot
.64682 .48463 Mdot
.40701 .57576 Mdot
.5567 .32299 Mdot
.55819 .34567 Mdot
.5663 .61336 Mdot
.52996 .331 Mdot
.68255 .47953 Mdot
.39937 .58527 Mdot
.65954 .50555 Mdot
.39064 .37507 Mdot
.58544 .61312 Mdot
.36077 .555 Mdot
.4412 .56184 Mdot
.61471 .65307 Mdot
.40597 .61737 Mdot
.3946 .33501 Mdot
.56287 .36826 Mdot
.603 .64397 Mdot
.68519 .49423 Mdot
.52645 .35351 Mdot
.34869 .57932 Mdot
.79932 .34844 Mdot
.43382 .5401 Mdot
.3954 .54412 Mdot
.26199 .70327 Mdot
.44938 .5722 Mdot
.55638 .3356 Mdot
.61138 .66892 Mdot
.48908 .60607 Mdot
.32807 .41666 Mdot
.24876 .7622 Mdot
.56059 .39175 Mdot
.42343 .60485 Mdot
.25715 .64606 Mdot
.41719 .60548 Mdot
.38678 .751 Mdot
.55499 .39794 Mdot
.58483 .49145 Mdot
.46139 .57711 Mdot
.69386 .48104 Mdot
.5523 .38137 Mdot
.53451 .34059 Mdot
.57734 .2291 Mdot
.38742 .60324 Mdot
.46711 .4211 Mdot
.3618 .58367 Mdot
.6887 .49281 Mdot
.34845 .47858 Mdot
.55634 .33873 Mdot
.82291 .58031 Mdot
.41341 .55893 Mdot
.58615 .62133 Mdot
.59541 .35126 Mdot
.70389 .45884 Mdot
.35042 .56146 Mdot
.37235 .32972 Mdot
.6364 .44001 Mdot
.34245 .51768 Mdot
.67581 .48137 Mdot
.34965 .56972 Mdot
.47965 .54944 Mdot
.81955 .51468 Mdot
.60936 .61364 Mdot
.66545 .44716 Mdot
.47384 .45113 Mdot
.36845 .60066 Mdot
.60247 .64558 Mdot
.58697 .64553 Mdot
.38313 .37376 Mdot
.57483 .5121 Mdot
.76931 .54187 Mdot
.44082 .78713 Mdot
.5533 .2171 Mdot
.59103 .37381 Mdot
.6807 .38978 Mdot
.39022 .54748 Mdot
.43964 .45084 Mdot
.68527 .45494 Mdot
.43558 .54006 Mdot
.52587 .70236 Mdot
.55906 .65868 Mdot
.43796 .54705 Mdot
.38681 .3451 Mdot
.34485 .31807 Mdot
.29931 .32244 Mdot
.21658 .54526 Mdot
.53677 .36922 Mdot
.32469 .56151 Mdot
.50386 .59005 Mdot
.54937 .32466 Mdot
.34014 .58233 Mdot
.54765 .32596 Mdot
.38807 .21416 Mdot
.35421 .34993 Mdot
.58993 .62017 Mdot
.64934 .53766 Mdot
.36278 .61199 Mdot
.40048 .52782 Mdot
.39606 .32757 Mdot
.42944 .57738 Mdot
.80762 .46382 Mdot
.41527 .4197 Mdot
.52184 .35559 Mdot
.60469 .60999 Mdot
.33845 .56545 Mdot
.52651 .50114 Mdot
.41664 .60162 Mdot
.51104 .7901 Mdot
.41061 .53726 Mdot
.76728 .57975 Mdot
.61322 .62397 Mdot
.67136 .47314 Mdot
.42967 .61545 Mdot
.38706 .5744 Mdot
.33064 .45969 Mdot
.41833 .62986 Mdot
.39007 .61188 Mdot
.48675 .62875 Mdot
.59931 .60264 Mdot
.60667 .62696 Mdot
.55156 .38935 Mdot
.27991 .67209 Mdot
.66548 .48446 Mdot
.48833 .5911 Mdot
.71135 .49348 Mdot
.34723 .69363 Mdot
.36237 .35731 Mdot
.25174 .52806 Mdot
.39851 .56253 Mdot
.57147 .66108 Mdot
.19774 .42324 Mdot
.54979 .61456 Mdot
.52893 .47415 Mdot
.67757 .50285 Mdot
.55482 .63317 Mdot
.39038 .56962 Mdot
.63921 .70685 Mdot
.27661 .70843 Mdot
.66057 .47648 Mdot
.37405 .62261 Mdot
.58961 .36886 Mdot
.54523 .26503 Mdot
.82658 .53038 Mdot
.6699 .45603 Mdot
.60278 .46484 Mdot
.3953 .60754 Mdot
.57961 .6737 Mdot
.69259 .48495 Mdot
.64845 .45862 Mdot
.52734 .3339 Mdot
.3689 .55192 Mdot
.37168 .54939 Mdot
.51476 .35993 Mdot
.65525 .48536 Mdot
.3904 .51447 Mdot
.3438 .52131 Mdot
.48873 .86084 Mdot
.76511 .59964 Mdot
.27876 .78395 Mdot
.60267 .57753 Mdot
.49849 .68319 Mdot
.17418 .47864 Mdot
.56861 .61731 Mdot
.42384 .61228 Mdot
.4104 .4993 Mdot
.53669 .38276 Mdot
.39075 .59393 Mdot
.56693 .40062 Mdot
.69925 .4982 Mdot
.55884 .83119 Mdot
.7049 .60963 Mdot
.32661 .25132 Mdot
.38876 .59389 Mdot
.51209 .60828 Mdot
.37269 .35358 Mdot
.64508 .57443 Mdot
.59095 .61529 Mdot
.45609 .54917 Mdot
.64159 .7516 Mdot
.57492 .38599 Mdot
.58013 .62893 Mdot
.66042 .77339 Mdot
.63648 .59957 Mdot
.35648 .58262 Mdot
.55105 .39272 Mdot
.16849 .52041 Mdot
.51305 .64803 Mdot
.69224 .51547 Mdot
.36915 .33863 Mdot
.5707 .3786 Mdot
.66207 .44351 Mdot
.54171 .59142 Mdot
.57059 .626 Mdot
.58122 .60421 Mdot
.67211 .73402 Mdot
.59831 .37437 Mdot
.37451 .35498 Mdot
.28877 .52067 Mdot
.3417 .46603 Mdot
.3814 .33575 Mdot
.5886 .36123 Mdot
.61476 .6188 Mdot
.55551 .6461 Mdot
.59385 .66598 Mdot
.74384 .69083 Mdot
.60451 .68101 Mdot
.58369 .21695 Mdot
.4548 .58607 Mdot
.32084 .59807 Mdot
.4207 .60675 Mdot
.67761 .51268 Mdot
.61393 .64927 Mdot
.67455 .42524 Mdot
.39216 .63036 Mdot
.26162 .50423 Mdot
.42767 .5366 Mdot
.63303 .46831 Mdot
.43571 .55061 Mdot
.75047 .30446 Mdot
.5735 .67458 Mdot
.39614 .5914 Mdot
.62839 .46276 Mdot
.39847 .36297 Mdot
.62522 .63108 Mdot
.36187 .55827 Mdot
.51126 .22331 Mdot
.44781 .58289 Mdot
.35358 .23732 Mdot
.79306 .51871 Mdot
.36823 .36501 Mdot
.7903 .42145 Mdot
.55557 .31949 Mdot
.39399 .6422 Mdot
.47599 .59192 Mdot
.66333 .47218 Mdot
.64969 .56778 Mdot
.54495 .3695 Mdot
.30007 .65843 Mdot
.36908 .51586 Mdot
.3909 .37608 Mdot
.41165 .66344 Mdot
.66134 .50303 Mdot
.33801 .57683 Mdot
.33318 .55121 Mdot
.65584 .25183 Mdot
.37336 .50895 Mdot
.37704 .52762 Mdot
.36146 .32259 Mdot
.6025 .2156 Mdot
.41354 .59648 Mdot
.53442 .48158 Mdot
.54157 .6257 Mdot
.40867 .63388 Mdot
.58644 .21282 Mdot
.3921 .53607 Mdot
.57102 .62214 Mdot
.54255 .58418 Mdot
.7505 .53827 Mdot
.38949 .32617 Mdot
.41073 .53688 Mdot
.64571 .21185 Mdot
.42547 .56512 Mdot
.66688 .49004 Mdot
.41358 .52204 Mdot
.53292 .35113 Mdot
.72164 .72133 Mdot
.52128 .37261 Mdot
.42585 .52854 Mdot
.58918 .66287 Mdot
.65214 .47531 Mdot
.72743 .69039 Mdot
.45069 .25536 Mdot
.64149 .2288 Mdot
.18609 .38988 Mdot
.40762 .34065 Mdot
.41409 .37761 Mdot
.69524 .50436 Mdot
.39794 .59263 Mdot
.50435 .17415 Mdot
.44176 .62447 Mdot
.44312 .57073 Mdot
.3824 .5788 Mdot
.25283 .48214 Mdot
.69972 .47697 Mdot
.55181 .34148 Mdot
.42412 .55113 Mdot
.36782 .59895 Mdot
.57776 .6181 Mdot
.39695 .3586 Mdot
.55866 .33228 Mdot
.39353 .35273 Mdot
.55714 .38069 Mdot
.6167 .80536 Mdot
.365 .52052 Mdot
.40169 .3637 Mdot
.68081 .44664 Mdot
.57521 .62034 Mdot
.74551 .50489 Mdot
.52892 .34561 Mdot
.53903 .38662 Mdot
.40678 .53772 Mdot
.56106 .62433 Mdot
.53993 .60796 Mdot
.3903 .37051 Mdot
.67638 .46548 Mdot
.36816 .57798 Mdot
.44159 .59189 Mdot
.48794 .55771 Mdot
.54831 .32048 Mdot
.7678 .47916 Mdot
.63621 .3982 Mdot
.40106 .5918 Mdot
.61619 .66808 Mdot
.37432 .57479 Mdot
.31458 .28549 Mdot
.57692 .67307 Mdot
.38403 .53462 Mdot
.77292 .71781 Mdot
.61076 .33458 Mdot
.71285 .56238 Mdot
.36064 .53365 Mdot
.14901 .51545 Mdot
.39297 .55393 Mdot
.57108 .83238 Mdot
.29227 .31187 Mdot
.4087 .52559 Mdot
.34948 .56065 Mdot
.4459 .75255 Mdot
.43283 .6002 Mdot
.51688 .3718 Mdot
.50801 .83645 Mdot
.55311 .60834 Mdot
.70107 .53387 Mdot
.56314 .7112 Mdot
.38327 .32527 Mdot
.53918 .37984 Mdot
.5965 .33357 Mdot
.39098 .34117 Mdot
.57875 .65376 Mdot
.41192 .58944 Mdot
.51804 .43967 Mdot
.56194 .33104 Mdot
.29327 .60327 Mdot
.6675 .49282 Mdot
.67777 .32063 Mdot
.35448 .40385 Mdot
.67897 .48229 Mdot
.35972 .55276 Mdot
.42391 .74272 Mdot
.58484 .77979 Mdot
.21038 .62218 Mdot
.63924 .44375 Mdot
.65891 .47469 Mdot
.74709 .698 Mdot
.42345 .35278 Mdot
.65699 .25624 Mdot
.76337 .58287 Mdot
.64797 .47845 Mdot
.61757 .60478 Mdot
.51477 .37129 Mdot
.72644 .42362 Mdot
.40742 .63777 Mdot
.44556 .59587 Mdot
.39 .57131 Mdot
.66728 .45993 Mdot
.58268 .56697 Mdot
.78266 .60664 Mdot
.6613 .46603 Mdot
.45262 .51741 Mdot
.57295 .46243 Mdot
.74587 .41397 Mdot
.52837 .32696 Mdot
.41103 .34119 Mdot
.42676 .35118 Mdot
.59296 .63137 Mdot
.4062 .336 Mdot
.3469 .3149 Mdot
.42096 .58036 Mdot
.65454 .46233 Mdot
.75465 .37929 Mdot
.68551 .4981 Mdot
.392 .34693 Mdot
.41962 .3557 Mdot
.59099 .64559 Mdot
.60976 .6649 Mdot
.4632 .71232 Mdot
.32369 .38001 Mdot
.438 .58465 Mdot
.4444 .33675 Mdot
.58468 .59424 Mdot
.30943 .59005 Mdot
.40906 .33797 Mdot
.39521 .36254 Mdot
.31579 .46185 Mdot
.3956 .56302 Mdot
.31102 .63234 Mdot
.4013 .56816 Mdot
.45961 .49258 Mdot
.3451 .56819 Mdot
.52769 .33324 Mdot
.38523 .55498 Mdot
.30486 .47103 Mdot
.39888 .61957 Mdot
.35294 .53237 Mdot
.57415 .3412 Mdot
.35271 .52085 Mdot
.53424 .35156 Mdot
.43867 .53995 Mdot
.37584 .37625 Mdot
.54095 .3819 Mdot
.31098 .42047 Mdot
.30251 .45603 Mdot
.58703 .35689 Mdot
.36092 .34817 Mdot
.35769 .32924 Mdot
.27192 .42289 Mdot
.58941 .61376 Mdot
.47372 .56668 Mdot
.3956 .59419 Mdot
.57174 .39427 Mdot
.68656 .45971 Mdot
.34711 .57858 Mdot
.37088 .52677 Mdot
.35631 .54012 Mdot
.59189 .62855 Mdot
.48412 .23831 Mdot
.40569 .36273 Mdot
.51443 .36525 Mdot
.57976 .54455 Mdot
.53123 .31953 Mdot
.32906 .57525 Mdot
.43246 .5092 Mdot
.53731 .70125 Mdot
.75031 .44555 Mdot
.76944 .671 Mdot
.57288 .62683 Mdot
.57121 .35543 Mdot
.40944 .37675 Mdot
.46002 .5353 Mdot
.57281 .66348 Mdot
.53314 .34831 Mdot
.40791 .59208 Mdot
.36054 .61568 Mdot
.77064 .41977 Mdot
.28243 .34095 Mdot
.31005 .44109 Mdot
.56043 .38805 Mdot
.58769 .34427 Mdot
.28227 .46839 Mdot
.40517 .30678 Mdot
.70329 .44384 Mdot
.39459 .60407 Mdot
.37609 .32998 Mdot
.60579 .67148 Mdot
.61038 .73577 Mdot
.64218 .47602 Mdot
.71598 .6755 Mdot
.38904 .59212 Mdot
.61378 .5552 Mdot
.59012 .66217 Mdot
.38604 .34206 Mdot
.66278 .45852 Mdot
.4041 .31497 Mdot
.57581 .35235 Mdot
.24172 .30495 Mdot
.43107 .5686 Mdot
.41039 .53904 Mdot
.63783 .45459 Mdot
.5648 .65968 Mdot
.3457 .34291 Mdot
.53873 .21664 Mdot
.53386 .33546 Mdot
.51663 .17507 Mdot
.60895 .67357 Mdot
.35236 .74155 Mdot
.51704 .33625 Mdot
.70889 .47765 Mdot
.2852 .41773 Mdot
.67852 .47558 Mdot
.42265 .53172 Mdot
.56933 .65411 Mdot
.67459 .45055 Mdot
.74806 .64039 Mdot
.2949 .75692 Mdot
.36346 .75162 Mdot
.41451 .5815 Mdot
.37051 .80151 Mdot
.41439 .21466 Mdot
.63689 .69691 Mdot
.67482 .44667 Mdot
.43284 .5372 Mdot
.40797 .53297 Mdot
.42761 .56467 Mdot
.69456 .47268 Mdot
.44537 .35235 Mdot
.54631 .33978 Mdot
.41332 .61041 Mdot
.41717 .35977 Mdot
.53642 .35957 Mdot
.71588 .48564 Mdot
.53574 .3259 Mdot
.55458 .59007 Mdot
.33457 .59219 Mdot
.65145 .60178 Mdot
.86637 .6229 Mdot
.65671 .4804 Mdot
.55017 .31872 Mdot
.40264 .51313 Mdot
.71004 .35247 Mdot
.59717 .61059 Mdot
.53051 .3363 Mdot
.4244 .54384 Mdot
.7569 .44626 Mdot
.66054 .74382 Mdot
.54563 .32847 Mdot
.57534 .66621 Mdot
.21494 .61824 Mdot
.39622 .59983 Mdot
.40678 .5618 Mdot
.56024 .6293 Mdot
.3576 .65555 Mdot
.71388 .73974 Mdot
.37204 .5721 Mdot
.67052 .47082 Mdot
.28247 .25705 Mdot
.37207 .5264 Mdot
.41439 .46348 Mdot
.54161 .37854 Mdot
.72222 .4439 Mdot
.75905 .51712 Mdot
.4342 .61708 Mdot
.62625 .26427 Mdot
.64456 .53627 Mdot
.27517 .67425 Mdot
.57736 .39959 Mdot
.43032 .23427 Mdot
.34353 .77172 Mdot
.63373 .48357 Mdot
.45623 .6489 Mdot
.59242 .24473 Mdot
.5228 .66706 Mdot
.18461 .5587 Mdot
.39654 .28142 Mdot
.64596 .75156 Mdot
.53772 .44131 Mdot
.57044 .37307 Mdot
.34748 .63976 Mdot
.36538 .55984 Mdot
.40843 .21764 Mdot
.80929 .53435 Mdot
.80114 .56414 Mdot
.37222 .80368 Mdot
.38392 .75546 Mdot
.26018 .65924 Mdot
.24694 .63647 Mdot
.42057 .47516 Mdot
.6657 .39806 Mdot
.49825 .16816 Mdot
.57097 .80515 Mdot
.4665 .19097 Mdot
.31846 .58929 Mdot
.51256 .46152 Mdot
.30403 .27958 Mdot
.43598 .66339 Mdot
.42663 .64893 Mdot
.51724 .36281 Mdot
.58812 .61082 Mdot
.64329 .2539 Mdot
.55556 .66725 Mdot
.75142 .53519 Mdot
.2253 .64887 Mdot
.28576 .74035 Mdot
.67054 .23511 Mdot
.15539 .51114 Mdot
.51454 .69617 Mdot
.4347 .13981 Mdot
.51395 .38438 Mdot
.56469 .61491 Mdot
.25281 .46746 Mdot
.30389 .48697 Mdot
.6823 .62398 Mdot
.5457 .23383 Mdot
.50923 .26117 Mdot
.26477 .38358 Mdot
.5716 .65028 Mdot
.78311 .454 Mdot
.73509 .4345 Mdot
.6981 .61492 Mdot
.53938 .81883 Mdot
.22007 .59133 Mdot
.49829 .42977 Mdot
.60069 .26801 Mdot
.68158 .34642 Mdot
.78567 .61195 Mdot
.35267 .41735 Mdot
.48238 .62465 Mdot
.76896 .5875 Mdot
.18266 .43071 Mdot
.42993 .68799 Mdot
.47414 .51226 Mdot
.30836 .4901 Mdot
.63991 .79184 Mdot
.37248 .24607 Mdot
.86322 .56351 Mdot
.56102 .67547 Mdot
.35147 .53928 Mdot
.35398 .6693 Mdot
.60444 .19063 Mdot
.36267 .31997 Mdot
.21207 .53774 Mdot
.41382 .35721 Mdot
.54284 .5943 Mdot
.70377 .73682 Mdot
.59479 .21273 Mdot
.54708 .1705 Mdot
.39265 .38185 Mdot
.48911 .58891 Mdot
.12626 .59696 Mdot
.26407 .56767 Mdot
.70596 .5842 Mdot
.49524 .85923 Mdot
.58546 .44873 Mdot
.78689 .58134 Mdot
.6746 .44982 Mdot
.39087 .80879 Mdot
.55786 .64301 Mdot
.88506 .52354 Mdot
.58512 .82597 Mdot
.56318 .72242 Mdot
.64847 .87598 Mdot
.26762 .47475 Mdot
.58824 .50417 Mdot
.62175 .52115 Mdot
.30206 .38283 Mdot
.73854 .67051 Mdot
.22101 .43495 Mdot
.70146 .34937 Mdot
.14439 .51606 Mdot
.33167 .76828 Mdot
.52698 .16931 Mdot
.30957 .25252 Mdot
.45128 .67681 Mdot
.53346 .50709 Mdot
.4063 .48377 Mdot
.5882 .29099 Mdot
.20169 .53821 Mdot
.66653 .78795 Mdot
.41492 .45047 Mdot
.24326 .75455 Mdot
.39053 .3879 Mdot
.48583 .27238 Mdot
.25802 .73164 Mdot
.26789 .39341 Mdot
.77906 .49657 Mdot
.27103 .59836 Mdot
.31376 .52122 Mdot
.5346 .52524 Mdot
.20737 .5466 Mdot
.71396 .53921 Mdot
.47079 .83753 Mdot
.15712 .54243 Mdot
.66167 .2572 Mdot
.47003 .77687 Mdot
.36948 .45873 Mdot
.62737 .67125 Mdot
.32173 .32717 Mdot
.76407 .51759 Mdot
.32284 .78703 Mdot
.65464 .51205 Mdot
.36807 .81799 Mdot
.70166 .74594 Mdot
.36188 .52128 Mdot
.47207 .5618 Mdot
.62779 .6069 Mdot
.30688 .33385 Mdot
.32075 .57215 Mdot
.74932 .34507 Mdot
.27809 .7314 Mdot
.55461 .78406 Mdot
.71964 .5226 Mdot
.64944 .55664 Mdot
.26097 .74468 Mdot
.40161 .71295 Mdot
.43289 .33431 Mdot
.4681 .82697 Mdot
.74518 .66626 Mdot
.54466 .36315 Mdot
.54344 .17804 Mdot
.61025 .45233 Mdot
.63586 .74188 Mdot
.43512 .78461 Mdot
.50687 .66871 Mdot
.27889 .73371 Mdot
.47372 .22985 Mdot
.68231 .74699 Mdot
.23806 .423 Mdot
.48263 .18037 Mdot
.74927 .42853 Mdot
.38356 .49801 Mdot
.53549 .23065 Mdot
.36523 .32711 Mdot
.47464 .73597 Mdot
.33148 .21337 Mdot
.44436 .29973 Mdot
.41496 .50786 Mdot
.57345 .72574 Mdot
.59895 .32611 Mdot
.65418 .70213 Mdot
.86047 .50268 Mdot
.33795 .55122 Mdot
.29979 .509 Mdot
.45065 .22308 Mdot
.30859 .36825 Mdot
.17975 .60002 Mdot
.24851 .3287 Mdot
.86799 .57647 Mdot
.43204 .83853 Mdot
.44539 .25056 Mdot
.31867 .74784 Mdot
.3351 .7812 Mdot
.85597 .59114 Mdot
.46728 .60614 Mdot
.65623 .51108 Mdot
.76667 .27984 Mdot
.52553 .32725 Mdot
.29114 .50698 Mdot
.55344 .21705 Mdot
.33179 .37566 Mdot
.65426 .61654 Mdot
.2954 .64341 Mdot
.53485 .44747 Mdot
.53878 .62605 Mdot
.3245 .55789 Mdot
.81463 .60932 Mdot
.84105 .63209 Mdot
.83957 .59007 Mdot
.21036 .36306 Mdot
.39526 .80945 Mdot
.59966 .54177 Mdot
.64046 .21521 Mdot
.3051 .58866 Mdot
.41765 .61493 Mdot
.34456 .3231 Mdot
.2644 .47326 Mdot
.62046 .73282 Mdot
.7204 .61391 Mdot
.42087 .6672 Mdot
.21006 .53919 Mdot
.13105 .37794 Mdot
.48773 .71367 Mdot
.55721 .20464 Mdot
.42444 .32648 Mdot
.31616 .36512 Mdot
.18749 .50949 Mdot
.62755 .72812 Mdot
.25302 .67375 Mdot
.5397 .62324 Mdot
.50579 .20268 Mdot
.43235 .30774 Mdot
.47885 .63937 Mdot
.48126 .23997 Mdot
.25665 .58291 Mdot
.65831 .56545 Mdot
.6635 .7217 Mdot
.75025 .59222 Mdot
.37371 .68037 Mdot
.39751 .41019 Mdot
.66611 .33379 Mdot
.40358 .18474 Mdot
.35013 .27708 Mdot
.42581 .46995 Mdot
.56752 .4609 Mdot
.7833 .38272 Mdot
.66401 .5289 Mdot
.45276 .48346 Mdot
.61227 .43716 Mdot
.27515 .56177 Mdot
.9112 .42311 Mdot
.84064 .55977 Mdot
.22289 .6633 Mdot
.22934 .38534 Mdot
.36074 .50748 Mdot
.24602 .66757 Mdot
.87217 .52608 Mdot
.75444 .74037 Mdot
.65148 .33187 Mdot
.52078 .39127 Mdot
.71166 .47983 Mdot
.79181 .65585 Mdot
.4563 .3514 Mdot
.23719 .61043 Mdot
.39211 .44787 Mdot
.69982 .4666 Mdot
.66626 .19197 Mdot
.61888 .79601 Mdot
.4116 .78475 Mdot
.29345 .33341 Mdot
.44767 .52441 Mdot
.79824 .43135 Mdot
.54995 .62776 Mdot
.69964 .38756 Mdot
.33669 .39592 Mdot
.55233 .3602 Mdot
.22515 .48952 Mdot
.50953 .2127 Mdot
.45347 .58033 Mdot
.49692 .47183 Mdot
.61825 .67565 Mdot
.74989 .41817 Mdot
.67437 .56967 Mdot
.7908 .71007 Mdot
.39086 .30835 Mdot
.46342 .56543 Mdot
.31381 .38189 Mdot
.51463 .24443 Mdot
.75111 .71503 Mdot
.70528 .49278 Mdot
.30842 .74825 Mdot
.49274 .4338 Mdot
.31737 .34836 Mdot
.56157 .69807 Mdot
.32238 .61385 Mdot
.36933 .52335 Mdot
.20249 .39306 Mdot
.55741 .77678 Mdot
.53587 .6642 Mdot
.44101 .63358 Mdot
.29661 .60847 Mdot
.24226 .65973 Mdot
.35245 .31398 Mdot
.67912 .32929 Mdot
.30075 .74508 Mdot
.69821 .4909 Mdot
.59003 .68058 Mdot
.43261 .37089 Mdot
.44873 .1936 Mdot
.35358 .75286 Mdot
.6629 .74332 Mdot
.41449 .43265 Mdot
.45316 .29444 Mdot
.30424 .75995 Mdot
.28754 .70871 Mdot
.75702 .30067 Mdot
.63345 .6876 Mdot
.48858 .51451 Mdot
.43161 .19122 Mdot
.58987 .60265 Mdot
.63147 .22824 Mdot
.67449 .26414 Mdot
.58669 .81681 Mdot
.48226 .45513 Mdot
.13903 .53551 Mdot
.3122 .43799 Mdot
.20019 .51307 Mdot
.7401 .68237 Mdot
.47069 .18582 Mdot
.27256 .51672 Mdot
.61282 .70165 Mdot
.43478 .75871 Mdot
.3337 .52661 Mdot
.73718 .29417 Mdot
.77256 .29873 Mdot
.40286 .39214 Mdot
.59531 .49619 Mdot
.15552 .55605 Mdot
.42837 .5829 Mdot
.85162 .50514 Mdot
.5068 .20857 Mdot
.74731 .6946 Mdot
.70527 .47579 Mdot
.35308 .57178 Mdot
.40176 .62601 Mdot
.36995 .77955 Mdot
.74402 .53729 Mdot
.26912 .60556 Mdot
.29419 .25266 Mdot
.1691 .53319 Mdot
.43239 .67111 Mdot
.29571 .5028 Mdot
.22108 .595 Mdot
.40921 .21995 Mdot
.56575 .49691 Mdot
.21502 .44991 Mdot
.27965 .39798 Mdot
.17223 .47385 Mdot
.60408 .45134 Mdot
.50035 .31302 Mdot
.66356 .54505 Mdot
.62075 .3247 Mdot
.69012 .72303 Mdot
.35996 .54795 Mdot
.65964 .77386 Mdot
.24519 .59842 Mdot
.79165 .37894 Mdot
.82527 .51418 Mdot
.83824 .56574 Mdot
.52408 .7792 Mdot
.38887 .24849 Mdot
.44651 .20917 Mdot
.38172 .18202 Mdot
.48054 .41981 Mdot
.24712 .5069 Mdot
.25674 .40416 Mdot
.30289 .75451 Mdot
.63958 .45502 Mdot
.7679 .5648 Mdot
.67976 .53489 Mdot
.29517 .7089 Mdot
.41299 .72379 Mdot
.25092 .62423 Mdot
.58909 .43325 Mdot
.87375 .57078 Mdot
.29233 .30216 Mdot
.55113 .43694 Mdot
.57668 .36059 Mdot
.41713 .24751 Mdot
.22643 .55648 Mdot
.29005 .30595 Mdot
.498 .18674 Mdot
.61287 .35416 Mdot
.57275 .54778 Mdot
.34309 .72426 Mdot
.32551 .3231 Mdot
.19952 .39495 Mdot
.31295 .38069 Mdot
.27439 .71614 Mdot
.40536 .81261 Mdot
.66029 .77172 Mdot
.26668 .4815 Mdot
.19364 .3761 Mdot
.70674 .58106 Mdot
.31903 .31792 Mdot
.50875 .21057 Mdot
.49624 .2831 Mdot
.54259 .65712 Mdot
.66028 .15099 Mdot
.25851 .29649 Mdot
.36648 .2662 Mdot
.6569 .79035 Mdot
.23522 .33944 Mdot
.75205 .42773 Mdot
.38101 .66505 Mdot
.74922 .62949 Mdot
.62327 .77506 Mdot
.38354 .57849 Mdot
.84204 .57461 Mdot
.43838 .45461 Mdot
.84832 .63836 Mdot
.2336 .6324 Mdot
.595 .48723 Mdot
.33285 .58798 Mdot
.52866 .38503 Mdot
.46191 .41083 Mdot
.34703 .48156 Mdot
.36694 .7003 Mdot
.78929 .51359 Mdot
.70051 .52733 Mdot
.50813 .3739 Mdot
.61057 .31405 Mdot
.5525 .67092 Mdot
.25229 .3585 Mdot
.62824 .38308 Mdot
.49609 .37929 Mdot
.48455 .41289 Mdot
.41832 .4483 Mdot
.76452 .50595 Mdot
.39962 .78164 Mdot
.64094 .7291 Mdot
.66802 .62356 Mdot
.52132 .3384 Mdot
.43794 .79178 Mdot
.28526 .28713 Mdot
.16497 .5268 Mdot
.66756 .78621 Mdot
.53125 .51942 Mdot
.38685 .72848 Mdot
.3973 .46379 Mdot
.802 .57686 Mdot
.64842 .64723 Mdot
.69881 .52546 Mdot
.79595 .4366 Mdot
.62411 .60821 Mdot
.61728 .26545 Mdot
.56165 .83043 Mdot
.47697 .19282 Mdot
.42785 .19056 Mdot
.40645 .4035 Mdot
.51242 .57453 Mdot
.47707 .63588 Mdot
.31205 .42709 Mdot
.695 .44359 Mdot
.52062 .14854 Mdot
.43485 .63227 Mdot
.4649 .12077 Mdot
.64858 .45625 Mdot
.48311 .65708 Mdot
.27279 .40262 Mdot
.57147 .4738 Mdot
.60841 .42987 Mdot
.32331 .28579 Mdot
.77489 .56527 Mdot
.39318 .24027 Mdot
.77741 .61089 Mdot
.52128 .38999 Mdot
.24311 .29079 Mdot
.16125 .42789 Mdot
.45372 .76678 Mdot
.44774 .55194 Mdot
.21971 .3269 Mdot
.50182 .36055 Mdot
.62533 .73143 Mdot
.18136 .60531 Mdot
.19848 .43951 Mdot
.33024 .70653 Mdot
.31557 .35436 Mdot
.24922 .50998 Mdot
.40026 .82962 Mdot
.77768 .32384 Mdot
.20778 .53349 Mdot
.64211 .45314 Mdot
.57868 .44161 Mdot
.2567 .54773 Mdot
.79545 .54914 Mdot
.7401 .46373 Mdot
.77952 .5139 Mdot
.39732 .14369 Mdot
.28333 .52142 Mdot
.29589 .52088 Mdot
.80469 .53005 Mdot
.60877 .60783 Mdot
.78477 .54129 Mdot
.77865 .49472 Mdot
.22288 .38023 Mdot
.3327 .25151 Mdot
.77296 .50329 Mdot
.39929 .17045 Mdot
.43086 .64376 Mdot
.65824 .41469 Mdot
.30807 .62211 Mdot
.29409 .5344 Mdot
.66276 .4388 Mdot
.56458 .79838 Mdot
.17403 .55477 Mdot
.69091 .52101 Mdot
.19351 .41541 Mdot
.59364 .2644 Mdot
.30751 .52199 Mdot
.38261 .77868 Mdot
.1839 .49356 Mdot
.41191 .73303 Mdot
.72936 .27538 Mdot
.58868 .73585 Mdot
.49902 .36366 Mdot
.19187 .58323 Mdot
.52421 .35057 Mdot
.2917 .60219 Mdot
.70839 .68246 Mdot
.21882 .44758 Mdot
.76609 .67789 Mdot
.38165 .32591 Mdot
.56343 .61155 Mdot
.77622 .31039 Mdot
.61823 .6624 Mdot
.81611 .61197 Mdot
.51954 .67688 Mdot
.79669 .47334 Mdot
.43693 .25766 Mdot
.42108 .27998 Mdot
.38786 .15593 Mdot
.73473 .44696 Mdot
.53874 .40397 Mdot
.71169 .27603 Mdot
.55983 .61674 Mdot
.40056 .4036 Mdot
.58393 .36096 Mdot
.47458 .38497 Mdot
.66977 .27382 Mdot
.44925 .63873 Mdot
.6316 .64684 Mdot
.47055 .37776 Mdot
.50492 .82386 Mdot
.50125 .84699 Mdot
.55978 .3366 Mdot
.52798 .13492 Mdot
.33133 .56331 Mdot
.47657 .7707 Mdot
.25973 .69493 Mdot
.65892 .18685 Mdot
.5794 .41311 Mdot
.15013 .47252 Mdot
.44941 .60406 Mdot
.20237 .46547 Mdot
.56226 .63979 Mdot
.491 .19807 Mdot
.39975 .37164 Mdot
.30551 .36326 Mdot
.64491 .4928 Mdot
.66341 .72123 Mdot
.6014 .40724 Mdot
.58363 .60386 Mdot
.22379 .38885 Mdot
.42599 .47755 Mdot
.61667 .48013 Mdot
.46135 .23691 Mdot
.44972 .77021 Mdot
.29719 .68602 Mdot
.41462 .65582 Mdot
.31055 .50302 Mdot
.37522 .20103 Mdot
.79743 .70635 Mdot
.63745 .70383 Mdot
.63467 .59999 Mdot
.72001 .3039 Mdot
.19001 .45513 Mdot
.76811 .36627 Mdot
.27856 .73762 Mdot
.44605 .46781 Mdot
.53952 .55719 Mdot
.46619 .49654 Mdot
.30714 .56276 Mdot
.55031 .46949 Mdot
.68497 .35921 Mdot
.80966 .50432 Mdot
.75826 .50132 Mdot
.40882 .68254 Mdot
.75695 .32785 Mdot
.34686 .47188 Mdot
.79364 .48399 Mdot
.4909 .35362 Mdot
.30283 .69306 Mdot
.63988 .56388 Mdot
.50538 .84932 Mdot
.27206 .72286 Mdot
.71493 .48388 Mdot
.56672 .27314 Mdot
.14847 .56821 Mdot
.44732 .62065 Mdot
.58416 .54052 Mdot
.41427 .54006 Mdot
.5165 .51134 Mdot
.61444 .16083 Mdot
.19772 .42414 Mdot
.41295 .50896 Mdot
.30418 .73372 Mdot
.34087 .77204 Mdot
.86483 .59815 Mdot
.48469 .16841 Mdot
.59477 .64741 Mdot
.83678 .61592 Mdot
.78461 .5096 Mdot
.38356 .81795 Mdot
.73281 .39982 Mdot
.33087 .81107 Mdot
.43916 .75702 Mdot
.17726 .47677 Mdot
.38588 .65898 Mdot
.75858 .6003 Mdot
.48147 .22289 Mdot
.58218 .53265 Mdot
.69866 .323 Mdot
.29508 .29296 Mdot
.23566 .28765 Mdot
.32993 .52225 Mdot
.52594 .22929 Mdot
.67515 .64309 Mdot
.1952 .60523 Mdot
.356 .28446 Mdot
.42548 .5207 Mdot
.65098 .55231 Mdot
.73064 .699 Mdot
.42713 .45591 Mdot
.6229 .59154 Mdot
.36669 .28048 Mdot
.61746 .76502 Mdot
.38567 .46679 Mdot
.43853 .19007 Mdot
.444 .76639 Mdot
.4799 .42706 Mdot
.3662 .59949 Mdot
.62268 .68748 Mdot
.36594 .37722 Mdot
.56452 .51996 Mdot
.44519 .55608 Mdot
.58735 .33602 Mdot
.73848 .48002 Mdot
.8041 .61586 Mdot
.70064 .54977 Mdot
.42756 .20202 Mdot
.43805 .64991 Mdot
.70835 .64671 Mdot
.7616 .35473 Mdot
.82808 .57239 Mdot
.43197 .31466 Mdot
.41356 .44954 Mdot
.26122 .65064 Mdot
.41071 .81763 Mdot
.49617 .6369 Mdot
.79576 .69991 Mdot
.68083 .4509 Mdot
.27879 .6163 Mdot
.72929 .62142 Mdot
.5791 .40497 Mdot
.36636 .63371 Mdot
.17912 .4735 Mdot
.32466 .35548 Mdot
.30422 .47767 Mdot
.36024 .24891 Mdot
.53895 .54548 Mdot
.38773 .76391 Mdot
.30653 .74238 Mdot
.56116 .39286 Mdot
.38491 .2082 Mdot
.61167 .49401 Mdot
.38155 .28179 Mdot
.41226 .82059 Mdot
.62434 .79891 Mdot
.61578 .42212 Mdot
.28645 .38682 Mdot
.40733 .5585 Mdot
.41156 .18594 Mdot
.19743 .41972 Mdot
.30497 .52803 Mdot
.66194 .31406 Mdot
.59487 .68032 Mdot
.65324 .36647 Mdot
.50152 .45321 Mdot
.60901 .77564 Mdot
.60242 .68604 Mdot
.79797 .44478 Mdot
.36863 .37299 Mdot
.59054 .50298 Mdot
.48085 .61895 Mdot
.29536 .38659 Mdot
.48525 .1537 Mdot
.45923 .62685 Mdot
.205 .55214 Mdot
.44659 .78394 Mdot
.53617 .21612 Mdot
.19323 .47522 Mdot
.75285 .44625 Mdot
.77414 .5687 Mdot
.32837 .72777 Mdot
.6898 .53599 Mdot
.3675 .53139 Mdot
.508 .38149 Mdot
.59388 .61121 Mdot
.18902 .59609 Mdot
.52043 .78439 Mdot
.30775 .4197 Mdot
.42312 .42 Mdot
.61322 .58997 Mdot
.62127 .52656 Mdot
.30059 .78194 Mdot
.77125 .57798 Mdot
.36283 .41659 Mdot
.48387 .4568 Mdot
.2792 .40355 Mdot
.47661 .67868 Mdot
.61119 .81885 Mdot
.3861 .66509 Mdot
.51397 .43174 Mdot
.49082 .65308 Mdot
.3689 .25528 Mdot
.17689 .60224 Mdot
.47308 .50917 Mdot
.58947 .46354 Mdot
.35204 .32915 Mdot
.76755 .38946 Mdot
.41229 .41071 Mdot
.60498 .56887 Mdot
.47239 .35405 Mdot
.65989 .28704 Mdot
.69173 .67377 Mdot
.45505 .50933 Mdot
.27486 .48338 Mdot
.27184 .68168 Mdot
.5389 .20993 Mdot
.6576 .52534 Mdot
.67632 .40074 Mdot
.56779 .79153 Mdot
.36423 .83834 Mdot
.81636 .42347 Mdot
.41162 .56076 Mdot
.63704 .53048 Mdot
.28179 .37283 Mdot
.5782 .38 Mdot
.77318 .48187 Mdot
.77477 .427 Mdot
.66066 .44913 Mdot
.32039 .34942 Mdot
.32393 .47319 Mdot
.57058 .26555 Mdot
.26941 .35948 Mdot
.6495 .57475 Mdot
.81777 .59496 Mdot
.23482 .3251 Mdot
.19001 .45822 Mdot
.50029 .8908 Mdot
.62408 .49927 Mdot
.35023 .50101 Mdot
.41397 .70942 Mdot
.45262 .83916 Mdot
.31802 .3909 Mdot
.63937 .73841 Mdot
.73485 .36122 Mdot
.47966 .51707 Mdot
.64574 .6952 Mdot
.29026 .48198 Mdot
.65001 .36029 Mdot
.55367 .45477 Mdot
.42329 .28511 Mdot
.80589 .69362 Mdot
.36135 .73494 Mdot
.26433 .67262 Mdot
.74329 .68439 Mdot
.38311 .17937 Mdot
.44477 .8387 Mdot
.30225 .45304 Mdot
.33074 .2942 Mdot
.35839 .6755 Mdot
.62254 .43204 Mdot
.46204 .66383 Mdot
.63109 .73288 Mdot
.45509 .81018 Mdot
.47667 .25622 Mdot
.47436 .66873 Mdot
.42716 .47041 Mdot
.48957 .8154 Mdot
.5905 .46178 Mdot
.41028 .78808 Mdot
.58889 .28913 Mdot
.79917 .52299 Mdot
.52691 .61323 Mdot
.33334 .41898 Mdot
.44925 .79016 Mdot
.70043 .28826 Mdot
.26926 .31186 Mdot
.33234 .1986 Mdot
.46578 .33381 Mdot
.80737 .59509 Mdot
.45965 .57424 Mdot
.89964 .54527 Mdot
.42613 .22822 Mdot
.47943 .22754 Mdot
.36487 .24064 Mdot
.54513 .30528 Mdot
.29729 .59538 Mdot
.36685 .5317 Mdot
.22158 .55824 Mdot
.33393 .70928 Mdot
.52455 .69731 Mdot
.68294 .71315 Mdot
.31073 .35172 Mdot
.38987 .44451 Mdot
.31159 .43203 Mdot
.54941 .57565 Mdot
.59236 .6768 Mdot
.83553 .59743 Mdot
.59979 .42205 Mdot
.31332 .51984 Mdot
.50735 .59588 Mdot
.37063 .67672 Mdot
.13985 .60408 Mdot
.59755 .48725 Mdot
.30776 .51032 Mdot
.40761 .76651 Mdot
.50736 .63146 Mdot
.77291 .3738 Mdot
.72309 .80705 Mdot
.91614 .53653 Mdot
.5761 .60415 Mdot
.56053 .20256 Mdot
.39531 .76252 Mdot
.27135 .64091 Mdot
.44114 .31437 Mdot
.65069 .29941 Mdot
.28171 .5824 Mdot
.63443 .71251 Mdot
.41484 .64128 Mdot
.43073 .22241 Mdot
.53095 .85077 Mdot
.67019 .71566 Mdot
.30094 .72847 Mdot
.3173 .55197 Mdot
.43379 .63833 Mdot
.47661 .89317 Mdot
.25934 .55372 Mdot
.34441 .6067 Mdot
.42333 .6727 Mdot
.47779 .55826 Mdot
.37043 .56056 Mdot
.20353 .49051 Mdot
.24953 .2869 Mdot
.38099 .46667 Mdot
.2927 .70407 Mdot
.58893 .6904 Mdot
.58838 .3201 Mdot
.6459 .458 Mdot
.62168 .42269 Mdot
.37855 .62621 Mdot
.68163 .45702 Mdot
.5029 .51386 Mdot
.15212 .55782 Mdot
.43611 .41523 Mdot
.32074 .23626 Mdot
.39312 .83927 Mdot
.50225 .78773 Mdot
.76755 .44675 Mdot
.44929 .6188 Mdot
.29945 .69237 Mdot
.43015 .81452 Mdot
.58962 .56549 Mdot
.1808 .42233 Mdot
.78263 .2566 Mdot
.76229 .40132 Mdot
.60113 .78797 Mdot
.58393 .59572 Mdot
.45945 .38864 Mdot
.36509 .74898 Mdot
.735 .40724 Mdot
.56693 .34921 Mdot
.317 .57056 Mdot
.6173 .61247 Mdot
.69078 .45523 Mdot
.5375 .12905 Mdot
.44945 .55533 Mdot
.7785 .44689 Mdot
.35723 .79448 Mdot
.59055 .73602 Mdot
.4643 .74434 Mdot
.34902 .59443 Mdot
.69252 .61636 Mdot
.58864 .46458 Mdot
.1976 .55376 Mdot
.64417 .77905 Mdot
.26303 .62781 Mdot
.51748 .78654 Mdot
.38907 .76354 Mdot
.36698 .59865 Mdot
.42123 .35641 Mdot
.72116 .43932 Mdot
.21487 .53676 Mdot
.47938 .58274 Mdot
.44698 .84704 Mdot
.60831 .40422 Mdot
.49159 .4738 Mdot
.60619 .52362 Mdot
.85763 .60384 Mdot
.42469 .69492 Mdot
.44512 .65075 Mdot
.82632 .57697 Mdot
.60652 .39699 Mdot
.30216 .33087 Mdot
.54292 .39223 Mdot
.47294 .60098 Mdot
.62242 .67797 Mdot
.85541 .50244 Mdot
.22193 .51292 Mdot
.70575 .32567 Mdot
.66797 .32831 Mdot
.58284 .22836 Mdot
.61482 .4794 Mdot
.52162 .89246 Mdot
.43299 .24317 Mdot
.85105 .53538 Mdot
.37527 .20379 Mdot
.62665 .6295 Mdot
.23097 .34705 Mdot
.40869 .63591 Mdot
.56191 .3481 Mdot
.27212 .6614 Mdot
.32544 .51464 Mdot
.68767 .7422 Mdot
.40186 .61676 Mdot
.76322 .69357 Mdot
.34313 .35117 Mdot
.53229 .25891 Mdot
.38377 .25243 Mdot
.38301 .68561 Mdot
.24099 .68862 Mdot
.75849 .36158 Mdot
.25108 .69366 Mdot
.22661 .65107 Mdot
.32317 .76645 Mdot
.68993 .733 Mdot
.74152 .26585 Mdot
.37316 .2582 Mdot
.18261 .49174 Mdot
.69352 .38073 Mdot
.35164 .65609 Mdot
.41527 .24824 Mdot
.59804 .58791 Mdot
.7407 .53943 Mdot
.64142 .55529 Mdot
.47808 .07518 Mdot
.35535 .44313 Mdot
.49176 .62406 Mdot
.41212 .25864 Mdot
.37378 .80229 Mdot
.36866 .68128 Mdot
.30667 .28603 Mdot
.51526 .46233 Mdot
.38293 .49712 Mdot
.45851 .80941 Mdot
.5382 .20522 Mdot
.51833 .24061 Mdot
.30364 .19743 Mdot
.28198 .2904 Mdot
.68132 .30426 Mdot
.53995 .46328 Mdot
.57321 .60515 Mdot
.71613 .26739 Mdot
.42976 .28078 Mdot
.18564 .40305 Mdot
.15959 .51501 Mdot
.25773 .55007 Mdot
.39699 .15468 Mdot
.51618 .20924 Mdot
.48324 .84502 Mdot
.21897 .36882 Mdot
.57465 .60304 Mdot
.29099 .44626 Mdot
.49551 .35431 Mdot
.69604 .34302 Mdot
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00D_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46oooo
o`;o000000?o410@ooooooooool0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0=Oooool4o`000003oa0@4?oooooooooo00;o
oooo001Booooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00/ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool0:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmg
MgOooooooiRHV?lQ8B40;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B40=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h0;Oooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol0000/ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000002cooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool00000=oooool00ol0003oooooooooo`04ooooo`00D_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo0000;Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@0/ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So
<S8b03Oooooo00?o0000ooooooooool01?ooool005;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ogMgMomVIVKooooo02_ooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmE
EEGoooooo`0002gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@
4?o<c<`0;?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<
c00gooooo`03o`000?oooooooooo00Cooooo001Booooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Zooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<
o`00000]ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0^ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Oooooo00?o0000
ooooooooool01?ooool005;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@4100;?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000
;Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000gooooo`03o`000?oooooo
oooo00Cooooo001Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<02cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0=Oooool00omEEEGoIVIVo`00
0006ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`007?ooooooo`0004Oo00001_ooool001cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo000Looooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`;o0000oooooom;oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo09Sooooo0_l0002_ooooo`007?ooool00ol0003oooooooooo`2Hooooo`;o0000[oooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`2/ooooo`;o0000Voooool001cooooo00?o0000oooo
ooooool0[?ooool2o`0009_ooooo000Looooo`;o0000oooooom;ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0;gooooo0_l0002:ooooo`007?ooool00ol0003oooooooooo`2iooooo`;o0000
0_ooool2o`0008[ooooo000Looooo`03o`000?oooooooooo09?ooooo0_l0000Tooooo`;o0000S_oo
ool001cooooo00?o0000ooooooooool0Toooool2o`0000_ooooo0_l0002Wooooo`007?ooool00ol0
003oooooooooo`2Pooooo`;o00002Oooool2o`0000gooooo0_l0002=ooooo`007?ooool00ol0003o
ooooooooo`2Looooo`;o00003Oooool2o`0000Wooooo0_l00002ooooo`;o0000SOooool001cooooo
00?o0000ooooooooool0W?ooool2o`0000[ooooo0_l0000<ooooo`;o0000TOooool001cooooo00?o
0000ooooooooool0Z?ooool2o`0001cooooo0_l00002ooooo`;o0000OOooool001cooooo00?o0000
ooooooooool0ROooool2o`0003_ooooo0_l00002ooooo`;o0000OOooool001cooooo00?o0000oooo
ooooool0OOooool2o`0000[ooooo0_l0000;ooooo`;o0000/Oooool001cooooo00?o0000oooooooo
ool0OOooool2o`0001Oooooo0_l0002aooooo`007?ooool00ol0003oooooooooo`2Cooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Oooooo0_l0002Rooooo`007?ooool2o`0009Cooooo0_l0
0005ooooo`Co00001oooool2o`0002cooooo0_l0001dooooo`007?ooool00ol0003oooooooooo`1[
ooooo`;o00003Oooool2o`000004ooooool0003o0000ooooo`;o00006?ooool2o`0003Oooooo0_l0
001dooooo`007?ooool00ol0003oooooooooo`1[ooooo`;o00003Oooool2o`000004ooooool0003o
0000ooooo`;o00008?ooool2o`000003ooooool0003o00000:;ooooo000Looooo`03o`000?oooooo
oooo0:;ooooo0_l000000ooooooo0000o`00000Aooooo`;o00002_ooool2o`0000Kooooo0_l0001k
ooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o00002oooool2o`0000cooooo0_l00005oooo
o`;o00002_ooool2o`0000Kooooo0_l0001kooooo`007?ooool00ol0003oooooooooo`2Fooooo`;o
00000_ooool2o`0000;ooooo0_l00003ooooo`;o00003?ooool2o`0000?ooooo0_l0000Dooooo`;o
0000Noooool001cooooo00?o0000ooooooooool0N?ooool2o`0000Cooooo0_l0000Jooooo`;o0000
0_ooool2o`0000Oooooo0_l00005ooooo`;o00001_ooool2o`0001Cooooo0_l0001kooooo`007?oo
ool00ol0003oooooooooo`1hooooo`;o00001?ooool2o`00023ooooo0_l00002ooooo`;o000000?o
ooooo`000?l000001Oooool2o`0000Cooooo0_l0002Cooooo`007?ooool00ol0003oooooooooo`2P
ooooo`;o00000_ooool2o`0000Oooooo0_l00005ooooo`;o0000Toooool001cooooo00?o0000oooo
ooooool0NOooool2o`0000?ooooo0_l0000Iooooo`;o00000oooool2o`0000gooooo0_l0000:oooo
o`;o0000S_ooool001cooooo00?o0000ooooooooool0N?ooool3o`0000?ooooo0_l00006ooooo`;o
00004Oooool2o`0000?ooooo0_l00002ooooo`;o00005Oooool2o`0008kooooo000Looooo`03o`00
0?oooooooooo07Sooooo0_l00005ooooo`;o000000?oooooo`000?l000001?l00009ooooo`;o0000
0_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo0_l0000Looooo`;o0000
4?ooool2o`0007Gooooo000Looooo`03o`000?oooooooooo07oooooo1ol000000ooooooo0000o`00
0002ooooo`;o00001?ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000;ooooo0_l0
0002ooooo`;o00003Oooool2o`0000Oooooo0_l00004ooooo`?o00003oooool2o`0007Gooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooo
ooooo`1Nooooo`;o00008?ooool2o`0000Gooooo0ol000001?oooooo0000o`000?ooool2o`0000Co
oooo0_l000000ooooooo0000o`00000Fooooo`Co00001oooool2o`0000Gooooo0_l0000Booooo`;o
0000L_ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo05kooooo0_l0000Xooooo`;o00001?ooool4
o`0000;ooooo0_l000000ooooooo0000o`00000Cooooo`;o000000?oooooo`000?l000002_ooool2
o`0001Sooooo0_l0001booooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0Goooool2o`0000Oooooo0_l0000Roooo
o`;o00000_ooool2o`0000Gooooo0_l00003ooooo`;o00003_ooool2o`0000Oooooo0_l00004oooo
o`;o00002?ooool2o`0008;ooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00_o
oooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0005oooooo0_l00007ooooo`;o00003?ooool2o`0000oo
oooo0_l00003ooooo`;o00001Oooool3o`0000Kooooo0_l00003ooooo`;o00001oooool2o`0000Ko
oooo0_l000000ooooooo0000o`00000>ooooo`;o0000P_ooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool03?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo07Kooooo
0_l00003ooooo`;o00002_ooool2o`0000[ooooo0ol0000;ooooo`;o00001oooool3o`0000Cooooo
0ol0002Eooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0J_ooool2o`000003ooooool0003o000000Gooooo1?l0
00000ooooooo0000o`000002o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0001;ooooo0_l0
00000ooooooo0000o`000005ooooo`;o000000?oooooo`000?l000000ol0002Fooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003o
ooooooooo`1Zooooo`;o000000?oooooo`000?l000001Oooool2o`0000?ooooo0_l00007ooooo`;o
00001?ooool2o`0000?ooooo0_l0000Booooo`;o000000?oooooo`000?l000001Oooool2o`000003
ooooool0003o000000;o000000?oooooo`000?l000006Oooool2o`0007Wooooo00001_ooooook^k^
oc8b<_l0003o<S8bonk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooo
oooo06Sooooo0_l0000@ooooo`;o00001oooool2o`0001Oooooo0_l00003ooooo`?o00001oooool2
o`0000Kooooo0_l00006ooooo`Co00001?ooool3o`0000Kooooo1?l0001iooooo`007?ooool00ol0
003oooooooooo`1Wooooo`?o00004?ooool2o`0000Gooooo1?l00002ooooo`;o00004oooool2o`00
00;ooooo1?l00006ooooo`?o00000oooool2o`0000Sooooo1Ol000001?oooooo0000o`000?ooool3
o`0000Gooooo0ol00003ooooo`;o00004Oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo
06Oooooo0_l0000<ooooo`;o00002_ooool2o`0000Cooooo0_l00008ooooo`;o00003Oooool4o`00
00?ooooo0_l000000ooooooo0000o`000003o`000003ooooool0003o000000Sooooo0_l00004oooo
o`;o00001oooool4o`0000;ooooo1?l00003ooooo`;o00002?ooool2o`0000;ooooo0_l0000@oooo
o`;o0000DOooool001cooooo00?o0000ooooooooool0M?ooool3o`0000[ooooo0_l00005ooooo`;o
000000?oooooo`000?l000000_ooool4o`0000Kooooo0_l00006ooooo`?o00000_ooool3o`0000Co
oooo0_l00004ooooo`;o00005?ooool2o`0000Cooooo0_l00005ooooo`;o00002?ooool2o`0001Co
oooo0_l0001Aooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00001oooool3o`0000?ooooo
1?l0000@ooooo`;o000000?oooooo`000?l000000_ooool2o`0000Oooooo0ol00007ooooo`;o0000
0_ooool3o`0000[ooooo0_l0002Dooooo`007?ooool00ol0003oooooooooo`1Uooooo`;o00001ooo
ool3o`0000Gooooo0ol0000<ooooo`Co00000_ooool3o`000003ooooool0003o000000;ooooo0_l0
00000ooooooo0000o`000002o`0000Kooooo0_l00005ooooo`;o000000?oooooo`000?l000003?oo
ool4o`0000;ooooo0_l00009ooooo`;o00000_ooool2o`0007[ooooo000Looooo`03o`000?oooooo
oooo06[ooooo0_l0000;ooooo`;o00003?ooool4o`0000;ooooo0ol000000ooooooo0000o`000002
ooooo`;o000000?oooooo`000?l000002?ooool5o`0000;ooooo0_l000001?oooooo0000o`000?oo
ool2o`0000Wooooo1?l00002ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o00001ooo
ool2o`0006gooooo000Looooo`03o`000?oooooooooo06Cooooo0_l00004ooooo`;o00007?ooool2
o`0000Gooooo0_l000000ooooooo0000o`00000;ooooo`Ko00002?ooool3o`00027ooooo0_l00003
ooooo`;o00000_ooool2o`0000[ooooo0_l0001Qooooo`007?ooool00ol0003oooooooooo`1Toooo
o`;o00002Oooool2o`0000?ooooo0_l0000@ooooo`Co00000_ooool2o`0000Cooooo0_l00004oooo
o`Co000000?oooooo`000?l000001?l0000;ooooo`;o00003oooool2o`0001Gooooo0_l0000>oooo
o`;o0000HOooool001cooooo00?o0000ooooooooool0Koooool2o`0000;ooooo0ol00006ooooo`Co
000000?oooooo`000?l000000oooool2o`000004ooooool0003o0000ooooo`;o00002_ooool4o`00
0003ooooool0003o000000;ooooo0_l000001?oooooo0000o`000?l0000Hooooo`;o00009_ooool2
o`00063ooooo000Looooo`03o`000?oooooooooo07?ooooo1?l00002ooooo`;o000000?oooooo`00
0?l000000_l000000ooooooo0000o`000006ooooo`;o00003Oooool2o`0000?ooooo0_l00004oooo
o`Co00001Oooool2o`0000?ooooo0_l0000:ooooo`?o00005oooool2o`0000Wooooo0_l00003oooo
o`;o0000H?ooool001cooooo00?o0000ooooooooool0LOooool2o`0000;ooooo0_l00002ooooo`Co
00001_ooool3o`0001;ooooo0_l00009ooooo`;o00001?ooool5o`0000;ooooo0ol0000:ooooo`?o
00005oooool2o`0000Wooooo0_l0001Uooooo`007?ooool2o`0006Oooooo1?l00007ooooo`;o0000
0_ooool2o`0000Cooooo0_l00006ooooo`?o00001oooool2o`0001[ooooo0ol00004ooooo`;o0000
7_ooool3o`0007Kooooo000Looooo`03o`000?oooooooooo05Sooooo0_l00002ooooo`;o00000ooo
ool4o`000003ooooool0003o000000;o00002_ooool2o`0000;ooooo0ol0000Booooo`Co00001ooo
ool2o`0000kooooo0_l0000Hooooo`;o00002Oooool2o`000005ooooool0003o0000o`000?ooool0
0_l0001cooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00000_ooool2o`0000?ooooo1?l0
000?ooooo`?o000000Coooooo`000?l0003o00000oooool3o`0000?ooooo0_l00004ooooo`;o0000
0oooool4o`0000Cooooo0ol0000;ooooo`;o000000?oooooo`000?l000000oooool2o`00013ooooo
0_l000000ooooooo0000o`000009ooooo`;o00000oooool4o`0000oooooo0_l0000Cooooo`;o0000
COooool001cooooo00?o0000ooooooooool0F?ooool2o`0001_ooooo1?l00005ooooo`?o000000?o
ooooo`000?l000000_l00004ooooo`;o00000_ooool5o`0000Cooooo0ol00008ooooo`;o000000?o
ooooo`000?l000000_ooool2o`0000;ooooo0_l0000@ooooo`;o00000_ooool3o`0000?ooooo1?l0
0005ooooo`Co00000oooool2o`0000?ooooo0_l00005ooooo`;o00004oooool2o`0004gooooo000L
ooooo`03o`000?oooooooooo07Oooooo0_l00006ooooo`;o000000?oooooo`000?l000002_ooool4
o`00013ooooo0_l00005ooooo`?o00001_ooool2o`0000Wooooo0_l00004ooooo`?o000000?ooooo
o`000?l000001?l0000:ooooo`Co00000oooool2o`0000;ooooo0_l00003ooooo`;o0000H?ooool0
01cooooo00?o0000ooooooooool0G?ooool2o`0001Gooooo0_l0000:ooooo`;o0000:Oooool2o`00
0003ooooool0003o000000?ooooo0_l00002ooooo`;o00001?ooool3o`0000Kooooo1Ol0000:oooo
o`;o000000Coooooo`000?l0003o00002?ooool2o`000003ooooool0003o000000;o00001?ooool2
o`0005[ooooo000Looooo`03o`000?oooooooooo05cooooo0_l0000Eooooo`;o00002_ooool2o`00
01;ooooo0_l0000@ooooo`;o00001_ooool2o`0000Oooooo0_l00004ooooo`;o000000?oooooo`00
0?l000001?ooool2o`0000gooooo0_l00002ooooo`?o00002_ooool2o`0000Kooooo0_l0001Joooo
o`007?ooool00ol0003oooooooooo`1Xooooo`;o0000:Oooool2o`0000Gooooo0_l00006ooooo`;o
000000?oooooo`000?l000003Oooool2o`0000Wooooo0_l00003ooooo`;o00004?ooool2o`000003
ooooool0003o000001Gooooo0_l0001Gooooo`007?ooool00ol0003oooooooooo`1Fooooo`;o0000
00?oooooo`000?l000001?ooool2o`0000Kooooo1Ol0000Cooooo`;o00006Oooool2o`0000Kooooo
0_l0000<ooooo`;o00000_ooool2o`0000Cooooo0_l00008ooooo`;o00004?ooool2o`0000_ooooo
0_l00004ooooo`;o00001Oooool2o`0005Oooooo000Looooo`03o`000?oooooooooo05Kooooo0_l0
00000ooooooo0000o`000003ooooo`?o00001_ooool2o`000003ooooool0003o000000;ooooo0_l0
0006ooooo`;o00001oooool2o`0000;ooooo1?l0000Yooooo`;o00002?ooool2o`0002Oooooo0_l0
0004ooooo`;o00002_ooool2o`0005;ooooo000Looooo`03o`000?oooooooooo05kooooo0ol0000=
ooooo`;o00000oooool2o`000003ooooool0003o000000;o00000oooool2o`0000Cooooo1?l00000
0ooooooo0000o`000005ooooo`;o00003?ooool2o`0000Kooooo0_l00009ooooo`;o00001Oooool2
o`0000Sooooo0_l00008ooooo`;o00007oooool2o`0000Oooooo0_l0001Booooo`007?ooool00ol0
003oooooooooo`1Gooooo`;o00001oooool8o`0000Sooooo1Ol00003ooooo`;o00000oooool2o`00
00Oooooo1?l00005ooooo`;o00003?ooool2o`0000Kooooo0_l00007ooooo`Co00001Oooool2o`00
00Gooooo0_l000000ooooooo0000o`000008ooooo`;o00007oooool2o`0005_ooooo000Looooo`03
o`000?oooooooooo04Wooooo0_l00002ooooo`;o00002?ooool4o`0000Gooooo2?l00008ooooo`Co
00004_ooool2o`0001gooooo0_l00007ooooo`;o00003?ooool4o`0001?ooooo0_l0000;ooooo`;o
000000?oooooo`000?l000001_ooool2o`0005cooooo000Looooo`03o`000?oooooooooo04Wooooo
1_l00009ooooo`Co00007oooool2o`0002?ooooo0_l00003ooooo`;o00001Oooool2o`0000gooooo
0ol0000Eooooo`;o00002oooool2o`000003ooooool0003o000000Kooooo0_l0001Looooo`007?oo
ool00ol0003oooooooooo`1;ooooo`;o00002oooool6o`0000[ooooo0_l0000Aooooo`;o00004_oo
ool2o`0000[ooooo0_l00003ooooo`;o00002_ooool2o`0000gooooo0_l0000Vooooo`;o00001Ooo
ool4o`0005_ooooo000Looooo`03o`000?oooooooooo04gooooo0_l000000ooooooo0000o`00000:
ooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`;o00006oooool2o`0000[ooooo0_l0000<
ooooo`Co0000:?ooool2o`0001?ooooo1?l0001Kooooo`007?ooool2o`0004Sooooo0_l00004oooo
o`;o000000?oooooo`000?l000004?ooool2o`0000_ooooo0_l000000ooooooo0000o`00000;oooo
o`;o00003?ooool2o`0000gooooo0_l00003ooooo`;o00001_ooool4o`0000Gooooo0_l00003oooo
o`;o00003oooool2o`0000Kooooo0_l00003ooooo`;o00006oooool2o`0000?ooooo0_l0001@oooo
o`007?ooool00ol0003oooooooooo`13ooooo`;o00000_ooool2o`0000Gooooo1_l00007ooooo`;o
00004_ooool2o`0000kooooo0_l0000<ooooo`;o00003Oooool2o`0000?ooooo0_l00007ooooo`Go
00000_ooool5o`000003ooooool0003o000000cooooo0_l000001?oooooo0000o`000?ooool2o`00
00?ooooo0_l00008ooooo`;o00001oooool2o`000003ooooool0003o000000Oooooo1Ol00003oooo
o`;o0000D?ooool001cooooo00?o0000ooooooooool0@oooool2o`0000Kooooo0_l000000ooooooo
0000o`000006o`0000Cooooo1?l0000Rooooo`?o00001_ooool2o`00017ooooo1?l00003ooooo`;o
00001Oooool5o`0000;ooooo0_l000001?oooooo0000o`000?l0000>ooooo`;o000000Coooooo`00
0?l0003ooooo0_l00005ooooo`?o00001Oooool2o`0000;ooooo0_l00003ooooo`;o000000?ooooo
o`000?l000001?ooool2o`000004ooooool0003o0000o`0000Wooooo0_l0001<ooooo`007?ooool0
0ol0003oooooooooo`1;ooooo`;o00001Oooool5o`0000?ooooo1?l0000?ooooo`;o00003?ooool2
o`0000?ooooo0ol00006ooooo`;o00003_ooool2o`0000?ooooo0_l00003ooooo`Co00000oooool2
o`000003ooooool0003o000000Kooooo0_l0000=ooooo`;o00003?ooool3o`0000Kooooo0_l00000
0ooooooo0000o`00000<ooooo`;o00000oooool2o`0000Gooooo0_l000000ooooooo0000o`00001<
ooooo`007?ooool00ol0003oooooooooo`1Booooo`Go00001?ooool2o`0000Oooooo0_l00006oooo
o`Go00000oooool2o`0000Gooooo0_l00003ooooo`;o00005oooool2o`0000Cooooo0_l00004oooo
o`;o00002?ooool2o`0000;ooooo0_l0000?ooooo`;o00005Oooool2o`0001Cooooo0ol00002oooo
o`Co0000Coooool001cooooo00?o0000ooooooooool0E?ooool2o`0000Gooooo0_l00003ooooo`;o
00000_ooool2o`0000Kooooo1Ol00003ooooo`;o00001Oooool2o`0000?ooooo0_l00007ooooo`;o
000000?oooooo`000?l000002oooool2o`0000Cooooo0_l00004ooooo`Oo000000?oooooo`000?l0
00001_l0000>ooooo`;o00001_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l0
00006_ooool2o`0000;ooooo1?l0001?ooooo`007?ooool00ol0003oooooooooo`0oooooo`;o0000
7_ooool3o`0000;ooooo0_l000000ooooooo0000o`000003ooooo`?o00000oooool2o`000003oooo
ool0003o000000Go00001?ooool2o`0000Oooooo0_l000001?oooooo0000o`000?ooool2o`0000So
oooo0_l00008oooooa3o00002?ooool2o`0000Kooooo0_l00006ooooo`;o00000_ooool2o`0000;o
oooo0_l000000ooooooo0000o`000003ooooo`;o00004Oooool2o`0005Wooooo000Looooo`03o`00
0?oooooooooo03oooooo0_l0000;ooooo`;o00003?ooool2o`0000;ooooo0ol00003ooooo`Go0000
0oooool3o`0000?ooooo0_l000000ooooooo0000o`000006o`0000;ooooo0_l00003ooooo`;o0000
2Oooool2o`0001;ooooo4Ol00007ooooo`;o000000?oooooo`000?l000000_ooool3o`0000Kooooo
1?l00009ooooo`;o000000?oooooo`000?l000000_ooool2o`000003ooooool0003o000000Sooooo
1?l0001Iooooo`007?ooool00ol0003oooooooooo`19ooooo`;o000000Coooooo`000?l0003o0000
1Oooool2o`0000Cooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00001?ooool2o`0000Co
oooo0_l000000ooooooo0000o`000006o`0000;ooooo0ol00002ooooo`;o00007OoooolAo`0000[o
oooo0ol000000ooooooo0000o`000002ooooo`;o00000oooool4o`0000Wooooo0_l00003ooooo`So
00001oooool3o`0000[ooooo0_l00004ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0
A?ooool2o`000003ooooool0003o000000;o000000?oooooo`000?l000000ol00003ooooo`;o0000
1oooool2o`0000Kooooo1?l00004oooooaGo00001?ooool2o`0000kooooo0_l00009oooooa?o0000
00?oooooo`000?l000002?ooool2o`0000Gooooo0_l0000:ooooo`;o000000?oooooo`000?l00000
0_ooool6o`000003ooooool0003o000000Co00001oooool2o`0000?ooooo0_l00005ooooo`;o0000
1?ooool2o`0004Sooooo000Looooo`03o`000?oooooooooo04Cooooo0_l000001?oooooo0000o`00
0?l00002ooooo`Go00003Oooool2o`0000Gooooo1?l00004oooooa?o00001?ooool4o`0000Kooooo
0_l00006ooooo`;o00002OoooolHo`0000Wooooo0_l0000<ooooo`Co000000?oooooo`000?l00000
0_ooool4o`0000Oooooo1?l00006ooooo`;o00000_ooool2o`0005Gooooo000Looooo`03o`000?oo
oooooooo04Sooooo0_l0000Booooo`Ko000000Coooooo`000?l0003ooooo0_l00006oooooago0000
0oooool2o`0000Cooooo0_l00007oooooaco00001Oooool2o`0000;ooooo0ol00008ooooo`;o0000
00?oooooo`000?l000000oooool2o`0000oooooo0_l00006ooooo`;o0000FOooool001cooooo00?o
0000ooooooooool0?Oooool4o`0001_ooooo0_l00002ooooo`;o000000Coooooo`000?l0003ooooo
0_l00006oooooaKo00000oooool4o`0000;ooooo0_l00005ooooo`;o00001ooooolMo`000004oooo
ool0003o0000ooooo`;o00000_ooool3o`0000Sooooo0_l00006ooooo`;o00004oooool2o`0005go
oooo000Looooo`03o`000?oooooooooo03gooooo1?l00008ooooo`;o00003Oooool2o`0001Cooooo
5_l00003ooooo`?o00000oooool2o`00013ooooo7ol00007ooooo`?o00005Oooool5o`0000Sooooo
0_l0001Mooooo`007?ooool00ol0003oooooooooo`18ooooo`?o00002?ooool2o`0000?ooooo0_l0
0005ooooo`;o00003?oooolMo`0000_ooooo0_l00008oooooaoo00001oooool3o`0000Kooooo0_l0
0003ooooo`;o00002?ooool5o`0006Oooooo000Looooo`03o`000?oooooooooo04Oooooo1?l00008
ooooo`;o00002_ooool2o`0000Gooooo0_l00005oooooa_o00003Oooool2o`0000Sooooo8Ol00003
ooooo`;o00002Oooool2o`0000?ooooo0_l00005ooooo`;o00000_ooool3o`0000oooooo0_l00002
ooooo`;o0000Doooool001cooooo0_l00018ooooo`;o00006_ooool5o`0000Oooooo5ol000000ooo
oooo0000o`00000Eoooooago000000?oooooo`000?l000000_l00003ooooo`;o00003Oooool2o`00
00Kooooo0_l00002ooooo`Co00002Oooool4o`000003ooooool0003o000000;ooooo0_l0000:oooo
o`;o0000Aoooool001cooooo00?o0000ooooooooool0Goooool9o`0000Cooooo7Ol00004ooooo`;o
000000?oooooo`000?l000001?ooool2o`0000;ooooo9_l0000=ooooo`;o00000oooool2o`0000[o
oooo1ol00006ooooo`Co00001_ooool2o`0000Wooooo0_l00017ooooo`007?ooool00ol0003ooooo
ooooo`1Oooooo`Wo00001?oooolMo`0000Cooooo0_l000000ooooooo0000o`000002o`0000;ooooo
0_l00002ooooo`Go000000?oooooo`000?l000007_l00003ooooo`;o00002?ooool2o`0000oooooo
0_l00002ooooo`?o00001_ooool5o`0000Cooooo0ol00002ooooo`;o0000C_ooool001cooooo00?o
0000ooooooooool0C_ooool5o`000003ooooool0003o000000gooooo0_l000000ooooooo0000o`00
0006oooooa[o00001_ooool2o`0000;ooooo0_l00006ooooo`;o000000Coooooo`000?l0003ooooo
8?l00003ooooo`;o00000_ooool2o`0000Cooooo0_l0000<ooooo`;o00000oooool4o`0000Kooooo
0_l00002ooooo`;o00001?ooool4o`000003ooooool0003o000004kooooo000Looooo`03o`000?oo
oooooooo047ooooo0ol0000:ooooo`Go000000?oooooo`000?l000002_ooool2o`0000Kooooo0_l0
0005ooooo`co000000?oooooo`000?l000002?l00008ooooo`;o00002_ooool2o`0000;ooooo3_l0
00001?oooooo0000o`000?ooool@o`0000Oooooo0_l00004ooooo`Co00002_ooool2o`0000?ooooo
1?l000000ooooooo0000o`000003ooooo`?o00001_ooool2o`000004ooooool0003o0000ooooo`;o
0000C_ooool001cooooo00?o0000ooooooooool0@Oooool3o`0000Kooooo0_l00003ooooo`;o0000
1?ooool2o`0000Wooooo0_l000000ooooooo0000o`000003ooooo`;o00001Oooool<o`000003oooo
ool0003o000000Wo00004oooool2o`0000;ooooo3_l000000ooooooo0000o`00000Ao`0000_ooooo
0_l00002ooooo`;o00002_ooool2o`0000;ooooo0_l00004ooooo`;o00001?ooool2o`0000;ooooo
0_l00002ooooo`;o000000Coooooo`000?l0003ooooo0_l0000:ooooo`;o0000@_ooool001cooooo
00?o0000ooooooooool0=Oooool2o`0000_ooooo0ol00005ooooo`?o00002?ooool2o`0000Gooooo
0_l00003ooooo`Co00001Oooool2o`0000Cooooo5ol00002ooooo`;o00004ooooolLo`000004oooo
ool0003o0000o`0000?ooooo0_l00008ooooo`?o00000_ooool2o`0000Wooooo1_l0000<ooooo`Co
00001Oooool2o`0000gooooo0_l00012ooooo`007?ooool00ol0003oooooooooo`0eooooo`;o0000
2?ooool2o`0000;ooooo0_l00005ooooo`?o00003oooool2o`0000?ooooo1?l00005ooooo`;o0000
1?oooolGo`000004ooooool0003o0000o`0001Gooooo7_l00002ooooo`?o00002Oooool2o`0000;o
oooo0_l00005ooooo`;o00001?ooool2o`0000Cooooo0_l00008ooooo`;o0000F_ooool001cooooo
00?o0000ooooooooool0?oooool2o`0001Oooooo0_l0000@ooooo`;o00001?ooool=o`000003oooo
ool0003o000000?o00000_ooool6o`0001Gooooo8_l00008ooooo`?o00002_ooool6o`0000Kooooo
0_l00008ooooo`;o00000_ooool2o`0000Cooooo0ol00002ooooo`;o0000Boooool001cooooo00?o
0000ooooooooool09oooool2o`0001;ooooo0_l00002ooooo`;o00002?ooool2o`0000gooooo0_l0
00000ooooooo0000o`000004ooooo`;o00001Oooool4o`0000Gooooo6?l0000<ooooo`;o00000ooo
ool2o`0000;ooooo4_l00002ooooo`oo00001_ooool2o`000004ooooool0003o0000o`0000cooooo
1?l0000Dooooo`;o00001?ooool3o`0000;ooooo0_l0001;ooooo`007?ooool00ol0003ooooooooo
o`0Wooooo`;o00004_ooool2o`0000Kooooo1?l00002ooooo`;o00000oooool2o`0000_ooooo0_l0
0002ooooo`Go000000Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?l00005ooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`000009o`0000oooooo0_l00003ooooo`;o
000000Goooooo`000?l0003o0000ooooo`03o`000003ooooool0003o000001Go00000oooool2o`00
0003ooooool0003o000000?ooooo0_l000001?oooooo0000o`000?l0000@ooooo`;o00002?ooool2
o`0000Sooooo0_l0000:ooooo`?o0000BOooool001cooooo00?o0000ooooooooool0:?ooool2o`00
01Wooooo1?l000000ooooooo0000o`000004ooooo`;o00000_ooool2o`0000[ooooo0ol000001?oo
oooo0000o`000?ooool3o`0000?ooooo0ol00007ooooo`Co00000oooool5o`000003ooooool0003o
000000;o00000_ooool2o`0001?ooooo8?l00002ooooo`;o000000Coooooo`000?l0003o00000ooo
ool4o`00017ooooo0_l00008ooooo`;o00002?ooool4o`0000Kooooo1Ol00008ooooo`;o0000?ooo
ool001cooooo00?o0000ooooooooool0:?ooool2o`0000Wooooo0ol00002ooooo`;o00001Oooool2
o`0000Cooooo1Ol00008ooooo`;o00001Oooool2o`000003ooooool0003o000000;o00000_ooool2
o`000003ooooool0003o000000;o00001oooool2o`0000;ooooo0ol00003ooooo`Go00000_ooool3
o`0000Cooooo0_l00003ooooo`;o00001oooool2o`0000Oooooo0_l00002ooooo`;o00000_oooolF
o`0000Cooooo1?l00003ooooo`;o00001_ooool2o`0000Sooooo0_l000000ooooooo0000o`000002
o`0000Oooooo0_l00004ooooo`;o00000oooool2o`0000Kooooo0_l0000;ooooo`;o0000?oooool0
01cooooo00?o0000ooooooooool0<oooool3o`0000;ooooo0ol00004ooooo`;o00001?ooool4o`00
00Kooooo0_l00008ooooo`;o000000?oooooo`000?l000001_ooool2o`000003ooooool0003o0000
00;o00000oooool5o`000003ooooool0003o000000Cooooo0ol00004ooooo`;o00002_ooool2o`00
00;ooooo0_l00003ooooo`;o00002oooool2o`000003ooooool0003o000001Go00001?ooool2o`00
00;ooooo0_l00009ooooo`;o00001oooool4o`000004ooooool0003o0000o`0000Oooooo0_l00004
ooooo`;o00001_ooool2o`00057ooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ
8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0iooooo`;o00000ooo
ool2o`0000Gooooo0ol00007ooooo`;o00000_ooool2o`0000oooooo0_l00003ooooo`;o00000ooo
ool2o`000003ooooool0003o000000cooooo0_l0000@ooooo`;o00004?oooolJo`0000?ooooo0ol0
0002ooooo`;o00002?ooool2o`0000?ooooo0_l00003ooooo`Co000000?oooooo`000?l000004_oo
ool3o`000003ooooool0003o0000057ooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>_ooool2o`000004oooo
ool0003o0000o`0000Kooooo0_l0000;ooooo`;o00003oooool2o`0000Cooooo0ol0000?ooooo`;o
000000?oooooo`000?l000003oooool2o`0001?ooooo0_l00003oooooa?o00000oooool3o`0000;o
oooo0_l00008ooooo`;o00000oooool2o`0001cooooo0ol0001Dooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`09ooooo`Go00001_ooool00ol0003oooooooooo`0jooooo`;o0000
00Coooooo`000?l0003ooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo0_l0000;ooooo`;o
00001?ooool4o`0000gooooo0ol00002ooooo`;o00003_ooool2o`0001Oooooo0_l00003ooooo`Oo
000000?oooooo`000?l000000_l000000ooooooo0000o`000004ooooo`;o00002?ooool2o`0000Oo
oooo0_l00008ooooo`;o00002_ooool2o`0000kooooo0_l0000:ooooo`;o00001Oooool2o`0003[o
oooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00CoA4A4omgMgOoooooo
00001oooool3o`0003Wooooo0_l00005ooooo`;o00003?ooool3o`0000;ooooo1_l0000Booooo`Go
00002oooool2o`0000?ooooo0_l0000<ooooo`;o00001Oooool2o`0000Gooooo0_l0000;ooooo`?o
00001?ooool6o`0000;ooooo1Ol00006ooooo`;o00001_ooool2o`0000Oooooo0_l00002ooooo`?o
00000oooool2o`0000Oooooo0_l000000ooooooo0000o`000008ooooo`;o00001?ooool3o`0000Wo
oooo0_l00005ooooo`;o0000>_ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool0
2Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo03Wooooo0_l0000<ooooo`;o
00000oooool6o`0000?ooooo1ol0000Booooo`?o00003Oooool4o`0000Gooooo1?l00003ooooo`;o
00001Oooool2o`0000Gooooo0_l0000<ooooo`Co00001_ooool2o`0000;ooooo1?l00006ooooo`?o
00000oooool2o`0000kooooo0ol00009ooooo`;o000000?oooooo`000?l000002oooool2o`0000Go
oooo0_l0000=ooooo`;o0000?Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo047ooooo0_l00004ooooo`;o0000
0oooool2o`0000;ooooo0_l00005ooooo`Go00000_ooool2o`0000oooooo0_l0000=ooooo`Co0000
0_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0001cooooo0ol0000:ooooo`;o0000
1_ooool4o`0000Cooooo0_l0000Jooooo`;o00001Oooool2o`0000Gooooo0_l0000Fooooo`;o0000
0_ooool2o`0003Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l0
00001oooool00ol0003oooooooooo`0cooooo`;o000000?oooooo`000?l000002Oooool2o`0001_o
oooo0_l0000Mooooo`;o00000oooool4o`0000?ooooo0_l00002ooooo`;o00000oooool2o`0000_o
oooo0_l0000Oooooo`;o00001Oooool2o`0000oooooo0_l00003ooooo`;o00003?ooool2o`0000Go
oooo0_l0000Jooooo`;o0000>Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omg
MgOo0000ooooo`06ooooo`03o`000?oooooooooo03?ooooo0_l000000ooooooo0000o`000003oooo
o`;o00005_ooool2o`0001?ooooo0_l0000Cooooo`;o00000oooool2o`0000Gooooo0ol00006oooo
o`;o00000_ooool2o`0000;ooooo0_l00003ooooo`;o00005?ooool2o`000003ooooool0003o0000
00gooooo0_l00009ooooo`;o00000oooool3o`0000?ooooo0_l0000?ooooo`;o00000_ooool2o`00
05Gooooo000Looooo`03o`000?oooooooooo03_ooooo0_l0000Fooooo`?o00000oooool6o`0000So
oooo1Ol00003ooooo`;o000000?oooooo`000?l000002?ooool2o`0000_ooooo0ol0000:ooooo`;o
00000_ooool2o`0001Wooooo0_l000000ooooooo0000o`00000Gooooo`?o00000oooool2o`0000So
oooo0_l0000;ooooo`So00002Oooool2o`0000;ooooo0_l00014ooooo`007?ooool00ol0003ooooo
ooooo`0looooo`;o00001_ooool2o`0000kooooo0_l00003ooooo`Ko000000Coooooo`000?l0003o
00001?ooool5o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool4o`0000Go
oooo1Ol00004ooooo`;o00001_ooool2o`0000;ooooo0_l0000`ooooo`;o00001Oooool2o`0000Go
oooo0_l00007ooooo`;o00003?ooool3o`0000;ooooo0_l000001?oooooo0000o`000?l00003oooo
o`Co00000_ooool2o`0004Cooooo000Looooo`03o`000?oooooooooo03Oooooo0_l00003ooooo`?o
00001Oooool2o`0000Cooooo0_l00006ooooo`Wo00001Oooool3o`0000Kooooo0_l00005ooooo`;o
00001?ooool2o`0000;ooooo0_l00007ooooo`Go00001?ooool2o`0000Kooooo0_l00002ooooo`?o
00006oooool2o`0000Oooooo0_l00002ooooo`Wo00001Oooool2o`0000;ooooo0_l000000ooooooo
0000o`00000>ooooo`;o00002_ooool2o`000004ooooool0003o0000o`0000?ooooo0ol00003oooo
o`Co00007Oooool2o`0002?ooooo000Looooo`03o`000?oooooooooo037ooooo0_l00004ooooo`;o
00001?ooool2o`0000_ooooo0_l00006ooooo`Wo00001oooool2o`0000cooooo0_l00006ooooo`;o
00004_ooool2o`0000Kooooo0_l00002ooooo`?o00006oooool2o`0000Oooooo0_l00002ooooo`Oo
00002oooool4o`0000oooooo0_l00002ooooo`?o000000Coooooo`000?l0003ooooo0ol00002oooo
o`;o00001?ooool2o`0000Cooooo0ol0000Mooooo`;o00008oooool001cooooo00?o0000oooooooo
ool0<Oooool2o`0000Gooooo0_l0000Nooooo`;o00002?ooool2o`0000Oooooo0_l00003ooooo`;o
00001_ooool2o`0001;ooooo1?l00008ooooo`;o00001?ooool4o`00023ooooo0_l00009ooooo`;o
00002?ooool4o`0000Oooooo0_l00008ooooo`?o000000Coooooo`000?l0003ooooo1?l000000ooo
oooo0000o`000003ooooo`;o00005oooool2o`000003ooooool0003o000002kooooo000Looooo`03
o`000?oooooooooo037ooooo0_l00005ooooo`;o00006Oooool2o`0000cooooo0_l00008ooooo`;o
00000_ooool3o`0000Cooooo0_l0000;ooooo`;o00001oooool4o`0000cooooo1_l000000ooooooo
0000o`000008ooooo`;o00003Oooool2o`0000Cooooo0_l00002ooooo`;o000000?oooooo`000?l0
00000_ooool2o`0000Oooooo1Ol00007ooooo`;o00002Oooool2o`000003ooooool0003o000000?o
oooo0_l00004ooooo`Ko00005Oooool2o`000003ooooool0003o000002kooooo000Looooo`03o`00
0?oooooooooo033ooooo0_l0000Booooo`;o00003Oooool2o`0000Wooooo0_l000000ooooooo0000
o`000003ooooo`;o00001oooool3o`0000Cooooo0_l0000;ooooo`;o00001_ooool3o`0000kooooo
0_l000000ooooooo0000o`000002ooooo`;o00002?ooool4o`0000_ooooo0_l00002ooooo`;o0000
00Coooooo`000?l0003ooooo0_l000000ooooooo0000o`000008ooooo`Go00004oooool3o`0000go
oooo0_l00002ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0<?ooool2o`0000_ooooo
0_l00004ooooo`?o00005_ooool4o`0000;ooooo0ol000001?oooooo0000o`000?ooool3o`0001go
oooo1Ol0000Dooooo`;o000000?oooooo`000?l000002?ooool2o`0000Kooooo0_l00007ooooo`;o
000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00003ooooo`;o000000?oooooo`000?l0
00000ol00007ooooo`;o00001Oooool2o`0000?ooooo1Ol0000?ooooo`;o0000B?ooool001cooooo
00?o0000ooooooooool0>?ooool2o`0000?ooooo0_l00004ooooo`;o00005oooool2o`0000?ooooo
1?l00004ooooo`?o00001?ooool2o`0000oooooo1?l00004ooooo`;o00001?ooool3o`00013ooooo
0_l000000ooooooo0000o`000004ooooo`;o00002Oooool4o`0000Kooooo0_l00005ooooo`;o0000
0_ooool2o`000003ooooool0003o000000Wo00001Oooool3o`0000Gooooo0_l00005ooooo`?o0000
2oooool2o`0000?ooooo0_l00017ooooo`007?ooool00ol0003oooooooooo`0hooooo`;o00008Ooo
ool4o`0000;ooooo0_l0000=ooooo`Co00001oooool2o`0000Cooooo1?l00004ooooo`;o00001?oo
ool3o`0001Wooooo0_l00009ooooo`Co000000?oooooo`000?l000000oooool2o`0000Wooooo3_l0
0005ooooo`Go00001?ooool2o`0000Cooooo1ol00002ooooo`;o00000oooool2o`0000;ooooo0ol0
0017ooooo`007?ooool00ol0003oooooooooo`13ooooo`;o00003?ooool2o`0000Sooooo1?l0000C
ooooo`;o00001oooool4o`0000Cooooo0ol00007ooooo`;o000000?oooooo`000?l000000_l00004
ooooo`;o00004?ooool2o`0000kooooo0ol00003ooooo`?o00002?ooool@o`0000?ooooo1Ol00004
ooooo`;o00000_ooool2o`000003ooooool0003o000000Co00000_ooool5o`0000Cooooo0_l00018
ooooo`007?ooool2o`0004?ooooo0ol0000<ooooo`;o00003oooool2o`0000Cooooo0_l0000Boooo
o`?o00001?ooool3o`0000Gooooo1?l00003ooooo`?o000000?oooooo`000?l000000_l0000@oooo
o`;o00003_ooool2o`0000Cooooo1?l00003ooooo`Oo000000?oooooo`000?l000002ol000001?oo
oooo0000o`000?l00006ooooo`;o00000oooool4o`000003ooooool0003o000000Cooooo1Ol0001>
ooooo`007?ooool00ol0003oooooooooo`0jooooo`;o00001_ooool2o`0000kooooo0_l0000:oooo
o`;o00000_ooool4o`0000;ooooo0_l0000Aooooo`;o00000oooool2o`000004ooooool0003o0000
o`0000Cooooo0ol00006ooooo`;o000000Coooooo`000?l0003ooooo2?l0000?ooooo`;o00002_oo
ool2o`0000;ooooo1?l00003oooooaSo00001oooool2o`0000Gooooo1?l00003ooooo`;o00001Ooo
ool2o`0004cooooo000Looooo`03o`000?oooooooooo03[ooooo0_l00004ooooo`;o00004?ooool2
o`0000[ooooo0ol00003ooooo`;o00003_ooool2o`0000Gooooo0_l00003ooooo`;o00000_ooool2
o`000004ooooool0003o0000ooooo`?o00003?ooool8o`0000oooooo0_l0000:ooooo`;o00000_oo
ool2o`0000Sooooo3ol000000ooooooo0000o`000003o`0000Oooooo0_l00003ooooo`;o00000_oo
ool2o`0000?ooooo0_l00002ooooo`Ko0000Boooool001cooooo00?o0000ooooooooool0>_ooool2
o`0000Cooooo0ol0000Kooooo`?o00000_ooool2o`0000?ooooo0_l0000:ooooo`;o00003_ooool2
o`000003ooooool0003o0000013ooooo1?l00002ooooo`;o00000_ooool2o`00013ooooo0_l00005
ooooo`;o00000_ooool2o`0000Sooooo6Ol00005ooooo`;o000000?oooooo`000?l000002oooool6
o`0004_ooooo000Looooo`03o`000?oooooooooo02cooooo0_l00005ooooo`;o00001_ooool2o`00
0003ooooool0003o000000?o00004oooool2o`0000Cooooo1?l00003ooooo`;o00000oooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000002?ooool2o`000003ooooool0003o0000
00;o00000_ooool3o`0001Gooooo0_l00006ooooo`?o000000?oooooo`000?l000000oooool2o`00
00Oooooo0ol00003ooooo`?o00000_ooool2o`0000Kooooo6ol00005ooooo`;o00000oooool2o`00
00;ooooo0_l00009ooooo`;o00001Oooool2o`0004Cooooo000Looooo`03o`000?oooooooooo02co
oooo0_l00005ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002o`0000co
oooo0_l00005ooooo`?o00001?ooool2o`0000gooooo1?l000000ooooooo0000o`000006ooooo`Co
000000?oooooo`000?l000000_l00002ooooo`;o00000_ooool2o`0000Cooooo0_l00002ooooo`;o
00000_ooool2o`0000gooooo0_l000001?oooooo0000o`000?l00002ooooo`;o00002?ooool2o`00
00?ooooo0ol00002ooooo`;o00000oooool2o`000003ooooool0003o000001[o00001_ooool2o`00
0003ooooool0003o000000;ooooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo1?l00014oooo
o`007?ooool00ol0003oooooooooo`0_ooooo`;o00001_ooool2o`0000Gooooo0_l0000>ooooo`;o
00001Oooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`00000:ooooo`;o
00001_ooool2o`0000?ooooo1?l00006ooooo`;o00000oooool2o`0000Cooooo0_l00002ooooo`;o
00000_ooool2o`00017ooooo0_l00005ooooo`;o00004Oooool2o`000004ooooool0003o0000oooo
oa;o00000_ooool8o`000003ooooool0003o000000?ooooo1Ol00007ooooo`;o00002Oooool4o`00
04Cooooo000Looooo`03o`000?oooooooooo02gooooo1?l00003ooooo`Co00004oooool2o`0000Go
oooo0_l00004ooooo`;o00001Oooool2o`0000Cooooo0_l00006ooooo`;o00001?ooool2o`0000Co
oooo0_l00007ooooo`;o00000oooool2o`0000Wooooo0_l00008ooooo`Co00002?ooool2o`0000?o
oooo1_l00003ooooo`;o00001Oooool2o`0000?ooooo0_l00004oooooaWo00001?ooool2o`000003
ooooool0003o000000;ooooo0_l0000Aooooo`Ko0000A?ooool001cooooo00?o0000ooooooooool0
;Oooool3o`0000Cooooo1?l00003ooooo`;o00003_ooool2o`0000Gooooo0ol0000:ooooo`;o0000
1?ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000001oooool2o`0000;ooooo
0_l00006ooooo`Co00002Oooool3o`0000Oooooo1?l00008ooooo`;o00000oooool2o`0000;ooooo
0_l00003ooooo`;o00001Oooool2o`000003ooooool0003o000000Kooooo0_l00002ooooo`co0000
00?oooooo`000?l000002?l00005ooooo`;o00005Oooool4o`0004Kooooo000Looooo`03o`000?oo
oooooooo02kooooo0_l00005ooooo`?o00000oooool2o`0001Kooooo0_l00004ooooo`;o00001?oo
ool2o`0000Sooooo1_l000000ooooooo0000o`000006ooooo`;o00000oooool2o`0000Kooooo1?l0
0006ooooo`;o000000Coooooo`000?l0003o00001Oooool2o`0002Cooooo0_l00002ooooo`?o0000
00Coooooo`000?l0003ooooo6_l00007ooooo`;o00001Oooool2o`000003ooooool0003o0000057o
oooo000Looooo`03o`000?oooooooooo03Gooooo0_l000000ooooooo0000o`00000Cooooo`?o0000
0_ooool3o`000004ooooool0003o0000ooooo`Co00000_ooool2o`0000Wooooo1Ol00009ooooo`?o
00003?ooool2o`0000Kooooo0_l000000ooooooo0000o`000006ooooo`;o00000_ooool2o`0000[o
oooo1?l00002ooooo`;o00004_ooool3o`0000?ooooo2_l000000ooooooo0000o`00000>o`0000Oo
oooo0_l00005ooooo`;o000000Coooooo`000?l0003o0000D?ooool001cooooo00?o0000oooooooo
ool0<oooool2o`0000?ooooo0_l00003ooooo`Co00003?ooool3o`0000;ooooo0ol000001?oooooo
0000o`000?ooool4o`00013ooooo0_l0000:ooooo`;o00001Oooool2o`0000_ooooo1?l0000=oooo
o`;o00002_ooool4o`0000;ooooo0_l0000>ooooo`;o00002?oooolMo`0000cooooo0_l00002oooo
o`;o00001Oooool2o`0000Kooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o
00001?ooool2o`0000Oooooo1Ol00004ooooo`;o00000_ooool2o`0000?ooooo0ol00008ooooo`;o
00001?ooool2o`0000Wooooo0_l0000Dooooo`;o000000?oooooo`000?l000002?ooool4o`0000?o
oooo0_l00003ooooo`;o00002Oooool2o`000004ooooool0003o0000ooooo`Ko00003Oooool5o`00
00Sooooo3?l000001Ooooooo0000o`000?l0003ooooo00co00005oooool2o`0000Kooooo0_l00011
ooooo`007?ooool00ol0003oooooooooo`0]ooooo`;o00001?ooool2o`0000?ooooo0_l000000ooo
oooo0000o`000003o`0000Gooooo0_l00002ooooo`;o00000oooool3o`0000kooooo0ol00002oooo
o`;o00001?ooool2o`0000Gooooo0_l00007ooooo`;o00001_ooool3o`0000_ooooo1_l00003oooo
o`;o00002Oooool2o`000004ooooool0003o0000ooooo`;o00000_ooool2o`0000[ooooo2Ol00005
ooooo`;o00000oooool<o`000003ooooool0003o000000_o0000H_ooool001cooooo00?o0000oooo
ooooool0>?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000007Oooool2
o`0000;ooooo0_l000000ooooooo0000o`000008ooooo`;o00000oooool2o`0000;ooooo0_l00003
ooooo`;o000000Coooooo`000?l0003o00002oooool6o`00013ooooo0_l0000?ooooo`;o000000?o
ooooo`000?l000000_l000000ooooooo0000o`000004o`0000?ooooo0_l00003ooooo`co000000?o
ooooo`000?l000002ol0000Booooo`;o000000?oooooo`000?l000002_ooool2o`0000Oooooo0_l0
000fooooo`007?ooool00ol0003oooooooooo`0booooo`;o00001?ooool2o`0000Gooooo1?l00007
ooooo`;o00001?ooool2o`0001Gooooo0_l0000=ooooo`;o000000?oooooo`000?l000000_l00002
ooooo`;o00004oooool2o`0000Sooooo1?l00004ooooo`;o00003?ooool2o`000003ooooool0003o
000000Gooooo0ol00002ooooo`;o00001oooool>o`000003ooooool0003o000000Wo00004oooool2
o`000003ooooool0003o000000[ooooo0_l00007ooooo`;o0000=_ooool001cooooo0_l0000coooo
o`;o00002oooool2o`0000Wooooo0_l00004ooooo`;o00001_ooool2o`0001Cooooo0_l00008oooo
o`Go00001?ooool3o`0000[ooooo0_l00002ooooo`Co00002?ooool4o`0000;ooooo0_l000000ooo
oooo0000o`000009ooooo`Co00002?ooool2o`000003ooooool0003o000000Cooooo0_l00003oooo
oaOo000000?oooooo`000?l000003?ooool3o`0000Cooooo0_l00002ooooo`;o0000B_ooool001co
oooo00?o0000ooooooooool0;?ooool2o`0002?ooooo0_l00005ooooo`;o00000_ooool2o`0000?o
oooo0_l0000;ooooo`;o00001oooool8o`000003ooooool0003o000000Co00000_ooool2o`0000Co
oooo0_l00002ooooo`;o00001_ooool2o`0000Sooooo1Ol00009ooooo`Co00001Oooool3o`0000?o
oooo0_l00004ooooo`;o00001?oooolFo`0000_ooooo0_l00002ooooo`?o00000_ooool2o`0000Co
oooo0_l00004ooooo`;o00002oooool6o`0000Gooooo0_l0000/ooooo`007?ooool00ol0003ooooo
ooooo`0/ooooo`;o00007oooool2o`0000;ooooo0_l00008ooooo`?o00000oooool2o`0000;ooooo
0_l00004ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`00000Co`0000_o
oooo0_l00002ooooo`?o00002?ooool2o`0000?ooooo0_l00008ooooo`;o00001Oooool3o`0000So
oooo0_l00005ooooo`;o00000ooooolAo`0000_ooooo0_l00005ooooo`Co00002_ooool2o`0000_o
oooo1_l00005ooooo`;o0000;?ooool001cooooo00?o0000ooooooooool0;oooool2o`0000Kooooo
1?l00003ooooo`;o00003Oooool2o`0000cooooo0_l000000ooooooo0000o`000003o`0000;ooooo
0_l00004ooooo`;o000000Coooooo`000?l0003ooooo1?l000000ooooooo0000o`000002o`000003
ooooool0003o000000ko00000oooool4o`0000Cooooo0_l00003ooooo`;o00001_ooool2o`0000Co
oooo0ol00005ooooo`;o00004oooool2o`0000Wooooo5?l000000ooooooo0000o`00000=ooooo`;o
000000Coooooo`000?l0003ooooo0_l0000Dooooo`;o0000=_ooool001cooooo00?o0000oooooooo
ool0;oooool4o`0000Cooooo1?l000000ooooooo0000o`000002o`0000Cooooo0_l00007ooooo`;o
00001_ooool2o`0000Oooooo1Ol00008ooooo`;o00002?ooool3o`0000Cooooo2Ol00003ooooo`?o
00000oooool4o`0000Cooooo0_l00008ooooo`;o000000Coooooo`000?l0003o00000oooool3o`00
00Cooooo0ol00004ooooo`;o00004oooool2o`0000?ooooo2Ol000000ooooooo0000o`00000;o`00
00;ooooo0_l0000<ooooo`Oo00002Oooool3o`0003kooooo000Looooo`03o`000?oooooooooo02_o
oooo1?l000001?oooooo0000o`000?l00009ooooo`?o00001Oooool2o`0000oooooo0_l0000?oooo
o`;o00003?ooool5o`0000;ooooo0ol000000ooooooo0000o`000003o`0000Gooooo0ol00008oooo
o`Ko000000?oooooo`000?l000000oooool2o`0000;ooooo0_l000000ooooooo0000o`000003o`00
00Cooooo0_l00005ooooo`;o00003Oooool3o`0000?ooooo0_l00003ooooo`;o000000?oooooo`00
0?l000002Ol00004ooooo`Go00000_ooool2o`0000Kooooo0ol00003ooooo`?o00000_ooool2o`00
00Oooooo1Ol0000nooooo`007?ooool00ol0003oooooooooo`0Yooooo`Ko000000Coooooo`000?l0
003ooooo0_l00003ooooo`;o00001oooool2o`0000Oooooo0_l00009ooooo`;o00002?ooool2o`00
0004ooooool0003o0000ooooo`?o00001?ooool2o`000004ooooool0003o0000ooooo`Co000000?o
ooooo`000?l000001Ol00004ooooo`;o00000_ooool6o`0000?ooooo2ol000000ooooooo0000o`00
000:ooooo`Co00002Oooool2o`00013ooooo0ol0000<ooooo`[o00001?ooool4o`0000Cooooo0_l0
0005ooooo`Co00002?ooool2o`0000Kooooo0_l00011ooooo`007?ooool00ol0003oooooooooo`0Y
ooooo`;o00002?ooool2o`0000?ooooo0_l00007ooooo`;o00001oooool2o`0000cooooo1_l00000
0ooooooo0000o`000003o`000003ooooool0003o000000;o000000?oooooo`000?l000001Ol00000
0ooooooo0000o`000009o`000004ooooool0003o0000o`0000;ooooo2Ol00003ooooo`Go00005Ooo
ool2o`0000Wooooo0_l0000@ooooo`;o00000_ooool2o`0000?ooooo0ol00003ooooo`[o000000?o
ooooo`000?l000000oooool3o`0000?ooooo0_l00007ooooo`;o00002?ooool4o`0004Oooooo000L
ooooo`03o`000?oooooooooo02kooooo0_l0000:ooooo`;o00007?ooool6o`0000;ooooo1?l00000
0ooooooo0000o`000002o`000003ooooool0003o000000Go000000?oooooo`000?l000007?l00000
1?oooooo0000o`000?l0000=ooooo`;o00001oooool2o`0000[ooooo0_l00009ooooo`;o00000ooo
ool2o`0000;ooooo0_l00003ooooo`Go000000Coooooo`000?l0003o00000_ooool8o`0000Cooooo
0_l0000Hooooo`;o00001Oooool2o`0000kooooo0_l00003ooooo`;o0000:oooool001cooooo00?o
0000ooooooooool0:oooool2o`000003ooooool0003o000000;ooooo0_l00006ooooo`;o00004_oo
ool2o`0000cooooo1Ol000001?oooooo0000o`000?ooool2o`0000;ooooo0ol000000ooooooo0000
o`000002o`0000Cooooo7_l0000>ooooo`;o00000_ooool2o`0000?ooooo0_l0000:ooooo`;o0000
2Oooool2o`0000?ooooo0_l00007ooooo`;o000000?oooooo`000?l000000_l00009ooooo`?o0000
1?ooool2o`0001oooooo0_l00004ooooo`;o00002?ooool2o`0000?ooooo0_l0000[ooooo`007?oo
ool00ol0003oooooooooo`0[ooooo`;o00001Oooool4o`0001Sooooo0_l00007ooooo`;o00001Ooo
ool3o`000004ooooool0003o0000o`0000;ooooo2_l000000ooooooo0000o`00000=o`000003oooo
ool0003o000000Oo00000oooool5o`0000[ooooo0_l00006ooooo`;o00000oooool2o`0000gooooo
0ol0000?ooooo`;o00000_ooool4o`000004ooooool0003o0000ooooo`;o00001Oooool4o`0000[o
oooo0_l0000Dooooo`;o00001Oooool2o`0000;ooooo0_l0000jooooo`007?ooool00ol0003ooooo
ooooo`0Yooooo`;o00001Oooool2o`000004ooooool0003o0000o`0000[ooooo0_l0000Eooooo`;o
00000oooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o00000_ooool3o`000003
ooooool0003o000001_o00001_ooool2o`0000Wooooo0_l00004ooooo`;o00003Oooool3o`0000?o
oooo1?l0000?ooooo`;o00000_ooool5o`000003ooooool0003o000000Co00000oooool4o`0000Oo
oooo0_l000000ooooooo0000o`000002ooooo`;o00004?ooool3o`0000Cooooo0_l00006ooooo`;o
0000=_ooool001cooooo00?o0000ooooooooool0:Oooool2o`0000Gooooo0_l000000ooooooo0000
o`000009ooooo`Ko00006?ooool2o`0000;ooooo0ol00009ooooo`;o000000?oooooo`000?l00000
0_l000000ooooooo0000o`00000Jo`0000;ooooo0_l0000?ooooo`;o00003Oooool3o`000003oooo
ool0003o000000;o00005?ooool3o`000004ooooool0003o0000ooooo`;o00000_ooool2o`000005
ooooool0003o0000o`000?ooool00_l00003ooooo`;o00000_ooool2o`0000?ooooo1?l00002oooo
o`;o00003Oooool2o`0000cooooo0_l0000Cooooo`;o00008Oooool001cooooo00?o0000oooooooo
ool0<?ooool2o`0000cooooo0_l000001?oooooo0000o`000?l00006ooooo`;o00005Oooool2o`00
00Oooooo9_l00002ooooo`;o00008?ooool4o`0000;ooooo0_l00003ooooo`;o00001Oooool2o`00
00;ooooo0ol000001?oooooo0000o`000?l00007ooooo`;o00000_ooool3o`0000;ooooo0_l00000
1?oooooo0000o`000?l00006ooooo`Go00000_ooool4o`0000?ooooo0_l00002ooooo`Co00008ooo
ool2o`00027ooooo000Looooo`03o`000?oooooooooo02oooooo0ol0000?ooooo`;o00001oooool2
o`0001Gooooo0_l00007ooooo`;o000000?oooooo`000?l000009Ol0000Pooooo`;o00000oooool5
o`000003ooooool0003o000000Gooooo0_l00002ooooo`?o00001oooool2o`0000;ooooo0_l00007
ooooo`;o000000?oooooo`000?l000001oooool2o`0000Oooooo0_l00002ooooo`?o00000_ooool4
o`0004Kooooo000Looooo`03o`000?oooooooooo02oooooo0_l0000?ooooo`;o000000?oooooo`00
0?l000002oooool2o`0000oooooo0_l0000:ooooobOo000000?oooooo`000?l000005?ooool2o`00
00Wooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003o000000_ooooo0_l00000
0ooooooo0000o`000003ooooo`;o00003oooool2o`0000gooooo0_l00004ooooo`;o00009?ooool2
o`0002Oooooo000Looooo`;o0000@?ooool3o`000003ooooool0003o000000_ooooo0_l0000>oooo
o`;o00001?ooool2o`000003ooooool0003o000001go000000?oooooo`000?l000003?l000000ooo
oooo0000o`00000Aooooo`;o00002Oooool2o`0000Oooooo0_l0000;ooooo`;o000000?oooooo`00
0?l000003_ooool3o`0000?ooooo0_l0000=ooooo`;o00000_ooool2o`0000Gooooo0_l00006oooo
o`;o00005oooool2o`0002Oooooo000Looooo`03o`000?oooooooooo03cooooo0_l000000ooooooo
0000o`00000?ooooo`?o00000_ooool2o`0000Wooooo1Ol000000ooooooo0000o`00000Go`000003
ooooool0003o0000013o00000_ooool2o`0000;ooooo0_l0000Qooooo`;o000000?oooooo`000?l0
00000_ooool2o`000003ooooool0003o000000Wooooo0_l00002ooooo`;o000000?oooooo`000?l0
00001_ooool4o`0001Gooooo0_l00004ooooo`?o00001_ooool2o`00043ooooo000Looooo`03o`00
0?oooooooooo02oooooo0_l00004ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo
0_l00009ooooo`?o000000?oooooo`000?l000000_ooool2o`0000;ooooo0_l00002ooooo`Co0000
0ooooolFo`0000?ooooo3ol000000ooooooo0000o`00000Hooooo`Ko00002_ooool2o`000003oooo
ool0003o000000;ooooo1Ol00006ooooo`Go00000_ooool2o`000003ooooool0003o000000Sooooo
0_l0000Hooooo`;o000000?oooooo`000?l000001Oooool2o`0004;ooooo000Looooo`03o`000?oo
oooooooo02kooooo0ol00004ooooo`;o000000?oooooo`000?l000001_ooool2o`0000;ooooo1?l0
000:ooooo`;o00001Oooool6o`0000Cooooo1_l00002ooooo`Go000000?oooooo`000?l000005_l0
00000ooooooo0000o`000004o`000005ooooool0003o0000o`000?ooool01Ol000000ooooooo0000
o`00000>ooooo`Ko00004oooool2o`0000Oooooo1?l0000;ooooo`;o00007Oooool2o`000003oooo
ool0003o000000Gooooo0_l00006ooooo`;o0000>_ooool001cooooo00?o0000ooooooooool0;?oo
ool4o`0000Sooooo0_l00006ooooo`;o00000_ooool2o`0000gooooo0_l000000ooooooo0000o`00
0003ooooo`;o00000oooool2o`0000?ooooo2?l000000ooooooo0000o`00000To`000003ooooool0
003o000000?o000000?oooooo`000?l000005?ooool2o`0000?ooooo0_l00009ooooo`;o00001ooo
ool2o`00013ooooo0_l00006ooooo`;o00006?ooool2o`0000gooooo0_l00006ooooo`?o0000<Ooo
ool001cooooo00?o0000ooooooooool0;?ooool2o`0002Gooooo0_l000000ooooooo0000o`000005
ooooo`Go00001?ooool6o`000003ooooool0003o000000_o00000ooooolHo`000003ooooool0003o
000001?ooooo0_l00004ooooo`;o00000oooool4o`0000;ooooo0_l00003ooooo`;o00000oooool2
o`0000;ooooo1?l00002ooooo`Co00004?ooool2o`00013ooooo1?l00006ooooo`;o00002_ooool2
o`0000Oooooo0ol0000aooooo`007?ooool00ol0003oooooooooo`0/ooooo`?o00002Oooool2o`00
01Sooooo0_l00009ooooo`?o00001_ooool3o`000003ooooool0003o000000go00000_oooolJo`00
0003ooooool0003o000000Co000000?oooooo`000?l000003?ooool2o`0000Sooooo0_l000001Ooo
oooo0000o`000?l0003ooooo00;o00000oooool2o`0000?ooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000ol00003ooooo`;o00000_ooool2o`0001Wooooo1?l00006ooooo`;o00002_ooool2
o`0003_ooooo000Looooo`03o`000?oooooooooo02gooooo0_l00009ooooo`;o00006?ooool2o`00
00[ooooo0_l00003ooooo`?o00001Oooool<o`0000;ooooo5ol000000ooooooo0000o`000009o`00
0003ooooool0003o000001Kooooo0_l00002ooooo`;o00001_ooool2o`0000cooooo0ol00005oooo
o`;o00000_ooool2o`0001Oooooo1_l0000?ooooo`;o00003Oooool2o`0002oooooo000Looooo`03
o`000?oooooooooo053ooooo0_l0000<ooooo`;o00000oooool6o`0000;ooooo;Ol00005ooooo`;o
00001?ooool2o`0000Kooooo0_l00002ooooo`;o00007Oooool3o`0000Oooooo1?l0000Hooooo`;o
00004oooool4o`000003ooooool0003o000000Sooooo0_l0000_ooooo`007?ooool00ol0003ooooo
ooooo`1;ooooo`;o00000oooool2o`0000cooooo0_l00004ooooo`So000000?oooooo`000?l00000
5ol000000ooooooo0000o`00000<o`000003ooooool0003o000000_ooooo0_l000000ooooooo0000
o`000003ooooo`;o00000_ooool2o`0000;ooooo1?l00009ooooo`;o00003?ooool3o`0000Oooooo
1?l0000Hooooo`;o000000?oooooo`000?l000002?ooool2o`0000Kooooo1?l000000ooooooo0000
o`000006ooooo`;o0000<Oooool001cooooo00?o0000ooooooooool0>oooool2o`000003ooooool0
003o000000_ooooo0_l00003ooooo`;o00003?ooool2o`0000Gooooo3Ol000000ooooooo0000o`00
000Po`0000?ooooo0_l00007ooooo`;o00000oooool2o`0000;ooooo0_l00003ooooo`;o00000_oo
ool4o`0000Oooooo1?l0000=ooooo`;o00004Oooool2o`0000Oooooo1Ol00004ooooo`Go00000ooo
ool2o`0000?ooooo0_l00004ooooo`Ko00002Oooool2o`00037ooooo000Looooo`03o`000?oooooo
oooo03_ooooo0_l000000ooooooo0000o`00000@ooooo`;o00001_ooool2o`0000gooooo0_l00000
0ooooooo0000o`00000Fo`000003ooooool0003o0000017o00000_ooool2o`0000Oooooo0_l00007
ooooo`Co000000?oooooo`000?l000003?ooool3o`0001Oooooo0_l00005ooooo`;o000000Cooooo
o`000?l0003o00001oooool5o`000004ooooool0003o0000ooooo`?o00001Oooool2o`0000Wooooo
0_l00002ooooo`;o0000??ooool001cooooo00?o0000ooooooooool0:Oooool2o`00013ooooo0_l0
000Cooooo`;o00001_ooool3o`0000cooooo8ol000000ooooooo0000o`000005o`000004ooooool0
003o0000o`0000;ooooo0_l0000Aooooo`?o00001_ooool2o`0000Oooooo0ol0000Gooooo`;o0000
1Oooool2o`000004ooooool0003o0000o`0000Oooooo0_l00004ooooo`;o000000?oooooo`000?l0
00000_l000000ooooooo0000o`000004ooooo`;o0000B?ooool001cooooo00?o0000ooooooooool0
:Oooool2o`0000Kooooo0_l00008ooooo`;o00003oooool2o`0000_ooooo0_l000001?oooooo0000
o`000?ooool4o`000003ooooool0003o000000;ooooo0ol000000ooooooo0000o`00000Jo`000003
ooooool0003o000000Oo000000Coooooo`000?l0003o00000oooool4o`0000?ooooo0_l00007oooo
o`;o00000_ooool2o`000003ooooool0003o000000;ooooo0_l000000ooooooo0000o`000005oooo
o`;o00000oooool2o`0000?ooooo0ol00003ooooo`;o00001_ooool2o`0000gooooo0_l0000?oooo
o`;o000000?oooooo`000?l000000_l00002ooooo`;o00001?ooool2o`0000Kooooo0_l00003oooo
o`;o0000=Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo037ooooo0ol0000@ooooo`?o00001Ooo
ool2o`0000kooooo0_l000000ooooooo0000o`000002o`000003ooooool0003o000000;ooooo1?l0
00000ooooooo0000o`00000So`0000Gooooo1_l00003ooooo`Co00001Oooool2o`000005ooooool0
003o0000o`000?ooool00_l00004ooooo`?o000000Coooooo`000?l0003o00001_ooool2o`0000;o
oooo1?l00003ooooo`;o00001_ooool2o`0000gooooo0_l00009ooooo`Go00001_ooool2o`0000So
oooo0_l00006ooooo`;o00000oooool2o`0003Gooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0U
ooooo`;o00002oooool2o`0000Cooooo1?l00008ooooo`?o00005_ooool2o`0000Cooooo0ol00002
ooooo`Co000000?oooooo`000?l000008_l00006ooooo`;o00002?ooool3o`0000Kooooo1Ol00003
ooooo`;o00000_ooool2o`0000;ooooo1Ol00008ooooo`;o00001Oooool2o`0000Sooooo0_l00003
ooooo`;o00004?ooool6o`0000gooooo0_l00002ooooo`;o00003?ooool2o`0003?ooooo00000ooo
oooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo02Gooooo0_l0000@ooooo`Go00002?ooool2o`0000Kooooo0_l00006
ooooo`;o00001oooool2o`0000Cooooo0ol00002ooooo`;o00001?oooolTo`0000oooooo0_l00002
ooooo`;o00000oooool3o`0000?ooooo4Ol00009ooooo`?o000000?oooooo`000?l000002?ooool3
o`0000;ooooo0_l00005ooooo`;o00002Oooool2o`0000;ooooo1?l0000;ooooo`;o00000_ooool2
o`0000Cooooo0_l00006ooooo`?o0000<_ooool00003ooooool0003ooooo00;ooooo00?o0000oooo
ooooool02Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0000fooooo`?o00003_ooool2
o`0000?ooooo1?l00004ooooo`;o00001Oooool3o`0000Kooooo0_l000000ooooooo0000o`000002
ooooobOo000000Coooooo`000?l0003ooooo1Ol0000:ooooo`;o00002?ooool;o`000005ooooool0
003o0000o`000?ooool00_l00008ooooo`Co00000oooool2o`000004ooooool0003o0000o`0000?o
oooo0_l00009ooooo`;o00003Oooool4o`0000;ooooo0_l00007ooooo`;o00002?ooool2o`0000Oo
oooo0_l0000booooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0Zooooo`;o00002_ooool4o`0000;o
oooo0_l00009ooooo`;o00001?ooool4o`0000?ooooo0_l00005ooooo`?o00002Ooooolfo`0000Oo
oooo0_l00007ooooo`Co000000?oooooo`000?l000003ol00002ooooo`;o00000_ooool2o`0000Go
oooo1_l0000>ooooo`;o00003oooool2o`0000;ooooo0ol0000Gooooo`;o0000=?ooool00003oooo
ool@413ooooo00;ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`00
0?oooooooooo02[ooooo0_l0000;ooooo`?o00000_ooool2o`0000oooooo1?l00003ooooo`;o0000
1oooool2o`0000[ooooo2ol00002oooooago000000?oooooo`000?l000000_l00003ooooo`;o0000
1_ooool3o`0000Gooooo6Ol000000ooooooo0000o`000003o`0000Sooooo0ol0000<ooooo`;o0000
5oooool2o`0000Wooooo0_l0000<ooooo`;o0000=?ooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg2oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo03[ooooo0_l0000=ooooo`;o
00004_ooool2o`0000;ooooo1?l00005ooooo`Ko000000?oooooo`000?l000006_l000000ooooooo
0000o`000003o`0000?ooooo0_l00003ooooo`;o00001_ooool2o`0000Kooooo0ol00002ooooo`Ko
000000?oooooo`000?l000002ol000000ooooooo0000o`000005o`0000?ooooo0_l0000:ooooo`;o
00000_ooool4o`0000;ooooo0_l0000Booooo`Co00000_ooool2o`0000Cooooo0_l0000>ooooo`;o
0000<_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool01?o<c<coA4A4o`000?l@4106
ooooo`03o`000?oooooooooo03Kooooo0_l00002ooooo`?o00003?ooool2o`0000Kooooo0_l0000>
ooooo`Ko00001?ooool>o`000003ooooool0003o000001;o00002?ooool2o`0000?ooooo1?l00007
ooooo`?o000000Coooooo`000?l0003o00000_oooolHo`000003ooooool0003o000000;o00000ooo
ool2o`0000[ooooo0_l00002ooooo`?o00000oooool3o`0000_ooooo0_l00004ooooo`Co00000_oo
ool4o`0000;ooooo0_l0000>ooooo`;o0000<_ooool001cooooo00?o0000ooooooooool0=_ooool2
o`0000?ooooo0_l00005ooooo`;o00003Oooool2o`000004ooooool0003o0000ooooo`Co00002_oo
ool2o`0000?ooooo2Ol00003ooooo`?o000000Coooooo`000?l0003ooooo3_l000000ooooooo0000
o`000002o`0000;ooooo2?l000000ooooooo0000o`000002o`0000Oooooo0ol000000ooooooo0000
o`000003ooooo`oo000000?oooooo`000?l000001Ol00002ooooo`;o00001oooool2o`0000Wooooo
1_l00004ooooo`;o00002oooool2o`0000cooooo0_l00009ooooo`;o0000>oooool001cooooo00?o
0000ooooooooool0=_ooool2o`0000[ooooo0_l00005ooooo`;o00000_ooool2o`0000Gooooo0_l0
00000ooooooo0000o`000002o`0000oooooo1_l00005ooooo`Co000000Coooooo`000?l0003ooooo
2Ol000000ooooooo0000o`000007o`0000;ooooo2Ol000000ooooooo0000o`000007ooooo`Co0000
0_ooool2o`000003ooooool0003o000000ko000000?oooooo`000?l000001Ol0000;ooooo`;o0000
2Oooool5o`0000Sooooo0_l000001Ooooooo0000o`000?l0003ooooo00;o00006_ooool2o`0003_o
oooo000Looooo`03o`000?oooooooooo03Kooooo0_l00009ooooo`;o00001_ooool2o`0000;ooooo
0ol0000@ooooo`;o00000_ooool2o`0000Kooooo0_l00002ooooo`;o00000oooool5o`000004oooo
ool0003o0000ooooo`_o00000_ooool=o`000004ooooool0003o0000ooooo`;o00001oooool2o`00
00Cooooo7Ol0000=ooooo`;o00000oooool2o`0000gooooo0_l000000ooooooo0000o`000004o`00
00Kooooo0_l0000Looooo`;o0000<Oooool001cooooo00?o0000ooooooooool0@Oooool2o`0000_o
oooo0_l00002ooooo`;o00002?ooool2o`0000;ooooo0_l00002ooooo`;o00002_ooool4o`000003
ooooool0003o000000Oo000000Goooooo`000?l0003o0000ooooo`07o`0000;ooooo1ol000000ooo
oooo0000o`000003ooooo`;o000000?oooooo`000?l000003?oooolNo`0000;ooooo0_l00009oooo
o`;o00000oooool2o`00013ooooo1?l00007ooooo`?o00000_ooool2o`0001Sooooo0_l0000aoooo
o`007?ooool00ol0003oooooooooo`13ooooo`;o00003Oooool2o`0000Sooooo0_l0000Dooooo`;o
000000?oooooo`000?l000000_l000000ooooooo0000o`00000:o`0000;ooooo0ol00002ooooo`?o
000000?oooooo`000?l000001Oooool4o`0000Wooooo0_l00003ooooo`ko000000?oooooo`000?l0
00004Ol00005ooooo`Co00005oooool2o`0000;ooooo1?l00003ooooo`;o00000oooool2o`0004_o
oooo000Looooo`03o`000?oooooooooo04?ooooo0_l00003ooooo`;o000000?oooooo`000?l00000
5?ooool2o`000003ooooool0003o000000gooooo0_l000000ooooooo0000o`000004ooooo`Co0000
00Coooooo`000?l0003ooooo0_l00003ooooo`Go00001?ooool4o`0000;ooooo1?l00005ooooo`;o
00000_ooool2o`0000;ooooo8Ol00007ooooo`Co00006oooool4o`0000?ooooo0_l0000Dooooo`;o
000000?oooooo`000?l00000=oooool001cooooo00?o0000ooooooooool0@oooool2o`0000?ooooo
0_l000000ooooooo0000o`000002o`0000cooooo0_l00004ooooo`;o000000?oooooo`000?l00000
0_ooool2o`000003ooooool0003o000000Gooooo0ol000000ooooooo0000o`000004ooooo`?o0000
0_ooool2o`0000Kooooo1Ol00004ooooo`Co000000Coooooo`000?l0003o00000oooool2o`0000;o
oooo0_l00006ooooo`Go000000?oooooo`000?l000006?l00009ooooo`;o00000_ooool2o`0003Go
oooo0_l000000ooooooo0000o`00000gooooo`007?ooool00ol0003oooooooooo`17ooooo`;o0000
1?ooool2o`0000cooooo0_l0000;ooooo`Oo00000oooool2o`0000;ooooo0_l00004ooooo`?o0000
0_ooool2o`0000;ooooo0_l00002ooooo`;o000000?oooooo`000?l000000_l00002ooooo`;o0000
0oooool3o`0000?ooooo0_l0000:ooooo`Co00000_oooolDo`0000;ooooo1?l00005ooooo`;o0000
0_ooool2o`0000;ooooo0_l000000ooooooo0000o`00000<ooooo`;o00000oooool2o`000003oooo
ool0003o000001oooooo0_l0000gooooo`007?ooool00ol0003oooooooooo`17ooooo`;o00002ooo
ool2o`0000Kooooo0_l0000<ooooo`;o000000?oooooo`000?l000001Oooool2o`0000Kooooo0_l0
0003ooooo`Ko00000_ooool2o`0000?ooooo0ol000000ooooooo0000o`000004ooooo`;o00003ooo
oolPo`0000Gooooo0_l00008ooooo`?o00001?ooool2o`0000Kooooo0_l00003ooooo`;o000000?o
ooooo`000?l000007_ooool3o`0003Oooooo000Looooo`03o`000?oooooooooo04_ooooo0_l00000
0ooooooo0000o`000002o`0000;ooooo0_l00006ooooo`;o00005_ooool2o`0000Kooooo0ol00004
ooooo`;o00000oooool2o`0000;ooooo1Ol00009ooooo`;o00002?ooool2o`0000;ooooo0_l00002
ooooo`Oo000000?oooooo`000?l000005?l0000>ooooo`?o00001?ooool2o`000003ooooool0003o
000001Gooooo0_l00009ooooo`;o00002Oooool2o`0003Sooooo000Looooo`03o`000?oooooooooo
04Gooooo0_l00003ooooo`?o000000?oooooo`000?l000000_l0000Yooooo`Co000000?oooooo`00
0?l000001Oooool3o`0000;ooooo1_l00008ooooo`;o00001oooool7o`0000?ooooo7_l00004oooo
o`;o00001Oooool2o`0000;ooooo0_l00006ooooo`;o00005Oooool2o`0000Wooooo0_l00013oooo
o`007?ooool2o`0004Kooooo0ol00002ooooo`;o00001Oooool2o`0000?ooooo0_l0000Pooooo`;o
000000?oooooo`000?l000000oooool2o`0000Gooooo0_l00002ooooo`Co000000?oooooo`000?l0
00004Oooool2o`000003ooooool0003o000000;o00000oooool7o`000003ooooool0003o000001Co
00001?ooool2o`0000Gooooo0_l00002ooooo`;o00006oooool2o`00053ooooo000Looooo`03o`00
0?oooooooooo04Cooooo1?l00009ooooo`;o00000oooool2o`0000Sooooo0_l0000>ooooo`;o0000
1_ooool2o`0000Wooooo0_l00002ooooo`;o00000_ooool4o`0000Cooooo0_l00007ooooo`;o0000
3ooooolLo`0002kooooo0_l00004ooooo`;o00002?ooool2o`00043ooooo000Looooo`03o`000?oo
oooooooo04Cooooo0_l0000=ooooo`;o00000_ooool2o`0000Gooooo1?l0000<ooooo`Co000000?o
ooooo`000?l000001Oooool2o`0000Kooooo0ol00002ooooo`;o00002_ooool2o`0000Cooooo0_l0
00000ooooooo0000o`00000>oooooa?o000000?oooooo`000?l000001ol0000Wooooo`;o00002ooo
ool2o`0000Sooooo0_l00010ooooo`007?ooool00ol0003oooooooooo`1;ooooo`;o00000oooool9
o`0000Gooooo0_l0000>ooooo`?o00000_ooool5o`0000;ooooo0_l00006ooooo`;o00005Oooool2
o`0000Wooooo0ol00003oooooaWo000000Coooooo`000?l0003ooooo0_l00006ooooo`;o00004ooo
ool2o`0000Cooooo0_l00004ooooo`;o0000Eoooool001cooooo00?o0000ooooooooool0AOooool2
o`0000Cooooo0_l00003ooooo`?o00000_ooool2o`0000gooooo0_l00009ooooo`;o00000_ooool9
o`0000Kooooo0_l00006ooooo`;o00001_ooool2o`00013ooooo0ol00003ooooo`?o00000ooooolH
o`0000;ooooo0_l00003ooooo`;o00004oooool8o`0005gooooo000Looooo`03o`000?oooooooooo
04Gooooo0_l00005ooooo`;o00005_ooool2o`0000gooooo0_l00003ooooo`Co00001_ooool2o`00
0003ooooool0003o000000;o000000?oooooo`000?l000000_l00004ooooo`;o00004_ooool3o`00
0005ooooool0003o0000o`000?ooool00_l000000ooooooo0000o`00000Eo`0000;ooooo0_l0000J
ooooo`Co00001?ooool2o`0000Gooooo0_l00008ooooo`;o0000B?ooool001cooooo00?o0000oooo
ooooool0C?ooool2o`00027ooooo0_l0000Dooooo`Ko000000?oooooo`000?l000002?ooool2o`00
00Wooooo0_l00003ooooo`?o00001OoooolIo`000003ooooool0003o000001gooooo0_l00003oooo
o`Co00001Oooool3o`0000Oooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1>ooooo`;o
00000_ooool2o`0000;ooooo1?l00007ooooo`Co00002_ooool2o`0000Kooooo0_l00002ooooo`;o
00002Oooool2o`000003ooooool0003o000000_ooooo0_l00009ooooo`;o00003?ooool3o`000003
ooooool0003o000001Go00004_ooool3o`0000Oooooo0ol00003ooooo`Co00001_ooool2o`00057o
oooo000Looooo`03o`000?oooooooooo04Kooooo0_l00005ooooo`Co000000?oooooo`000?l00000
0_ooool4o`0000Oooooo1?l0000<ooooo`;o00000_ooool4o`0000;ooooo0_l00002ooooo`;o0000
1Oooool2o`0000Cooooo0_l000000ooooooo0000o`00000Dooooo`;o00001_ooool2o`0000;ooooo
6Ol0000Booooo`?o00001_ooool3o`0000Kooooo0_l00003ooooo`;o0000E?ooool001cooooo00?o
0000ooooooooool0A_ooool2o`0000Gooooo1?l0000Hooooo`;o00001_ooool2o`0000;ooooo1?l0
0003ooooo`;o000000?oooooo`000?l000002oooool2o`000003ooooool0003o000000Kooooo0_l0
000<ooooo`?o00001Oooool2o`0000;ooooo7?l000000ooooooo0000o`00000@ooooo`;o000000?o
ooooo`000?l000000_l0000<ooooo`Co0000D_ooool001cooooo00?o0000ooooooooool0EOooool2
o`0001;ooooo0_l00009ooooo`Co00001?ooool2o`0000?ooooo0_l0000Dooooo`;o000000?ooooo
o`000?l000000_ooool2o`0000;ooooo1_l00008ooooo`Co000000?oooooo`000?l000000ooooolC
o`000003ooooool0003o000000[ooooo0ol00003ooooo`Go00002?ooool2o`000003ooooool0003o
000000?ooooo0_l0001Booooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00000_ooool2o`00
00Kooooo0_l0000Dooooo`?o00000oooool2o`000003ooooool0003o000000?ooooo0_l0000Goooo
o`;o00000_ooool8o`0000Sooooo1?l00003ooooo`;o000000Coooooo`000?l0003ooooo2Ol00000
0ooooooo0000o`000004ooooo`;o00001Oooool2o`000003ooooool0003o000000?ooooo0ol00003
ooooo`Co000000?oooooo`000?l000001_ooool5o`0000Sooooo0_l0001=ooooo`007?ooool00ol0
003oooooooooo`1;ooooo`;o00001?ooool2o`0000Gooooo0_l00003ooooo`;o00005?ooool4o`00
00;ooooo0_l00006ooooo`;o00001Oooool2o`0001Kooooo0_l0000<ooooo`;o00000_ooool2o`00
00?ooooo0ol000000ooooooo0000o`000002o`000003ooooool0003o000000;o00000_ooool2o`00
00;ooooo0_l00006ooooo`Go00001?ooool2o`000003ooooool0003o000000;o00000_ooool3o`00
00Oooooo0_l00007ooooo`;o000000?oooooo`000?l00000COooool001cooooo00?o0000oooooooo
ool0Boooool2o`0000Cooooo0_l00005ooooo`;o00001?ooool2o`000003ooooool0003o000001;o
oooo0_l0000Aooooo`;o00001Oooool2o`00027ooooo0_l00003ooooo`;o00000_ooool3o`0000Go
oooo1Ol00002ooooo`;o00001Oooool2o`000003ooooool0003o000000Gooooo0_l000000ooooooo
0000o`000004ooooo`;o00000_ooool2o`0000Cooooo0_l00007ooooo`Co0000C_ooool001cooooo
00?o0000ooooooooool0C_ooool2o`000003ooooool0003o000000_ooooo1Ol0000:ooooo`;o0000
2?ooool2o`0000Wooooo0_l00002ooooo`?o00001_ooool2o`0001cooooo0_l0000=ooooo`Ko0000
00Coooooo`000?l0003o00002?ooool2o`000003ooooool0003o0000017ooooo0_l00002ooooo`;o
00001?ooool3o`0000?ooooo0_l00003ooooo`;o00001oooool2o`0004Gooooo000Looooo`03o`00
0?oooooooooo04kooooo0_l000000ooooooo0000o`00000<ooooo`?o00002oooool2o`0000Sooooo
0_l00003ooooo`;o00000_ooool4o`0000;ooooo0ol0000Jooooo`;o00000_ooool2o`0000Cooooo
0_l00004ooooo`;o00001oooool6o`000003ooooool0003o000000Kooooo0_l000000ooooooo0000
o`000006ooooo`?o00001?ooool2o`0000Gooooo0_l00004ooooo`;o00000oooool2o`0000?ooooo
0_l0000<ooooo`;o0000AOooool001cooooo0_l0001Qooooo`;o00004Oooool2o`0000Oooooo0_l0
0002ooooo`;o00001?ooool2o`0000cooooo0_l0000=ooooo`;o00000_ooool2o`0000;ooooo0_l0
0006ooooo`;o00002Oooool3o`0000;ooooo0ol000000ooooooo0000o`000002ooooo`;o00001?oo
ool2o`0000?ooooo1?l00003ooooo`;o00000oooool2o`000003ooooool0003o000000;o000000?o
ooooo`000?l000000oooool2o`0000kooooo0_l00018ooooo`007?ooool00ol0003oooooooooo`1;
ooooo`;o00001?ooool2o`0000Sooooo0ol00008ooooo`;o00002oooool4o`0000oooooo0_l00009
ooooo`;o000000?oooooo`000?l000004Oooool2o`0000;ooooo0_l0000:ooooo`;o00001Oooool2
o`0000?ooooo0ol000000ooooooo0000o`000002ooooo`;o00000_ooool4o`0000Gooooo0_l00008
ooooo`;o000000?oooooo`000?l000000_l0000Fooooo`;o0000B?ooool001cooooo00?o0000oooo
ooooool0@?ooool2o`0000Wooooo0_l00004ooooo`;o000000?oooooo`000?l000001Oooool3o`00
00Sooooo1?l0000;ooooo`;o00003oooool2o`0000?ooooo0_l00004ooooo`;o00005?ooool2o`00
00kooooo0_l000000ooooooo0000o`000002ooooo`;o00002oooool3o`000003ooooool0003o0000
02;ooooo0_l00008ooooo`Co0000B?ooool001cooooo00?o0000ooooooooool0@?ooool2o`0000[o
oooo0_l00006ooooo`Co00000_ooool4o`0000Wooooo1?l0000Hooooo`;o00001Oooool3o`00023o
oooo0_l00004ooooo`;o00001Oooool2o`0000;ooooo0_l00003ooooo`;o00001oooool2o`0002Go
oooo0_l000000ooooooo0000o`000005ooooo`Co0000B?ooool001cooooo00?o0000ooooooooool0
C?ooool2o`0000Sooooo0_l00002ooooo`Co00002oooool2o`0001Cooooo0_l00002ooooo`;o0000
1Oooool2o`0000Oooooo0_l00006ooooo`;o00004?ooool2o`0000;ooooo1?l00009ooooo`;o0000
0oooool2o`0000Gooooo0_l0000>ooooo`;o00006_ooool2o`0000Gooooo0_l0001:ooooo`007?oo
ool00ol0003oooooooooo`1Eooooo`;o00008?ooool2o`0000Kooooo0_l0000Booooo`;o00001_oo
ool2o`0001Cooooo0_l00004ooooo`;o00001Oooool2o`0000[ooooo0_l00003ooooo`?o00001?oo
ool2o`0000;ooooo0_l00008ooooo`;o00001Oooool2o`0000?ooooo1?l0001Eooooo`007?ooool0
0ol0003oooooooooo`1;ooooo`;o00002?ooool2o`0000_ooooo0_l0000<ooooo`;o00001Oooool2
o`0003[ooooo0_l00002ooooo`;o00001Oooool2o`000003ooooool0003o000000cooooo0ol00004
ooooo`;o00002Oooool2o`000003ooooool0003o000000Gooooo0_l00003ooooo`Co00000oooool2
o`00053ooooo000Looooo`03o`000?oooooooooo04_ooooo1?l00004ooooo`Co00002oooool2o`00
00cooooo0_l0000:ooooo`;o00006oooool4o`00017ooooo0_l00003ooooo`;o00002?ooool2o`00
00;ooooo0_l0000Aooooo`;o00001_ooool3o`0000;ooooo1?l00002ooooo`;o00003_ooool4o`00
04kooooo000Looooo`03o`000?oooooooooo04gooooo0_l00004ooooo`Co00005Oooool2o`0000Co
oooo0_l00008ooooo`;o00001?ooool2o`0001Gooooo1?l0000Aooooo`;o00000oooool2o`0000;o
oooo0_l00004ooooo`;o00005Oooool2o`0000Kooooo0ol00004ooooo`;o00000_ooool2o`00013o
oooo0_l0001>ooooo`007?ooool00ol0003oooooooooo`1Hooooo`;o00001?ooool2o`0000Oooooo
0_l00003ooooo`;o00001?ooool2o`0000Kooooo0_l00006ooooo`;o0000;oooool2o`0000;ooooo
0_l00006ooooo`;o00001oooool2o`0000;ooooo0_l00004ooooo`;o00000_ooool2o`0000Wooooo
0ol00004ooooo`;o00002_ooool2o`0005?ooooo000Looooo`03o`000?oooooooooo053ooooo0_l0
0004ooooo`Co00001?ooool2o`0000Oooooo0_l0000Aooooo`;o00003Oooool2o`0000cooooo0_l0
000Jooooo`;o00002Oooool3o`0000Gooooo1Ol000000ooooooo0000o`000003ooooo`?o00000_oo
ool2o`0000Oooooo1Ol00004ooooo`?o00002Oooool2o`0005?ooooo000Looooo`03o`000?oooooo
oooo053ooooo0_l00004ooooo`Go00001?ooool2o`0000;ooooo0_l0000=ooooo`Co00001oooool2
o`0000?ooooo0_l00005ooooo`;o00002oooool3o`000003ooooool0003o000001oooooo1Ol00002
ooooo`;o00000_ooool5o`0000Kooooo0_l00004ooooo`;o00000oooool2o`000003ooooool0003o
000000Sooooo0_l00003ooooo`;o0000FOooool001cooooo00?o0000ooooooooool0Eoooool4o`00
00Cooooo0_l00002ooooo`Ko00002Oooool4o`0000?ooooo0_l00002ooooo`;o00000oooool2o`00
013ooooo1?l00002ooooo`;o00007oooool4o`0000?ooooo0_l00002ooooo`;o00001?ooool2o`00
00Wooooo0_l00003ooooo`;o00000oooool2o`0000_ooooo0_l0001Iooooo`007?ooool00ol0003o
ooooooooo`1?ooooo`;o00001_ooool4o`0000[ooooo1?l00006ooooo`;o00002?ooool2o`0001Wo
oooo0_l0000Uooooo`;o00003_ooool3o`0000Wooooo0_l00003ooooo`;o00000oooool2o`000003
ooooool0003o000000_ooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1?ooooo`Co0000
1_ooool2o`0000?ooooo1?l0000=ooooo`;o00005Oooool2o`0000_ooooo0_l00003ooooo`Co0000
6?ooool2o`0000Gooooo0_l0000>ooooo`;o00001_ooool3o`0000Kooooo0_l00006ooooo`;o0000
1_ooool2o`0000?ooooo0_l0001Fooooo`007?ooool00ol0003oooooooooo`1Aooooo`;o00001ooo
ool2o`0000;ooooo1?l00002ooooo`?o00002?ooool2o`0001Gooooo0ol0000:ooooo`;o00000ooo
ool4o`0000;ooooo0_l0000Dooooo`;o000000?oooooo`000?l000000_ooool2o`0000gooooo1?l0
0003ooooo`Go00001?ooool2o`0000Cooooo0_l0000:ooooo`;o0000Foooool001cooooo0_l0001B
ooooo`;o00001oooool2o`0000Cooooo0_l00002ooooo`?o00002_ooool4o`000004ooooool0003o
0000ooooo`?o00002oooool2o`0000oooooo0_l00004ooooo`;o00005oooool2o`00017ooooo1?l0
0003ooooo`;o00001oooool2o`0000Cooooo0_l0001Wooooo`007?ooool00ol0003oooooooooo`1A
ooooo`;o00003?ooool2o`0000kooooo1_l000001?oooooo0000o`000?ooool3o`00017ooooo0_l0
0009ooooo`?o0000<_ooool3o`0000Kooooo0_l00008ooooo`;o0000Ioooool001cooooo00?o0000
ooooooooool0Boooool2o`0000kooooo0ol000000ooooooo0000o`00000>ooooo`;o000000?ooooo
o`000?l000001Oooool2o`000003ooooool0003o000000cooooo1Ol0000:ooooo`;o000000?ooooo
o`000?l00000;oooool3o`0000Kooooo0_l00003ooooo`;o00000oooool2o`0006Oooooo000Loooo
o`03o`000?oooooooooo04_ooooo0_l0000>ooooo`?o000000?oooooo`000?l000003Oooool2o`00
00Wooooo0_l000000ooooooo0000o`00000;ooooo`Co00003oooool2o`0001[ooooo0_l0000<oooo
o`;o00004oooool2o`0000Kooooo0_l0001Tooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o
00003?ooool2o`0000;ooooo0_l0000;ooooo`Co00002?ooool2o`000003ooooool0003o000000;o
00002_ooool2o`00017ooooo0_l0000Jooooo`;o00003?ooool2o`0000Sooooo0_l00003ooooo`;o
00001?ooool2o`0000Kooooo0ol0001Sooooo`007?ooool00ol0003oooooooooo`1=ooooo`;o0000
3oooool2o`0000Gooooo0_l00005ooooo`;o00000_ooool2o`000003ooooool0003o000000?ooooo
1ol00002ooooo`;o00002Oooool2o`0000;ooooo0_l00002ooooo`;o00001_ooool2o`0001_ooooo
0_l00003ooooo`;o00000_ooool2o`000003ooooool0003o000000Wooooo0_l00003ooooo`;o0000
3Oooool2o`0006?ooooo000Looooo`03o`000?oooooooooo05kooooo0ol00002ooooo`Co000000?o
ooooo`000?l000001_ooool2o`000003ooooool0003o000000Gooooo0_l00005ooooo`;o00002Ooo
ool2o`0000;ooooo0_l00002ooooo`;o00001?ooool2o`0001gooooo0_l00003ooooo`;o00000_oo
ool2o`000003ooooool0003o000000Cooooo0_l0001looooo`007?ooool00ol0003oooooooooo`1C
ooooo`Co00002?ooool2o`0000;ooooo0_l00003ooooo`;o000000Coooooo`000?l0003o00002?oo
ool2o`0001Kooooo0_l00004ooooo`;o000000Coooooo`000?l0003ooooo0_l0000@ooooo`;o0000
7Oooool2o`0000Kooooo1?l0001booooo`007?ooool00ol0003oooooooooo`1Cooooo`Co00002?oo
ool2o`0000[ooooo0ol00008ooooo`;o00004?ooool2o`0000Cooooo0_l00007ooooo`;o00003Ooo
ool2o`0000Cooooo0_l0000Dooooo`;o00000oooool2o`0000Cooooo0_l00003ooooo`Go0000L_oo
ool001cooooo00?o0000ooooooooool0Goooool2o`0001;ooooo0_l00004ooooo`;o00003Oooool2
o`0000_ooooo0_l0000?ooooo`;o000000?oooooo`000?l000001_ooool2o`0000oooooo0_l00003
ooooo`;o00001?ooool3o`0000;ooooo0ol0001dooooo`007?ooool00ol0003oooooooooo`1Noooo
o`;o00002Oooool2o`0000Cooooo0_l00002ooooo`?o00000oooool2o`0000?ooooo0_l0000Eoooo
o`;o000000?oooooo`000?l000003?ooool2o`000003ooooool0003o000000Kooooo0_l00002oooo
o`?o00000_ooool2o`0000Oooooo0_l00008ooooo`?o0000NOooool001cooooo00?o0000oooooooo
ool0Eoooool2o`0000Gooooo0_l00009ooooo`;o00001?ooool2o`0000?ooooo0_l000001?oooooo
0000o`000?l00004ooooo`;o00000_ooool2o`0000Kooooo0_l000000ooooooo0000o`000002oooo
o`;o00001Oooool2o`0000_ooooo1?l00007ooooo`;o00000oooool3o`0000;ooooo0_l00007oooo
o`;o00001?ooool3o`0007gooooo000Looooo`03o`000?oooooooooo05Oooooo0_l0000<ooooo`;o
00004?ooool3o`0000Sooooo0_l00006ooooo`Go00000_ooool2o`0000cooooo0_l00003ooooo`Go
00001_ooool3o`0000gooooo0_l00004ooooo`;o00000_ooool3o`0000Gooooo0_l00002ooooo`;o
0000L_ooool001cooooo00?o0000ooooooooool0IOooool2o`0001;ooooo0_l00005ooooo`Co0000
1oooool2o`000003ooooool0003o000000oooooo0_l000000ooooooo0000o`000002o`0000Wooooo
0_l00004ooooo`;o00001Oooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l0
00000oooool2o`0000Gooooo0ol000000ooooooo0000o`00001booooo`0000Koooooonk^k_lb<S;o
0000oc8b<_o^k^h5ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0L?ooool2o`0000?ooooo0_l00002ooooo`;o00001?ooool3o`0000Wooooo0_l00000
0ooooooo0000o`00000Booooo`;o00004Oooool2o`0000Gooooo0_l00004ooooo`;o000000?ooooo
o`000?l000000oooool4o`0000Cooooo0_l0001eooooo`0000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0
L?ooool2o`0000?ooooo0_l00003ooooo`;o00000oooool2o`0000[ooooo0_l0000Wooooo`Go0000
1?ooool2o`0000Kooooo0_l00003ooooo`Co0000Noooool00003ooooool@413ooooo00;ooooo00?o
410@ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
N?ooool4o`0003Sooooo1Ol00004ooooo`;o000000?oooooo`000?l000000oooool4o`00083ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`?o0000MOooool6o`0000Wooooo0_l0000;ooooo`;o00005_ooool2o`0000Sooooo
1Ol00003ooooo`;o00000oooool2o`0000Gooooo0_l00008ooooo`;o0000M_ooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo
00?o0000ooooooooool0MOooool4o`0000_ooooo0_l00007ooooo`;o00000_ooool2o`0000;ooooo
0_l0000@ooooo`Co00002?ooool2o`000003ooooool0003o000000;ooooo1_l00005ooooo`;o0000
2_ooool2o`0007Kooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00Wooooo00Go
410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo07Oooooo0_l00002ooooo`Co0000
3_ooool2o`0000;ooooo0ol000000ooooooo0000o`00000@ooooo`;o00003Oooool2o`0000;ooooo
0_l000001?oooooo0000o`000?l00005ooooo`;o00008?ooool2o`00063ooooo00001_ooooooMgMg
oiRHV?ooooooV9RHogMgM`_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooo
oooo06Sooooo0_l0000Aooooo`Co000000?oooooo`000?l000000ol0000;ooooo`Co00003Oooool2
o`0000;ooooo0_l00010ooooo`;o0000H?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^2ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0J?ooool2o`0000cooooo
0_l00008ooooo`Oo000000?oooooo`000?l000001_ooool2o`0000Wooooo0_l00004ooooo`;o0000
0_ooool2o`00027ooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`1dooooo`Co000000?o
ooooo`000?l000001oooool2o`000004ooooool0003o0000ooooo`;o00001_ooool2o`0000Wooooo
0_l0000>ooooo`Co000000?oooooo`000?l000001_ooool2o`000004ooooool0003o0000ooooo`;o
00000oooool2o`0000?ooooo0_l0001oooooo`007?ooool00ol0003oooooooooo`1dooooo`;o0000
0oooool2o`0000Oooooo1?l0000?ooooo`;o00002Oooool2o`0000Wooooo1?l000000ooooooo0000
o`000006ooooo`;o000000Coooooo`000?l0003ooooo0_l00003ooooo`;o0000Q?ooool001cooooo
00?o0000ooooooooool0P_ooool4o`0000oooooo0_l00009ooooo`;o0000Yoooool001cooooo00?o
0000ooooooooool0O?ooool2o`0000Kooooo0_l0000>ooooo`;o00002_ooool2o`0000?ooooo0_l0
0003ooooo`;o00001?ooool2o`0000Oooooo0ol0002=ooooo`007?ooool00ol0003oooooooooo`1l
ooooo`Co00005?ooool2o`0000Wooooo0_l00004ooooo`;o00000oooool2o`0000Cooooo1Ol00004
ooooo`?o0000SOooool001cooooo00?o0000ooooooooool0O_ooool2o`0001oooooo0_l0000Aoooo
o`?o000000?oooooo`000?l00000TOooool001cooooo00?o0000ooooooooool0UOooool2o`0000?o
oooo1?l00003ooooo`;o000000?oooooo`000?l000004?ooool2o`00097ooooo000Looooo`03o`00
0?oooooooooo07?ooooo0_l00007ooooo`;o00002oooool2o`0000;ooooo1?l00002ooooo`Co0000
0oooool4o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`;o0000Woooool001cooooo00?o
0000ooooooooool0Loooool2o`0000Oooooo0_l0000;ooooo`;o00000_ooool4o`0000;ooooo0_l0
000Cooooo`;o0000Woooool001cooooo00?o0000ooooooooool0T_ooool2o`0000Gooooo0_l0002^
ooooo`007?ooool00ol0003oooooooooo`2=ooooo`;o00000oooool2o`0000Gooooo0_l00004oooo
o`?o0000Yoooool001cooooo0_l0002>ooooo`;o00004?ooool3o`0000Oooooo0ol0002Mooooo`00
7?ooool00ol0003oooooooooo`2Sooooo`;o00001?ooool3o`0009gooooo000Looooo`03o`000?oo
oooooooo09gooooo0_l00004ooooo`;o0000Y?ooool001cooooo00?o0000ooooooooool0Voooool4
o`000:[ooooo000Looooo`03o`000?oooooooooo09_ooooo0_l0002/ooooo`007?ooool00ol0003o
ooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o
0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`2Eooooo`;o0000>?ooool2
o`0007Sooooo000Looooo`03o`000?oooooooooo09Gooooo0_l0000hooooo`;o0000N?ooool001co
oooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo
000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0Qoooool2
o`0001Kooooo0_l00005ooooo`;o0000XOooool001cooooo00?o0000ooooooooool0Qoooool2o`00
00kooooo0_l00006ooooo`;o00001Oooool2o`000:7ooooo000Looooo`03o`000?oooooooooo09Oo
oooo0_l0002`ooooo`007?ooool2o`000?ooooooBoooool001cooooo00?o0000ooooooooool0oooo
oom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo
0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003ooooo
ooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000
ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03
o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?oo
ool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool0
01cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[o
oooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo0_l0003ooooood_ooooo000L
ooooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:oooo
o`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?oooooo
B_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3o
oooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001cooooo00?o0000oooooooo
ool0oooooom:ooooo`007?ooool00ol0003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oo
oooooooo0?ooooooB_ooool001cooooo00?o0000ooooooooool0oooooom:ooooo`007?ooool00ol0
003oooooooooo`3ooooood[ooooo000Looooo`03o`000?oooooooooo0?ooooooB_ooool001;ooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooB_ooool001Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3ooooood[ooooo000Dooooo`03o`000?oooooo
oooo00Gooooo0ol0003ooooood[ooooo000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001Co
oooo00?o0000ooooooooool0oooooomBooooo`005?ooool00ol0003oooooooooo`3ooooooe;ooooo
000Dooooo`03o`000?oooooooooo0?ooooooD_ooool001;ooooo00?oEEEEofIVI_l00000oooooomD
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00XOooool01?l@413o0000o`00
0?ooool2o`000003oa0@4?oooooooooo01Kooooo1?l000001Ol@413oooooooooooooooooA4A400;o
000000Wo<S8bomgMgOooooooooooonk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^08cooooo002Rooooo`05o`000?ooooooooooooooool000002Oooool6o`0000cooooo
00?o0000ooooooooool01_ooool02OmgMgOo<S8booooooooooooMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0S?ooool00:;ooooo00Go0000ooooooooooooooooo`00
000Kooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo410@0oooool01Ol@413ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool0R_ooool00:;ooooo00Go0000oooooooooooo
ooooo`000009ooooo`Ko00003?ooool00ol0003oooooooooo`06ooooo`05ogMgMolb<S;ooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0R_ooool0
0:;ooooo00Go0000ohN7QoooooooZJVYo`00000Kooooo`03o`000?oooooooooo00?ooooo00Go0000
ob4Q8Ol0003o<S8bolc<c002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000008cooooo002Qooooo`03oa0@4?l0003oMgMg00;o000000?oV9RHooooooooool0
6Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go410@oooooooooooo
oooooa0@4003ooooo`05oa0@4?ooooooooooooooool@4100S?ooool00<;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg08cooooo0030ooooo`03oeEEEOmVIVKo000000Gooooo1?l00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08cooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0880646, -0.0471599, \
0.00385053, 0.00385053}}]
}, Open  ]],

Cell[BoxData[
    \({18966.5`\ Second, Null}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox["(f) ",
    FontWeight->"Bold"],
  StyleBox["Vortices with opposite signs",
    FontSlant->"Italic"],
  ". One big difference between fluids and self-gravitating systems is that \
fluid vorticity can be both positive and negative, whereas mass density is \
always positive (so far as we know!). Vortices with opposite signs act in \
qualitatively different ways than like-sign vortices. "
}], "Text"],

Cell[TextData[{
  "\t\t(i) Modify the fluid code to handle ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " point vortices, each with arbitrary circulation ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Gamma]\_i\), ",", " ", \(i = 1\), ",", "...", ",", 
          RowBox[{"N", ".", Cell[""]}]}], TraditionalForm]]],
  " (Hint: Define a list ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\)]],
  " whose elements are the circulation of each point vortex.) "
}], "Text"],

Cell[TextData[{
  "\t\t(ii) Analytically determine the dynamics of two isolated point \
vortices with circulations of opposite signs ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]\[Gamma]\)\)]],
  ", separated by distance ",
  Cell[BoxData[
      \(TraditionalForm\`R\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\t\t(iii) Test the code by running an initial condition with ",
  Cell[BoxData[
      \(TraditionalForm\`N = 2\)]],
  " opposite-signed point vortices separated by ",
  Cell[BoxData[
      \(TraditionalForm\`R = 0.3\)]],
  ". Compare to the analytics."
}], "Text"],

Cell["\<\
\t\t(iv) Investigate the dynamics of extended regions of vorticity \
with overall zero circulation:\
\>", "Text"],

Cell[TextData[{
  "\t\t\t(A) ",
  Cell[BoxData[
      \(TraditionalForm\`N = 2000\)]],
  " point vorticies randomly distributed in the cell, of which half have one \
sign of circulation, the other half the opposite sign."
}], "Text"],

Cell[TextData[{
  "\t\t\t(B) Create an initial condition consisting of two opposite-signed \
uniform circular vortex patches of radius ",
  Cell[BoxData[
      \(TraditionalForm\`R = 0.1\)]],
  ", with centers separated by distance ",
  Cell[BoxData[
      \(TraditionalForm\`D = 0.25\)]],
  ".  Take ",
  Cell[BoxData[
      \(TraditionalForm\`N = 1000\)]],
  " (500 in each patch),  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = \ \(\[PlusMinus]2\)/N\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["Nstep",
            FontFamily->"Courier",
            FontWeight->"Bold"], " ", "=", " ", "300"}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["t",
                FontSlant->"Italic"]}]], " ", "=", " ", "0.01"}], 
        TraditionalForm]]],
  ".  (This run requires fine resolution; take ",
  Cell[BoxData[
      \(TraditionalForm\`M > 30\)]],
  "). Do the vortices merge, as they did when they had the same sign of \
vorticity?"
}], "Text"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  StyleBox[" SIMULATION PROJECT: PLASMA WAVES. ",
    FontSlant->"Italic"],
  "If one changes the sign of the interaction potential in Eq. ",
  ButtonBox["(7.3.2)",
    ButtonData:>"(7.3.2)",
    ButtonStyle->"Hyperlink"],
  ", setting ",
  Cell[BoxData[
      \(TraditionalForm\`G = \(-q\^2\)/\((4\ \[Pi]\ m\ \[Epsilon]\_o)\)\)]],
  ", the equations of gravitational dynamics now describe a collection of \
like charges, with charge ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  " and mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ", interacting via the repulsive Coulomb potential ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " through a mean-field interparticle force ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Del]\[Phi]\)\)]],
  ". This collection of charges is called a ",
  StyleBox["one component plasma",
    FontSlant->"Italic"],
  ", since there is only a single charge species present. "
}], "Text",
  CellTags->"i:92"],

Cell[TextData[{
  "\t",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Perform this substitution, and show in a simulation of ",
  Cell[BoxData[
      \(TraditionalForm\`N = 1000\)]],
  "charges with zero initial velocities and random initial conditions that \
the system is now stable. Take ",
  Cell[BoxData[
      \(TraditionalForm\`M = 20, \ 
      m = \(q = 1\)\ , \ \ \[Epsilon]\_0 = \((4  \[Pi])\)\^\(-1\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta]t = 0.003\)]],
  "and run for 60 steps. Plot the particle positions in the ",
  Cell[BoxData[
      \(TraditionalForm\`x - y\)]],
  " plane as an animation. The oscillations one can see here are called ",
  StyleBox["plasma waves",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " We will study the behavior of these plasma oscillations as we vary the \
plasma temperature. First, we will set up an initial condition consisting of \
a single sinusoidal density oscillation with amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`A\_0\)]],
  ". This is done using the rejection method, discussed in Chapter ",
  ButtonBox["8",
    ButtonData:>{"Chapter8.nb", "c:19"},
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[BoxData[{
    \(\(A0 = 0.25;\)\), "\[IndentingNewLine]", 
    \(\(\(w[y_]\  = \ 1\  + \ A0\ Cos[2\ Pi\ y];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(sx[]\  := \ Random[Real, {0, 1}];\)\), "\n", 
    \(\(\(sy[]\  := \ Random[Real, {0, 1.5}];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(s[]\  := \((xx = sx[]; \ \ While[sy[]\  > \ w[xx], \ \ xx = sx[]]; 
        xx)\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.96"],

Cell[TextData[{
  "Positions of the particles can now be obtained using the random variable  \
",
  StyleBox["s[]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". Take as the initial positions "
}], "Text"],

Cell[BoxData[
    \(\(r0\  = \ Table[{Random[], s[]}, {1000}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.97"],

Cell[TextData[{
  "and run the simulation for the same parameters as in part a), wtih zero \
initial velocity and with ",
  Cell[BoxData[
      \(TraditionalForm\`A\_0 = 0.25\)]],
  ". One should see a single well-behaved density oscillation. \n\tDetermine \
the amplitude of the ",
  Cell[BoxData[
      \(TraditionalForm\`cos(2\ \[Pi]\ y)\)]],
  " oscillation by defining"
}], "Text"],

Cell[BoxData[
    \(\(\(amp[n_]\)\(\ \)\(:=\)\(\ \)\(Sum[
        Cos[2\ Pi\ \(r[n]\)[\([m, 2]\)]], {m, 1, 1000}]\)\(\ \)\)\)], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 7.98"],

Cell[TextData[{
  "This function takes the projection of the density onto ",
  Cell[BoxData[
      \(TraditionalForm\`cos(2\ \[Pi]\ y)\)]],
  ", and is equivalent to ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(amp(t)\), "=", 
          RowBox[{"\[Integral]", 
            RowBox[{
              RowBox[{"n", "(", 
                RowBox[{
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["t",
                    FontWeight->"Plain"]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}], 
              " ", \(cos(2  \[Pi]\ y)\), \(\[DifferentialD]\^2 r\)}]}]}], 
        TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"n", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " is the number density.\n\tPlot this function versus ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(t\_n\), "=", 
          RowBox[{"n", " ", 
            StyleBox[
              RowBox[{"\[CapitalDelta]", 
                StyleBox["t",
                  FontSlant->"Italic"]}]]}]}], TraditionalForm]]],
  " and from this graph estimate the period of the plasma oscillation."
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Using the linearized fluid equations ",
  ButtonBox["(7.3.13)",
    ButtonData:>"(7.3.13)",
    ButtonStyle->"Hyperlink"],
  ", determine the frequency of small-amplitude oscillations versus \
wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ". Show that  the oscillation frequency is"
}], "Text",
  CellTags->"i:90"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2 = \(c\^\(\(2\)\(\ \)\)\) 
            k\^2 + \[Omega]\_p\^2\)]],
  ", "
}], "NE3"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is the sound speed, as in Eq. ",
  ButtonBox["(7.3.14)",
    ButtonData:>"(7.3.14)",
    ButtonStyle->"Hyperlink"],
  ",  and  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Omega]\_p\)\(=\)\(\@\(\(q\^2\) 
              n/m\ \[Epsilon]\_o\)\)\(\ \)\)\)]],
  " is the ",
  StyleBox["plasma frequency",
    FontSlant->"Italic"],
  " . Evaluate this frequency for the parameters of part (b) and compare to \
the observed period of oscillation. "
}], "Text"],

Cell[TextData[{
  "\t",
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Increase the temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " of the simulation, and repeat part (b) five times, taking ",
  Cell[BoxData[
      \(TraditionalForm\`\@T = 1, \ 2, 5, 7, 10\)]],
  ". Choose momenta distributed according to a Gaussian distribution using \
the following rejection method algorithm, discussed in Chapter ",
  ButtonBox["8",
    ButtonData:>{"Chapter8.nb", "c:19"},
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[BoxData[{
    \(\(wv[x_]\  := \ 
        Exp[\(-x^2\)/\((2\ T)\)\ ]/Sqrt[2\ T\ Pi\ ];\)\), "\n", 
    \(aa := \(-5\)\ Sqrt[T]; bb = 5\ Sqrt[T];\), "\n", 
    \(\(f00\  := \ 1/Sqrt[2\ T\ Pi];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.99"],

Cell[BoxData[{
    \(\(svx[]\  := \ Random[Real, {aa, bb}];\)\), "\n", 
    \(\(svy[]\  := \ Random[Real, {0, f00}];\)\), "\n", 
    \(sp[]\  := \((xx = svx[]; \ \ While[svy[]\  > \ wv[xx], \ \ xx = svx[]]; 
        xx)\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.100"],

Cell[BoxData[
    \(\(p0 = \ Table[{sp[], sp[]}, {1000}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 7.101"],

Cell[TextData[{
  "For each temperature, determine the oscillation frequency from the \
simulation. Plot this data versus ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " and compare to the prediction of Eq. ",
  ButtonBox["(7.3.26)",
    ButtonData:>"(7.3.26)",
    ButtonStyle->"Hyperlink"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma] = 3\)]],
  " (the value for a one-dimensional ideal adiabatic process), and ",
  Cell[BoxData[
      \(TraditionalForm\`p\_o = n\ \ T\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tNote that for the largest temperatures, the oscillation amplitude damps \
away rapidly with time. This is a phase-mixing process called",
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["Landau",
    ButtonData:>{
      URL[ 
      "http://turnbull.dcs.st-and.ac.uk/~history/Mathematicians/Landau_Lev.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" damping",
    FontSlant->"Italic"],
  ". The process is similar to the phase-mixing observed previously in the \
collisionless Boltzmann equation, in Sec. ",
  ButtonBox["7.1.2",
    ButtonData:>"c:9",
    ButtonStyle->"Hyperlink"],
  ".  It can be understood analytically by solving the linearized \
collisionless Boltzmann equation as an initial-value problem, using methods \
similar to those in Exercise (3).  For more information see ",
  ButtonBox["Birdsall and Langdon (1991)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ", or ",
  ButtonBox["Stix (1962)",
    ButtonData:>{"Chapter5.nb", "refs"},
    ButtonStyle->"Hyperlink"],
  " (in the references for Chapter 5)."
}], "Text",
  CellTags->"i:91"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 746}},
WindowSize->{700, 652},
WindowMargins->{{9, Automatic}, {Automatic, 21}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsection"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->30,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {2, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 4}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {2, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 8}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->15,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{20, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{47, 62}, {0, 14}},
    CellFrameMargins->5,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{34, 62}, {0, 14}},
    CellFrameColor->GrayLevel[0.700008],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{56, 4}, {3, 9}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[0, 1, 1]],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {3, 8}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{57, 4}, {5, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{56, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{40, 4}, {4, 2}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(5.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE2"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(5.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE2"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE2",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE2", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE3"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(5.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE3"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE3",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE3", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE4"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(5.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE4"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE4",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE4", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE5"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(5.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE5"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE5",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE5", "Printout"],
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE6"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(5.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE6"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE6",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE6", "Printout"],
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextTop"],
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{10, 4}, {2, 80}},
    CellHorizontalScrolling->True,
    CellFrameMargins->4,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["TextTop", "Printout"],
    CellMargins->{{2, 4}, {2, 80}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 4},
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["IndentedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.39, 0.59}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.325}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.23,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.145, 0.345, 0.145, 0.345}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.195}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.23, 0.13, 0.13, 0.23, 0.13}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 50}, {2, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    GridBoxOptions->{ColumnWidths->{0.39, 0.59},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.325,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "i:55"->{
    Cell[2057, 66, 113, 2, 36, "Subtitle",
      CellTags->{"i:55", "c:27"}]},
  "c:27"->{
    Cell[2057, 66, 113, 2, 36, "Subtitle",
      CellTags->{"i:55", "c:27"}]},
  "c:28"->{
    Cell[2214, 74, 66, 1, 32, "Subsubtitle",
      CellTags->"c:28"]},
  "i:76"->{
    Cell[2283, 77, 1441, 31, 168, "Text",
      CellTags->"i:76"]},
  "Fig. 7.9"->{
    Cell[3019383, 37346, 250, 5, 27, "Caption",
      CellTags->"Fig. 7.9"]},
  "i:54"->{
    Cell[3021737, 37412, 779, 22, 32, "NE3",
      CellTags->{"i:54", "(7.3.1)"}]},
  "(7.3.1)"->{
    Cell[3021737, 37412, 779, 22, 32, "NE3",
      CellTags->{"i:54", "(7.3.1)"}]},
  "(7.3.2)"->{
    Cell[3022985, 37451, 140, 5, 26, "NE3",
      CellTags->"(7.3.2)"]},
  "c:29"->{
    Cell[3027177, 37568, 75, 1, 24, "Subsubtitle",
      CellTags->"c:29"]},
  "Fig. 7.10"->{
    Cell[3298119, 44322, 516, 12, 42, "Caption",
      CellTags->"Fig. 7.10"]},
  "i:89"->{
    Cell[3299792, 44365, 926, 15, 152, "Text",
      CellTags->"i:89"]},
  "i:61"->{
    Cell[3301512, 44403, 74, 1, 24, "Subsubtitle",
      CellTags->{"i:61", "c:30"}]},
  "c:30"->{
    Cell[3301512, 44403, 74, 1, 24, "Subsubtitle",
      CellTags->{"i:61", "c:30"}]},
  "Cell 7.66"->{
    Cell[3311321, 44708, 2383, 46, 505, "Input",
      CellTags->"Cell 7.66"]},
  "i:60"->{
    Cell[3313707, 44756, 1674, 49, 114, "Text",
      CellTags->"i:60"]},
  "c:31"->{
    Cell[3316913, 44867, 54, 1, 24, "Subsubtitle",
      CellTags->"c:31"]},
  "c:32"->{
    Cell[3316992, 44872, 63, 1, 42, "Section",
      CellTags->"c:32"]},
  "Cell 7.67"->{
    Cell[3319293, 44958, 222, 6, 121, "Input",
      CellTags->"Cell 7.67"]},
  "i:88"->{
    Cell[3319518, 44966, 542, 13, 60, "Text",
      CellTags->"i:88"]},
  "i:58"->{
    Cell[3320063, 44981, 958, 35, 60, "Text",
      CellTags->"i:58"]},
  "(7.3.3)"->{
    Cell[3321024, 45018, 1263, 38, 45, "NE3",
      CellTags->"(7.3.3)"]},
  "i:59"->{
    Cell[3322290, 45058, 725, 27, 41, "Text",
      CellTags->"i:59"]},
  "(7.3.4)"->{
    Cell[3323018, 45087, 999, 29, 45, "NE3",
      CellTags->"(7.3.4)"]},
  "(7.3.5)"->{
    Cell[3324295, 45127, 424, 14, 40, "NE3",
      CellTags->"(7.3.5)"]},
  "(7.3.6)"->{
    Cell[3328215, 45248, 2541, 75, 85, "NE3",
      CellTags->"(7.3.6)"]},
  "Fig. 7.11"->{
    Cell[4143876, 56567, 96, 1, 15, "Caption",
      CellTags->"Fig. 7.11"]},
  "(7.3.7)"->{
    Cell[4144049, 56572, 1780, 44, 115, "NE3",
      CellTags->"(7.3.7)"]},
  "Cell 7.68"->{
    Cell[4147494, 56668, 2441, 46, 406, "Input",
      CellTags->"Cell 7.68"]},
  "Cell 7.69"->{
    Cell[4151741, 56765, 1333, 29, 220, "Input",
      CellTags->"Cell 7.69"]},
  "Cell 7.70"->{
    Cell[4154031, 56832, 395, 10, 140, "Input",
      CellTags->"Cell 7.70"]},
  "i:62"->{
    Cell[4262771, 60014, 70, 1, 31, "Section",
      CellTags->{"i:62", "c:33"}]},
  "c:33"->{
    Cell[4262771, 60014, 70, 1, 31, "Section",
      CellTags->{"i:62", "c:33"}]},
  "(7.3.8)"->{
    Cell[4263713, 60047, 901, 24, 75, "NE3",
      CellTags->"(7.3.8)"]},
  "Cell 7.71"->{
    Cell[4265127, 60091, 3567, 69, 690, "Input",
      CellTags->"Cell 7.71"]},
  "Cell 7.72"->{
    Cell[4272209, 60262, 201, 5, 105, "Input",
      CellTags->"Cell 7.72"]},
  "Cell 7.73"->{
    Cell[4419525, 62797, 433, 10, 121, "Input",
      CellTags->"Cell 7.73"]},
  "i:63"->{
    Cell[4567296, 66642, 121, 4, 31, "Section",
      CellTags->{"i:63", "c:34"}]},
  "c:34"->{
    Cell[4567296, 66642, 121, 4, 31, "Section",
      CellTags->{"i:63", "c:34"}]},
  "Cell 7.74"->{
    Cell[4567852, 66661, 516, 11, 140, "Input",
      CellTags->"Cell 7.74"]},
  "Cell 7.75"->{
    Cell[4568897, 66689, 121, 4, 85, "Input",
      CellTags->"Cell 7.75"]},
  "Cell 7.76"->{
    Cell[4570367, 66726, 4242, 83, 655, "Input",
      CellTags->"Cell 7.76"]},
  "Cell 7.77"->{
    Cell[4575064, 66827, 907, 21, 180, "Input",
      CellTags->"Cell 7.77"]},
  "c:35"->{
    Cell[4576020, 66854, 57, 1, 24, "Subsubtitle",
      CellTags->"c:35"]},
  "c:36"->{
    Cell[4576102, 66859, 50, 1, 36, "Section",
      CellTags->"c:36"]},
  "Cell 7.78"->{
    Cell[4577865, 66916, 613, 14, 215, "Input",
      CellTags->"Cell 7.78"]},
  "Cell 7.79"->{
    Cell[4578865, 66943, 200, 5, 71, "Input",
      CellTags->"Cell 7.79"]},
  "Cell 7.80"->{
    Cell[4580509, 66993, 349, 8, 87, "Input",
      CellTags->"Cell 7.80"]},
  "Cell 7.81"->{
    Cell[4624289, 67972, 689, 15, 200, "Input",
      CellTags->"Cell 7.81"]},
  "(7.3.9)"->{
    Cell[4672689, 68878, 249, 7, 50, "NE3",
      CellTags->"(7.3.9)"]},
  "(7.3.10)"->{
    Cell[4673175, 68895, 739, 21, 35, "NE3",
      CellTags->"(7.3.10)"]},
  "Cell 7.82"->{
    Cell[4675228, 68965, 1396, 27, 390, "Input",
      CellTags->"Cell 7.82"]},
  "Cell 7.83"->{
    Cell[4736653, 70011, 951, 19, 255, "Input",
      CellTags->"Cell 7.83"]},
  "(7.3.11)"->{
    Cell[4776967, 70858, 953, 26, 39, "NE3",
      CellTags->"(7.3.11)"]},
  "(7.3.12)"->{
    Cell[4782241, 71014, 1323, 38, 36, "NE3",
      CellTags->"(7.3.12)"]},
  "i:56"->{
    Cell[4788701, 71215, 85, 1, 30, "Section",
      CellTags->{"i:56", "c:37"}]},
  "c:37"->{
    Cell[4788701, 71215, 85, 1, 30, "Section",
      CellTags->{"i:56", "c:37"}]},
  "i:80"->{
    Cell[4788789, 71218, 756, 20, 72, "Text",
      CellTags->"i:80"]},
  "Cell 7.84"->{
    Cell[4790740, 71271, 449, 10, 135, "Input",
      CellTags->"Cell 7.84"]},
  "Cell 7.85"->{
    Cell[4791263, 71287, 200, 5, 71, "Input",
      CellTags->"Cell 7.85"]},
  "Cell 7.86"->{
    Cell[4792114, 71312, 187, 4, 71, "Input",
      CellTags->"Cell 7.86"]},
  "i:57"->{
    Cell[4832954, 72129, 97, 1, 30, "Section",
      CellTags->{"i:57", "c:38"}]},
  "c:38"->{
    Cell[4832954, 72129, 97, 1, 30, "Section",
      CellTags->{"i:57", "c:38"}]},
  "Cell 7.87"->{
    Cell[4833513, 72146, 453, 10, 119, "Input",
      CellTags->"Cell 7.87"]},
  "Cell 7.88"->{
    Cell[4834158, 72167, 200, 5, 71, "Input",
      CellTags->"Cell 7.88"]},
  "Cell 7.89"->{
    Cell[4834383, 72176, 338, 7, 103, "Input",
      CellTags->"Cell 7.89"]},
  "i:83"->{
    Cell[4872136, 72967, 856, 27, 56, "Text",
      CellTags->"i:83"]},
  "(7.3.13)"->{
    Cell[4872995, 72996, 1241, 36, 85, "NE3",
      CellTags->"(7.3.13)"]},
  "i:81"->{
    Cell[4874857, 73053, 190, 6, 26, "NE3",
      CellTags->{"i:81", "(7.3.14)"}]},
  "(7.3.14)"->{
    Cell[4874857, 73053, 190, 6, 26, "NE3",
      CellTags->{"i:81", "(7.3.14)"}]},
  "(7.3.15)"->{
    Cell[4876267, 73095, 160, 5, 28, "NE3",
      CellTags->"(7.3.15)"]},
  "(7.3.16)"->{
    Cell[4876909, 73116, 189, 6, 34, "NE3",
      CellTags->"(7.3.16)"]},
  "c:39"->{
    Cell[4877927, 73147, 47, 1, 30, "Section",
      CellTags->"c:39"]},
  "(7.3.17)"->{
    Cell[4881125, 73243, 154, 6, 28, "NE3",
      CellTags->"(7.3.17)"]},
  "Cell 7.90"->{
    Cell[4881582, 73265, 1030, 21, 311, "Input",
      CellTags->"Cell 7.90"]},
  "Cell 7.91"->{
    Cell[4882686, 73292, 200, 5, 71, "Input",
      CellTags->"Cell 7.91"]},
  "Cell 7.92"->{
    Cell[4882995, 73304, 298, 6, 103, "Input",
      CellTags->"Cell 7.92"]},
  "c:40"->{
    Cell[4940454, 74325, 65, 1, 24, "Subsubtitle",
      CellTags->"c:40"]},
  "i:82"->{
    Cell[4942234, 74382, 1231, 36, 65, "Text",
      CellTags->"i:82"]},
  "(7.3.18)"->{
    Cell[4943468, 74420, 1678, 46, 68, "NE3",
      CellTags->"(7.3.18)"]},
  "(7.3.19)"->{
    Cell[4949158, 74614, 120, 2, 33, "NE3",
      CellTags->"(7.3.19)"]},
  "i:65"->{
    Cell[4953926, 74767, 623, 13, 95, "Text",
      CellTags->"i:65"]},
  "(7.3.20)"->{
    Cell[4954649, 74787, 649, 20, 41, "NE3",
      CellTags->"(7.3.20)"]},
  "(7.3.21)"->{
    Cell[4955414, 74814, 675, 23, 29, "NE3",
      CellTags->"(7.3.21)"]},
  "i:64"->{
    Cell[4956092, 74839, 536, 18, 44, "Text",
      CellTags->"i:64"]},
  "(7.3.22)"->{
    Cell[4956631, 74859, 606, 21, 30, "NE3",
      CellTags->"(7.3.22)"]},
  "(7.3.23)"->{
    Cell[4958209, 74915, 380, 12, 38, "NE3",
      CellTags->"(7.3.23)"]},
  "i:66"->{
    Cell[4958592, 74929, 1480, 49, 62, "Text",
      CellTags->"i:66"]},
  "(7.3.24)"->{
    Cell[4960075, 74980, 402, 10, 69, "NE3",
      CellTags->"(7.3.24)"]},
  "i:69"->{
    Cell[4960480, 74992, 2160, 60, 133, "Text",
      CellTags->"i:69"]},
  "(7.3.25)"->{
    Cell[4962946, 75066, 1643, 47, 32, "NE3",
      CellTags->"(7.3.25)"]},
  "i:84"->{
    Cell[4964592, 75115, 1482, 43, 112, "Text",
      CellTags->"i:84"]},
  "Table 7.1"->{
    Cell[4966077, 75160, 734, 26, 187, "Text",
      CellTags->"Table 7.1"]},
  "i:68"->{
    Cell[4966814, 75188, 1418, 40, 129, "Text",
      CellTags->"i:68"]},
  "i:67"->{
    Cell[4968235, 75230, 451, 13, 61, "Text",
      CellTags->"i:67"]},
  "Cell 7.93"->{
    Cell[4968689, 75245, 7403, 150, 854, "Input",
      CellTags->"Cell 7.93"]},
  "i:72"->{
    Cell[4980776, 75545, 1200, 38, 78, "Text",
      CellTags->"i:72"]},
  "i:70"->{
    Cell[4983031, 75612, 1459, 47, 95, "Text",
      CellTags->"i:70"]},
  "i:71"->{
    Cell[4984921, 75676, 1145, 30, 136, "Text",
      CellTags->"i:71"]},
  "Cell 7.94"->{
    Cell[4986069, 75708, 788, 17, 199, "Input",
      CellTags->"Cell 7.94"]},
  "Cell 7.95"->{
    Cell[4989274, 75807, 162, 4, 71, "Input",
      CellTags->"Cell 7.95"]},
  "i:92"->{
    Cell[5344541, 89900, 1028, 30, 82, "Text",
      CellTags->"i:92"]},
  "Cell 7.96"->{
    Cell[5346848, 89972, 444, 10, 181, "Input",
      CellTags->"Cell 7.96"]},
  "Cell 7.97"->{
    Cell[5347514, 89993, 124, 3, 67, "Input",
      CellTags->"Cell 7.97"]},
  "Cell 7.98"->{
    Cell[5348030, 90010, 185, 5, 55, "Input",
      CellTags->"Cell 7.98"]},
  "i:90"->{
    Cell[5349800, 90066, 403, 14, 40, "Text",
      CellTags->"i:90"]},
  "Cell 7.99"->{
    Cell[5351433, 90126, 258, 6, 87, "Input",
      CellTags->"Cell 7.99"]},
  "Cell 7.100"->{
    Cell[5351694, 90134, 283, 6, 103, "Input",
      CellTags->"Cell 7.100"]},
  "Cell 7.101"->{
    Cell[5351980, 90142, 120, 3, 55, "Input",
      CellTags->"Cell 7.101"]},
  "i:91"->{
    Cell[5352624, 90165, 1145, 31, 104, "Text",
      CellTags->"i:91"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"i:55", 5386559, 91288},
  {"c:27", 5386650, 91291},
  {"c:28", 5386741, 91294},
  {"i:76", 5386824, 91297},
  {"Fig. 7.9", 5386908, 91300},
  {"i:54", 5386998, 91303},
  {"(7.3.1)", 5387097, 91306},
  {"(7.3.2)", 5387196, 91309},
  {"c:29", 5387281, 91312},
  {"Fig. 7.10", 5387375, 91315},
  {"i:89", 5387467, 91318},
  {"i:61", 5387552, 91321},
  {"c:30", 5387651, 91324},
  {"Cell 7.66", 5387755, 91327},
  {"i:60", 5387847, 91330},
  {"c:31", 5387933, 91333},
  {"c:32", 5388022, 91336},
  {"Cell 7.67", 5388112, 91339},
  {"i:88", 5388202, 91342},
  {"i:58", 5388286, 91345},
  {"(7.3.3)", 5388373, 91348},
  {"i:59", 5388460, 91351},
  {"(7.3.4)", 5388547, 91354},
  {"(7.3.5)", 5388636, 91357},
  {"(7.3.6)", 5388725, 91360},
  {"Fig. 7.11", 5388817, 91363},
  {"(7.3.7)", 5388910, 91366},
  {"Cell 7.68", 5389003, 91369},
  {"Cell 7.69", 5389100, 91372},
  {"Cell 7.70", 5389197, 91375},
  {"i:62", 5389288, 91378},
  {"c:33", 5389383, 91381},
  {"(7.3.8)", 5389481, 91384},
  {"Cell 7.71", 5389572, 91387},
  {"Cell 7.72", 5389669, 91390},
  {"Cell 7.73", 5389764, 91393},
  {"i:63", 5389855, 91396},
  {"c:34", 5389951, 91399},
  {"Cell 7.74", 5390052, 91402},
  {"Cell 7.75", 5390148, 91405},
  {"Cell 7.76", 5390242, 91408},
  {"Cell 7.77", 5390339, 91411},
  {"c:35", 5390430, 91414},
  {"c:36", 5390519, 91417},
  {"Cell 7.78", 5390609, 91420},
  {"Cell 7.79", 5390705, 91423},
  {"Cell 7.80", 5390799, 91426},
  {"Cell 7.81", 5390893, 91429},
  {"(7.3.9)", 5390987, 91432},
  {"(7.3.10)", 5391076, 91435},
  {"Cell 7.82", 5391168, 91438},
  {"Cell 7.83", 5391265, 91441},
  {"(7.3.11)", 5391360, 91444},
  {"(7.3.12)", 5391451, 91447},
  {"i:56", 5391539, 91450},
  {"c:37", 5391634, 91453},
  {"i:80", 5391729, 91456},
  {"Cell 7.84", 5391818, 91459},
  {"Cell 7.85", 5391914, 91462},
  {"Cell 7.86", 5392008, 91465},
  {"i:57", 5392097, 91468},
  {"c:38", 5392192, 91471},
  {"Cell 7.87", 5392292, 91474},
  {"Cell 7.88", 5392388, 91477},
  {"Cell 7.89", 5392482, 91480},
  {"i:83", 5392572, 91483},
  {"(7.3.13)", 5392660, 91486},
  {"i:81", 5392748, 91489},
  {"(7.3.14)", 5392848, 91492},
  {"(7.3.15)", 5392948, 91495},
  {"(7.3.16)", 5393038, 91498},
  {"c:39", 5393124, 91501},
  {"(7.3.17)", 5393213, 91504},
  {"Cell 7.90", 5393304, 91507},
  {"Cell 7.91", 5393401, 91510},
  {"Cell 7.92", 5393495, 91513},
  {"c:40", 5393585, 91516},
  {"i:82", 5393674, 91519},
  {"(7.3.18)", 5393763, 91522},
  {"(7.3.19)", 5393855, 91525},
  {"i:65", 5393941, 91528},
  {"(7.3.20)", 5394029, 91531},
  {"(7.3.21)", 5394120, 91534},
  {"i:64", 5394207, 91537},
  {"(7.3.22)", 5394295, 91540},
  {"(7.3.23)", 5394386, 91543},
  {"i:66", 5394473, 91546},
  {"(7.3.24)", 5394562, 91549},
  {"i:69", 5394649, 91552},
  {"(7.3.25)", 5394739, 91555},
  {"i:84", 5394827, 91558},
  {"Table 7.1", 5394918, 91561},
  {"i:68", 5395008, 91564},
  {"i:67", 5395094, 91567},
  {"Cell 7.93", 5395183, 91570},
  {"i:72", 5395276, 91573},
  {"i:70", 5395361, 91576},
  {"i:71", 5395446, 91579},
  {"Cell 7.94", 5395537, 91582},
  {"Cell 7.95", 5395633, 91585},
  {"i:92", 5395722, 91588},
  {"Cell 7.96", 5395812, 91591},
  {"Cell 7.97", 5395908, 91594},
  {"Cell 7.98", 5396002, 91597},
  {"i:90", 5396091, 91600},
  {"Cell 7.99", 5396180, 91603},
  {"Cell 7.100", 5396275, 91606},
  {"Cell 7.101", 5396372, 91609},
  {"i:91", 5396462, 91612}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 151, 4, 68, "Subtitle"],
Cell[1881, 58, 139, 3, 24, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2057, 66, 113, 2, 36, "Subtitle",
  CellTags->{"i:55", "c:27"}],
Cell[2173, 70, 16, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[2214, 74, 66, 1, 32, "Subsubtitle",
  CellTags->"c:28"],
Cell[2283, 77, 1441, 31, 168, "Text",
  CellTags->"i:76"],
Cell[3727, 110, 3015653, 37234, 279, 3015531, 37230, "GraphicsData", \
"Bitmap", "Picture",
  Evaluatable->False],
Cell[3019383, 37346, 250, 5, 27, "Caption",
  CellTags->"Fig. 7.9"],
Cell[3019636, 37353, 323, 6, 56, "Text"],
Cell[3019962, 37361, 812, 20, 104, "Text"],
Cell[3020777, 37383, 957, 27, 72, "Text"],
Cell[3021737, 37412, 779, 22, 32, "NE3",
  CellTags->{"i:54", "(7.3.1)"}],
Cell[3022519, 37436, 463, 13, 56, "Text"],
Cell[3022985, 37451, 140, 5, 26, "NE3",
  CellTags->"(7.3.2)"],
Cell[3023128, 37458, 187, 6, 24, "Text"],
Cell[3023318, 37466, 893, 21, 120, "Text"],
Cell[3024214, 37489, 542, 10, 88, "Text"],
Cell[3024759, 37501, 848, 19, 104, "Text"],
Cell[3025610, 37522, 932, 28, 72, "Text"],
Cell[3026545, 37552, 595, 11, 88, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3027177, 37568, 75, 1, 24, "Subsubtitle",
  CellTags->"c:29"],
Cell[3027255, 37571, 798, 21, 72, "Text"],
Cell[3028056, 37594, 926, 20, 88, "Text"],
Cell[3028985, 37616, 75, 0, 24, "Text"],
Cell[3029063, 37618, 275, 8, 24, "Text"],
Cell[3029341, 37628, 445, 12, 40, "Text"],
Cell[3029789, 37642, 245, 5, 40, "Text"],
Cell[3030037, 37649, 170, 6, 24, "Text"],
Cell[3030210, 37657, 267906, 6663, 350, 122612, 4864, "GraphicsData", \
"PostScript", "Picture"],
Cell[3298119, 44322, 516, 12, 42, "Caption",
  CellTags->"Fig. 7.10"],
Cell[3298638, 44336, 344, 8, 40, "Text"],
Cell[3298985, 44346, 386, 8, 56, "Text"],
Cell[3299374, 44356, 415, 7, 72, "Text"],
Cell[3299792, 44365, 926, 15, 152, "Text",
  CellTags->"i:89"],
Cell[3300721, 44382, 754, 16, 104, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3301512, 44403, 74, 1, 24, "Subsubtitle",
  CellTags->{"i:61", "c:30"}],
Cell[3301589, 44406, 2433, 69, 79, "Text"],
Cell[3304025, 44477, 770, 25, 31, "UNNEQ"],
Cell[3304798, 44504, 588, 18, 27, "Text"],
Cell[3305389, 44524, 870, 27, 31, "UNNEQ"],
Cell[3306262, 44553, 4277, 124, 168, "Text"],
Cell[3310542, 44679, 776, 27, 45, "Text"],
Cell[3311321, 44708, 2383, 46, 505, "Input",
  CellTags->"Cell 7.66"],
Cell[3313707, 44756, 1674, 49, 114, "Text",
  CellTags->"i:60"],
Cell[3315384, 44807, 649, 22, 27, "Text"],
Cell[3316036, 44831, 840, 31, 61, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[3316913, 44867, 54, 1, 24, "Subsubtitle",
  CellTags->"c:31"],

Cell[CellGroupData[{
Cell[3316992, 44872, 63, 1, 42, "Section",
  CellTags->"c:32"],
Cell[3317058, 44875, 378, 12, 45, "Text"],
Cell[3317439, 44889, 736, 25, 45, "UNNEQ"],
Cell[3318178, 44916, 833, 29, 41, "Text"],
Cell[3319014, 44947, 276, 9, 41, "Text"],
Cell[3319293, 44958, 222, 6, 121, "Input",
  CellTags->"Cell 7.67"],
Cell[3319518, 44966, 542, 13, 60, "Text",
  CellTags->"i:88"],
Cell[3320063, 44981, 958, 35, 60, "Text",
  CellTags->"i:58"],
Cell[3321024, 45018, 1263, 38, 45, "NE3",
  CellTags->"(7.3.3)"],
Cell[3322290, 45058, 725, 27, 41, "Text",
  CellTags->"i:59"],
Cell[3323018, 45087, 999, 29, 45, "NE3",
  CellTags->"(7.3.4)"],
Cell[3324020, 45118, 272, 7, 45, "Text"],
Cell[3324295, 45127, 424, 14, 40, "NE3",
  CellTags->"(7.3.5)"],
Cell[3324722, 45143, 1615, 42, 81, "Text"],
Cell[3326340, 45187, 1872, 59, 110, "Text"],
Cell[3328215, 45248, 2541, 75, 85, "NE3",
  CellTags->"(7.3.6)"],
Cell[3330759, 45325, 813114, 11240, 185, 778757, 10811, "GraphicsData", \
"PostScript", "Picture"],
Cell[4143876, 56567, 96, 1, 15, "Caption",
  CellTags->"Fig. 7.11"],
Cell[4143975, 56570, 71, 0, 25, "Text"],
Cell[4144049, 56572, 1780, 44, 115, "NE3",
  CellTags->"(7.3.7)"],
Cell[4145832, 56618, 909, 23, 80, "Text"],
Cell[4146744, 56643, 363, 9, 41, "Text"],
Cell[4147110, 56654, 381, 12, 45, "Text"],
Cell[4147494, 56668, 2441, 46, 406, "Input",
  CellTags->"Cell 7.68"],
Cell[4149938, 56716, 1800, 47, 130, "Text"],
Cell[4151741, 56765, 1333, 29, 220, "Input",
  CellTags->"Cell 7.69"],
Cell[4153077, 56796, 655, 23, 25, "Text"],
Cell[4153735, 56821, 271, 7, 41, "Text"],

Cell[CellGroupData[{
Cell[4154031, 56832, 395, 10, 140, "Input",
  CellTags->"Cell 7.70"],
Cell[4154429, 56844, 108128, 3156, 370, 31273, 2203, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4262560, 60002, 36, 1, 45, "Output"]
}, Open  ]],
Cell[4262611, 60006, 123, 3, 25, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4262771, 60014, 70, 1, 31, "Section",
  CellTags->{"i:62", "c:33"}],
Cell[4262844, 60017, 866, 28, 61, "Text"],
Cell[4263713, 60047, 901, 24, 75, "NE3",
  CellTags->"(7.3.8)"],
Cell[4264617, 60073, 507, 16, 41, "Text"],
Cell[4265127, 60091, 3567, 69, 690, "Input",
  CellTags->"Cell 7.71"],
Cell[4268697, 60162, 1936, 50, 175, "Text"],
Cell[4270636, 60214, 1334, 35, 95, "Text"],
Cell[4271973, 60251, 211, 7, 25, "Text"],

Cell[CellGroupData[{
Cell[4272209, 60262, 201, 5, 105, "Input",
  CellTags->"Cell 7.72"],
Cell[4272413, 60269, 146656, 2512, 300, 33748, 1114, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4419084, 62784, 416, 9, 60, "Text"],

Cell[CellGroupData[{
Cell[4419525, 62797, 433, 10, 121, "Input",
  CellTags->"Cell 7.73"],
Cell[4419961, 62809, 147027, 3820, 370, 53055, 2655, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4567003, 66632, 256, 5, 41, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4567296, 66642, 121, 4, 31, "Section",
  CellTags->{"i:63", "c:34"}],
Cell[4567420, 66648, 429, 11, 60, "Text"],
Cell[4567852, 66661, 516, 11, 140, "Input",
  CellTags->"Cell 7.74"],
Cell[4568371, 66674, 358, 6, 60, "Text"],
Cell[4568732, 66682, 140, 3, 25, "Text"],

Cell[CellGroupData[{
Cell[4568897, 66689, 121, 4, 85, "Input",
  CellTags->"Cell 7.75"],
Cell[4569021, 66695, 861, 15, 225, "Output"]
}, Open  ]],
Cell[4569897, 66713, 98, 3, 25, "Text"],
Cell[4569998, 66718, 366, 6, 60, "Text"],
Cell[4570367, 66726, 4242, 83, 655, "Input",
  CellTags->"Cell 7.76"],
Cell[4574612, 66811, 449, 14, 25, "Text"],
Cell[4575064, 66827, 907, 21, 180, "Input",
  CellTags->"Cell 7.77"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4576020, 66854, 57, 1, 24, "Subsubtitle",
  CellTags->"c:35"],

Cell[CellGroupData[{
Cell[4576102, 66859, 50, 1, 36, "Section",
  CellTags->"c:36"],
Cell[4576155, 66862, 1130, 27, 104, "Text"],
Cell[4577288, 66891, 106, 4, 24, "UNNEQ"],
Cell[4577397, 66897, 443, 15, 40, "Text"],

Cell[CellGroupData[{
Cell[4577865, 66916, 613, 14, 215, "Input",
  CellTags->"Cell 7.78"],
Cell[4578481, 66932, 56, 1, 38, "Output"]
}, Open  ]],
Cell[4578552, 66936, 310, 5, 56, "Text"],
Cell[4578865, 66943, 200, 5, 71, "Input",
  CellTags->"Cell 7.79"],
Cell[4579068, 66950, 75, 1, 43, "Input"],
Cell[4579146, 66953, 429, 9, 56, "Text"],
Cell[4579578, 66964, 906, 25, 56, "Text"],

Cell[CellGroupData[{
Cell[4580509, 66993, 349, 8, 87, "Input",
  CellTags->"Cell 7.80"],
Cell[4580861, 67003, 40525, 887, 258, 9072, 494, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4621401, 67893, 690, 18, 72, "Text"],
Cell[4622094, 67913, 875, 17, 104, "Text"],
Cell[4622972, 67932, 1292, 36, 60, "Text"],

Cell[CellGroupData[{
Cell[4624289, 67972, 689, 15, 200, "Input",
  CellTags->"Cell 7.81"],
Cell[4624981, 67989, 47307, 874, 230, 5742, 356, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4672303, 68866, 290, 5, 60, "Text"],
Cell[4672596, 68873, 90, 3, 25, "Text"],
Cell[4672689, 68878, 249, 7, 50, "NE3",
  CellTags->"(7.3.9)"],
Cell[4672941, 68887, 231, 6, 41, "Text"],
Cell[4673175, 68895, 739, 21, 35, "NE3",
  CellTags->"(7.3.10)"],
Cell[4673917, 68918, 403, 10, 60, "Text"],
Cell[4674323, 68930, 384, 10, 60, "Text"],
Cell[4674710, 68942, 339, 11, 50, "UNNEQ"],
Cell[4675052, 68955, 151, 6, 25, "Text"],

Cell[CellGroupData[{
Cell[4675228, 68965, 1396, 27, 390, "Input",
  CellTags->"Cell 7.82"],
Cell[4676627, 68994, 59660, 998, 230, 5168, 321, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4736302, 69995, 127, 3, 25, "Text"],
Cell[4736432, 70000, 196, 7, 25, "Text"],

Cell[CellGroupData[{
Cell[4736653, 70011, 951, 19, 255, "Input",
  CellTags->"Cell 7.83"],
Cell[4737607, 70032, 38609, 804, 230, 7849, 420, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4776231, 70839, 733, 17, 72, "Text"],
Cell[4776967, 70858, 953, 26, 39, "NE3",
  CellTags->"(7.3.11)"],
Cell[4777923, 70886, 363, 12, 24, "Text"],
Cell[4778289, 70900, 791, 23, 30, "UNNEQ"],
Cell[4779083, 70925, 2279, 70, 101, "Text"],
Cell[4781365, 70997, 873, 15, 104, "Text"],
Cell[4782241, 71014, 1323, 38, 36, "NE3",
  CellTags->"(7.3.12)"],
Cell[4783567, 71054, 2551, 77, 102, "Text"],
Cell[4786121, 71133, 997, 29, 57, "Text"],
Cell[4787121, 71164, 248, 5, 40, "Text"],
Cell[4787372, 71171, 326, 6, 56, "Text"],
Cell[4787701, 71179, 324, 10, 24, "Text"],
Cell[4788028, 71191, 323, 10, 24, "Text"],
Cell[4788354, 71203, 310, 7, 40, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4788701, 71215, 85, 1, 30, "Section",
  CellTags->{"i:56", "c:37"}],
Cell[4788789, 71218, 756, 20, 72, "Text",
  CellTags->"i:80"],
Cell[4789548, 71240, 543, 10, 88, "Text"],
Cell[4790094, 71252, 621, 15, 88, "Text"],

Cell[CellGroupData[{
Cell[4790740, 71271, 449, 10, 135, "Input",
  CellTags->"Cell 7.84"],
Cell[4791192, 71283, 56, 1, 38, "Output"]
}, Open  ]],
Cell[4791263, 71287, 200, 5, 71, "Input",
  CellTags->"Cell 7.85"],
Cell[4791466, 71294, 58, 1, 43, "Input"],
Cell[4791527, 71297, 562, 11, 96, "Text"],

Cell[CellGroupData[{
Cell[4792114, 71312, 187, 4, 71, "Input",
  CellTags->"Cell 7.86"],
Cell[4792304, 71318, 39696, 790, 186, 5122, 359, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4832015, 72111, 902, 13, 152, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4832954, 72129, 97, 1, 30, "Section",
  CellTags->{"i:57", "c:38"}],
Cell[4833054, 72132, 456, 12, 56, "Text"],
Cell[4833513, 72146, 453, 10, 119, "Input",
  CellTags->"Cell 7.87"],

Cell[CellGroupData[{
Cell[4833991, 72160, 81, 1, 43, "Input"],
Cell[4834075, 72163, 68, 1, 38, "Output"]
}, Open  ]],
Cell[4834158, 72167, 200, 5, 71, "Input",
  CellTags->"Cell 7.88"],

Cell[CellGroupData[{
Cell[4834383, 72176, 338, 7, 103, "Input",
  CellTags->"Cell 7.89"],
Cell[4834724, 72185, 37397, 779, 186, 6161, 389, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4872136, 72967, 856, 27, 56, "Text",
  CellTags->"i:83"],
Cell[4872995, 72996, 1241, 36, 85, "NE3",
  CellTags->"(7.3.13)"],
Cell[4874239, 73034, 615, 17, 72, "Text"],
Cell[4874857, 73053, 190, 6, 26, "NE3",
  CellTags->{"i:81", "(7.3.14)"}],
Cell[4875050, 73061, 442, 12, 41, "Text"],
Cell[4875495, 73075, 769, 18, 90, "Text"],
Cell[4876267, 73095, 160, 5, 28, "NE3",
  CellTags->"(7.3.15)"],
Cell[4876430, 73102, 476, 12, 58, "Text"],
Cell[4876909, 73116, 189, 6, 34, "NE3",
  CellTags->"(7.3.16)"],
Cell[4877101, 73124, 789, 18, 104, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[4877927, 73147, 47, 1, 30, "Section",
  CellTags->"c:39"],
Cell[4877977, 73150, 2764, 79, 107, "Text"],
Cell[4880744, 73231, 378, 10, 56, "Text"],
Cell[4881125, 73243, 154, 6, 28, "NE3",
  CellTags->"(7.3.17)"],
Cell[4881282, 73251, 275, 10, 24, "Text"],

Cell[CellGroupData[{
Cell[4881582, 73265, 1030, 21, 311, "Input",
  CellTags->"Cell 7.90"],
Cell[4882615, 73288, 56, 1, 38, "Output"]
}, Open  ]],
Cell[4882686, 73292, 200, 5, 71, "Input",
  CellTags->"Cell 7.91"],
Cell[4882889, 73299, 81, 1, 43, "Input"],

Cell[CellGroupData[{
Cell[4882995, 73304, 298, 6, 103, "Input",
  CellTags->"Cell 7.92"],
Cell[4883296, 73312, 56081, 984, 186, 5733, 358, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[4939392, 74299, 253, 5, 56, "Text"],
Cell[4939648, 74306, 757, 13, 120, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[4940454, 74325, 65, 1, 24, "Subsubtitle",
  CellTags->"c:40"],
Cell[4940522, 74328, 418, 13, 44, "Text"],
Cell[4940943, 74343, 1288, 37, 95, "Text"],
Cell[4942234, 74382, 1231, 36, 65, "Text",
  CellTags->"i:82"],
Cell[4943468, 74420, 1678, 46, 68, "NE3",
  CellTags->"(7.3.18)"],
Cell[4945149, 74468, 566, 22, 30, "Text"],
Cell[4945718, 74492, 241, 8, 27, "Text"],
Cell[4945962, 74502, 252, 6, 45, "UNNEQ"],
Cell[4946217, 74510, 666, 20, 73, "Text"],
Cell[4946886, 74532, 146, 5, 32, "UNNEQ"],
Cell[4947035, 74539, 575, 19, 65, "Text"],
Cell[4947613, 74560, 255, 10, 27, "Text"],
Cell[4947871, 74572, 1107, 33, 153, "Text"],
Cell[4948981, 74607, 174, 5, 27, "Text"],
Cell[4949158, 74614, 120, 2, 33, "NE3",
  CellTags->"(7.3.19)"],
Cell[4949281, 74618, 1092, 28, 112, "Text"],
Cell[4950376, 74648, 736, 22, 27, "Text"],
Cell[4951115, 74672, 1759, 58, 79, "Text"],
Cell[4952877, 74732, 1046, 33, 87, "Text"],
Cell[4953926, 74767, 623, 13, 95, "Text",
  CellTags->"i:65"],
Cell[4954552, 74782, 94, 3, 27, "Text"],
Cell[4954649, 74787, 649, 20, 41, "NE3",
  CellTags->"(7.3.20)"],
Cell[4955301, 74809, 110, 3, 27, "Text"],
Cell[4955414, 74814, 675, 23, 29, "NE3",
  CellTags->"(7.3.21)"],
Cell[4956092, 74839, 536, 18, 44, "Text",
  CellTags->"i:64"],
Cell[4956631, 74859, 606, 21, 30, "NE3",
  CellTags->"(7.3.22)"],
Cell[4957240, 74882, 966, 31, 62, "Text"],
Cell[4958209, 74915, 380, 12, 38, "NE3",
  CellTags->"(7.3.23)"],
Cell[4958592, 74929, 1480, 49, 62, "Text",
  CellTags->"i:66"],
Cell[4960075, 74980, 402, 10, 69, "NE3",
  CellTags->"(7.3.24)"],
Cell[4960480, 74992, 2160, 60, 133, "Text",
  CellTags->"i:69"],
Cell[4962643, 75054, 300, 10, 27, "Text"],
Cell[4962946, 75066, 1643, 47, 32, "NE3",
  CellTags->"(7.3.25)"],
Cell[4964592, 75115, 1482, 43, 112, "Text",
  CellTags->"i:84"],
Cell[4966077, 75160, 734, 26, 187, "Text",
  CellTags->"Table 7.1"],
Cell[4966814, 75188, 1418, 40, 129, "Text",
  CellTags->"i:68"],
Cell[4968235, 75230, 451, 13, 61, "Text",
  CellTags->"i:67"],
Cell[4968689, 75245, 7403, 150, 854, "Input",
  CellTags->"Cell 7.93"],
Cell[4976095, 75397, 1297, 42, 91, "Text"],
Cell[4977395, 75441, 482, 15, 44, "Text"],
Cell[4977880, 75458, 578, 18, 48, "Text"],
Cell[4978461, 75478, 1431, 39, 102, "Text"],
Cell[4979895, 75519, 878, 24, 65, "Text"],
Cell[4980776, 75545, 1200, 38, 78, "Text",
  CellTags->"i:72"],
Cell[4981979, 75585, 1049, 25, 112, "Text"],
Cell[4983031, 75612, 1459, 47, 95, "Text",
  CellTags->"i:70"],
Cell[4984493, 75661, 425, 13, 44, "Text"],
Cell[4984921, 75676, 1145, 30, 136, "Text",
  CellTags->"i:71"],
Cell[4986069, 75708, 788, 17, 199, "Input",
  CellTags->"Cell 7.94"],
Cell[4986860, 75727, 453, 9, 72, "Text"],
Cell[4987316, 75738, 366, 9, 40, "Text"],
Cell[4987685, 75749, 1090, 34, 88, "Text"],
Cell[4988778, 75785, 108, 5, 24, "Text"],
Cell[4988889, 75792, 139, 3, 40, "Text"],
Cell[4989031, 75797, 218, 6, 40, "Text"],

Cell[CellGroupData[{
Cell[4989274, 75807, 162, 4, 71, "Input",
  CellTags->"Cell 7.95"],

Cell[CellGroupData[{
Cell[4989461, 75815, 158128, 6768, 296, 116028, 6244, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5147592, 82585, 193870, 7210, 296, 115984, 6244, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[5341477, 89798, 58, 1, 38, "Output"]
}, Open  ]],
Cell[5341550, 89802, 435, 10, 61, "Text"],
Cell[5341988, 89814, 488, 13, 46, "Text"],
Cell[5342479, 89829, 302, 9, 44, "Text"],
Cell[5342784, 89840, 283, 8, 44, "Text"],
Cell[5343070, 89850, 123, 3, 27, "Text"],
Cell[5343196, 89855, 233, 6, 44, "Text"],
Cell[5343432, 89863, 1106, 35, 78, "Text"],
Cell[5344541, 89900, 1028, 30, 82, "Text",
  CellTags->"i:92"],
Cell[5345572, 89932, 762, 22, 81, "Text"],
Cell[5346337, 89956, 508, 14, 61, "Text"],
Cell[5346848, 89972, 444, 10, 181, "Input",
  CellTags->"Cell 7.96"],
Cell[5347295, 89984, 216, 7, 27, "Text"],
Cell[5347514, 89993, 124, 3, 67, "Input",
  CellTags->"Cell 7.97"],
Cell[5347641, 89998, 386, 10, 69, "Text"],
Cell[5348030, 90010, 185, 5, 55, "Input",
  CellTags->"Cell 7.98"],
Cell[5348218, 90017, 1579, 47, 80, "Text"],
Cell[5349800, 90066, 403, 14, 40, "Text",
  CellTags->"i:90"],
Cell[5350206, 90082, 151, 5, 26, "NE3"],
Cell[5350360, 90089, 537, 17, 58, "Text"],
Cell[5350900, 90108, 530, 16, 57, "Text"],
Cell[5351433, 90126, 258, 6, 87, "Input",
  CellTags->"Cell 7.99"],
Cell[5351694, 90134, 283, 6, 103, "Input",
  CellTags->"Cell 7.100"],
Cell[5351980, 90142, 120, 3, 55, "Input",
  CellTags->"Cell 7.101"],
Cell[5352103, 90147, 518, 16, 56, "Text"],
Cell[5352624, 90165, 1145, 31, 104, "Text",
  CellTags->"i:91"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

